import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$main$ui$cursors$resize_ew$$=function($rot__73700__auto__$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__73700__auto__$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_nesw$$=function($rot__73700__auto__$jscomp$1$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(45+$rot__73700__auto__$jscomp$1$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_ns$$=function($rot__73700__auto__$jscomp$2$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__73700__auto__$jscomp$2$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_nwse$$=function($rot__73700__auto__$jscomp$3$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(135+$rot__73700__auto__$jscomp$3$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$rotate$$=function($rot__73700__auto__$jscomp$4$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__73700__auto__$jscomp$4$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%31%20%33%2E%37%4C%33%2E%37%20%31%6C%32%2E%37%20%32%2E%37%2D%2E%36%2E%36%2D%31%2E%37%2D%31%2E%38%68%2D%2E%38%4C%31%2E%36%20%34%2E%33%20%31%20%33%2E%37%7A%4D%31%32%2E%33%20%31%35%6C%32%2E%37%2D%32%2E%37%2D%32%2E%38%2D%32%2E%38%2D%2E%36%2E%36%20%31%2E%39%20%31%2E%38%76%2E%38%6C%2D%31%2E%38%20%31%2E%37%2E%36%2E%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%33%2E%32%20%31%2E%39%76%2E%34%41%31%30%2E%35%20%31%30%2E%35%20%30%20%30%30%31%34%20%31%32%2E%38%76%2D%2E%39%68%2D%2E%34%41%39%2E%36%20%39%2E%36%20%30%20%30%31%34%2E%31%20%32%48%33%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%33%2E%37%2E%33%4C%37%20%33%2E%37%20%35%2E%38%20%35%20%34%2E%37%20%33%2E%38%61%39%2E%31%20%39%2E%31%20%30%20%30%30%37%2E%34%20%37%2E%35%4C%31%31%20%31%30%2E%31%6C%31%2E%33%2D%31%2E%33%20%33%2E%35%20%33%2E%35%2D%33%2E%34%20%33%2E%34%2D%31%2E%33%2D%31%2E%33%20%31%2E%32%2D%31%2E%32%61%31%31%20%31%31%20%30%20%30%31%2D%39%2E%34%2D%39%2E%34%4C%31%2E%36%20%35%20%2E%33%20%33%2E%37%20%33%2E%37%2E%33%7A%6D%2D%2E%35%20%32%2E%33%76%2E%37%61%31%30%2E%35%20%31%30%2E%35%20%30%20%30%30%31%30%2E%31%20%39%2E%35%6C%2D%31%2E%36%20%31%2E%36%2E%36%2E%36%20%32%2E%37%2D%32%2E%37%2D%32%2E%38%2D%32%2E%38%2D%2E%36%2E%36%20%31%2E%39%20%31%2E%38%61%31%33%33%2E%35%20%31%33%33%2E%35%20%30%20%30%30%2D%2E%37%20%30%41%39%2E%36%20%39%2E%36%20%30%20%30%31%34%20%32%2E%35%6C%31%2E%38%20%31%2E%38%2E%36%2D%2E%36%4C%33%2E%37%20%31%20%31%20%33%2E%37%6C%2E%36%2E%36%20%31%2E%36%2D%31%2E%37%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$text$$=function($rot__73700__auto__$jscomp$5$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__73700__auto__$jscomp$5$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%35%20%2E%35%76%32%63%31%2E%35%20%30%20%32%20%2E%39%20%32%20%32%76%37%63%30%20%31%2E%31%2D%2E%35%20%32%2D%32%20%32%76%32%63%31%2E%35%20%30%20%32%2E%34%2D%2E%34%20%33%2D%31%20%2E%36%2E%36%20%31%2E%35%20%31%20%33%20%31%76%2D%32%63%2D%31%2E%35%20%30%2D%32%2D%2E%39%2D%32%2D%32%76%2D%37%63%30%2D%31%2E%31%2E%35%2D%32%20%32%2D%32%76%2D%32%63%2D%31%2E%35%20%30%2D%32%2E%34%2E%34%2D%33%20%31%2D%2E%36%2D%2E%36%2D%31%2E%35%2D%31%2D%33%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%35%20%31%76%31%61%32%20%32%20%30%20%30%31%32%20%32%76%38%61%32%20%32%20%30%20%30%31%2D%32%20%32%76%31%63%31%20%30%20%32%2D%2E%35%20%32%2E%35%2D%31%2E%33%61%33%20%33%20%30%20%30%30%32%2E%35%20%31%2E%33%76%2D%31%61%32%20%32%20%30%20%30%31%2D%32%2D%32%56%34%63%30%2D%31%2E%31%2E%39%2D%32%20%32%2D%32%56%31%63%2D%31%20%30%2D%32%20%2E%35%2D%32%2E%35%20%31%2E%33%41%33%20%33%20%30%20%30%30%35%2E%35%20%31%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_ew$$=function($rot__73700__auto__$jscomp$6$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__73700__auto__$jscomp$6$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_nesw$$=function($rot__73700__auto__$jscomp$7$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(45+$rot__73700__auto__$jscomp$7$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_ns$$=function($rot__73700__auto__$jscomp$8$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__73700__auto__$jscomp$8$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_nwse$$=function($rot__73700__auto__$jscomp$9$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(135+$rot__73700__auto__$jscomp$9$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_ew_2$$=function($rot__73700__auto__$jscomp$10$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__73700__auto__$jscomp$10$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%39%2E%38%36%36%39%39%39%38%2C%38%2E%38%35%39%30%30%30%32%20%68%20%2D%33%2E%37%33%34%20%56%20%31%30%2E%37%33%32%20%4C%20%2D%30%2E%30%30%31%30%30%30%31%39%2C%38%2E%30%30%30%30%30%30%32%20%36%2E%31%33%32%39%39%39%38%2C%35%2E%32%36%38%30%30%30%31%20%76%20%31%2E%38%37%33%20%68%20%33%2E%37%33%34%20%76%20%2D%31%2E%38%37%33%20%4C%20%31%36%2E%30%30%31%2C%38%2E%30%30%30%30%30%30%32%20%39%2E%38%36%36%39%39%39%38%2C%31%30%2E%37%33%32%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%31%30%2E%34%2C%38%2E%33%39%30%30%30%30%32%20%48%20%35%2E%35%39%39%39%39%39%38%20%56%20%39%2E%39%35%30%39%39%39%39%20%4C%20%30%2E%37%39%39%39%39%39%38%31%2C%38%2E%30%30%30%30%30%30%32%20%35%2E%35%39%39%39%39%39%38%2C%36%2E%30%34%39%30%30%30%31%20%76%20%31%2E%35%36%20%48%20%31%30%2E%34%20%76%20%2D%31%2E%35%36%20%6C%20%34%2E%38%2C%31%2E%39%35%31%30%30%30%31%20%2D%34%2E%38%2C%31%2E%39%35%30%39%39%39%37%20%56%20%38%2E%33%39%31%30%30%30%32%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_ns_2$$=function($rot__73700__auto__$jscomp$11$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__73700__auto__$jscomp$11$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%39%2E%38%36%36%39%39%39%38%2C%38%2E%38%35%39%30%30%30%32%20%68%20%2D%33%2E%37%33%34%20%56%20%31%30%2E%37%33%32%20%4C%20%2D%30%2E%30%30%31%30%30%30%31%39%2C%38%2E%30%30%30%30%30%30%32%20%36%2E%31%33%32%39%39%39%38%2C%35%2E%32%36%38%30%30%30%31%20%76%20%31%2E%38%37%33%20%68%20%33%2E%37%33%34%20%76%20%2D%31%2E%38%37%33%20%4C%20%31%36%2E%30%30%31%2C%38%2E%30%30%30%30%30%30%32%20%39%2E%38%36%36%39%39%39%38%2C%31%30%2E%37%33%32%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%31%30%2E%34%2C%38%2E%33%39%30%30%30%30%32%20%48%20%35%2E%35%39%39%39%39%39%38%20%56%20%39%2E%39%35%30%39%39%39%39%20%4C%20%30%2E%37%39%39%39%39%39%38%31%2C%38%2E%30%30%30%30%30%30%32%20%35%2E%35%39%39%39%39%39%38%2C%36%2E%30%34%39%30%30%30%31%20%76%20%31%2E%35%36%20%48%20%31%30%2E%34%20%76%20%2D%31%2E%35%36%20%6C%20%34%2E%38%2C%31%2E%39%35%31%30%30%30%31%20%2D%34%2E%38%2C%31%2E%39%35%30%39%39%39%37%20%56%20%38%2E%33%39%31%30%30%30%32%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$common$uri$query_string__GT_map$$=function($s$jscomp$352$$){return $APP.$lambdaisland$uri$query_string__GT_map$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$352$$)},$app$common$schema$validate$$=function($s$jscomp$377$$,$value$jscomp$315$$){return $APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$377$$,$value$jscomp$315$$)},$rumext$v2$render_BANG_$$=function(){var $root$jscomp$27$$=$app$main$app_root$$,$element$jscomp$56$$=$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$01$$();
return $root$jscomp$27$$.render($element$jscomp$56$$)},$cljs$core$_methods$$=function(){var $JSCompiler_temp$jscomp$2022_mf$jscomp$11$$=$app$main$ui$releases$common$render_release_notes$$;if($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$!=null&&$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$.$cljs$core$IMultiFn$_methods$arity$1$!=null)$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$=$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$.$cljs$core$IMultiFn$_methods$arity$1$($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$);
else{var $m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$=$cljs$core$_methods$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$==null?null:$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$)];if($m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$!=null)$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$=$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$):
$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$);else if($m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$=$cljs$core$_methods$$._,$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$!=null)$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$=$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$):
$m__5372__auto__$jscomp$inline_9603_m__5374__auto__$jscomp$inline_9602$$($JSCompiler_temp$jscomp$2022_mf$jscomp$11$$);else throw $APP.$cljs$core$missing_protocol$$("IMultiFn.-methods",$JSCompiler_temp$jscomp$2022_mf$jscomp$11$$);}return $JSCompiler_temp$jscomp$2022_mf$jscomp$11$$},$app$util$object$without_empty$$=function($obj$jscomp$126$$){return $obj$jscomp$126$$!=null?Object.entries($obj$jscomp$126$$).reduce(($a$jscomp$300$$,[$k$jscomp$525$$,$v$jscomp$315$$])=>$v$jscomp$315$$==null?$a$jscomp$300$$:
($a$jscomp$300$$[$k$jscomp$525$$]=$v$jscomp$315$$,$a$jscomp$300$$),{}):null},$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$01$$=function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$app$$,{},void 0)},$app$common$types$tokens_lib$enable_set$$=function($JSCompiler_temp$jscomp$2024__$jscomp$1300$$,$set_name$jscomp$2$$){if($JSCompiler_temp$jscomp$2024__$jscomp$1300$$!=null&&$JSCompiler_temp$jscomp$2024__$jscomp$1300$$.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$!=null)$JSCompiler_temp$jscomp$2024__$jscomp$1300$$=
$JSCompiler_temp$jscomp$2024__$jscomp$1300$$.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$($JSCompiler_temp$jscomp$2024__$jscomp$1300$$,$set_name$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$=$app$common$types$tokens_lib$enable_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2024__$jscomp$1300$$==null?null:$JSCompiler_temp$jscomp$2024__$jscomp$1300$$)];if($m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$!=null)$JSCompiler_temp$jscomp$2024__$jscomp$1300$$=
$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2024__$jscomp$1300$$,$set_name$jscomp$2$$):$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$($JSCompiler_temp$jscomp$2024__$jscomp$1300$$,$set_name$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$=$app$common$types$tokens_lib$enable_set$$._,
$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$!=null)$JSCompiler_temp$jscomp$2024__$jscomp$1300$$=$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2024__$jscomp$1300$$,$set_name$jscomp$2$$):$m__5372__auto__$jscomp$inline_9608_m__5374__auto__$jscomp$inline_9607$$($JSCompiler_temp$jscomp$2024__$jscomp$1300$$,
$set_name$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.enable-set",$JSCompiler_temp$jscomp$2024__$jscomp$1300$$);}return $JSCompiler_temp$jscomp$2024__$jscomp$1300$$},$app$common$types$tokens_lib$disable_set$$=function($JSCompiler_temp$jscomp$2025__$jscomp$1304$$,$set_name$jscomp$4$$){if($JSCompiler_temp$jscomp$2025__$jscomp$1304$$!=null&&$JSCompiler_temp$jscomp$2025__$jscomp$1304$$.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$!=null)$JSCompiler_temp$jscomp$2025__$jscomp$1304$$=
$JSCompiler_temp$jscomp$2025__$jscomp$1304$$.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$($JSCompiler_temp$jscomp$2025__$jscomp$1304$$,$set_name$jscomp$4$$);else{var $m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$=$app$common$types$tokens_lib$disable_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2025__$jscomp$1304$$==null?null:$JSCompiler_temp$jscomp$2025__$jscomp$1304$$)];if($m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$!=null)$JSCompiler_temp$jscomp$2025__$jscomp$1304$$=
$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2025__$jscomp$1304$$,$set_name$jscomp$4$$):$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$($JSCompiler_temp$jscomp$2025__$jscomp$1304$$,$set_name$jscomp$4$$);else if($m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$=$app$common$types$tokens_lib$disable_set$$._,
$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$!=null)$JSCompiler_temp$jscomp$2025__$jscomp$1304$$=$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2025__$jscomp$1304$$,$set_name$jscomp$4$$):$m__5372__auto__$jscomp$inline_9613_m__5374__auto__$jscomp$inline_9612$$($JSCompiler_temp$jscomp$2025__$jscomp$1304$$,
$set_name$jscomp$4$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.disable-set",$JSCompiler_temp$jscomp$2025__$jscomp$1304$$);}return $JSCompiler_temp$jscomp$2025__$jscomp$1304$$},$app$common$types$tokens_lib$theme_active_QMARK_$$=function($JSCompiler_temp$jscomp$2026__$jscomp$1345$$,$id$jscomp$197$$){if($JSCompiler_temp$jscomp$2026__$jscomp$1345$$!=null&&$JSCompiler_temp$jscomp$2026__$jscomp$1345$$.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$2026__$jscomp$1345$$=
$JSCompiler_temp$jscomp$2026__$jscomp$1345$$.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$($JSCompiler_temp$jscomp$2026__$jscomp$1345$$,$id$jscomp$197$$);else{var $m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$=$app$common$types$tokens_lib$theme_active_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2026__$jscomp$1345$$==null?null:$JSCompiler_temp$jscomp$2026__$jscomp$1345$$)];if($m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$!=
null)$JSCompiler_temp$jscomp$2026__$jscomp$1345$$=$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2026__$jscomp$1345$$,$id$jscomp$197$$):$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$($JSCompiler_temp$jscomp$2026__$jscomp$1345$$,$id$jscomp$197$$);else if($m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$=
$app$common$types$tokens_lib$theme_active_QMARK_$$._,$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$!=null)$JSCompiler_temp$jscomp$2026__$jscomp$1345$$=$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2026__$jscomp$1345$$,$id$jscomp$197$$):$m__5372__auto__$jscomp$inline_9618_m__5374__auto__$jscomp$inline_9617$$($JSCompiler_temp$jscomp$2026__$jscomp$1345$$,
$id$jscomp$197$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.theme-active?",$JSCompiler_temp$jscomp$2026__$jscomp$1345$$);}return $JSCompiler_temp$jscomp$2026__$jscomp$1345$$},$app$common$types$tokens_lib$deactivate_theme$$=function($JSCompiler_temp$jscomp$2027__$jscomp$1349$$,$id$jscomp$201$$){if($JSCompiler_temp$jscomp$2027__$jscomp$1349$$!=null&&$JSCompiler_temp$jscomp$2027__$jscomp$1349$$.$app$common$types$tokens_lib$ITokenThemes$deactivate_theme$arity$2$!=null)$JSCompiler_temp$jscomp$2027__$jscomp$1349$$=
$JSCompiler_temp$jscomp$2027__$jscomp$1349$$.$app$common$types$tokens_lib$ITokenThemes$deactivate_theme$arity$2$($JSCompiler_temp$jscomp$2027__$jscomp$1349$$,$id$jscomp$201$$);else{var $m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$=$app$common$types$tokens_lib$deactivate_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2027__$jscomp$1349$$==null?null:$JSCompiler_temp$jscomp$2027__$jscomp$1349$$)];if($m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$!=
null)$JSCompiler_temp$jscomp$2027__$jscomp$1349$$=$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2027__$jscomp$1349$$,$id$jscomp$201$$):$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$($JSCompiler_temp$jscomp$2027__$jscomp$1349$$,$id$jscomp$201$$);else if($m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$=
$app$common$types$tokens_lib$deactivate_theme$$._,$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$!=null)$JSCompiler_temp$jscomp$2027__$jscomp$1349$$=$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2027__$jscomp$1349$$,$id$jscomp$201$$):$m__5372__auto__$jscomp$inline_9623_m__5374__auto__$jscomp$inline_9622$$($JSCompiler_temp$jscomp$2027__$jscomp$1349$$,
$id$jscomp$201$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.deactivate-theme",$JSCompiler_temp$jscomp$2027__$jscomp$1349$$);}return $JSCompiler_temp$jscomp$2027__$jscomp$1349$$},$app$main$data$event$Event$$=function(){},$app$main$data$event$_data$$=function($JSCompiler_temp$jscomp$2029__$jscomp$1416$$){if($JSCompiler_temp$jscomp$2029__$jscomp$1416$$!=null&&$JSCompiler_temp$jscomp$2029__$jscomp$1416$$.$app$main$data$event$Event$_data$arity$1$!=null)$JSCompiler_temp$jscomp$2029__$jscomp$1416$$=
$JSCompiler_temp$jscomp$2029__$jscomp$1416$$.$app$main$data$event$Event$_data$arity$1$($JSCompiler_temp$jscomp$2029__$jscomp$1416$$);else{var $m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$=$app$main$data$event$_data$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2029__$jscomp$1416$$==null?null:$JSCompiler_temp$jscomp$2029__$jscomp$1416$$)];if($m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$!=null)$JSCompiler_temp$jscomp$2029__$jscomp$1416$$=$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$.$cljs$core$IFn$_invoke$arity$1$?
$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2029__$jscomp$1416$$):$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$($JSCompiler_temp$jscomp$2029__$jscomp$1416$$);else if($m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$=$app$main$data$event$_data$$._,$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$!=null)$JSCompiler_temp$jscomp$2029__$jscomp$1416$$=
$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2029__$jscomp$1416$$):$m__5372__auto__$jscomp$inline_9627_m__5374__auto__$jscomp$inline_9626$$($JSCompiler_temp$jscomp$2029__$jscomp$1416$$);else throw $APP.$cljs$core$missing_protocol$$("Event.-data",$JSCompiler_temp$jscomp$2029__$jscomp$1416$$);}return $JSCompiler_temp$jscomp$2029__$jscomp$1416$$},
$app$main$data$event$PerformanceEvent$$=function(){},$goog$history$Event$$=function($token$jscomp$57$$){$APP.$goog$events$Event$$.call(this,"navigate");this.token=$token$jscomp$57$$},$goog$history$Html5History$$=function($opt_win$$,$opt_transformer$$){$APP.$goog$events$EventTarget$$.call(this);this.$window_$=$opt_win$$||window;this.$transformer_$=$opt_transformer$$||null;this.$lastFragment_$=null;$APP.$goog$events$listen$$(this.$window_$,"popstate",this.$onHistoryEvent_$,!1,this);$APP.$goog$events$listen$$(this.$window_$,
"hashchange",this.$onHistoryEvent_$,!1,this)},$JSCompiler_StaticMethods_setEnabled$$=function($JSCompiler_StaticMethods_setEnabled$self$$,$enable$jscomp$1$$){$enable$jscomp$1$$!=$JSCompiler_StaticMethods_setEnabled$self$$.$enabled_$&&($JSCompiler_StaticMethods_setEnabled$self$$.$enabled_$=$enable$jscomp$1$$)&&$JSCompiler_StaticMethods_setEnabled$self$$.dispatchEvent(new $goog$history$Event$$($JSCompiler_StaticMethods_setEnabled$self$$.getToken(),!1))},$JSCompiler_StaticMethods_getFragment_$$=function($JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$){if($JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.$useFragment_$){$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$=
$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.$window_$.location.href;const $index$jscomp$208$$=$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.indexOf("#");return $index$jscomp$208$$<0?"":$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.substring($index$jscomp$208$$+1)}return null},$JSCompiler_StaticMethods_getUrl_$$=function($JSCompiler_StaticMethods_getUrl_$self$$,$token$jscomp$60$$){return $JSCompiler_StaticMethods_getUrl_$self$$.$useFragment_$?"#"+$token$jscomp$60$$:
$JSCompiler_StaticMethods_getUrl_$self$$.$transformer_$?$JSCompiler_StaticMethods_getUrl_$self$$.$pathPrefix_$+$token$jscomp$60$$:$JSCompiler_StaticMethods_getUrl_$self$$.$pathPrefix_$+$token$jscomp$60$$+$JSCompiler_StaticMethods_getUrl_$self$$.$window_$.location.search},$meta_merge$core$meta_STAR_$$=function($obj$jscomp$178$$){return($obj$jscomp$178$$!=null?$obj$jscomp$178$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$178$$.$cljs$core$IMeta$$||
($obj$jscomp$178$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IMeta$$,$obj$jscomp$178$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IMeta$$,$obj$jscomp$178$$))?$APP.$cljs$core$meta$$($obj$jscomp$178$$):null},$reitit$trie$match$$=function($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$){if($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$!=null&&$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$.$reitit$trie$Matcher$match$arity$4$!=
null)$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$=$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$.$reitit$trie$Matcher$match$arity$4$($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$);else{var $m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$=$reitit$trie$match$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$==null?null:$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$)];if($m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$!=
null)$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$=$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$):$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$,$i$jscomp$494$$,
$max$jscomp$69$$,$path$jscomp$192$$);else if($m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$=$reitit$trie$match$$._,$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$!=null)$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$=$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$,
$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$):$m__5372__auto__$jscomp$inline_9638_m__5374__auto__$jscomp$inline_9637$$($JSCompiler_temp$jscomp$2032_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$);else throw $APP.$cljs$core$missing_protocol$$("Matcher.match",$JSCompiler_temp$jscomp$2032_this$$jscomp$717$$);}return $JSCompiler_temp$jscomp$2032_this$$jscomp$717$$},$reitit$trie$depth$$=function($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$){if($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$!=
null&&$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$.$reitit$trie$Matcher$depth$arity$1$!=null)$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$=$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$.$reitit$trie$Matcher$depth$arity$1$($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$);else{var $m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$=$reitit$trie$depth$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$==null?null:$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$)];
if($m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$!=null)$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$=$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$):$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$);
else if($m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$=$reitit$trie$depth$$._,$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$!=null)$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$=$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$):$m__5372__auto__$jscomp$inline_9642_m__5374__auto__$jscomp$inline_9641$$($JSCompiler_temp$jscomp$2033_this$$jscomp$721$$);
else throw $APP.$cljs$core$missing_protocol$$("Matcher.depth",$JSCompiler_temp$jscomp$2033_this$$jscomp$721$$);}return $JSCompiler_temp$jscomp$2033_this$$jscomp$721$$},$reitit$trie$length$$=function($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$){if($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$!=null&&$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$.$reitit$trie$Matcher$length$arity$1$!=null)$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$=$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$.$reitit$trie$Matcher$length$arity$1$($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$);
else{var $m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$=$reitit$trie$length$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$==null?null:$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$)];if($m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$!=null)$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$=$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$):
$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$);else if($m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$=$reitit$trie$length$$._,$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$!=null)$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$=$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$):
$m__5372__auto__$jscomp$inline_9646_m__5374__auto__$jscomp$inline_9645$$($JSCompiler_temp$jscomp$2034_this$$jscomp$723$$);else throw $APP.$cljs$core$missing_protocol$$("Matcher.length",$JSCompiler_temp$jscomp$2034_this$$jscomp$723$$);}return $JSCompiler_temp$jscomp$2034_this$$jscomp$723$$},$reitit$trie$data_matcher$$=function($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$){if($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$!=null&&$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$.$reitit$trie$TrieCompiler$data_matcher$arity$3$!=
null)$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$=$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$.$reitit$trie$TrieCompiler$data_matcher$arity$3$($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$);else{var $m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$=$reitit$trie$data_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$==null?null:$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$)];if($m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$!=
null)$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$=$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$):$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$);
else if($m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$=$reitit$trie$data_matcher$$._,$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$!=null)$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$=$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$,$params$jscomp$121$$,
$data$jscomp$162$$):$m__5372__auto__$jscomp$inline_9652_m__5374__auto__$jscomp$inline_9651$$($JSCompiler_temp$jscomp$2035_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.data-matcher",$JSCompiler_temp$jscomp$2035_this$$jscomp$725$$);}return $JSCompiler_temp$jscomp$2035_this$$jscomp$725$$},$reitit$trie$static_matcher$$=function($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$){if($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$!=
null&&$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$.$reitit$trie$TrieCompiler$static_matcher$arity$3$!=null)$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$=$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$.$reitit$trie$TrieCompiler$static_matcher$arity$3$($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$=$reitit$trie$static_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$==
null?null:$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$)];if($m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$!=null)$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$=$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$):$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$,
$path$jscomp$194$$,$matcher$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$=$reitit$trie$static_matcher$$._,$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$!=null)$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$=$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$,
$path$jscomp$194$$,$matcher$jscomp$2$$):$m__5372__auto__$jscomp$inline_9658_m__5374__auto__$jscomp$inline_9657$$($JSCompiler_temp$jscomp$2036_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.static-matcher",$JSCompiler_temp$jscomp$2036_this$$jscomp$727$$);}return $JSCompiler_temp$jscomp$2036_this$$jscomp$727$$},$reitit$trie$wild_matcher$$=function($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$,$key$jscomp$318$$,$end$jscomp$76$$,
$matcher$jscomp$4$$){if($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$!=null&&$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$.$reitit$trie$TrieCompiler$wild_matcher$arity$4$!=null)$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$=$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$.$reitit$trie$TrieCompiler$wild_matcher$arity$4$($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$,$key$jscomp$318$$,$end$jscomp$76$$,$matcher$jscomp$4$$);else{var $m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$=
$reitit$trie$wild_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$==null?null:$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$)];if($m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$!=null)$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$=$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$,
$key$jscomp$318$$,$end$jscomp$76$$,$matcher$jscomp$4$$):$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$,$key$jscomp$318$$,$end$jscomp$76$$,$matcher$jscomp$4$$);else if($m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$=$reitit$trie$wild_matcher$$._,$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$!=null)$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$=$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$,$key$jscomp$318$$,$end$jscomp$76$$,$matcher$jscomp$4$$):$m__5372__auto__$jscomp$inline_9665_m__5374__auto__$jscomp$inline_9664$$($JSCompiler_temp$jscomp$2037_this$$jscomp$729$$,$key$jscomp$318$$,$end$jscomp$76$$,$matcher$jscomp$4$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.wild-matcher",$JSCompiler_temp$jscomp$2037_this$$jscomp$729$$);
}return $JSCompiler_temp$jscomp$2037_this$$jscomp$729$$},$reitit$trie$catch_all_matcher$$=function($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$,$key$jscomp$320$$,$params$jscomp$123$$,$data$jscomp$164$$){if($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$!=null&&$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$.$reitit$trie$TrieCompiler$catch_all_matcher$arity$4$!=null)$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$=$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$.$reitit$trie$TrieCompiler$catch_all_matcher$arity$4$($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$,
$key$jscomp$320$$,$params$jscomp$123$$,$data$jscomp$164$$);else{var $m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$=$reitit$trie$catch_all_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$==null?null:$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$)];if($m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$!=null)$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$=$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$,$key$jscomp$320$$,$params$jscomp$123$$,$data$jscomp$164$$):$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$,$key$jscomp$320$$,$params$jscomp$123$$,$data$jscomp$164$$);else if($m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$=$reitit$trie$catch_all_matcher$$._,
$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$!=null)$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$=$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$,$key$jscomp$320$$,$params$jscomp$123$$,$data$jscomp$164$$):$m__5372__auto__$jscomp$inline_9672_m__5374__auto__$jscomp$inline_9671$$($JSCompiler_temp$jscomp$2038_this$$jscomp$731$$,
$key$jscomp$320$$,$params$jscomp$123$$,$data$jscomp$164$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.catch-all-matcher",$JSCompiler_temp$jscomp$2038_this$$jscomp$731$$);}return $JSCompiler_temp$jscomp$2038_this$$jscomp$731$$},$reitit$trie$linear_matcher$$=function($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$){if($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$!=null&&$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$.$reitit$trie$TrieCompiler$linear_matcher$arity$3$!=
null)$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$=$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$.$reitit$trie$TrieCompiler$linear_matcher$arity$3$($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$=$reitit$trie$linear_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$==null?null:$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$)];if($m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$!=
null)$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$=$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$):$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$,$matchers$jscomp$1$$,
$ordered_QMARK_$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$=$reitit$trie$linear_matcher$$._,$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$!=null)$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$=$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$,
$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$):$m__5372__auto__$jscomp$inline_9678_m__5374__auto__$jscomp$inline_9677$$($JSCompiler_temp$jscomp$2039_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.linear-matcher",$JSCompiler_temp$jscomp$2039_this$$jscomp$733$$);}return $JSCompiler_temp$jscomp$2039_this$$jscomp$733$$},$reitit$trie$_path_matcher$$=function($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$,$matcher$jscomp$8$$){if($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$!=
null&&$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$.$reitit$trie$TrieCompiler$_path_matcher$arity$2$!=null)$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$=$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$.$reitit$trie$TrieCompiler$_path_matcher$arity$2$($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$,$matcher$jscomp$8$$);else{var $m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$=$reitit$trie$_path_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$==
null?null:$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$)];if($m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$!=null)$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$=$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$,$matcher$jscomp$8$$):$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$,
$matcher$jscomp$8$$);else if($m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$=$reitit$trie$_path_matcher$$._,$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$!=null)$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$=$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$,
$matcher$jscomp$8$$):$m__5372__auto__$jscomp$inline_9683_m__5374__auto__$jscomp$inline_9682$$($JSCompiler_temp$jscomp$2040_this$$jscomp$737$$,$matcher$jscomp$8$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.-path-matcher",$JSCompiler_temp$jscomp$2040_this$$jscomp$737$$);}return $JSCompiler_temp$jscomp$2040_this$$jscomp$737$$},$reitit$impl$fast_get$$=function($m$jscomp$213$$,$k$jscomp$612$$){return $m$jscomp$213$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$213$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$612$$):
$m$jscomp$213$$($k$jscomp$612$$)},$reitit$impl$maybe_url_decode$$=function($s$jscomp$536$$){return $APP.$cljs$core$truth_$$($s$jscomp$536$$)?decodeURIComponent($s$jscomp$536$$):null},$reitit$core$match_by_path$$=function($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$,$path$jscomp$212$$){if($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$!=null&&$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$.$reitit$core$Router$match_by_path$arity$2$!=null)$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$=$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$.$reitit$core$Router$match_by_path$arity$2$($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$,
$path$jscomp$212$$);else{var $m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$=$reitit$core$match_by_path$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$==null?null:$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$)];if($m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$!=null)$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$=$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$,
$path$jscomp$212$$):$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$,$path$jscomp$212$$);else if($m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$=$reitit$core$match_by_path$$._,$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$!=null)$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$=$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$,$path$jscomp$212$$):$m__5372__auto__$jscomp$inline_9688_m__5374__auto__$jscomp$inline_9687$$($JSCompiler_temp$jscomp$2042_this$$jscomp$761$$,$path$jscomp$212$$);else throw $APP.$cljs$core$missing_protocol$$("Router.match-by-path",$JSCompiler_temp$jscomp$2042_this$$jscomp$761$$);}return $JSCompiler_temp$jscomp$2042_this$$jscomp$761$$},$app$plugins$utils$reject_not_valid$$=
function($reject$jscomp$20$$,$code$jscomp$35_msg$jscomp$29$$,$value$jscomp$527$$){$code$jscomp$35_msg$jscomp$29$$="[PENPOT PLUGIN] Value not valid: "+($value$jscomp$527$$??"")+". Code: "+($code$jscomp$35_msg$jscomp$29$$??"");console.error($code$jscomp$35_msg$jscomp$29$$);return $reject$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($code$jscomp$35_msg$jscomp$29$$):$reject$jscomp$20$$($code$jscomp$35_msg$jscomp$29$$)},$app$util$text_editor$create_editor_state$cljs$0core$0IFn$0_invoke$0arity$01$$=
function($content$jscomp$174$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createEditorState($content$jscomp$174$$,null)},$app$main$ui$css_cursors$init_static_cursor_style$$=function($style$jscomp$56$$,$name$jscomp$415$$,$value$jscomp$752$$){$style$jscomp$56$$.add(".cursor-"+($name$jscomp$415$$??""),{cursor:""+($value$jscomp$752$$??"")+" !important"})},$app$util$theme$get_system_theme$$=function(){return $APP.$app$util$theme$color_scheme_media_query$$.matches?"dark":"light"},$meta_merge$core$with_meta_STAR_$$=
function($obj$jscomp$179$$,$m$jscomp$204$$){return($obj$jscomp$179$$!=null?$obj$jscomp$179$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$179$$.$cljs$core$IWithMeta$$||($obj$jscomp$179$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$179$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$179$$))?$APP.$cljs$core$with_meta$$($obj$jscomp$179$$,
$m$jscomp$204$$):$obj$jscomp$179$$},$reitit$trie$t_reitit$0trie50204$$=function($meta50198$$,$_$jscomp$1438$$,$params$jscomp$126$$,$data$jscomp$166$$,$match$jscomp$28$$,$meta50205$$){this.$meta50198$=$meta50198$$;this.$_$=$_$jscomp$1438$$;this.params=$params$jscomp$126$$;this.data=$data$jscomp$166$$;this.match=$match$jscomp$28$$;this.$meta50205$=$meta50205$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$util$object$type_of_QMARK_$$=function($o$jscomp$203$$,
$t$jscomp$53$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($o$jscomp$203$$,$APP.$app$util$object$type_symbol$$),$t$jscomp$53$$)},$meta_merge$core$displace_QMARK_$$=function($obj$jscomp$180$$){return $APP.$cljs$cst$2367$displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($obj$jscomp$180$$))},$reitit$trie$assoc_param$$=function($match$jscomp$27$$,$k$jscomp$605$$,$v$jscomp$550$$){var $params$jscomp$124$$=
$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($match$jscomp$27$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($match$jscomp$27$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$124$$,$k$jscomp$605$$,$v$jscomp$550$$))},$meta_merge$core$replace_QMARK_$$=function($obj$jscomp$181$$){return $APP.$cljs$cst$2368$replace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($obj$jscomp$181$$))},$cljs$core$take_last$$=
function($G__27098_coll$jscomp$284_lead$$){var $G__27097_s$jscomp$77$$=$APP.$cljs$core$seq$$($G__27098_coll$jscomp$284_lead$$);for($G__27098_coll$jscomp$284_lead$$=$APP.$cljs$core$seq$$($APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$G__27098_coll$jscomp$284_lead$$));;)if($G__27098_coll$jscomp$284_lead$$)$G__27097_s$jscomp$77$$=$APP.$cljs$core$next$$($G__27097_s$jscomp$77$$),$G__27098_coll$jscomp$284_lead$$=$APP.$cljs$core$next$$($G__27098_coll$jscomp$284_lead$$);else return $G__27097_s$jscomp$77$$},
$app$main$data$event$append_to_buffer$$=function($buffer$jscomp$60$$,$item$jscomp$54$$){return $APP.$cljs$core$count$$($buffer$jscomp$60$$)>=1024?$buffer$jscomp$60$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($buffer$jscomp$60$$,$item$jscomp$54$$)},$cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$03$$=function(){return function(){function $cljs$core$sp3__3$$($or__5025__auto____$6_x$jscomp$452$$,$or__5025__auto____$7_y$jscomp$222$$,$z$jscomp$74$$){var $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=
$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6_x$jscomp$452$$):$or__5025__auto____$6_x$jscomp$452$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$7_y$jscomp$222$$):$or__5025__auto____$7_y$jscomp$222$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$74$$):$z$jscomp$74$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6_x$jscomp$452$$):$meta_merge$core$displace_QMARK_$$($or__5025__auto____$6_x$jscomp$452$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$7_y$jscomp$222$$):$meta_merge$core$displace_QMARK_$$($or__5025__auto____$7_y$jscomp$222$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$74$$):$meta_merge$core$displace_QMARK_$$($z$jscomp$74$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto____$6_x$jscomp$452$$=$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6_x$jscomp$452$$):$meta_merge$core$replace_QMARK_$$($or__5025__auto____$6_x$jscomp$452$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$6_x$jscomp$452$$))return $or__5025__auto____$6_x$jscomp$452$$;$or__5025__auto____$7_y$jscomp$222$$=$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$7_y$jscomp$222$$):
$meta_merge$core$replace_QMARK_$$($or__5025__auto____$7_y$jscomp$222$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$7_y$jscomp$222$$)?$or__5025__auto____$7_y$jscomp$222$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$74$$):$meta_merge$core$replace_QMARK_$$($z$jscomp$74$$)}function $cljs$core$sp3__2$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$,$y$jscomp$221$$){var $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=
$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$):$or__5025__auto____$4$jscomp$1_x$jscomp$451$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;$or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=
$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$221$$):$y$jscomp$221$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;$or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=
$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$):$meta_merge$core$displace_QMARK_$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;
$or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$221$$):$meta_merge$core$displace_QMARK_$$($y$jscomp$221$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;
$or__5025__auto____$4$jscomp$1_x$jscomp$451$$=$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$):$meta_merge$core$replace_QMARK_$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$)?$or__5025__auto____$4$jscomp$1_x$jscomp$451$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$221$$):
$meta_merge$core$replace_QMARK_$$($y$jscomp$221$$)}function $cljs$core$sp3__1$$($x$jscomp$450$$){var $or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$450$$):$x$jscomp$450$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$))return $or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$;$or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$=
$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$450$$):$meta_merge$core$displace_QMARK_$$($x$jscomp$450$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$)?$or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$450$$):
$meta_merge$core$replace_QMARK_$$($x$jscomp$450$$)}var $cljs$core$sp3$$=null,$cljs$core$sp3__4$$=function(){function $G__26948$$($x$jscomp$454$$,$y$jscomp$224$$,$z$jscomp$76$$,$var_args$jscomp$208$$){var $G__26950__i_args$jscomp$82$$=null;if(arguments.length>3){$G__26950__i_args$jscomp$82$$=0;for(var $G__26950__a$$=Array(arguments.length-3);$G__26950__i_args$jscomp$82$$<$G__26950__a$$.length;)$G__26950__a$$[$G__26950__i_args$jscomp$82$$]=arguments[$G__26950__i_args$jscomp$82$$+3],++$G__26950__i_args$jscomp$82$$;
$G__26950__i_args$jscomp$82$$=new $APP.$cljs$core$IndexedSeq$$($G__26950__a$$,0,null)}return $G__26948__delegate$$.call(this,$x$jscomp$454$$,$y$jscomp$224$$,$z$jscomp$76$$,$G__26950__i_args$jscomp$82$$)}function $G__26948__delegate$$($or__5025__auto__$jscomp$21_x$jscomp$453$$,$y$jscomp$223$$,$z$jscomp$75$$,$args$jscomp$81$$){$or__5025__auto__$jscomp$21_x$jscomp$453$$=$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$3$($or__5025__auto__$jscomp$21_x$jscomp$453$$,$y$jscomp$223$$,$z$jscomp$75$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$21_x$jscomp$453$$)?
$or__5025__auto__$jscomp$21_x$jscomp$453$$:$APP.$cljs$core$some$$(function($p1__23398_SHARP_$$){var $or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__23398_SHARP_$$):$p1__23398_SHARP_$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$))return $or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$;$or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$=
$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__23398_SHARP_$$):$meta_merge$core$displace_QMARK_$$($p1__23398_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$)?$or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__23398_SHARP_$$):
$meta_merge$core$replace_QMARK_$$($p1__23398_SHARP_$$)},$args$jscomp$81$$)}$G__26948$$.$cljs$lang$maxFixedArity$=3;$G__26948$$.$cljs$lang$applyTo$=function($arglist__26951_args$jscomp$83$$){var $x$jscomp$455$$=$APP.$cljs$core$first$$($arglist__26951_args$jscomp$83$$);$arglist__26951_args$jscomp$83$$=$APP.$cljs$core$next$$($arglist__26951_args$jscomp$83$$);var $y$jscomp$225$$=$APP.$cljs$core$first$$($arglist__26951_args$jscomp$83$$);$arglist__26951_args$jscomp$83$$=$APP.$cljs$core$next$$($arglist__26951_args$jscomp$83$$);
var $z$jscomp$77$$=$APP.$cljs$core$first$$($arglist__26951_args$jscomp$83$$);$arglist__26951_args$jscomp$83$$=$APP.$cljs$core$rest$$($arglist__26951_args$jscomp$83$$);return $G__26948__delegate$$($x$jscomp$455$$,$y$jscomp$225$$,$z$jscomp$77$$,$arglist__26951_args$jscomp$83$$)};$G__26948$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26948__delegate$$;return $G__26948$$}();$cljs$core$sp3$$=function($x$jscomp$456$$,$y$jscomp$226$$,$z$jscomp$78$$,$var_args$jscomp$209$$){switch(arguments.length){case 0:return null;
case 1:return $cljs$core$sp3__1$$.call(this,$x$jscomp$456$$);case 2:return $cljs$core$sp3__2$$.call(this,$x$jscomp$456$$,$y$jscomp$226$$);case 3:return $cljs$core$sp3__3$$.call(this,$x$jscomp$456$$,$y$jscomp$226$$,$z$jscomp$78$$);default:var $G__26952_G__26953__i$$=null;if(arguments.length>3){$G__26952_G__26953__i$$=0;for(var $G__26953__a$$=Array(arguments.length-3);$G__26952_G__26953__i$$<$G__26953__a$$.length;)$G__26953__a$$[$G__26952_G__26953__i$$]=arguments[$G__26952_G__26953__i$$+3],++$G__26952_G__26953__i$$;
$G__26952_G__26953__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26953__a$$,0,null)}return $cljs$core$sp3__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$456$$,$y$jscomp$226$$,$z$jscomp$78$$,$G__26952_G__26953__i$$)}throw Error("Invalid arity: "+arguments.length);};$cljs$core$sp3$$.$cljs$lang$maxFixedArity$=3;$cljs$core$sp3$$.$cljs$lang$applyTo$=$cljs$core$sp3__4$$.$cljs$lang$applyTo$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$0$=function(){return null};$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$1$=
$cljs$core$sp3__1$$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$2$=$cljs$core$sp3__2$$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$3$=$cljs$core$sp3__3$$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$variadic$=$cljs$core$sp3__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $cljs$core$sp3$$}()},$reitit$core$t_reitit$0core52118$$=function($non_conflicting$$,$map__52110$$,$names$jscomp$18$$,$conflicting_paths$$,$compiled_routes$jscomp$20$$,$conflicting$$,$routes$jscomp$24$$,$conflicting_QMARK_$$,
$mixed_router$$,$linear_router$$,$opts$jscomp$288$$,$meta52119$$){this.$non_conflicting$=$non_conflicting$$;this.$map__52110$=$map__52110$$;this.names=$names$jscomp$18$$;this.$conflicting_paths$=$conflicting_paths$$;this.$compiled_routes$=$compiled_routes$jscomp$20$$;this.$conflicting$=$conflicting$$;this.$routes$=$routes$jscomp$24$$;this.$conflicting_QMARK_$=$conflicting_QMARK_$$;this.$mixed_router$=$mixed_router$$;this.$linear_router$=$linear_router$$;this.$opts$=$opts$jscomp$288$$;this.$meta52119$=
$meta52119$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core52097$$=function($names$jscomp$15$$,$compiled_routes$jscomp$16$$,$routes$jscomp$21$$,$__GT_static_router$$,$lookup$jscomp$12$$,$wild$$,$static_router$$,$map__52095$$,$opts$jscomp$285$$,$wildcard_router$$,$meta52098$$){this.names=$names$jscomp$15$$;this.$compiled_routes$=$compiled_routes$jscomp$16$$;this.$routes$=$routes$jscomp$21$$;this.$__GT_static_router$=$__GT_static_router$$;
this.$lookup$=$lookup$jscomp$12$$;this.$wild$=$wild$$;this.$static_router$=$static_router$$;this.$map__52095$=$map__52095$$;this.$opts$=$opts$jscomp$285$$;this.$wildcard_router$=$wildcard_router$$;this.$meta52098$=$meta52098$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$decode$$=function($param$jscomp$11_path$jscomp$196$$,$start$jscomp$212$$,$end$jscomp$77$$,$percent_QMARK_$$){$param$jscomp$11_path$jscomp$196$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($param$jscomp$11_path$jscomp$196$$,
$start$jscomp$212$$,$end$jscomp$77$$);return $APP.$cljs$core$truth_$$($percent_QMARK_$$)?decodeURIComponent($param$jscomp$11_path$jscomp$196$$):$param$jscomp$11_path$jscomp$196$$},$reitit$trie$t_reitit$0trie50245$$=function($meta50198$jscomp$6$$,$_$jscomp$1444$$,$key$jscomp$323$$,$params$jscomp$128$$,$data$jscomp$168$$,$match$jscomp$31$$,$meta50246$$){this.$meta50198$=$meta50198$jscomp$6$$;this.$_$=$_$jscomp$1444$$;this.key=$key$jscomp$323$$;this.params=$params$jscomp$128$$;this.data=$data$jscomp$168$$;
this.match=$match$jscomp$31$$;this.$meta50246$=$meta50246$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$_slice_end$$=function($x$jscomp$1137$$,$xs$jscomp$32$$){var $i$jscomp$499$$=typeof $x$jscomp$1137$$==="string"?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($x$jscomp$1137$$,"/"):null;return typeof $i$jscomp$499$$==="number"&&$i$jscomp$499$$>0?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1137$$,$i$jscomp$499$$)],null),$xs$jscomp$32$$):$xs$jscomp$32$$},$reitit$trie$t_reitit$0trie50210$$=function($meta50198$jscomp$2$$,$_$jscomp$1440$$,$path$jscomp$197$$,$matcher$jscomp$9$$,$size$jscomp$97$$,$meta50211$$){this.$meta50198$=$meta50198$jscomp$2$$;this.$_$=$_$jscomp$1440$$;this.path=$path$jscomp$197$$;this.$matcher$=$matcher$jscomp$9$$;this.size=$size$jscomp$97$$;this.$meta50211$=
$meta50211$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$helpers$lookup_profile$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$48$$,$profile_id$jscomp$1$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$48$$,$APP.$cljs$cst$1915$profiles$$),$profile_id$jscomp$1$$)},$app$plugins$register$get_plugin_data$$=function($state$jscomp$192$$,$plugin_id$jscomp$3$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$192$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3197$plugins$$,$APP.$cljs$cst$142$data$$,$plugin_id$jscomp$3$$],null))},$app$plugins$register$check_permission$$=function($map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,$permission$jscomp$1$$){var $or__5025__auto__$jscomp$611_or__5025__auto____$1$jscomp$73$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,
"00000000-0000-0000-0000-000000000000");if($or__5025__auto__$jscomp$611_or__5025__auto____$1$jscomp$73$$||($or__5025__auto__$jscomp$611_or__5025__auto____$1$jscomp$73$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,"96dfa740-005d-8020-8007-55ede24a2bae")))return $or__5025__auto__$jscomp$611_or__5025__auto____$1$jscomp$73$$;$map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$),
$APP.$cljs$cst$142$data$$),$map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$);$map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$);$map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,$APP.$cljs$cst$1722$permissions$$);return $APP.$cljs$core$contains_QMARK_$$($map__54158_map__54158__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,
$permission$jscomp$1$$)},$app$main$data$event$longtask_observer$$=function(){return typeof globalThis!=="undefined"&&globalThis.PerformanceObserver!=null?$APP.$beicon$v2$core$create$$(function($subs$jscomp$13$$){var $observer$jscomp$4$$=new PerformanceObserver(function($list$jscomp$2$$){return $APP.$cljs$core$run_BANG_$$(function($entry$jscomp$40$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("longtask",$entry$jscomp$40$$.entryType)&&$entry$jscomp$40$$.duration>1E3?$subs$jscomp$13$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"long-task",$APP.$cljs$cst$1960$duration$$,$entry$jscomp$40$$.duration],null)):null},$list$jscomp$2$$.getEntries())});$observer$jscomp$4$$.observe({entryTypes:["longtask"]});return function(){return $observer$jscomp$4$$.disconnect()}}):$APP.$beicon$v2$core$empty$$()},$app$main$data$event$user_input_observer$$=function(){return typeof globalThis!=="undefined"&&globalThis.PerformanceObserver!=null?$APP.$beicon$v2$core$create$$(function($subs$jscomp$12$$){var $observer$jscomp$3$$=
new PerformanceObserver(function($list$jscomp$1$$){return $APP.$cljs$core$run_BANG_$$(function($entry$jscomp$39$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("event",$entry$jscomp$39$$.entryType)&&$entry$jscomp$39$$.duration>1E3?$subs$jscomp$12$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"user-input",$APP.$cljs$cst$1960$duration$$,$entry$jscomp$39$$.duration,$APP.$cljs$cst$2317$event_name$$,$entry$jscomp$39$$.name],
null)):null},$list$jscomp$1$$.getEntries())});$observer$jscomp$3$$.observe({entryTypes:["event"]});return function(){return $observer$jscomp$3$$.disconnect()}}):$APP.$beicon$v2$core$empty$$()},$reitit$impl$maybe_map_values$$=function($f$jscomp$794$$,$coll$jscomp$1084$$){return $APP.$cljs$core$reduce_kv$$(function($coll__$1$jscomp$558$$,$k$jscomp$608$$,$temp__5827__auto__$jscomp$20_v$jscomp$553$$){$temp__5827__auto__$jscomp$20_v$jscomp$553$$=$f$jscomp$794$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$794$$.$cljs$core$IFn$_invoke$arity$1$($temp__5827__auto__$jscomp$20_v$jscomp$553$$):
$f$jscomp$794$$($temp__5827__auto__$jscomp$20_v$jscomp$553$$);return $temp__5827__auto__$jscomp$20_v$jscomp$553$$==null?$coll__$1$jscomp$558$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($coll__$1$jscomp$558$$,$k$jscomp$608$$,$temp__5827__auto__$jscomp$20_v$jscomp$553$$)},$coll$jscomp$1084$$,$coll$jscomp$1084$$)},$reitit$impl$path_params$$=function($params$jscomp$134$$){return $reitit$impl$maybe_map_values$$(function($p1__51654_SHARP__s$jscomp$inline_9692$$){$p1__51654_SHARP__s$jscomp$inline_9692$$=
$APP.$reitit$impl$into_string$$($p1__51654_SHARP__s$jscomp$inline_9692$$);return $APP.$cljs$core$truth_$$($p1__51654_SHARP__s$jscomp$inline_9692$$)?encodeURIComponent($p1__51654_SHARP__s$jscomp$inline_9692$$):null},$params$jscomp$134$$)},$reitit$core$t_reitit$0core52081$$=function($p$jscomp$233$$,$names$jscomp$12$$,$match$jscomp$48$$,$data$jscomp$186$$,$compiled_routes$jscomp$12$$,$routes$jscomp$18$$,$vec__52075$$,$vec__52078$$,$n$jscomp$281$$,$vec__52072$$,$result$jscomp$225$$,$opts$jscomp$282$$,
$meta52082$$){this.p=$p$jscomp$233$$;this.names=$names$jscomp$12$$;this.match=$match$jscomp$48$$;this.data=$data$jscomp$186$$;this.$compiled_routes$=$compiled_routes$jscomp$12$$;this.$routes$=$routes$jscomp$18$$;this.$vec__52075$=$vec__52075$$;this.$vec__52078$=$vec__52078$$;this.n=$n$jscomp$281$$;this.$vec__52072$=$vec__52072$$;this.result=$result$jscomp$225$$;this.$opts$=$opts$jscomp$282$$;this.$meta52082$=$meta52082$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$reitit$core$t_reitit$0core52046$$=function($matcher$jscomp$20$$,$names$jscomp$9$$,$compiled_routes$jscomp$8$$,$routes$jscomp$15$$,$vec__52031$$,$lookup$jscomp$9$$,$pl$jscomp$8$$,$nl$jscomp$12$$,$match_by_path$jscomp$3$$,$compiler$jscomp$7$$,$opts$jscomp$279$$,$meta52047$$){this.$matcher$=$matcher$jscomp$20$$;this.names=$names$jscomp$9$$;this.$compiled_routes$=$compiled_routes$jscomp$8$$;this.$routes$=$routes$jscomp$15$$;this.$vec__52031$=$vec__52031$$;this.$lookup$=$lookup$jscomp$9$$;this.pl=
$pl$jscomp$8$$;this.nl=$nl$jscomp$12$$;this.$match_by_path$=$match_by_path$jscomp$3$$;this.$compiler$=$compiler$jscomp$7$$;this.$opts$=$opts$jscomp$279$$;this.$meta52047$=$meta52047$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core52001$$=function($names$jscomp$6$$,$data$jscomp$181$$,$compiled_routes$jscomp$4$$,$routes$jscomp$12$$,$lookup$jscomp$6$$,$pl$jscomp$4$$,$vec__51985$$,$nl$jscomp$8$$,$opts$jscomp$276$$,$meta52002$$){this.names=
$names$jscomp$6$$;this.data=$data$jscomp$181$$;this.$compiled_routes$=$compiled_routes$jscomp$4$$;this.$routes$=$routes$jscomp$12$$;this.$lookup$=$lookup$jscomp$6$$;this.pl=$pl$jscomp$4$$;this.$vec__51985$=$vec__51985$$;this.nl=$nl$jscomp$8$$;this.$opts$=$opts$jscomp$276$$;this.$meta52002$=$meta52002$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core51955$$=function($vec__51918$$,$matcher$jscomp$17$$,$names$jscomp$3$$,$compiled_routes$$,
$routes$jscomp$9$$,$lookup$jscomp$3$$,$pl$$,$nl$jscomp$4$$,$match_by_path$$,$compiler$jscomp$4$$,$opts$jscomp$273$$,$meta51956$$){this.$vec__51918$=$vec__51918$$;this.$matcher$=$matcher$jscomp$17$$;this.names=$names$jscomp$3$$;this.$compiled_routes$=$compiled_routes$$;this.$routes$=$routes$jscomp$9$$;this.$lookup$=$lookup$jscomp$3$$;this.pl=$pl$$;this.nl=$nl$jscomp$4$$;this.$match_by_path$=$match_by_path$$;this.$compiler$=$compiler$jscomp$4$$;this.$opts$=$opts$jscomp$273$$;this.$meta51956$=$meta51956$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$impl$_copy_meta$$=function($to$jscomp$21$$,$from$jscomp$19$$){function $_with_meta$$($x$jscomp$1139$$,$m$jscomp$207$$){try{return $APP.$cljs$core$with_meta$$($x$jscomp$1139$$,$m$jscomp$207$$)}catch($e51448$$){if($e51448$$ instanceof Error)return $x$jscomp$1139$$;throw $e51448$$;}}return function $reitit$impl$_copy_meta_$__copy$$($l$jscomp$99$$,$p$jscomp$221$$,$m$jscomp$208$$){return $APP.$cljs$core$reduce_kv$$(function($l__$1$jscomp$2$$,
$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$,$v$jscomp$552$$){$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$221$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$);var $m_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$meta$$($v$jscomp$552$$))?$APP.$cljs$core$meta$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$19$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$)):null;return $APP.$cljs$core$truth_$$($m_SINGLEQUOTE_$jscomp$3$$)?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($l__$1$jscomp$2$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$,$_with_meta$$,$m_SINGLEQUOTE_$jscomp$3$$):$APP.$cljs$core$map_QMARK_$$($v$jscomp$552$$)&&!$APP.$cljs$core$record_QMARK_$$($v$jscomp$552$$)&&$APP.$cljs$core$seq$$($v$jscomp$552$$)?$reitit$impl$_copy_meta_$__copy$$($l__$1$jscomp$2$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$,$v$jscomp$552$$):$l__$1$jscomp$2$$},$l$jscomp$99$$,$m$jscomp$208$$)}($to$jscomp$21$$,$APP.$cljs$core$PersistentVector$EMPTY$$,
$to$jscomp$21$$)},$app$main$router$navigated$$=function($match$jscomp$53$$,$send_event_info_QMARK_$$){typeof $app$main$router$navigated_52197$$==="undefined"&&($app$main$router$navigated_52197$$=function($match$jscomp$54$$,$send_event_info_QMARK_$jscomp$1$$,$meta52198$$){this.match=$match$jscomp$54$$;this.$send_event_info_QMARK_$=$send_event_info_QMARK_$jscomp$1$$;this.$meta52198$=$meta52198$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$navigated_52197$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigated_52197$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2454$app_DOT_main_DOT_router_SLASH_navigated$$},$app$main$router$navigated_52197$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52199$$,$meta52198__$1$$){return new $app$main$router$navigated_52197$$(this.match,this.$send_event_info_QMARK_$,$meta52198__$1$$)},$app$main$router$navigated_52197$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta52198$},$app$main$router$navigated_52197$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.match},$app$main$router$navigated_52197$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigated_52197$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){if($APP.$cljs$core$truth_$$(this.$send_event_info_QMARK_$)){var $route$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.match,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$725$name$$),$params$jscomp$138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.match,$APP.$cljs$cst$2269$query_params$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($params$jscomp$138$$,$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"navigate",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2171$route$$,$APP.$cljs$core$name$$($route$jscomp$5$$)]))))}return null},
$app$main$router$navigated_52197$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigated_52197$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1522$$,$state$jscomp$112$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$112$$,$APP.$cljs$cst$2171$route$$,this.match),$APP.$cljs$cst$727$exception$$)});return new $app$main$router$navigated_52197$$($match$jscomp$53$$,
$send_event_info_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$event$simplify_props$$=function($data$jscomp$147$$){return $APP.$cljs$core$reduce_kv$$(function($data__$1$jscomp$5$$,$k$jscomp$604$$,$v$jscomp$549$$){return $APP.$cljs$core$map_QMARK_$$($v$jscomp$549$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$cst$2303$placeholder_SLASH_map$$):$APP.$cljs$core$vector_QMARK_$$($v$jscomp$549$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,
$k$jscomp$604$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$event$xf_COLON_coerce_to_string$$,$v$jscomp$549$$)):$APP.$cljs$core$set_QMARK_$$($v$jscomp$549$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$event$xf_COLON_coerce_to_string$$,$v$jscomp$549$$)):$APP.$cljs$core$coll_QMARK_$$($v$jscomp$549$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$cst$2304$placeholder_SLASH_coll$$):$APP.$cljs$core$fn_QMARK_$$($v$jscomp$549$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$cst$2305$placeholder_SLASH_fn$$):$v$jscomp$549$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($data__$1$jscomp$5$$,$k$jscomp$604$$):$data__$1$jscomp$5$$},$data$jscomp$147$$,$data$jscomp$147$$)},$app$main$ui$static$0$request_dialog_STAR_$$=
function($props_75805_title$jscomp$29$$){var $on_close$jscomp$13$$=$props_75805_title$jscomp$29$$.onClose,$cancel_text$$=$props_75805_title$jscomp$29$$.cancelText,$content$jscomp$242$$=$props_75805_title$jscomp$29$$.content,$button_text$$=$props_75805_title$jscomp$29$$.buttonText,$on_button_click_on_click$jscomp$31$$=$props_75805_title$jscomp$29$$.onButtonClick;$props_75805_title$jscomp$29$$=$props_75805_title$jscomp$29$$.title;$on_button_click_on_click$jscomp$31$$=$APP.$cljs$core$truth_$$($on_button_click_on_click$jscomp$31$$)?
$on_button_click_on_click$jscomp$31$$:$on_close$jscomp$13$$;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__dialog",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__modal-close",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$13$$,className:"main_ui_static__modal-close-button",children:$APP.$app$main$ui$icons$close$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__dialog-title",
children:$props_75805_title$jscomp$29$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$113$$,$content__$1$jscomp$45_p__75808$$){var $index$jscomp$408$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content__$1$jscomp$45_p__75808$$,0,null);$content__$1$jscomp$45_p__75808$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content__$1$jscomp$45_p__75808$$,1,null);$out_arr__44124__auto__$jscomp$113$$.push((0,$APP.$rumext$v2$jsx$$)("div",
{children:$content__$1$jscomp$45_p__75808$$},$index$jscomp$408$$));return $out_arr__44124__auto__$jscomp$113$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$242$$)),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__sign-info",children:[$APP.$cljs$core$truth_$$($cancel_text$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$13$$,className:"main_ui_static__cancel-button",children:$cancel_text$$}):null,(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$on_button_click_on_click$jscomp$31$$,children:$button_text$$})]})]})})},$app$util$css$declarations__GT_str$$=function($declarations$$){return Array.from(Object.entries($declarations$$)).reduce(function($acc$jscomp$146$$,$p__73723_v$jscomp$625$$){var $k$jscomp$667$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73723_v$jscomp$625$$,0,null);$p__73723_v$jscomp$625$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73723_v$jscomp$625$$,1,null);return""+($acc$jscomp$146$$??
"")+($k$jscomp$667$$??"")+": "+($p__73723_v$jscomp$625$$??"")+";"},"")},$app$util$css$add_rule$$=function($styleSheet$jscomp$7$$,$rule$jscomp$3_selector$jscomp$18$$,$declarations$jscomp$1$$){$rule$jscomp$3_selector$jscomp$18$$=""+($rule$jscomp$3_selector$jscomp$18$$??"")+" { "+($app$util$css$declarations__GT_str$$($declarations$jscomp$1$$)??"")+" }";return $styleSheet$jscomp$7$$.insertRule($rule$jscomp$3_selector$jscomp$18$$,$styleSheet$jscomp$7$$.cssRules.length)},$reitit$impl$find_names$$=function($routes$jscomp$6$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__51630_SHARP_$$){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__51630_SHARP_$$))}),$routes$jscomp$6$$)},$app$plugins$flags$set_flag$$=function($id$jscomp$407$$,$key$jscomp$370$$,$value$jscomp$528$$){typeof $app$plugins$flags$set_flag_55472$$==="undefined"&&($app$plugins$flags$set_flag_55472$$=function($id$jscomp$408$$,$key$jscomp$371$$,$value$jscomp$529$$,$meta55473$$){this.id=$id$jscomp$408$$;
this.key=$key$jscomp$371$$;this.value=$value$jscomp$529$$;this.$meta55473$=$meta55473$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$plugins$flags$set_flag_55472$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$flags$set_flag_55472$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3393$app_DOT_plugins_DOT_flags_SLASH_set_flag$$},$app$plugins$flags$set_flag_55472$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55474$$,$meta55473__$1$$){return new $app$plugins$flags$set_flag_55472$$(this.id,this.key,this.value,$meta55473__$1$$)},$app$plugins$flags$set_flag_55472$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55473$},$app$plugins$flags$set_flag_55472$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$flags$set_flag_55472$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1787$$,$state$jscomp$243$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$243$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3197$plugins$$,$APP.$cljs$cst$1467$flags$$,this.id],null),$APP.$cljs$core$assoc$$,this.key,this.value)});return new $app$plugins$flags$set_flag_55472$$($id$jscomp$407$$,$key$jscomp$370$$,$value$jscomp$528$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$event$snapshot_performance_info$$=function($p__50594$$){var $map__50595__$1$$=$APP.$cljs$core$__destructure_map$$($p__50594$$),
$file_id$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50595__$1$$,$APP.$cljs$cst$1644$file_id$$);typeof $app$main$data$event$snapshot_performance_info_50609$$==="undefined"&&($app$main$data$event$snapshot_performance_info_50609$$=function($p__50594$jscomp$1$$,$map__50595$jscomp$1$$,$file_id$jscomp$16$$,$count_shapes$jscomp$1$$,$add_libraries_counters$jscomp$1$$,$meta50610$$){this.$p__50594$=$p__50594$jscomp$1$$;this.$map__50595$=$map__50595$jscomp$1$$;this.$file_id$=$file_id$jscomp$16$$;
this.$count_shapes$=$count_shapes$jscomp$1$$;this.$add_libraries_counters$=$add_libraries_counters$jscomp$1$$;this.$meta50610$=$meta50610$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$event$snapshot_performance_info_50609$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$snapshot_performance_info_50609$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2322$app_DOT_main_DOT_data_DOT_event_SLASH_snapshot_performance_info$$},
$app$main$data$event$snapshot_performance_info_50609$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50611$$,$meta50610__$1$$){return new $app$main$data$event$snapshot_performance_info_50609$$(this.$p__50594$,this.$map__50595$,this.$file_id$,this.$count_shapes$,this.$add_libraries_counters$,$meta50610__$1$$)},$app$main$data$event$snapshot_performance_info_50609$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50610$},$app$main$data$event$snapshot_performance_info_50609$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$snapshot_performance_info_50609$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1419$$,$state$jscomp$102$$){var $self__$jscomp$3002$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$102$$,$APP.$cljs$cst$2314$performance_info$$,function($info$jscomp$5$$){var $files$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$102$$,$APP.$cljs$cst$1916$files$$),$file$jscomp$14$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$6$$,$self__$jscomp$3002$$.$file_id$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($info$jscomp$5$$,$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$3002$$.$file_id$),$APP.$cljs$cst$2316$counters$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2323$total_shapes$$,$self__$jscomp$3002$$.$count_shapes$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$3002$$.$count_shapes$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$14$$):$self__$jscomp$3002$$.$count_shapes$($file$jscomp$14$$)),$APP.$cljs$cst$2316$counters$$,$self__$jscomp$3002$$.$add_libraries_counters$,$files$jscomp$6$$)})});return new $app$main$data$event$snapshot_performance_info_50609$$($p__50594$$,$map__50595__$1$$,$file_id$jscomp$15$$,function($file$jscomp$13$$){return $APP.$cljs$core$reduce_kv$$(function($sum$jscomp$1$$,$_$jscomp$1418$$,$page$jscomp$2$$){return $sum$jscomp$1$$+
$APP.$cljs$core$count$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$2$$))},0,$APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$13$$)))},function($state$jscomp$101$$,$files$jscomp$5$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$8$$,$data$jscomp$150_library_id$jscomp$4$$){$data$jscomp$150_library_id$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$5$$,
$data$jscomp$150_library_id$jscomp$4$$),$APP.$cljs$cst$142$data$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$8$$,$APP.$cljs$cst$2319$total_components$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$150_library_id$jscomp$4$$))),$APP.$cljs$cst$2320$total_colors$$,$APP.$cljs$core$_PLUS_$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$150_library_id$jscomp$4$$))),$APP.$cljs$cst$2321$total_typographies$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$count$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$150_library_id$jscomp$4$$)))},$state$jscomp$101$$,$APP.$app$main$refs$select_libraries$$($files$jscomp$5$$,$file_id$jscomp$15$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$event$store_performace_info$$=
function(){typeof $app$main$data$event$store_performace_info_50628$$==="undefined"&&($app$main$data$event$store_performace_info_50628$$=function($meta50629$$){this.$meta50629$=$meta50629$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$event$store_performace_info_50628$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$store_performace_info_50628$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2324$app_DOT_main_DOT_data_DOT_event_SLASH_store_performace_info$$},$app$main$data$event$store_performace_info_50628$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50630$$,$meta50629__$1$$){return new $app$main$data$event$store_performace_info_50628$$($meta50629__$1$$)},$app$main$data$event$store_performace_info_50628$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50629$},$app$main$data$event$store_performace_info_50628$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$store_performace_info_50628$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1420_start$jscomp$211$$,$state$jscomp$103$$){$_$jscomp$1420_start$jscomp$211$$=performance.now();a:for(var $end$jscomp$74_i$jscomp$inline_9700$$=1E6;;){if($end$jscomp$74_i$jscomp$inline_9700$$===0)break a;Math.sin($end$jscomp$74_i$jscomp$inline_9700$$)*Math.sqrt($end$jscomp$74_i$jscomp$inline_9700$$);--$end$jscomp$74_i$jscomp$inline_9700$$}$end$jscomp$74_i$jscomp$inline_9700$$=
performance.now();return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$103$$,$APP.$cljs$cst$2314$performance_info$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2325$bench$$,$end$jscomp$74_i$jscomp$inline_9700$$-$_$jscomp$1420_start$jscomp$211$$)},$app$main$data$event$store_performace_info_50628$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$store_performace_info_50628$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1421$$,
$___$1$jscomp$809$$,$stream$jscomp$16$$){return $APP.$beicon$v2$core$map$$($app$main$data$event$snapshot_performance_info$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2326$app_DOT_main_DOT_data_DOT_workspace_SLASH_all_libraries_resolved$$),$stream$jscomp$16$$))))});return new $app$main$data$event$store_performace_info_50628$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$team$finalize_team$$=function($team_id$jscomp$39$$){typeof $app$main$data$team$finalize_team_55444$$==="undefined"&&($app$main$data$team$finalize_team_55444$$=function($team_id$jscomp$40$$,$meta55445$$){this.$team_id$=$team_id$jscomp$40$$;this.$meta55445$=$meta55445$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$finalize_team_55444$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$finalize_team_55444$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3273$app_DOT_main_DOT_data_DOT_team_SLASH_finalize_team$$},$app$main$data$team$finalize_team_55444$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55446$$,$meta55445__$1$$){return new $app$main$data$team$finalize_team_55444$$(this.$team_id$,$meta55445__$1$$)},$app$main$data$team$finalize_team_55444$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55445$},$app$main$data$team$finalize_team_55444$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$finalize_team_55444$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1709_team_id_SINGLEQUOTE_$$,$state$jscomp$215$$){$_$jscomp$1709_team_id_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$215$$,$APP.$cljs$cst$1926$current_team_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1709_team_id_SINGLEQUOTE_$$,this.$team_id$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$215$$,
$APP.$cljs$cst$1926$current_team_id$$),$APP.$cljs$cst$2179$shared_files$$),$APP.$cljs$cst$2969$fonts$$):$state$jscomp$215$$});return new $app$main$data$team$finalize_team_55444$$($team_id$jscomp$39$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$reitit$trie$t_reitit$0trie50219$$=function($meta50198$jscomp$4$$,$_$jscomp$1442$$,$key$jscomp$321$$,$end$jscomp$78$$,$matcher$jscomp$11$$,$meta50220$$){this.$meta50198$=$meta50198$jscomp$4$$;this.$_$=$_$jscomp$1442$$;this.key=$key$jscomp$321$$;this.end=$end$jscomp$78$$;
this.$matcher$=$matcher$jscomp$11$$;this.$meta50220$=$meta50220$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$common_prefix$$=function($s1$jscomp$17$$,$s2$jscomp$14$$){var $max$jscomp$70_x__5113__auto__$jscomp$inline_9704$$=$APP.$cljs$core$count$$($s1$jscomp$17$$);var $i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$=$APP.$cljs$core$count$$($s2$jscomp$14$$);$max$jscomp$70_x__5113__auto__$jscomp$inline_9704$$=$max$jscomp$70_x__5113__auto__$jscomp$inline_9704$$<
$i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$?$max$jscomp$70_x__5113__auto__$jscomp$inline_9704$$:$i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$;for($i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$=0;;){if($i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$>$max$jscomp$70_x__5113__auto__$jscomp$inline_9704$$)return $APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s1$jscomp$17$$,0,$max$jscomp$70_x__5113__auto__$jscomp$inline_9704$$);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s1$jscomp$17$$,
$i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s2$jscomp$14$$,$i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$)))return $i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$!==0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s1$jscomp$17$$,0,$i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$):null;$i$jscomp$495_y__5114__auto__$jscomp$inline_9705$$+=1}},$reitit$trie$_slice_start$$=function($p__50121$$,$p__50122$$){function $_tailcut$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$,
$p__50138$$){var $JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50138$$,0,null),$JSCompiler_temp_const$jscomp$2050$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$;typeof $cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$!=="string"?$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$=new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$],null):typeof $cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$),$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$))?$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$=
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$,$APP.$cljs$core$count$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$))],null):typeof $JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$==="string"&&$APP.$cljs$core$not$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$)?
($cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$)?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$,"/"):$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$,$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$=
$APP.$cljs$core$truth_$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$,0,$cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$,
$cp$jscomp$10_temp__5823__auto__$jscomp$inline_13862$$)],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$],null)):$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$=null;return $JSCompiler_temp_const$jscomp$2050$$.call($APP.$cljs$core$concat$$,$JSCompiler_temp$jscomp$11059_JSCompiler_temp$jscomp$11060_JSCompiler_temp$jscomp$11061_p$jscomp$210$$,
$APP.$cljs$core$rest$$($p__50138$$))}function $_postcut$$($p__50134$$){var $p$jscomp$209$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50134$$,0,null),$i$jscomp$498$$=$APP.$cljs$core$truth_$$($p$jscomp$209$$)?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$209$$,"/"):$p$jscomp$209$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($i$jscomp$498$$)?$i$jscomp$498$$>0:$i$jscomp$498$$)?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($p$jscomp$209$$,0,$i$jscomp$498$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$209$$,$i$jscomp$498$$)],null),$APP.$cljs$core$rest$$($p__50134$$)):$p__50134$$}var $p1$jscomp$70$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50121$$,0,null),$p2$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50122$$,0,null);if($p1$jscomp$70$$==null||
$p2$jscomp$52$$==null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_postcut$$($p__50121$$),$_postcut$$($p__50122$$)],null);var $temp__5823__auto__$jscomp$126$$=function(){var $and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$=typeof $p1$jscomp$70$$==="string";return $and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$?($and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$=typeof $p2$jscomp$52$$==="string")?
$reitit$trie$common_prefix$$($p1$jscomp$70$$,$p2$jscomp$52$$):$and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$:$and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$}();return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$126$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_tailcut$$($temp__5823__auto__$jscomp$126$$,$p__50121$$),$_tailcut$$($temp__5823__auto__$jscomp$126$$,$p__50122$$)],null):new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__50121$$,$p__50122$$],null)},$reitit$trie$map_parameters$$=function($keys$jscomp$50$$){return $APP.$cljs$core$zipmap$$($keys$jscomp$50$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null))},$app$main$ui$css_cursors$init_dynamic_cursor_style$$=function($style$jscomp$57$$,$name$jscomp$416$$,$fn$jscomp$49$$){var $c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$=$APP.$cljs$core$seq$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,
360,10));$c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$);for(var $G__73818_chunk__73802_seq__73801__$1$$=null,$G__73817_count__73803$$=0,$i__73804$$=0;;)if($i__73804$$<$G__73817_count__73803$$){var $G__73819_rotation$jscomp$18$$=$G__73818_chunk__73802_seq__73801__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__73804$$);$style$jscomp$57$$.add(".cursor-"+($name$jscomp$416$$??
"")+"-"+($G__73819_rotation$jscomp$18$$??""),{cursor:""+(($fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__73819_rotation$jscomp$18$$):$fn$jscomp$49$$($G__73819_rotation$jscomp$18$$))??"")+" !important"});$i__73804$$+=1}else if($c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$))$G__73818_chunk__73802_seq__73801__$1$$=
$c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__73818_chunk__73802_seq__73801__$1$$)?($c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$=$APP.$cljs$core$_chunked_first$$($G__73818_chunk__73802_seq__73801__$1$$),$G__73817_count__73803$$=$APP.$cljs$core$_chunked_rest$$($G__73818_chunk__73802_seq__73801__$1$$),$G__73818_chunk__73802_seq__73801__$1$$=$c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$,
$G__73819_rotation$jscomp$18$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$),$c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$=$G__73817_count__73803$$,$G__73817_count__73803$$=$G__73819_rotation$jscomp$18$$):($G__73819_rotation$jscomp$18$$=$APP.$cljs$core$first$$($G__73818_chunk__73802_seq__73801__$1$$),$style$jscomp$57$$.add(".cursor-"+($name$jscomp$416$$??"")+"-"+($G__73819_rotation$jscomp$18$$??""),{cursor:""+
(($fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__73819_rotation$jscomp$18$$):$fn$jscomp$49$$($G__73819_rotation$jscomp$18$$))??"")+" !important"}),$c__5548__auto__$jscomp$24_rotations_seq__73801_temp__5825__auto__$jscomp$282$$=$APP.$cljs$core$next$$($G__73818_chunk__73802_seq__73801__$1$$),$G__73818_chunk__73802_seq__73801__$1$$=null,$G__73817_count__73803$$=0),$i__73804$$=0;else break},$reitit$impl$path_for$$=function($route$jscomp$1_temp__5823__auto__$jscomp$132$$,
$path_params$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2395$path_params$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$1_temp__5823__auto__$jscomp$132$$))?($route$jscomp$1_temp__5823__auto__$jscomp$132$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$107$$,$part$jscomp$2_temp__5823__auto__$jscomp$133$$){if(typeof $part$jscomp$2_temp__5823__auto__$jscomp$133$$==="string")return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$107$$,
$part$jscomp$2_temp__5823__auto__$jscomp$133$$);$part$jscomp$2_temp__5823__auto__$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path_params$jscomp$1$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($part$jscomp$2_temp__5823__auto__$jscomp$133$$));return $APP.$cljs$core$truth_$$($part$jscomp$2_temp__5823__auto__$jscomp$133$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$107$$,$part$jscomp$2_temp__5823__auto__$jscomp$133$$):$APP.$cljs$core$reduced$$(null)},
$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$2396$path_parts$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$1_temp__5823__auto__$jscomp$132$$)),$APP.$cljs$core$truth_$$($route$jscomp$1_temp__5823__auto__$jscomp$132$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$route$jscomp$1_temp__5823__auto__$jscomp$132$$):null):$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$1_temp__5823__auto__$jscomp$132$$)},$app$main$fonts$find_variant$$=
function($map__53072__$1_p__53071_variants$jscomp$4$$,$variant_data$$){$map__53072__$1_p__53071_variants$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__53072__$1_p__53071_variants$jscomp$4$$);$map__53072__$1_p__53071_variants$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53072__$1_p__53071_variants$jscomp$4$$,$APP.$cljs$cst$2676$variants$$);var $props$jscomp$94$$=$APP.$cljs$core$keys$$($variant_data$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53070_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($p1__53070_SHARP_$$,
$props$jscomp$94$$),$variant_data$$)},$map__53072__$1_p__53071_variants$jscomp$4$$)},$cljs$core$shuffle$$=function($a$jscomp$109_coll$jscomp$150$$){$a$jscomp$109_coll$jscomp$150$$=$APP.$cljs$core$to_array$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$to_array$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$109_coll$jscomp$150$$):$APP.$cljs$core$to_array$$($a$jscomp$109_coll$jscomp$150$$);const $randFn$jscomp$inline_9712$$=Math.random;for(let $i$jscomp$inline_9713$$=$a$jscomp$109_coll$jscomp$150$$.length-
1;$i$jscomp$inline_9713$$>0;$i$jscomp$inline_9713$$--){const $j$jscomp$inline_9714$$=Math.floor($randFn$jscomp$inline_9712$$()*($i$jscomp$inline_9713$$+1)),$tmp$jscomp$inline_9715$$=$a$jscomp$109_coll$jscomp$150$$[$i$jscomp$inline_9713$$];$a$jscomp$109_coll$jscomp$150$$[$i$jscomp$inline_9713$$]=$a$jscomp$109_coll$jscomp$150$$[$j$jscomp$inline_9714$$];$a$jscomp$109_coll$jscomp$150$$[$j$jscomp$inline_9714$$]=$tmp$jscomp$inline_9715$$}return $APP.$cljs$core$vec$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$vec$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$109_coll$jscomp$150$$):
$APP.$cljs$core$vec$$($a$jscomp$109_coll$jscomp$150$$)},$meta_merge$core$remove_top_displace$$=function($JSCompiler_temp$jscomp$11062_obj$jscomp$183$$){if(!$APP.$cljs$core$not$$($APP.$cljs$cst$2369$top_displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($JSCompiler_temp$jscomp$11062_obj$jscomp$183$$)))){var $G__23227$jscomp$inline_13866_JSCompiler_inline_result$jscomp$inline_13865$$=$APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$11062_obj$jscomp$183$$);$G__23227$jscomp$inline_13866_JSCompiler_inline_result$jscomp$inline_13865$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__23227$jscomp$inline_13866_JSCompiler_inline_result$jscomp$inline_13865$$,$APP.$cljs$cst$2369$top_displace$$):$APP.$cljs$core$dissoc$$($G__23227$jscomp$inline_13866_JSCompiler_inline_result$jscomp$inline_13865$$,$APP.$cljs$cst$2369$top_displace$$);$JSCompiler_temp$jscomp$11062_obj$jscomp$183$$=$APP.$cljs$core$with_meta$$($JSCompiler_temp$jscomp$11062_obj$jscomp$183$$,$G__23227$jscomp$inline_13866_JSCompiler_inline_result$jscomp$inline_13865$$)}return $JSCompiler_temp$jscomp$11062_obj$jscomp$183$$},
$meta_merge$core$pick_prioritized$$=function($left$jscomp$20$$,$right$jscomp$17$$){return $left$jscomp$20$$==null?$right$jscomp$17$$:$right$jscomp$17$$==null?$meta_merge$core$remove_top_displace$$($left$jscomp$20$$):$APP.$cljs$core$truth_$$($APP.$cljs$cst$2369$top_displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($left$jscomp$20$$)))?$right$jscomp$17$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$281$$=$meta_merge$core$displace_QMARK_$$($left$jscomp$20$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$281$$)?$meta_merge$core$displace_QMARK_$$($right$jscomp$17$$):$and__5023__auto__$jscomp$281$$}())?$meta_merge$core$with_meta_STAR_$$($right$jscomp$17$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$meta_merge$core$meta_STAR_$$($right$jscomp$17$$)]))):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$282$$=
$meta_merge$core$replace_QMARK_$$($left$jscomp$20$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$282$$)?$meta_merge$core$replace_QMARK_$$($right$jscomp$17$$):$and__5023__auto__$jscomp$282$$}())?$meta_merge$core$with_meta_STAR_$$($right$jscomp$17$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$meta_merge$core$meta_STAR_$$($right$jscomp$17$$)]))):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$420$$=
$meta_merge$core$displace_QMARK_$$($left$jscomp$20$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$420$$)?$or__5025__auto__$jscomp$420$$:$meta_merge$core$replace_QMARK_$$($right$jscomp$17$$)}())?$meta_merge$core$with_meta_STAR_$$($right$jscomp$17$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$APP.$cljs$cst$2367$displace$$),
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($right$jscomp$17$$),$APP.$cljs$cst$2368$replace$$)]))):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$421$$=$meta_merge$core$replace_QMARK_$$($left$jscomp$20$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$421$$)?$or__5025__auto__$jscomp$421$$:$meta_merge$core$displace_QMARK_$$($right$jscomp$17$$)}())?$meta_merge$core$with_meta_STAR_$$($left$jscomp$20$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($right$jscomp$17$$),
$APP.$cljs$cst$2367$displace$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$APP.$cljs$cst$2368$replace$$)]))):null},$reitit$impl$compile_routes$$=function($routes$jscomp$7$$,$opts$jscomp$270$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51640_SHARP_$$){var $p$jscomp$inline_9721$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__51640_SHARP_$$,
0,null),$m$jscomp$inline_9722$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__51640_SHARP_$$,1,null),$map__51639__$1$jscomp$inline_9723$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$270$$),$compile$jscomp$inline_9724$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51639__$1$jscomp$inline_9723$$,$APP.$cljs$cst$411$compile$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p$jscomp$inline_9721$$,$m$jscomp$inline_9722$$,
$APP.$cljs$core$truth_$$($compile$jscomp$inline_9724$$)?$compile$jscomp$inline_9724$$.$cljs$core$IFn$_invoke$arity$2$?$compile$jscomp$inline_9724$$.$cljs$core$IFn$_invoke$arity$2$($p1__51640_SHARP_$$,$map__51639__$1$jscomp$inline_9723$$):$compile$jscomp$inline_9724$$($p1__51640_SHARP_$$,$map__51639__$1$jscomp$inline_9723$$):null],null)},$routes$jscomp$7$$))},$reitit$impl$_match$$=function($path$jscomp$206$$,$path_map$$){function $match$jscomp$36$$($x$jscomp$1138$$,$f$jscomp$791$$){return $APP.$cljs$core$fn_QMARK_$$($f$jscomp$791$$)?
$f$jscomp$791$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$791$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1138$$):$f$jscomp$791$$($x$jscomp$1138$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1138$$,$f$jscomp$791$$)}return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$1455_ps$jscomp$23$$,$f$jscomp$792_p__51417$$){$_$jscomp$1455_ps$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$792_p__51417$$,0,null);$f$jscomp$792_p__51417$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$792_p__51417$$,1,null);return $APP.$cljs$core$count$$($path$jscomp$206$$)>=$APP.$cljs$core$count$$($_$jscomp$1455_ps$jscomp$23$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$identity$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($match$jscomp$36$$,$path$jscomp$206$$,$_$jscomp$1455_ps$jscomp$23$$))?$APP.$cljs$core$reduced$$($f$jscomp$792_p__51417$$):null},null,$path_map$$)},$reitit$impl$_path_vals$$=function($m$jscomp$206$$,
$path_map$jscomp$1$$){return function $reitit$impl$_path_vals_$__path_vals$$($l$jscomp$98$$,$p$jscomp$220$$,$m__$1$jscomp$8$$){return $APP.$cljs$core$reduce_kv$$(function($l__$1$jscomp$1$$,$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$v$jscomp$551$$){$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$220$$,$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$);var $f$jscomp$793$$=$reitit$impl$_match$$($k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$path_map$jscomp$1$$);
return $APP.$cljs$core$truth_$$($f$jscomp$793$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l__$1$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$f$jscomp$793$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$793$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$551$$):$f$jscomp$793$$($v$jscomp$551$$)],null)):$APP.$cljs$core$map_QMARK_$$($v$jscomp$551$$)&&!$APP.$cljs$core$record_QMARK_$$($v$jscomp$551$$)&&
$APP.$cljs$core$seq$$($v$jscomp$551$$)?$reitit$impl$_path_vals_$__path_vals$$($l__$1$jscomp$1$$,$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$v$jscomp$551$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l__$1$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$v$jscomp$551$$],null))},$l$jscomp$98$$,$m__$1$jscomp$8$$)}($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,
$m$jscomp$206$$)},$reitit$trie$t_reitit$0trie50259$$=function($meta50198$jscomp$8$$,$_$jscomp$1446$$,$matchers$jscomp$2$$,$ordered_QMARK_$jscomp$3$$,$size$jscomp$99$$,$meta50260$$){this.$meta50198$=$meta50198$jscomp$8$$;this.$_$=$_$jscomp$1446$$;this.$matchers$=$matchers$jscomp$2$$;this.$ordered_QMARK_$=$ordered_QMARK_$jscomp$3$$;this.size=$size$jscomp$99$$;this.$meta50260$=$meta50260$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$util$theme$use_initialize$$=
function($map__73796__$1_p__73795$$){$map__73796__$1_p__73795$$=$APP.$cljs$core$__destructure_map$$($map__73796__$1_p__73795$$);var $profile_theme$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73796__$1_p__73795$$,$APP.$cljs$cst$3184$theme$$),$system_theme_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$util$theme$get_system_theme$$),$system_theme$$=$APP.$cljs$core$_deref$$($system_theme_STAR_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $s$jscomp$555$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73794_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($system_theme_STAR_$$,$p1__73794_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__73793_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__73793_SHARP_$$.matches)?"dark":"light"},$APP.$shadow$js$shim$module$0rxjs$$.fromEvent($APP.$app$util$theme$color_scheme_media_query$$,"change")));return function(){return $APP.$beicon$v2$core$_dispose$$($s$jscomp$555$$)}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($system_theme$$),$APP.$rumext$v2$adapt$$($profile_theme$$)],function(){var $class$$jscomp$inline_9728_color$jscomp$inline_9726$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_theme$$,"system")?$system_theme$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_theme$$,"default")?"dark":$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($profile_theme$$,"dark"),$node$jscomp$inline_9727$$=
document.querySelector("body");$class$$jscomp$inline_9728_color$jscomp$inline_9726$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$inline_9728_color$jscomp$inline_9726$$,"dark")?"default":"light";$node$jscomp$inline_9727$$.removeAttribute("class");return $node$jscomp$inline_9727$$.classList.add($class$$jscomp$inline_9728_color$jscomp$inline_9726$$)})},$app$main$data$exports$files$export_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($files$jscomp$24_map__73230__$1_p__73226$$){$files$jscomp$24_map__73230__$1_p__73226$$=
$APP.$cljs$core$__destructure_map$$($files$jscomp$24_map__73230__$1_p__73226$$);var $type$jscomp$587$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$24_map__73230__$1_p__73226$$,$APP.$cljs$cst$139$type$$);$files$jscomp$24_map__73230__$1_p__73226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$24_map__73230__$1_p__73226$$,$APP.$cljs$cst$1916$files$$);return $APP.$beicon$v2$core$mapcat$$(function($file$jscomp$88$$){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$90_error$jscomp$80$$){$cause$jscomp$90_error$jscomp$80$$=
$APP.$cljs$core$ex_data$$($cause$jscomp$90_error$jscomp$80$$);return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$88$$),$APP.$cljs$cst$849$error$$,$cause$jscomp$90_error$jscomp$80$$],null))},$APP.$beicon$v2$core$map$$(function($uri$jscomp$103$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$88$$),
$APP.$cljs$cst$1579$uri$$,$uri$jscomp$103$$,$APP.$cljs$cst$4767$filename$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$88$$)],null)},$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2263$app_DOT_util_DOT_sse_SLASH_export_binfile$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$88$$),
$APP.$cljs$cst$2289$version$$,3,$APP.$cljs$cst$5016$include_libraries$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$587$$,$APP.$cljs$cst$2124$all$$),$APP.$cljs$cst$5017$embed_assets$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$587$$,$APP.$cljs$cst$735$merge$$)],null))))))},$APP.$beicon$v2$core$from$$($files$jscomp$24_map__73230__$1_p__73226$$))},$reitit$exception$exception$$=function($e$jscomp$293$$){var $data$jscomp$154$$=$APP.$cljs$core$ex_data$$($e$jscomp$293$$),
$message$jscomp$55$$=$APP.$reitit$exception$format_exception$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$154$$),$APP.$cljs$core$ex_message$$($e$jscomp$293$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$154$$));return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($message$jscomp$55$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$truth_$$($data$jscomp$154$$)?$data$jscomp$154$$:
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2362$reitit_DOT_exception_SLASH_cause$$,$e$jscomp$293$$))},$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$371$$,$data$jscomp$153$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$371$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$371$$,$APP.$cljs$cst$142$data$$,$data$jscomp$153$$],
null));},$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ob$jscomp$72$$){var $JSCompiler_inline_result$jscomp$2057$$=$APP.$shadow$js$shim$module$0rxjs$$.timeout(3E3);return $APP.$beicon$v2$operators$pipe$$($JSCompiler_inline_result$jscomp$2057$$,$ob$jscomp$72$$)},$app$main$ui$static$0$load_info$$=function($path_params$jscomp$19_stream$jscomp$104$$){var $default$$jscomp$89$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5024$loaded$$,!0],null);$path_params$jscomp$19_stream$jscomp$104$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$104$$))?$APP.$beicon$v2$core$map$$(function($info$jscomp$6$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5024$loaded$$,!0,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$6$$)],null)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5417$get_file_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$104$$)],null))):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$104$$))?$APP.$beicon$v2$core$map$$(function($info$jscomp$7$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$5024$loaded$$,!0,$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$7$$),
$APP.$cljs$cst$5418$team_default$$,$APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$7$$)],null)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5419$get_team_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$104$$)],null))):(0,$APP.$beicon$v2$core$of$$)($default$$jscomp$89$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$104$$){return $cause$jscomp$104$$ instanceof
$APP.$app$main$ui$static$0$TimeoutError$$?(0,$APP.$beicon$v2$core$of$$)($default$$jscomp$89$$):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$104$$)},$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$($path_params$jscomp$19_stream$jscomp$104$$))},$app$main$data$common$create_team_access_request$$=function($params$jscomp$149$$){typeof $app$main$data$common$create_team_access_request_52517$$==="undefined"&&($app$main$data$common$create_team_access_request_52517$$=function($params$jscomp$150$$,
$meta52518$$){this.params=$params$jscomp$150$$;this.$meta52518$=$meta52518$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$create_team_access_request_52517$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$create_team_access_request_52517$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2487$app_DOT_main_DOT_data_DOT_common_SLASH_create_team_access_request$$},
$app$main$data$common$create_team_access_request_52517$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52519$$,$meta52518__$1$$){return new $app$main$data$common$create_team_access_request_52517$$(this.params,$meta52518__$1$$)},$app$main$data$common$create_team_access_request_52517$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52518$},$app$main$data$common$create_team_access_request_52517$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$create_team_access_request_52517$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__52520_on_success$$=$APP.$cljs$core$meta$$(this.params),$map__52520__$1_on_error$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__52520_on_success$$);$map__52520_on_success$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52520__$1_on_error$jscomp$3$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__52520__$1_on_error$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52520__$1_on_error$jscomp$3$$,
$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__52520__$1_on_error$jscomp$3$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__52520_on_success$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2489$create_team_access_request$$,this.params)))});return new $app$main$data$common$create_team_access_request_52517$$($params$jscomp$149$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$reitit$impl$map_data$$=function($f$jscomp$795$$,$routes$jscomp$3$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($ds$jscomp$12_p__51533$$){var $p$jscomp$223$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ds$jscomp$12_p__51533$$,0,null);$ds$jscomp$12_p__51533$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ds$jscomp$12_p__51533$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p$jscomp$223$$,
$f$jscomp$795$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$795$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$223$$,$ds$jscomp$12_p__51533$$):$f$jscomp$795$$($p$jscomp$223$$,$ds$jscomp$12_p__51533$$)],null)},$routes$jscomp$3$$)},$reitit$impl$walk$$=function($raw_routes$$,$p__51485_path$jscomp$210$$){function $walk_one$$($pacc$$,$macc_macc__$1$$,$first__51520_routes__$1$$){if($APP.$cljs$core$vector_QMARK_$$($APP.$cljs$core$first$$($first__51520_routes__$1$$)))return $walk_many$$($pacc$$,$macc_macc__$1$$,
$first__51520_routes__$1$$);if(typeof $APP.$cljs$core$first$$($first__51520_routes__$1$$)==="string"){var $childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$=$APP.$cljs$core$seq$$($first__51520_routes__$1$$);$first__51520_routes__$1$$=$APP.$cljs$core$first$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$);$childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$=$APP.$cljs$core$next$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$);var $child_routes_data__$1$jscomp$6_maybe_arg$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$,0,null);$childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$=$APP.$cljs$core$vector_QMARK_$$($child_routes_data__$1$jscomp$6_maybe_arg$$)||$APP.$cljs$core$sequential_QMARK_$$($child_routes_data__$1$jscomp$6_maybe_arg$$)&&$APP.$cljs$core$sequential_QMARK_$$($APP.$cljs$core$first$$($child_routes_data__$1$jscomp$6_maybe_arg$$))||$child_routes_data__$1$jscomp$6_maybe_arg$$==null?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_routes_data__$1$jscomp$6_maybe_arg$$,$APP.$cljs$core$rest$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$)],null);$child_routes_data__$1$jscomp$6_maybe_arg$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$,
0,null);$childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$,1,null);$macc_macc__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($macc_macc__$1$$,$expand$$.$cljs$core$IFn$_invoke$arity$2$?$expand$$.$cljs$core$IFn$_invoke$arity$2$($child_routes_data__$1$jscomp$6_maybe_arg$$,$map__51487__$1$$):$expand$$($child_routes_data__$1$jscomp$6_maybe_arg$$,$map__51487__$1$$));$child_routes_data__$1$jscomp$6_maybe_arg$$=
$walk_many$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pacc$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first__51520_routes__$1$$)].join(""),$macc_macc__$1$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$));return $APP.$cljs$core$seq$$($childs$jscomp$5_seq__51519_seq__51519__$1_vec__51524$$)?$APP.$cljs$core$seq$$($child_routes_data__$1$jscomp$6_maybe_arg$$):new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pacc$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first__51520_routes__$1$$)].join(""),$macc_macc__$1$$],null)],null)}return null}function $walk_many$$($p$jscomp$222$$,$m$jscomp$210$$,$r$jscomp$106$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__51483_SHARP_$$,
$p2__51484_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__51483_SHARP_$$,$walk_one$$($p$jscomp$222$$,$m$jscomp$210$$,$p2__51484_SHARP_$$))},$APP.$cljs$core$PersistentVector$EMPTY$$,$r$jscomp$106$$)}var $map__51487__$1$$=$APP.$cljs$core$__destructure_map$$($p__51485_path$jscomp$210$$);$p__51485_path$jscomp$210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51487__$1$$,$APP.$cljs$cst$296$path$$);var $data$jscomp$175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51487__$1$$,
$APP.$cljs$cst$142$data$$,$APP.$cljs$core$PersistentVector$EMPTY$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51487__$1$$,$APP.$cljs$cst$2397$routes$$,$APP.$cljs$core$PersistentVector$EMPTY$$);var $expand$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51487__$1$$,$APP.$cljs$cst$2398$expand$$);return $walk_one$$($p__51485_path$jscomp$210$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$identity$$,$data$jscomp$175$$),$raw_routes$$)},$app$main$ui$components$forms$image_radio_buttons$$=
function($props_73559$$){var $form$jscomp$164$$=function(){var $or__5025__auto__$jscomp$950$$=$props_73559$$.form;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$950$$)?$or__5025__auto__$jscomp$950$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$)}(),$name$jscomp$407$$=$props_73559$$.name,$image$jscomp$32$$=$props_73559$$.image,$img_height$$=$props_73559$$["img-height"],$img_width$$=$props_73559$$["img-width"],$current_value$jscomp$3$$=function(){var $or__5025__auto__$jscomp$951$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$164$$),$APP.$cljs$cst$142$data$$),$name$jscomp$407$$,"");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$951$$)?$or__5025__auto__$jscomp$951$$:$props_73559$$.value}(),$on_change$jscomp$21$$=$props_73559$$["on-change"],$options$jscomp$591$$=$props_73559$$.options,$trim_QMARK_$jscomp$3$$=$props_73559$$.trim,$class$$jscomp$38$$=$props_73559$$["class"],
$encode_fn$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_73559$$["encode-fn"],$APP.$cljs$core$identity$$),$decode_fn$jscomp$6$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_73559$$["decode-fn"],$APP.$cljs$core$identity$$),$on_change_SINGLEQUOTE_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$21$$),$APP.$rumext$v2$adapt$$($form$jscomp$164$$),$APP.$rumext$v2$adapt$$($name$jscomp$407$$)],
function($G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$){$G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$));$G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$=$decode_fn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$decode_fn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$):
$decode_fn$jscomp$6$$($G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$);$form$jscomp$164$$!=null&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$164$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$name$jscomp$407$$],null),!0),$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$164$$,$name$jscomp$407$$,$G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$,
$trim_QMARK_$jscomp$3$$));return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$21$$)?$on_change$jscomp$21$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$21$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$407$$,$G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$):$on_change$jscomp$21$$($name$jscomp$407$$,$G__73560$jscomp$inline_9732_event$jscomp$182_value$jscomp$745$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:$APP.$cljs$core$truth_$$($image$jscomp$32$$)?$class$$jscomp$38$$:
""+($class$$jscomp$38$$??"")+" main_ui_components_forms__custom-radio",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$45$$,$JSCompiler_inline_result$jscomp$2060_image__$1$jscomp$1_p__73561$$){var $JSCompiler_temp_const$jscomp$2058_map__73562__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$2060_image__$1$jscomp$1_p__73561$$);$JSCompiler_inline_result$jscomp$2060_image__$1$jscomp$1_p__73561$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2058_map__73562__$1$$,
$APP.$cljs$cst$1612$image$$);var $icon$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2058_map__73562__$1$$,$APP.$cljs$cst$1721$icon$$),$checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2058_map__73562__$1$$,$APP.$cljs$cst$260$value$$),$label$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2058_map__73562__$1$$,$APP.$cljs$cst$2287$label$$),
$area$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2058_map__73562__$1$$,$APP.$cljs$cst$1674$area$$);$JSCompiler_temp_const$jscomp$2058_map__73562__$1$$=$out_arr__44124__auto__$jscomp$45$$.push;var $icon_QMARK_$jscomp$inline_9734$$=$icon$jscomp$14$$!=null,$value_SINGLEQUOTE_$jscomp$inline_9735$$=$encode_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$encode_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$):
$encode_fn$jscomp$3$$($checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$);$checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$,$current_value$jscomp$3$$);var $key$jscomp$inline_9737$$=""+($APP.$app$common$data$name$$($name$jscomp$407$$)??"")+"-"+($APP.$app$common$data$name$$($value_SINGLEQUOTE_$jscomp$inline_9735$$)??"");$JSCompiler_inline_result$jscomp$2060_image__$1$jscomp$1_p__73561$$=
(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$key$jscomp$inline_9737$$,style:{gridArea:$area$jscomp$6$$},className:"main_ui_components_forms__radio-label-image "+($checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$?"checked":""),children:[$icon_QMARK_$jscomp$inline_9734$$?(0,$APP.$rumext$v2$jsx$$)("span",{style:{height:$img_height$$,width:$img_width$$},className:"main_ui_components_forms__icon-inside",children:$icon$jscomp$14$$}):(0,$APP.$rumext$v2$jsx$$)("span",{style:{backgroundImage:"url("+($JSCompiler_inline_result$jscomp$2060_image__$1$jscomp$1_p__73561$$??
"")+")",height:$img_height$$,width:$img_width$$},className:"main_ui_components_forms__image-inside"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__image-text",children:$label$jscomp$30$$}),(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$on_change_SINGLEQUOTE_$jscomp$2$$,type:"radio",id:$key$jscomp$inline_9737$$,name:$name$jscomp$407$$,value:$value_SINGLEQUOTE_$jscomp$inline_9735$$,checked:$checked_QMARK_$jscomp$inline_9736_value$jscomp$746$$,className:"main_ui_components_forms__radio-input"})]},
$key$jscomp$inline_9737$$);$JSCompiler_temp_const$jscomp$2058_map__73562__$1$$.call($out_arr__44124__auto__$jscomp$45$$,$JSCompiler_inline_result$jscomp$2060_image__$1$jscomp$1_p__73561$$);return $out_arr__44124__auto__$jscomp$45$$},[],$options$jscomp$591$$)})},$app$main$data$workspace$texts$decorate_range_info$$=function($content$jscomp$183$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$(function($node$jscomp$315$$){return $APP.$app$common$data$update_when$$($node$jscomp$315$$,
$APP.$cljs$cst$342$children$$,function($children$jscomp$248$$){var $start$jscomp$221$$=$APP.$cljs$cst$1292$start$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$meta$$($node$jscomp$315$$),0);return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__70114_start__$1$jscomp$13$$,$node__$1$jscomp$71$$){var $result$jscomp$305$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70114_start__$1$jscomp$13$$,0,null);$p__70114_start__$1$jscomp$13$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70114_start__$1$jscomp$13$$,1,null);var $end$jscomp$87$$=$p__70114_start__$1$jscomp$13$$+$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$71$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$305$$,$APP.$cljs$core$with_meta$$($node__$1$jscomp$71$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1292$start$$,$p__70114_start__$1$jscomp$13$$,$APP.$cljs$cst$1293$end$$,$end$jscomp$87$$],null))),$end$jscomp$87$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$start$jscomp$221$$],null),$children$jscomp$248$$))})},$APP.$cljs$core$with_meta$$($content$jscomp$183$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1292$start$$,0,$APP.$cljs$cst$1293$end$$,$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$183$$)],
null)))},$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$02$$=function($data$jscomp$293$$,$variant_id$jscomp$6$$){var $objects$jscomp$260_page_id$jscomp$86$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55583_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55583_SHARP_$$),
$variant_id$jscomp$6$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$293$$)))));$objects$jscomp$260_page_id$jscomp$86$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$293$$,$APP.$cljs$cst$1630$pages_index$$),$objects$jscomp$260_page_id$jscomp$86$$),$APP.$cljs$cst$1631$objects$$);return $APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$293$$,
$objects$jscomp$260_page_id$jscomp$86$$,$variant_id$jscomp$6$$)},$reitit$impl$unresolved_conflicts$$=function($path_conflicting$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($conflicts$jscomp$2_p__51593$$){var $and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($conflicts$jscomp$2_p__51593$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$,0,null);$and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$,1,null);$conflicts$jscomp$2_p__51593$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($conflicts$jscomp$2_p__51593$$,1,null);$and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$=
$APP.$cljs$cst$2364$conflicting$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$)?$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2364$conflicting$$,$APP.$cljs$core$second$$),$conflicts$jscomp$2_p__51593$$):$and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51597$$}),$path_conflicting$$))},$app$main$data$workspace$texts$update_content_range$$=
function($content$jscomp$185$$,$start$jscomp$223$$,$end$jscomp$89$$,$attrs$jscomp$121$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$(function($node$jscomp$318$$){return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$318$$)&&$APP.$cljs$cst$1292$start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$318$$))>=$start$jscomp$223$$&&$APP.$cljs$cst$1293$end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$318$$))<=
$end$jscomp$89$$},function($p1__70128_SHARP_$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($p1__70128_SHARP_$$,$attrs$jscomp$121$$)},$content$jscomp$185$$)},$app$main$data$workspace$texts$split_content_at$$=function($content$jscomp$184$$,$position$jscomp$100$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$(function($node$jscomp$316$$){return $APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$316$$)&&$APP.$cljs$cst$1292$start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$316$$))<
$position$jscomp$100$$&&$position$jscomp$100$$<$APP.$cljs$cst$1293$end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$316$$))},function($node$jscomp$317$$){function $process_node$$($child$jscomp$119$$){var $start$jscomp$222$$=$APP.$cljs$cst$1292$start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($child$jscomp$119$$)),$end$jscomp$88$$=$APP.$cljs$cst$1293$end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($child$jscomp$119$$));return $start$jscomp$222$$<
$position$jscomp$100$$&&$position$jscomp$100$$<$end$jscomp$88$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($child$jscomp$119$$,$APP.$cljs$cst$1293$end$$,$position$jscomp$100$$),$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$subs$$,0,$position$jscomp$100$$-$start$jscomp$222$$),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($child$jscomp$119$$,
$APP.$cljs$cst$1292$start$$,$position$jscomp$100$$),$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$subs$$,$position$jscomp$100$$-$start$jscomp$222$$)],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child$jscomp$119$$],null)}return $APP.$app$common$data$update_when$$($node$jscomp$317$$,$APP.$cljs$cst$342$children$$,function($p1__70118_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($process_node$$),
$p1__70118_SHARP_$$)})},$content$jscomp$184$$)},$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$01$$=function($n$jscomp$91$$){return function($rf$jscomp$5$$){var $na$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$($n$jscomp$91$$);return function(){function $G__27050__2$$($result$jscomp$41$$,$input$jscomp$24$$){var $n__$1$jscomp$3$$=$APP.$cljs$core$_deref$$($na$jscomp$1$$);$na$jscomp$1$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$na$jscomp$1$$.$cljs$core$IDeref$_deref$arity$1$(null)-1);return $n__$1$jscomp$3$$>
0?$result$jscomp$41$$:$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$41$$,$input$jscomp$24$$):$rf$jscomp$5$$($result$jscomp$41$$,$input$jscomp$24$$)}function $G__27050__1$$($result$jscomp$40$$){return $rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$40$$):$rf$jscomp$5$$($result$jscomp$40$$)}function $G__27050__0$$(){return $rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():
$rf$jscomp$5$$()}var $G__27050$$=null;$G__27050$$=function($result$jscomp$42$$,$input$jscomp$25$$){switch(arguments.length){case 0:return $G__27050__0$$.call(this);case 1:return $G__27050__1$$.call(this,$result$jscomp$42$$);case 2:return $G__27050__2$$.call(this,$result$jscomp$42$$,$input$jscomp$25$$)}throw Error("Invalid arity: "+arguments.length);};$G__27050$$.$cljs$core$IFn$_invoke$arity$0$=$G__27050__0$$;$G__27050$$.$cljs$core$IFn$_invoke$arity$1$=$G__27050__1$$;$G__27050$$.$cljs$core$IFn$_invoke$arity$2$=
$G__27050__2$$;return $G__27050$$}()}},$app$main$data$event$remove_from_buffer$$=function($buffer$jscomp$61$$,$items$jscomp$25$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$01$$($items$jscomp$25$$),$buffer$jscomp$61$$)},$reitit$impl$uncompile_routes$$=function($routes$jscomp$8$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$,
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$take$$,2)),$routes$jscomp$8$$)},$app$plugins$utils$throw_validation_errors_QMARK_$$=function($plugin_id$jscomp$5$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$3197$plugins$$),
$APP.$cljs$cst$1467$flags$$),$plugin_id$jscomp$5$$),$APP.$cljs$cst$3391$throw_validation_errors$$))},$app$plugins$utils$not_valid$$=function($plugin_id$jscomp$6$$,$code$jscomp$34$$,$value$jscomp$526$$){if($app$plugins$utils$throw_validation_errors_QMARK_$$($plugin_id$jscomp$6$$)){if($value$jscomp$526$$!=null)throw Error("[PENPOT PLUGIN] Value not valid: "+($value$jscomp$526$$??"")+". Code: "+($code$jscomp$34$$??""));throw Error("[PENPOT PLUGIN] Value not valid. Code: "+($code$jscomp$34$$??""));}$value$jscomp$526$$!=
null?console.error("[PENPOT PLUGIN] Value not valid: "+($value$jscomp$526$$??"")+". Code: "+($code$jscomp$34$$??"")):console.error("[PENPOT PLUGIN] Value not valid. Code: "+($code$jscomp$34$$??""));return null},$app$plugins$utils$natural_child_ordering_QMARK_$$=function($plugin_id$jscomp$4$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$3197$plugins$$),$APP.$cljs$cst$1467$flags$$),$plugin_id$jscomp$4$$),$APP.$cljs$cst$3390$natural_child_ordering$$))},$app$plugins$utils$locate_component$$=function($objects$jscomp$258_root$jscomp$49$$,$shape$jscomp$374$$){var $libraries$jscomp$32_state$jscomp$240$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file$jscomp$44$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($libraries$jscomp$32_state$jscomp$240$$);$libraries$jscomp$32_state$jscomp$240$$=
$APP.$app$main$data$helpers$lookup_libraries$$($libraries$jscomp$32_state$jscomp$240$$);$objects$jscomp$258_root$jscomp$49$$=$APP.$app$common$types$container$get_instance_root$$($objects$jscomp$258_root$jscomp$49$$,$shape$jscomp$374$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$objects$jscomp$258_root$jscomp$49$$,$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($objects$jscomp$258_root$jscomp$49$$,
$file$jscomp$44$$,$libraries$jscomp$32_state$jscomp$240$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]))],null)},$app$plugins$utils$locate_presence$$=function($session_id$jscomp$1$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$2216$workspace_presence$$),
$session_id$jscomp$1$$)},$app$plugins$utils$locate_profile$$=function($map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$){$map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$=$app$plugins$utils$locate_presence$$($map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$);$map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$);$map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$,$APP.$cljs$cst$2313$profile_id$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1915$profiles$$),$map__55390_map__55390__$1_profile_id$jscomp$10_session_id$jscomp$2$$)},$app$plugins$utils$locate_page$$=function($file_id$jscomp$45$$,$id$jscomp$392$$){return $APP.$app$main$data$helpers$get_page$$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$file_id$jscomp$45$$),$id$jscomp$392$$)},$app$plugins$utils$locate_ruler_guide$$=function($file_id$jscomp$61_page$jscomp$46$$,$page_id$jscomp$79$$,$ruler_id$$){$file_id$jscomp$61_page$jscomp$46$$=$app$plugins$utils$locate_page$$($file_id$jscomp$61_page$jscomp$46$$,$page_id$jscomp$79$$);return $file_id$jscomp$61_page$jscomp$46$$!=null?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55406_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55406_SHARP_$$),
$ruler_id$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$2057$guides$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$61_page$jscomp$46$$))):null},$app$plugins$utils$proxy__GT_ruler_guide$$=function($proxy$jscomp$10$$){return $app$plugins$utils$locate_ruler_guide$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$10$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$10$$,"$page"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$10$$,
"$id"))},$app$plugins$utils$proxy__GT_flow$$=function($page$jscomp$45_proxy$jscomp$9$$){var $flow_id$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$45_proxy$jscomp$9$$,"$id");$page$jscomp$45_proxy$jscomp$9$$=$app$plugins$utils$locate_page$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$45_proxy$jscomp$9$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$45_proxy$jscomp$9$$,"$page"));return $page$jscomp$45_proxy$jscomp$9$$!=
null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$45_proxy$jscomp$9$$),$flow_id$$):null},$app$plugins$utils$proxy__GT_page$$=function($id$jscomp$399_proxy$jscomp$4$$){var $file_id$jscomp$55$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$399_proxy$jscomp$4$$,"$file");$id$jscomp$399_proxy$jscomp$4$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$399_proxy$jscomp$4$$,
"$id");return $file_id$jscomp$55$$!=null&&$id$jscomp$399_proxy$jscomp$4$$!=null?$app$plugins$utils$locate_page$$($file_id$jscomp$55$$,$id$jscomp$399_proxy$jscomp$4$$):null},$app$plugins$utils$locate_shape$$=function($file_id$jscomp$47$$,$page_id$jscomp$76$$,$id$jscomp$393$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_page$$($file_id$jscomp$47$$,$page_id$jscomp$76$$),$APP.$cljs$cst$1631$objects$$),$id$jscomp$393$$)},
$app$plugins$utils$proxy__GT_interaction$$=function($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$){var $index$jscomp$inline_9764$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$,"$index");$proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$,
"$page"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$,"$shape"));return $APP.$cljs$core$truth_$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$)?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9765$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2051$interactions$$,$index$jscomp$inline_9764$$],
null)):null},$app$plugins$utils$proxy__GT_shape$$=function($id$jscomp$400_proxy$jscomp$5$$){var $file_id$jscomp$56$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$400_proxy$jscomp$5$$,"$file"),$page_id$jscomp$77$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$400_proxy$jscomp$5$$,"$page");$id$jscomp$400_proxy$jscomp$5$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$400_proxy$jscomp$5$$,"$id");return $file_id$jscomp$56$$!=
null&&$page_id$jscomp$77$$!=null&&$id$jscomp$400_proxy$jscomp$5$$!=null?$app$plugins$utils$locate_shape$$($file_id$jscomp$56$$,$page_id$jscomp$77$$,$id$jscomp$400_proxy$jscomp$5$$):null},$app$plugins$utils$is_main_component_proxy_QMARK_$$=function($p$jscomp$242_temp__5825__auto__$jscomp$191$$){$p$jscomp$242_temp__5825__auto__$jscomp$191$$=$app$plugins$utils$proxy__GT_shape$$($p$jscomp$242_temp__5825__auto__$jscomp$191$$);return $APP.$cljs$core$truth_$$($p$jscomp$242_temp__5825__auto__$jscomp$191$$)?
$APP.$app$common$types$component$main_instance_QMARK_$$($p$jscomp$242_temp__5825__auto__$jscomp$191$$):null},$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_id$jscomp$46$$,$page_id$jscomp$75$$){return $APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_page$$($file_id$jscomp$46$$,$page_id$jscomp$75$$))},$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return $app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))},$app$plugins$utils$locate_file$$=function($id$jscomp$391$$){return $APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$id$jscomp$391$$)},$app$plugins$utils$proxy__GT_file$$=function($id$jscomp$398_proxy$jscomp$3$$){$id$jscomp$398_proxy$jscomp$3$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$398_proxy$jscomp$3$$,
"$id");return $id$jscomp$398_proxy$jscomp$3$$!=null?$app$plugins$utils$locate_file$$($id$jscomp$398_proxy$jscomp$3$$):null},$app$plugins$utils$locate_tokens_lib$$=function($file$jscomp$43_file_id$jscomp$51$$){$file$jscomp$43_file_id$jscomp$51$$=$app$plugins$utils$locate_file$$($file$jscomp$43_file_id$jscomp$51$$);return $APP.$cljs$cst$2139$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$43_file_id$jscomp$51$$))},$app$plugins$utils$locate_token$$=
function($file_id$jscomp$54_tokens_lib$jscomp$9$$,$set_id$jscomp$22$$,$token_id$jscomp$16$$){$file_id$jscomp$54_tokens_lib$jscomp$9$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$54_tokens_lib$jscomp$9$$);return $file_id$jscomp$54_tokens_lib$jscomp$9$$!=null?$APP.$app$common$types$tokens_lib$get_token$$($file_id$jscomp$54_tokens_lib$jscomp$9$$,$set_id$jscomp$22$$,$token_id$jscomp$16$$):null},$app$plugins$utils$locate_token_set$$=function($file_id$jscomp$53_tokens_lib$jscomp$8$$,$set_id$jscomp$21$$){$file_id$jscomp$53_tokens_lib$jscomp$8$$=
$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$53_tokens_lib$jscomp$8$$);return $file_id$jscomp$53_tokens_lib$jscomp$8$$!=null?$APP.$app$common$types$tokens_lib$get_set$$($file_id$jscomp$53_tokens_lib$jscomp$8$$,$set_id$jscomp$21$$):null},$app$plugins$utils$locate_token_theme$$=function($file_id$jscomp$52_tokens_lib$jscomp$7$$,$id$jscomp$397$$){$file_id$jscomp$52_tokens_lib$jscomp$7$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$52_tokens_lib$jscomp$7$$);return $file_id$jscomp$52_tokens_lib$jscomp$7$$!=
null?$APP.$app$common$types$tokens_lib$get_theme$$($file_id$jscomp$52_tokens_lib$jscomp$7$$,$id$jscomp$397$$):null},$app$plugins$utils$locate_library_component$$=function($file_id$jscomp$50$$,$id$jscomp$396$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_file$$($file_id$jscomp$50$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1638$components$$),$id$jscomp$396$$)},
$app$plugins$utils$proxy__GT_library_component$$=function($id$jscomp$403_proxy$jscomp$8$$){var $file_id$jscomp$59$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$403_proxy$jscomp$8$$,"$file");$id$jscomp$403_proxy$jscomp$8$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$403_proxy$jscomp$8$$,"$id");return $file_id$jscomp$59$$!=null&&$id$jscomp$403_proxy$jscomp$8$$!=null?$app$plugins$utils$locate_library_component$$($file_id$jscomp$59$$,$id$jscomp$403_proxy$jscomp$8$$):
null},$app$plugins$utils$locate_library_typography$$=function($file_id$jscomp$49$$,$id$jscomp$395$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_file$$($file_id$jscomp$49$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2215$typographies$$),$id$jscomp$395$$)},$app$plugins$utils$proxy__GT_library_typography$$=function($id$jscomp$402_proxy$jscomp$7$$){var $file_id$jscomp$58$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$402_proxy$jscomp$7$$,"$file");$id$jscomp$402_proxy$jscomp$7$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$402_proxy$jscomp$7$$,"$id");return $file_id$jscomp$58$$!=null&&$id$jscomp$402_proxy$jscomp$7$$!=null?$app$plugins$utils$locate_library_typography$$($file_id$jscomp$58$$,$id$jscomp$402_proxy$jscomp$7$$):null},$app$plugins$utils$locate_library_color$$=function($file_id$jscomp$48$$,$id$jscomp$394$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_file$$($file_id$jscomp$48$$),
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2212$colors$$),$id$jscomp$394$$)},$app$plugins$utils$proxy__GT_library_color$$=function($id$jscomp$401_proxy$jscomp$6$$){var $file_id$jscomp$57$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$401_proxy$jscomp$6$$,"$file");$id$jscomp$401_proxy$jscomp$6$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$401_proxy$jscomp$6$$,"$id");return $file_id$jscomp$57$$!=null&&$id$jscomp$401_proxy$jscomp$6$$!=null?$app$plugins$utils$locate_library_color$$($file_id$jscomp$57$$,
$id$jscomp$401_proxy$jscomp$6$$):null},$app$main$data$event$process_performance_event$$=function($result$jscomp$217$$){var $event$jscomp$66$$=$result$jscomp$217$$[0],$profile_id$jscomp$6$$=$result$jscomp$217$$[1];return($event$jscomp$66$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$event$jscomp$66$$.$app$main$data$event$PerformanceEvent$$||($event$jscomp$66$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$PerformanceEvent$$,$event$jscomp$66$$)):
$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$PerformanceEvent$$,$event$jscomp$66$$))?$APP.$beicon$v2$core$create$$(function($subs$jscomp$11$$){var $start$jscomp$210$$=performance.now();(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return scheduler.postTask(function(){var $time$jscomp$3$$=performance.now()-$start$jscomp$210$$;$time$jscomp$3$$>1E3&&$subs$jscomp$11$$.next($app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$6$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"blocking-event",$APP.$cljs$cst$2317$event_name$$,$APP.$app$common$data$name$$($APP.$potok$v2$core$type$$($event$jscomp$66$$)),$APP.$cljs$cst$1960$duration$$,$time$jscomp$3$$],null)));return $subs$jscomp$11$$.complete()},{priority:"user-blocking"})});return null}):$APP.$beicon$v2$core$empty$$()},$app$main$data$workspace$versions$wait_persisted_status$$=function(){return $APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__73418_SHARP_$$){return $p1__73418_SHARP_$$==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3151$saved$$,$p1__73418_SHARP_$$)},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$persistence_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null))))},$app$main$data$workspace$versions$create_version_from_plugins$$=function($file_id$jscomp$333$$,$label$jscomp$25$$,$resolve$jscomp$35$$,$reject$jscomp$24$$){typeof $app$main$data$workspace$versions$create_version_from_plugins_73422$$===
"undefined"&&($app$main$data$workspace$versions$create_version_from_plugins_73422$$=function($file_id$jscomp$334$$,$label$jscomp$26$$,$resolve$jscomp$36$$,$reject$jscomp$25$$,$meta73423$$){this.$file_id$=$file_id$jscomp$334$$;this.label=$label$jscomp$26$$;this.resolve=$resolve$jscomp$36$$;this.reject=$reject$jscomp$25$$;this.$meta73423$=$meta73423$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$create_version_from_plugins_73422$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_from_plugins_73422$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5051$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_create_version_from_plugins$$},$app$main$data$workspace$versions$create_version_from_plugins_73422$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73424$$,$meta73423__$1$$){return new $app$main$data$workspace$versions$create_version_from_plugins_73422$$(this.$file_id$,
this.label,this.resolve,this.reject,$meta73423__$1$$)},$app$main$data$workspace$versions$create_version_from_plugins_73422$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73423$},$app$main$data$workspace$versions$create_version_from_plugins_73422$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_from_plugins_73422$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2798_current_file_id$jscomp$11$$,
$state$jscomp$1080$$){var $self__$jscomp$7050$$=this;$_$jscomp$2798_current_file_id$jscomp$11$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1080$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$81$$){$self__$jscomp$7050$$.reject.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$7050$$.reject.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$81$$):$self__$jscomp$7050$$.reject($error$jscomp$81$$);return $APP.$beicon$v2$core$empty$$()},
$APP.$beicon$v2$core$concat$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$7050$$.$file_id$,$_$jscomp$2798_current_file_id$jscomp$11$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$):null,$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7050$$.resolve,$APP.$beicon$v2$core$mapcat$$(function($map__73427__$1_p__73426$$){$map__73427__$1_p__73426$$=$APP.$cljs$core$__destructure_map$$($map__73427__$1_p__73426$$);
var $id$jscomp$864$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73427__$1_p__73426$$,$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$map$$(function($versions$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73421_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$864$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73421_SHARP_$$))},$versions$$)},$APP.$beicon$v2$core$take$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5025$get_file_snapshots$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$7050$$.$file_id$],null))))},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5028$create_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$7050$$.$file_id$,$APP.$cljs$cst$2287$label$$,$self__$jscomp$7050$$.label],null))},$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$7050$$.$file_id$,
$_$jscomp$2798_current_file_id$jscomp$11$$)?$app$main$data$workspace$versions$wait_persisted_status$$():(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$5052$nothing$$)))))))});return new $app$main$data$workspace$versions$create_version_from_plugins_73422$$($file_id$jscomp$333$$,$label$jscomp$25$$,$resolve$jscomp$35$$,$reject$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$plugins$flags$flags_proxy$$=function($plugin_id$jscomp$8$$){var $obj_55485$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_55485$$,
Symbol.toStringTag,{enumerable:!1,get:function(){return"FlagProxy"}});Object.defineProperty($obj_55485$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FlagProxy"}});Object.defineProperty($obj_55485$$,"naturalChildOrdering",{enumerable:!0,get:function(){return $app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$8$$)},set:function($val_naturalchildordering_55514$$){return $APP.$cljs$core$boolean_QMARK_$$($val_naturalchildordering_55514$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$flags$set_flag$$($plugin_id$jscomp$8$$,
$APP.$cljs$cst$3390$natural_child_ordering$$,$val_naturalchildordering_55514$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3394$naturalChildOrdering$$,$val_naturalchildordering_55514$$)}});Object.defineProperty($obj_55485$$,"throwValidationErrors",{enumerable:!0,get:function(){return $app$plugins$utils$throw_validation_errors_QMARK_$$($plugin_id$jscomp$8$$)},set:function($val_throwvalidationerrors_55523$$){return $APP.$cljs$core$boolean_QMARK_$$($val_throwvalidationerrors_55523$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$flags$set_flag$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3391$throw_validation_errors$$,$val_throwvalidationerrors_55523$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3395$throwValidationErrors$$,$val_throwvalidationerrors_55523$$)}});return $obj_55485$$},$app$util$worker$Worker$$=function($instance$jscomp$6$$,$stream$jscomp$26$$,$__meta$jscomp$34$$,$__extmap$jscomp$34$$,$__hash$jscomp$93$$){this.instance=
$instance$jscomp$6$$;this.stream=$stream$jscomp$26$$;this.$__meta$=$__meta$jscomp$34$$;this.$__extmap$=$__extmap$jscomp$34$$;this.$__hash$=$__hash$jscomp$93$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$core$PartialMatch$$=function($template$jscomp$5$$,$data$jscomp$178$$,$result$jscomp$220$$,$path_params$jscomp$8$$,$required$jscomp$4$$,$__meta$jscomp$32$$,$__extmap$jscomp$32$$,$__hash$jscomp$91$$){this.template=$template$jscomp$5$$;
this.data=$data$jscomp$178$$;this.result=$result$jscomp$220$$;this.$path_params$=$path_params$jscomp$8$$;this.required=$required$jscomp$4$$;this.$__meta$=$__meta$jscomp$32$$;this.$__extmap$=$__extmap$jscomp$32$$;this.$__hash$=$__hash$jscomp$91$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$core$Match$$=function($template$jscomp$3$$,$data$jscomp$176$$,$result$jscomp$218$$,$path_params$jscomp$6$$,$path$jscomp$213$$,$__meta$jscomp$31$$,
$__extmap$jscomp$31$$,$__hash$jscomp$90$$){this.template=$template$jscomp$3$$;this.data=$data$jscomp$176$$;this.result=$result$jscomp$218$$;this.$path_params$=$path_params$jscomp$6$$;this.path=$path$jscomp$213$$;this.$__meta$=$__meta$jscomp$31$$;this.$__extmap$=$__extmap$jscomp$31$$;this.$__hash$=$__hash$jscomp$90$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$core$__GT_Match$$=function($template$jscomp$4$$,$data$jscomp$177$$,$result$jscomp$219$$,
$path_params$jscomp$7$$,$path$jscomp$214$$){return new $reitit$core$Match$$($template$jscomp$4$$,$data$jscomp$177$$,$result$jscomp$219$$,$path_params$jscomp$7$$,$path$jscomp$214$$,null,null,null)},$reitit$trie$Node$$=function($children$jscomp$170$$,$wilds$$,$catch_all$$,$params$jscomp$118$$,$data$jscomp$159$$,$__meta$jscomp$30$$,$__extmap$jscomp$30$$,$__hash$jscomp$89$$){this.children=$children$jscomp$170$$;this.$wilds$=$wilds$$;this.$catch_all$=$catch_all$$;this.params=$params$jscomp$118$$;this.data=
$data$jscomp$159$$;this.$__meta$=$__meta$jscomp$30$$;this.$__extmap$=$__extmap$jscomp$30$$;this.$__hash$=$__hash$jscomp$89$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$trie$_node$$=function($G__50056$jscomp$inline_13868_m$jscomp$205$$){$G__50056$jscomp$inline_13868_m$jscomp$205$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$342$children$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2371$wilds$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2372$catch_all$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$G__50056$jscomp$inline_13868_m$jscomp$205$$]));var $G__50073$jscomp$inline_13870_extmap__5365__auto__$jscomp$inline_13869$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50056$jscomp$inline_13868_m$jscomp$205$$,
$APP.$cljs$cst$342$children$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2371$wilds$$,$APP.$cljs$cst$2372$catch_all$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$142$data$$]));$G__50073$jscomp$inline_13870_extmap__5365__auto__$jscomp$inline_13869$$=$APP.$cljs$core$record_QMARK_$$($G__50056$jscomp$inline_13868_m$jscomp$205$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__50073$jscomp$inline_13870_extmap__5365__auto__$jscomp$inline_13869$$):
$G__50073$jscomp$inline_13870_extmap__5365__auto__$jscomp$inline_13869$$;return new $reitit$trie$Node$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($G__50056$jscomp$inline_13868_m$jscomp$205$$),$APP.$cljs$cst$2371$wilds$$.$cljs$core$IFn$_invoke$arity$1$($G__50056$jscomp$inline_13868_m$jscomp$205$$),$APP.$cljs$cst$2372$catch_all$$.$cljs$core$IFn$_invoke$arity$1$($G__50056$jscomp$inline_13868_m$jscomp$205$$),$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($G__50056$jscomp$inline_13868_m$jscomp$205$$),
$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($G__50056$jscomp$inline_13868_m$jscomp$205$$),null,$APP.$cljs$core$not_empty$$($G__50073$jscomp$inline_13870_extmap__5365__auto__$jscomp$inline_13869$$),null)},$reitit$trie$Match$$=function($params$jscomp$116$$,$data$jscomp$157$$,$__meta$jscomp$29$$,$__extmap$jscomp$29$$,$__hash$jscomp$88$$){this.params=$params$jscomp$116$$;this.data=$data$jscomp$157$$;this.$__meta$=$__meta$jscomp$29$$;this.$__extmap$=$__extmap$jscomp$29$$;this.$__hash$=$__hash$jscomp$88$$;
this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$trie$t_reitit$0trie50197$$=function($meta50198$jscomp$10$$){this.$meta50198$=$meta50198$jscomp$10$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$CatchAll$$=function($value$jscomp$452$$,$__meta$jscomp$28$$,$__extmap$jscomp$28$$,$__hash$jscomp$87$$){this.value=$value$jscomp$452$$;this.$__meta$=$__meta$jscomp$28$$;this.$__extmap$=
$__extmap$jscomp$28$$;this.$__hash$=$__hash$jscomp$87$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$trie$Wild$$=function($value$jscomp$450$$,$__meta$jscomp$27$$,$__extmap$jscomp$27$$,$__hash$jscomp$86$$){this.value=$value$jscomp$450$$;this.$__meta$=$__meta$jscomp$27$$;this.$__extmap$=$__extmap$jscomp$27$$;this.$__hash$=$__hash$jscomp$86$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264},$reitit$trie$join_path$$=function($xs$jscomp$31$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($s$jscomp$532$$,$x$jscomp$1136$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$532$$),typeof $x$jscomp$1136$$==="string"?$x$jscomp$1136$$:$x$jscomp$1136$$ instanceof $reitit$trie$Wild$$?["{",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1136$$.value),1),"}"].join(""):
$x$jscomp$1136$$ instanceof $reitit$trie$CatchAll$$?["{*",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1136$$.value),1),"}"].join(""):null].join("")},"",$xs$jscomp$31$$)},$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$=function($map__50327__$1_matchers$jscomp$5_p__50326$$,$compiler$jscomp$1$$,$cp$jscomp$12$$){function $ends$$($children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$){$children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$=
$APP.$cljs$core$__destructure_map$$($children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$);$children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$,$APP.$cljs$cst$342$children$$);$children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$=$APP.$cljs$core$keys$$($children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$);
return $APP.$cljs$core$truth_$$($children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$)?$children__$1$jscomp$22_map__50335__$1_or__5025__auto__$jscomp$429_p__50334$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/"],null)}$map__50327__$1_matchers$jscomp$5_p__50326$$=$APP.$cljs$core$__destructure_map$$($map__50327__$1_matchers$jscomp$5_p__50326$$);var $data$jscomp$174$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50327__$1_matchers$jscomp$5_p__50326$$,
$APP.$cljs$cst$142$data$$),$params$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50327__$1_matchers$jscomp$5_p__50326$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$children$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50327__$1_matchers$jscomp$5_p__50326$$,$APP.$cljs$cst$342$children$$),$wilds$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50327__$1_matchers$jscomp$5_p__50326$$,$APP.$cljs$cst$2371$wilds$$),
$catch_all$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50327__$1_matchers$jscomp$5_p__50326$$,$APP.$cljs$cst$2372$catch_all$$);$map__50327__$1_matchers$jscomp$5_p__50326$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__50336$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return $APP.$cljs$core$truth_$$($data$jscomp$174$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__50336$$,
$reitit$trie$data_matcher$$($compiler$jscomp$1$$,$params$jscomp$133$$,$data$jscomp$174$$)):$G__50336$$}(),function(){return function $reitit$trie$iter__50337$$($s__50338$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__50338__$2_temp__5825__auto__$jscomp$140$$=$APP.$cljs$core$seq$$($s__50338$$);if($s__50338__$2_temp__5825__auto__$jscomp$140$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__50338__$2_temp__5825__auto__$jscomp$140$$)){var $JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$=
$APP.$cljs$core$_chunked_first$$($s__50338__$2_temp__5825__auto__$jscomp$140$$),$size__5502__auto__$jscomp$19$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$),$b__50340_p$jscomp$214$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$19$$);a:{for(var $i__50339$jscomp$inline_9776$$=0;;)if($i__50339$jscomp$inline_9776$$<$size__5502__auto__$jscomp$19$$){var $b$jscomp$inline_13872_vec__50341$jscomp$inline_9777$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$,
$i__50339$jscomp$inline_9776$$),$p$jscomp$inline_9778_x$jscomp$inline_13873$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13872_vec__50341$jscomp$inline_9777$$,0,null),$c$jscomp$inline_9779$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13872_vec__50341$jscomp$inline_9777$$,1,null);$b$jscomp$inline_13872_vec__50341$jscomp$inline_9777$$=$b__50340_p$jscomp$214$$;$p$jscomp$inline_9778_x$jscomp$inline_13873$$=$reitit$trie$static_matcher$$($compiler$jscomp$1$$,
$p$jscomp$inline_9778_x$jscomp$inline_13873$$,$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$inline_9779$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$p$jscomp$inline_9778_x$jscomp$inline_13873$$)));$b$jscomp$inline_13872_vec__50341$jscomp$inline_9777$$.add($p$jscomp$inline_9778_x$jscomp$inline_13873$$);$i__50339$jscomp$inline_9776$$+=1}else{$JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$=
!0;break a}$JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$=void 0}return $JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50340_p$jscomp$214$$),$reitit$trie$iter__50337$$($APP.$cljs$core$_chunked_rest$$($s__50338__$2_temp__5825__auto__$jscomp$140$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50340_p$jscomp$214$$),null)}$JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$=
$APP.$cljs$core$first$$($s__50338__$2_temp__5825__auto__$jscomp$140$$);$b__50340_p$jscomp$214$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$,0,null);$JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$,1,null);return $APP.$cljs$core$cons$$($reitit$trie$static_matcher$$($compiler$jscomp$1$$,
$b__50340_p$jscomp$214$$,$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2072_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50345$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$b__50340_p$jscomp$214$$))),$reitit$trie$iter__50337$$($APP.$cljs$core$rest$$($s__50338__$2_temp__5825__auto__$jscomp$140$$)))}return null}},null,null)}($children$jscomp$173$$)}()),function(){return function $reitit$trie$iter__50348$$($s__50349$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__50349__$2_temp__5825__auto__$jscomp$141$$=$APP.$cljs$core$seq$$($s__50349$$);if($s__50349__$2_temp__5825__auto__$jscomp$141$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__50349__$2_temp__5825__auto__$jscomp$141$$)){var $c__5501__auto__$jscomp$20$$=$APP.$cljs$core$_chunked_first$$($s__50349__$2_temp__5825__auto__$jscomp$141$$),$size__5502__auto__$jscomp$20$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$20$$),$b__50351$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$20$$);
return function(){for(var $i__50350$$=0;;)if($i__50350$$<$size__5502__auto__$jscomp$20$$){var $JSCompiler_temp_const$jscomp$2073_vec__50352$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$20$$,$i__50350$$),$JSCompiler_inline_result$jscomp$2074_p$jscomp$217$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2073_vec__50352$$,0,null),$c$jscomp$285$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2073_vec__50352$$,1,null);
$JSCompiler_temp_const$jscomp$2073_vec__50352$$=$b__50351$$;var $pv$jscomp$inline_9781$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2074_p$jscomp$217$$),$ends__$1$jscomp$inline_9782$$=$ends$$($c$jscomp$285$$);$JSCompiler_inline_result$jscomp$2074_p$jscomp$217$$=$APP.$cljs$core$next$$($ends__$1$jscomp$inline_9782$$)?$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2392$reitit_DOT_trie_SLASH_multiple_terminators$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2393$terminators$$,$ends__$1$jscomp$inline_9782$$,$APP.$cljs$cst$296$path$$,$reitit$trie$join_path$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$JSCompiler_inline_result$jscomp$2074_p$jscomp$217$$))],null)):$reitit$trie$wild_matcher$$($compiler$jscomp$1$$,$pv$jscomp$inline_9781$$,$APP.$cljs$core$ffirst$$($ends__$1$jscomp$inline_9782$$),$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$285$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,
$pv$jscomp$inline_9781$$)));$JSCompiler_temp_const$jscomp$2073_vec__50352$$.add($JSCompiler_inline_result$jscomp$2074_p$jscomp$217$$);$i__50350$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50351$$),$reitit$trie$iter__50348$$($APP.$cljs$core$_chunked_rest$$($s__50349__$2_temp__5825__auto__$jscomp$141$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50351$$),null)}var $vec__50355$$=$APP.$cljs$core$first$$($s__50349__$2_temp__5825__auto__$jscomp$141$$),
$p$jscomp$216$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__50355$$,0,null),$c$jscomp$284$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__50355$$,1,null);return $APP.$cljs$core$cons$$(function(){var $pv$jscomp$12$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$216$$),$ends__$1$jscomp$1$$=$ends$$($c$jscomp$284$$);return $APP.$cljs$core$next$$($ends__$1$jscomp$1$$)?$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2392$reitit_DOT_trie_SLASH_multiple_terminators$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2393$terminators$$,$ends__$1$jscomp$1$$,$APP.$cljs$cst$296$path$$,$reitit$trie$join_path$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$p$jscomp$216$$))],null)):$reitit$trie$wild_matcher$$($compiler$jscomp$1$$,$pv$jscomp$12$$,$APP.$cljs$core$ffirst$$($ends__$1$jscomp$1$$),$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$284$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,
$pv$jscomp$12$$)))}(),$reitit$trie$iter__50348$$($APP.$cljs$core$rest$$($s__50349__$2_temp__5825__auto__$jscomp$141$$)))}return null}},null,null)}($wilds$jscomp$2$$)}()),function(){return function $reitit$trie$iter__50359$$($s__50360$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__50360__$2_temp__5825__auto__$jscomp$142$$=$APP.$cljs$core$seq$$($s__50360$$);if($s__50360__$2_temp__5825__auto__$jscomp$142$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__50360__$2_temp__5825__auto__$jscomp$142$$)){var $JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$=
$APP.$cljs$core$_chunked_first$$($s__50360__$2_temp__5825__auto__$jscomp$142$$),$size__5502__auto__$jscomp$21$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$),$b__50362_p$jscomp$218$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$21$$);a:{for(var $i__50361$jscomp$inline_9784$$=0;;)if($i__50361$jscomp$inline_9784$$<$size__5502__auto__$jscomp$21$$){var $b$jscomp$inline_13878_vec__50364$jscomp$inline_9785$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$,
$i__50361$jscomp$inline_9784$$),$p$jscomp$inline_9786_x$jscomp$inline_13879$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13878_vec__50364$jscomp$inline_9785$$,0,null),$c$jscomp$inline_9787$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13878_vec__50364$jscomp$inline_9785$$,1,null);$b$jscomp$inline_13878_vec__50364$jscomp$inline_9785$$=$b__50362_p$jscomp$218$$;$p$jscomp$inline_9786_x$jscomp$inline_13879$$=$reitit$trie$catch_all_matcher$$($compiler$jscomp$1$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_9786_x$jscomp$inline_13879$$),$params$jscomp$133$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$inline_9787$$));$b$jscomp$inline_13878_vec__50364$jscomp$inline_9785$$.add($p$jscomp$inline_9786_x$jscomp$inline_13879$$);$i__50361$jscomp$inline_9784$$+=1}else{$JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$=!0;break a}$JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$=
void 0}return $JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50362_p$jscomp$218$$),$reitit$trie$iter__50359$$($APP.$cljs$core$_chunked_rest$$($s__50360__$2_temp__5825__auto__$jscomp$142$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50362_p$jscomp$218$$),null)}$JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$=$APP.$cljs$core$first$$($s__50360__$2_temp__5825__auto__$jscomp$142$$);
$b__50362_p$jscomp$218$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$,0,null);$JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$,1,null);return $APP.$cljs$core$cons$$($reitit$trie$catch_all_matcher$$($compiler$jscomp$1$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($b__50362_p$jscomp$218$$),$params$jscomp$133$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2075_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50368$$)),$reitit$trie$iter__50359$$($APP.$cljs$core$rest$$($s__50360__$2_temp__5825__auto__$jscomp$142$$)))}return null}},null,null)}($catch_all$jscomp$2$$)}());return $APP.$cljs$core$count$$($map__50327__$1_matchers$jscomp$5_p__50326$$)>1?$reitit$trie$linear_matcher$$($compiler$jscomp$1$$,
$map__50327__$1_matchers$jscomp$5_p__50326$$,!1):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($map__50327__$1_matchers$jscomp$5_p__50326$$),1)?$APP.$cljs$core$first$$($map__50327__$1_matchers$jscomp$5_p__50326$$):null},$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$01$$=function($options$jscomp$450$$){return $reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($options$jscomp$450$$,new $reitit$trie$t_reitit$0trie50197$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$APP.$cljs$core$PersistentVector$EMPTY$$)},$reitit$trie$conflicting_parts_QMARK_$$=function($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$,$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$){for(;;){var $G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$=$reitit$trie$_slice_start$$($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$,$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$);$G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$,
0,null);$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$=$APP.$cljs$core$seq$$($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$);$G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$=$APP.$cljs$core$first$$($G__50533_parts2_seq__50147_seq__50147__$1_ss1$$);$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$=$APP.$cljs$core$next$$($G__50533_parts2_seq__50147_seq__50147__$1_ss1$$);$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$,
1,null);var $seq__50150_seq__50150__$1_ss2$$=$APP.$cljs$core$seq$$($G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$);$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$=$APP.$cljs$core$first$$($seq__50150_seq__50150__$1_ss2$$);$seq__50150_seq__50150__$1_ss2$$=$APP.$cljs$core$next$$($seq__50150_seq__50150__$1_ss2$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$,$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null])))return!0;if($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$==null||$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$==null)return!1;if($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$ instanceof $reitit$trie$CatchAll$$||$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$ instanceof $reitit$trie$CatchAll$$)return!0;if($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$ instanceof $reitit$trie$Wild$$||
$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$ instanceof $reitit$trie$Wild$$)$G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$=$reitit$trie$_slice_end$$($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$,$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$),$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$=$reitit$trie$_slice_end$$($G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$,$seq__50150_seq__50150__$1_ss2$$);else{if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$,
$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$))return!1;$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$=$seq__50150_seq__50150__$1_ss2$$;$G__50532_first__50148_parts1_s1$jscomp$18_vec__50146$$=$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$;$G__50533_parts2_seq__50147_seq__50147__$1_ss1$$=$G__50536_first__50151_s2$jscomp$15_vec__50143_vec__50149$$}}},$app$main$data$workspace$zoom$fit_to_shapes$$=function($ids$jscomp$64$$){typeof $app$main$data$workspace$zoom$fit_to_shapes_66279$$===
"undefined"&&($app$main$data$workspace$zoom$fit_to_shapes_66279$$=function($ids$jscomp$65$$,$meta66280$$){this.ids=$ids$jscomp$65$$;this.$meta66280$=$meta66280$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3585$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_fit_to_shapes$$},
$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66281$$,$meta66280__$1$$){return new $app$main$data$workspace$zoom$fit_to_shapes_66279$$(this.ids,$meta66280__$1$$)},$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66280$},$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1912_page_id$jscomp$106$$,$state$jscomp$351$$){if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$351$$)||$APP.$cljs$core$empty_QMARK_$$(this.ids))return $state$jscomp$351$$;$_$jscomp$1912_page_id$jscomp$106$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$351$$);var $objects$jscomp$309$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$351$$,$_$jscomp$1912_page_id$jscomp$106$$),
$srect$jscomp$5$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66278_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$309$$,$p1__66278_SHARP_$$)},this.ids));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$351$$,$APP.$cljs$cst$1920$workspace_local$$,function($map__66290__$1_p__66289$$){$map__66290__$1_p__66289$$=$APP.$cljs$core$__destructure_map$$($map__66290__$1_p__66289$$);
var $vport$jscomp$2_zoom$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66290__$1_p__66289$$,$APP.$cljs$cst$2203$vport$$),$srect__$1$jscomp$2$$=$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$($vport$jscomp$2_zoom$jscomp$8$$,$srect$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$256$padding$$,40,$APP.$cljs$cst$3421$min_zoom$$,.01],null));$vport$jscomp$2_zoom$jscomp$8$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$2_zoom$jscomp$8$$)/
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect__$1$jscomp$2$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66290__$1_p__66289$$,$APP.$cljs$cst$2196$zoom$$,$vport$jscomp$2_zoom$jscomp$8$$),$APP.$cljs$cst$3577$zoom_inverse$$,1/$vport$jscomp$2_zoom$jscomp$8$$),$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$merge$$,$srect__$1$jscomp$2$$)})},$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$fit_to_shapes_66279$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1913$$,$state$jscomp$352$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$352$$)});return new $app$main$data$workspace$zoom$fit_to_shapes_66279$$($ids$jscomp$64$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$features$toggle_feature$$=function(){typeof $app$main$features$toggle_feature_54804$$===
"undefined"&&($app$main$features$toggle_feature_54804$$=function($feature$jscomp$10$$,$meta54805$$){this.$feature$=$feature$jscomp$10$$;this.$meta54805$=$meta54805$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$features$toggle_feature_54804$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$toggle_feature_54804$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3106$app_DOT_main_DOT_features_SLASH_toggle_feature$$},
$app$main$features$toggle_feature_54804$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54806$$,$meta54805__$1$$){return new $app$main$features$toggle_feature_54804$$(this.$feature$,$meta54805__$1$$)},$app$main$features$toggle_feature_54804$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54805$},$app$main$features$toggle_feature_54804$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$toggle_feature_54804$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1637$$,$state$jscomp$171$$){var $self__$jscomp$3450$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$171$$,$APP.$cljs$cst$3082$features_runtime$$,function($features__$1$jscomp$5$$){if($APP.$cljs$core$contains_QMARK_$$($features__$1$jscomp$5$$,$self__$jscomp$3450$$.$feature$))return $APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"feature disabled"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2563$feature$$,$self__$jscomp$3450$$.$feature$],null)],null)}),null,"app.main.features",$APP.$cljs$cst$144$trace$$,!1),$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$5$$,
$self__$jscomp$3450$$.$feature$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"feature enabled"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2563$feature$$,$self__$jscomp$3450$$.$feature$],null)],null)}),null,"app.main.features",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$5$$,$self__$jscomp$3450$$.$feature$)}),$APP.$cljs$cst$3082$features_runtime$$,$APP.$clojure$set$intersection$$,$APP.$app$common$features$no_migration_features$$)});return new $app$main$features$toggle_feature_54804$$("layout/grid",$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$features$enable_feature$$=
function(){typeof $app$main$features$enable_feature_54819$$==="undefined"&&($app$main$features$enable_feature_54819$$=function($feature$jscomp$12$$,$meta54820$$){this.$feature$=$feature$jscomp$12$$;this.$meta54820$=$meta54820$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$features$enable_feature_54819$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$enable_feature_54819$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3107$app_DOT_main_DOT_features_SLASH_enable_feature$$},$app$main$features$enable_feature_54819$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54821$$,$meta54820__$1$$){return new $app$main$features$enable_feature_54819$$(this.$feature$,$meta54820__$1$$)},$app$main$features$enable_feature_54819$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54820$},$app$main$features$enable_feature_54819$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$enable_feature_54819$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1638$$,$state$jscomp$172$$){var $self__$jscomp$3454$$=this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$172$$,$self__$jscomp$3454$$.$feature$))return $state$jscomp$172$$;$APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"feature enabled"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2563$feature$$,$self__$jscomp$3454$$.$feature$],null)],null)}),null,"app.main.features",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$172$$,
$APP.$cljs$cst$3082$features_runtime$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$self__$jscomp$3454$$.$feature$),$APP.$cljs$cst$3082$features_runtime$$,$APP.$clojure$set$intersection$$,$APP.$app$common$features$no_migration_features$$)});return new $app$main$features$enable_feature_54819$$("plugins/runtime",$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$team$create_team_with_invitations$$=function($p__55567$$){var $map__55568__$1$$=
$APP.$cljs$core$__destructure_map$$($p__55567$$),$name$jscomp$273$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55568__$1$$,$APP.$cljs$cst$725$name$$),$emails$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55568__$1$$,$APP.$cljs$cst$3290$emails$$),$role$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55568__$1$$,$APP.$cljs$cst$2490$role$$);typeof $app$main$data$team$create_team_with_invitations_55569$$==="undefined"&&($app$main$data$team$create_team_with_invitations_55569$$=
function($p__55567$jscomp$1$$,$map__55568$jscomp$1$$,$params$jscomp$200$$,$name$jscomp$274$$,$emails$jscomp$1$$,$role$jscomp$6$$,$meta55570$$){this.$p__55567$=$p__55567$jscomp$1$$;this.$map__55568$=$map__55568$jscomp$1$$;this.params=$params$jscomp$200$$;this.name=$name$jscomp$274$$;this.$emails$=$emails$jscomp$1$$;this.role=$role$jscomp$6$$;this.$meta55570$=$meta55570$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$create_team_with_invitations_55569$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_team_with_invitations_55569$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3291$app_DOT_main_DOT_data_DOT_team_SLASH_create_team_with_invitations$$},$app$main$data$team$create_team_with_invitations_55569$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55571$$,$meta55570__$1$$){return new $app$main$data$team$create_team_with_invitations_55569$$(this.$p__55567$,this.$map__55568$,this.params,
this.name,this.$emails$,this.role,$meta55570__$1$$)},$app$main$data$team$create_team_with_invitations_55569$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55570$},$app$main$data$team$create_team_with_invitations_55569$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_team_with_invitations_55569$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55572_on_success$jscomp$12$$=$APP.$cljs$core$meta$$(this.params),
$map__55572__$1_on_error$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($map__55572_on_success$jscomp$12$$);$map__55572_on_success$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55572__$1_on_error$jscomp$16$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__55572__$1_on_error$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55572__$1_on_error$jscomp$16$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55572__$1_on_error$jscomp$16$$,
$APP.$beicon$v2$core$map$$($APP.$app$main$data$team$team_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55572_on_success$jscomp$12$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3292$create_team_with_invitations$$,$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,this.name,$APP.$cljs$cst$3290$emails$$,this.$emails$,$APP.$cljs$cst$2490$role$$,this.role,$APP.$cljs$cst$227$features$$,
$APP.$app$main$features$global_enabled_features$$],null),$APP.$cljs$core$meta$$(this))))))});return new $app$main$data$team$create_team_with_invitations_55569$$($p__55567$$,$map__55568__$1$$,$map__55568__$1$$,$name$jscomp$273$$,$emails$$,$role$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$reitit$impl$meta_merge$$=function($G__51544_left$jscomp$24$$,$G__51545_right$jscomp$20$$,$map__51542__$1_p__51541_update$$){$map__51542__$1_p__51541_update$$=$APP.$cljs$core$__destructure_map$$($map__51542__$1_p__51541_update$$);
var $merge$jscomp$1_meta_merge__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51542__$1_p__51541_update$$,$APP.$cljs$cst$2399$meta_merge$$),$update_paths$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51542__$1_p__51541_update$$,$APP.$cljs$cst$2400$update_paths$$);$map__51542__$1_p__51541_update$$=$APP.$cljs$core$truth_$$($update_paths$$)?function($p1__51537_SHARP_$$){var $JSCompiler_inline_result$jscomp$11058_c$jscomp$inline_13886$$=$reitit$impl$_path_vals$$($p1__51537_SHARP_$$,
$update_paths$$);$JSCompiler_inline_result$jscomp$11058_c$jscomp$inline_13886$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$apply$$,$APP.$cljs$core$assoc_in$$),$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$JSCompiler_inline_result$jscomp$11058_c$jscomp$inline_13886$$);return $reitit$impl$_copy_meta$$($JSCompiler_inline_result$jscomp$11058_c$jscomp$inline_13886$$,$p1__51537_SHARP_$$)}:$APP.$cljs$core$identity$$;
$merge$jscomp$1_meta_merge__$1$$=$APP.$cljs$core$truth_$$($merge$jscomp$1_meta_merge__$1$$)?$merge$jscomp$1_meta_merge__$1$$:$meta_merge$core$meta_merge$$;$G__51544_left$jscomp$24$$=$map__51542__$1_p__51541_update$$.$cljs$core$IFn$_invoke$arity$1$?$map__51542__$1_p__51541_update$$.$cljs$core$IFn$_invoke$arity$1$($G__51544_left$jscomp$24$$):$map__51542__$1_p__51541_update$$($G__51544_left$jscomp$24$$);$G__51545_right$jscomp$20$$=$map__51542__$1_p__51541_update$$.$cljs$core$IFn$_invoke$arity$1$?$map__51542__$1_p__51541_update$$.$cljs$core$IFn$_invoke$arity$1$($G__51545_right$jscomp$20$$):
$map__51542__$1_p__51541_update$$($G__51545_right$jscomp$20$$);return $merge$jscomp$1_meta_merge__$1$$.$cljs$core$IFn$_invoke$arity$2$?$merge$jscomp$1_meta_merge__$1$$.$cljs$core$IFn$_invoke$arity$2$($G__51544_left$jscomp$24$$,$G__51545_right$jscomp$20$$):$merge$jscomp$1_meta_merge__$1$$($G__51544_left$jscomp$24$$,$G__51545_right$jscomp$20$$)},$reitit$impl$merge_data$$=function($opts$jscomp$266$$,$p$jscomp$224$$,$x$jscomp$1143$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$105$$,
$p__51546_v$jscomp$554$$){var $k$jscomp$609$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51546_v$jscomp$554$$,0,null);$p__51546_v$jscomp$554$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51546_v$jscomp$554$$,1,null);try{return $reitit$impl$meta_merge$$($acc$jscomp$105$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$609$$,$p__51546_v$jscomp$554$$]),$opts$jscomp$266$$)}catch($e51550$$){if($e51550$$ instanceof Error){var $e$jscomp$294$$=$e51550$$;
return $reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2366$reitit_DOT_impl_SLASH_merge_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$296$path$$,$p$jscomp$224$$,$APP.$cljs$cst$257$left$$,$acc$jscomp$105$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$609$$,$p__51546_v$jscomp$554$$]),$APP.$cljs$cst$727$exception$$,$e$jscomp$294$$],null))}throw $e51550$$;}},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$x$jscomp$1143$$)},$reitit$impl$resolve_routes$$=function($G__51560_raw_routes$jscomp$1$$,$p__51557$$){var $map__51558__$1$$=$APP.$cljs$core$__destructure_map$$($p__51557$$),$coerce$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51558__$1$$,$APP.$cljs$cst$2401$coerce$$);$G__51560_raw_routes$jscomp$1$$=$reitit$impl$map_data$$(function($p1__51554_SHARP_$$,$p2__51555_SHARP_$$){return $reitit$impl$merge_data$$($map__51558__$1$$,$p1__51554_SHARP_$$,$p2__51555_SHARP_$$)},$reitit$impl$walk$$($G__51560_raw_routes$jscomp$1$$,
$map__51558__$1$$));return $APP.$cljs$core$truth_$$($coerce$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__51556_SHARP_$$){return $coerce$$.$cljs$core$IFn$_invoke$arity$2$?$coerce$$.$cljs$core$IFn$_invoke$arity$2$($p1__51556_SHARP_$$,$map__51558__$1$$):$coerce$$($p1__51556_SHARP_$$,$map__51558__$1$$)}),$G__51560_raw_routes$jscomp$1$$):$G__51560_raw_routes$jscomp$1$$},$reitit$core$default_router_options$$=
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2450$lookup$$,function($map__52142_map__52142__$1_name$jscomp$250_p__52138$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52142_map__52142__$1_name$jscomp$250_p__52138$$,0,null);$map__52142_map__52142__$1_name$jscomp$250_p__52138$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52142_map__52142__$1_name$jscomp$250_p__52138$$,1,null);$map__52142_map__52142__$1_name$jscomp$250_p__52138$$=
$APP.$cljs$core$__destructure_map$$($map__52142_map__52142__$1_name$jscomp$250_p__52138$$);$map__52142_map__52142__$1_name$jscomp$250_p__52138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52142_map__52142__$1_name$jscomp$250_p__52138$$,$APP.$cljs$cst$725$name$$);return $APP.$cljs$core$truth_$$($map__52142_map__52142__$1_name$jscomp$250_p__52138$$)?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$map__52142_map__52142__$1_name$jscomp$250_p__52138$$]):null},$APP.$cljs$cst$2398$expand$$,
$APP.$reitit$core$expand$$,$APP.$cljs$cst$2401$coerce$$,function($route$jscomp$4$$){return $route$jscomp$4$$},$APP.$cljs$cst$411$compile$$,function($map__52147_map__52147__$1_p__52143$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52147_map__52147__$1_p__52143$$,0,null);$map__52147_map__52147__$1_p__52143$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52147_map__52147__$1_p__52143$$,1,null);$map__52147_map__52147__$1_p__52143$$=$APP.$cljs$core$__destructure_map$$($map__52147_map__52147__$1_p__52143$$);
return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52147_map__52147__$1_p__52143$$,$APP.$cljs$cst$2402$handler$$)},$APP.$cljs$cst$727$exception$$,$reitit$exception$exception$$,$APP.$cljs$cst$2400$update_paths$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2379$parameters$$,$APP.$cljs$core$any_QMARK_$$],null),$reitit$impl$accumulate$$],null)],null),$APP.$cljs$cst$2451$conflicts$$,function($conflicts$jscomp$4$$){return $reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2363$path_conflicts$$,$conflicts$jscomp$4$$)}],null)},$app$plugins$utils$mixed_value$$=function($s$jscomp$545_values$jscomp$71$$){$s$jscomp$545_values$jscomp$71$$=$APP.$cljs$core$set$$($s$jscomp$545_values$jscomp$71$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($s$jscomp$545_values$jscomp$71$$),
1)?$APP.$cljs$core$first$$($s$jscomp$545_values$jscomp$71$$):"mixed"},$reitit$impl$name_conflicting_routes$$=function($G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$){$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$=$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$group_by$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$second$$),
$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$);$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$=$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$first$$),$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$);
$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$=$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$pos_QMARK_$$,$APP.$cljs$core$count$$,$APP.$cljs$core$butlast$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$second$$])),$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$);
$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$=$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$seq$$($G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$);$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$=$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__51626_v$jscomp$555$$){var $k$jscomp$610$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51626_v$jscomp$555$$,0,null);$p__51626_v$jscomp$555$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51626_v$jscomp$555$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$610$$,$APP.$cljs$core$set$$($p__51626_v$jscomp$555$$)],null)},$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$);return $G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$==
null?null:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__51621__$1_G__51621__$2_G__51621__$3_G__51621__$4_G__51621__$5_routes$jscomp$5$$)},$reitit$impl$conflicting_paths$$=function($conflicts$jscomp$3$$){return $APP.$cljs$core$set$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,function(){return function $reitit$impl$conflicting_paths_$_iter__51604$$($s__51605$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__51605__$2_temp__5825__auto__$jscomp$143$$=
$APP.$cljs$core$seq$$($s__51605$$);if($s__51605__$2_temp__5825__auto__$jscomp$143$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__51605__$2_temp__5825__auto__$jscomp$143$$)){var $JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$=$APP.$cljs$core$_chunked_first$$($s__51605__$2_temp__5825__auto__$jscomp$143$$),$size__5502__auto__$jscomp$22$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$),$b__51607_p$jscomp$226$$=
$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$22$$);a:{for(var $i__51606$jscomp$inline_9794$$=0;;)if($i__51606$jscomp$inline_9794$$<$size__5502__auto__$jscomp$22$$){var $b$jscomp$inline_13888_vec__51610$jscomp$inline_9795$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$,$i__51606$jscomp$inline_9794$$),$p$jscomp$inline_9796_x$jscomp$inline_13889$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13888_vec__51610$jscomp$inline_9795$$,
0,null),$pc$jscomp$inline_9797$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13888_vec__51610$jscomp$inline_9795$$,1,null);$b$jscomp$inline_13888_vec__51610$jscomp$inline_9795$$=$b__51607_p$jscomp$226$$;$p$jscomp$inline_9796_x$jscomp$inline_13889$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$pc$jscomp$inline_9797$$),$APP.$cljs$core$first$$($p$jscomp$inline_9796_x$jscomp$inline_13889$$));
$b$jscomp$inline_13888_vec__51610$jscomp$inline_9795$$.add($p$jscomp$inline_9796_x$jscomp$inline_13889$$);$i__51606$jscomp$inline_9794$$+=1}else{$JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$=!0;break a}$JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$=void 0}return $JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__51607_p$jscomp$226$$),
$reitit$impl$conflicting_paths_$_iter__51604$$($APP.$cljs$core$_chunked_rest$$($s__51605__$2_temp__5825__auto__$jscomp$143$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__51607_p$jscomp$226$$),null)}$JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$=$APP.$cljs$core$first$$($s__51605__$2_temp__5825__auto__$jscomp$143$$);$b__51607_p$jscomp$226$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$,
0,null);$JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$,1,null);return $APP.$cljs$core$cons$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$JSCompiler_inline_result$jscomp$2082_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51616$$),
$APP.$cljs$core$first$$($b__51607_p$jscomp$226$$)),$reitit$impl$conflicting_paths_$_iter__51604$$($APP.$cljs$core$rest$$($s__51605__$2_temp__5825__auto__$jscomp$143$$)))}return null}},null,null)}($conflicts$jscomp$3$$)}()))},$reitit$trie$into_set$$=function($x$jscomp$1133$$){return $APP.$cljs$core$set_QMARK_$$($x$jscomp$1133$$)||$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$1133$$)?$APP.$cljs$core$set$$($x$jscomp$1133$$):$x$jscomp$1133$$==null?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$x$jscomp$1133$$)},$reitit$trie$split_path$$=function($s$jscomp$531$$,$bracket_QMARK__map__50105__$1_p__50104$$){function $_catch_all$$($from$jscomp$18_value$jscomp$inline_9804$$,$to$jscomp$20$$){var $JSCompiler_temp_const$jscomp$2070$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$from$jscomp$18_value$jscomp$inline_9804$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$531$$,$from$jscomp$18_value$jscomp$inline_9804$$+1,$to$jscomp$20$$));
return new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$2070$$,[new $reitit$trie$CatchAll$$($from$jscomp$18_value$jscomp$inline_9804$$,null,null,null)],null)}function $_wild$$($JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$,$temp__5823__auto__$jscomp$inline_9800_to$jscomp$19$$){var $JSCompiler_temp_const$jscomp$2053$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$531$$,
$JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$+1,$temp__5823__auto__$jscomp$inline_9800_to$jscomp$19$$);$temp__5823__auto__$jscomp$inline_9800_to$jscomp$19$$=$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$,"/");$JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$=$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_9800_to$jscomp$19$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$,
0,$temp__5823__auto__$jscomp$inline_9800_to$jscomp$19$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$,$temp__5823__auto__$jscomp$inline_9800_to$jscomp$19$$+1)):$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$);return new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$2053$$,[new $reitit$trie$Wild$$($JSCompiler_inline_result$jscomp$2054_from$jscomp$17_s$jscomp$inline_9799$$,
null,null,null)],null)}function $_static$$($from$jscomp$16$$,$to$jscomp$18$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$16$$,$to$jscomp$18$$)?null:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$531$$,$from$jscomp$16$$,$to$jscomp$18$$)],null)}$bracket_QMARK__map__50105__$1_p__50104$$=$APP.$cljs$core$__destructure_map$$($bracket_QMARK__map__50105__$1_p__50104$$);
var $colon_QMARK__syntax$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($bracket_QMARK__map__50105__$1_p__50104$$,$APP.$cljs$cst$2375$syntax$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1432$colon$$,null,$APP.$cljs$cst$2376$bracket$$,null],null),null));$bracket_QMARK__map__50105__$1_p__50104$$=$APP.$cljs$cst$2376$bracket$$.$cljs$core$IFn$_invoke$arity$1$($reitit$trie$into_set$$($colon_QMARK__syntax$$));$colon_QMARK__syntax$$=
$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($reitit$trie$into_set$$($colon_QMARK__syntax$$));for(var $G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$=null,$G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$=0,$to$jscomp$17$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($to$jscomp$17$$,$APP.$cljs$core$count$$($s$jscomp$531$$)))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$,$_static$$($G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$,
$to$jscomp$17$$));var $G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$531$$,$to$jscomp$17$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($bracket_QMARK__map__50105__$1_p__50104$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("{",$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$):$bracket_QMARK__map__50105__$1_p__50104$$)?($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=
function(){var $or__5025__auto__$jscomp$423$$=$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$531$$,"}",$to$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$423$$)?$or__5025__auto__$jscomp$423$$:$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2377$reitit_DOT_trie_SLASH_unclosed_brackets$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$296$path$$,$s$jscomp$531$$],null))}(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("*",
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$531$$,$to$jscomp$17$$+1))?($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$,$_static$$($G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_catch_all$$($to$jscomp$17$$+1,$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$)])),
$G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$+1),$to$jscomp$17$$=$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$+1)):($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$,$_static$$($G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$,
$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_wild$$($to$jscomp$17$$,$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$+1),$to$jscomp$17$$=$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$+1))):
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($colon_QMARK__syntax$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(":",$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$):$colon_QMARK__syntax$$)?($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=function(){var $or__5025__auto__$jscomp$424$$=$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$531$$,"/",$to$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$424$$)?
$or__5025__auto__$jscomp$424$$:$APP.$cljs$core$count$$($s$jscomp$531$$)}(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$-$to$jscomp$17$$)?$to$jscomp$17$$+=1:($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$,$_static$$($G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_wild$$($to$jscomp$17$$,
$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$),$to$jscomp$17$$=$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$))):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($colon_QMARK__syntax$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("*",
$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$):$colon_QMARK__syntax$$)?($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$count$$($s$jscomp$531$$),$G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50496_G__50499_G__50507_G__50511_ss$jscomp$7$$,$_static$$($G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_catch_all$$($to$jscomp$17$$,
$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50497_G__50500_G__50508_G__50512_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$),$to$jscomp$17$$=$G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50498_G__50501_G__50509_G__50513_c$jscomp$280_to_SINGLEQUOTE_$$)):$to$jscomp$17$$+=1}},$reitit$impl$path_conflicting_routes$$=function($routes$jscomp$4$$,$opts$jscomp$268$$){var $parts_and_routes$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__51577$$){var $s$jscomp$534$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51577$$,0,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$reitit$trie$split_path$$($s$jscomp$534$$,$opts$jscomp$268$$),$p__51577$$],null)},$routes$jscomp$4$$);return $APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$209$$,$p__51581_r$jscomp$108$$){var $p$jscomp$225$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51581_r$jscomp$108$$,0,null);$p__51581_r$jscomp$108$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51581_r$jscomp$108$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p__51581_r$jscomp$108$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$106$$,$p__51585_r_SINGLEQUOTE_$$){var $p_SINGLEQUOTE_$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51585_r_SINGLEQUOTE_$$,0,null);$p__51585_r_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51585_r_SINGLEQUOTE_$$,1,null);return $reitit$trie$conflicting_parts_QMARK_$$($p$jscomp$225$$,$p_SINGLEQUOTE_$jscomp$4$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$106$$,
$p__51585_r_SINGLEQUOTE_$$):$acc$jscomp$106$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($parts_and_routes$$,$index$jscomp$209$$+1))],null)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$core$second$$))),$parts_and_routes$$))},$reitit$trie$insert$cljs$0core$0IFn$0_invoke$0arity$04$$=function($node$jscomp$257$$,$path$jscomp$205$$,$data$jscomp$173$$,
$map__50310__$1_p__50309$$){$map__50310__$1_p__50309$$=$APP.$cljs$core$__destructure_map$$($map__50310__$1_p__50309$$);var $parameters$jscomp$1_params$jscomp$132$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50310__$1_p__50309$$,$APP.$cljs$cst$2391$reitit_DOT_trie_SLASH_parameters$$,$reitit$trie$map_parameters$$),$G__50314$jscomp$inline_13891_parts$jscomp$20$$=$reitit$trie$split_path$$($path$jscomp$205$$,$map__50310__$1_p__50309$$);$G__50314$jscomp$inline_13891_parts$jscomp$20$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$string_QMARK_$$,$G__50314$jscomp$inline_13891_parts$jscomp$20$$));$parameters$jscomp$1_params$jscomp$132$$=$parameters$jscomp$1_params$jscomp$132$$.$cljs$core$IFn$_invoke$arity$1$?$parameters$jscomp$1_params$jscomp$132$$.$cljs$core$IFn$_invoke$arity$1$($G__50314$jscomp$inline_13891_parts$jscomp$20$$):$parameters$jscomp$1_params$jscomp$132$$($G__50314$jscomp$inline_13891_parts$jscomp$20$$);return $reitit$trie$_insert$$($APP.$cljs$core$truth_$$($node$jscomp$257$$)?
$node$jscomp$257$$:$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$reitit$trie$split_path$$($path$jscomp$205$$,$map__50310__$1_p__50309$$),$path$jscomp$205$$,$parameters$jscomp$1_params$jscomp$132$$,$data$jscomp$173$$)},$reitit$impl$parse$$=function($path$jscomp$207_path__$1$jscomp$6$$,$opts$jscomp$262_path_parts$$){$path$jscomp$207_path__$1$jscomp$6$$=$reitit$trie$join_path$$($reitit$trie$split_path$$($path$jscomp$207_path__$1$jscomp$6$$,$opts$jscomp$262_path_parts$$));$opts$jscomp$262_path_parts$$=
$reitit$trie$split_path$$($path$jscomp$207_path__$1$jscomp$6$$,$opts$jscomp$262_path_parts$$);var $path_params$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$string_QMARK_$$,$opts$jscomp$262_path_parts$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2395$path_params$$,$path_params$$,$APP.$cljs$cst$2396$path_parts$$,$opts$jscomp$262_path_parts$$,
$APP.$cljs$cst$296$path$$,$path$jscomp$207_path__$1$jscomp$6$$],null)},$reitit$core$linear_router$cljs$0core$0IFn$0_invoke$0arity$02$$=function($compiled_routes$jscomp$3$$,$opts$jscomp$275$$){var $compiler$jscomp$6$$=$APP.$cljs$cst$2418$reitit_DOT_trie_SLASH_trie_compiler$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$275$$,new $reitit$trie$t_reitit$0trie50197$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)),$names$jscomp$5$$=$reitit$impl$find_names$$($compiled_routes$jscomp$3$$),$vec__51918$jscomp$2$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($nl$jscomp$7_p__51922$$,$map__51936_p__51923$$){function $f$jscomp$796$$($JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$){var $temp__5823__auto__$jscomp$138$$=$reitit$impl$path_for$$($map__51936__$1$$,$JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$);$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$138$$)?$JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$=
$reitit$core$__GT_Match$$($p$jscomp$230$$,$map__51934__$1$$,$result$jscomp$222$$,$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$),$temp__5823__auto__$jscomp$138$$):($JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$=$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$),$JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$=
new $reitit$core$PartialMatch$$($p$jscomp$230$$,$map__51934__$1$$,$result$jscomp$222$$,$JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$,$path_params$jscomp$12$$,null,null,null));return $JSCompiler_temp$jscomp$2068_p1__51905_SHARP__path_params$jscomp$inline_9815$$}var $pl$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$7_p__51922$$,0,null);$nl$jscomp$7_p__51922$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$7_p__51922$$,
1,null);var $p$jscomp$230$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__51936_p__51923$$,0,null),$map__51934_name$jscomp$237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__51936_p__51923$$,1,null),$map__51934__$1$$=$APP.$cljs$core$__destructure_map$$($map__51934_name$jscomp$237$$);$map__51934_name$jscomp$237$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51934__$1$$,$APP.$cljs$cst$725$name$$);var $result$jscomp$222$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__51936_p__51923$$,
2,null);$map__51936_p__51923$$=$reitit$impl$parse$$($p$jscomp$230$$,$opts$jscomp$275$$);var $map__51936__$1$$=$APP.$cljs$core$__destructure_map$$($map__51936_p__51923$$),$path_params$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51936__$1$$,$APP.$cljs$cst$2395$path_params$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($pl$jscomp$3$$,$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$01$$($reitit$trie$insert$cljs$0core$0IFn$0_invoke$0arity$04$$(null,
$p$jscomp$230$$,$reitit$core$__GT_Match$$($p$jscomp$230$$,$map__51934__$1$$,$result$jscomp$222$$,null,null),$opts$jscomp$275$$))),$APP.$cljs$core$truth_$$($map__51934_name$jscomp$237$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nl$jscomp$7_p__51922$$,$map__51934_name$jscomp$237$$,$f$jscomp$796$$):$nl$jscomp$7_p__51922$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],
null),$compiled_routes$jscomp$3$$),$pl$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51918$jscomp$2$$,0,null),$nl$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51918$jscomp$2$$,1,null),$matcher$jscomp$19$$=$reitit$trie$linear_matcher$$($compiler$jscomp$6$$,$pl$jscomp$2$$,!0),$match_by_path$jscomp$2$$=$reitit$trie$_path_matcher$$($compiler$jscomp$6$$,$matcher$jscomp$19$$),$routes$jscomp$11$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$3$$);
return new $reitit$core$t_reitit$0core51955$$($vec__51918$jscomp$2$$,$matcher$jscomp$19$$,$names$jscomp$5$$,$compiled_routes$jscomp$3$$,$routes$jscomp$11$$,$nl$jscomp$6$$,$pl$jscomp$2$$,$nl$jscomp$6$$,$match_by_path$jscomp$2$$,$compiler$jscomp$6$$,$opts$jscomp$275$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$],null))},$reitit$impl$__GT_wild_route_QMARK_$$=function($opts$jscomp$264$$){return function($p__51479_path$jscomp$209$$){$p__51479_path$jscomp$209$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51479_path$jscomp$209$$,0,null);return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$cst$2395$path_params$$.$cljs$core$IFn$_invoke$arity$1$($reitit$impl$parse$$($p__51479_path$jscomp$209$$,$opts$jscomp$264$$))))}},$app$main$router$initialize_router$$=function(){var $routes$jscomp$29$$=$app$main$ui$routes$routes$$;typeof $app$main$router$initialize_router_52190$$==="undefined"&&($app$main$router$initialize_router_52190$$=function($routes$jscomp$30$$,
$meta52191$$){this.$routes$=$routes$jscomp$30$$;this.$meta52191$=$meta52191$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$initialize_router_52190$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_router_52190$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2453$app_DOT_main_DOT_router_SLASH_initialize_router$$},$app$main$router$initialize_router_52190$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_52192$$,$meta52191__$1$$){return new $app$main$router$initialize_router_52190$$(this.$routes$,$meta52191__$1$$)},$app$main$router$initialize_router_52190$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52191$},$app$main$router$initialize_router_52190$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_router_52190$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($JSCompiler_temp_const$jscomp$14093__$jscomp$1519$$,
$e$jscomp$inline_14729_state$jscomp$111$$){$JSCompiler_temp_const$jscomp$14093__$jscomp$1519$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;a:{var $raw_routes$jscomp$inline_14714$$=this.$routes$,$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$reitit$core$default_router_options$$(),$APP.$cljs$core$PersistentArrayMap$EMPTY$$]));$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$=
$APP.$cljs$core$__destructure_map$$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$);var $router$jscomp$inline_14717$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$,$APP.$cljs$cst$2172$router$$),$conflicts$jscomp$inline_14718$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$,$APP.$cljs$cst$2451$conflicts$$);try{var $routes$jscomp$inline_14719$$=
$reitit$impl$resolve_routes$$($raw_routes$jscomp$inline_14714$$,$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$),$path_conflicting$jscomp$inline_14720$$=$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($router$jscomp$inline_14717$$)?$APP.$cljs$core$not$$($conflicts$jscomp$inline_14718$$):$router$jscomp$inline_14717$$)?$reitit$impl$path_conflicting_routes$$($routes$jscomp$inline_14719$$,$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$):null,$name_conflicting$jscomp$inline_14721$$=
$reitit$impl$name_conflicting_routes$$($routes$jscomp$inline_14719$$),$compiled_routes$jscomp$inline_14722$$=$reitit$impl$compile_routes$$($routes$jscomp$inline_14719$$,$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$),$wilds_QMARK_$jscomp$inline_14723$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$($reitit$impl$__GT_wild_route_QMARK_$$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$),$compiled_routes$jscomp$inline_14722$$)),$all_wilds_QMARK_$jscomp$inline_14724$$=
$APP.$cljs$core$every_QMARK_$$($reitit$impl$__GT_wild_route_QMARK_$$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$),$compiled_routes$jscomp$inline_14722$$),$router__$1$jscomp$inline_14725$$=$APP.$cljs$core$truth_$$($router$jscomp$inline_14717$$)?$router$jscomp$inline_14717$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($compiled_routes$jscomp$inline_14722$$))&&!$wilds_QMARK_$jscomp$inline_14723$$?$reitit$core$single_static_path_router$$:$APP.$cljs$core$truth_$$($path_conflicting$jscomp$inline_14720$$)?
$reitit$core$quarantine_router$$:$wilds_QMARK_$jscomp$inline_14723$$?$all_wilds_QMARK_$jscomp$inline_14724$$?$reitit$core$trie_router$$:$reitit$core$mixed_router$$:$reitit$core$lookup_router$$,$temp__5825__auto___52354$jscomp$inline_14726$$=$APP.$cljs$core$truth_$$($conflicts$jscomp$inline_14718$$)?$reitit$impl$unresolved_conflicts$$($path_conflicting$jscomp$inline_14720$$):$conflicts$jscomp$inline_14718$$;$APP.$cljs$core$truth_$$($temp__5825__auto___52354$jscomp$inline_14726$$)&&($conflicts$jscomp$inline_14718$$.$cljs$core$IFn$_invoke$arity$1$?
$conflicts$jscomp$inline_14718$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto___52354$jscomp$inline_14726$$):$conflicts$jscomp$inline_14718$$($temp__5825__auto___52354$jscomp$inline_14726$$));$APP.$cljs$core$truth_$$($name_conflicting$jscomp$inline_14721$$)&&$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2365$name_conflicts$$,$name_conflicting$jscomp$inline_14721$$);var $temp__5825__auto___52359$jscomp$inline_14727$$=$APP.$cljs$cst$2452$validate$$.$cljs$core$IFn$_invoke$arity$1$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$);
$APP.$cljs$core$truth_$$($temp__5825__auto___52359$jscomp$inline_14727$$)&&($temp__5825__auto___52359$jscomp$inline_14727$$.$cljs$core$IFn$_invoke$arity$2$?$temp__5825__auto___52359$jscomp$inline_14727$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$inline_14722$$,$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$):$temp__5825__auto___52359$jscomp$inline_14727$$($compiled_routes$jscomp$inline_14722$$,$map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$));
var $G__52161$jscomp$inline_14728$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$,$APP.$cljs$cst$2449$reitit_DOT_core_SLASH_path_conflicting$$,$path_conflicting$jscomp$inline_14720$$);var $JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$=$router__$1$jscomp$inline_14725$$.$cljs$core$IFn$_invoke$arity$2$?$router__$1$jscomp$inline_14725$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$inline_14722$$,
$G__52161$jscomp$inline_14728$$):$router__$1$jscomp$inline_14725$$($compiled_routes$jscomp$inline_14722$$,$G__52161$jscomp$inline_14728$$);break a}catch($e52158$jscomp$inline_14732$$){if($e52158$jscomp$inline_14732$$ instanceof Error)throw $e$jscomp$inline_14729_state$jscomp$111$$=$e52158$jscomp$inline_14732$$,$JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52157$jscomp$inline_14715_map__52157__$1$jscomp$inline_14716$$,
$APP.$cljs$cst$727$exception$$,$APP.$cljs$core$identity$$),$JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$inline_14729_state$jscomp$111$$):$JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$($e$jscomp$inline_14729_state$jscomp$111$$);throw $e52158$jscomp$inline_14732$$;}$JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$=
void 0}return $JSCompiler_temp_const$jscomp$14093__$jscomp$1519$$.call($APP.$cljs$core$assoc$$,$e$jscomp$inline_14729_state$jscomp$111$$,$APP.$cljs$cst$2172$router$$,$JSCompiler_inline_result$jscomp$14095_fexpr__52159$jscomp$inline_14731$$)});return new $app$main$router$initialize_router_52190$$($routes$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$router$initialize_history$$=function(){var $on_change$jscomp$3$$=$app$main$ui$routes$on_navigate$$;typeof $app$main$router$initialize_history_52403$$===
"undefined"&&($app$main$router$initialize_history_52403$$=function($on_change$jscomp$4$$,$meta52404$$){this.$on_change$=$on_change$jscomp$4$$;this.$meta52404$=$meta52404$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$initialize_history_52403$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_history_52403$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2464$app_DOT_main_DOT_router_SLASH_initialize_history$$},
$app$main$router$initialize_history_52403$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52405$$,$meta52404__$1$$){return new $app$main$router$initialize_history_52403$$(this.$on_change$,$meta52404__$1$$)},$app$main$router$initialize_history_52403$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52404$},$app$main$router$initialize_history_52403$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_history_52403$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1530_instance$jscomp$inline_9820$$,$state$jscomp$117$$){$_$jscomp$1530_instance$jscomp$inline_9820$$=new $goog$history$Html5History$$(null,new $$jscomp$scope$m1810428007$0$TokenTransformer$$);$_$jscomp$1530_instance$jscomp$inline_9820$$.$useFragment_$!=1&&($APP.$goog$events$listen$$($_$jscomp$1530_instance$jscomp$inline_9820$$.$window_$,"hashchange",$_$jscomp$1530_instance$jscomp$inline_9820$$.$onHistoryEvent_$,!1,$_$jscomp$1530_instance$jscomp$inline_9820$$),$_$jscomp$1530_instance$jscomp$inline_9820$$.$useFragment_$=
!0);$JSCompiler_StaticMethods_setEnabled$$($_$jscomp$1530_instance$jscomp$inline_9820$$,!0);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$117$$,$APP.$cljs$cst$2457$history$$,$_$jscomp$1530_instance$jscomp$inline_9820$$)},$app$main$router$initialize_history_52403$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_history_52403$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1531_stopper$jscomp$3$$,
$state$jscomp$118$$,$stream$jscomp$19$$){var $self__$jscomp$3273$$=this;$_$jscomp$1531_stopper$jscomp$3$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2464$app_DOT_main_DOT_router_SLASH_initialize_history$$),$stream$jscomp$19$$);var $history__$1$jscomp$2$$=$APP.$cljs$cst$2457$history$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$118$$),$router$jscomp$5$$=$APP.$cljs$cst$2172$router$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$118$$);
$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $G__52413$$=$history__$1$jscomp$2$$.getToken();return $self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$($router$jscomp$5$$,$G__52413$$,!0):$self__$jscomp$3273$$.$on_change$($router$jscomp$5$$,$G__52413$$,!0)});return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($new_url$jscomp$1_p__52415$$){var $old_path$jscomp$inline_9831_old_url$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_url$jscomp$1_p__52415$$,0,null);$new_url$jscomp$1_p__52415$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_url$jscomp$1_p__52415$$,1,null);if($new_url$jscomp$1_p__52415$$!=null){var $JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$;if(!($JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$=$old_path$jscomp$inline_9831_old_url$jscomp$1$$==null)){var $old_params$jscomp$inline_9832_params$jscomp$inline_9826$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$1927$team_id$$],null),$new_params$jscomp$inline_9829_new_uri$jscomp$inline_9827$$=$APP.$app$common$uri$uri$$($new_url$jscomp$1_p__52415$$);$JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_params$jscomp$inline_9829_new_uri$jscomp$inline_9827$$);$new_params$jscomp$inline_9829_new_uri$jscomp$inline_9827$$=
$APP.$cljs$core$select_keys$$($app$common$uri$query_string__GT_map$$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($new_params$jscomp$inline_9829_new_uri$jscomp$inline_9827$$)),$old_params$jscomp$inline_9832_params$jscomp$inline_9826$$);var $old_uri$jscomp$inline_9830$$=$APP.$app$common$uri$uri$$($old_path$jscomp$inline_9831_old_url$jscomp$1$$);$old_path$jscomp$inline_9831_old_url$jscomp$1$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($old_uri$jscomp$inline_9830$$);$old_params$jscomp$inline_9832_params$jscomp$inline_9826$$=
$APP.$cljs$core$select_keys$$($app$common$uri$query_string__GT_map$$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($old_uri$jscomp$inline_9830$$)),$old_params$jscomp$inline_9832_params$jscomp$inline_9826$$);$JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_path$jscomp$inline_9831_old_url$jscomp$1$$,$JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_params$jscomp$inline_9829_new_uri$jscomp$inline_9827$$,
$old_params$jscomp$inline_9832_params$jscomp$inline_9826$$)}return $self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$($router$jscomp$5$$,$new_url$jscomp$1_p__52415$$,$JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$):$self__$jscomp$3273$$.$on_change$($router$jscomp$5$$,$new_url$jscomp$1_p__52415$$,$JSCompiler_temp$jscomp$2084_new_path$jscomp$inline_9828_send_QMARK_$$)}return null},$APP.$beicon$v2$core$take_until$$($_$jscomp$1531_stopper$jscomp$3$$,
$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(null,null),$APP.$beicon$v2$core$create$$(function($subs$jscomp$14$$){var $key$jscomp$327$$=$APP.$goog$events$listen$$($history__$1$jscomp$2$$,"navigate",function($o$jscomp$261$$){return $subs$jscomp$14$$.next($o$jscomp$261$$.token)});return function(){$JSCompiler_StaticMethods_setEnabled$$($history__$1$jscomp$2$$,!1);return $APP.$goog$events$unlistenByKey$$($key$jscomp$327$$)}})))))});
return new $app$main$router$initialize_history_52403$$($on_change$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$router$match$$=function($router$jscomp$3_temp__5825__auto__$jscomp$145$$,$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$){$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$=$APP.$app$common$uri$uri$$($path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$);$router$jscomp$3_temp__5825__auto__$jscomp$145$$=$reitit$core$match_by_path$$($router$jscomp$3_temp__5825__auto__$jscomp$145$$,
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$));if($APP.$cljs$core$truth_$$($router$jscomp$3_temp__5825__auto__$jscomp$145$$)){$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$=$app$common$uri$query_string__GT_map$$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$));var $params$jscomp$137$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,
$APP.$cljs$cst$2395$path_params$$.$cljs$core$IFn$_invoke$arity$1$($router$jscomp$3_temp__5825__auto__$jscomp$145$$),$APP.$cljs$cst$747$query$$,$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$],null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($router$jscomp$3_temp__5825__auto__$jscomp$145$$,$APP.$cljs$cst$1430$params$$,$params$jscomp$137$$),$APP.$cljs$cst$2269$query_params$$,$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$)}return null},
$app$main$rasterizer$on_message$$=function($evdata_event$jscomp$91$$){var $evorigin_message$jscomp$inline_9836_type$jscomp$476$$=$evdata_event$jscomp$91$$.origin;$evdata_event$jscomp$91$$=$evdata_event$jscomp$91$$.data;if($APP.$cljs$core$object_QMARK_$$($evdata_event$jscomp$91$$)&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$app$main$rasterizer$origin$$,$evorigin_message$jscomp$inline_9836_type$jscomp$476$$)&&($evorigin_message$jscomp$inline_9836_type$jscomp$476$$=$evdata_event$jscomp$91$$.type,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("penpot/rasterizer",$evdata_event$jscomp$91$$.scope))){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($evorigin_message$jscomp$inline_9836_type$jscomp$476$$,"ready"))a:for($APP.$app$main$rasterizer$ready_QMARK_$$=!0,$evorigin_message$jscomp$inline_9836_type$jscomp$476$$=$APP.$app$main$rasterizer$queue$$.shift();;)if($evorigin_message$jscomp$inline_9836_type$jscomp$476$$!=null)$APP.$app$main$rasterizer$send_message_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$main$rasterizer$send_message_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($evorigin_message$jscomp$inline_9836_type$jscomp$476$$):$APP.$app$main$rasterizer$send_message_BANG_$$($evorigin_message$jscomp$inline_9836_type$jscomp$476$$),$evorigin_message$jscomp$inline_9836_type$jscomp$476$$=$APP.$app$main$rasterizer$queue$$.shift();else break a;return $APP.$app$main$rasterizer$msgbus$$.next($evdata_event$jscomp$91$$)}return null},$app$util$worker$init$$=function(){var $on_error$jscomp$4$$=$app$main$worker$on_error$$,
$instance$jscomp$9$$=new Worker($APP.$app$config$worker_uri$$),$bus$$=$APP.$beicon$v2$core$subject$$(),$worker$jscomp$10$$=new $app$util$worker$Worker$$($instance$jscomp$9$$,$bus$$.asObservable(),null,null,null);$instance$jscomp$9$$.addEventListener("message",function($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$){$G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$=$G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$.data;var $sender_id$jscomp$inline_9839$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$,"senderId"),$reply_to$jscomp$inline_9840$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$,"replyTo"),$payload$jscomp$inline_9841$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$,"payload"),$buffer$jscomp$inline_9842$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$,"buffer");$G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3111$sender_id$$,$APP.$cljs$core$truth_$$($sender_id$jscomp$inline_9839$$)?$APP.$cljs$core$uuid$$($sender_id$jscomp$inline_9839$$):null,$APP.$cljs$cst$3112$reply_to$$,
$APP.$cljs$core$truth_$$($reply_to$jscomp$inline_9840$$)?$APP.$cljs$core$uuid$$($reply_to$jscomp$inline_9840$$):null,$APP.$cljs$cst$3113$payload$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$,"cmd"),"initialize-indices")?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3116$initialize_indices$$,$APP.$cljs$cst$3117$file_raw$$,
$payload$jscomp$inline_9841$$],null):$payload$jscomp$inline_9841$$!=null?$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$inline_9841$$):null,$APP.$cljs$cst$3114$buffer_QMARK_$$,$buffer$jscomp$inline_9842$$],null));return $APP.$cljs$core$truth_$$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$))?($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$=$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$),
$on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$):$on_error$jscomp$4$$($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$)):$bus$$.next($G__53883_data$jscomp$inline_9838_event$jscomp$79_message$jscomp$71$$)});$instance$jscomp$9$$.addEventListener("error",function($G__53885_event$jscomp$80$$){$G__53885_event$jscomp$80$$=$G__53885_event$jscomp$80$$.data;return $on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?
$on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($worker$jscomp$10$$,$G__53885_event$jscomp$80$$):$on_error$jscomp$4$$($worker$jscomp$10$$,$G__53885_event$jscomp$80$$)});return $worker$jscomp$10$$},$app$main$data$profile$mark_questions_as_answered$$=function($onboarding_questions$$){typeof $app$main$data$profile$mark_questions_as_answered_55295$$==="undefined"&&($app$main$data$profile$mark_questions_as_answered_55295$$=function($onboarding_questions$jscomp$1$$,$meta55296$$){this.$onboarding_questions$=
$onboarding_questions$jscomp$1$$;this.$meta55296$=$meta55296$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3229$app_DOT_main_DOT_data_DOT_profile_SLASH_mark_questions_as_answered$$},$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55297$$,$meta55296__$1$$){return new $app$main$data$profile$mark_questions_as_answered_55295$$(this.$onboarding_questions$,$meta55296__$1$$)},$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55296$},$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1682$$,$state$jscomp$202$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$202$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3230$onboarding_questions_answered$$,!0)},$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$mark_questions_as_answered_55295$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $props$jscomp$135$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3230$onboarding_questions_answered$$,!0,$APP.$cljs$cst$3231$onboarding_questions$$,this.$onboarding_questions$],null);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3196$update_profile_props$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,$props$jscomp$135$$],null)))});return new $app$main$data$profile$mark_questions_as_answered_55295$$($onboarding_questions$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$ui$static$0$request_access_STAR_$$=function($on_close$jscomp$14_props_75813$$){var $is_default$$=$on_close$jscomp$14_props_75813$$.isDefault,$profile$jscomp$63$$=$on_close$jscomp$14_props_75813$$.profile,$team_id$jscomp$142$$=$on_close$jscomp$14_props_75813$$.teamId,
$file_id$jscomp$367$$=$on_close$jscomp$14_props_75813$$.fileId,$is_workspace$$=$on_close$jscomp$14_props_75813$$.isWorkspace,$requested_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5412$sent$$,!1,$APP.$cljs$cst$5413$already_requested$$,!1],null)),$requested$$=$APP.$cljs$core$_deref$$($requested_STAR_$$);$on_close$jscomp$14_props_75813$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$63$$)],
function(){var $team_id__$1$jscomp$13$$=$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$63$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id__$1$jscomp$13$$])))});var $on_success$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($requested_STAR_$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5412$sent$$,!0,$APP.$cljs$cst$5413$already_requested$$,!1],null))}),$on_error$jscomp$70$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($requested_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5412$sent$$,!0,$APP.$cljs$cst$5413$already_requested$$,!0],null))}),$on_request_access$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$367$$),
$APP.$rumext$v2$adapt$$($team_id$jscomp$142$$),$APP.$rumext$v2$adapt$$($is_workspace$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$create_team_access_request$$($APP.$cljs$core$with_meta$$($file_id$jscomp$367$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$367$$,$APP.$cljs$cst$5414$is_viewer$$,$APP.$cljs$core$not$$($is_workspace$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$142$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$56$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$70$$],null))))});return $APP.$cljs$core$truth_$$($is_default$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project"),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),
onClose:$on_close$jscomp$14_props_75813$$}):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$682$$=$file_id$jscomp$367$$!=null;return $and__5023__auto__$jscomp$682$$?$APP.$cljs$cst$5413$already_requested$$.$cljs$core$IFn$_invoke$arity$1$($requested$$):$and__5023__auto__$jscomp$682$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.file"),content:new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.or-others.file")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_75813$$}):$APP.$cljs$core$truth_$$($APP.$cljs$cst$5413$already_requested$$.$cljs$core$IFn$_invoke$arity$1$($requested$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.project"),content:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.or-others.project")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_75813$$}):$APP.$cljs$core$truth_$$($APP.$cljs$cst$5412$sent$$.$cljs$core$IFn$_invoke$arity$1$($requested$$))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.done.success"),content:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.done.remember")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_75813$$}):
$file_id$jscomp$367$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.file"),content:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.you-can-ask.file"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.if-approves")],null),
buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.ask"),onButtonClick:$on_request_access$$,cancelText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_75813$$}):$team_id$jscomp$142$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project"),content:new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.you-can-ask.project"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.if-approves")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.ask"),onButtonClick:$on_request_access$$,cancelText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_75813$$}):
null},$app$main$ui$static$0$internal_error_STAR_$$=function($props_75830_support_contact_click$$){var $report$jscomp$3$$=$props_75830_support_contact_click$$.report,$on_reset$$=$props_75830_support_contact_click$$.onReset,$report_uri$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_reset__$1$$=function(){return $APP.$cljs$core$truth_$$($on_reset$$)?$on_reset$$:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(null))}}();$props_75830_support_contact_click$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reset__$1$$),$APP.$rumext$v2$adapt$$($report$jscomp$3$$)],function(){$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$($on_reset__$1$$);var $error_report_id$$=$APP.$app$common$uuid$next$$(),$error_href$$=$APP.$app$util$globals$location$$.href;$APP.$app$main$errors$last_report$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$error_report_id$$,$APP.$cljs$cst$1637$content$$,
$report$jscomp$3$$],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2509$settings_feedback$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,"issue",$APP.$cljs$cst$5415$error_report_id$$,$error_report_id$$,$APP.$cljs$cst$5416$error_href$$,$error_href$$],null)))});var $on_download$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$285_temp__5825__auto__$jscomp$326$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$285_temp__5825__auto__$jscomp$326$$);
$event$jscomp$285_temp__5825__auto__$jscomp$326$$=$APP.$rumext$v2$ref_val$$($report_uri$$);return $APP.$cljs$core$truth_$$($event$jscomp$285_temp__5825__auto__$jscomp$326$$)?$APP.$app$util$dom$trigger_download_uri$$("report","text/plain",$event$jscomp$285_temp__5825__auto__$jscomp$326$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($report$jscomp$3$$)],function(){if($report$jscomp$3$$!=null){$APP.$app$main$errors$last_report$$=$report$jscomp$3$$;
var $uri$jscomp$106$$=$APP.$app$util$webapi$create_uri$$($APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($report$jscomp$3$$,"text/plain"));$APP.$rumext$v2$set_ref_val_BANG_$$($report_uri$$,$uri$jscomp$106$$);return function(){return $APP.$app$util$webapi$revoke_uri$$($uri$jscomp$106$$)}}return null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.internal-error.main-message")}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__desc-message",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_static__desc-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.internal-error.desc-message-first")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_static__desc-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.internal-error.desc-message-second")})]}),$report$jscomp$3$$!=null?(0,$APP.$rumext$v2$jsx$$)("a",
{onClick:$on_download$jscomp$1$$,className:"main_ui_static__download-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.download",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["report.txt"]))}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__buttons-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",className:"main_ui_static__support-btn",onClick:$props_75830_support_contact_click$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.contact-support")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_static__retry-btn",onClick:$on_reset__$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")})]})]})},$app$main$ui$static$0$service_unavailable_STAR_$$=function(){var $on_click$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(null))});
return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.service-unavailable.main-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.service-unavailable.desc-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__sign-info",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_click$jscomp$32$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")})})]})},$app$main$ui$static$0$bad_gateway_STAR_$$=function(){var $handle_retry$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(null))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,
{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.bad-gateway.main-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.bad-gateway.desc-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__sign-info",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_retry$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")})})]})},$app$main$ui$static$0$not_found_STAR_$$=function(){return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.not-found.main-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.desc-message.error")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.desc-message.doesnt-exist")})]})},$app$main$ui$auth$recovery_request$recovery_sent_page$$=function($email$jscomp$16_props_75250$$){$email$jscomp$16_props_75250$$=$email$jscomp$16_props_75250$$.email;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_recovery_request__auth-form-wrapper main_ui_auth_recovery_request__register-success",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_auth_recovery_request__auth-title-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_auth_recovery_request__auth-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.check-mail")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__notification-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.sent-recovery")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__notification-text-email",
children:$email$jscomp$16_props_75250$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__notification-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.sent-recovery-check")})]})},$app$main$data$profile$mark_onboarding_as_viewed$cljs$0core$0IFn$0_invoke$0arity$01$$=function($p__55285$$){var $map__55286__$1$$=$APP.$cljs$core$__destructure_map$$($p__55285$$),$version$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55286__$1$$,
$APP.$cljs$cst$2289$version$$);typeof $app$main$data$profile$mark_onboarding_as_viewed_55290$$==="undefined"&&($app$main$data$profile$mark_onboarding_as_viewed_55290$$=function($p__55285$jscomp$1$$,$map__55286$jscomp$1$$,$version$jscomp$14$$,$meta55291$$){this.$p__55285$=$p__55285$jscomp$1$$;this.$map__55286$=$map__55286$jscomp$1$$;this.version=$version$jscomp$14$$;this.$meta55291$=$meta55291$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$mark_onboarding_as_viewed_55290$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_onboarding_as_viewed_55290$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3226$app_DOT_main_DOT_data_DOT_profile_SLASH_mark_onboarding_as_viewed$$},$app$main$data$profile$mark_onboarding_as_viewed_55290$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55292$$,$meta55291__$1$$){return new $app$main$data$profile$mark_onboarding_as_viewed_55290$$(this.$p__55285$,this.$map__55286$,this.version,
$meta55291__$1$$)},$app$main$data$profile$mark_onboarding_as_viewed_55290$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55291$},$app$main$data$profile$mark_onboarding_as_viewed_55290$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_onboarding_as_viewed_55290$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$=this.version;$or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$=
$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$)?$or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$:$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$);$or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3227$onboarding_viewed$$,!0,$APP.$cljs$cst$3228$release_notes_viewed$$,$or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$],
null);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3196$update_profile_props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,$or__5025__auto__$jscomp$inline_9844_props$jscomp$134_version__$1$$],null)))});return new $app$main$data$profile$mark_onboarding_as_viewed_55290$$($p__55285$$,$map__55286__$1$$,$version$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$rasterizer$init_BANG_$$=function(){var $iframe$jscomp$3$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("iframe");$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"id","rasterizer");$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"src",$APP.$app$main$rasterizer$origin$$);$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"hidden",!0);window.addEventListener("message",$app$main$rasterizer$on_message$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($allowed_QMARK_$$){if($APP.$cljs$core$truth_$$($allowed_QMARK_$$))$APP.$app$util$dom$append_child_BANG_$$(document.body,
$iframe$jscomp$3$$);else{var $new_origin$jscomp$1$$=""+($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"rasterizer.html"]))??"");$APP.$app$common$logging$enabled_QMARK_$$("app.main.rasterizer",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"fallback to main domain"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1786$origin$$,$new_origin$jscomp$1$$],null)],null)}),null,"app.main.rasterizer",$APP.$cljs$cst$1162$warn$$,!1);$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"src",$new_origin$jscomp$1$$);$APP.$app$util$dom$append_child_BANG_$$(document.body,
$iframe$jscomp$3$$);$APP.$app$main$rasterizer$origin$$=$new_origin$jscomp$1$$;$APP.$app$config$rasterizer_uri$$=$APP.$app$config$public_uri$$}return $APP.$app$main$rasterizer$instance$$=$iframe$jscomp$3$$},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$81$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.rasterizer",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"rasterizer iframe blocked by adblocker"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1786$origin$$,$APP.$app$main$rasterizer$origin$$],null)],null)}),$cause$jscomp$81$$,"app.main.rasterizer",$APP.$cljs$cst$849$error$$,!1);return(0,$APP.$beicon$v2$core$of$$)(!1)},
$APP.$beicon$v2$core$map$$(function($allowed_QMARK_$jscomp$1_response$jscomp$12$$){($allowed_QMARK_$jscomp$1_response$jscomp$12$$=$APP.$cljs$core$not$$($allowed_QMARK_$jscomp$1_response$jscomp$12$$.redirected))||$APP.$app$common$logging$enabled_QMARK_$$("app.main.rasterizer",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"rasterizer iframe blocked by adblocker"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1786$origin$$,$APP.$app$main$rasterizer$origin$$],null)],null)}),null,"app.main.rasterizer",$APP.$cljs$cst$849$error$$,!1);return $allowed_QMARK_$jscomp$1_response$jscomp$12$$},$APP.$app$util$http$fetch$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1578$method$$,
$APP.$cljs$cst$3767$head$$,$APP.$cljs$cst$1579$uri$$,$APP.$app$config$rasterizer_uri$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$3697$no_cors$$],null)))))},$app$main$data$event$persist_events$$=function($events$jscomp$2$$){if($APP.$cljs$core$seq$$($events$jscomp$2$$)){var $uri$jscomp$68$$=$APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"api/main/methods/push-audit-events"]));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)(null)},
$APP.$beicon$v2$core$mapcat$$($APP.$app$main$repo$handle_response$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1579$uri$$,$uri$jscomp$68$$,$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$2276$post$$,$APP.$cljs$cst$1583$credentials$$,"include",$APP.$cljs$cst$1581$body$$,new $APP.$app$util$http$t_app$0util$0http45214$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2318$events$$,$events$jscomp$2$$],null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)],
null))))}return(0,$APP.$beicon$v2$core$of$$)(null)},$app$main$data$event$initialize$$=function(){typeof $app$main$data$event$initialize_50642$$==="undefined"&&($app$main$data$event$initialize_50642$$=function($meta50643$$){this.$meta50643$=$meta50643$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$event$initialize_50642$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$initialize_50642$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2327$app_DOT_main_DOT_data_DOT_event_SLASH_initialize$$},$app$main$data$event$initialize_50642$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50644$$,$meta50643__$1$$){return new $app$main$data$event$initialize_50642$$($meta50643__$1$$)},$app$main$data$event$initialize_50642$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50643$},$app$main$data$event$initialize_50642$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$event$initialize_50642$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$event$store_performace_info$$())},$app$main$data$event$initialize_50642$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$initialize_50642$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1423$$,$___$1$jscomp$811$$,$stream$jscomp$17$$){var $session$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$stopper$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2327$app_DOT_main_DOT_data_DOT_event_SLASH_initialize$$),$stream$jscomp$17$$),$buffer$jscomp$62$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$)),$profile$jscomp$1$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$APP.$beicon$v2$core$map$$($APP.$cljs$cst$266$id$$,$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1914$profile$$,$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$storage$user$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null)))));$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event instrumentation initialized"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function($chunk$jscomp$18$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($buffer$jscomp$62$$,
$app$main$data$event$remove_from_buffer$$,$APP.$cljs$core$count$$($chunk$jscomp$18$$))},function($cause$jscomp$37$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"unexpected error on audit persistence"],null)],null)}),$cause$jscomp$37$$,"app.main.data.event",$APP.$cljs$cst$849$error$$,!1);return null},function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"audit persistence terminated"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$take_until$$($stopper$$,$APP.$beicon$v2$core$mapcat$$(function($events$jscomp$3_p__50658$$){var $chunk$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($events$jscomp$3_p__50658$$,0,null),$profile_id$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($events$jscomp$3_p__50658$$,1,null);$events$jscomp$3_p__50658$$=
$APP.$cljs$core$filterv$$(function($p1__50638_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$7$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__50638_SHARP_$$))},$chunk$jscomp$19$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($chunk$jscomp$19$$),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"events chunk persisted"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2328$total$$,$APP.$cljs$core$count$$($chunk$jscomp$19$$)],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return null},$app$main$data$event$persist_events$$($events$jscomp$3_p__50658$$)))},
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$APP.$beicon$v2$core$map$$(function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(100),$APP.$cljs$core$_deref$$($buffer$jscomp$62$$))},$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$debounce$$(2E3,$APP.$beicon$v2$core$filter$$(function($p1__50637_SHARP_$$){return $APP.$cljs$core$count$$($p1__50637_SHARP_$$)>
0},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($buffer$jscomp$62$$,null))),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2330$app_DOT_main_DOT_data_DOT_profile_SLASH_logout$$),$stream$jscomp$17$$))))))));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"session reinitialized"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$reset_BANG_$$($session$$,null)},function($cause$jscomp$38$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"error on event batching stream"],null)],null)}),$cause$jscomp$38$$,"app.main.data.event",$APP.$cljs$cst$849$error$$,!1);return null},function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"events batching stream terminated"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$take_until$$($stopper$$,$APP.$beicon$v2$core$switch_map$$(function(){return(0,$APP.$beicon$v2$core$timer$$)(18E5)},
$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($event$jscomp$67$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event enqueued"],
null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($buffer$jscomp$62$$,$app$main$data$event$append_to_buffer$$,$event$jscomp$67$$)},$APP.$beicon$v2$core$map$$(function($event$jscomp$68$$){var $or__5025__auto__$jscomp$inline_9846_session_STAR_$$=$APP.$cljs$core$_deref$$($session$$);$or__5025__auto__$jscomp$inline_9846_session_STAR_$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9846_session_STAR_$$)?
$or__5025__auto__$jscomp$inline_9846_session_STAR_$$:$APP.$app$common$time$now$$();var $JSCompiler_temp_const$jscomp$11068_context$jscomp$27$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$11070_context$jscomp$inline_13897$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_deref$$($APP.$app$main$data$event$context$$),
$APP.$cljs$cst$2312$context$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$68$$)])),$APP.$cljs$cst$2331$session$$,$or__5025__auto__$jscomp$inline_9846_session_STAR_$$),$APP.$cljs$cst$2332$session_id$$,$APP.$app$config$session_id$$),$APP.$cljs$cst$2333$external_session_id$$,$APP.$app$config$external_session_id$$());var $JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,
"externalContextInfo");$JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$=$APP.$cljs$core$fn_QMARK_$$($JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$)?$JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$.$cljs$core$IFn$_invoke$arity$0$?$JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$.$cljs$core$IFn$_invoke$arity$0$():
$JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$():null;$JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$=$APP.$app$common$json$__GT_clj$$($JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$);$JSCompiler_inline_result$jscomp$11070_context$jscomp$inline_13897$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$11070_context$jscomp$inline_13897$$,
$JSCompiler_inline_result$jscomp$inline_13898_external_context_info$jscomp$inline_13900_f$jscomp$inline_13899$$]));$JSCompiler_temp_const$jscomp$11068_context$jscomp$27$$=$JSCompiler_temp_const$jscomp$11068_context$jscomp$27$$.call($APP.$app$common$data$without_nils$$,$JSCompiler_inline_result$jscomp$11070_context$jscomp$inline_13897$$);$APP.$cljs$core$reset_BANG_$$($session$$,$or__5025__auto__$jscomp$inline_9846_session_STAR_$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$68$$,
$APP.$cljs$cst$2334$timestamp$$,$APP.$app$common$time$now$$()),$APP.$cljs$cst$2312$context$$,$JSCompiler_temp_const$jscomp$11068_context$jscomp$27$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$cst$2313$profile_id$$,$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$event$make_event$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$stream$jscomp$17$$)),$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$map$$($app$main$data$event$make_performance_event$$,
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$app$main$data$event$user_input_observer$$()))),$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$map$$($app$main$data$event$make_performance_event$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$app$main$data$event$longtask_observer$$()))),typeof globalThis!=="undefined"&&globalThis.requestAnimationFrame!=null&&globalThis.scheduler!=null&&globalThis.scheduler.postTask!=
null?$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$merge_map$$($app$main$data$event$process_performance_event$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$stream$jscomp$17$$))):$APP.$beicon$v2$core$empty$$())))))))},function($cause$jscomp$39$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unexpected error during event collection initialization"],null)],null)}),$cause$jscomp$39$$,"app.main.data.event",$APP.$cljs$cst$1162$warn$$,!1);return null},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($flags$jscomp$16$$){if($APP.$cljs$core$contains_QMARK_$$($flags$jscomp$16$$,$APP.$cljs$cst$1199$audit_log$$)||
$APP.$cljs$core$contains_QMARK_$$($flags$jscomp$16$$,$APP.$cljs$cst$1230$telemetry$$))return $APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event collection enabled"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1467$flags$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$flags$jscomp$16$$))],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1),(0,$APP.$beicon$v2$core$of$$)(!0);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event collection disabled (no audit-log or telemetry flag)"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$40$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unable to fetch backend flags, proceeding with event collection"],null)],null)}),$cause$jscomp$40$$,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1230$telemetry$$,null],null),null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2335$get_enabled_flags$$)))))});return new $app$main$data$event$initialize_50642$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$team$team_initialized$$=function($team_id$jscomp$35$$){typeof $app$main$data$team$team_initialized_55433$$==="undefined"&&($app$main$data$team$team_initialized_55433$$=function($team_id$jscomp$36$$,
$meta55434$$){this.$team_id$=$team_id$jscomp$36$$;this.$meta55434$=$meta55434$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$team_initialized_55433$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_initialized_55433$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3271$app_DOT_main_DOT_data_DOT_team_SLASH_team_initialized$$},$app$main$data$team$team_initialized_55433$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55435$$,$meta55434__$1$$){return new $app$main$data$team$team_initialized_55433$$(this.$team_id$,$meta55434__$1$$)},$app$main$data$team$team_initialized_55433$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55434$},$app$main$data$team$team_initialized_55433$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_initialized_55433$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$,
$state$jscomp$213$$){$_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$213$$,$APP.$cljs$cst$2173$teams$$);$_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$,this.$team_id$);if($APP.$cljs$core$not$$($_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$))return $APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("authentication",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3157$authentication$$],null),null])),null));var $permissions$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$,$APP.$cljs$cst$1722$permissions$$);$_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$,$APP.$cljs$cst$227$features$$);return(0,$APP.$beicon$v2$core$of$$)(function($p1__55432_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55432_SHARP_$$,$APP.$cljs$cst$1722$permissions$$,$permissions$jscomp$5$$)},$APP.$app$main$features$initialize$$($_$jscomp$1705_features__$1$jscomp$12_team$jscomp$4_teams$jscomp$3$$),$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$team_id$))},
$app$main$data$team$team_initialized_55433$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_initialized_55433$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$,this.$team_id$)});return new $app$main$data$team$team_initialized_55433$$($team_id$jscomp$35$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$team$initialize_team$$=function($team_id$jscomp$37$$){typeof $app$main$data$team$initialize_team_55441$$==="undefined"&&($app$main$data$team$initialize_team_55441$$=function($team_id$jscomp$38$$,$meta55442$$){this.$team_id$=$team_id$jscomp$38$$;this.$meta55442$=$meta55442$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$initialize_team_55441$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$initialize_team_55441$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3272$app_DOT_main_DOT_data_DOT_team_SLASH_initialize_team$$},$app$main$data$team$initialize_team_55441$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55443$$,$meta55442__$1$$){return new $app$main$data$team$initialize_team_55441$$(this.$team_id$,$meta55442__$1$$)},$app$main$data$team$initialize_team_55441$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55442$},$app$main$data$team$initialize_team_55441$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$initialize_team_55441$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1707$$,$state$jscomp$214$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$214$$,$APP.$cljs$cst$1926$current_team_id$$,this.$team_id$)},$app$main$data$team$initialize_team_55441$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$initialize_team_55441$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1708_stopper$jscomp$4$$,$___$1$jscomp$1043$$,$stream$jscomp$31$$){$_$jscomp$1708_stopper$jscomp$4$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3273$app_DOT_main_DOT_data_DOT_team_SLASH_finalize_team$$),$stream$jscomp$31$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$1708_stopper$jscomp$4$$,
$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$()),$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$team_initialized$$,this.$team_id$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3255$app_DOT_main_DOT_data_DOT_team_SLASH_teams_fetched$$),$stream$jscomp$31$$))))});return new $app$main$data$team$initialize_team_55441$$($team_id$jscomp$37$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$plugins$utils$error_messages$$=function($explain$jscomp$3$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(". ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__55440_map__55440__$1_message$jscomp$93_p__55436$$){var $field$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__55440_map__55440__$1_message$jscomp$93_p__55436$$,0,null);$map__55440_map__55440__$1_message$jscomp$93_p__55436$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__55440_map__55440__$1_message$jscomp$93_p__55436$$,
1,null);$map__55440_map__55440__$1_message$jscomp$93_p__55436$$=$APP.$cljs$core$__destructure_map$$($map__55440_map__55440__$1_message$jscomp$93_p__55436$$);$map__55440_map__55440__$1_message$jscomp$93_p__55436$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55440_map__55440__$1_message$jscomp$93_p__55436$$,$APP.$cljs$cst$141$message$$);return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("plugins.validation.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$name$$($field$jscomp$1$$),
$map__55440_map__55440__$1_message$jscomp$93_p__55436$$]))},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$core$val$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$schema$messages$interpret_schema_problem$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($explain$jscomp$3$$))]))))},
$app$plugins$utils$handle_error$$=function($plugin_id$jscomp$7$$){return function($cause$jscomp$71$$){var $message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$=$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$71$$));$APP.$cljs$core$truth_$$($message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$)?(console.error($APP.$app$common$schema$humanize_explain$$($message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$)),
$message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$=$app$plugins$utils$error_messages$$($message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$)):$message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$=$APP.$cljs$core$ex_data$$($cause$jscomp$71$$);console.log($cause$jscomp$71$$.stack);return $app$plugins$utils$not_valid$$($plugin_id$jscomp$7$$,$APP.$cljs$cst$849$error$$,$message$jscomp$94_temp__5823__auto__$jscomp$inline_9848$$)}},$app$common$files$tokens$convert_dtcg_token$$=function($description$jscomp$15_token_attrs$jscomp$3$$){var $name$jscomp$366$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"name"),$type$jscomp$546_value__$1$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"type"),$value$jscomp$626$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"value");$description$jscomp$15_token_attrs$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,
"description");var $type__$1$jscomp$8$$=$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$546_value__$1$jscomp$21$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($type$jscomp$546_value__$1$jscomp$21$$);$type$jscomp$546_value__$1$jscomp$21$$=function(){switch($type__$1$jscomp$8$$ instanceof $APP.$cljs$core$Keyword$$?$type__$1$jscomp$8$$.$fqn$:
null){case "font-family":return $APP.$app$common$types$tokens_lib$convert_dtcg_font_family$$($value$jscomp$626$$);case "typography":return $APP.$app$common$types$tokens_lib$convert_dtcg_typography_composite$$($value$jscomp$626$$);case "shadow":return $APP.$app$common$types$tokens_lib$convert_dtcg_shadow_composite$$($value$jscomp$626$$);default:return $value$jscomp$626$$}}();return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,
[$APP.$cljs$cst$725$name$$,$name$jscomp$366$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$8$$,$APP.$cljs$cst$260$value$$,$type$jscomp$546_value__$1$jscomp$21$$,$APP.$cljs$cst$936$description$$,$description$jscomp$15_token_attrs$jscomp$3$$],null))},$app$main$ui$static$0$login_modal_STAR_$$=function(){var $current_section$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1172$login$$),$user_email$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$register_token$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$set_section$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$284_section$jscomp$24$$){$event$jscomp$284_section$jscomp$24$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$284_section$jscomp$24$$),"section"));return $APP.$cljs$core$reset_BANG_$$($current_section$$,$event$jscomp$284_section$jscomp$24$$)}),
$set_section_recovery$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$5407$recovery_request$$)}),$set_section_login$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$1172$login$$)}),$success_login$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$reload$$())}),
$success_register$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$461$$){$APP.$cljs$core$reset_BANG_$$($register_token$$,$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$461$$));return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$5408$register_validate$$)}),$register_email_sent$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($email$jscomp$18$$){$APP.$cljs$core$reset_BANG_$$($user_email$$,$email$jscomp$18$$);
return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$5409$register_email_sent$$)}),$recovery_email_sent$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($email$jscomp$19$$){$APP.$cljs$core$reset_BANG_$$($user_email$$,$email$jscomp$19$$);return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$5410$recovery_email_sent$$)}),$on_nav_root$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$navigate$$($APP.$cljs$cst$3356$auth_login$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__dialog-login",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__modal-close",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_nav_root$jscomp$1$$,className:"main_ui_static__modal-close-button",children:$APP.$app$main$ui$icons$close$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__login",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo",children:$APP.$app$main$ui$icons$logo$$}),function(){var $G__75791_G__75791__$1$$=$APP.$cljs$core$_deref$$($current_section$$);$G__75791_G__75791__$1$$=$G__75791_G__75791__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75791_G__75791__$1$$.$fqn$:null;switch($G__75791_G__75791__$1$$){case "login":return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.login")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.free")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$login$login_dialog_STAR_$$,{onRecoveryRequest:$set_section_recovery$$,onSuccessCallback:$success_login$$,handleRedirect:!0}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_static__separator"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_static__change-section",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register")," ",(0,$APP.$rumext$v2$jsx$$)("a",{"data-section":"register",onClick:$set_section$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register-submit")})]})]});case "register":return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.signup-free")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.start-using")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_methods_STAR_$$,{onSuccessCallback:$success_register$$,hideSeparator:!0}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__separator"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__change-section",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.already-have-account"),
" ",(0,$APP.$rumext$v2$jsx$$)("a",{"data-section":"login",onClick:$set_section$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-here")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__links",children:[(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_static__separator"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$terms_register_STAR_$$,{})]})]});case "register-validate":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__form-container",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_form_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$_deref$$($register_token$$)],null),onSuccessCallback:$register_email_sent$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__links",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__register",children:(0,$APP.$rumext$v2$jsx$$)("a",{"data-section":"register",onClick:$set_section$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.go-back")})})})]});
case "register-email-sent":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__form-container",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_success_page_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$core$_deref$$($user_email$$),$APP.$cljs$cst$5411$hide_logo$$,!0],null)})});case "recovery-request":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$recovery_request$recovery_request_page$$,{"go-back-callback":$set_section_login$$,
"on-success-callback":$recovery_email_sent$$});case "recovery-email-sent":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__form-container",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth$recovery_request$recovery_sent_page$$,{email:$APP.$cljs$core$_deref$$($user_email$$)})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75791_G__75791__$1$$)].join(""));}}()]})]})})},$app$common$files$tokens$make_token_theme_schema$$=function($tokens_lib$jscomp$14$$,
$group$jscomp$42$$,$name$jscomp$370$$){return $APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$schema_COLON_token_theme_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1608$group$$,$APP.$app$common$files$tokens$make_token_theme_group_schema$$($tokens_lib$jscomp$14$$,
$name$jscomp$370$$,null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$app$common$files$tokens$make_token_theme_name_schema$$($tokens_lib$jscomp$14$$,$group$jscomp$42$$,null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_theme_description$$],
null)],null)]))},$app$common$files$tokens$make_token_set_schema$$=function($tokens_lib$jscomp$11$$){return $APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$app$common$files$tokens$make_token_set_name_schema$$($tokens_lib$jscomp$11$$,null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($p1__71694_SHARP_$$){return $APP.$app$common$types$tokens_lib$normalized_set_name_QMARK_$$($p1__71694_SHARP_$$)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_set_description$$],null)],null)]))},$app$common$logic$tokens$generate_set_active_token_theme$$=function($changes$jscomp$286$$,$tokens_lib$jscomp$19$$,$id$jscomp$771$$,$active_QMARK_$$){return $APP.$cljs$core$truth_$$($active_QMARK_$$)?$APP.$app$common$logic$tokens$generate_update_active_token_theme$$($changes$jscomp$286$$,
$tokens_lib$jscomp$19$$,function($p1__71909_SHARP_$$){return $APP.$app$common$types$tokens_lib$activate_theme$$($p1__71909_SHARP_$$,$id$jscomp$771$$)}):$APP.$app$common$logic$tokens$generate_update_active_token_theme$$($changes$jscomp$286$$,$tokens_lib$jscomp$19$$,function($p1__71910_SHARP_$$){return $app$common$types$tokens_lib$deactivate_theme$$($p1__71910_SHARP_$$,$id$jscomp$771$$)})},$app$common$logic$tokens$generate_set_enabled_token_set$$=function($changes$jscomp$283$$,$tokens_lib$jscomp$16$$,
$set_name$jscomp$27$$,$enabled_QMARK_$jscomp$3$$){return $APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$3$$)?$APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$283$$,$tokens_lib$jscomp$16$$,function($p1__71899_SHARP_$$){return $app$common$types$tokens_lib$enable_set$$($p1__71899_SHARP_$$,$set_name$jscomp$27$$)}):$APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$283$$,$tokens_lib$jscomp$16$$,function($p1__71900_SHARP_$$){return $app$common$types$tokens_lib$disable_set$$($p1__71900_SHARP_$$,
$set_name$jscomp$27$$)})},$app$common$files$changes_builder$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$=function($changes$jscomp$33$$,$type$jscomp$426$$,$id$jscomp$351$$,$page_id$jscomp$59$$,$namespace$jscomp$13$$,$key$jscomp$367$$,$value$jscomp$521$$){var $data$jscomp$265$$=$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$33$$)),$old_val$jscomp$1$$=function(){var $G__54047__$1$$=$type$jscomp$426$$ instanceof
$APP.$cljs$core$Keyword$$?$type$jscomp$426$$.$fqn$:null;switch($G__54047__$1$$){case "file":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$1738$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$367$$);case "page":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,
$APP.$cljs$cst$1630$pages_index$$),$id$jscomp$351$$),$APP.$cljs$cst$873$options$$),$APP.$cljs$cst$1738$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$367$$);case "shape":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,
$APP.$cljs$cst$1630$pages_index$$),$page_id$jscomp$59$$),$APP.$cljs$cst$1631$objects$$),$id$jscomp$351$$),$APP.$cljs$cst$1738$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$367$$);case "color":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$2212$colors$$),
$id$jscomp$351$$),$APP.$cljs$cst$1738$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$367$$);case "typography":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$2215$typographies$$),$id$jscomp$351$$),$APP.$cljs$cst$1738$plugin_data$$),$namespace$jscomp$13$$),
$key$jscomp$367$$);case "component":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$1638$components$$),$id$jscomp$351$$),$APP.$cljs$cst$1738$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$367$$);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__54047__$1$$)].join(""));}}(),$redo_change$$=function(){var $G__54054_G__54054__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2606$set_plugin_data$$,$APP.$cljs$cst$2607$object_type$$,$type$jscomp$426$$,$APP.$cljs$cst$394$namespace$$,$namespace$jscomp$13$$,$APP.$cljs$cst$302$key$$,$key$jscomp$367$$,$APP.$cljs$cst$260$value$$,$value$jscomp$521$$],null);$G__54054_G__54054__$1$$=$APP.$cljs$core$uuid_QMARK_$$($id$jscomp$351$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54054_G__54054__$1$$,$APP.$cljs$cst$2272$object_id$$,$id$jscomp$351$$):$G__54054_G__54054__$1$$;return $APP.$cljs$core$uuid_QMARK_$$($page_id$jscomp$59$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54054_G__54054__$1$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$59$$):$G__54054_G__54054__$1$$}(),$undo_change$$=function(){var $G__54055_G__54055__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2606$set_plugin_data$$,$APP.$cljs$cst$2607$object_type$$,$type$jscomp$426$$,$APP.$cljs$cst$394$namespace$$,$namespace$jscomp$13$$,$APP.$cljs$cst$302$key$$,$key$jscomp$367$$,$APP.$cljs$cst$260$value$$,$old_val$jscomp$1$$],null);$G__54055_G__54055__$1$$=$APP.$cljs$core$uuid_QMARK_$$($id$jscomp$351$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54055_G__54055__$1$$,$APP.$cljs$cst$2272$object_id$$,$id$jscomp$351$$):$G__54055_G__54055__$1$$;return $APP.$cljs$core$uuid_QMARK_$$($page_id$jscomp$59$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54055_G__54055__$1$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$59$$):$G__54055_G__54055__$1$$}();return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$33$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$redo_change$$),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$undo_change$$))},
$app$main$data$workspace$reorder_children$$=function($file_id$jscomp$279$$,$page_id$jscomp$272$$,$parent_id$jscomp$95$$,$children$jscomp$252$$){typeof $app$main$data$workspace$reorder_children_71788$$==="undefined"&&($app$main$data$workspace$reorder_children_71788$$=function($file_id$jscomp$280$$,$page_id$jscomp$273$$,$parent_id$jscomp$96$$,$children$jscomp$253$$,$meta71789$$){this.$file_id$=$file_id$jscomp$280$$;this.$page_id$=$page_id$jscomp$273$$;this.$parent_id$=$parent_id$jscomp$96$$;this.children=
$children$jscomp$253$$;this.$meta71789$=$meta71789$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$reorder_children_71788$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$reorder_children_71788$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4483$app_DOT_main_DOT_data_DOT_workspace_SLASH_reorder_children$$},$app$main$data$workspace$reorder_children_71788$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71790$$,$meta71789__$1$$){return new $app$main$data$workspace$reorder_children_71788$$(this.$file_id$,this.$page_id$,this.$parent_id$,this.children,$meta71789__$1$$)},$app$main$data$workspace$reorder_children_71788$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71789$},$app$main$data$workspace$reorder_children_71788$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$reorder_children_71788$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$277_it$jscomp$246_page_id__$1$jscomp$17$$,$state$jscomp$897$$){var $self__$jscomp$6264$$=this,$file_id__$1$jscomp$8_undo_id$jscomp$83$$=function(){var $or__5025__auto__$jscomp$853$$=$self__$jscomp$6264$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$853$$)?$or__5025__auto__$jscomp$853$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$897$$)}();$changes$jscomp$277_it$jscomp$246_page_id__$1$jscomp$17$$=function(){var $or__5025__auto__$jscomp$854$$=
$self__$jscomp$6264$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$854$$)?$or__5025__auto__$jscomp$854$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$897$$)}();var $objects$jscomp$660$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$897$$,$file_id__$1$jscomp$8_undo_id$jscomp$83$$,$changes$jscomp$277_it$jscomp$246_page_id__$1$jscomp$17$$);$file_id__$1$jscomp$8_undo_id$jscomp$83$$=Symbol();
$changes$jscomp$277_it$jscomp$246_page_id__$1$jscomp$17$$=$APP.$app$common$files$changes_builder$reorder_children$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$277_it$jscomp$246_page_id__$1$jscomp$17$$),$objects$jscomp$660$$),$self__$jscomp$6264$$.$parent_id$,$self__$jscomp$6264$$.children);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($file_id__$1$jscomp$8_undo_id$jscomp$83$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$277_it$jscomp$246_page_id__$1$jscomp$17$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6264$$.$parent_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($file_id__$1$jscomp$8_undo_id$jscomp$83$$))});
return new $app$main$data$workspace$reorder_children_71788$$($file_id$jscomp$279$$,$page_id$jscomp$272$$,$parent_id$jscomp$95$$,$children$jscomp$252$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$set_shape_index$$=function($file_id$jscomp$277$$,$page_id$jscomp$270$$,$id$jscomp$750$$,$new_index$jscomp$4$$){typeof $app$main$data$workspace$set_shape_index_71783$$==="undefined"&&($app$main$data$workspace$set_shape_index_71783$$=function($file_id$jscomp$278$$,$page_id$jscomp$271$$,
$id$jscomp$751$$,$new_index$jscomp$5$$,$meta71784$$){this.$file_id$=$file_id$jscomp$278$$;this.$page_id$=$page_id$jscomp$271$$;this.id=$id$jscomp$751$$;this.$new_index$=$new_index$jscomp$5$$;this.$meta71784$=$meta71784$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_shape_index_71783$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_index_71783$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4482$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_shape_index$$},$app$main$data$workspace$set_shape_index_71783$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71785$$,$meta71784__$1$$){return new $app$main$data$workspace$set_shape_index_71783$$(this.$file_id$,this.$page_id$,this.id,this.$new_index$,$meta71784__$1$$)},$app$main$data$workspace$set_shape_index_71783$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71784$},$app$main$data$workspace$set_shape_index_71783$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_index_71783$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$276_it$jscomp$245_page_id__$1$jscomp$16$$,$state$jscomp$896$$){var $self__$jscomp$6260$$=this,$file_id__$1$jscomp$7_undo_id$jscomp$82$$=function(){var $or__5025__auto__$jscomp$851$$=$self__$jscomp$6260$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$851$$)?$or__5025__auto__$jscomp$851$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$896$$)}();
$changes$jscomp$276_it$jscomp$245_page_id__$1$jscomp$16$$=function(){var $or__5025__auto__$jscomp$852$$=$self__$jscomp$6260$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$852$$)?$or__5025__auto__$jscomp$852$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$896$$)}();var $objects$jscomp$659$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$896$$,$file_id__$1$jscomp$7_undo_id$jscomp$82$$,$changes$jscomp$276_it$jscomp$245_page_id__$1$jscomp$16$$);
$file_id__$1$jscomp$7_undo_id$jscomp$82$$=Symbol();var $shape$jscomp$755$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$659$$,$self__$jscomp$6260$$.id),$parent$jscomp$283$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$659$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$755$$)),$current_index$jscomp$4_new_index__$1$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$283$$),
$self__$jscomp$6260$$.id);$current_index$jscomp$4_new_index__$1$$=$self__$jscomp$6260$$.$new_index$>$current_index$jscomp$4_new_index__$1$$?$self__$jscomp$6260$$.$new_index$+1:$self__$jscomp$6260$$.$new_index$;$changes$jscomp$276_it$jscomp$245_page_id__$1$jscomp$16$$=$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$276_it$jscomp$245_page_id__$1$jscomp$16$$),$objects$jscomp$659$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$283$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$755$$],null),$current_index$jscomp$4_new_index__$1$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($file_id__$1$jscomp$7_undo_id$jscomp$82$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$276_it$jscomp$245_page_id__$1$jscomp$16$$),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6260$$.id],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($file_id__$1$jscomp$7_undo_id$jscomp$82$$))});return new $app$main$data$workspace$set_shape_index_71783$$($file_id$jscomp$277$$,
$page_id$jscomp$270$$,$id$jscomp$750$$,$new_index$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$libraries$update_color_data$$=function($color$jscomp$64_color__$1$jscomp$6$$,$file_id$jscomp$133$$){$color$jscomp$64_color__$1$jscomp$6$$=(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$64_color__$1$jscomp$6$$));typeof $app$main$data$workspace$libraries$update_color_data_69451$$===
"undefined"&&($app$main$data$workspace$libraries$update_color_data_69451$$=function($color$jscomp$65$$,$file_id$jscomp$134$$,$meta69452$$){this.color=$color$jscomp$65$$;this.$file_id$=$file_id$jscomp$134$$;this.$meta69452$=$meta69452$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_color_data_69451$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_color_data_69451$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3907$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_color_data$$},$app$main$data$workspace$libraries$update_color_data_69451$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69453$$,$meta69452__$1$$){return new $app$main$data$workspace$libraries$update_color_data_69451$$(this.color,this.$file_id$,$meta69452__$1$$)},$app$main$data$workspace$libraries$update_color_data_69451$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69452$},
$app$main$data$workspace$libraries$update_color_data_69451$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_color_data_69451$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($color__$1$jscomp$7_it$jscomp$177$$,$state$jscomp$489$$){$color__$1$jscomp$7_it$jscomp$177$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.color,$APP.$cljs$cst$725$name$$,""+($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$(this.color)??
"")+"/"+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.color)??""));return $APP.$app$main$data$workspace$libraries$update_color_STAR_$$(this,$state$jscomp$489$$,$color__$1$jscomp$7_it$jscomp$177$$,this.$file_id$)});return new $app$main$data$workspace$libraries$update_color_data_69451$$($color$jscomp$64_color__$1$jscomp$6$$,$file_id$jscomp$133$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$groups$ungroup_shapes$$=function($var_args$jscomp$1224$$){for(var $args__5755__auto__$jscomp$225$$=
[],$len__5749__auto___67610$$=arguments.length,$i__5750__auto___67611$$=0;;)if($i__5750__auto___67611$$<$len__5749__auto___67610$$)$args__5755__auto__$jscomp$225$$.push(arguments[$i__5750__auto___67611$$]),$i__5750__auto___67611$$+=1;else break;return $APP.$app$main$data$workspace$groups$ungroup_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$225$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$225$$.slice(1),0,null):null)},$app$main$data$workspace$groups$group_shapes$$=
function($var_args$jscomp$1223$$){for(var $args__5755__auto__$jscomp$224$$=[],$len__5749__auto___67602$$=arguments.length,$i__5750__auto___67603$$=0;;)if($i__5750__auto___67603$$<$len__5749__auto___67602$$)$args__5755__auto__$jscomp$224$$.push(arguments[$i__5750__auto___67603$$]),$i__5750__auto___67603$$+=1;else break;return $APP.$app$main$data$workspace$groups$group_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$224$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$224$$.slice(2),
0,null):null)},$app$main$data$workspace$media$create_svg_shape_with_images$$=function($file_id$jscomp$109$$,$id$jscomp$518$$,$svg_string$jscomp$2$$,$position$jscomp$82$$,$on_success$jscomp$29$$,$on_error$jscomp$31$$){typeof $app$main$data$workspace$media$create_svg_shape_with_images_67808$$==="undefined"&&($app$main$data$workspace$media$create_svg_shape_with_images_67808$$=function($file_id$jscomp$110$$,$id$jscomp$519$$,$name$jscomp$319$$,$svg_string$jscomp$3$$,$position$jscomp$83$$,$on_success$jscomp$30$$,
$on_error$jscomp$32$$,$meta67809$$){this.$file_id$=$file_id$jscomp$110$$;this.id=$id$jscomp$519$$;this.name=$name$jscomp$319$$;this.$svg_string$=$svg_string$jscomp$3$$;this.position=$position$jscomp$83$$;this.$on_success$=$on_success$jscomp$30$$;this.$on_error$=$on_error$jscomp$32$$;this.$meta67809$=$meta67809$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$create_svg_shape_with_images_67808$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_with_images_67808$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3713$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_create_svg_shape_with_images$$},$app$main$data$workspace$media$create_svg_shape_with_images_67808$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67810$$,$meta67809__$1$$){return new $app$main$data$workspace$media$create_svg_shape_with_images_67808$$(this.$file_id$,
this.id,this.name,this.$svg_string$,this.position,this.$on_success$,this.$on_error$,$meta67809__$1$$)},$app$main$data$workspace$media$create_svg_shape_with_images_67808$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67809$},$app$main$data$workspace$media$create_svg_shape_with_images_67808$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_with_images_67808$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$4428$$=this;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4428$$.$on_error$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4428$$.$on_success$,$APP.$beicon$v2$core$map$$(function($svg_data$jscomp$23$$){return $APP.$app$main$data$workspace$svg_upload$add_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4428$$.id,$svg_data$jscomp$23$$,$self__$jscomp$4428$$.position,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3683$ignore_selection_QMARK_$$,!0,$APP.$cljs$cst$3617$change_selection_QMARK_$$,!1],null))},$APP.$beicon$v2$core$mapcat$$(function($svg_data$jscomp$24$$){return $APP.$beicon$v2$core$map$$(function($p1__67807_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($svg_data$jscomp$24$$,$APP.$cljs$cst$3673$image_data$$,$p1__67807_SHARP_$$)},$APP.$app$main$data$workspace$svg_upload$upload_images$$($svg_data$jscomp$24$$,$self__$jscomp$4428$$.$file_id$))},$APP.$beicon$v2$core$take$$($APP.$app$main$data$workspace$media$svg__GT_clj$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4428$$.name,$self__$jscomp$4428$$.$svg_string$],null)))))))});return new $app$main$data$workspace$media$create_svg_shape_with_images_67808$$($file_id$jscomp$109$$,$id$jscomp$518$$,"svg",$svg_string$jscomp$2$$,$position$jscomp$82$$,$on_success$jscomp$29$$,$on_error$jscomp$31$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$media$create_svg_shape$$=function($id$jscomp$516$$,$svg_string$$){var $position$jscomp$80$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);typeof $app$main$data$workspace$media$create_svg_shape_67804$$==="undefined"&&($app$main$data$workspace$media$create_svg_shape_67804$$=function($id$jscomp$517$$,$name$jscomp$317$$,$svg_string$jscomp$1$$,$position$jscomp$81$$,$meta67805$$){this.id=$id$jscomp$517$$;this.name=$name$jscomp$317$$;this.$svg_string$=$svg_string$jscomp$1$$;this.position=$position$jscomp$81$$;this.$meta67805$=$meta67805$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$create_svg_shape_67804$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_67804$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3712$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_create_svg_shape$$},$app$main$data$workspace$media$create_svg_shape_67804$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67806$$,
$meta67805__$1$$){return new $app$main$data$workspace$media$create_svg_shape_67804$$(this.id,this.name,this.$svg_string$,this.position,$meta67805__$1$$)},$app$main$data$workspace$media$create_svg_shape_67804$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67805$},$app$main$data$workspace$media$create_svg_shape_67804$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_67804$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$4424$$=this;return $APP.$beicon$v2$core$map$$(function($p1__67803_SHARP_$$){return $APP.$app$main$data$workspace$svg_upload$add_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4424$$.id,$p1__67803_SHARP_$$,$self__$jscomp$4424$$.position,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3683$ignore_selection_QMARK_$$,!0,$APP.$cljs$cst$3617$change_selection_QMARK_$$,!1],null))},$APP.$beicon$v2$core$take$$($APP.$app$main$data$workspace$media$svg__GT_clj$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4424$$.name,$self__$jscomp$4424$$.$svg_string$],null))))});return new $app$main$data$workspace$media$create_svg_shape_67804$$($id$jscomp$516$$,"svg",$svg_string$$,$position$jscomp$80$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$interactions$add_interaction$$=function($page_id$jscomp$213$$,$shape_id$jscomp$116$$,$interaction$jscomp$38$$){typeof $app$main$data$workspace$interactions$add_interaction_70453$$===
"undefined"&&($app$main$data$workspace$interactions$add_interaction_70453$$=function($page_id$jscomp$214$$,$shape_id$jscomp$117$$,$interaction$jscomp$39$$,$meta70454$$){this.$page_id$=$page_id$jscomp$214$$;this.$shape_id$=$shape_id$jscomp$117$$;this.interaction=$interaction$jscomp$39$$;this.$meta70454$=$meta70454$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_interaction_70453$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_interaction_70453$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4305$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_interaction$$},$app$main$data$workspace$interactions$add_interaction_70453$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70455$$,$meta70454__$1$$){return new $app$main$data$workspace$interactions$add_interaction_70453$$(this.$page_id$,this.$shape_id$,
this.interaction,$meta70454__$1$$)},$app$main$data$workspace$interactions$add_interaction_70453$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70454$},$app$main$data$workspace$interactions$add_interaction_70453$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_interaction_70453$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2392_page_id__$1$jscomp$11$$,$state$jscomp$768$$){var $self__$jscomp$5715$$=
this;$_$jscomp$2392_page_id__$1$jscomp$11$$=function(){var $or__5025__auto__$jscomp$830$$=$self__$jscomp$5715$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$830$$)?$or__5025__auto__$jscomp$830$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$768$$)}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$self__$jscomp$5715$$.$shape_id$],null),function($shape$jscomp$706$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$706$$,$APP.$cljs$cst$2051$interactions$$,$APP.$app$common$types$shape$interactions$add_interaction$$,$self__$jscomp$5715$$.interaction)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2392_page_id__$1$jscomp$11$$],null)),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5715$$.interaction))?
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5715$$.interaction)],null),$APP.$app$common$logic$shapes$show_in_viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2392_page_id__$1$jscomp$11$$],null)):null)});return new $app$main$data$workspace$interactions$add_interaction_70453$$($page_id$jscomp$213$$,
$shape_id$jscomp$116$$,$interaction$jscomp$38$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set$$=function($name$jscomp$371$$,$enabled_QMARK_$jscomp$4$$){typeof $app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$=function($name$jscomp$372$$,$enabled_QMARK_$jscomp$5$$,$meta72857$$){this.name=$name$jscomp$372$$;this.$enabled_QMARK_$=
$enabled_QMARK_$jscomp$5$$;this.$meta72857$=$meta72857$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4705$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_enabled_token_set$$},
$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72858$$,$meta72857__$1$$){return new $app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$(this.name,this.$enabled_QMARK_$,$meta72857__$1$$)},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72857$},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2663_data$jscomp$416$$,$changes$jscomp$301_state$jscomp$981_tlib$$){$_$jscomp$2663_data$jscomp$416$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$301_state$jscomp$981_tlib$$);$changes$jscomp$301_state$jscomp$981_tlib$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$301_state$jscomp$981_tlib$$);
$changes$jscomp$301_state$jscomp$981_tlib$$=$app$common$logic$tokens$generate_set_enabled_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$_$jscomp$2663_data$jscomp$416$$),$changes$jscomp$301_state$jscomp$981_tlib$$,this.name,this.$enabled_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$301_state$jscomp$981_tlib$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});
return new $app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$($name$jscomp$371$$,$enabled_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$tokens$library_edit$set_token_theme_active$$=function($id$jscomp$783$$,$active_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$=function($id$jscomp$784$$,
$active_QMARK_$jscomp$2$$,$meta72799$$){this.id=$id$jscomp$784$$;this.$active_QMARK_$=$active_QMARK_$jscomp$2$$;this.$meta72799$=$meta72799$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4698$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_token_theme_active$$},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72800$$,$meta72799__$1$$){return new $app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$(this.id,this.$active_QMARK_$,$meta72799__$1$$)},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72799$},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2656_data$jscomp$410$$,$changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$){$_$jscomp$2656_data$jscomp$410$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$);
$changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$);$changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$=$app$common$logic$tokens$generate_set_active_token_theme$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$_$jscomp$2656_data$jscomp$410$$),$changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$,
this.id,this.$active_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$294_state$jscomp$975_tokens_lib$jscomp$29$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$($id$jscomp$783$$,$active_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$texts$update_text_range$$=function($id$jscomp$612$$,
$start$jscomp$225$$,$end$jscomp$91$$,$attrs$jscomp$123$$){typeof $app$main$data$workspace$texts$update_text_range_70135$$==="undefined"&&($app$main$data$workspace$texts$update_text_range_70135$$=function($id$jscomp$613$$,$start$jscomp$226$$,$end$jscomp$92$$,$attrs$jscomp$124$$,$meta70136$$){this.id=$id$jscomp$613$$;this.start=$start$jscomp$226$$;this.end=$end$jscomp$92$$;this.$attrs$=$attrs$jscomp$124$$;this.$meta70136$=$meta70136$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$update_text_range_70135$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_range_70135$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4012$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_range$$},$app$main$data$workspace$texts$update_text_range_70135$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70137$$,$meta70136__$1$$){return new $app$main$data$workspace$texts$update_text_range_70135$$(this.id,
this.start,this.end,this.$attrs$,$meta70136__$1$$)},$app$main$data$workspace$texts$update_text_range_70135$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70136$},$app$main$data$workspace$texts$update_text_range_70135$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_range_70135$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2167_objects$jscomp$511_shape_ids$jscomp$5$$,$state$jscomp$566$$){var $self__$jscomp$4972$$=
this;$_$jscomp$2167_objects$jscomp$511_shape_ids$jscomp$5$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$566$$);var $shape$jscomp$578$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2167_objects$jscomp$511_shape_ids$jscomp$5$$,$self__$jscomp$4972$$.id);$_$jscomp$2167_objects$jscomp$511_shape_ids$jscomp$5$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$578$$)?new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4972$$.id],null):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$578$$)?$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2167_objects$jscomp$511_shape_ids$jscomp$5$$,$self__$jscomp$4972$$.id):null;return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2167_objects$jscomp$511_shape_ids$jscomp$5$$,
function($JSCompiler_temp$jscomp$2063_shape__$1$jscomp$42$$){if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2063_shape__$1$jscomp$42$$)){var $new_content$jscomp$inline_9854_start$jscomp$inline_9851$$=$self__$jscomp$4972$$.start,$end$jscomp$inline_9852$$=$self__$jscomp$4972$$.end,$attrs$jscomp$inline_9853$$=$self__$jscomp$4972$$.$attrs$;$new_content$jscomp$inline_9854_start$jscomp$inline_9851$$=$app$main$data$workspace$texts$update_content_range$$($app$main$data$workspace$texts$split_content_at$$($app$main$data$workspace$texts$split_content_at$$($app$main$data$workspace$texts$decorate_range_info$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2063_shape__$1$jscomp$42$$)),
$new_content$jscomp$inline_9854_start$jscomp$inline_9851$$),$end$jscomp$inline_9852$$),$new_content$jscomp$inline_9854_start$jscomp$inline_9851$$,$end$jscomp$inline_9852$$,$attrs$jscomp$inline_9853$$);$JSCompiler_temp$jscomp$2063_shape__$1$jscomp$42$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2063_shape__$1$jscomp$42$$,$APP.$cljs$cst$1637$content$$,$new_content$jscomp$inline_9854_start$jscomp$inline_9851$$)}return $JSCompiler_temp$jscomp$2063_shape__$1$jscomp$42$$})),
$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$566$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4972$$.id)):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$texts$update_text_range_70135$$($id$jscomp$612$$,$start$jscomp$225$$,$end$jscomp$91$$,$attrs$jscomp$123$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$=
function($file_id$jscomp$67$$,$type$jscomp$440$$,$id$jscomp$417$$,$page_id$jscomp$84$$,$namespace$jscomp$16$$,$key$jscomp$374$$,$value$jscomp$534$$){typeof $app$main$data$plugins$set_file_plugin_data_66358$$==="undefined"&&($app$main$data$plugins$set_file_plugin_data_66358$$=function($file_id$jscomp$68$$,$type$jscomp$441$$,$id$jscomp$418$$,$page_id$jscomp$85$$,$namespace$jscomp$17$$,$key$jscomp$375$$,$value$jscomp$535$$,$meta66359$$){this.$file_id$=$file_id$jscomp$68$$;this.type=$type$jscomp$441$$;
this.id=$id$jscomp$418$$;this.$page_id$=$page_id$jscomp$85$$;this.$namespace$=$namespace$jscomp$17$$;this.key=$key$jscomp$375$$;this.value=$value$jscomp$535$$;this.$meta66359$=$meta66359$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$set_file_plugin_data_66358$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$set_file_plugin_data_66358$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3411$app_DOT_main_DOT_data_DOT_plugins_SLASH_set_file_plugin_data$$},$app$main$data$plugins$set_file_plugin_data_66358$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66360$$,$meta66359__$1$$){return new $app$main$data$plugins$set_file_plugin_data_66358$$(this.$file_id$,this.type,this.id,this.$page_id$,this.$namespace$,this.key,this.value,$meta66359__$1$$)},$app$main$data$plugins$set_file_plugin_data_66358$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66359$},$app$main$data$plugins$set_file_plugin_data_66358$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$set_file_plugin_data_66358$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$,$state$jscomp$251$$){$changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$251$$,
$APP.$cljs$cst$1916$files$$),this.$file_id$),$APP.$cljs$cst$142$data$$);$changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$=$app$common$files$changes_builder$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$),$APP.$cljs$cst$1644$file_id$$,
this.$file_id$),this.type,this.id,this.$page_id$,this.$namespace$,this.key,this.value);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$))});return new $app$main$data$plugins$set_file_plugin_data_66358$$($file_id$jscomp$67$$,$type$jscomp$440$$,$id$jscomp$417$$,$page_id$jscomp$84$$,$namespace$jscomp$16$$,$key$jscomp$374$$,$value$jscomp$534$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$=
function($file_id$jscomp$66$$,$type$jscomp$439$$,$id$jscomp$416$$,$namespace$jscomp$15$$,$key$jscomp$373$$,$value$jscomp$533$$){return $app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$66$$,$type$jscomp$439$$,$id$jscomp$416$$,null,$namespace$jscomp$15$$,$key$jscomp$373$$,$value$jscomp$533$$)},$app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$=function($file_id$jscomp$65$$,$type$jscomp$438$$,$namespace$jscomp$14$$,$key$jscomp$372$$,
$value$jscomp$532$$){return $app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$65$$,$type$jscomp$438$$,null,null,$namespace$jscomp$14$$,$key$jscomp$372$$,$value$jscomp$532$$)},$app$main$data$workspace$versions$restore_version_from_plugin$$=function($file_id$jscomp$335$$,$id$jscomp$865$$,$resolve$jscomp$37$$,$reject$jscomp$26$$){typeof $app$main$data$workspace$versions$restore_version_from_plugins_73429$$==="undefined"&&($app$main$data$workspace$versions$restore_version_from_plugins_73429$$=
function($file_id$jscomp$336$$,$id$jscomp$866$$,$resolve$jscomp$38$$,$reject$jscomp$27$$,$meta73430$$){this.$file_id$=$file_id$jscomp$336$$;this.id=$id$jscomp$866$$;this.resolve=$resolve$jscomp$38$$;this.reject=$reject$jscomp$27$$;this.$meta73430$=$meta73430$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$restore_version_from_plugins_73429$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_from_plugins_73429$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5053$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_restore_version_from_plugins$$},$app$main$data$workspace$versions$restore_version_from_plugins_73429$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73431$$,$meta73430__$1$$){return new $app$main$data$workspace$versions$restore_version_from_plugins_73429$$(this.$file_id$,this.id,this.resolve,this.reject,$meta73430__$1$$)},$app$main$data$workspace$versions$restore_version_from_plugins_73429$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73430$},$app$main$data$workspace$versions$restore_version_from_plugins_73429$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_from_plugins_73429$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7054$$=this;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$82$$){$self__$jscomp$7054$$.reject.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$7054$$.reject.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$82$$):$self__$jscomp$7054$$.reject($error$jscomp$82$$);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-version",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugins"],null)),$APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$),
$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$versions$initialize_version$$()},$APP.$app$main$data$workspace$versions$wait_for_persistence$$($self__$jscomp$7054$$.$file_id$,$self__$jscomp$7054$$.id)),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7054$$.resolve,(0,$APP.$beicon$v2$core$of$$)(1)))))});return new $app$main$data$workspace$versions$restore_version_from_plugins_73429$$($file_id$jscomp$335$$,$id$jscomp$865$$,
$resolve$jscomp$37$$,$reject$jscomp$26$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$ui$static$0$context_wrapper_STAR_$$=function($props_75844$$){var $profile$jscomp$64$$=$props_75844$$.profile,$children$jscomp$291$$=$props_75844$$.children,$is_dashboard$$=$props_75844$$.isDashboard,$is_viewer$$=$props_75844$$.isViewer;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($props_75844$$.isWorkspace)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__workspace",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__workspace-left",children:[$APP.$app$main$ui$icons$logo_icon$$,(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__project-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project-name")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__file-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.penpot-file")})]})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__workspace-right"})]}):$APP.$cljs$core$truth_$$($is_viewer$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__viewer",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$viewer$header$header$$,{zoom:1,permissions:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5402$is_logged$$,!0],null),frame:null,index:0,section:$APP.$cljs$cst$2051$interactions$$,file:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.penpot-file")],null),"shown-thumbnails":!1,page:null,"interactions-mode":null,project:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project-name")],null)})}):$APP.$cljs$core$truth_$$($is_dashboard$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__dashboard",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_static__dashboard-sidebar",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$sidebar$sidebar_STAR_$$,{team:null,projects:$APP.$cljs$core$PersistentVector$EMPTY$$,project:$APP.$cljs$cst$2511$default_project_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$64$$),profile:$profile$jscomp$64$$,section:$APP.$cljs$cst$4897$dashboard_projects$$,searchTerm:""})})}):null,$children$jscomp$291$$]})},$app$main$ui$static$0$exception_section_STAR_$$=function($props_75833_props__$1$jscomp$70$$){var $data$jscomp$463$$=
$props_75833_props__$1$jscomp$70$$.data,$type$jscomp$603$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$463$$,$APP.$cljs$cst$139$type$$),$cause$jscomp$105$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$463$$,$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$),$report$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cause$jscomp$105$$)],function(){return $APP.$app$common$exceptions$exception_QMARK_$$($cause$jscomp$105$$)?
$APP.$app$main$errors$generate_report$$($cause$jscomp$105$$):null});$props_75833_props__$1$jscomp$70$$={...$props_75833_props__$1$jscomp$70$$,report:$report$jscomp$4$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($report$jscomp$4$$),$APP.$rumext$v2$adapt$$($type$jscomp$603$$),$APP.$rumext$v2$adapt$$($cause$jscomp$105$$)],function(){return $APP.$app$common$exceptions$exception_QMARK_$$($cause$jscomp$105$$)&&!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3157$authentication$$,null,$APP.$cljs$cst$2665$not_found$$,null],null),null),$type$jscomp$603$$)?$APP.$app$main$errors$submit_report$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2317$event_name$$,"exception-page",$APP.$cljs$cst$572$report$$,$report$jscomp$4$$,$APP.$cljs$cst$275$hint$$,$APP.$app$common$exceptions$get_hint$$($cause$jscomp$105$$)])):null});switch($type$jscomp$603$$ instanceof
$APP.$cljs$core$Keyword$$?$type$jscomp$603$$.$fqn$:null){case "not-found":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$not_found_STAR_$$,{});case "authentication":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$not_found_STAR_$$,{});case "bad-gateway":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$bad_gateway_STAR_$$,$props_75833_props__$1$jscomp$70$$);case "service-unavailable":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$service_unavailable_STAR_$$,{});
default:return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$internal_error_STAR_$$,$props_75833_props__$1$jscomp$70$$)}},$app$main$ui$static$0$exception_page_STAR_$$=function($props_75884$$){var $profile$jscomp$65_route$jscomp$19$$=$props_75884$$.route,$not_found_QMARK__type$jscomp$604$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($props_75884$$.data),$auth_error_QMARK__path$jscomp$257$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$65_route$jscomp$19$$),
$params$jscomp$416$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$65_route$jscomp$19$$),$workspace_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($auth_error_QMARK__path$jscomp$257$$,"workspace"),$dashboard_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($auth_error_QMARK__path$jscomp$257$$,"dashboard"),$view_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($auth_error_QMARK__path$jscomp$257$$,"view"),$info_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$info$jscomp$8$$=$APP.$cljs$core$_deref$$($info_STAR_$$);$profile$jscomp$65_route$jscomp$19$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$auth_error_QMARK__path$jscomp$257$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($not_found_QMARK__type$jscomp$604$$,$APP.$cljs$cst$3157$authentication$$);$not_found_QMARK__type$jscomp$604$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($not_found_QMARK__type$jscomp$604$$,$APP.$cljs$cst$2665$not_found$$);var $authenticated_QMARK_$$=
$APP.$app$main$data$auth$is_authenticated_QMARK_$$($profile$jscomp$65_route$jscomp$19$$),$initial_authenticated_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $authenticated_QMARK_$$}),$request_access_QMARK_$$=function(){var $and__5023__auto__$jscomp$683$$=$APP.$cljs$core$truth_$$($workspace_QMARK_$$)?$workspace_QMARK_$$:$APP.$cljs$core$truth_$$($dashboard_QMARK_$$)?$dashboard_QMARK_$$:$view_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$683$$)?
$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$)!=null||$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$)!=null:$and__5023__auto__$jscomp$683$$}();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$416$$),$APP.$rumext$v2$adapt$$($info$jscomp$8$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5024$loaded$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$))?null:$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,
$info_STAR_$$),$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$reset_BANG_$$,$info_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5024$loaded$$,!0],null)),$app$main$ui$static$0$load_info$$($params$jscomp$416$$))});return $auth_error_QMARK__path$jscomp$257$$||$not_found_QMARK__type$jscomp$604$$?$authenticated_QMARK_$$?$APP.$cljs$core$not$$($initial_authenticated_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0}):$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($info$jscomp$8$$,$APP.$cljs$cst$5024$loaded$$,!1))?$APP.$cljs$core$truth_$$($request_access_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$context_wrapper_STAR_$$,{isWorkspace:$workspace_QMARK_$$,isDashboard:$dashboard_QMARK_$$,isViewer:$view_QMARK_$$,profile:$profile$jscomp$65_route$jscomp$19$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_access_STAR_$$,
{fileId:$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$),teamId:$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$),isDefault:$APP.$cljs$cst$5418$team_default$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$),profile:$profile$jscomp$65_route$jscomp$19$$,isWorkspace:$workspace_QMARK_$$})}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$exception_section_STAR_$$,$props_75884$$):null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$context_wrapper_STAR_$$,
{isWorkspace:$workspace_QMARK_$$,isDashboard:$dashboard_QMARK_$$,isViewer:$view_QMARK_$$,profile:$profile$jscomp$65_route$jscomp$19$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$login_modal_STAR_$$,{})}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$exception_section_STAR_$$,$props_75884$$)},$app$common$types$objects_map$get_data$$=function($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$){if($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$!=null&&$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$.$app$common$types$objects_map$IObjectsMap$get_data$arity$1$!=
null)$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$=$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$.$app$common$types$objects_map$IObjectsMap$get_data$arity$1$($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$);else{var $m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$=$app$common$types$objects_map$get_data$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$==null?null:$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$)];if($m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$!=
null)$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$=$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$):$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$);else if($m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$=
$app$common$types$objects_map$get_data$$._,$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$!=null)$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$=$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$):$m__5372__auto__$jscomp$inline_9858_m__5374__auto__$jscomp$inline_9857$$($JSCompiler_temp$jscomp$2086_this$$jscomp$888$$);
else throw $APP.$cljs$core$missing_protocol$$("IObjectsMap.get-data",$JSCompiler_temp$jscomp$2086_this$$jscomp$888$$);}return $JSCompiler_temp$jscomp$2086_this$$jscomp$888$$},$app$common$types$objects_map$_hash_for_key$$=function($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$,$key$jscomp$429$$){if($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$!=null&&$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$.$app$common$types$objects_map$IObjectsMap$_hash_for_key$arity$2$!=null)$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$=
$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$.$app$common$types$objects_map$IObjectsMap$_hash_for_key$arity$2$($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$,$key$jscomp$429$$);else{var $m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$=$app$common$types$objects_map$_hash_for_key$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$==null?null:$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$)];if($m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$!=
null)$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$=$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$,$key$jscomp$429$$):$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$,$key$jscomp$429$$);else if($m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$=
$app$common$types$objects_map$_hash_for_key$$._,$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$!=null)$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$=$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$,$key$jscomp$429$$):$m__5372__auto__$jscomp$inline_9863_m__5374__auto__$jscomp$inline_9862$$($JSCompiler_temp$jscomp$2087_this$$jscomp$890$$,
$key$jscomp$429$$);else throw $APP.$cljs$core$missing_protocol$$("IObjectsMap.-hash-for-key",$JSCompiler_temp$jscomp$2087_this$$jscomp$890$$);}return $JSCompiler_temp$jscomp$2087_this$$jscomp$890$$},$app$common$types$objects_map$ObjectsMapEntry$$=function($key$jscomp$430$$,$omap$$){this.key=$key$jscomp$430$$;this.$omap$=$omap$$;this.$cljs$lang$protocol_mask$partition0$$=2178943251;this.$cljs$lang$protocol_mask$partition1$$=0},$app$common$types$objects_map$ObjectsMap$$=function($metadata$jscomp$9$$,
$cache$jscomp$107$$,$data$jscomp$520$$,$modified$$,$hash$jscomp$35$$){this.metadata=$metadata$jscomp$9$$;this.cache=$cache$jscomp$107$$;this.data=$data$jscomp$520$$;this.$modified$=$modified$$;this.hash=$hash$jscomp$35$$;this.$cljs$lang$protocol_mask$partition0$$=2163607311;this.$cljs$lang$protocol_mask$partition1$$=139264},$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$$=function($JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$){if($APP.$cljs$core$truth_$$($JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.$modified$)){var $G__83001_83042$$=
$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.data,$G__83002_83043$$=$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.cache,$G__83003_83044$$=function($data_SINGLEQUOTE_$$){$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.$modified$=!1;return $JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.data=$data_SINGLEQUOTE_$$};$app$common$types$objects_map$do_compact$$.$cljs$core$IFn$_invoke$arity$3$?
$app$common$types$objects_map$do_compact$$.$cljs$core$IFn$_invoke$arity$3$($G__83001_83042$$,$G__83002_83043$$,$G__83003_83044$$):$app$common$types$objects_map$do_compact$$($G__83001_83042$$,$G__83002_83043$$,$G__83003_83044$$)}},$app$common$types$objects_map$do_compact$$=function($data$jscomp$522_new_data$jscomp$4$$,$cache$jscomp$109$$,$update_fn$jscomp$53$$){$data$jscomp$522_new_data$jscomp$4$$=$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($JSCompiler_temp$jscomp$10720_data__$1$jscomp$18$$,
$id$jscomp$1080$$,$JSCompiler_temp_const$jscomp$10721_obj$jscomp$225$$){if($JSCompiler_temp_const$jscomp$10721_obj$jscomp$225$$==null){$JSCompiler_temp_const$jscomp$10721_obj$jscomp$225$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$;var $JSCompiler_inline_result$jscomp$10723_data$jscomp$inline_13902$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cache$jscomp$109$$,$id$jscomp$1080$$);$JSCompiler_inline_result$jscomp$10723_data$jscomp$inline_13902$$=$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$10723_data$jscomp$inline_13902$$,
null);$JSCompiler_temp$jscomp$10720_data__$1$jscomp$18$$=$JSCompiler_temp_const$jscomp$10721_obj$jscomp$225$$.call($APP.$cljs$core$assoc_BANG_$$,$JSCompiler_temp$jscomp$10720_data__$1$jscomp$18$$,$id$jscomp$1080$$,$JSCompiler_inline_result$jscomp$10723_data$jscomp$inline_13902$$)}return $JSCompiler_temp$jscomp$10720_data__$1$jscomp$18$$},$APP.$cljs$core$_as_transient$$($data$jscomp$522_new_data$jscomp$4$$),$data$jscomp$522_new_data$jscomp$4$$));$update_fn$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$?
$update_fn$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$522_new_data$jscomp$4$$):$update_fn$jscomp$53$$($data$jscomp$522_new_data$jscomp$4$$);return null},$app$common$types$objects_map$from_data$$=function($data$jscomp$523$$){return new $app$common$types$objects_map$ObjectsMap$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$data$jscomp$523$$,!1,null)},$app$common$types$objects_map$create$$=function($var_args$jscomp$1510$$){switch(arguments.length){case 0:return $app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$();
case 1:var $JSCompiler_inline_result$jscomp$2088_other$jscomp$inline_9865$$=arguments[0];if($JSCompiler_inline_result$jscomp$2088_other$jscomp$inline_9865$$ instanceof $app$common$types$objects_map$ObjectsMap$$)$JSCompiler_inline_result$jscomp$2088_other$jscomp$inline_9865$$=$app$common$types$objects_map$from_data$$($app$common$types$objects_map$get_data$$($JSCompiler_inline_result$jscomp$2088_other$jscomp$inline_9865$$));else throw Error("invalid arguments");return $JSCompiler_inline_result$jscomp$2088_other$jscomp$inline_9865$$;
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}},$app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return $app$common$types$objects_map$from_data$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$ui$debug$icons_preview$icons_gallery$$=function(){var $entries$jscomp$48$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$seq$$(Object.entries($APP.$app$main$ui$icons$default$0$$)));
return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_debug_icons_preview__gallery",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$254$$,$p__83020_val$jscomp$232$$){var $key$jscomp$433$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83020_val$jscomp$232$$,0,null);$p__83020_val$jscomp$232$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83020_val$jscomp$232$$,1,null);$out_arr__44124__auto__$jscomp$254$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{title:$key$jscomp$433$$,className:"main_ui_debug_icons_preview__gallery-item",children:[$p__83020_val$jscomp$232$$,(0,$APP.$rumext$v2$jsx$$)("span",{children:$key$jscomp$433$$})]},$key$jscomp$433$$));return $out_arr__44124__auto__$jscomp$254$$},[],$entries$jscomp$48$$)})},$app$main$ui$debug$icons_preview$cursors_gallery$$=function(){var $rotation$jscomp$25$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$entries$jscomp$49$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,
$APP.$cljs$core$seq$$(Object.entries($app$main$ui$cursors$default$0$$)));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$timers$interval$$(100,function(){return $APP.$cljs$core$reset_BANG_$$($rotation$jscomp$25$$,$APP.$cljs$core$inc$$)})});return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_debug_icons_preview__gallery",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$255$$,$JSCompiler_temp_const$jscomp$11073_p__83032$$){var $JSCompiler_inline_result$jscomp$11075_key$jscomp$434$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11073_p__83032$$,0,null),$JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11073_p__83032$$,1,null);$JSCompiler_temp_const$jscomp$11073_p__83032$$=$out_arr__44124__auto__$jscomp$255$$.push;if($APP.$cljs$core$fn_QMARK_$$($JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$)){var $G__83036$jscomp$inline_13905$$=
$APP.$cljs$core$_deref$$($rotation$jscomp$25$$);$JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$=$JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$.$cljs$core$IFn$_invoke$arity$1$($G__83036$jscomp$inline_13905$$):$JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$($G__83036$jscomp$inline_13905$$)}$JSCompiler_inline_result$jscomp$11075_key$jscomp$434$$=
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_debug_icons_preview__gallery-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundImage:$APP.$cuerdas$core$replace$$($JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$,/(url\(.*\)).*/,"$1"),cursor:$JSCompiler_temp$jscomp$inline_13904_value$jscomp$1018_value__$1$jscomp$inline_13906$$},className:"main_ui_debug_icons_preview__cursor"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$11075_key$jscomp$434$$]))})]},
$JSCompiler_inline_result$jscomp$11075_key$jscomp$434$$);$JSCompiler_temp_const$jscomp$11073_p__83032$$.call($out_arr__44124__auto__$jscomp$255$$,$JSCompiler_inline_result$jscomp$11075_key$jscomp$434$$);return $out_arr__44124__auto__$jscomp$255$$},[],$entries$jscomp$49$$)})},$app$main$ui$debug$icons_preview$icons_preview$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_debug_icons_preview__container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_debug_icons_preview__title",
children:"Cursors"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$icons_preview$cursors_gallery$$,{}),(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_debug_icons_preview__title",children:"Icons"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$icons_preview$icons_gallery$$,{})]})},$app$main$ui$debug$playground$playground_clipboard$$=function(){var $on_paste$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$412_stream$jscomp$108$$){$e$jscomp$412_stream$jscomp$108$$=
$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$412_stream$jscomp$108$$.clipboardData,$APP.$app$util$clipboard$default_options$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$412_stream$jscomp$108$$,function($data$jscomp$524$$){return console.log("data",$data$jscomp$524$$)})}),$on_dragover$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$413$$){return $e$jscomp$413$$.preventDefault()}),
$on_drop$jscomp$23$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$414_stream$jscomp$109$$){$e$jscomp$414_stream$jscomp$109$$.preventDefault();$e$jscomp$414_stream$jscomp$109$$=$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$414_stream$jscomp$109$$.dataTransfer,$APP.$app$util$clipboard$default_options$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$414_stream$jscomp$109$$,function($data$jscomp$525$$){return console.log("data",
$data$jscomp$525$$)})}),$on_click$jscomp$76$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$415_stream$jscomp$110$$){console.log("event",$e$jscomp$415_stream$jscomp$110$$);$e$jscomp$415_stream$jscomp$110$$=$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$clipboard$default_options$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$415_stream$jscomp$110$$,function($data$jscomp$526$$){return console.log("data",
$data$jscomp$526$$)})});window.addEventListener("paste",$on_paste$jscomp$2$$);window.addEventListener("drop",$on_drop$jscomp$23$$);window.addEventListener("dragover",$on_dragover$$);return(0,$APP.$rumext$v2$jsx$$)("button",{id:"paste",onClick:$on_click$jscomp$76$$,children:"Paste"})},$app$main$ui$debug$playground$playground$$=function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$playground$playground_clipboard$$,{})},$app$main$ui$error_boundary$error_boundary_STAR_$$=function($fallback_wrapper_props_83077$$){var $children$jscomp$318$$=
$fallback_wrapper_props_83077$$.children,$fallback$jscomp$1$$=$fallback_wrapper_props_83077$$.fallback;$fallback_wrapper_props_83077$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fallback$jscomp$1$$)],function(){return function($props_83078_route$jscomp$24$$){var $reset_error_boundary$$=$props_83078_route$jscomp$24$$.resetErrorBoundary,$data$jscomp$527_error$jscomp$157$$=$props_83078_route$jscomp$24$$.error;$props_83078_route$jscomp$24$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);
$data$jscomp$527_error$jscomp$157$$=$APP.$app$main$errors$exception__GT_error_data$$($data$jscomp$527_error$jscomp$157$$);return(0,$APP.$rumext$v2$jsx$$)($fallback$jscomp$1$$,{data:$data$jscomp$527_error$jscomp$157$$,route:$props_83078_route$jscomp$24$$,onReset:$reset_error_boundary$$})}});var $on_error$jscomp$73$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$goog$functions$debounce$$(function($error$jscomp$158$$,$info$jscomp$9$$){if($APP.$cljs$core$truth_$$($APP.$app$main$errors$stale_asset_error_QMARK_$$($error$jscomp$158$$)))return $APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$984$reason$$,
$APP.$cljs$core$ex_message$$($error$jscomp$158$$)]));$APP.$app$common$exceptions$print_throwable$$($error$jscomp$158$$);return console.error("Component trace: \n",$info$jscomp$9$$.componentStack,"\n",$error$jscomp$158$$)},100)});return(0,$APP.$rumext$v2$jsx$$)($shadow$js$shim$module$0react_error_boundary$$.ErrorBoundary,{FallbackComponent:$fallback_wrapper_props_83077$$,onError:$on_error$jscomp$73$$,children:$children$jscomp$318$$})},$app$main$ui$exports$files$mark_file_error$$=function($files$jscomp$50$$,
$file_id$jscomp$457$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83172_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$457$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83172_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__83172_SHARP_$$,$APP.$cljs$cst$2191$export_error_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5019$loading$$,!1])):
$p1__83172_SHARP_$$},$files$jscomp$50$$)},$app$main$ui$exports$files$mark_file_success$$=function($files$jscomp$51$$,$file_id$jscomp$458$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83174_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$458$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83174_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__83174_SHARP_$$,$cljs$cst$6345$export_success_QMARK_$$,
!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5019$loading$$,!1])):$p1__83174_SHARP_$$},$files$jscomp$51$$)},$app$main$ui$exports$files$initialize_state$$=function($files$jscomp$52_files__$1$jscomp$8$$){$files$jscomp$52_files__$1$jscomp$8$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$208$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$208$$,$APP.$cljs$cst$5019$loading$$,!0)},$files$jscomp$52_files__$1$jscomp$8$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$109$status$$,$cljs$cst$6346$prepare$$,$APP.$cljs$cst$1921$selected$$,$APP.$cljs$cst$2124$all$$,$APP.$cljs$cst$1916$files$$,$files$jscomp$52_files__$1$jscomp$8$$],null)},$app$main$ui$exports$files$export_entry_STAR_$$=function($file$jscomp$209_props_83176$$){$file$jscomp$209_props_83176$$=$file$jscomp$209_props_83176$$.file;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__file-entry "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$5019$loading$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$))?
"main_ui_exports_files__loading":"")+" "+($APP.$cljs$core$truth_$$($cljs$cst$6345$export_success_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$))?"main_ui_exports_files__success":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$2191$export_error_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$))?"main_ui_exports_files__error":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__file-name",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$5019$loading$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$))?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{width:16,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_files__file-icon",children:$APP.$cljs$core$truth_$$($cljs$cst$6345$export_success_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$))?$APP.$app$main$ui$icons$tick$$:$APP.$cljs$core$truth_$$($APP.$cljs$cst$2191$export_error_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$))?
$APP.$app$main$ui$icons$close$$:null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__file-name-label",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$209_props_83176$$)})]})})},$app$main$ui$exports$files$export_dialog$$=function($props_83178_status$jscomp$27$$){var $on_accept$jscomp$17_team_id$jscomp$169$$=$props_83178_status$jscomp$27$$["team-id"],$files$jscomp$53$$=$props_83178_status$jscomp$27$$.files,$state_STAR_$jscomp$27$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$exports$files$initialize_state$$,
$files$jscomp$53$$)),$has_libs_QMARK_$$=$APP.$cljs$core$some$$($APP.$cljs$cst$2485$has_libraries$$,$files$jscomp$53$$),$state$jscomp$1236$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$27$$),$selected$jscomp$222$$=$APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1236$$);$props_83178_status$jscomp$27$$=$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1236$$);var $start_export$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$17_team_id$jscomp$169$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$222$$),$APP.$rumext$v2$adapt$$($files$jscomp$53$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$27$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$109$status$$,$cljs$cst$6347$exporting$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file_id$jscomp$459_p__83179$$){var $map__83180__$1_uri$jscomp$114$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$459_p__83179$$);$file_id$jscomp$459_p__83179$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83180__$1_uri$jscomp$114$$,$APP.$cljs$cst$1644$file_id$$);var $error$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83180__$1_uri$jscomp$114$$,$APP.$cljs$cst$849$error$$),$filename$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83180__$1_uri$jscomp$114$$,$APP.$cljs$cst$4767$filename$$);$map__83180__$1_uri$jscomp$114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83180__$1_uri$jscomp$114$$,
$APP.$cljs$cst$1579$uri$$);if($APP.$cljs$core$truth_$$($error$jscomp$159$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$27$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1916$files$$,$app$main$ui$exports$files$mark_file_error$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_id$jscomp$459_p__83179$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$27$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1916$files$$,
$app$main$ui$exports$files$mark_file_success$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_id$jscomp$459_p__83179$$]));return $APP.$app$util$dom$trigger_download_uri$$($filename$jscomp$15$$,"application/penpot",$map__83180__$1_uri$jscomp$114$$)},$app$main$data$exports$files$export_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1916$files$$,$files$jscomp$53$$,$APP.$cljs$cst$139$type$$,$selected$jscomp$222$$])))}),
$on_cancel$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$777$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$777$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())});$on_accept$jscomp$17_team_id$jscomp$169$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($start_export$$)],function($event$jscomp$778$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$778$$);
return $start_export$$.$cljs$core$IFn$_invoke$arity$0$?$start_export$$.$cljs$core$IFn$_invoke$arity$0$():$start_export$$()});var $on_change$jscomp$104$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$779_type$jscomp$724$$){$event$jscomp$779_type$jscomp$724$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($event$jscomp$779_type$jscomp$724$$),"type"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$27$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1921$selected$$,$event$jscomp$779_type$jscomp$724$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($has_libs_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($has_libs_QMARK_$$)?null:$start_export$$.$cljs$core$IFn$_invoke$arity$0$?$start_export$$.$cljs$core$IFn$_invoke$arity$0$():$start_export$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_exports_files__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_exports_files__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_cancel$jscomp$11$$,className:"main_ui_exports_files__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83178_status$jscomp$27$$,
$cljs$cst$6346$prepare$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_files__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.description-1")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_files__modal-scd-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.description-2")}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$256$$,$type$jscomp$725$$){$out_arr__44124__auto__$jscomp$256$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__export-option",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:["export-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$725$$)].join(""),className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$222$$,$type$jscomp$725$$)?
"checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$222$$,$type$jscomp$725$$)?"checked":"",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$222$$,$type$jscomp$725$$)?$APP.$app$main$ui$icons$status_tick$$:null}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__option-content",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_exports_files__modal-subtitle",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.options."+($APP.$app$common$data$name$$($type$jscomp$725$$)??"")+".title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_files__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.options."+($APP.$app$common$data$name$$($type$jscomp$725$$)??"")+".message")})]}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"radio",id:["export-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$725$$)].join(""),
checked:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$222$$,$type$jscomp$725$$),name:"export-option","data-type":$APP.$cljs$core$name$$($type$jscomp$725$$),onChange:$on_change$jscomp$104$$,className:"main_ui_exports_files__option-input"})]})},$APP.$cljs$core$name$$($type$jscomp$725$$)));return $out_arr__44124__auto__$jscomp$256$$},[],$APP.$app$main$data$exports$files$valid_types$$)]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_exports_files__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),onClick:$on_cancel$jscomp$11$$,className:"main_ui_exports_files__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),onClick:$on_accept$jscomp$17_team_id$jscomp$169$$,className:"main_ui_exports_files__accept-btn"})]})})]}):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83178_status$jscomp$27$$,$cljs$cst$6347$exporting$$)?function(){var $in_progress_QMARK_$jscomp$3$$=$APP.$cljs$core$some$$($APP.$cljs$cst$5019$loading$$,$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1236$$));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-content",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$257$$,
$file$jscomp$210$$){$out_arr__44124__auto__$jscomp$257$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$exports$files$export_entry_STAR_$$,{file:$file$jscomp$210$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210$$)??"")));return $out_arr__44124__auto__$jscomp$257$$},[],$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1236$$)),$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{role:"status","aria-live":"polite",
className:"main_ui_exports_files__status-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.downloading-file")}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__modal-footer",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__action-buttons",children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),disabled:$in_progress_QMARK_$jscomp$3$$,
onClick:$on_cancel$jscomp$11$$,className:"main_ui_exports_files__accept-btn"})})})]})}():null]})})},$app$main$ui$nitrate$entry$nitrate_entry_STAR_$$=function($props_83181$$){var $profile$jscomp$84$$=$props_83181$$.profile;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$84$$)],function(){var $_STAR_sync_STAR__orig_val__73327$jscomp$inline_9869$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$util$storage$storage$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5055$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5056$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$,!0]))}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__73327$jscomp$inline_9869$$}return $APP.$app$main$data$auth$is_authenticated_QMARK_$$($profile$jscomp$84$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2522$dashboard_recent$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$84$$)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5383$auth_register$$))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),
overlay:!0})},$app$main$ui$nitrate$entry$nitrate_entry_page_STAR_$$=function($props_83182$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$nitrate$entry$nitrate_entry_STAR_$$,$props_83182$$)},$app$main$ui$ds$notifications$toast$toast_STAR_$$=function($detail$jscomp$10_props_83183$$){var $children$jscomp$319$$,$on_close$jscomp$53$$,$is_html$jscomp$3_or__5025__auto__$jscomp$inline_9871$$,$props$jscomp$453$$;({className:$class$$jscomp$84_class$__$1$jscomp$14$$,level:$level$jscomp$66_level__$1$jscomp$2$$,
appearance:$appearance$jscomp$2_appearance__$1$jscomp$1$$,type:$type$jscomp$726_type__$1$jscomp$19$$,isHtml:$is_html$jscomp$3_or__5025__auto__$jscomp$inline_9871$$,children:$children$jscomp$319$$,detail:$detail$jscomp$10_props_83183$$,onClose:$on_close$jscomp$53$$,...$props$jscomp$453$$}=$detail$jscomp$10_props_83183$$);var $class$$jscomp$84_class$__$1$jscomp$14$$=""+($class$$jscomp$84_class$__$1$jscomp$14$$??"")+" main_ui_ds_notifications_toast__toast";var $level$jscomp$66_level__$1$jscomp$2$$=typeof $level$jscomp$66_level__$1$jscomp$2$$===
"string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$66_level__$1$jscomp$2$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$2$$,$APP.$cljs$cst$205$default$$);var $type$jscomp$726_type__$1$jscomp$19$$=typeof $type$jscomp$726_type__$1$jscomp$19$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$726_type__$1$jscomp$19$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$726_type__$1$jscomp$19$$,
$APP.$cljs$cst$2312$context$$);var $appearance$jscomp$2_appearance__$1$jscomp$1$$=typeof $appearance$jscomp$2_appearance__$1$jscomp$1$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($appearance$jscomp$2_appearance__$1$jscomp$1$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($appearance$jscomp$2_appearance__$1$jscomp$1$$,$APP.$cljs$cst$4984$neutral$$);return(0,$APP.$rumext$v2$create_element$$)("aside",{...$props$jscomp$453$$,className:$class$$jscomp$84_class$__$1$jscomp$14$$,
role:"alert","aria-live":"polite"},$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,{level:$level$jscomp$66_level__$1$jscomp$2$$,type:$type$jscomp$726_type__$1$jscomp$19$$,isHtml:$APP.$cljs$core$truth_$$($is_html$jscomp$3_or__5025__auto__$jscomp$inline_9871$$)?$is_html$jscomp$3_or__5025__auto__$jscomp$inline_9871$$:!1,appearance:$appearance$jscomp$2_appearance__$1$jscomp$1$$,detail:$detail$jscomp$10_props_83183$$,children:$children$jscomp$319$$}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$53$$,"aria-label":"Close",className:"main_ui_ds_notifications_toast__close-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$2$$,$APP.$cljs$cst$205$default$$)?"main_ui_ds_notifications_toast__level-default":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$2$$,$APP.$cljs$cst$2343$warning$$)?"main_ui_ds_notifications_toast__level-warning":"")+
" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$2$$,$APP.$cljs$cst$849$error$$)?"main_ui_ds_notifications_toast__level-error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$2$$,$APP.$cljs$cst$2344$success$$)?"main_ui_ds_notifications_toast__level-success":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$2$$,$APP.$cljs$cst$1161$info$$)?"main_ui_ds_notifications_toast__level-info":
""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close"})}))},$app$main$ui$ds$notifications$actionable$actionable_STAR_$$=function($props_83184_variant__$1$jscomp$9$$){var $on_cancel$jscomp$12$$=void 0,$children$jscomp$320$$=void 0,$on_cancel__$1_variant$jscomp$31$$=void 0,$accept_label$$=void 0,$cancel_label$$=void 0,$on_accept$jscomp$18$$=void 0,$class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$=void 0,$props$jscomp$454_props__$1$jscomp$114$$=
void 0;({className:$class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$,variant:$on_cancel__$1_variant$jscomp$31$$,acceptLabel:$accept_label$$,cancelLabel:$cancel_label$$,children:$children$jscomp$320$$,onAccept:$on_accept$jscomp$18$$,onCancel:$on_cancel$jscomp$12$$,...$props$jscomp$454_props__$1$jscomp$114$$}=$props_83184_variant__$1$jscomp$9$$);$props_83184_variant__$1$jscomp$9$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($on_cancel__$1_variant$jscomp$31$$,"default");$class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$=
$APP.$app$common$data$append_class$$($class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$,"main_ui_ds_notifications_actionable__notification");$props$jscomp$454_props__$1$jscomp$114$$={...$props$jscomp$454_props__$1$jscomp$114$$,className:$class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$,"data-testid":"actionable"};$class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$18$$)],function($e$jscomp$416$$){return $APP.$cljs$core$fn_QMARK_$$($on_accept$jscomp$18$$)?
$on_accept$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$416$$):$on_accept$jscomp$18$$($e$jscomp$416$$):null});$on_cancel__$1_variant$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$jscomp$12$$)],function($e$jscomp$417$$){return $APP.$cljs$core$truth_$$($on_cancel$jscomp$12$$)?$on_cancel$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_cancel$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$417$$):
$on_cancel$jscomp$12$$($e$jscomp$417$$):null});return(0,$APP.$rumext$v2$create_element$$)("aside",$props$jscomp$454_props__$1$jscomp$114$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_notifications_actionable__notification-message",children:$children$jscomp$320$$}),$APP.$cljs$core$truth_$$($cancel_label$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$on_cancel__$1_variant$jscomp$31$$,children:$cancel_label$$}):null,
$APP.$cljs$core$truth_$$($accept_label$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83184_variant__$1$jscomp$9$$,"default")?"primary":"destructive",type:"button",onClick:$class$$jscomp$85_class$__$1$jscomp$15_on_accept__$1$$,children:$accept_label$$}):null)},$app$main$ui$notifications$inline_notification$inline_notification$$=function($cancel$jscomp$3_props_83185$$){var $links$jscomp$4$$=$cancel$jscomp$3_props_83185$$.links,
$accept$jscomp$12$$=$cancel$jscomp$3_props_83185$$.accept,$content$jscomp$275$$=$cancel$jscomp$3_props_83185$$.content;$cancel$jscomp$3_props_83185$$=$cancel$jscomp$3_props_83185$$.cancel;return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$ds$notifications$actionable$actionable_STAR_$$,{className:"main_ui_notifications_inline_notification__new-inline",cancelLabel:$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($cancel$jscomp$3_props_83185$$),onCancel:$APP.$cljs$cst$2354$callback$$.$cljs$core$IFn$_invoke$arity$1$($cancel$jscomp$3_props_83185$$),
acceptLabel:$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($accept$jscomp$12$$),onAccept:$APP.$cljs$cst$2354$callback$$.$cljs$core$IFn$_invoke$arity$1$($accept$jscomp$12$$),children:[$content$jscomp$275$$,$links$jscomp$4$$!=null?(0,$APP.$rumext$v2$jsx$$)("nav",{className:"main_ui_notifications_inline_notification__link-nav",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$258$$,$link$jscomp$10_p__83186$$){var $index$jscomp$596$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($link$jscomp$10_p__83186$$,0,null);$link$jscomp$10_p__83186$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($link$jscomp$10_p__83186$$,1,null);$out_arr__44124__auto__$jscomp$258$$.push($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link_button$link_button$$,{"class":"main_ui_notifications_inline_notification__link","on-click":$APP.$cljs$cst$2354$callback$$.$cljs$core$IFn$_invoke$arity$1$($link$jscomp$10_p__83186$$),value:$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($link$jscomp$10_p__83186$$)},
"link-"+($index$jscomp$596$$??"")));return $out_arr__44124__auto__$jscomp$258$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($links$jscomp$4$$))}):null]})},$app$main$ui$notifications$current_notification_STAR_$$=function(){var $notification$jscomp$6$$=$APP.$rumext$v2$deref$$($app$main$ui$notifications$ref_COLON_notification$$),$on_close$jscomp$54$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$hide$$())}),
$actionable_QMARK_$$=$APP.$cljs$cst$2353$timeout$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)==null&&$APP.$cljs$cst$2356$actions$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)==null,$inline_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2348$inline$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2347$floating$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)),
$toast_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$))||$APP.$cljs$cst$2353$timeout$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)!=null,$content$jscomp$276$$=function(){var $or__5025__auto__$jscomp$1418$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1418$$)?
$or__5025__auto__$jscomp$1418$$:""}();return $APP.$cljs$core$truth_$$($notification$jscomp$6$$)?$toast_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$notifications$toast$toast_STAR_$$,{level:function(){var $or__5025__auto__$jscomp$1419$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1419$$)?$or__5025__auto__$jscomp$1419$$:$APP.$cljs$cst$1161$info$$}(),type:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),
detail:$APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),onClose:$on_close$jscomp$54$$,children:$content$jscomp$276$$}):$inline_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$notifications$inline_notification$inline_notification$$,{accept:$APP.$cljs$cst$924$accept$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),cancel:$APP.$cljs$cst$2355$cancel$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),links:$APP.$cljs$cst$2357$links$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),
content:$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)}):$actionable_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:function(){var $or__5025__auto__$jscomp$1420$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1420$$)?$or__5025__auto__$jscomp$1420$$:$APP.$cljs$cst$1161$info$$}(),links:$APP.$cljs$cst$2357$links$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),
content:$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$notifications$toast$toast_STAR_$$,{level:function(){var $or__5025__auto__$jscomp$1421$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1421$$)?$or__5025__auto__$jscomp$1421$$:$APP.$cljs$cst$1161$info$$}(),type:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),
detail:$APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),onClose:$on_close$jscomp$54$$,children:$content$jscomp$276$$}):null},$app$main$ui$onboarding$questions$step_container$$=function($class$$jscomp$86_props_83191$$){var $form$jscomp$212$$=$class$$jscomp$86_props_83191$$.form,$on_next$$=$class$$jscomp$86_props_83191$$["on-next"],$step$jscomp$38$$=$class$$jscomp$86_props_83191$$.step,$children$jscomp$321$$=$class$$jscomp$86_props_83191$$.children,$on_prev$$=$class$$jscomp$86_props_83191$$["on-prev"],
$label$jscomp$56$$=$class$$jscomp$86_props_83191$$.label;$class$$jscomp$86_props_83191$$=$class$$jscomp$86_props_83191$$.class;var $on_next_STAR_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_next$$),$APP.$rumext$v2$adapt$$($step$jscomp$38$$),$APP.$rumext$v2$adapt$$($label$jscomp$56$$)],function($form__$1$jscomp$21$$,$event$jscomp$780$$){var $params$jscomp$454$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$21$$)),
$APP.$cljs$cst$2287$label$$,$label$jscomp$56$$),$APP.$cljs$cst$5673$step$$,$step$jscomp$38$$),$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$($params$jscomp$454$$));return $on_next$$.$cljs$core$IFn$_invoke$arity$2$?$on_next$$.$cljs$core$IFn$_invoke$arity$2$($form__$1$jscomp$21$$,$event$jscomp$780$$):$on_next$$($form__$1$jscomp$21$$,$event$jscomp$780$$)});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,
{form:$form$jscomp$212$$,"on-submit":$on_next_STAR_$$,"class":""+($class$$jscomp$86_props_83191$$??"")+" main_ui_onboarding_questions__form-wrapper",children:[$children$jscomp$321$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__action-buttons",children:[$on_prev$$!=null?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_prev$$,className:"main_ui_onboarding_questions__prev-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.previous")}):null,
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$step$jscomp$38$$<4?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.start"),className:"main_ui_onboarding_questions__next-button"})]})]})},$app$main$ui$onboarding$questions$step_1$$=function($props_83194_show_step_3$$){var $form$jscomp$213$$=$props_83194_show_step_3$$.form,$on_next$jscomp$1$$=$props_83194_show_step_3$$["on-next"];
$props_83194_show_step_3$$=$props_83194_show_step_3$$["show-step-3"];var $use_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.use.work"),$APP.$cljs$cst$260$value$$,"work"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.use.education"),$APP.$cljs$cst$260$value$$,"education"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.use.personal"),$APP.$cljs$cst$260$value$$,"personal"],null)],null))}),$role_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.select-option"),$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$302$key$$,"role",$APP.$cljs$cst$2948$disabled$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.product-design"),$APP.$cljs$cst$260$value$$,"ux",
$APP.$cljs$cst$302$key$$,"ux"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.developer"),$APP.$cljs$cst$260$value$$,"developer",$APP.$cljs$cst$302$key$$,"developer"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.student-teacher"),$APP.$cljs$cst$260$value$$,"student-teacher",$APP.$cljs$cst$302$key$$,
"student"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.graphic-design"),$APP.$cljs$cst$260$value$$,"designer",$APP.$cljs$cst$302$key$$,"design"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.marketing"),$APP.$cljs$cst$260$value$$,"marketing",$APP.$cljs$cst$302$key$$,"marketing"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.product-management"),$APP.$cljs$cst$260$value$$,"manager",$APP.$cljs$cst$302$key$$,"manager"],null)],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other-short"),$APP.$cljs$cst$260$value$$,"other"],null))}),$current_role$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$213$$),
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2490$role$$);return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container$$,{form:$form$jscomp$213$$,step:1,label:"questions:about-you","on-next":$on_next$jscomp$1$$,"class":"main_ui_onboarding_questions__step-1",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:"1/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($props_83194_show_step_3$$))?4:3)}),(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/form/use-for-1.png",alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.lets-get-started"),className:"main_ui_onboarding_questions__header-image"}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step1.title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_questions__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step1.subtitle")}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__modal-question",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_onboarding_questions__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step1.question1")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$radio_buttons$$,{options:$use_options$$,name:$cljs$cst$6348$expected_use$$,"class":"main_ui_onboarding_questions__radio-btns"}),(0,$APP.$rumext$v2$jsx$$)("h3",
{className:"main_ui_onboarding_questions__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step3.question1")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{options:$role_options$$,"select-class":"main_ui_onboarding_questions__select-class","default":"",name:$APP.$cljs$cst$2490$role$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_role$$,"other")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,
{name:$cljs$cst$6349$role_other$$,"class":"main_ui_onboarding_questions__input-spacing",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other"),"show-error":!1,label:""}):null]})]})},$app$main$ui$onboarding$questions$step_2$$=function($on_prev$jscomp$1_props_83195$$){var $form$jscomp$214$$=$on_prev$jscomp$1_props_83195$$.form,$on_next$jscomp$2$$=$on_prev$jscomp$1_props_83195$$["on-next"],$show_step_3$jscomp$1$$=$on_prev$jscomp$1_props_83195$$["show-step-3"];$on_prev$jscomp$1_props_83195$$=
$on_prev$jscomp$1_props_83195$$["on-prev"];var $design_tool_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.figma"),$cljs$cst$6352$img_width$$,
"48px",$cljs$cst$6353$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"figma",$APP.$cljs$cst$1612$image$$,"images/form/figma.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.sketch"),$cljs$cst$6352$img_width$$,"48px",$cljs$cst$6353$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"sketch",$APP.$cljs$cst$1612$image$$,"images/form/sketch.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.adobe-xd"),$cljs$cst$6352$img_width$$,"48px",$cljs$cst$6353$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"adobe-xd",$APP.$cljs$cst$1612$image$$,"images/form/adobe-xd.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.canva"),$cljs$cst$6352$img_width$$,"48px",$cljs$cst$6353$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"canva",$APP.$cljs$cst$1612$image$$,
"images/form/canva.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invision"),$cljs$cst$6352$img_width$$,"48px",$cljs$cst$6353$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"invision",$APP.$cljs$cst$1612$image$$,"images/form/invision.png"],null)],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other-short"),
$APP.$cljs$cst$260$value$$,"other",$APP.$cljs$cst$1721$icon$$,$APP.$app$main$ui$icons$curve$$],null))}),$current_experience$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$214$$),$APP.$cljs$cst$142$data$$),$cljs$cst$6350$experience_design_tool$$),$on_design_tool_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_experience$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_experience$$,
"other")?($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$214$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$6351$experience_design_tool_other$$],null)),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$214$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$cljs$cst$6351$experience_design_tool_other$$],null))):null});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container$$,{form:$form$jscomp$214$$,step:2,label:"questions:experience-design-tool","on-next":$on_next$jscomp$2$$,"on-prev":$on_prev$jscomp$1_props_83195$$,"class":"main_ui_onboarding_questions__step-2",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:"2/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$1$$))?
4:3)}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step2.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__radio-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$forms$image_radio_buttons$$,{options:$design_tool_options$$,"img-width":"48px","img-height":"60px",name:$cljs$cst$6350$experience_design_tool$$,image:!0,"class":"main_ui_onboarding_questions__image-radio",
"on-change":$on_design_tool_change$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_experience$$,"other")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$cljs$cst$6351$experience_design_tool_other$$,"class":"main_ui_onboarding_questions__input-spacing",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other"),"show-error":!1,label:""}):null]})]})},$app$main$ui$onboarding$questions$step_3$$=function($on_prev$jscomp$2_props_83196$$){var $form$jscomp$215$$=
$on_prev$jscomp$2_props_83196$$.form,$on_next$jscomp$3$$=$on_prev$jscomp$2_props_83196$$["on-next"],$show_step_3$jscomp$2$$=$on_prev$jscomp$2_props_83196$$["show-step-3"];$on_prev$jscomp$2_props_83196$$=$on_prev$jscomp$2_props_83196$$["on-prev"];var $team_size_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.select-option"),$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$302$key$$,"team-size",$APP.$cljs$cst$2948$disabled$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.just-me"),$APP.$cljs$cst$260$value$$,"1",$APP.$cljs$cst$302$key$$,"1"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.2-100"),$APP.$cljs$cst$260$value$$,"2-100",$APP.$cljs$cst$302$key$$,"2-100"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.101-500"),$APP.$cljs$cst$260$value$$,"101-500",$APP.$cljs$cst$302$key$$,"101-500"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.501-1000"),$APP.$cljs$cst$260$value$$,"501-1000",$APP.$cljs$cst$302$key$$,"501-1000"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.1001-5000"),$APP.$cljs$cst$260$value$$,"1001-5000",$APP.$cljs$cst$302$key$$,"1001-5000"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.more-than-5001"),$APP.$cljs$cst$260$value$$,"5001+",$APP.$cljs$cst$302$key$$,"5001+"],null)],null)});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container$$,{form:$form$jscomp$215$$,step:3,label:"questions:about-your-job","on-next":$on_next$jscomp$3$$,"on-prev":$on_prev$jscomp$2_props_83196$$,"class":"main_ui_onboarding_questions__step-3",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",
children:"3/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$2$$))?4:3)}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step3.title")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__modal-question",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{options:$team_size_options$$,"default":"","select-class":"main_ui_onboarding_questions__select-class",
name:$cljs$cst$6354$team_size$$})})]})},$app$main$ui$onboarding$questions$step_4$$=function($on_prev$jscomp$3_props_83199$$){var $form$jscomp$216$$=$on_prev$jscomp$3_props_83199$$.form,$on_next$jscomp$4$$=$on_prev$jscomp$3_props_83199$$["on-next"],$show_step_3$jscomp$3$$=$on_prev$jscomp$3_props_83199$$["show-step-3"];$on_prev$jscomp$3_props_83199$$=$on_prev$jscomp$3_props_83199$$["on-prev"];var $start_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.ui"),$APP.$cljs$cst$260$value$$,"ui",$APP.$cljs$cst$1612$image$$,"images/form/Design.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.wireframing"),$APP.$cljs$cst$260$value$$,
"wireframing",$APP.$cljs$cst$1612$image$$,"images/form/templates.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.prototyping"),$APP.$cljs$cst$260$value$$,"prototyping",$APP.$cljs$cst$1612$image$$,"images/form/Prototype.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.ds"),
$APP.$cljs$cst$260$value$$,"ds",$APP.$cljs$cst$1612$image$$,"images/form/components.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.code"),$APP.$cljs$cst$260$value$$,"code",$APP.$cljs$cst$1612$image$$,"images/form/design-and-dev.png"],null)],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other-short"),
$APP.$cljs$cst$260$value$$,"other",$APP.$cljs$cst$1721$icon$$,$APP.$app$main$ui$icons$curve$$],null))}),$current_start$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$216$$),$APP.$cljs$cst$142$data$$),$cljs$cst$6355$start_with$$),$on_start_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_start$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_start$$,
"other")?($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$216$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$6356$start_with_other$$],null)),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$216$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,
$cljs$cst$6356$start_with_other$$],null))):null});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container$$,{form:$form$jscomp$216$$,step:4,label:"questions:how-start","on-next":$on_next$jscomp$4$$,"on-prev":$on_prev$jscomp$3_props_83199$$,"class":"main_ui_onboarding_questions__step-4",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:""+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$3$$))?4:3)+
"/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$3$$))?4:3)}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step4.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__radio-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$forms$image_radio_buttons$$,{options:$start_options$$,"img-width":"159px",
"img-height":"120px",name:$cljs$cst$6355$start_with$$,"on-change":$on_start_change$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_start$$,"other")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$cljs$cst$6356$start_with_other$$,"class":"main_ui_onboarding_questions__input-spacing",label:"","show-error":!1,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other")}):null]})]})},$app$main$ui$onboarding$questions$questions_modal$$=
function(){var $container$jscomp$102$$=(0,$APP.$rumext$v2$use_ref$$)(),$step$jscomp$39$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(1),$clean_data$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$show_step_3$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$step_1_form$$=function(){var $G__83202$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$5076$initial$$,$G__83202$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_1$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$5076$initial$$,$G__83202$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_1$$)}(),$step_2_form$$=function(){var $G__83206$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$5076$initial$$,$G__83206$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_2$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$5076$initial$$,$G__83206$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_2$$)}(),$step_3_form$$=function(){var $G__83210$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$5076$initial$$,$G__83210$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_3$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$5076$initial$$,$G__83210$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_3$$)}(),$step_4_form$$=function(){var $G__83214$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$5076$initial$$,$G__83214$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_4$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$5076$initial$$,$G__83214$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_4$$)}(),$on_next$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form$jscomp$217$$){$APP.$cljs$core$truth_$$($cljs$cst$6348$expected_use$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$217$$))))&&
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6348$expected_use$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$217$$))),"work")?$APP.$cljs$core$reset_BANG_$$($show_step_3$jscomp$4$$,!0):$APP.$cljs$core$reset_BANG_$$($show_step_3$jscomp$4$$,!1));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($step$jscomp$39$$,$APP.$cljs$core$inc$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($clean_data$$,
$APP.$cljs$core$merge$$,$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$217$$)))}),$on_prev$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($step$jscomp$39$$,$APP.$cljs$core$dec$$)}),$on_submit$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($clean_data$$))],function($data$jscomp$530_form$jscomp$218$$){$data$jscomp$530_form$jscomp$218$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_deref$$($clean_data$$),$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$530_form$jscomp$218$$))]));$APP.$cljs$core$reset_BANG_$$($clean_data$$,$data$jscomp$530_form$jscomp$218$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$mark_questions_as_answered$$($data$jscomp$530_form$jscomp$218$$))});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{ref:$container$jscomp$102$$,className:"main_ui_onboarding_questions__modal-container",children:function(){switch($APP.$cljs$core$_deref$$($step$jscomp$39$$)){case 1:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_1$$,{"on-next":$on_next$jscomp$5$$,"on-prev":$on_prev$jscomp$4$$,form:$step_1_form$$,"show-step-3":$show_step_3$jscomp$4$$});case 2:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_2$$,
{"on-next":$on_next$jscomp$5$$,"on-prev":$on_prev$jscomp$4$$,form:$step_2_form$$,"show-step-3":$show_step_3$jscomp$4$$});case 3:return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_3$$,{"on-next":$on_next$jscomp$5$$,"on-prev":$on_prev$jscomp$4$$,form:$step_3_form$$,"show-step-3":$show_step_3$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_4$$,{"on-next":$on_submit$jscomp$20$$,
"on-prev":$on_prev$jscomp$4$$,form:$step_4_form$$,"show-step-3":$show_step_3$jscomp$4$$});default:return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_4$$,{"on-next":$on_submit$jscomp$20$$,"on-prev":$on_prev$jscomp$4$$,form:$step_4_form$$,"show-step-3":$show_step_3$jscomp$4$$}):null}}()})})},$app$main$ui$onboarding$team_choice$left_sidebar$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-left",
children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_onboarding_team_choice__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.team-definition")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-desc")}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_onboarding_team_choice__team-features",children:[(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_onboarding_team_choice__feature",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_onboarding_team_choice__icon",children:$APP.$app$main$ui$icons$document$$}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-desc",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-1")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_onboarding_team_choice__feature",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_onboarding_team_choice__icon",children:$APP.$app$main$ui$icons$move$$}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-desc",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-2")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_onboarding_team_choice__feature",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_onboarding_team_choice__icon",children:$APP.$app$main$ui$icons$tree$$}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-desc",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-3")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_onboarding_team_choice__feature",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_onboarding_team_choice__icon",children:$APP.$app$main$ui$icons$user$$}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-desc",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-4")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_onboarding_team_choice__feature",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_onboarding_team_choice__icon",children:$APP.$app$main$ui$icons$tick$$}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-desc",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-5")})]})]})]})},
$app$main$ui$onboarding$team_choice$get_available_roles$$=function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"viewer",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.viewer")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"editor",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.editor")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"admin",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.admin")],null)],null)},$app$main$ui$onboarding$team_choice$team_form$$=function($initial$jscomp$42_props_83222_roles$jscomp$1$$){var $go_to_team$$=$initial$jscomp$42_props_83222_roles$jscomp$1$$["go-to-team"];$initial$jscomp$42_props_83222_roles$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2490$role$$,"editor"],null)});var $form$jscomp$219$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$team_choice$schema_COLON_team_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$42_props_83222_roles$jscomp$1$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$team_choice$schema_COLON_team_form$$,
$APP.$cljs$cst$5076$initial$$,$initial$jscomp$42_props_83222_roles$jscomp$1$$);$initial$jscomp$42_props_83222_roles$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$onboarding$team_choice$get_available_roles$$);var $error_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_success$jscomp$58$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($response$jscomp$16_team_id$jscomp$170$$){$response$jscomp$16_team_id$jscomp$170$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($response$jscomp$16_team_id$jscomp$170$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$6357$onboarding_team_id$$,$response$jscomp$16_team_id$jscomp$170$$,$APP.$cljs$cst$3227$onboarding_viewed$$,!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$go_to_team$$])),
$APP.$cljs$core$truth_$$($go_to_team$$)?$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$response$jscomp$16_team_id$jscomp$170$$])):null]))}),$on_error$jscomp$74$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause$jscomp$114_map__83223__$1$$){$cause$jscomp$114_map__83223__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$114_map__83223__$1$$));
var $type$jscomp$727$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$114_map__83223__$1$$,$APP.$cljs$cst$139$type$$),$code$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$114_map__83223__$1$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$type$jscomp$727$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5128$profile_is_muted$$,$code$jscomp$62$$)?
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$type$jscomp$727$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5129$max_invitations_by_request$$,$code$jscomp$62$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.maximum-invitations-by-request-reached",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2501$threshold$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$114_map__83223__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$type$jscomp$727$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3382$max_quote_reached$$,$code$jscomp$62$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.max-quota-reached",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2872$target$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$114_map__83223__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5130$member_is_muted$$,$code$jscomp$62$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5131$email_has_permanent_bounces$$,$code$jscomp$62$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5132$email_has_complaints$$,$code$jscomp$62$$)?
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-spam-or-permanent-bounces",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$114_map__83223__$1$$)]))):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic"))}),
$on_invite_later$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__83225__$1_name$jscomp$508_p__83224$$){$map__83225__$1_name$jscomp$508_p__83224$$=$APP.$cljs$core$__destructure_map$$($map__83225__$1_name$jscomp$508_p__83224$$);$map__83225__$1_name$jscomp$508_p__83224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83225__$1_name$jscomp$508_p__83224$$,$APP.$cljs$cst$725$name$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$with_meta$$($APP.$app$main$data$team$create_team$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$725$name$$,$map__83225__$1_name$jscomp$508_p__83224$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$58$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$74$$],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$cljs$cst$6358$onboarding_without_invitations$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step",$APP.$cljs$cst$2287$label$$,"team:create-team-and-invite-later",$APP.$cljs$cst$2493$team_name$$,$map__83225__$1_name$jscomp$508_p__83224$$,$APP.$cljs$cst$5673$step$$,8],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-finish"],null))]))}),$on_invite_now$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__83227__$1_p__83226$$){$map__83227__$1_p__83226$$=
$APP.$cljs$core$__destructure_map$$($map__83227__$1_p__83226$$);var $name$jscomp$509$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83227__$1_p__83226$$,$APP.$cljs$cst$725$name$$),$emails$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83227__$1_p__83226$$,$APP.$cljs$cst$3290$emails$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$with_meta$$($app$main$data$team$create_team_with_invitations$$($APP.$cljs$core$with_meta$$($map__83227__$1_p__83226$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$58$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$74$$],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$cljs$cst$6359$onboarding_with_invitations$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"onboarding-step",$APP.$cljs$cst$2287$label$$,"team:create-team-and-invite",$cljs$cst$6360$invites$$,$APP.$cljs$core$count$$($emails$jscomp$4$$),$APP.$cljs$cst$2493$team_name$$,$name$jscomp$509$$,$APP.$cljs$cst$2490$role$$,$APP.$cljs$cst$2490$role$$.$cljs$core$IFn$_invoke$arity$1$($map__83227__$1_p__83226$$),$APP.$cljs$cst$5673$step$$,8],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-finish"],
null))]))}),$on_submit_STAR_$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form__$1$jscomp$22_params$jscomp$457$$){$form__$1$jscomp$22_params$jscomp$457$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$22_params$jscomp$457$$));var $emails$jscomp$5$$=$APP.$cljs$cst$3290$emails$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$22_params$jscomp$457$$);return $APP.$cljs$core$count$$($emails$jscomp$5$$)>0?$on_invite_now$$.$cljs$core$IFn$_invoke$arity$1$?
$on_invite_now$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$22_params$jscomp$457$$):$on_invite_now$$($form__$1$jscomp$22_params$jscomp$457$$):$on_invite_later$$.$cljs$core$IFn$_invoke$arity$1$?$on_invite_later$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$22_params$jscomp$457$$):$on_invite_later$$($form__$1$jscomp$22_params$jscomp$457$$)}),$on_skip$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3227$onboarding_viewed$$,!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step",$APP.$cljs$cst$2287$label$$,"team:skip-team-creation",$APP.$cljs$cst$5673$step$$,7],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"onboarding-finish"],null))]))});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__first-block",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$219$$,"class":"main_ui_onboarding_team_choice__modal-form","on-submit":$on_submit_STAR_$jscomp$3$$,children:[(0,$APP.$rumext$v2$jsx$$)("h2",
{className:"main_ui_onboarding_team_choice__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-desc")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"text","class":"main_ui_onboarding_team_choice__team-name-input",
name:$APP.$cljs$cst$725$name$$,"auto-focus?":!0,placeholder:"Team name",label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-placeholder")}),(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_onboarding_team_choice__modal-subtitle main_ui_onboarding_team_choice__invite-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.invite-members")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.invite-members-info")}),function(){var $temp__5825__auto__$jscomp$464$$=$APP.$cljs$core$_deref$$($error_STAR_$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$464$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$temp__5825__auto__$jscomp$464$$,level:$APP.$cljs$cst$849$error$$}):null}(),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__role-select",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__role-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.roles")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{name:$APP.$cljs$cst$2490$role$$,options:$initial$jscomp$42_props_83222_roles$jscomp$1$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__invitation-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$multi_input$$,
{type:"email",name:$APP.$cljs$cst$3290$emails$$,trim:!0,"valid-item-fn":$APP.$app$common$schema$parse_email$$,"caution-item-fn":$APP.$cljs$core$PersistentHashSet$EMPTY$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-member.emails")})}),function(){var $emails$jscomp$6_params$jscomp$458$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$219$$));$emails$jscomp$6_params$jscomp$458$$=$APP.$cljs$cst$3290$emails$$.$cljs$core$IFn$_invoke$arity$1$($emails$jscomp$6_params$jscomp$458$$);
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__action-buttons",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{className:"main_ui_onboarding_team_choice__accept-button",label:$APP.$cljs$core$count$$($emails$jscomp$6_params$jscomp$458$$)>0?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-and-invite"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-without-invite")})}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($emails$jscomp$6_params$jscomp$458$$),0)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-hint",children:["(",$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-and-send-invites-description"),")"]}):null]})}()]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__second-block",children:[(0,$APP.$rumext$v2$jsx$$)("h2",
{className:"main_ui_onboarding_team_choice__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.start-without-a-team")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_team_choice__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.start-without-a-team-description")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__action-buttons",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$on_skip$$,className:"main_ui_onboarding_team_choice__accept-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.continue-without-a-team")})})]})]})})},$app$main$ui$onboarding$team_choice$onboarding_team_modal$$=function($go_to_team$jscomp$1_props_83230$$){$go_to_team$jscomp$1_props_83230$$=$go_to_team$jscomp$1_props_83230$$["go-to-team"];return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"animated fade-in main_ui_onboarding_team_choice__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_team_choice__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding-v2.welcome.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-sections",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$left_sidebar$$,{}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__separator"}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_form$$,{"go-to-team":$go_to_team$jscomp$1_props_83230$$})]})]})})},$app$main$ui$releases$common$navigation_bullets_STAR_$$=function($props_83221$$){var $navigate$jscomp$5$$=$props_83221$$.navigate,$slide$$=$props_83221$$.slide;return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_releases_common__step-dots",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$259$$,$i$jscomp$545$$){$out_arr__44124__auto__$jscomp$259$$.push((0,$APP.$rumext$v2$jsx$$)("li",
{onClick:function(){return $navigate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$navigate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($i$jscomp$545$$):$navigate$jscomp$5$$($i$jscomp$545$$)},className:"main_ui_releases_common__dot "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($slide$$,$i$jscomp$545$$)?"main_ui_releases_common__current":"")}));return $out_arr__44124__auto__$jscomp$259$$},[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($props_83221$$.total))})},$app$main$ui$releases$release_notes$$=
function($klass$jscomp$38_props_83330$$){var $version$jscomp$58$$=$klass$jscomp$38_props_83330$$.version,$slide_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1292$start$$),$slide$jscomp$33$$=$APP.$cljs$core$_deref$$($slide_STAR_$$),$klass_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("fade-in-down");$klass$jscomp$38_props_83330$$=$APP.$cljs$core$_deref$$($klass_STAR_$$);var $navigate$jscomp$36$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__83329_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($slide_STAR_$$,
$p1__83329_SHARP_$$)}),$next$jscomp$43$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($slide$jscomp$33$$)],function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($slide$jscomp$33$$,$APP.$cljs$cst$1292$start$$))return $navigate$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$?$navigate$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$(0):$navigate$jscomp$36$$(0);var $G__83331$$=$slide$jscomp$33$$+1;return $navigate$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$?
$navigate$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$($G__83331$$):$navigate$jscomp$36$$($G__83331$$)}),$finish$jscomp$33$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($version$jscomp$58$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$profile$mark_onboarding_as_viewed$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2289$version$$,$version$jscomp$58$$],null))]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$mark_onboarding_as_viewed$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2289$version$$,$version$jscomp$58$$],null)))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($slide$jscomp$33$$)],
function(){$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$slide$jscomp$33$$)&&$APP.$cljs$core$reset_BANG_$$($klass_STAR_$$,"fade-in");var $sem$jscomp$11$$=$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(300,function(){return $APP.$cljs$core$reset_BANG_$$($klass_STAR_$$,null)});return function(){$APP.$cljs$core$reset_BANG_$$($klass_STAR_$$,null);return $APP.$beicon$v2$core$_dispose$$($sem$jscomp$11$$)}});return $app$main$ui$releases$common$render_release_notes$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1328$next$$,$next$jscomp$43$$,$APP.$cljs$cst$1941$navigate$$,$navigate$jscomp$36$$,$cljs$cst$6362$finish$$,$finish$jscomp$33$$,$cljs$cst$6361$klass$$,$klass$jscomp$38_props_83330$$,$APP.$cljs$cst$1958$slide$$,$slide$jscomp$33$$,$APP.$cljs$cst$2289$version$$,$version$jscomp$58$$],null))},$app$main$ui$releases$release_notes_modal$$=function($props_83332$$){var $versions$jscomp$1$$=$cljs$core$_methods$$();return $APP.$cljs$core$contains_QMARK_$$($versions$jscomp$1$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_83332$$,
"version"))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"relnotes",children:(0,$APP.$rumext$v2$create_element$$)($app$main$ui$releases$release_notes$$,$props_83332$$)}):null},$app$main$ui$workspace_legacy_redirect_STAR_$$=function($props_83355$$){var $project_id$jscomp$54$$=$props_83355$$.projectId,$file_id$jscomp$460$$=$props_83355$$.fileId,$layout$jscomp$38$$=$props_83355$$.layout,$page_id$jscomp$477$$=$props_83355$$.pageId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($map__83357__$1_p__83356_team_id$jscomp$171$$){$map__83357__$1_p__83356_team_id$jscomp$171$$=
$APP.$cljs$core$__destructure_map$$($map__83357__$1_p__83356_team_id$jscomp$171$$);$map__83357__$1_p__83356_team_id$jscomp$171$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83357__$1_p__83356_team_id$jscomp$171$$,$APP.$cljs$cst$1927$team_id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$map__83357__$1_p__83356_team_id$jscomp$171$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$460$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$477$$,$APP.$cljs$cst$1615$layout$$,$layout$jscomp$38$$])))},$APP.$app$main$errors$on_error$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3511$get_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$project_id$jscomp$54$$],null)))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$dashboard_legacy_redirect_STAR_$$=function($props_83362$$){var $project_id$jscomp$55$$=$props_83362$$.projectId,$team_id$jscomp$172$$=$props_83362$$.teamId,$search_term$jscomp$9$$=$props_83362$$.searchTerm,$plugin_url$jscomp$6$$=$props_83362$$.pluginUrl,$section$jscomp$55$$=$props_83362$$.section,$template$jscomp$13$$=$props_83362$$.template,$section__$1$jscomp$4$$=function(){var $G__83363__$1$$=
$section$jscomp$55$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$55$$.$fqn$:null;switch($G__83363__$1$$){case "dashboard-legacy-search":return $APP.$cljs$cst$2515$dashboard_search$$;case "dashboard-legacy-projects":return $APP.$cljs$cst$2522$dashboard_recent$$;case "dashboard-legacy-files":return $APP.$cljs$cst$2512$dashboard_files$$;case "dashboard-legacy-libraries":return $APP.$cljs$cst$2518$dashboard_libraries$$;case "dashboard-legacy-fonts":return $APP.$cljs$cst$2520$dashboard_fonts$$;
case "dashboard-legacy-font-providers":return $cljs$cst$6369$dashboard_font_providers$$;case "dashboard-legacy-team-members":return $APP.$cljs$cst$2524$dashboard_members$$;case "dashboard-legacy-team-invitations":return $APP.$cljs$cst$2526$dashboard_invitations$$;case "dashboard-legacy-team-webhooks":return $APP.$cljs$cst$2528$dashboard_webhooks$$;case "dashboard-legacy-team-settings":return $APP.$cljs$cst$2530$dashboard_settings$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83363__$1$$)].join(""));
}}();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($section__$1$jscomp$4$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$172$$,$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$55$$,$APP.$cljs$cst$2516$search_term$$,
$search_term$jscomp$9$$,$APP.$cljs$cst$3402$plugin$$,$plugin_url$jscomp$6$$,$APP.$cljs$cst$2403$template$$,$template$jscomp$13$$],null))))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$viewer_legacy_redirect_STAR_$$=function($props_83367$$){var $file_id$jscomp$461$$=$props_83367$$.fileId,$index$jscomp$597$$=$props_83367$$.index,$section$jscomp$56$$=$props_83367$$.section,
$interactions_mode$jscomp$10$$=$props_83367$$.interactionsMode,$page_id$jscomp$478$$=$props_83367$$.pageId,$share$jscomp$7$$=$props_83367$$.share,$share_id$jscomp$36$$=$props_83367$$.shareId,$frame_id$jscomp$159$$=$props_83367$$.frameId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
8,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$478$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$461$$,$APP.$cljs$cst$1366$section$$,$section$jscomp$56$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$597$$,$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$36$$,$APP.$cljs$cst$5231$interactions_mode$$,$interactions_mode$jscomp$10$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$159$$,$APP.$cljs$cst$5399$share$$,$share$jscomp$7$$],null))))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$team_container_STAR_$$=function($map__83369_map__83369__$1_props_83368$$){var $children$jscomp$322$$=$map__83369_map__83369__$1_props_83368$$.children,$team_id$jscomp$173$$=$map__83369_map__83369__$1_props_83368$$.teamId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$173$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$initialize_team$$($team_id$jscomp$173$$));
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$finalize_team$$($team_id$jscomp$173$$))}});$map__83369_map__83369__$1_props_83368$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$);$map__83369_map__83369__$1_props_83368$$=$APP.$cljs$core$__destructure_map$$($map__83369_map__83369__$1_props_83368$$);var $permissions$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83369_map__83369__$1_props_83368$$,$APP.$cljs$cst$1722$permissions$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$173$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__83369_map__83369__$1_props_83368$$))?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_team_id$$),{value:$team_id$jscomp$173$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$permissions$$),{value:$permissions$jscomp$49$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$can_edit_QMARK_$$),
{value:$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$49$$),children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$children$jscomp$322$$},$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($team_id$jscomp$173$$))})})}):null},$app$main$ui$page_STAR_$$=function($map__83452__$1_props_83372$$){var $profile$jscomp$85$$=$map__83452__$1_props_83372$$.profile,$route$jscomp$25$$=$map__83452__$1_props_83372$$.route;$map__83452__$1_props_83372$$=$APP.$cljs$core$__destructure_map$$($route$jscomp$25$$);
var $data$jscomp$531$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83452__$1_props_83372$$,$APP.$cljs$cst$142$data$$),$params$jscomp$462$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83452__$1_props_83372$$,$APP.$cljs$cst$1430$params$$),$props$jscomp$457$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$85$$,$APP.$cljs$cst$575$props$$),$section$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$531$$,$APP.$cljs$cst$725$name$$),
$team$jscomp$85$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$nitrate_entry_active_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$storage$$,$APP.$cljs$cst$5055$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$)===!0,$show_question_modal_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1222$onboarding$$)&&!$nitrate_entry_active_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$cst$3227$onboarding_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$457$$))&&
!$APP.$cljs$core$contains_QMARK_$$($props$jscomp$457$$,$APP.$cljs$cst$3231$onboarding_questions$$),$show_team_modal_QMARK_$$=function(){var $and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1222$onboarding$$);return $and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$?($and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$=
!$nitrate_entry_active_QMARK_$$)?($and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$=$APP.$cljs$core$not$$($APP.$cljs$cst$3227$onboarding_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$457$$)))?($and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$=!$APP.$cljs$core$contains_QMARK_$$($props$jscomp$457$$,$cljs$cst$6357$onboarding_team_id$$))?
$APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$85$$):$and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$:$and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$:$and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$:$and__5023__auto__$jscomp$1033_and__5023__auto____$1$jscomp$170_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$10$$}(),
$show_release_modal_QMARK_$$=function(){var $and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1222$onboarding$$);return $and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$?($and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$=
!$nitrate_entry_active_QMARK_$$)?($and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$=!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1245$hide_release_modal$$))?($and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$=$APP.$cljs$cst$3227$onboarding_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$457$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3228$release_notes_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$457$$),$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("0.0",$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)):$and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$):
$and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$:$and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$:$and__5023__auto__$jscomp$1034_and__5023__auto____$1$jscomp$171_and__5023__auto____$2$jscomp$51_and__5023__auto____$3$jscomp$11$$}();return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_route$$),{value:$route$jscomp$25$$,
children:function(){switch($section$jscomp$57$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$57$$.$fqn$:null){case "auth-login":case "auth-register":case "auth-register-validate":case "auth-register-success":case "auth-recovery-request":case "auth-recovery":return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth_page$$,{route:$route$jscomp$25$$})});case "auth-verify-token":return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$verify_token_page_STAR_$$,
{route:$route$jscomp$25$$})});case "nitrate-entry":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$nitrate$entry$nitrate_entry_page_STAR_$$,{profile:$profile$jscomp$85$$});case "settings-profile":case "settings-password":case "settings-options":case "settings-feedback":case "settings-subscription":case "settings-integrations":case "settings-notifications":var $params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$462$$,$APP.$cljs$cst$747$query$$),$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=
function(){var $G__83477_G__83477__$1$$=$params__$1$jscomp$64$$;$G__83477_G__83477__$1$$=$G__83477_G__83477__$1$$==null?null:$APP.$cljs$cst$5415$error_report_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83477_G__83477__$1$$);return $G__83477_G__83477__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83477_G__83477__$1$$)}();return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings_page_STAR_$$,{route:$route$jscomp$25$$,type:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$64$$,
$APP.$cljs$cst$139$type$$),errorReportId:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,errorHref:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$64$$,$APP.$cljs$cst$5416$error_href$$)})});case "debug-icons-preview":return $APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$icons_preview$icons_preview$$,{}):null;case "debug-playground":return $APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$playground$playground$$,{}):null;case "dashboard-search":case "dashboard-recent":case "dashboard-files":case "dashboard-libraries":case "dashboard-fonts":case "dashboard-font-providers":case "dashboard-members":case "dashboard-invitations":case "dashboard-webhooks":case "dashboard-settings":case "dashboard-deleted":$params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$462$$,$APP.$cljs$cst$747$query$$);var $index$jscomp$598_team_id$jscomp$174$$=
function(){var $G__83482_G__83482__$1$$=$params__$1$jscomp$64$$;$G__83482_G__83482__$1$$=$G__83482_G__83482__$1$$==null?null:$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83482_G__83482__$1$$);return $G__83482_G__83482__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83482_G__83482__$1$$)}(),$project_id$jscomp$56_share_id$jscomp$37$$=function(){var $G__83497_G__83497__$1$$=$params__$1$jscomp$64$$;$G__83497_G__83497__$1$$=$G__83497_G__83497__$1$$==null?null:$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83497_G__83497__$1$$);
return $G__83497_G__83497__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83497_G__83497__$1$$)}();$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__83500$$=$params__$1$jscomp$64$$;return $G__83500$$==null?null:$APP.$cljs$cst$2516$search_term$$.$cljs$core$IFn$_invoke$arity$1$($G__83500$$)}();var $file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=function(){var $G__83501$$=$params__$1$jscomp$64$$;
return $G__83501$$==null?null:$APP.$cljs$cst$3402$plugin$$.$cljs$core$IFn$_invoke$arity$1$($G__83501$$)}(),$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__83502$$=$params__$1$jscomp$64$$;return $G__83502$$==null?null:$APP.$cljs$cst$2403$template$$.$cljs$core$IFn$_invoke$arity$1$($G__83502$$)}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Suspense$$,{children:[$show_question_modal_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$questions_modal$$,
{}):$APP.$cljs$core$truth_$$($show_team_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$onboarding_team_modal$$,{"go-to-team":!0}):$APP.$cljs$core$truth_$$($show_release_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$release_notes_modal$$,{version:$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$team_container_STAR_$$,{teamId:$index$jscomp$598_team_id$jscomp$174$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard_page_STAR_$$,
{profile:$profile$jscomp$85$$,section:$section$jscomp$57$$,teamId:$index$jscomp$598_team_id$jscomp$174$$,searchTerm:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,pluginUrl:$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,projectId:$project_id$jscomp$56_share_id$jscomp$37$$,template:$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$})})]});case "workspace":return $params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$462$$,
$APP.$cljs$cst$747$query$$),$index$jscomp$598_team_id$jscomp$174$$=function(){var $G__83503_G__83503__$1$$=$params__$1$jscomp$64$$;$G__83503_G__83503__$1$$=$G__83503_G__83503__$1$$==null?null:$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83503_G__83503__$1$$);return $G__83503_G__83503__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83503_G__83503__$1$$)}(),$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=function(){var $G__83504_G__83504__$1$$=
$params__$1$jscomp$64$$;$G__83504_G__83504__$1$$=$G__83504_G__83504__$1$$==null?null:$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83504_G__83504__$1$$);return $G__83504_G__83504__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83504_G__83504__$1$$)}(),$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__83505_G__83505__$1$$=$params__$1$jscomp$64$$;$G__83505_G__83505__$1$$=$G__83505_G__83505__$1$$==null?null:$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83505_G__83505__$1$$);
return $G__83505_G__83505__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83505_G__83505__$1$$)}(),$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__83506_G__83506__$1$$=$params__$1$jscomp$64$$;$G__83506_G__83506__$1$$=$G__83506_G__83506__$1$$==null?null:$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($G__83506_G__83506__$1$$);return $G__83506_G__83506__$1$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__83506_G__83506__$1$$)}(),
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Suspense$$,{children:[$APP.$cljs$core$truth_$$($APP.$app$config$external_feature_flag$$("onboarding-03"))?$show_question_modal_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$questions_modal$$,{}):$APP.$cljs$core$truth_$$($show_team_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$onboarding_team_modal$$,{"go-to-team":!1}):$APP.$cljs$core$truth_$$($show_release_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$release_notes_modal$$,
{version:$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)}):null:null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$team_container_STAR_$$,{teamId:$index$jscomp$598_team_id$jscomp$174$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace_page_STAR_$$,{teamId:$index$jscomp$598_team_id$jscomp$174$$,fileId:$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,pageId:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,
layoutName:$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$},$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$)})]});case "viewer":$params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$462$$,$APP.$cljs$cst$747$query$$);$index$jscomp$598_team_id$jscomp$174$$=function(){var $G__83509$$=$APP.$app$main$router$get_query_param$$($params__$1$jscomp$64$$,$APP.$cljs$cst$1795$index$$);return $G__83509$$==null?null:
$APP.$cljs$core$parse_long$$($G__83509$$)}();$project_id$jscomp$56_share_id$jscomp$37$$=function(){var $G__83510$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__83510$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83510$$)}();$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__83511$jscomp$inline_9875_or__5025__auto__$jscomp$1422$$=$APP.$cljs$cst$1366$section$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);
$G__83511$jscomp$inline_9875_or__5025__auto__$jscomp$1422$$=$G__83511$jscomp$inline_9875_or__5025__auto__$jscomp$1422$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__83511$jscomp$inline_9875_or__5025__auto__$jscomp$1422$$);return $APP.$cljs$core$truth_$$($G__83511$jscomp$inline_9875_or__5025__auto__$jscomp$1422$$)?$G__83511$jscomp$inline_9875_or__5025__auto__$jscomp$1422$$:$APP.$cljs$cst$2051$interactions$$}();$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=
function(){var $G__83512$$=$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__83512$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83512$$)}();$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__83513$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__83513$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83513$$)}();var $imode_interactions_mode$jscomp$11$$=
function(){var $G__83514$jscomp$inline_9877_or__5025__auto__$jscomp$1423$$=$APP.$cljs$cst$5231$interactions_mode$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);$G__83514$jscomp$inline_9877_or__5025__auto__$jscomp$1423$$=$G__83514$jscomp$inline_9877_or__5025__auto__$jscomp$1423$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__83514$jscomp$inline_9877_or__5025__auto__$jscomp$1423$$);return $APP.$cljs$core$truth_$$($G__83514$jscomp$inline_9877_or__5025__auto__$jscomp$1423$$)?
$G__83514$jscomp$inline_9877_or__5025__auto__$jscomp$1423$$:$APP.$cljs$cst$5234$show_on_click$$}(),$frame_id$jscomp$160$$=function(){var $G__83515$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__83515$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83515$$)}(),$map__83534__$1_share$jscomp$8$$=$APP.$cljs$cst$5399$share$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer_page_STAR_$$,
{pageId:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,fileId:$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,frameId:$frame_id$jscomp$160$$,section:$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$,index:$index$jscomp$598_team_id$jscomp$174$$,shareId:$project_id$jscomp$56_share_id$jscomp$37$$,interactionsMode:$imode_interactions_mode$jscomp$11$$,share:$map__83534__$1_share$jscomp$8$$})});case "workspace-legacy":return $project_id$jscomp$56_share_id$jscomp$37$$=
function(){var $G__83516__$1_G__83516__$2$$=$params$jscomp$462$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);$G__83516__$1_G__83516__$2$$=$G__83516__$1_G__83516__$2$$==null?null:$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83516__$1_G__83516__$2$$);return $G__83516__$1_G__83516__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83516__$1_G__83516__$2$$)}(),$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=
function(){var $G__83517__$1_G__83517__$2$$=$params$jscomp$462$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);$G__83517__$1_G__83517__$2$$=$G__83517__$1_G__83517__$2$$==null?null:$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83517__$1_G__83517__$2$$);return $G__83517__$1_G__83517__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83517__$1_G__83517__$2$$)}(),$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=
function(){var $G__83521__$1_G__83521__$2$$=$params$jscomp$462$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);$G__83521__$1_G__83521__$2$$=$G__83521__$1_G__83521__$2$$==null?null:$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83521__$1_G__83521__$2$$);return $G__83521__$1_G__83521__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83521__$1_G__83521__$2$$)}(),$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__83522__$1_G__83522__$2$$=
$params$jscomp$462$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);$G__83522__$1_G__83522__$2$$=$G__83522__$1_G__83522__$2$$==null?null:$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($G__83522__$1_G__83522__$2$$);return $G__83522__$1_G__83522__$2$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__83522__$1_G__83522__$2$$)}(),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace_legacy_redirect_STAR_$$,{projectId:$project_id$jscomp$56_share_id$jscomp$37$$,
fileId:$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,pageId:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,layout:$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$});case "dashboard-legacy-search":case "dashboard-legacy-projects":case "dashboard-legacy-files":case "dashboard-legacy-libraries":case "dashboard-legacy-fonts":case "dashboard-legacy-font-providers":case "dashboard-legacy-team-members":case "dashboard-legacy-team-invitations":case "dashboard-legacy-team-webhooks":case "dashboard-legacy-team-settings":return $index$jscomp$598_team_id$jscomp$174$$=
function(){var $G__83525__$1_G__83525__$2$$=$params$jscomp$462$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);$G__83525__$1_G__83525__$2$$=$G__83525__$1_G__83525__$2$$==null?null:$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83525__$1_G__83525__$2$$);return $G__83525__$1_G__83525__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83525__$1_G__83525__$2$$)}(),$project_id$jscomp$56_share_id$jscomp$37$$=function(){var $G__83526__$1_G__83526__$2$$=
$params$jscomp$462$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);$G__83526__$1_G__83526__$2$$=$G__83526__$1_G__83526__$2$$==null?null:$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83526__$1_G__83526__$2$$);return $G__83526__$1_G__83526__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__83526__$1_G__83526__$2$$)}(),$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__83528__$1$$=
$params$jscomp$462$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);return $G__83528__$1$$==null?null:$APP.$cljs$cst$2516$search_term$$.$cljs$core$IFn$_invoke$arity$1$($G__83528__$1$$)}(),$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=function(){var $G__83529__$1$$=$params$jscomp$462$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$);return $G__83529__$1$$==null?null:
$APP.$cljs$cst$3402$plugin$$.$cljs$core$IFn$_invoke$arity$1$($G__83529__$1$$)}(),$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$=$params$jscomp$462$$==null?null:$APP.$cljs$cst$2403$template$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$462$$),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard_legacy_redirect_STAR_$$,{teamId:$index$jscomp$598_team_id$jscomp$174$$,section:$section$jscomp$57$$,projectId:$project_id$jscomp$56_share_id$jscomp$37$$,searchTerm:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,
pluginUrl:$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,template:$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$});case "viewer-legacy":return $file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($route$jscomp$25$$),$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,
$APP.$cljs$cst$2269$query_params$$),$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,$APP.$cljs$cst$2395$path_params$$),$map__83534__$1_share$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$),$index$jscomp$598_team_id$jscomp$174$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83534__$1_share$jscomp$8$$,$APP.$cljs$cst$1795$index$$),$project_id$jscomp$56_share_id$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83534__$1_share$jscomp$8$$,$APP.$cljs$cst$3237$share_id$$),$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__83534__$1_share$jscomp$8$$,$APP.$cljs$cst$1366$section$$,$APP.$cljs$cst$2051$interactions$$),$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83534__$1_share$jscomp$8$$,$APP.$cljs$cst$2043$page_id$$),$imode_interactions_mode$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__83534__$1_share$jscomp$8$$,$APP.$cljs$cst$5231$interactions_mode$$,$APP.$cljs$cst$5234$show_on_click$$),$frame_id$jscomp$160$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83534__$1_share$jscomp$8$$,$APP.$cljs$cst$1607$frame_id$$),$map__83534__$1_share$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83534__$1_share$jscomp$8$$,
$APP.$cljs$cst$5399$share$$),$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$),$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,$APP.$cljs$cst$1644$file_id$$),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer_legacy_redirect_STAR_$$,{pageId:$error_report_id$jscomp$1_page_id$jscomp$479_query_params$jscomp$3_search_term$jscomp$10$$,fileId:$file_id$jscomp$462_map__83533__$1_map__83535__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,section:$layout$jscomp$39_section__$1$jscomp$5_template$jscomp$14$$,index:$index$jscomp$598_team_id$jscomp$174$$,shareId:$project_id$jscomp$56_share_id$jscomp$37$$,interactionsMode:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($imode_interactions_mode$jscomp$11$$),
frameId:$frame_id$jscomp$160$$,share:$map__83534__$1_share$jscomp$8$$});case "frame-preview":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$frame_preview$frame_preview$$,{});default:return null}}()})},$app$main$ui$app$$=function(){var $route$jscomp$26$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$),$edata$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$exception$$),$profile$jscomp$86$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$app$util$theme$use_initialize$$($profile$jscomp$86$$);
document.documentElement.style.overscrollBehaviorX="none";document.body.style.overscrollBehaviorX="none";return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_route$$),{value:$route$jscomp$26$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_profile$$),{value:$profile$jscomp$86$$,children:$APP.$cljs$core$truth_$$($edata$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$exception_page_STAR_$$,{data:$edata$jscomp$1$$,
route:$route$jscomp$26$$}):(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$error_boundary$error_boundary_STAR_$$,{fallback:$app$main$ui$static$0$exception_page_STAR_$$,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$notifications$current_notification_STAR_$$,{}),$APP.$cljs$core$truth_$$($route$jscomp$26$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$page_STAR_$$,{route:$route$jscomp$26$$,profile:$profile$jscomp$86$$}):null]})})})},$app$main$ui$alert$alert_dialog$$=function($map__83336_props_83333_scd_message$$){$map__83336_props_83333_scd_message$$=
$APP.$rumext$v2$util$wrap_props$$($map__83336_props_83333_scd_message$$);var $map__83336__$1$$=$APP.$cljs$core$__destructure_map$$($map__83336_props_83333_scd_message$$),$message$jscomp$125_message__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,$APP.$cljs$cst$141$message$$);$map__83336_props_83333_scd_message$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,$APP.$cljs$cst$5135$scd_message$$);var $link_message$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,
$APP.$cljs$cst$3383$link_message$$),$title$jscomp$51_title__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,$APP.$cljs$cst$939$title$$),$accept_fn$jscomp$3_on_accept$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,$APP.$cljs$cst$2479$on_accept$$),$hint$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,$APP.$cljs$cst$275$hint$$),$accept_label$jscomp$1_accept_label__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,
$APP.$cljs$cst$2476$accept_label$$),$accept_style_accept_style__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83336__$1$$,$APP.$cljs$cst$2477$accept_style$$),$on_accept__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($accept_fn$jscomp$3_on_accept$jscomp$19$$)?$accept_fn$jscomp$3_on_accept$jscomp$19$$:$APP.$cljs$core$identity$$;$message$jscomp$125_message__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($message$jscomp$125_message__$1$jscomp$1$$)?$message$jscomp$125_message__$1$jscomp$1$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.alert-title");
$accept_label$jscomp$1_accept_label__$1$$=$APP.$cljs$core$truth_$$($accept_label$jscomp$1_accept_label__$1$$)?$accept_label$jscomp$1_accept_label__$1$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.alert-ok");$accept_style_accept_style__$1$$=$APP.$cljs$core$truth_$$($accept_style_accept_style__$1$$)?$accept_style_accept_style__$1$$:$APP.$cljs$cst$5158$danger$$;$title$jscomp$51_title__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($title$jscomp$51_title__$1$jscomp$2$$)?$title$jscomp$51_title__$1$jscomp$2$$:
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.alert-title");$accept_fn$jscomp$3_on_accept$jscomp$19$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$781$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$781$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_accept__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($map__83336__$1$$):
$on_accept__$1$jscomp$1$$($map__83336__$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$APP.$goog$events$listen$$(document,"keydown",function($event$jscomp$782$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$782$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$782$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$782$$),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$()),$on_accept__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($map__83336__$1$$):$on_accept__$1$jscomp$1$$($map__83336__$1$$)):null}))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_alert__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_alert__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_alert__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_alert__modal-title",children:$title$jscomp$51_title__$1$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$accept_fn$jscomp$3_on_accept$jscomp$19$$,className:"main_ui_alert__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_alert__modal-content",children:[typeof $message$jscomp$125_message__$1$jscomp$1$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($message$jscomp$125_message__$1$jscomp$1$$,
"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_alert__modal-msg",children:$message$jscomp$125_message__$1$jscomp$1$$}):null,$APP.$cljs$core$seq$$($link_message$$)?(0,$APP.$rumext$v2$jsxs$$)("h3",{className:"main_ui_alert__modal-msg",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$cljs$cst$3384$before$$.$cljs$core$IFn$_invoke$arity$1$($link_message$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$APP.$cljs$cst$3386$on_click$$.$cljs$core$IFn$_invoke$arity$1$($link_message$$),
"class":"main_ui_alert__link",children:$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($link_message$$)}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$cljs$cst$3385$after$$.$cljs$core$IFn$_invoke$arity$1$($link_message$$)})]}):null,typeof $map__83336_props_83333_scd_message$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__83336_props_83333_scd_message$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_alert__modal-scd-msg",children:$map__83336_props_83333_scd_message$$}):
null,typeof $hint$jscomp$30$$==="string"?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$1161$info$$,appearance:$APP.$cljs$cst$4985$ghost$$,children:$hint$jscomp$30$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_alert__modal-footer",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_alert__action-buttons",children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$accept_label$jscomp$1_accept_label__$1$$,
onClick:$accept_fn$jscomp$3_on_accept$jscomp$19$$,className:"main_ui_alert__accept-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style_accept_style__$1$$,$APP.$cljs$cst$5158$danger$$)?"main_ui_alert__danger":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style_accept_style__$1$$,$APP.$cljs$cst$2478$primary$$)?"main_ui_alert__primary":"")})})})]})})},$app$main$ui$confirm$confirm_dialog$$=function($items$jscomp$63_map__83338_props_83337$$){$items$jscomp$63_map__83338_props_83337$$=
$APP.$rumext$v2$util$wrap_props$$($items$jscomp$63_map__83338_props_83337$$);var $map__83338__$1$$=$APP.$cljs$core$__destructure_map$$($items$jscomp$63_map__83338_props_83337$$);$items$jscomp$63_map__83338_props_83337$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$1838$items$$);var $hint_level$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$5157$hint_level$$),$message__$1$jscomp$2_on_cancel$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,
$APP.$cljs$cst$5608$on_cancel$$),$accept_fn$jscomp$4_message$jscomp$126$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$141$message$$),$accept_style$jscomp$1_accept_style__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$2477$accept_style$$),$accept_label$jscomp$2_accept_label__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$2476$accept_label$$),$scd_message$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$5135$scd_message$$),$cancel_label$jscomp$1_cancel_label__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$2474$cancel_label$$),$hint$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$275$hint$$),$title$jscomp$52_title__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$939$title$$),
$error_msg$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$5372$error_msg$$),$cancel_fn$jscomp$1_on_accept$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83338__$1$$,$APP.$cljs$cst$2479$on_accept$$),$on_accept__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($cancel_fn$jscomp$1_on_accept$jscomp$20$$)?$cancel_fn$jscomp$1_on_accept$jscomp$20$$:$APP.$cljs$core$identity$$,$on_cancel__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($message__$1$jscomp$2_on_cancel$jscomp$13$$)?
$message__$1$jscomp$2_on_cancel$jscomp$13$$:$APP.$cljs$core$identity$$;$message__$1$jscomp$2_on_cancel$jscomp$13$$=$APP.$cljs$core$truth_$$($accept_fn$jscomp$4_message$jscomp$126$$)?$accept_fn$jscomp$4_message$jscomp$126$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-title");$cancel_label$jscomp$1_cancel_label__$1$$=$APP.$cljs$core$truth_$$($cancel_label$jscomp$1_cancel_label__$1$$)?$cancel_label$jscomp$1_cancel_label__$1$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel");
$accept_label$jscomp$2_accept_label__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($accept_label$jscomp$2_accept_label__$1$jscomp$1$$)?$accept_label$jscomp$2_accept_label__$1$jscomp$1$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-ok");$accept_style$jscomp$1_accept_style__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($accept_style$jscomp$1_accept_style__$1$jscomp$1$$)?$accept_style$jscomp$1_accept_style__$1$jscomp$1$$:$APP.$cljs$cst$5158$danger$$;$title$jscomp$52_title__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($title$jscomp$52_title__$1$jscomp$3$$)?
$title$jscomp$52_title__$1$jscomp$3$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-title");$accept_fn$jscomp$4_message$jscomp$126$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$783$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$783$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($map__83338__$1$$):
$on_accept__$1$jscomp$2$$($map__83338__$1$$)});$cancel_fn$jscomp$1_on_accept$jscomp$20$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$784$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$784$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_cancel__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_cancel__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($map__83338__$1$$):$on_cancel__$1$jscomp$1$$($map__83338__$1$$)});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$APP.$goog$events$listen$$(document,"keydown",function($event$jscomp$785$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$785$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$785$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$785$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$()),
$on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($map__83338__$1$$):$on_accept__$1$jscomp$2$$($map__83338__$1$$)):null}))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_confirm__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_confirm__modal-title",
children:$title$jscomp$52_title__$1$jscomp$3$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_confirm__modal-close-btn",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$cancel_fn$jscomp$1_on_accept$jscomp$20$$,icon:"close"})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__modal-content",children:[typeof $message__$1$jscomp$2_on_cancel$jscomp$13$$===
"string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($message__$1$jscomp$2_on_cancel$jscomp$13$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_confirm__modal-msg",children:$message__$1$jscomp$2_on_cancel$jscomp$13$$}):null,typeof $scd_message$jscomp$1$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($scd_message$jscomp$1$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_confirm__modal-scd-msg",children:$scd_message$jscomp$1$$}):null,typeof $hint$jscomp$31$$===
"string"?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$core$truth_$$($hint_level$$)?$hint_level$$:$APP.$cljs$cst$1161$info$$,appearance:$APP.$cljs$cst$4985$ghost$$,children:$hint$jscomp$31$$}):null,typeof $error_msg$jscomp$1$$==="string"?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$849$error$$,className:"main_ui_confirm__modal-error-msg",
children:$error_msg$jscomp$1$$}):null,$APP.$cljs$core$count$$($items$jscomp$63_map__83338_props_83337$$)>0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_confirm__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.component-subtitle")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_confirm__component-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$260$$,
$item$jscomp$151$$){$out_arr__44124__auto__$jscomp$260$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_confirm__modal-item-element",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"component",className:"main_ui_confirm__modal-component-icon",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_confirm__modal-component-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$151$$)})]}));return $out_arr__44124__auto__$jscomp$260$$},
[],$items$jscomp$63_map__83338_props_83337$$)})]}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_confirm__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__action-buttons",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cancel_label$jscomp$1_cancel_label__$1$$,$APP.$cljs$cst$2475$omit$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",onClick:$cancel_fn$jscomp$1_on_accept$jscomp$20$$,
children:$cancel_label$jscomp$1_cancel_label__$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$1_accept_style__$1$jscomp$1$$,$APP.$cljs$cst$5158$danger$$)?"destructive":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$1_accept_style__$1$jscomp$1$$,$APP.$cljs$cst$2478$primary$$)?"primary":null,onClick:$accept_fn$jscomp$4_message$jscomp$126$$,children:$accept_label$jscomp$2_accept_label__$1$jscomp$1$$})]})})]})})},
$app$main$ui$delete_shared$delete_shared_dialog$$=function($props_83341_references$jscomp$10$$){var $cancel_label$jscomp$2_on_cancel$jscomp$14$$=$props_83341_references$jscomp$10$$["on-cancel"],$accept_style$jscomp$2_accept_style__$1$jscomp$2$$=$props_83341_references$jscomp$10$$["accept-style"],$count_libraries$$=$props_83341_references$jscomp$10$$["count-libraries"],$ids$jscomp$321$$=$props_83341_references$jscomp$10$$.ids,$on_accept$jscomp$21_title$jscomp$53$$=$props_83341_references$jscomp$10$$["on-accept"],
$origin$jscomp$77$$=$props_83341_references$jscomp$10$$.origin,$references_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$props_83341_references$jscomp$10$$=$APP.$cljs$core$_deref$$($references_STAR_$$);var $on_accept__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($on_accept$jscomp$21_title$jscomp$53$$)?$on_accept$jscomp$21_title$jscomp$53$$:$app$main$ui$delete_shared$noop$$,$on_cancel__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($cancel_label$jscomp$2_on_cancel$jscomp$14$$)?$cancel_label$jscomp$2_on_cancel$jscomp$14$$:
$app$main$ui$delete_shared$noop$$;$cancel_label$jscomp$2_on_cancel$jscomp$14$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel");$accept_style$jscomp$2_accept_style__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($accept_style$jscomp$2_accept_style__$1$jscomp$2$$)?$accept_style$jscomp$2_accept_style__$1$jscomp$2$$:$APP.$cljs$cst$5158$danger$$;var $count_files_hint$jscomp$32$$=$APP.$cljs$core$count$$($APP.$cljs$core$keys$$($props_83341_references$jscomp$10$$));$on_accept$jscomp$21_title$jscomp$53$$=
function(){var $G__83344__$1$$=$origin$jscomp$77$$ instanceof $APP.$cljs$core$Keyword$$?$origin$jscomp$77$$.$fqn$:null;switch($G__83344__$1$$){case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "unpublish":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.unpublish-shared-confirm.title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.move-shared-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83344__$1$$)].join(""));}}();var $subtitle$jscomp$2$$=function(){var $G__83347__$1$$=
$origin$jscomp$77$$ instanceof $APP.$cljs$core$Keyword$$?$origin$jscomp$77$$.$fqn$:null;switch($G__83347__$1$$){case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "unpublish":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.unpublish-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));
case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.move-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83347__$1$$)].join(""));}}(),$accept_label$jscomp$3$$=function(){var $G__83350__$1$$=$origin$jscomp$77$$ instanceof $APP.$cljs$core$Keyword$$?$origin$jscomp$77$$.$fqn$:null;
switch($G__83350__$1$$){case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.accept",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "unpublish":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.unpublish-shared-confirm.accept",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.move-shared-confirm.accept",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83350__$1$$)].join(""));}}(),$no_files_msg$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.activated.no-files-message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)])),$scd_msg$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.activated.scd-message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));$count_files_hint$jscomp$32$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-unpublish-shared-confirm.activated.hint",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_files_hint$jscomp$32$$)]));var $accept_fn$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept__$1$jscomp$3$$)],
function($event$jscomp$786$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$786$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_accept__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_accept__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_accept__$1$jscomp$3$$()}),$cancel_fn$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel__$1$jscomp$2$$)],function($event$jscomp$787$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$787$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_cancel__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel__$1$jscomp$2$$()});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$321$$)],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83340_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($references_STAR_$$,
$p1__83340_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$),$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$identity$$,$APP.$beicon$v2$core$mapcat$$(function($p1__83339_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6370$get_library_file_references$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$p1__83339_SHARP_$$],null))},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$from$$($ids$jscomp$321$$)))))))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($accept_fn$jscomp$5$$)],function(){var $key$jscomp$435$$=$APP.$goog$events$listen$$(document,"keydown",function($event$jscomp$788$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$788$$))?
($APP.$app$util$dom$prevent_default$$($event$jscomp$788$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$788$$),$accept_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$accept_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$accept_fn$jscomp$5$$()):null});return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$key$jscomp$435$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_delete_shared__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_delete_shared__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_delete_shared__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_delete_shared__modal-title",children:$on_accept$jscomp$21_title$jscomp$53$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$cancel_fn$jscomp$2$$,className:"main_ui_delete_shared__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_delete_shared__modal-content",
children:[typeof $subtitle$jscomp$2$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subtitle$jscomp$2$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_delete_shared__modal-subtitle",children:$subtitle$jscomp$2$$}):null,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$count_libraries$$)?$APP.$cljs$core$count$$($props_83341_references$jscomp$10$$)>0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[typeof $scd_msg$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($scd_msg$$,
"")?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_delete_shared__modal-scd-msg",children:$scd_msg$$}):null,(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_delete_shared__element-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$261$$,$file_name$jscomp$14_p__83358$$){var $file_id$jscomp$463$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_name$jscomp$14_p__83358$$,0,null);$file_name$jscomp$14_p__83358$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_name$jscomp$14_p__83358$$,
1,null);$out_arr__44124__auto__$jscomp$261$$.push((0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_delete_shared__list-item",children:(0,$APP.$rumext$v2$jsxs$$)("span",{children:["- ",$file_name$jscomp$14_p__83358$$]})},""+($file_id$jscomp$463$$??"")));return $out_arr__44124__auto__$jscomp$261$$},[],$props_83341_references$jscomp$10$$)}),typeof $count_files_hint$jscomp$32$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($count_files_hint$jscomp$32$$,"")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,
{level:$APP.$cljs$cst$1161$info$$,appearance:$APP.$cljs$cst$4985$ghost$$,children:$count_files_hint$jscomp$32$$}):null]}):(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_delete_shared__modal-msg",children:$no_files_msg$$})}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_delete_shared__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_delete_shared__action-buttons",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cancel_label$jscomp$2_on_cancel$jscomp$14$$,
$APP.$cljs$cst$2475$omit$$)?null:(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$cancel_label$jscomp$2_on_cancel$jscomp$14$$,onClick:$cancel_fn$jscomp$2$$,className:"main_ui_delete_shared__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$accept_label$jscomp$3$$,onClick:$accept_fn$jscomp$5$$,className:"main_ui_delete_shared__accept-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$2_accept_style__$1$jscomp$2$$,$APP.$cljs$cst$5158$danger$$)?
"main_ui_delete_shared__danger":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$2_accept_style__$1$jscomp$2$$,$APP.$cljs$cst$2478$primary$$)?"main_ui_delete_shared__primary":"")})]})})]})})},$app$main$ui$routes$on_navigate$$=function($match$jscomp$60_router$jscomp$9$$,$path$jscomp$299$$,$send_event_info_QMARK_$jscomp$2$$){var $location__$1$jscomp$2_valid_location_QMARK_$$=document.location,$qs_vec__83447$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($path$jscomp$299$$,
"?"),$base_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($qs_vec__83447$$,0,null);$qs_vec__83447$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($qs_vec__83447$$,1,null);$location__$1$jscomp$2_valid_location_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(""+($location__$1$jscomp$2_valid_location_QMARK_$$.origin??"")+($location__$1$jscomp$2_valid_location_QMARK_$$.pathname??""),""+($APP.$app$config$public_uri$$??""));$match$jscomp$60_router$jscomp$9$$=
$app$main$router$match$$($match$jscomp$60_router$jscomp$9$$,$path$jscomp$299$$);var $empty_path_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_path$$,"")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_path$$,"/"),$query_params$jscomp$4$$=$APP.$lambdaisland$uri$query_string__GT_map$cljs$0core$0IFn$0_invoke$0arity$02$$($qs_vec__83447$$);return $location__$1$jscomp$2_valid_location_QMARK_$$?$match$jscomp$60_router$jscomp$9$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$router$navigated$$($match$jscomp$60_router$jscomp$9$$,
$send_event_info_QMARK_$jscomp$2$$)):$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($map__83451__$1_p__83450_template$jscomp$inline_9882$$){$map__83451__$1_p__83450_template$jscomp$inline_9882$$=$APP.$cljs$core$__destructure_map$$($map__83451__$1_p__83450_template$jscomp$inline_9882$$);var $_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83451__$1_p__83450_template$jscomp$inline_9882$$,
$APP.$cljs$cst$266$id$$),$map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83451__$1_p__83450_template$jscomp$inline_9882$$,$cljs$cst$6393$app_DOT_main_DOT_ui_DOT_routes_SLASH_teams$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$,$APP.$app$common$uuid$zero$$)){$map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$=
$APP.$cljs$core$__destructure_map$$($query_params$jscomp$4$$);$map__83451__$1_p__83450_template$jscomp$inline_9882$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$,$APP.$cljs$cst$2403$template$$);$map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$,$APP.$cljs$cst$3402$plugin$$);
$_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$map__83451__$1_p__83450_template$jscomp$inline_9882$$!=null&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$session$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2403$template$$,$map__83451__$1_p__83450_template$jscomp$inline_9882$$),$map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$!=
null&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$session$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$6301$plugin_url$$,$map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3356$auth_login$$))}return $empty_path_QMARK_$$?
($_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$=$APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$global$$),$APP.$cljs$core$contains_QMARK_$$($map__83376__$1$jscomp$inline_9881_plugin$jscomp$inline_9883_teams$jscomp$22$$,$_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2522$dashboard_recent$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($query_params$jscomp$4$$,$APP.$cljs$cst$1927$team_id$$,$_STAR_sync_STAR__orig_val__83377$jscomp$inline_9884_id$jscomp$1081_team_id$jscomp$175$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2522$dashboard_recent$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($query_params$jscomp$4$$,$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__83451__$1_p__83450_template$jscomp$inline_9882$$))))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2665$not_found$$],null)))},function($cause$jscomp$115$$){return $APP.$app$main$errors$on_error$$($cause$jscomp$115$$)},$APP.$beicon$v2$core$mapcat$$(function($profile$jscomp$88$$){return $APP.$beicon$v2$core$map$$(function($teams$jscomp$23$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($profile$jscomp$88$$,
$cljs$cst$6393$app_DOT_main_DOT_ui_DOT_routes_SLASH_teams$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$teams$jscomp$23$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3262$get_teams$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3204$get_profile$$))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2665$not_found$$],null)))},$app$main$ui$routes$init_routes$$=function(){typeof $app$main$ui$routes$init_routes_83454$$==="undefined"&&($app$main$ui$routes$init_routes_83454$$=function($meta83455$$){this.$meta83455$=$meta83455$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$ui$routes$init_routes_83454$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$ui$routes$init_routes_83454$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6394$app_DOT_main_DOT_ui_DOT_routes_SLASH_init_routes$$},$app$main$ui$routes$init_routes_83454$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_83456$$,$meta83455__$1$$){return new $app$main$ui$routes$init_routes_83454$$($meta83455__$1$$)},$app$main$ui$routes$init_routes_83454$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta83455$},$app$main$ui$routes$init_routes_83454$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$ui$routes$init_routes_83454$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3186$$,$___$1$jscomp$2108$$,$stream$jscomp$111$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$router$initialize_router$$(),$app$main$router$initialize_history$$()),$APP.$beicon$v2$core$map$$($APP.$app$main$features$recompute_features$$,
$APP.$beicon$v2$core$filter$$(function($p__83478_v2$jscomp$36$$){var $v1$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83478_v2$jscomp$36$$,0,null);$p__83478_v2$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83478_v2$jscomp$36$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v1$jscomp$45$$,$p__83478_v2$jscomp$36$$)},$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$map$$(function($p1__83453_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__83453_SHARP_$$,
$APP.$cljs$cst$2269$query_params$$),$APP.$cljs$cst$3104$wasm$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2454$app_DOT_main_DOT_router_SLASH_navigated$$),$stream$jscomp$111$$)))))))});return new $app$main$ui$routes$init_routes_83454$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$plugins$image_data$create_image_data$$=function($obj_83380_p__83373$$){var $map__83374__$1$$=
$APP.$cljs$core$__destructure_map$$($obj_83380_p__83373$$),$name$jscomp$510$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83374__$1$$,$APP.$cljs$cst$725$name$$),$width$jscomp$258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83374__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83374__$1$$,$APP.$cljs$cst$1522$height$$),$mtype$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83374__$1$$,
$APP.$cljs$cst$1726$mtype$$),$id$jscomp$1082$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83374__$1$$,$APP.$cljs$cst$266$id$$),$keep_aspect_ratio$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83374__$1$$,$APP.$cljs$cst$1727$keep_aspect_ratio$$);$obj_83380_p__83373$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_83380_p__83373$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ImageData"}});Object.defineProperty($obj_83380_p__83373$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ImageData"}});Object.defineProperty($obj_83380_p__83373$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($name$jscomp$510$$).call(this)}});Object.defineProperty($obj_83380_p__83373$$,"width",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($width$jscomp$258$$).call(this)}});Object.defineProperty($obj_83380_p__83373$$,"height",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($height$jscomp$224$$).call(this)}});
Object.defineProperty($obj_83380_p__83373$$,"mtype",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($mtype$jscomp$24$$).call(this)}});Object.defineProperty($obj_83380_p__83373$$,"id",{enumerable:!0,get:function(){return $APP.$cljs$core$truth_$$($id$jscomp$1082$$)?""+($id$jscomp$1082$$??""):null}});Object.defineProperty($obj_83380_p__83373$$,"keepAspectRatio",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($keep_aspect_ratio$jscomp$1$$).call(this)}});Object.defineProperty($obj_83380_p__83373$$,
"data",{enumerable:!1,get:function(){return function(){var $url$jscomp$104$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($map__83374__$1$$);return new Promise(function($resolve$jscomp$41$$,$reject$jscomp$28$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$41$$,$reject$jscomp$28$$,$APP.$beicon$v2$core$map$$(function($p1__83371_SHARP_$$){return new Uint8Array($p1__83371_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__83370_SHARP_$$){return $p1__83370_SHARP_$$.arrayBuffer()},
$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$url$jscomp$104$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$],null))))))})}.bind(this)}});return $obj_83380_p__83373$$},$app$plugins$format$format_id$$=function($id$jscomp$1083$$){return $APP.$cljs$core$truth_$$($id$jscomp$1083$$)?""+($id$jscomp$1083$$??""):null},
$app$plugins$format$format_key$$=function($kw$jscomp$4$$){return $APP.$cljs$core$truth_$$($kw$jscomp$4$$)?$APP.$app$common$data$name$$($kw$jscomp$4$$):null},$app$plugins$format$format_array$$=function($format_fn$$,$coll$jscomp$1105$$){return $coll$jscomp$1105$$!=null?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($format_fn$$,$coll$jscomp$1105$$)):null},$app$plugins$format$format_mixed$$=function($value$jscomp$1019$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1019$$,
$APP.$cljs$cst$1616$multiple$$)?"mixed":$value$jscomp$1019$$},$app$plugins$format$format_point$$=function($map__83524__$1_p__83523$$){$map__83524__$1_p__83523$$=$APP.$cljs$core$__destructure_map$$($map__83524__$1_p__83523$$);var $x$jscomp$1366$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83524__$1_p__83523$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$550$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83524__$1_p__83523$$,$APP.$cljs$cst$1511$y$$);return $map__83524__$1_p__83523$$!=
null?$app$util$object$without_empty$$({x:$x$jscomp$1366$$,y:$y$jscomp$550$$}):null},$app$plugins$format$shape_type$$=function($type$jscomp$728$$){switch($type$jscomp$728$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$728$$.$fqn$:null){case "frame":return"board";case "rect":return"rectangle";case "circle":return"ellipse";default:return $APP.$app$common$data$name$$($type$jscomp$728$$)}},$app$plugins$format$format_bounds$$=function($map__83532__$1_p__83531$$){$map__83532__$1_p__83531$$=$APP.$cljs$core$__destructure_map$$($map__83532__$1_p__83531$$);
var $x$jscomp$1367$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83532__$1_p__83531$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$551$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83532__$1_p__83531$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$259$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83532__$1_p__83531$$,$APP.$cljs$cst$290$width$$),$height$jscomp$225$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83532__$1_p__83531$$,$APP.$cljs$cst$1522$height$$);
return $map__83532__$1_p__83531$$!=null?$app$util$object$without_empty$$({x:$x$jscomp$1367$$,y:$y$jscomp$551$$,width:$width$jscomp$259$$,height:$height$jscomp$225$$}):null},$app$plugins$format$format_shape_info$$=function($map__83537__$1_p__83536$$){$map__83537__$1_p__83536$$=$APP.$cljs$core$__destructure_map$$($map__83537__$1_p__83536$$);var $prop$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83537__$1_p__83536$$,$APP.$cljs$cst$4158$prop$$),$shape_id$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83537__$1_p__83536$$,
$APP.$cljs$cst$2543$shape_id$$),$index$jscomp$599$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83537__$1_p__83536$$,$APP.$cljs$cst$1795$index$$);return $map__83537__$1_p__83536$$!=null?$app$util$object$without_empty$$({property:$APP.$app$common$data$name$$($prop$jscomp$45$$),index:$index$jscomp$599$$,shapeId:""+($shape_id$jscomp$181$$??"")}):null},$app$plugins$format$format_stop$$=function($map__83540__$1_p__83539$$){$map__83540__$1_p__83539$$=$APP.$cljs$core$__destructure_map$$($map__83540__$1_p__83539$$);
var $color$jscomp$239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83540__$1_p__83539$$,$APP.$cljs$cst$1298$color$$),$opacity$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83540__$1_p__83539$$,$APP.$cljs$cst$1734$opacity$$),$offset$jscomp$221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83540__$1_p__83539$$,$APP.$cljs$cst$195$offset$$);return $map__83540__$1_p__83539$$!=null?$app$util$object$without_empty$$({color:$color$jscomp$239$$,opacity:$opacity$jscomp$53$$,
offset:$offset$jscomp$221$$}):null},$app$plugins$format$format_gradient$$=function($map__83542__$1_p__83541$$){$map__83542__$1_p__83541$$=$APP.$cljs$core$__destructure_map$$($map__83542__$1_p__83541$$);var $type$jscomp$729$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,$APP.$cljs$cst$139$type$$),$start_x$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,$APP.$cljs$cst$1729$start_x$$),$start_y$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,
$APP.$cljs$cst$1730$start_y$$),$end_x$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,$APP.$cljs$cst$1731$end_x$$),$end_y$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,$APP.$cljs$cst$1732$end_y$$),$width$jscomp$260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,$APP.$cljs$cst$290$width$$),$stops$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83542__$1_p__83541$$,
$APP.$cljs$cst$1733$stops$$);return $map__83542__$1_p__83541$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($type$jscomp$729$$),startX:$start_x$jscomp$7$$,startY:$start_y$jscomp$6$$,endX:$end_x$jscomp$6$$,endY:$end_y$jscomp$6$$,width:$width$jscomp$260$$,stops:$app$plugins$format$format_array$$($app$plugins$format$format_stop$$,$stops$jscomp$24$$)}):null},$app$plugins$format$format_image$$=function($image$jscomp$38$$){return $image$jscomp$38$$!=null?$app$plugins$image_data$create_image_data$$($image$jscomp$38$$):
null},$app$plugins$format$format_color$$=function($map__83544__$1_p__83543$$){$map__83544__$1_p__83543$$=$APP.$cljs$core$__destructure_map$$($map__83544__$1_p__83543$$);var $ref_id$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$1735$ref_id$$),$path$jscomp$300$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$296$path$$),$file_id$jscomp$464$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,
$APP.$cljs$cst$1644$file_id$$),$color$jscomp$240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$1298$color$$),$name$jscomp$511$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$725$name$$),$ref_file$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$1736$ref_file$$),$opacity$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,
$APP.$cljs$cst$1734$opacity$$),$id$jscomp$1084$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$266$id$$),$gradient$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$1724$gradient$$),$image$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83544__$1_p__83543$$,$APP.$cljs$cst$1612$image$$);if($map__83544__$1_p__83543$$!=null){var $id__$1$jscomp$23$$=function(){var $or__5025__auto__$jscomp$1440$$=
$app$plugins$format$format_id$$($id$jscomp$1084$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1440$$)?$or__5025__auto__$jscomp$1440$$:$app$plugins$format$format_id$$($ref_id$jscomp$13$$)}(),$file_id__$1$jscomp$13$$=function(){var $or__5025__auto__$jscomp$1441$$=$app$plugins$format$format_id$$($file_id$jscomp$464$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1441$$)?$or__5025__auto__$jscomp$1441$$:$app$plugins$format$format_id$$($ref_file$jscomp$13$$)}();return $app$util$object$without_empty$$({path:$path$jscomp$300$$,
color:$color$jscomp$240$$,name:$name$jscomp$511$$,refFile:$app$plugins$format$format_id$$($ref_file$jscomp$13$$),refId:$app$plugins$format$format_id$$($ref_id$jscomp$13$$),opacity:$opacity$jscomp$54$$,id:function(){var $or__5025__auto__$jscomp$1442$$=$app$plugins$format$format_id$$($id__$1$jscomp$23$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1442$$)?$or__5025__auto__$jscomp$1442$$:$app$plugins$format$format_id$$($ref_id$jscomp$13$$)}(),gradient:$app$plugins$format$format_gradient$$($gradient$jscomp$31$$),
image:$app$plugins$format$format_image$$($image$jscomp$39$$),fileId:function(){var $or__5025__auto__$jscomp$1443$$=$app$plugins$format$format_id$$($file_id__$1$jscomp$13$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1443$$)?$or__5025__auto__$jscomp$1443$$:$app$plugins$format$format_id$$($ref_file$jscomp$13$$)}()})}return null},$app$plugins$format$format_color_result$$=function($attrs$jscomp$185_p__83561_shapes_info$$){var $color$jscomp$241_color__$1$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$185_p__83561_shapes_info$$,
0,null);$attrs$jscomp$185_p__83561_shapes_info$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$185_p__83561_shapes_info$$,1,null);$attrs$jscomp$185_p__83561_shapes_info$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$format$format_shape_info$$,$attrs$jscomp$185_p__83561_shapes_info$$));$color$jscomp$241_color__$1$jscomp$37$$=$app$plugins$format$format_color$$($color$jscomp$241_color__$1$jscomp$37$$);
$APP.$app$util$object$set_BANG_$$($color$jscomp$241_color__$1$jscomp$37$$,"shapeInfo",$attrs$jscomp$185_p__83561_shapes_info$$);return $color$jscomp$241_color__$1$jscomp$37$$},$app$plugins$format$format_shadow$$=function($map__83590__$1_p__83572$$){$map__83590__$1_p__83572$$=$APP.$cljs$core$__destructure_map$$($map__83590__$1_p__83572$$);var $id$jscomp$1085$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,$APP.$cljs$cst$266$id$$),$style$jscomp$82$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,
$APP.$cljs$cst$1904$style$$),$offset_x$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,$APP.$cljs$cst$1653$blur$$),$spread$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,
$APP.$cljs$cst$1652$spread$$),$hidden$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,$APP.$cljs$cst$1620$hidden$$),$color$jscomp$242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83590__$1_p__83572$$,$APP.$cljs$cst$1298$color$$);return $map__83590__$1_p__83572$$!=null?$app$util$object$without_empty$$({id:$app$plugins$format$format_id$$($id$jscomp$1085$$),style:$app$plugins$format$format_key$$($style$jscomp$82$$),offsetX:$offset_x$jscomp$19$$,
offsetY:$offset_y$jscomp$20$$,blur:$blur$jscomp$15$$,spread:$spread$jscomp$9$$,hidden:$hidden$jscomp$12$$,color:$app$plugins$format$format_color$$($color$jscomp$242$$)}):null},$app$plugins$format$format_fill$$=function($map__83760__$1_p__83759$$){$map__83760__$1_p__83759$$=$APP.$cljs$core$__destructure_map$$($map__83760__$1_p__83759$$);var $fill_color$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_p__83759$$,$APP.$cljs$cst$1746$fill_color$$),$fill_opacity$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_p__83759$$,$APP.$cljs$cst$1747$fill_opacity$$),$fill_color_gradient$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_p__83759$$,$APP.$cljs$cst$1748$fill_color_gradient$$),$fill_color_ref_file$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_p__83759$$,$APP.$cljs$cst$1640$fill_color_ref_file$$),$fill_color_ref_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_p__83759$$,
$APP.$cljs$cst$1745$fill_color_ref_id$$),$fill_image$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_p__83759$$,$APP.$cljs$cst$1632$fill_image$$);return $map__83760__$1_p__83759$$!=null?$app$util$object$without_empty$$({fillColor:$fill_color$jscomp$6$$,fillOpacity:$fill_opacity$jscomp$3$$,fillColorGradient:$app$plugins$format$format_gradient$$($fill_color_gradient$jscomp$2$$),fillColorRefFile:$app$plugins$format$format_id$$($fill_color_ref_file$$),fillColorRefId:$app$plugins$format$format_id$$($fill_color_ref_id$$),
fillImage:$app$plugins$format$format_image$$($fill_image$jscomp$2$$)}):null},$app$plugins$format$format_fills$$=function($fills$jscomp$33$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fills$jscomp$33$$,$APP.$cljs$cst$1616$multiple$$)?"mixed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fills$jscomp$33$$,"mixed")?"mixed":$fills$jscomp$33$$!=null?$app$plugins$format$format_array$$($app$plugins$format$format_fill$$,$fills$jscomp$33$$):null},$app$plugins$format$format_stroke$$=
function($map__83764__$1_p__83763$$){$map__83764__$1_p__83763$$=$APP.$cljs$core$__destructure_map$$($map__83764__$1_p__83763$$);var $stroke_color_gradient$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1741$stroke_color_gradient$$),$stroke_cap_start$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1865$stroke_cap_start$$),$stroke_style$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,
$APP.$cljs$cst$1866$stroke_style$$),$stroke_color$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1739$stroke_color$$),$stroke_opacity$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1740$stroke_opacity$$),$stroke_alignment$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1868$stroke_alignment$$),$stroke_cap_end$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1869$stroke_cap_end$$),$stroke_color_ref_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1742$stroke_color_ref_id$$),$stroke_width$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,$APP.$cljs$cst$1655$stroke_width$$),$stroke_color_ref_file$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_p__83763$$,
$APP.$cljs$cst$1641$stroke_color_ref_file$$);return $map__83764__$1_p__83763$$!=null?$app$util$object$without_empty$$({strokeCapEnd:$app$plugins$format$format_key$$($stroke_cap_end$jscomp$1$$),strokeOpacity:$stroke_opacity$jscomp$1$$,strokeStyle:$app$plugins$format$format_key$$($stroke_style$jscomp$5$$),strokeColorRefFile:$app$plugins$format$format_id$$($stroke_color_ref_file$$),strokeColorRefId:$app$plugins$format$format_id$$($stroke_color_ref_id$$),strokeCapStart:$app$plugins$format$format_key$$($stroke_cap_start$jscomp$1$$),
strokeWidth:$stroke_width$jscomp$11$$,strokeColorGradient:$app$plugins$format$format_gradient$$($stroke_color_gradient$$),strokeColor:$stroke_color$jscomp$2$$,strokeAlignment:$app$plugins$format$format_key$$($stroke_alignment$jscomp$2$$)}):null},$app$plugins$format$format_export$$=function($map__83769__$1_p__83768$$){$map__83769__$1_p__83768$$=$APP.$cljs$core$__destructure_map$$($map__83769__$1_p__83768$$);var $type$jscomp$731$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83769__$1_p__83768$$,
$APP.$cljs$cst$139$type$$),$scale$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83769__$1_p__83768$$,$APP.$cljs$cst$1902$scale$$),$suffix$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83769__$1_p__83768$$,$APP.$cljs$cst$1371$suffix$$);return $map__83769__$1_p__83768$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($type$jscomp$731$$),scale:$scale$jscomp$39$$,suffix:$suffix$jscomp$32$$}):null},$app$plugins$format$format_frame_guide_column_params$$=
function($map__83772__$1_p__83771$$){$map__83772__$1_p__83771$$=$APP.$cljs$core$__destructure_map$$($map__83772__$1_p__83771$$);var $color$jscomp$243$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83772__$1_p__83771$$,$APP.$cljs$cst$1298$color$$),$type$jscomp$732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83772__$1_p__83771$$,$APP.$cljs$cst$139$type$$),$size$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83772__$1_p__83771$$,$APP.$cljs$cst$874$size$$),
$margin$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83772__$1_p__83771$$,$APP.$cljs$cst$1929$margin$$),$item_length$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83772__$1_p__83771$$,$APP.$cljs$cst$1930$item_length$$),$gutter$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83772__$1_p__83771$$,$APP.$cljs$cst$1931$gutter$$);return $map__83772__$1_p__83771$$!=null?$app$util$object$without_empty$$({color:$app$plugins$format$format_color$$($color$jscomp$243$$),
type:$app$plugins$format$format_key$$($type$jscomp$732$$),size:$size$jscomp$173$$,margin:$margin$jscomp$8$$,itemLength:$item_length$jscomp$4$$,gutter:$gutter$jscomp$6$$}):null},$app$plugins$format$format_frame_guide$$=function($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$){$map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$=$APP.$cljs$core$__destructure_map$$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$);
var $G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,$APP.$cljs$cst$139$type$$);if($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$!=null)switch($G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$=
$G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$ instanceof $APP.$cljs$core$Keyword$$?$G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$.$fqn$:null,$G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$){case "column":$map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$=
$APP.$cljs$core$__destructure_map$$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$);$G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,$APP.$cljs$cst$139$type$$);var $display$jscomp$inline_9889_display$jscomp$inline_9895_display$jscomp$inline_9901$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,$APP.$cljs$cst$1932$display$$),$params$jscomp$inline_9890_params$jscomp$inline_9896_params$jscomp$inline_9902$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,$APP.$cljs$cst$1430$params$$);
return $map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$),display:$display$jscomp$inline_9889_display$jscomp$inline_9895_display$jscomp$inline_9901$$,params:$app$plugins$format$format_frame_guide_column_params$$($params$jscomp$inline_9890_params$jscomp$inline_9896_params$jscomp$inline_9902$$)}):
null;case "row":return $map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$=$APP.$cljs$core$__destructure_map$$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$),$G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,
$APP.$cljs$cst$139$type$$),$display$jscomp$inline_9889_display$jscomp$inline_9895_display$jscomp$inline_9901$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,$APP.$cljs$cst$1932$display$$),$params$jscomp$inline_9890_params$jscomp$inline_9896_params$jscomp$inline_9902$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,
$APP.$cljs$cst$1430$params$$),$map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$),display:$display$jscomp$inline_9889_display$jscomp$inline_9895_display$jscomp$inline_9901$$,params:$app$plugins$format$format_frame_guide_column_params$$($params$jscomp$inline_9890_params$jscomp$inline_9896_params$jscomp$inline_9902$$)}):
null;case "square":return $map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$=$APP.$cljs$core$__destructure_map$$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$),$G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,
$APP.$cljs$cst$139$type$$),$display$jscomp$inline_9889_display$jscomp$inline_9895_display$jscomp$inline_9901$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,$APP.$cljs$cst$1932$display$$),$params$jscomp$inline_9890_params$jscomp$inline_9896_params$jscomp$inline_9902$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$,
$APP.$cljs$cst$1430$params$$),$map__83774__$1$jscomp$inline_9887_map__83776__$1$jscomp$inline_9893_map__83780__$1$jscomp$inline_9899_map__83782__$1_p__83781$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$),display:$display$jscomp$inline_9889_display$jscomp$inline_9895_display$jscomp$inline_9901$$,params:$app$plugins$format$format_frame_guide_column_params$$($params$jscomp$inline_9890_params$jscomp$inline_9896_params$jscomp$inline_9902$$)}):
null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83783__$1_type$jscomp$736_type$jscomp$inline_9888_type$jscomp$inline_9894_type$jscomp$inline_9900$$)].join(""));}else return null},$app$plugins$format$format_command$$=function($JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$){$JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$);
var $command$jscomp$24_x$jscomp$inline_9906$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$,$APP.$cljs$cst$1812$command$$),$JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$,$APP.$cljs$cst$1430$params$$);if($JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$!=
null){$JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$=$app$plugins$format$format_key$$($command$jscomp$24_x$jscomp$inline_9906$$);$JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$);$command$jscomp$24_x$jscomp$inline_9906$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,
$APP.$cljs$cst$1510$x$$);var $c2x$jscomp$inline_9907$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$APP.$cljs$cst$1817$c2x$$),$c2y$jscomp$inline_9908$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$APP.$cljs$cst$1818$c2y$$),$ry$jscomp$inline_9909$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,
$APP.$cljs$cst$1882$ry$$),$y$jscomp$inline_9910$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$APP.$cljs$cst$1511$y$$),$rx$jscomp$inline_9911$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$APP.$cljs$cst$1881$rx$$),$large_arc_flag$jscomp$inline_9912$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,
$cljs$cst$6395$large_arc_flag$$),$c1x$jscomp$inline_9913$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$APP.$cljs$cst$1815$c1x$$),$x_axis_rotation$jscomp$inline_9914$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$cljs$cst$6396$x_axis_rotation$$),$c1y$jscomp$inline_9915$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,
$APP.$cljs$cst$1816$c1y$$),$sweep_flag$jscomp$inline_9916$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$,$cljs$cst$6397$sweep_flag$$);$JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$=$JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$!=null?$app$util$object$without_empty$$({y:$y$jscomp$inline_9910$$,sweepFlag:$sweep_flag$jscomp$inline_9916$$,
rx:$rx$jscomp$inline_9911$$,c1x:$c1x$jscomp$inline_9913$$,largeArcFlag:$large_arc_flag$jscomp$inline_9912$$,c1y:$c1y$jscomp$inline_9915$$,x:$command$jscomp$24_x$jscomp$inline_9906$$,c2x:$c2x$jscomp$inline_9907$$,c2y:$c2y$jscomp$inline_9908$$,ry:$ry$jscomp$inline_9909$$,xAxisRotation:$x_axis_rotation$jscomp$inline_9914$$}):null;$JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$=$app$util$object$without_empty$$({command:$JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$,
params:$JSCompiler_inline_result$jscomp$2096_map__83785__$1$jscomp$inline_9905_params$jscomp$468$$})}else $JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$=null;return $JSCompiler_temp$jscomp$2094_JSCompiler_temp_const$jscomp$2095_map__83789__$1_p__83788$$},$app$plugins$format$format_track$$=function($map__83792__$1_p__83791$$){$map__83792__$1_p__83791$$=$APP.$cljs$core$__destructure_map$$($map__83792__$1_p__83791$$);var $type$jscomp$737$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_p__83791$$,
$APP.$cljs$cst$139$type$$),$value$jscomp$1021$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_p__83791$$,$APP.$cljs$cst$260$value$$);return $map__83792__$1_p__83791$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($type$jscomp$737$$),value:$value$jscomp$1021$$}):null},$app$plugins$format$format_tracks$$=function($tracks$jscomp$7$$){return $tracks$jscomp$7$$!=null?$app$plugins$format$format_array$$($app$plugins$format$format_track$$,$tracks$jscomp$7$$):
null},$app$plugins$format$format_animation$$=function($animation$jscomp$16$$){return $APP.$cljs$core$truth_$$($animation$jscomp$16$$)?$app$util$object$without_empty$$(function(){var $G__83794$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$);switch($G__83794$$ instanceof $APP.$cljs$core$Keyword$$?$G__83794$$.$fqn$:null){case "dissolve":return{type:"dissolve",duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$),
easing:$app$plugins$format$format_key$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$))};case "slide":return{type:"slide",way:$app$plugins$format$format_key$$($APP.$cljs$cst$1962$way$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),direction:$app$plugins$format$format_key$$($APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$),
easing:$app$plugins$format$format_key$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),offsetEffect:$APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)};case "push":return{type:"push",direction:$app$plugins$format$format_key$$($APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$),easing:$app$plugins$format$format_key$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$))};
default:return null}}()):null},$app$plugins$format$format_action$$=function($interaction$jscomp$56$$,$plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$){return $APP.$cljs$core$truth_$$($interaction$jscomp$56$$)?$app$util$object$without_empty$$(function(){var $G__83795$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);switch($G__83795$$ instanceof $APP.$cljs$core$Keyword$$?$G__83795$$.$fqn$:null){case "navigate":return{type:"navigate-to",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?
function(){var $G__83799$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83799$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83799$$)}():null,preserveScrollPosition:$APP.$cljs$cst$1968$preserve_scroll$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$56$$,
!1),animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};case "open-overlay":return{type:"open-overlay",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__83803$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?
$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83803$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83803$$)}():null,relativeTo:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1396$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__83807$$=$APP.$cljs$cst$1396$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);
return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83807$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83807$$)}():null,position:$app$plugins$format$format_key$$($APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),manualPositionLocation:$app$plugins$format$format_point$$($APP.$cljs$cst$1970$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),
closeWhenClickOutside:$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),addBackgroundOverlay:$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};case "toggle-overlay":return{type:"toggle-overlay",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?
function(){var $G__83811$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83811$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83811$$)}():null,relativeTo:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1396$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?
function(){var $G__83815$$=$APP.$cljs$cst$1396$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83815$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83815$$)}():null,position:$app$plugins$format$format_key$$($APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),
manualPositionLocation:$app$plugins$format$format_point$$($APP.$cljs$cst$1970$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),closeWhenClickOutside:$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),addBackgroundOverlay:$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};
case "close-overlay":return{type:"close-overlay",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__83819$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,
$G__83819$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$465$$,$page_id$jscomp$480$$,$G__83819$$)}():null,animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};case "prev-screen":return{type:"previous-screen"};case "open-url":return{type:"open-url",url:$APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)};default:return null}}()):null},$app$plugins$parser$parse_id$$=
function($id$jscomp$1087$$){return $APP.$cljs$core$truth_$$($id$jscomp$1087$$)?$APP.$app$common$uuid$parse$$($id$jscomp$1087$$):null},$app$plugins$parser$parse_keyword$$=function($kw$jscomp$5$$){return $APP.$cljs$core$truth_$$($kw$jscomp$5$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($kw$jscomp$5$$):null},$app$plugins$parser$parse_hex$$=function($color$jscomp$245$$){return typeof $color$jscomp$245$$==="string"?$APP.$cuerdas$core$lower$$($color$jscomp$245$$):$color$jscomp$245$$},$app$plugins$parser$parse_point$$=
function($point$jscomp$97$$){return $APP.$cljs$core$truth_$$($point$jscomp$97$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($point$jscomp$97$$,"x"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($point$jscomp$97$$,"y")):null},$app$plugins$parser$parse_shape_type$$=function($type$jscomp$738$$){switch($type$jscomp$738$$){case "board":return $APP.$cljs$cst$1606$frame$$;case "boolean":return $APP.$cljs$cst$1610$bool$$;
case "rectangle":return $APP.$cljs$cst$1611$rect$$;case "ellipse":return $APP.$cljs$cst$1417$circle$$;default:return $app$plugins$parser$parse_keyword$$($type$jscomp$738$$)}},$app$plugins$parser$parse_image_data$$=function($image_data$jscomp$6$$){return $image_data$jscomp$6$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$6$$,
"id")),$APP.$cljs$cst$725$name$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$6$$,"name"),$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$6$$,"width"),$APP.$cljs$cst$1522$height$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$6$$,"height"),$APP.$cljs$cst$1726$mtype$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$6$$,"mtype"),$APP.$cljs$cst$1727$keep_aspect_ratio$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$6$$,"keepAspectRatio")],null)):null},$app$plugins$parser$parse_gradient_stop$$=function($stop$jscomp$15$$){return $stop$jscomp$15$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stop$jscomp$15$$,"color")),$APP.$cljs$cst$1734$opacity$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stop$jscomp$15$$,"opacity"),$APP.$cljs$cst$195$offset$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stop$jscomp$15$$,"offset")],null)):null},$app$plugins$parser$parse_gradient$$=function($gradient$jscomp$32$$){return $gradient$jscomp$32$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,
"type")),$APP.$cljs$cst$1729$start_x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,"startX"),$APP.$cljs$cst$1730$start_y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,"startY"),$APP.$cljs$cst$1731$end_x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,"endX"),$APP.$cljs$cst$1732$end_y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,"endY"),
$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,"width"),$APP.$cljs$cst$1733$stops$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$parser$parse_gradient_stop$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$32$$,"stops"))],null)):null},$app$plugins$parser$parse_color_data$$=function($color$jscomp$246$$){if($color$jscomp$246$$!=null){var $file_id$jscomp$466$$=function(){var $or__5025__auto__$jscomp$1445$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"fileId");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1445$$)?$or__5025__auto__$jscomp$1445$$:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"refFile")}();return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$(function(){var $or__5025__auto__$jscomp$1444$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"id");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1444$$)?$or__5025__auto__$jscomp$1444$$:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"refId")}()),$APP.$cljs$cst$1644$file_id$$,$app$plugins$parser$parse_id$$($file_id$jscomp$466$$),$APP.$cljs$cst$1298$color$$,$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,
"color")),$APP.$cljs$cst$1734$opacity$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"opacity"),$APP.$cljs$cst$1724$gradient$$,$app$plugins$parser$parse_gradient$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"gradient")),$APP.$cljs$cst$1612$image$$,$app$plugins$parser$parse_image_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$246$$,"image"))],null))}return null},$app$plugins$parser$parse_color$$=
function($color$jscomp$247$$){return $color$jscomp$247$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$parser$parse_color_data$$($color$jscomp$247$$),$APP.$cljs$cst$725$name$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$247$$,"name"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$247$$,
"path")]))):null},$app$plugins$parser$parse_fill$$=function($fill$jscomp$29$$){return $fill$jscomp$29$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1746$fill_color$$,$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillColor")),$APP.$cljs$cst$1747$fill_opacity$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,
"fillOpacity"),$APP.$cljs$cst$1748$fill_color_gradient$$,$app$plugins$parser$parse_gradient$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillColorGradient")),$APP.$cljs$cst$1640$fill_color_ref_file$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillColorRefFile")),$APP.$cljs$cst$1745$fill_color_ref_id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,
"fillColorRefId")),$APP.$cljs$cst$1632$fill_image$$,$app$plugins$parser$parse_image_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillImage"))],null)):null},$app$plugins$parser$parse_fills$$=function($fills$jscomp$34$$){return $fills$jscomp$34$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_fill$$),$fills$jscomp$34$$):null},
$app$plugins$parser$parse_stroke$$=function($stroke$jscomp$38$$){return $stroke$jscomp$38$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1865$stroke_cap_start$$,$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$1739$stroke_color$$,$APP.$cljs$cst$1740$stroke_opacity$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$1869$stroke_cap_end$$,$APP.$cljs$cst$1742$stroke_color_ref_id$$,$APP.$cljs$cst$1655$stroke_width$$,
$APP.$cljs$cst$1641$stroke_color_ref_file$$,$APP.$cljs$cst$1741$stroke_color_gradient$$],[$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeCapStart")),$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeStyle")),$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColor")),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,
"strokeOpacity"),$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeAlignment")),$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeCapEnd")),$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColorRefId")),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,
"strokeWidth"),$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColorRefFile")),$app$plugins$parser$parse_gradient$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColorGradient"))])):null},$app$plugins$parser$parse_strokes$$=function($strokes$jscomp$12$$){return $strokes$jscomp$12$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_stroke$$),$strokes$jscomp$12$$):null},$app$plugins$parser$parse_blur$$=function($blur$jscomp$17$$){return $blur$jscomp$17$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$17$$,"id")),$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$17$$,
"type")),$APP.$cljs$cst$260$value$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$17$$,"value"),$APP.$cljs$cst$1620$hidden$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$17$$,"hidden")],null)):null},$app$plugins$parser$parse_export$$=function($export$$jscomp$15$$){return $export$$jscomp$15$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,
$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($export$$jscomp$15$$,"type")),$APP.$cljs$cst$1902$scale$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$15$$,"scale",1),$APP.$cljs$cst$1371$suffix$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$15$$,"suffix",""),$APP.$cljs$cst$3784$skip_children$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$15$$,"skipChildren",
!1)],null)):null},$app$plugins$parser$parse_exports$$=function($exports$jscomp$14$$){return $exports$jscomp$14$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_export$$),$exports$jscomp$14$$):null},$app$plugins$parser$parse_frame_guide_column_params$$=function($params$jscomp$469$$){return $APP.$cljs$core$truth_$$($params$jscomp$469$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1298$color$$,$app$plugins$parser$parse_color$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$469$$,"color")),$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$469$$,"type")),$APP.$cljs$cst$874$size$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$469$$,"size"),$APP.$cljs$cst$1929$margin$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$469$$,
"margin"),$APP.$cljs$cst$1930$item_length$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$469$$,"itemLength"),$APP.$cljs$cst$1931$gutter$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$469$$,"gutter")],null)):null},$app$plugins$parser$parse_frame_guide_column$$=function($guide$jscomp$22$$){return $APP.$cljs$core$truth_$$($guide$jscomp$22$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$22$$,"type")),$APP.$cljs$cst$1932$display$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$22$$,"display"),$APP.$cljs$cst$1430$params$$,$app$plugins$parser$parse_frame_guide_column_params$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$22$$,"params"))],null)):null},$app$plugins$parser$parse_frame_guide_row$$=
function($guide$jscomp$23$$){return $APP.$cljs$core$truth_$$($guide$jscomp$23$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$23$$,"type")),$APP.$cljs$cst$1932$display$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$23$$,"display"),$APP.$cljs$cst$1430$params$$,
$app$plugins$parser$parse_frame_guide_column_params$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$23$$,"params"))],null)):null},$app$plugins$parser$parse_frame_guide$$=function($guide$jscomp$25$$){if($guide$jscomp$25$$!=null){var $G__83557$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$25$$,"type");switch($G__83557$$){case "column":return $app$plugins$parser$parse_frame_guide_column$$;case "row":return $app$plugins$parser$parse_frame_guide_row$$;
case "square":return $APP.$cljs$core$truth_$$($guide$jscomp$25$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$25$$,"type")),$APP.$cljs$cst$1932$display$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$25$$,"display"),$APP.$cljs$cst$1430$params$$,$app$plugins$parser$parse_frame_guide_column_params$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($guide$jscomp$25$$,
"params"))],null)):null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83557$$)].join(""));}}else return null},$app$plugins$parser$parse_frame_guides$$=function($guides$jscomp$13$$){return $guides$jscomp$13$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_frame_guide$$),$guides$jscomp$13$$):null},$app$plugins$parser$parse_animation$$=
function($animation$jscomp$17$$){if($APP.$cljs$core$truth_$$($animation$jscomp$17$$)){var $animation_type$jscomp$2$$=$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"type"));return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(function(){switch($animation_type$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$animation_type$jscomp$2$$.$fqn$:null){case "dissolve":return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1959$animation_type$$,$animation_type$jscomp$2$$,$APP.$cljs$cst$1960$duration$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"duration"),$APP.$cljs$cst$1961$easing$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"easing"))],null);case "slide":return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1959$animation_type$$,$animation_type$jscomp$2$$,$APP.$cljs$cst$1962$way$$,
$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"way")),$APP.$cljs$cst$1963$direction$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"direction")),$APP.$cljs$cst$1960$duration$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"duration"),$APP.$cljs$cst$1961$easing$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,
"easing")),$APP.$cljs$cst$1964$offset_effect$$,$APP.$cljs$core$boolean$0$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"offsetEffect"))],null);case "push":return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1959$animation_type$$,$animation_type$jscomp$2$$,$APP.$cljs$cst$1963$direction$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"direction")),$APP.$cljs$cst$1960$duration$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"duration"),$APP.$cljs$cst$1961$easing$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"easing"))],null);default:return null}}())}return null},$app$plugins$parser$parse_action$$=function($action$jscomp$9$$){if($APP.$cljs$core$truth_$$($action$jscomp$9$$)){var $action_type$jscomp$5$$=$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,
"type"));return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(function(){switch($action_type$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$action_type$jscomp$5$$.$fqn$:null){case "navigate-to":return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1966$action_type$$,$APP.$cljs$cst$1941$navigate$$,$APP.$cljs$cst$1967$destination$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,
"destination"),"$id"),$APP.$cljs$cst$1968$preserve_scroll$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"preserveScrollPosition"),$APP.$cljs$cst$1969$animation$$,$app$plugins$parser$parse_animation$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"animation"))],null);case "open-overlay":case "toggle-overlay":return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1966$action_type$$,$action_type$jscomp$5$$,$APP.$cljs$cst$1967$destination$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"destination"),"$id"),$APP.$cljs$cst$1396$relative_to$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"relativeTo"),"$id"),$APP.$cljs$cst$1971$overlay_pos_type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,
"position")),$APP.$cljs$cst$1970$overlay_position$$,$app$plugins$parser$parse_point$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"manualPositionLocation")),$APP.$cljs$cst$1972$close_click_outside$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"closeWhenClickOutside"),$APP.$cljs$cst$1973$background_overlay$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"addBackgroundOverlay"),$APP.$cljs$cst$1969$animation$$,
$app$plugins$parser$parse_animation$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"animation"))],null);case "close-overlay":return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1966$action_type$$,$action_type$jscomp$5$$,$APP.$cljs$cst$1967$destination$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"destination"),"$id"),$APP.$cljs$cst$1969$animation$$,
$app$plugins$parser$parse_animation$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,"animation"))],null);case "previous-screen":return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1966$action_type$$,$APP.$cljs$cst$1943$prev_screen$$],null);case "open-url":return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1966$action_type$$,$action_type$jscomp$5$$,$APP.$cljs$cst$1975$url$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$9$$,
"url")],null);default:return null}}())}return null},$app$plugins$parser$orientation__GT_axis$$=function($axis$jscomp$60$$){switch($axis$jscomp$60$$){case "horizontal":return $APP.$cljs$cst$1511$y$$;case "vertical":return $APP.$cljs$cst$1510$x$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($axis$jscomp$60$$)].join(""));}},$app$plugins$system_events$event$$=function($var_args$jscomp$1511$$){for(var $args__5755__auto__$jscomp$275$$=[],$len__5749__auto___83518$$=
arguments.length,$i__5750__auto___83519$$=0;;)if($i__5750__auto___83519$$<$len__5749__auto___83518$$)$args__5755__auto__$jscomp$275$$.push(arguments[$i__5750__auto___83519$$]),$i__5750__auto___83519$$+=1;else break;return $app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$275$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$275$$.slice(2),0,null):null)},$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=
function($plugin_data_plugin_id$jscomp$15$$,$name$jscomp$512$$,$p__83507_props$jscomp$462$$){$p__83507_props$jscomp$462$$=$APP.$cljs$core$__destructure_map$$($p__83507_props$jscomp$462$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($plugin_data_plugin_id$jscomp$15$$,"96dfa740-005d-8020-8007-55ede24a2bae"))return $APP.$app$main$data$event$event$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__83507_props$jscomp$462$$,
$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$name$jscomp$512$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"mcp"));$plugin_data_plugin_id$jscomp$15$$=$app$plugins$register$get_plugin_data$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$plugin_data_plugin_id$jscomp$15$$);return $APP.$app$main$data$event$event$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__83507_props$jscomp$462$$,
$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$name$jscomp$512$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugin"),$APP.$cljs$cst$2306$app_DOT_main_DOT_data_DOT_event_SLASH_context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$6399$plugin_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data_plugin_id$jscomp$15$$),$APP.$cljs$cst$6301$plugin_url$$,$APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data_plugin_id$jscomp$15$$)],
null)))},$app$plugins$system_events$add_event$$=function($event$jscomp$789$$,$plugin_id$jscomp$16$$){var $plugin_data$jscomp$1$$=$app$plugins$register$get_plugin_data$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$plugin_id$jscomp$16$$);return $APP.$cljs$core$with_meta$$($event$jscomp$789$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$16$$,"96dfa740-005d-8020-8007-55ede24a2bae")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"mcp"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugin",$APP.$cljs$cst$2306$app_DOT_main_DOT_data_DOT_event_SLASH_context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$6399$plugin_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data$jscomp$1$$),$APP.$cljs$cst$6301$plugin_url$$,$APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data$jscomp$1$$)],null)],null))},$app$plugins$flex$flex_layout_proxy$$=
function($plugin_id$jscomp$17$$,$file_id$jscomp$467$$,$page_id$jscomp$481$$,$id$jscomp$1089$$){var $obj_83568$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_83568$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FlexLayoutProxy"}});Object.defineProperty($obj_83568$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FlexLayoutProxy"}});Object.defineProperty($obj_83568$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$17$$}});Object.defineProperty($obj_83568$$,
"$id",{enumerable:!1,get:function(){return $id$jscomp$1089$$}});Object.defineProperty($obj_83568$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$467$$}});Object.defineProperty($obj_83568$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$481$$}});Object.defineProperty($obj_83568$$,"dir",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_dir_83621_value__$1$jscomp$inline_9922$$){$val_dir_83621_value__$1$jscomp$inline_9922$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_dir_83621_value__$1$jscomp$inline_9922$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$flex_direction_types$$,$val_dir_83621_value__$1$jscomp$inline_9922$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1679$layout_flex_dir$$,$val_dir_83621_value__$1$jscomp$inline_9922$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6400$dir$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6400$dir$$,$val_dir_83621_value__$1$jscomp$inline_9922$$)}});Object.defineProperty($obj_83568$$,"wrap",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1684$layout_wrap_type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_wrap_83629_value__$1$jscomp$inline_9926$$){$val_wrap_83629_value__$1$jscomp$inline_9926$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_wrap_83629_value__$1$jscomp$inline_9926$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$wrap_types$$,$val_wrap_83629_value__$1$jscomp$inline_9926$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1684$layout_wrap_type$$,$val_wrap_83629_value__$1$jscomp$inline_9926$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$APP.$cljs$cst$896$wrap$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$APP.$cljs$cst$896$wrap$$,$val_wrap_83629_value__$1$jscomp$inline_9926$$)}});Object.defineProperty($obj_83568$$,"alignItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_alignitems_83638_value__$1$jscomp$inline_9930$$){$val_alignitems_83638_value__$1$jscomp$inline_9930$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignitems_83638_value__$1$jscomp$inline_9930$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_items_types$$,$val_alignitems_83638_value__$1$jscomp$inline_9930$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1692$layout_align_items$$,$val_alignitems_83638_value__$1$jscomp$inline_9930$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6401$alignItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6401$alignItems$$,$val_alignitems_83638_value__$1$jscomp$inline_9930$$)}});Object.defineProperty($obj_83568$$,"alignContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_aligncontent_83646_value__$1$jscomp$inline_9934$$){$val_aligncontent_83646_value__$1$jscomp$inline_9934$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_aligncontent_83646_value__$1$jscomp$inline_9934$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_content_types$$,$val_aligncontent_83646_value__$1$jscomp$inline_9934$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_align_content$$,$val_aligncontent_83646_value__$1$jscomp$inline_9934$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6402$alignContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6402$alignContent$$,$val_aligncontent_83646_value__$1$jscomp$inline_9934$$)}});Object.defineProperty($obj_83568$$,"justifyItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1690$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_justifyitems_83654_value__$1$jscomp$inline_9938$$){$val_justifyitems_83654_value__$1$jscomp$inline_9938$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifyitems_83654_value__$1$jscomp$inline_9938$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_items_types$$,$val_justifyitems_83654_value__$1$jscomp$inline_9938$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1690$layout_justify_items$$,$val_justifyitems_83654_value__$1$jscomp$inline_9938$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6403$justifyItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6403$justifyItems$$,$val_justifyitems_83654_value__$1$jscomp$inline_9938$$)}});Object.defineProperty($obj_83568$$,"justifyContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_justifycontent_83662_value__$1$jscomp$inline_9942$$){$val_justifycontent_83662_value__$1$jscomp$inline_9942$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifycontent_83662_value__$1$jscomp$inline_9942$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_content_types$$,$val_justifycontent_83662_value__$1$jscomp$inline_9942$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1689$layout_justify_content$$,$val_justifycontent_83662_value__$1$jscomp$inline_9942$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6404$justifyContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6404$justifyContent$$,$val_justifycontent_83662_value__$1$jscomp$inline_9942$$)}});Object.defineProperty($obj_83568$$,"rowGap",{enumerable:!0,
get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_rowgap_83670$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_rowgap_83670$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6405$rowGap$$,$val_rowgap_83670$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1681$row_gap$$,$val_rowgap_83670$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,
$cljs$cst$6405$rowGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"columnGap",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_columngap_83678$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_columngap_83678$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6406$columnGap$$,$val_columngap_83678$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1682$column_gap$$,$val_columngap_83678$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6406$columnGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"verticalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_verticalpadding_83686$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_verticalpadding_83686$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6407$verticalPadding$$,$val_verticalpadding_83686$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val_verticalpadding_83686$$,$APP.$cljs$cst$1687$p3$$,$val_verticalpadding_83686$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6407$verticalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"horizontalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_horizontalpadding_83694$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_horizontalpadding_83694$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6408$horizontalPadding$$,$val_horizontalpadding_83694$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val_horizontalpadding_83694$$,$APP.$cljs$cst$1688$p4$$,$val_horizontalpadding_83694$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6408$horizontalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"topPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_toppadding_83702$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_toppadding_83702$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6409$topPadding$$,$val_toppadding_83702$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1093$p1$$,$val_toppadding_83702$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6409$topPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"rightPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rightpadding_83710$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_rightpadding_83710$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6410$rightPadding$$,$val_rightpadding_83710$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1091$p2$$,$val_rightpadding_83710$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6410$rightPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"bottomPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_bottompadding_83718$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_bottompadding_83718$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6411$bottomPadding$$,$val_bottompadding_83718$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1687$p3$$,$val_bottompadding_83718$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6411$bottomPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"leftPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_leftpadding_83726$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_leftpadding_83726$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6412$leftPadding$$,$val_leftpadding_83726$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1688$p4$$,$val_leftpadding_83726$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6412$leftPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83568$$,"remove",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$])))}.bind(this)}});
Object.defineProperty($obj_83568$$,"appendChild",{enumerable:!1,get:function(){return function($child$jscomp$125_child_id$jscomp$12$$){if($APP.$cljs$core$not$$($app$plugins$flex$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$plugins$flex$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$125_child_id$jscomp$12$$):$app$plugins$flex$shape_proxy_QMARK_$$($child$jscomp$125_child_id$jscomp$12$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6413$appendChild$$,
$child$jscomp$125_child_id$jscomp$12$$);$child$jscomp$125_child_id$jscomp$12$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$125_child_id$jscomp$12$$,"$id");var $shape$jscomp$1117$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$467$$,$page_id$jscomp$481$$,$id$jscomp$1089$$),$child_shape$jscomp$1$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$467$$,$page_id$jscomp$481$$,$child$jscomp$125_child_id$jscomp$12$$),$index$jscomp$600$$=$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$17$$)&&
!$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1117$$)?0:$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1117$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child$jscomp$125_child_id$jscomp$12$$]),$id$jscomp$1089$$,$index$jscomp$600$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$17$$,
"add-layout-element",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($child_shape$jscomp$1$$),$APP.$cljs$cst$3622$parent_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1117$$)]))]))}.bind(this)}});Object.defineProperty($obj_83568$$,"horizontalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1697$fix$$))},set:function($val_horizontalsizing_83748_value__$1$jscomp$inline_9970$$){$val_horizontalsizing_83748_value__$1$jscomp$inline_9970$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_horizontalsizing_83748_value__$1$jscomp$inline_9970$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_h_sizing_types$$,$val_horizontalsizing_83748_value__$1$jscomp$inline_9970$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,$val_horizontalsizing_83748_value__$1$jscomp$inline_9970$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6414$horizontalSizing$$,"Plugin doesn't have 'content:write' permission"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6414$horizontalSizing$$,$val_horizontalsizing_83748_value__$1$jscomp$inline_9970$$)}});Object.defineProperty($obj_83568$$,"verticalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1697$fix$$))},set:function($val_verticalsizing_83756_value__$1$jscomp$inline_9974$$){$val_verticalsizing_83756_value__$1$jscomp$inline_9974$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_verticalsizing_83756_value__$1$jscomp$inline_9974$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_v_sizing_types$$,$val_verticalsizing_83756_value__$1$jscomp$inline_9974$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1089$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,$val_verticalsizing_83756_value__$1$jscomp$inline_9974$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6415$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6415$verticalSizing$$,$val_verticalsizing_83756_value__$1$jscomp$inline_9974$$)}});return $obj_83568$$},$app$plugins$flex$layout_child_proxy$$=
function($plugin_id$jscomp$18$$,$file_id$jscomp$468$$,$page_id$jscomp$482$$,$id$jscomp$1090$$){var $obj_84141$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84141$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LayoutChildProxy"}});Object.defineProperty($obj_84141$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LayoutChildProxy"}});Object.defineProperty($obj_84141$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$18$$}});Object.defineProperty($obj_84141$$,
"$id",{enumerable:!1,get:function(){return $id$jscomp$1090$$}});Object.defineProperty($obj_84141$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$468$$}});Object.defineProperty($obj_84141$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$482$$}});Object.defineProperty($obj_84141$$,"absolute",{enumerable:!0,get:function(){return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1711$layout_item_absolute$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_absolute_84192$$){return $APP.$cljs$core$boolean_QMARK_$$($val_absolute_84192$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1711$layout_item_absolute$$,
$val_absolute_84192$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$4078$absolute$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$4078$absolute$$,$val_absolute_84192$$)}});Object.defineProperty($obj_84141$$,"zIndex",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1712$layout_item_z_index$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
0)},set:function($val_zindex_84200$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_zindex_84200$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6416$zIndex$$,$val_zindex_84200$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1712$layout_item_z_index$$,$val_zindex_84200$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6416$zIndex$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"horizontalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1697$fix$$))},set:function($val_horizontalsizing_84208_value__$1$jscomp$inline_9984$$){$val_horizontalsizing_84208_value__$1$jscomp$inline_9984$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_horizontalsizing_84208_value__$1$jscomp$inline_9984$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_h_sizing_types$$,$val_horizontalsizing_84208_value__$1$jscomp$inline_9984$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,$val_horizontalsizing_84208_value__$1$jscomp$inline_9984$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6408$horizontalPadding$$,
"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6408$horizontalPadding$$,$val_horizontalsizing_84208_value__$1$jscomp$inline_9984$$)}});Object.defineProperty($obj_84141$$,"verticalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1697$fix$$))},
set:function($val_verticalsizing_84216_value__$1$jscomp$inline_9988$$){$val_verticalsizing_84216_value__$1$jscomp$inline_9988$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_verticalsizing_84216_value__$1$jscomp$inline_9988$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_v_sizing_types$$,$val_verticalsizing_84216_value__$1$jscomp$inline_9988$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,$val_verticalsizing_84216_value__$1$jscomp$inline_9988$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6415$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6415$verticalSizing$$,$val_verticalsizing_84216_value__$1$jscomp$inline_9988$$)}});Object.defineProperty($obj_84141$$,"alignSelf",{enumerable:!0,
get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1710$layout_item_align_self$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1672$auto$$))},set:function($val_alignself_84224_value__$1$jscomp$inline_9992$$){$val_alignself_84224_value__$1$jscomp$inline_9992$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignself_84224_value__$1$jscomp$inline_9992$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_align_self_types$$,
$val_alignself_84224_value__$1$jscomp$inline_9992$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1710$layout_item_align_self$$,$val_alignself_84224_value__$1$jscomp$inline_9992$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6417$alignSelf$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6417$alignSelf$$,$val_alignself_84224_value__$1$jscomp$inline_9992$$)}});Object.defineProperty($obj_84141$$,"verticalMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_verticalmargin_84232$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_verticalmargin_84232$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6418$verticalMargin$$,$val_verticalmargin_84232$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1700$m1$$,$val_verticalmargin_84232$$,$APP.$cljs$cst$1702$m3$$,$val_verticalmargin_84232$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6418$verticalMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"horizontalMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_horizontalmargin_84241$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_horizontalmargin_84241$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6419$horizontalMargin$$,$val_horizontalmargin_84241$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1701$m2$$,$val_horizontalmargin_84241$$,$APP.$cljs$cst$1703$m4$$,$val_horizontalmargin_84241$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6419$horizontalMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"topMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_topmargin_84249$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_topmargin_84249$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6420$topMargin$$,$val_topmargin_84249$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1700$m1$$,$val_topmargin_84249$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6420$topMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"rightMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rightmargin_84257$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_rightmargin_84257$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6421$rightMargin$$,$val_rightmargin_84257$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1701$m2$$,$val_rightmargin_84257$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6421$rightMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"bottomMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_bottommargin_84265$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_bottommargin_84265$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6422$bottomMargin$$,$val_bottommargin_84265$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1702$m3$$,$val_bottommargin_84265$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6422$bottomMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"leftMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_leftmargin_84273$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_leftmargin_84273$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6423$leftMargin$$,$val_leftmargin_84273$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1703$m4$$,$val_leftmargin_84273$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6423$leftMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"maxWidth",{enumerable:!0,get:function(){return $APP.$cljs$cst$1706$layout_item_max_w$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},
set:function($val_maxwidth_84281$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_maxwidth_84281$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6424$maxWidth$$,$val_maxwidth_84281$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1706$layout_item_max_w$$,$val_maxwidth_84281$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6424$maxWidth$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"minWidth",{enumerable:!0,get:function(){return $APP.$cljs$cst$1707$layout_item_min_w$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},set:function($val_minwidth_84289$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_minwidth_84289$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6425$minWidth$$,$val_minwidth_84289$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1707$layout_item_min_w$$,
$val_minwidth_84289$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6425$minWidth$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"maxHeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1704$layout_item_max_h$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},set:function($val_maxheight_84297$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_maxheight_84297$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$5839$maxHeight$$,$val_maxheight_84297$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_max_h$$,
$val_maxheight_84297$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$5839$maxHeight$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84141$$,"minHeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1705$layout_item_min_h$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},set:function($val_minheight_84305$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_minheight_84305$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6426$minHeight$$,$val_minheight_84305$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1090$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1705$layout_item_min_h$$,
$val_minheight_84305$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6426$minHeight$$,"Plugin doesn't have 'content:write' permission")}});return $obj_84141$$},$app$plugins$grid$grid_layout_proxy$$=function($plugin_id$jscomp$19$$,$file_id$jscomp$469$$,$page_id$jscomp$483$$,$id$jscomp$1091$$){var $obj_83870$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_83870$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"GridLayoutProxy"}});Object.defineProperty($obj_83870$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"GridLayoutProxy"}});Object.defineProperty($obj_83870$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$19$$).call(this)}});Object.defineProperty($obj_83870$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1091$$).call(this)}});Object.defineProperty($obj_83870$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$469$$).call(this)}});
Object.defineProperty($obj_83870$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$483$$).call(this)}});Object.defineProperty($obj_83870$$,"dir",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1693$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_dir_83926_value__$1$jscomp$inline_10026$$){$val_dir_83926_value__$1$jscomp$inline_10026$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_dir_83926_value__$1$jscomp$inline_10026$$);
return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_direction_types$$,$val_dir_83926_value__$1$jscomp$inline_10026$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1693$layout_grid_dir$$,$val_dir_83926_value__$1$jscomp$inline_10026$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6400$dir$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6400$dir$$,$val_dir_83926_value__$1$jscomp$inline_10026$$)}});Object.defineProperty($obj_83870$$,"rows",{enumerable:!0,get:function(){return $app$plugins$format$format_tracks$$($APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}});
Object.defineProperty($obj_83870$$,"columns",{enumerable:!0,get:function(){return $app$plugins$format$format_tracks$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}});Object.defineProperty($obj_83870$$,"alignItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_alignitems_83950_value__$1$jscomp$inline_10030$$){$val_alignitems_83950_value__$1$jscomp$inline_10030$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignitems_83950_value__$1$jscomp$inline_10030$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_items_types$$,$val_alignitems_83950_value__$1$jscomp$inline_10030$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1692$layout_align_items$$,$val_alignitems_83950_value__$1$jscomp$inline_10030$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6401$alignItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6401$alignItems$$,$val_alignitems_83950_value__$1$jscomp$inline_10030$$)}});Object.defineProperty($obj_83870$$,"alignContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_aligncontent_83958_value__$1$jscomp$inline_10034$$){$val_aligncontent_83958_value__$1$jscomp$inline_10034$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_aligncontent_83958_value__$1$jscomp$inline_10034$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_content_types$$,$val_aligncontent_83958_value__$1$jscomp$inline_10034$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_align_content$$,$val_aligncontent_83958_value__$1$jscomp$inline_10034$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6402$alignContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6402$alignContent$$,$val_aligncontent_83958_value__$1$jscomp$inline_10034$$)}});Object.defineProperty($obj_83870$$,"justifyItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1690$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_justifyitems_83968_value__$1$jscomp$inline_10038$$){$val_justifyitems_83968_value__$1$jscomp$inline_10038$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifyitems_83968_value__$1$jscomp$inline_10038$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_items_types$$,$val_justifyitems_83968_value__$1$jscomp$inline_10038$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1690$layout_justify_items$$,$val_justifyitems_83968_value__$1$jscomp$inline_10038$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6403$justifyItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6403$justifyItems$$,$val_justifyitems_83968_value__$1$jscomp$inline_10038$$)}});Object.defineProperty($obj_83870$$,"justifyContent",{enumerable:!0,
get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_justifycontent_83976_value__$1$jscomp$inline_10042$$){$val_justifycontent_83976_value__$1$jscomp$inline_10042$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifycontent_83976_value__$1$jscomp$inline_10042$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_content_types$$,
$val_justifycontent_83976_value__$1$jscomp$inline_10042$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1689$layout_justify_content$$,$val_justifycontent_83976_value__$1$jscomp$inline_10042$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6404$justifyContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6404$justifyContent$$,$val_justifycontent_83976_value__$1$jscomp$inline_10042$$)}});Object.defineProperty($obj_83870$$,"rowGap",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rowgap_83984$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_rowgap_83984$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6405$rowGap$$,$val_rowgap_83984$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1681$row_gap$$,$val_rowgap_83984$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6405$rowGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"columnGap",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_columngap_83994$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_columngap_83994$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6406$columnGap$$,$val_columngap_83994$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1682$column_gap$$,$val_columngap_83994$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6406$columnGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"verticalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_verticalpadding_84002$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_verticalpadding_84002$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6407$verticalPadding$$,$val_verticalpadding_84002$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val_verticalpadding_84002$$,$APP.$cljs$cst$1687$p3$$,$val_verticalpadding_84002$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6407$verticalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"horizontalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_horizontalpadding_84010$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_horizontalpadding_84010$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6408$horizontalPadding$$,$val_horizontalpadding_84010$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val_horizontalpadding_84010$$,$APP.$cljs$cst$1688$p4$$,$val_horizontalpadding_84010$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6408$horizontalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"topPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_toppadding_84020$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_toppadding_84020$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6409$topPadding$$,$val_toppadding_84020$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1093$p1$$,$val_toppadding_84020$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6409$topPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"rightPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rightpadding_84028$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_rightpadding_84028$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6410$rightPadding$$,$val_rightpadding_84028$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1091$p2$$,$val_rightpadding_84028$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6427$righPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"bottomPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_bottompadding_84036$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_bottompadding_84036$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6411$bottomPadding$$,$val_bottompadding_84036$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1687$p3$$,$val_bottompadding_84036$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6411$bottomPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"leftPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_leftpadding_84046$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_leftpadding_84046$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6412$leftPadding$$,$val_leftpadding_84046$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1688$p4$$,$val_leftpadding_84046$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6412$leftPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_83870$$,"addRow",{enumerable:!1,get:function(){return function($type$jscomp$739_type__$1$jscomp$20$$,$value$jscomp$1066$$){$type$jscomp$739_type__$1$jscomp$20$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$739_type__$1$jscomp$20$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$739_type__$1$jscomp$20$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1670$percent$$,$type$jscomp$739_type__$1$jscomp$20$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$type$jscomp$739_type__$1$jscomp$20$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,
$type$jscomp$739_type__$1$jscomp$20$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1066$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6429$addRow_value$$,$value$jscomp$1066$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
$APP.$cljs$cst$1656$row$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$739_type__$1$jscomp$20$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1066$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6430$addRow$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6428$addRow_type$$,$type$jscomp$739_type__$1$jscomp$20$$)}.bind(this)}});Object.defineProperty($obj_83870$$,"addRowAtIndex",
{enumerable:!1,get:function(){return function($index$jscomp$601$$,$type$jscomp$740_type__$1$jscomp$21$$,$value$jscomp$1067$$){$type$jscomp$740_type__$1$jscomp$21$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$740_type__$1$jscomp$21$$);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$601$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6431$addRowAtIndex_index$$,$index$jscomp$601$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,
$type$jscomp$740_type__$1$jscomp$21$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1670$percent$$,$type$jscomp$740_type__$1$jscomp$21$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$type$jscomp$740_type__$1$jscomp$21$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$type$jscomp$740_type__$1$jscomp$21$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1067$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6433$addRowAtIndex_value$$,$value$jscomp$1067$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),$APP.$cljs$cst$1656$row$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$type$jscomp$740_type__$1$jscomp$21$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1067$$],null),$index$jscomp$601$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6434$addRowAtIndex$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6432$addRowAtIndex_type$$,$type$jscomp$740_type__$1$jscomp$21$$)}.bind(this)}});Object.defineProperty($obj_83870$$,"addColumn",{enumerable:!1,get:function(){return function($type$jscomp$741_type__$1$jscomp$22$$,
$value$jscomp$1068$$){$type$jscomp$741_type__$1$jscomp$22$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$741_type__$1$jscomp$22$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$741_type__$1$jscomp$22$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1670$percent$$,$type$jscomp$741_type__$1$jscomp$22$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$type$jscomp$741_type__$1$jscomp$22$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6436$lex$$,$type$jscomp$741_type__$1$jscomp$22$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1068$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6437$addColumn_value$$,$value$jscomp$1068$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
$APP.$cljs$cst$216$column$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$741_type__$1$jscomp$22$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1068$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6438$addColumn$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6435$addColumn_type$$,$type$jscomp$741_type__$1$jscomp$22$$)}.bind(this)}});Object.defineProperty($obj_83870$$,
"addColumnAtIndex",{enumerable:!1,get:function(){return function($index$jscomp$602$$,$type$jscomp$742_type__$1$jscomp$23$$,$value$jscomp$1069$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$602$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6439$addColumnAtIndex_index$$,$index$jscomp$602$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$742_type__$1$jscomp$23$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1670$percent$$,
$type$jscomp$742_type__$1$jscomp$23$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$type$jscomp$742_type__$1$jscomp$23$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$type$jscomp$742_type__$1$jscomp$23$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1069$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6441$addColumnAtIndex_value$$,$value$jscomp$1069$$):
$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?($type$jscomp$742_type__$1$jscomp$23$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$742_type__$1$jscomp$23$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),$APP.$cljs$cst$216$column$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$type$jscomp$742_type__$1$jscomp$23$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1069$$],null),$index$jscomp$602$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6442$addColumnAtIndex$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6440$addColumnAtIndex_type$$,$type$jscomp$742_type__$1$jscomp$23$$)}.bind(this)}});Object.defineProperty($obj_83870$$,"removeRow",{enumerable:!1,get:function(){return function($index$jscomp$603$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$603$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6443$removeRow$$,$index$jscomp$603$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),$APP.$cljs$cst$1656$row$$,$index$jscomp$603$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6443$removeRow$$,
"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_83870$$,"removeColumn",{enumerable:!1,get:function(){return function($index$jscomp$604$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$604$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6444$removeColumn$$,$index$jscomp$604$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
$APP.$cljs$cst$216$column$$,$index$jscomp$604$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6444$removeColumn$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_83870$$,"setColumn",{enumerable:!1,get:function(){return function($index$jscomp$605$$,$type$jscomp$743_type__$1$jscomp$24$$,$value$jscomp$1070$$){$type$jscomp$743_type__$1$jscomp$24$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$743_type__$1$jscomp$24$$);
return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$605$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6445$setColumn_index$$,$index$jscomp$605$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$743_type__$1$jscomp$24$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1670$percent$$,$type$jscomp$743_type__$1$jscomp$24$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,
$type$jscomp$743_type__$1$jscomp$24$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$type$jscomp$743_type__$1$jscomp$24$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1070$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6447$setColumn_value$$,$value$jscomp$1070$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
$APP.$cljs$cst$216$column$$,$index$jscomp$605$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$743_type__$1$jscomp$24$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1070$$],null)))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6448$setColumn$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6446$setColumn_type$$,
$type$jscomp$743_type__$1$jscomp$24$$)}.bind(this)}});Object.defineProperty($obj_83870$$,"setRow",{enumerable:!1,get:function(){return function($index$jscomp$606$$,$type$jscomp$744_type__$1$jscomp$25$$,$value$jscomp$1071$$){$type$jscomp$744_type__$1$jscomp$25$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$744_type__$1$jscomp$25$$);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$606$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,
$cljs$cst$6449$setRow_index$$,$index$jscomp$606$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$744_type__$1$jscomp$25$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1670$percent$$,$type$jscomp$744_type__$1$jscomp$25$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$type$jscomp$744_type__$1$jscomp$25$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,
$type$jscomp$744_type__$1$jscomp$25$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1071$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6451$setRow_value$$,$value$jscomp$1071$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]),
$APP.$cljs$cst$1656$row$$,$index$jscomp$606$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$744_type__$1$jscomp$25$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1071$$],null)))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6452$setRow$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6450$setRow_type$$,$type$jscomp$744_type__$1$jscomp$25$$)}.bind(this)}});
Object.defineProperty($obj_83870$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1091$$]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});
Object.defineProperty($obj_83870$$,"appendChild",{enumerable:!1,get:function(){return function($child$jscomp$126$$,$row$jscomp$36$$,$column$jscomp$46$$){return $APP.$cljs$core$not$$($app$plugins$grid$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$plugins$grid$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$126$$):$app$plugins$grid$shape_proxy_QMARK_$$($child$jscomp$126$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6453$appendChild_child$$,$child$jscomp$126$$):
$row$jscomp$36$$<0||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($row$jscomp$36$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6454$appendChild_row$$,$row$jscomp$36$$):$column$jscomp$46$$<0||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($column$jscomp$46$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6455$appendChild_column$$,$column$jscomp$46$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$126$$,"$id")]),$id$jscomp$1091$$,null,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$36$$,$column$jscomp$46$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1091$$],null)],null))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$cljs$cst$6413$appendChild$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});return $obj_83870$$},$app$plugins$grid$layout_cell_proxy$$=function($plugin_id$jscomp$20$$,$file_id$jscomp$470$$,$page_id$jscomp$484$$,$id$jscomp$1092$$){function $locate_cell$$(){var $parent$jscomp$308_shape$jscomp$1118$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$470$$,$page_id$jscomp$484$$,$id$jscomp$1092$$);$parent$jscomp$308_shape$jscomp$1118$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$470$$,$page_id$jscomp$484$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$308_shape$jscomp$1118$$));return $APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($parent$jscomp$308_shape$jscomp$1118$$,$id$jscomp$1092$$)}var $obj_84516$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84516$$,
Symbol.toStringTag,{enumerable:!1,get:function(){return"GridCellProxy"}});Object.defineProperty($obj_84516$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"GridCellProxy"}});Object.defineProperty($obj_84516$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$20$$).call(this)}});Object.defineProperty($obj_84516$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1092$$).call(this)}});Object.defineProperty($obj_84516$$,
"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$470$$).call(this)}});Object.defineProperty($obj_84516$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$484$$).call(this)}});Object.defineProperty($obj_84516$$,"row",{enumerable:!0,get:function(){return $APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_row_84567$$){var $cell$jscomp$inline_10070$$=$locate_cell$$(this),$shape$jscomp$inline_10071$$=
$app$plugins$utils$proxy__GT_shape$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_row_84567$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6456$row_value$$,$val_row_84567$$):$cell$jscomp$inline_10070$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6457$row_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10071$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10070$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1656$row$$,$val_row_84567$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$APP.$cljs$cst$1656$row$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84516$$,"rowSpan",{enumerable:!0,get:function(){return $APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_rowspan_84575$$){var $shape$jscomp$inline_10075$$=
$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10076$$=$locate_cell$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_rowspan_84575$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6458$rowSpan_value$$,$val_rowspan_84575$$):$cell$jscomp$inline_10076$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6459$rowSpan_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10075$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10076$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1657$row_span$$,$val_rowspan_84575$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6460$rowSpan$$,
"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84516$$,"column",{enumerable:!0,get:function(){return $APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_column_84583$$){var $shape$jscomp$inline_10080$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10081$$=$locate_cell$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_column_84583$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,
$cljs$cst$6461$column_value$$,$val_column_84583$$):$cell$jscomp$inline_10081$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6462$column_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10080$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10081$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$216$column$$,$val_column_84583$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$APP.$cljs$cst$216$column$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84516$$,"columnSpan",{enumerable:!0,get:function(){return $APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_columnspan_84591$$){var $shape$jscomp$inline_10085$$=$app$plugins$utils$proxy__GT_shape$$(this),
$cell$jscomp$inline_10086$$=$locate_cell$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_columnspan_84591$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6463$columnSpan_value$$,$val_columnspan_84591$$):$cell$jscomp$inline_10086$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6464$columnSpan_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10085$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10086$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1658$column_span$$,$val_columnspan_84591$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6465$columnSpan$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84516$$,"areaName",{enumerable:!0,get:function(){return $APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},
set:function($val_areaname_84599$$){var $shape$jscomp$inline_10090$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10091$$=$locate_cell$$(this);return typeof $val_areaname_84599$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6466$areaName_value$$,$val_areaname_84599$$):$cell$jscomp$inline_10091$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6467$areaName_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10090$$),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10091$$)]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1675$area_name$$,$val_areaname_84599$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,
$cljs$cst$6468$areaName$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84516$$,"position",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this)))},set:function($val_position_84607_value__$1$jscomp$inline_10097$$){var $shape$jscomp$inline_10095$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10096$$=$locate_cell$$(this);$val_position_84607_value__$1$jscomp$inline_10097$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_position_84607_value__$1$jscomp$inline_10097$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_position_types$$,$val_position_84607_value__$1$jscomp$inline_10097$$)?$cell$jscomp$inline_10096$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6470$position_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_cells_mode$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10095$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10096$$)]),$val_position_84607_value__$1$jscomp$inline_10097$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$APP.$cljs$cst$1676$position$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6469$position_value$$,$val_position_84607_value__$1$jscomp$inline_10097$$)}});Object.defineProperty($obj_84516$$,
"alignSelf",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1677$align_self$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this)))},set:function($val_alignself_84615_value__$1$jscomp$inline_10102$$){var $shape$jscomp$inline_10101$$=$app$plugins$utils$proxy__GT_shape$$(this);$val_alignself_84615_value__$1$jscomp$inline_10102$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignself_84615_value__$1$jscomp$inline_10102$$);var $cell$jscomp$inline_10103$$=
$locate_cell$$(this);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_cell_align_self_types$$,$val_alignself_84615_value__$1$jscomp$inline_10102$$)?$cell$jscomp$inline_10103$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6472$alignSelf_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10101$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10103$$)]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1677$align_self$$,$val_alignself_84615_value__$1$jscomp$inline_10102$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6417$alignSelf$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6471$alignSelf_value$$,
$val_alignself_84615_value__$1$jscomp$inline_10102$$)}});Object.defineProperty($obj_84516$$,"justifySelf",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1678$justify_self$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this)))},set:function($val_justifyself_84623_value__$1$jscomp$inline_10108$$){var $shape$jscomp$inline_10107$$=$app$plugins$utils$proxy__GT_shape$$(this);$val_justifyself_84623_value__$1$jscomp$inline_10108$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifyself_84623_value__$1$jscomp$inline_10108$$);
var $cell$jscomp$inline_10109$$=$locate_cell$$(this);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_cell_justify_self_types$$,$val_justifyself_84623_value__$1$jscomp$inline_10108$$)?$cell$jscomp$inline_10109$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6474$justifySelf_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$20$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10107$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10109$$)]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1678$justify_self$$,$val_justifyself_84623_value__$1$jscomp$inline_10108$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6475$justifySelf$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$20$$,$cljs$cst$6473$justifySelf_value$$,
$val_justifyself_84623_value__$1$jscomp$inline_10108$$)}});return $obj_84516$$},$app$plugins$ruler_guides$ruler_guide_proxy$$=function($plugin_id$jscomp$21$$,$file_id$jscomp$471$$,$page_id$jscomp$485$$,$id$jscomp$1093$$){var $obj_84738$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84738$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"RulerGuideProxy"}});Object.defineProperty($obj_84738$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"RulerGuideProxy"}});
Object.defineProperty($obj_84738$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$21$$).call(this)}});Object.defineProperty($obj_84738$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$471$$).call(this)}});Object.defineProperty($obj_84738$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$485$$).call(this)}});Object.defineProperty($obj_84738$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1093$$).call(this)}});
Object.defineProperty($obj_84738$$,"board",{enumerable:!1,get:function(){var $board_id$jscomp$inline_10112$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_ruler_guide$$(this));return $APP.$cljs$core$truth_$$($board_id$jscomp$inline_10112$$)?$app$plugins$ruler_guides$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$ruler_guides$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$21$$,$file_id$jscomp$471$$,$page_id$jscomp$485$$,$board_id$jscomp$inline_10112$$):
$app$plugins$ruler_guides$shape_proxy$$($plugin_id$jscomp$21$$,$file_id$jscomp$471$$,$page_id$jscomp$485$$,$board_id$jscomp$inline_10112$$):null},set:function($val_board_84903$$){return function($guide$jscomp$26_self$jscomp$135$$,$board_id$jscomp$2_value$jscomp$1080$$){var $shape$jscomp$1127$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$471$$,$page_id$jscomp$485$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($board_id$jscomp$2_value$jscomp$1080$$,"$id"));return $APP.$cljs$core$not$$($app$plugins$ruler_guides$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$app$plugins$ruler_guides$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($board_id$jscomp$2_value$jscomp$1080$$):$app$plugins$ruler_guides$shape_proxy_QMARK_$$($board_id$jscomp$2_value$jscomp$1080$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6476$board$$,"The board is not a shape proxy"):$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1127$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?
($board_id$jscomp$2_value$jscomp$1080$$=$APP.$cljs$core$truth_$$($board_id$jscomp$2_value$jscomp$1080$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($board_id$jscomp$2_value$jscomp$1080$$,"$id"):null,$guide$jscomp$26_self$jscomp$135$$=$app$plugins$utils$proxy__GT_ruler_guide$$($guide$jscomp$26_self$jscomp$135$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$26_self$jscomp$135$$,
$APP.$cljs$cst$1607$frame_id$$,$board_id$jscomp$2_value$jscomp$1080$$)),$plugin_id$jscomp$21$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6476$board$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6476$board$$,"The shape is not a board")}.call(this,this,$val_board_84903$$)}});Object.defineProperty($obj_84738$$,"orientation",{enumerable:!0,get:function(){a:{var $G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$=
$APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_ruler_guide$$(this));$G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$=$G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$ instanceof $APP.$cljs$core$Keyword$$?$G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$.$fqn$:null;switch($G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$){case "y":$G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$=
"horizontal";break a;case "x":$G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$="vertical";break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$)].join(""));}}return $G__83820__$1$jscomp$inline_13915_JSCompiler_inline_result$jscomp$11082_axis$jscomp$inline_13914$$}});Object.defineProperty($obj_84738$$,
"position",{enumerable:!0,get:function(){var $JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$=$app$plugins$utils$proxy__GT_ruler_guide$$(this);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$))){var $board_pos$jscomp$inline_10117_objects$jscomp$inline_10116$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$471$$,$page_id$jscomp$485$$);
$board_pos$jscomp$inline_10117_objects$jscomp$inline_10116$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($board_pos$jscomp$inline_10117_objects$jscomp$inline_10116$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$)),$APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$));$JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$=
$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$)-$board_pos$jscomp$inline_10117_objects$jscomp$inline_10116$$}else $JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$=$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$);return $JSCompiler_inline_result$jscomp$2155_guide$jscomp$inline_10115$$},set:function($JSCompiler_temp$jscomp$inline_13920_val_position_84918$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($JSCompiler_temp$jscomp$inline_13920_val_position_84918$$)))var $JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$APP.$cljs$cst$1676$position$$,"Not valid position");else if($app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")){$JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$=$app$plugins$utils$proxy__GT_ruler_guide$$(this);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$))){var $objects$jscomp$inline_13921$$=
$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$471$$,$page_id$jscomp$485$$);$JSCompiler_temp$jscomp$inline_13920_val_position_84918$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_13921$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$)),$APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$))+
$JSCompiler_temp$jscomp$inline_13920_val_position_84918$$}$JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$,$APP.$cljs$cst$1676$position$$,$JSCompiler_temp$jscomp$inline_13920_val_position_84918$$)),$plugin_id$jscomp$21$$))}else $JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$APP.$cljs$cst$1676$position$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$11084_guide$jscomp$inline_13919$$}});Object.defineProperty($obj_84738$$,"color",{enumerable:!0,get:function(){return $APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_ruler_guide$$(this))},set:function($JSCompiler_inline_result$jscomp$2157_val_color_84926$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,
"content:write")){var $guide$jscomp$inline_10123$$=$app$plugins$utils$proxy__GT_ruler_guide$$(this);$JSCompiler_inline_result$jscomp$2157_val_color_84926$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$inline_10123$$,$APP.$cljs$cst$1298$color$$,$JSCompiler_inline_result$jscomp$2157_val_color_84926$$)))}else $JSCompiler_inline_result$jscomp$2157_val_color_84926$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$APP.$cljs$cst$1298$color$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2157_val_color_84926$$}});Object.defineProperty($obj_84738$$,"remove",{enumerable:!1,get:function(){return function(){var $guide$jscomp$30$$=$app$plugins$utils$locate_ruler_guide$$($file_id$jscomp$471$$,$page_id$jscomp$485$$,$id$jscomp$1093$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$30$$),
$plugin_id$jscomp$21$$))}.bind(this)}});return $obj_84738$$},$app$plugins$text$font_data$$=function($font$jscomp$60$$,$variant$jscomp$32$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$60$$),$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$2675$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$60$$),$APP.$cljs$cst$1759$font_variant_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$32$$),$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$32$$),$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$32$$)],null))},$app$plugins$text$variant_data$$=function($variant$jscomp$33$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$33$$),$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$33$$),$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$33$$)],null))},$app$plugins$text$text_props$$=function($shape$jscomp$1128$$){return $APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$1128$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$1128$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1811$shape$$,
$shape$jscomp$1128$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]))},$app$plugins$text$content_range__GT_text_PLUS_styles$$=function($G__85943_node$jscomp$488_sss_styles$jscomp$36$$,$start$jscomp$256$$,$end$jscomp$112$$){$G__85943_node$jscomp$488_sss_styles$jscomp$36$$=$APP.$app$common$types$text$content__GT_text_PLUS_styles$$($G__85943_node$jscomp$488_sss_styles$jscomp$36$$);$G__85943_node$jscomp$488_sss_styles$jscomp$36$$=$APP.$cljs$core$seq$$($G__85943_node$jscomp$488_sss_styles$jscomp$36$$);
for(var $result__$1$jscomp$42_taking_QMARK_$$=!1,$acc$jscomp$170$$=0,$result$jscomp$388$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;)if($G__85943_node$jscomp$488_sss_styles$jscomp$36$$){var $G__85945_to$jscomp$29_vec__84945$$=$APP.$cljs$core$first$$($G__85943_node$jscomp$488_sss_styles$jscomp$36$$),$node_style$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__85945_to$jscomp$29_vec__84945$$,0,null),$G__85947_text$jscomp$152$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__85945_to$jscomp$29_vec__84945$$,
1,null),$G__85944_from$jscomp$33$$=$acc$jscomp$170$$;$G__85945_to$jscomp$29_vec__84945$$=$acc$jscomp$170$$+$APP.$cljs$core$count$$($G__85947_text$jscomp$152$$);var $taking_QMARK___$1$$=$result__$1$jscomp$42_taking_QMARK_$$||$G__85944_from$jscomp$33$$<=$start$jscomp$256$$&&$start$jscomp$256$$<$G__85945_to$jscomp$29_vec__84945$$,$text__$1$jscomp$2$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($G__85947_text$jscomp$152$$,function(){var $y__5111__auto__$jscomp$201$$=$start$jscomp$256$$-$acc$jscomp$170$$;
return 0>$y__5111__auto__$jscomp$201$$?0:$y__5111__auto__$jscomp$201$$}(),$end$jscomp$112$$-$acc$jscomp$170$$);$result__$1$jscomp$42_taking_QMARK_$$=function(){var $G__84949$$=$result$jscomp$388$$;return $taking_QMARK___$1$$&&$APP.$app$common$data$not_empty_QMARK_$$($text__$1$jscomp$2$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__84949$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node_style$jscomp$2$$,$APP.$cljs$cst$1588$text$$,$text__$1$jscomp$2$$)):$G__84949$$}();$G__85943_node$jscomp$488_sss_styles$jscomp$36$$=
$G__85944_from$jscomp$33$$>$end$jscomp$112$$||$end$jscomp$112$$>=$G__85945_to$jscomp$29_vec__84945$$?$APP.$cljs$core$rest$$($G__85943_node$jscomp$488_sss_styles$jscomp$36$$):null;$G__85944_from$jscomp$33$$=$taking_QMARK___$1$$;$G__85947_text$jscomp$152$$=$result__$1$jscomp$42_taking_QMARK_$$;$result__$1$jscomp$42_taking_QMARK_$$=$G__85944_from$jscomp$33$$;$acc$jscomp$170$$=$G__85945_to$jscomp$29_vec__84945$$;$result$jscomp$388$$=$G__85947_text$jscomp$152$$}else return $result$jscomp$388$$},$app$plugins$text$text_range_proxy$$=
function($plugin_id$jscomp$22$$,$file_id$jscomp$472$$,$page_id$jscomp$486$$,$id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$){var $obj_84971$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84971$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TextRange"}});Object.defineProperty($obj_84971$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TextRange"}});Object.defineProperty($obj_84971$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$22$$).call(this)}});
Object.defineProperty($obj_84971$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1094$$).call(this)}});Object.defineProperty($obj_84971$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$472$$).call(this)}});Object.defineProperty($obj_84971$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$486$$).call(this)}});Object.defineProperty($obj_84971$$,"shape",{enumerable:!0,get:function(){return $app$plugins$utils$proxy__GT_shape$$(this)}});
Object.defineProperty($obj_84971$$,"characters",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10126$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$range_data$jscomp$inline_10126$$))}});
Object.defineProperty($obj_84971$$,"fontId",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10129$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$,$range_data$jscomp$inline_10129$$))},set:function($val_fontid_85038$$){var $font$jscomp$inline_10133$$=
typeof $val_fontid_85038$$==="string"?$APP.$app$main$fonts$get_font_data$$($val_fontid_85038$$):null,$variant$jscomp$inline_10134$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10133$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10133$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6477$fontId$$,$val_fontid_85038$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,
$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$font_data$$($font$jscomp$inline_10133$$,$variant$jscomp$inline_10134$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6477$fontId$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"fontFamily",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10137$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1758$font_family$$,$range_data$jscomp$inline_10137$$))},set:function($val_fontfamily_85048$$){var $font$jscomp$inline_10141$$=$APP.$app$main$fonts$find_font_data$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2675$family$$,$val_fontfamily_85048$$],null)),$variant$jscomp$inline_10142$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10141$$);
return typeof $val_fontfamily_85048$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6478$fontFamily$$,$val_fontfamily_85048$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$font_data$$($font$jscomp$inline_10141$$,$variant$jscomp$inline_10142$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6478$fontFamily$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"fontVariantId",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10145$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1759$font_variant_id$$,
$range_data$jscomp$inline_10145$$))},set:function($val_fontvariantid_85056$$){var $font$jscomp$inline_10149_variant$jscomp$inline_10150$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId"));$font$jscomp$inline_10149_variant$jscomp$inline_10150$$=$APP.$app$main$fonts$get_variant$$($font$jscomp$inline_10149_variant$jscomp$inline_10150$$,$val_fontvariantid_85056$$);return typeof $val_fontvariantid_85056$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,
$cljs$cst$6479$fontVariantId$$,$val_fontvariantid_85056$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$variant_data$$($font$jscomp$inline_10149_variant$jscomp$inline_10150$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6479$fontVariantId$$,"Plugin doesn't have 'content:write' permission")}});
Object.defineProperty($obj_84971$$,"fontSize",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10153$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1760$font_size$$,$range_data$jscomp$inline_10153$$))},set:function($val_fontsize_85064_value__$1$jscomp$inline_10157$$){$val_fontsize_85064_value__$1$jscomp$inline_10157$$=
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($val_fontsize_85064_value__$1$jscomp$inline_10157$$??""));return $APP.$cljs$core$empty_QMARK_$$($val_fontsize_85064_value__$1$jscomp$inline_10157$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$font_size_re$$,$val_fontsize_85064_value__$1$jscomp$inline_10157$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6480$fontSize$$,$val_fontsize_85064_value__$1$jscomp$inline_10157$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1760$font_size$$,$val_fontsize_85064_value__$1$jscomp$inline_10157$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6480$fontSize$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"fontWeight",
{enumerable:!0,get:function(){var $range_data$jscomp$inline_10160$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1761$font_weight$$,$range_data$jscomp$inline_10160$$))},set:function($val_fontweight_85082$$){var $font$jscomp$inline_13925_variant$jscomp$inline_13927$$=
$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$weight$jscomp$inline_13926$$=""+($val_fontweight_85082$$??""),$or__5025__auto__$jscomp$inline_13928$$=$app$main$fonts$find_variant$$($font$jscomp$inline_13925_variant$jscomp$inline_13927$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1904$style$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontStyle"),$APP.$cljs$cst$1996$weight$$,$weight$jscomp$inline_13926$$],
null));$font$jscomp$inline_13925_variant$jscomp$inline_13927$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13928$$)?$or__5025__auto__$jscomp$inline_13928$$:$app$main$fonts$find_variant$$($font$jscomp$inline_13925_variant$jscomp$inline_13927$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1996$weight$$,$weight$jscomp$inline_13926$$],null));return $font$jscomp$inline_13925_variant$jscomp$inline_13927$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6481$fontWeight$$,
"Font weight '"+($val_fontweight_85082$$??"")+"' not supported for the current font"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$variant_data$$($font$jscomp$inline_13925_variant$jscomp$inline_13927$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6481$fontWeight$$,
"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"fontStyle",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10165$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1762$font_style$$,$range_data$jscomp$inline_10165$$))},
set:function($val_fontstyle_85098$$){var $font$jscomp$inline_13932_variant$jscomp$inline_13934$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$style$jscomp$inline_13933$$=""+($val_fontstyle_85098$$??""),$or__5025__auto__$jscomp$inline_13935$$=$app$main$fonts$find_variant$$($font$jscomp$inline_13932_variant$jscomp$inline_13934$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1996$weight$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"fontWeight"),$APP.$cljs$cst$1904$style$$,$style$jscomp$inline_13933$$],null));$font$jscomp$inline_13932_variant$jscomp$inline_13934$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13935$$)?$or__5025__auto__$jscomp$inline_13935$$:$app$main$fonts$find_variant$$($font$jscomp$inline_13932_variant$jscomp$inline_13934$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1904$style$$,$style$jscomp$inline_13933$$],null));return $font$jscomp$inline_13932_variant$jscomp$inline_13934$$==
null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6482$fontStyle$$,"Font style '"+($val_fontstyle_85098$$??"")+"' not supported for the current font"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$variant_data$$($font$jscomp$inline_13932_variant$jscomp$inline_13934$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6482$fontStyle$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"lineHeight",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10170$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1765$line_height$$,
$range_data$jscomp$inline_10170$$))},set:function($val_lineheight_85113_value__$1$jscomp$inline_10174$$){$val_lineheight_85113_value__$1$jscomp$inline_10174$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($val_lineheight_85113_value__$1$jscomp$inline_10174$$??""));return $APP.$cljs$core$empty_QMARK_$$($val_lineheight_85113_value__$1$jscomp$inline_10174$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$line_height_re$$,$val_lineheight_85113_value__$1$jscomp$inline_10174$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6483$lineHeight$$,$val_lineheight_85113_value__$1$jscomp$inline_10174$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1765$line_height$$,$val_lineheight_85113_value__$1$jscomp$inline_10174$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6483$lineHeight$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"letterSpacing",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10177$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1766$letter_spacing$$,
$range_data$jscomp$inline_10177$$))},set:function($val_letterspacing_85121_value__$1$jscomp$inline_13939$$){$val_letterspacing_85121_value__$1$jscomp$inline_13939$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($val_letterspacing_85121_value__$1$jscomp$inline_13939$$??""));var $JSCompiler_inline_result$jscomp$inline_13940_or__5025__auto__$jscomp$inline_13941$$=($JSCompiler_inline_result$jscomp$inline_13940_or__5025__auto__$jscomp$inline_13941$$=$APP.$cljs$core$empty_QMARK_$$($val_letterspacing_85121_value__$1$jscomp$inline_13939$$))?
$JSCompiler_inline_result$jscomp$inline_13940_or__5025__auto__$jscomp$inline_13941$$:$APP.$cljs$core$re_matches$$($app$plugins$text$letter_spacing_re$$,$val_letterspacing_85121_value__$1$jscomp$inline_13939$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13940_or__5025__auto__$jscomp$inline_13941$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6484$letterSpacing$$,$val_letterspacing_85121_value__$1$jscomp$inline_13939$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1766$letter_spacing$$,$val_letterspacing_85121_value__$1$jscomp$inline_13939$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6484$letterSpacing$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,
"textTransform",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10182$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1769$text_transform$$,$range_data$jscomp$inline_10182$$))},set:function($val_texttransform_85129$$){return typeof $val_texttransform_85129$$===
"string"&&$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_transform_re$$,$val_texttransform_85129$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6485$textTransform$$,$val_texttransform_85129$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1769$text_transform$$,$val_texttransform_85129$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6485$textTransform$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"textDecoration",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10188$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,
$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$,$range_data$jscomp$inline_10188$$))},set:function($val_textdecoration_85137$$){var $JSCompiler_inline_result$jscomp$inline_13945_and__5023__auto__$jscomp$inline_13946$$=($JSCompiler_inline_result$jscomp$inline_13945_and__5023__auto__$jscomp$inline_13946$$=typeof $val_textdecoration_85137$$==="string")?$APP.$cljs$core$re_matches$$($app$plugins$text$text_decoration_re$$,
$val_textdecoration_85137$$):$JSCompiler_inline_result$jscomp$inline_13945_and__5023__auto__$jscomp$inline_13946$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13945_and__5023__auto__$jscomp$inline_13946$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6486$textDecoration$$,$val_textdecoration_85137$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,
$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,$val_textdecoration_85137$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6486$textDecoration$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"direction",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10193$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1963$direction$$,$range_data$jscomp$inline_10193$$))},set:function($val_direction_85145$$){var $JSCompiler_inline_result$jscomp$inline_13950_and__5023__auto__$jscomp$inline_13951$$=($JSCompiler_inline_result$jscomp$inline_13950_and__5023__auto__$jscomp$inline_13951$$=typeof $val_direction_85145$$==="string")?$APP.$cljs$core$re_matches$$($app$plugins$text$text_direction_re$$,
$val_direction_85145$$):$JSCompiler_inline_result$jscomp$inline_13950_and__5023__auto__$jscomp$inline_13951$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13950_and__5023__auto__$jscomp$inline_13951$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1963$direction$$,$val_direction_85145$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,
$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1963$direction$$,$val_direction_85145$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1963$direction$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"align",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10198$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1763$text_align$$,$range_data$jscomp$inline_10198$$))},set:function($val_align_85153$$){var $JSCompiler_inline_result$jscomp$inline_13955_and__5023__auto__$jscomp$inline_13956$$=($JSCompiler_inline_result$jscomp$inline_13955_and__5023__auto__$jscomp$inline_13956$$=typeof $val_align_85153$$==="string")?$APP.$cljs$core$re_matches$$($app$plugins$text$text_align_re$$,
$val_align_85153$$):$JSCompiler_inline_result$jscomp$inline_13955_and__5023__auto__$jscomp$inline_13956$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13955_and__5023__auto__$jscomp$inline_13956$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$5116$align$$,$val_align_85153$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,
$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1763$text_align$$,$val_align_85153$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$5116$align$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"fills",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10203$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$format$format_fills$$($app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1634$fills$$,$range_data$jscomp$inline_10203$$)))},set:function($val_fills_85162_value__$1$jscomp$inline_10207$$){$val_fills_85162_value__$1$jscomp$inline_10207$$=$app$plugins$parser$parse_fills$$($val_fills_85162_value__$1$jscomp$inline_10207$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$fills$schema_COLON_fill$$],null),$val_fills_85162_value__$1$jscomp$inline_10207$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1634$fills$$,$val_fills_85162_value__$1$jscomp$inline_10207$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,
$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1634$fills$$,$val_fills_85162_value__$1$jscomp$inline_10207$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1634$fills$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84971$$,"applyTypography",{enumerable:!1,get:function(){return function($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$){$attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$=
$app$plugins$utils$proxy__GT_library_typography$$($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$);$attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$,$APP.$cljs$cst$1642$typography_ref_file$$,$file_id$jscomp$472$$),$APP.$cljs$cst$1756$typography_ref_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$)),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1094$$,$start$jscomp$257$$,$end$jscomp$113$$,$attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$))}.bind(this)}});
return $obj_84971$$},$app$plugins$text$add_text_props$$=function($shape_proxy$$,$plugin_id$jscomp$23$$){function $set_fn85662_86111$$($id$jscomp$1096_self$jscomp$158$$,$value$jscomp$1097$$){$id$jscomp$1096_self$jscomp$158$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1096_self$jscomp$158$$,"$id");var $value__$1$jscomp$108$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1097$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$1671$fixed$$,null,$APP.$cljs$cst$2036$auto_width$$,null],null),null),$value__$1$jscomp$108$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$1096_self$jscomp$158$$],null),function($p1__85599_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__85599_SHARP_$$,$APP.$cljs$cst$1770$grow_type$$,$value__$1$jscomp$108$$)}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1096_self$jscomp$158$$)):
null])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6488$growType$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6488$growType$$,$value__$1$jscomp$108$$)}function $set_fn85662_86106$$($self$jscomp$157_shape$jscomp$1129$$,$value$jscomp$1096$$){var $editor$jscomp$12_id$jscomp$1095$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$157_shape$jscomp$1129$$,"$id");if(typeof $value$jscomp$1096$$!==
"string"||$APP.$cljs$core$empty_QMARK_$$($value$jscomp$1096$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6487$characters$$,$value$jscomp$1096$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")){if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2222$workspace_editor_state$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$editor$jscomp$12_id$jscomp$1095$$))return $self$jscomp$157_shape$jscomp$1129$$=
$app$plugins$utils$proxy__GT_shape$$($self$jscomp$157_shape$jscomp$1129$$),$editor$jscomp$12_id$jscomp$1095$$=$app$util$text_editor$create_editor_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$text_editor$import_content$$($app$common$types$text$change_text$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self$jscomp$157_shape$jscomp$1129$$,$APP.$cljs$cst$1637$content$$),$value$jscomp$1096$$))),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($self$jscomp$157_shape$jscomp$1129$$,
$editor$jscomp$12_id$jscomp$1095$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$editor$jscomp$12_id$jscomp$1095$$],null),function($p1__85597_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__85597_SHARP_$$,$APP.$cljs$cst$1637$content$$,$app$common$types$text$change_text$$,
$value$jscomp$1096$$)}));return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($editor$jscomp$12_id$jscomp$1095$$)):null}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6487$characters$$,"Plugin doesn't have 'content:write' permission")}Object.defineProperty($shape_proxy$$,
"characters",function(){return{enumerable:!0,get:function(){return $APP.$app$common$types$text$content__GT_text$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42799__auto__$$){return $set_fn85662_86106$$(this,$value__42799__auto__$$)}}}());Object.defineProperty($shape_proxy$$,"growType",function(){return{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($value__42799__auto__$jscomp$1$$){return $set_fn85662_86111$$(this,$value__42799__auto__$jscomp$1$$)}}}());Object.defineProperty($shape_proxy$$,"fontId",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$2$$){var $id$jscomp$inline_10211$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id"),$font$jscomp$inline_10212$$=typeof $value__42799__auto__$jscomp$2$$==="string"?$APP.$app$main$fonts$get_font_data$$($value__42799__auto__$jscomp$2$$):null,$variant$jscomp$inline_10213$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10212$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10212$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6477$fontId$$,$value__42799__auto__$jscomp$2$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10211$$,$app$plugins$text$font_data$$($font$jscomp$inline_10212$$,$variant$jscomp$inline_10213$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6477$fontId$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontFamily",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42799__auto__$jscomp$3$$){var $id$jscomp$inline_10217$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_10218$$=$APP.$app$main$fonts$find_font_data$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2675$family$$,$value__42799__auto__$jscomp$3$$],null)),$variant$jscomp$inline_10219$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10218$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10218$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,
$cljs$cst$6478$fontFamily$$,$value__42799__auto__$jscomp$3$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10217$$,$app$plugins$text$font_data$$($font$jscomp$inline_10218$$,$variant$jscomp$inline_10219$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6478$fontFamily$$,"Plugin doesn't have 'content:write' permission")}}}());
Object.defineProperty($shape_proxy$$,"fontVariantId",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$4$$){var $id$jscomp$inline_10223$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_10224_variant$jscomp$inline_10225$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"fontId"));$font$jscomp$inline_10224_variant$jscomp$inline_10225$$=$APP.$app$main$fonts$get_variant$$($font$jscomp$inline_10224_variant$jscomp$inline_10225$$,$value__42799__auto__$jscomp$4$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10224_variant$jscomp$inline_10225$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6479$fontVariantId$$,$value__42799__auto__$jscomp$4$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10223$$,
$app$plugins$text$variant_data$$($font$jscomp$inline_10224_variant$jscomp$inline_10225$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6479$fontVariantId$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontSize",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$){var $id$jscomp$inline_10229$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$??""));return $APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$font_size_re$$,
$value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6480$fontSize$$,$value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10229$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1760$font_size$$,
$value__$1$jscomp$inline_10230_value__42799__auto__$jscomp$5$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6480$fontSize$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontWeight",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$6$$){var $id$jscomp$inline_13960$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_13961_variant$jscomp$inline_13963$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$weight$jscomp$inline_13962$$=""+($value__42799__auto__$jscomp$6$$??""),$or__5025__auto__$jscomp$inline_13964$$=$app$main$fonts$find_variant$$($font$jscomp$inline_13961_variant$jscomp$inline_13963$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1904$style$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontStyle"),$APP.$cljs$cst$1996$weight$$,$weight$jscomp$inline_13962$$],null));$font$jscomp$inline_13961_variant$jscomp$inline_13963$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13964$$)?$or__5025__auto__$jscomp$inline_13964$$:$app$main$fonts$find_variant$$($font$jscomp$inline_13961_variant$jscomp$inline_13963$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1996$weight$$,$weight$jscomp$inline_13962$$],
null));return $font$jscomp$inline_13961_variant$jscomp$inline_13963$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6481$fontWeight$$,"Font weight '"+($value__42799__auto__$jscomp$6$$??"")+"' not supported for the current font"):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_13960$$,$app$plugins$text$variant_data$$($font$jscomp$inline_13961_variant$jscomp$inline_13963$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6481$fontWeight$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontStyle",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$7$$){var $id$jscomp$inline_13968$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id"),$font$jscomp$inline_13969_variant$jscomp$inline_13971$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$style$jscomp$inline_13970$$=""+($value__42799__auto__$jscomp$7$$??""),$or__5025__auto__$jscomp$inline_13972$$=$app$main$fonts$find_variant$$($font$jscomp$inline_13969_variant$jscomp$inline_13971$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1996$weight$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"fontWeight"),$APP.$cljs$cst$1904$style$$,$style$jscomp$inline_13970$$],null));$font$jscomp$inline_13969_variant$jscomp$inline_13971$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13972$$)?$or__5025__auto__$jscomp$inline_13972$$:$app$main$fonts$find_variant$$($font$jscomp$inline_13969_variant$jscomp$inline_13971$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1904$style$$,$style$jscomp$inline_13970$$],null));return $font$jscomp$inline_13969_variant$jscomp$inline_13971$$==
null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6482$fontStyle$$,"Font style '"+($value__42799__auto__$jscomp$7$$??"")+"' not supported for the current font"):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_13968$$,$app$plugins$text$variant_data$$($font$jscomp$inline_13969_variant$jscomp$inline_13971$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,
$cljs$cst$6482$fontStyle$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"lineHeight",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$){var $id$jscomp$inline_10238$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id");$value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$??""));return $APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$line_height_re$$,$value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,
$cljs$cst$6483$lineHeight$$,$value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10238$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1765$line_height$$,$value__$1$jscomp$inline_10239_value__42799__auto__$jscomp$8$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,
$cljs$cst$6483$lineHeight$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"letterSpacing",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$){var $id$jscomp$inline_10243$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id");$value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$??""));return typeof $value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$letter_spacing_re$$,$value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6484$letterSpacing$$,
$value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10243$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1766$letter_spacing$$,$value__$1$jscomp$inline_10244_value__42799__auto__$jscomp$9$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6484$letterSpacing$$,
"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"textTransform",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$10$$){var $id$jscomp$inline_10248$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42799__auto__$jscomp$10$$!==
"string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_transform_re$$,$value__42799__auto__$jscomp$10$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6485$textTransform$$,$value__42799__auto__$jscomp$10$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10248$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1769$text_transform$$,$value__42799__auto__$jscomp$10$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6485$textTransform$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"textDecoration",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42799__auto__$jscomp$11$$){var $id$jscomp$inline_10252$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42799__auto__$jscomp$11$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_decoration_re$$,$value__42799__auto__$jscomp$11$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6486$textDecoration$$,$value__42799__auto__$jscomp$11$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10252$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,$value__42799__auto__$jscomp$11$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6486$textDecoration$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"direction",function(){return{enumerable:!0,
get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$12$$){var $id$jscomp$inline_10256$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42799__auto__$jscomp$12$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_direction_re$$,
$value__42799__auto__$jscomp$12$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6489$textDirection$$,$value__42799__auto__$jscomp$12$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10256$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1764$text_direction$$,$value__42799__auto__$jscomp$12$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6489$textDirection$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"align",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1763$text_align$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42799__auto__$jscomp$13$$){var $id$jscomp$inline_10260$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42799__auto__$jscomp$13$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_align_re$$,$value__42799__auto__$jscomp$13$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$5116$align$$,$value__42799__auto__$jscomp$13$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10260$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1763$text_align$$,$value__42799__auto__$jscomp$13$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$5116$align$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"verticalAlign",function(){return{enumerable:!0,get:function(){return $APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($value__42799__auto__$jscomp$14$$){var $id$jscomp$inline_10264$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42799__auto__$jscomp$14$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$vertical_align_re$$,$value__42799__auto__$jscomp$14$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6490$verticalAlign$$,$value__42799__auto__$jscomp$14$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10264$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1767$vertical_align$$,$value__42799__auto__$jscomp$14$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6490$verticalAlign$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"textBounds",function(){return{enumerable:!0,
get:function(){var $JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$=$app$plugins$utils$proxy__GT_shape$$(this);var $points$jscomp$inline_13975_y$jscomp$inline_13980$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$rect__GT_points$$,$APP.$app$common$geom$shapes$text$position_data__GT_rect$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$)]));
$JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$inline_13975_y$jscomp$inline_13980$$,$APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$,null)));var $height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$);$JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$,$APP.$cljs$cst$1510$x$$);$points$jscomp$inline_13975_y$jscomp$inline_13980$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$,
$APP.$cljs$cst$1511$y$$);var $width$jscomp$inline_13981$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$,$APP.$cljs$cst$1522$height$$);return{x:$JSCompiler_inline_result$jscomp$11063_shape$jscomp$inline_13974_x$jscomp$inline_13979$$,
y:$points$jscomp$inline_13975_y$jscomp$inline_13980$$,width:$width$jscomp$inline_13981$$,height:$height$jscomp$inline_13982_map__83822__$1$jscomp$inline_13978$$}}}}());return $shape_proxy$$},$app$plugins$tokens$token_attr_plugin__GT_token_attr$$=function($k$jscomp$735_k__$1$jscomp$23$$){$k$jscomp$735_k__$1$jscomp$23$$=typeof $k$jscomp$735_k__$1$jscomp$23$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$735_k__$1$jscomp$23$$):$k$jscomp$735_k__$1$jscomp$23$$;return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$tokens$map_COLON_token_attr_plugin__GT_token_attr$$,
$k$jscomp$735_k__$1$jscomp$23$$,$k$jscomp$735_k__$1$jscomp$23$$)},$app$plugins$tokens$applied_tokens_plugin__GT_applied_tokens$$=function($value$jscomp$1111$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__84941_v$jscomp$698$$){var $k$jscomp$736$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__84941_v$jscomp$698$$,0,null);$p__84941_v$jscomp$698$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__84941_v$jscomp$698$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$tokens$map_COLON_token_attr__GT_token_attr_plugin$$,$k$jscomp$736$$,$k$jscomp$736$$),$p__84941_v$jscomp$698$$],null)}),$value$jscomp$1111$$)},$app$plugins$tokens$token_attr_QMARK_$$=function($attr$jscomp$95_attr$jscomp$inline_10266$$){$attr$jscomp$95_attr$jscomp$inline_10266$$=$app$plugins$tokens$token_attr_plugin__GT_token_attr$$($attr$jscomp$95_attr$jscomp$inline_10266$$);
return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$token$all_keys$$,$attr$jscomp$95_attr$jscomp$inline_10266$$)},$app$plugins$tokens$apply_token_to_shapes$$=function($plugin_id$jscomp$24$$,$file_id$jscomp$473_token$jscomp$207$$,$set_id$jscomp$46$$,$id$jscomp$1110$$,$shape_ids$jscomp$118$$,$attrs$jscomp$187$$){$file_id$jscomp$473_token$jscomp$207$$=$app$plugins$utils$locate_token$$($file_id$jscomp$473_token$jscomp$207$$,$set_id$jscomp$46$$,$id$jscomp$1110$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__84948_SHARP_$$){return!$app$plugins$tokens$token_attr_QMARK_$$($p1__84948_SHARP_$$)},
$attrs$jscomp$187$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6503$applyToSelected$$,$attrs$jscomp$187$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$file_id$jscomp$473_token$jscomp$207$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$tokens$token_attr_plugin__GT_token_attr$$),$attrs$jscomp$187$$),$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$118$$,$APP.$cljs$cst$4653$expand_with_children$$,!1],null)),$plugin_id$jscomp$24$$))},$app$plugins$tokens$get_resolved_value$$=function($token$jscomp$208$$,$resolved_tokens$jscomp$31_tokens_tree$jscomp$14$$){$resolved_tokens$jscomp$31_tokens_tree$jscomp$14$$=$APP.$app$main$data$tokenscript$resolve_tokens$$($resolved_tokens$jscomp$31_tokens_tree$jscomp$14$$);
return $APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$31_tokens_tree$jscomp$14$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$208$$)),$APP.$cljs$cst$4605$resolved_value$$))},$app$plugins$tokens$shape_proxy_QMARK_$$=function($s$jscomp$611$$){return $app$util$object$type_of_QMARK_$$($s$jscomp$611$$,"ShapeProxy")},$app$plugins$tokens$token_set_proxy_QMARK_$$=
function($p$jscomp$275$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$275$$,"TokenSetProxy")},$app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$=function($plugin_id$jscomp$27$$,$file_id$jscomp$476$$,$id$jscomp$1113$$,$initial_name$$){function $schema_addtoken_85724_86439$$($G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$){var $tokens_tree$jscomp$17$$=$APP.$app$common$types$tokens_lib$tokens_tree$$($APP.$app$common$types$tokens_lib$get_tokens$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$476$$),
$id$jscomp$1113$$)),$JSCompiler_temp_const$jscomp$2206$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$),"type");$G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$=$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$2206$$,[$APP.$cljs$cst$498$tuple$$,$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($tokens_tree$jscomp$17$$,
$G__85800$jscomp$inline_10306_JSCompiler_inline_result$jscomp$2207_args$jscomp$268$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$938$decode_SLASH_json$$,$app$common$files$tokens$convert_dtcg_token$$]))],null)}var $obj_85617$$=new $APP.$app$util$object$Proxy$$,$schema_name_85676_86420$$=$APP.$app$common$files$tokens$make_token_set_name_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$476$$),$id$jscomp$1113$$),$coercer_fn_name_85674_86421$$=$schema_name_85676_86420$$==
null||$APP.$cljs$core$fn_QMARK_$$($schema_name_85676_86420$$)?null:$APP.$app$common$schema$coercer$$($schema_name_85676_86420$$),$coercer_fn_active_85684_86426$$=$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$==null||$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?null:$APP.$app$common$schema$coercer$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$),$schema_gettokenbyid_85717_86435$$=new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$coercer_fn_gettokenbyid_85715_86436$$=$schema_gettokenbyid_85717_86435$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_gettokenbyid_85717_86435$$)?null:$APP.$app$common$schema$coercer$$($schema_gettokenbyid_85717_86435$$),$coercer_fn_addtoken_85722_86440$$=$schema_addtoken_85724_86439$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addtoken_85724_86439$$)?null:$APP.$app$common$schema$coercer$$($schema_addtoken_85724_86439$$);
Object.defineProperty($obj_85617$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TokenSetProxy"}});Object.defineProperty($obj_85617$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokenSetProxy"}});Object.defineProperty($obj_85617$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_85641$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$27$$);try{return $internal_fn_plugin_85641$$.call(this)}catch($e85748$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85748$$)}}});
Object.defineProperty($obj_85617$$,"$file-id",{enumerable:!1,get:function(){var $internal_fn_fileid_85648$$=$APP.$cljs$core$constantly$$($file_id$jscomp$476$$);try{return $internal_fn_fileid_85648$$.call(this)}catch($e85755$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85755$$)}}});Object.defineProperty($obj_85617$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_85655$$=$APP.$cljs$core$constantly$$($id$jscomp$1113$$);try{return $internal_fn_id_85655$$.call(this)}catch($e85756$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85756$$)}}});
Object.defineProperty($obj_85617$$,"id",{enumerable:!0,get:function(){try{return""+($id$jscomp$1113$$??"")}catch($e85763$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85763$$)}}});Object.defineProperty($obj_85617$$,"name",{enumerable:!0,get:function(){try{var $set$jscomp$inline_10291$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$476$$,$id$jscomp$1113$$);return $set$jscomp$inline_10291$$!=null?$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$inline_10291$$):
$initial_name$$}catch($e85770$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85770$$)}},set:function($val_name_85678$$){try{var $schema_name_85676__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_name_85676_86420$$)?$schema_name_85676_86420$$($val_name_85678$$):$schema_name_85676_86420$$,$coercer_fn_name_85674__$1$$=$coercer_fn_name_85674_86421$$==null?$APP.$app$common$schema$coercer$$($schema_name_85676__$1$$):$coercer_fn_name_85674_86421$$,$val_name_85678__$1$$=$APP.$app$common$json$__GT_clj$$($val_name_85678$$,
null),$name$jscomp$inline_10295$$=$coercer_fn_name_85674__$1$$($val_name_85678__$1$$),$set$jscomp$inline_10296$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$476$$,$id$jscomp$1113$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$rename_token_set$$($set$jscomp$inline_10296$$,$name$jscomp$inline_10295$$))}catch($e85773$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85773$$)}}});Object.defineProperty($obj_85617$$,
"active",{enumerable:!1,get:function(){try{var $tokens_lib$jscomp$inline_10298$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$476$$),$set$jscomp$inline_10299$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$476$$,$id$jscomp$1113$$);return $APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$($tokens_lib$jscomp$inline_10298$$,$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$inline_10299$$))}catch($e85778$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85778$$)}},
set:function($val_active_85688$$){try{var $schema_active_85686__$1$$=$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?(0,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)($val_active_85688$$):$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$,$coercer_fn_active_85684__$1$$=$coercer_fn_active_85684_86426$$==null?$APP.$app$common$schema$coercer$$($schema_active_85686__$1$$):$coercer_fn_active_85684_86426$$,$val_active_85688__$1$$=$APP.$app$common$json$__GT_clj$$($val_active_85688$$,
null),$value$jscomp$inline_10303$$=$coercer_fn_active_85684__$1$$($val_active_85688__$1$$),$set$jscomp$inline_10304$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$476$$,$id$jscomp$1113$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$set_enabled_token_set$$($APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$inline_10304$$),$value$jscomp$inline_10303$$))}catch($e85779$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85779$$)}}});
Object.defineProperty($obj_85617$$,"toggleActive",{enumerable:!1,get:function(){return function(){try{var $set$jscomp$27$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$476$$,$id$jscomp$1113$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_set$$($APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$27$$)))}catch($e85782$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85782$$)}}.bind(this)}});
Object.defineProperty($obj_85617$$,"tokens",{enumerable:!1,get:function(){function $internal_fn_tokens_85698$$(){var $tokens_lib$jscomp$59$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$476$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__85573_SHARP_$$){return $app$plugins$tokens$token_proxy$$($plugin_id$jscomp$27$$,$file_id$jscomp$476$$,$id$jscomp$1113$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__85573_SHARP_$$))},
$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$59$$,$id$jscomp$1113$$))))}try{return $internal_fn_tokens_85698$$.call(this,this)}catch($e85785$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85785$$)}}});Object.defineProperty($obj_85617$$,"tokensByType",{enumerable:!1,get:function(){function $internal_fn_tokensbytype_85705$$(){var $tokens$jscomp$81_tokens_lib$jscomp$60$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$476$$);$tokens$jscomp$81_tokens_lib$jscomp$60$$=
$APP.$app$common$types$tokens_lib$get_tokens$$($tokens$jscomp$81_tokens_lib$jscomp$60$$,$id$jscomp$1113$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__85786_tokens__$1$jscomp$14$$){var $type$jscomp$745$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__85786_tokens__$1$jscomp$14$$,0,null);$p__85786_tokens__$1$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__85786_tokens__$1$jscomp$14$$,
1,null);return[$APP.$cljs$core$name$$($type$jscomp$745$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__85577_SHARP_$$){return $app$plugins$tokens$token_proxy$$($plugin_id$jscomp$27$$,$file_id$jscomp$476$$,$id$jscomp$1113$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__85577_SHARP_$$))},$p__85786_tokens__$1$jscomp$14$$))]},$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$group_by$$(function($G__85792_p1__85576_SHARP_$$){$G__85792_p1__85576_SHARP_$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__85792_p1__85576_SHARP_$$);return $APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__85792_p1__85576_SHARP_$$):(0,$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$)($G__85792_p1__85576_SHARP_$$)},
$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$vals$$($tokens$jscomp$81_tokens_lib$jscomp$60$$))))))}try{return $internal_fn_tokensbytype_85705$$.call(this,this)}catch($e85793$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85793$$)}}});Object.defineProperty($obj_85617$$,"getTokenById",{enumerable:!1,get:function(){var $internal_fn_gettokenbyid_85714__$1$$=function($token_id$jscomp$25$$){try{return $app$plugins$utils$locate_token$$($file_id$jscomp$476$$,
$id$jscomp$1113$$,$token_id$jscomp$25$$)!=null?$app$plugins$tokens$token_proxy$$($plugin_id$jscomp$27$$,$file_id$jscomp$476$$,$id$jscomp$1113$$,$token_id$jscomp$25$$):null}catch($e85796$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85796$$)}}.bind(this);return function(){try{var $val_gettokenbyid_85719$$=Array.from(arguments),$val_gettokenbyid_85719__$1$$=$APP.$app$common$json$__GT_clj$$($val_gettokenbyid_85719$$,null),$schema_gettokenbyid_85717__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_gettokenbyid_85717_86435$$)?
$schema_gettokenbyid_85717_86435$$($val_gettokenbyid_85719__$1$$):$schema_gettokenbyid_85717_86435$$,$val_gettokenbyid_85719__$2$$=($coercer_fn_gettokenbyid_85715_86436$$==null?$APP.$app$common$schema$coercer$$($schema_gettokenbyid_85717__$1$$):$coercer_fn_gettokenbyid_85715_86436$$)($val_gettokenbyid_85719__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_gettokenbyid_85714__$1$$,$val_gettokenbyid_85719__$2$$)}catch($e85797$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85797$$)}}}});
Object.defineProperty($obj_85617$$,"addToken",{enumerable:!1,get:function(){var $internal_fn_addtoken_85721__$1$$=function($attrs$jscomp$190$$){try{var $tokens_lib$jscomp$61$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$476$$),$token$jscomp$218$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$190$$])),$tokens_tree$jscomp$18$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$61$$),
$token$jscomp$218$$.name,$token$jscomp$218$$),$resolved_tokens$jscomp$32$$=$APP.$app$main$data$tokenscript$resolve_tokens$$($tokens_tree$jscomp$18$$),$map__85804$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$32$$,$token$jscomp$218$$.name),$map__85804__$1$$=$APP.$cljs$core$__destructure_map$$($map__85804$$),$errors$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__85804__$1$$,$APP.$cljs$cst$570$errors$$),$resolved_value$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__85804__$1$$,
$APP.$cljs$cst$4605$resolved_value$$);if($APP.$cljs$core$truth_$$($resolved_value$jscomp$13$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1113$$,$token$jscomp$218$$),$plugin_id$jscomp$27$$)),$app$plugins$tokens$token_proxy$$($plugin_id$jscomp$27$$,$file_id$jscomp$476$$,$id$jscomp$1113$$,$token$jscomp$218$$.id);$app$plugins$utils$not_valid$$($plugin_id$jscomp$27$$,
$cljs$cst$6504$addToken$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($errors$jscomp$49$$));return null}catch($e85803$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85803$$)}}.bind(this);return function(){try{var $val_addtoken_85726$$=Array.from(arguments),$val_addtoken_85726__$1$$=$APP.$app$common$json$__GT_clj$$($val_addtoken_85726$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$],null)),$schema_addtoken_85724__$1$$=
$APP.$cljs$core$fn_QMARK_$$($schema_addtoken_85724_86439$$)?$schema_addtoken_85724_86439$$($val_addtoken_85726__$1$$):$schema_addtoken_85724_86439$$,$val_addtoken_85726__$2$$=($coercer_fn_addtoken_85722_86440$$==null?$APP.$app$common$schema$coercer$$($schema_addtoken_85724__$1$$):$coercer_fn_addtoken_85722_86440$$)($val_addtoken_85726__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addtoken_85721__$1$$,$val_addtoken_85726__$2$$)}catch($e85807$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85807$$)}}}});
Object.defineProperty($obj_85617$$,"duplicate",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$duplicate_token_set$$($id$jscomp$1113$$))}catch($e85810$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85810$$)}}.bind(this)}});Object.defineProperty($obj_85617$$,"remove",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_set$$($id$jscomp$1113$$))}catch($e85811$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e85811$$)}}.bind(this)}});
return $obj_85617$$},$app$plugins$tokens$tokens_catalog$$=function($plugin_id$jscomp$29$$,$file_id$jscomp$478$$){function $schema_addtheme_86164_87016$$($attrs$jscomp$191$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$app$common$schema$dissoc_key$$($APP.$app$common$schema$schema$$($app$common$files$tokens$make_token_theme_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$478$$),function(){var $or__5025__auto__$jscomp$1451$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($attrs$jscomp$191$$,"group");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1451$$)?$or__5025__auto__$jscomp$1451$$:""}(),function(){var $or__5025__auto__$jscomp$1452$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($attrs$jscomp$191$$,"name");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1452$$)?$or__5025__auto__$jscomp$1452$$:""}())))],null)}var $obj_86113$$=new $APP.$app$util$object$Proxy$$,$coercer_fn_addtheme_86162_87017$$=
$schema_addtheme_86164_87016$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addtheme_86164_87016$$)?null:$APP.$app$common$schema$coercer$$($schema_addtheme_86164_87016$$),$schema_addset_86171_87020$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$app$common$schema$dissoc_key$$($APP.$app$common$schema$schema$$($app$common$files$tokens$make_token_set_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$478$$))))],
null),$coercer_fn_addset_86169_87021$$=$schema_addset_86171_87020$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addset_86171_87020$$)?null:$APP.$app$common$schema$coercer$$($schema_addset_86171_87020$$),$schema_getthemebyid_86178_87024$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$coercer_fn_getthemebyid_86176_87025$$=$schema_getthemebyid_86178_87024$$==null||
$APP.$cljs$core$fn_QMARK_$$($schema_getthemebyid_86178_87024$$)?null:$APP.$app$common$schema$coercer$$($schema_getthemebyid_86178_87024$$),$schema_getsetbyid_86185_87028$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$coercer_fn_getsetbyid_86183_87029$$=$schema_getsetbyid_86185_87028$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_getsetbyid_86185_87028$$)?null:
$APP.$app$common$schema$coercer$$($schema_getsetbyid_86185_87028$$);Object.defineProperty($obj_86113$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TokensCatalog"}});Object.defineProperty($obj_86113$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokensCatalog"}});Object.defineProperty($obj_86113$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_86131$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$29$$);try{return $internal_fn_plugin_86131$$.call(this)}catch($e86193$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86193$$)}}});
Object.defineProperty($obj_86113$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_86138$$=$APP.$cljs$core$constantly$$($file_id$jscomp$478$$);try{return $internal_fn_id_86138$$.call(this)}catch($e86196$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86196$$)}}});Object.defineProperty($obj_86113$$,"themes",{enumerable:!1,get:function(){function $internal_fn_themes_86145$$(){var $themes$jscomp$21_tokens_lib$jscomp$64$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$478$$);
$themes$jscomp$21_tokens_lib$jscomp$64$$=$APP.$cljs$core$truth_$$($themes$jscomp$21_tokens_lib$jscomp$64$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86107_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__86107_SHARP_$$),$APP.$app$common$uuid$zero$$)},$APP.$app$common$types$tokens_lib$get_themes$$($themes$jscomp$21_tokens_lib$jscomp$64$$)):null;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86108_SHARP_$$){return $app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$29$$,$file_id$jscomp$478$$,$APP.$app$common$types$tokens_lib$get_id$$($p1__86108_SHARP_$$))},$themes$jscomp$21_tokens_lib$jscomp$64$$))}try{return $internal_fn_themes_86145$$.call(this,this)}catch($e86199$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86199$$)}}});Object.defineProperty($obj_86113$$,"sets",{enumerable:!1,get:function(){function $internal_fn_sets_86152$$(){var $sets$jscomp$23_tokens_lib$jscomp$65$$=
$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$478$$);$sets$jscomp$23_tokens_lib$jscomp$65$$=$APP.$cljs$core$truth_$$($sets$jscomp$23_tokens_lib$jscomp$65$$)?$APP.$app$common$types$tokens_lib$get_sets$$($sets$jscomp$23_tokens_lib$jscomp$65$$):null;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$inline_10334_p1__86109_SHARP_$$){$id$jscomp$inline_10334_p1__86109_SHARP_$$=$APP.$app$common$types$tokens_lib$get_id$$($id$jscomp$inline_10334_p1__86109_SHARP_$$);
return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$($plugin_id$jscomp$29$$,$file_id$jscomp$478$$,$id$jscomp$inline_10334_p1__86109_SHARP_$$,null)},$sets$jscomp$23_tokens_lib$jscomp$65$$))}try{return $internal_fn_sets_86152$$.call(this,this)}catch($e86204$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86204$$)}}});Object.defineProperty($obj_86113$$,"addTheme",{enumerable:!1,get:function(){var $internal_fn_addtheme_86161__$1$$=function($attrs$jscomp$192$$){try{var $theme$jscomp$42$$=
$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$192$$]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$($theme$jscomp$42$$));return $app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$29$$,$file_id$jscomp$478$$,$theme$jscomp$42$$.id)}catch($e86209$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86209$$)}}.bind(this);
return function(){try{var $val_addtheme_86166$$=Array.from(arguments),$val_addtheme_86166__$1$$=$APP.$app$common$json$__GT_clj$$($val_addtheme_86166$$,null),$schema_addtheme_86164__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addtheme_86164_87016$$)?$schema_addtheme_86164_87016$$($val_addtheme_86166__$1$$):$schema_addtheme_86164_87016$$,$val_addtheme_86166__$2$$=($coercer_fn_addtheme_86162_87017$$==null?$APP.$app$common$schema$coercer$$($schema_addtheme_86164__$1$$):$coercer_fn_addtheme_86162_87017$$)($val_addtheme_86166__$1$$);
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addtheme_86161__$1$$,$val_addtheme_86166__$2$$)}catch($e86212$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86212$$)}}}});Object.defineProperty($obj_86113$$,"addSet",{enumerable:!1,get:function(){var $internal_fn_addset_86168__$1$$=function($attrs$jscomp$193$$){try{var $attrs__$1$jscomp$26$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$193$$,$APP.$cljs$cst$725$name$$,$APP.$app$common$types$tokens_lib$normalize_set_name$$),
$set$jscomp$28$$=$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs__$1$jscomp$26$$]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$create_token_set$$($set$jscomp$28$$));return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$($plugin_id$jscomp$29$$,$file_id$jscomp$478$$,$set$jscomp$28$$.id,$set$jscomp$28$$.name)}catch($e86219$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86219$$)}}.bind(this);
return function(){try{var $val_addset_86173$$=Array.from(arguments),$val_addset_86173__$1$$=$APP.$app$common$json$__GT_clj$$($val_addset_86173$$,null),$schema_addset_86171__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addset_86171_87020$$)?$schema_addset_86171_87020$$($val_addset_86173__$1$$):$schema_addset_86171_87020$$,$val_addset_86173__$2$$=($coercer_fn_addset_86169_87021$$==null?$APP.$app$common$schema$coercer$$($schema_addset_86171__$1$$):$coercer_fn_addset_86169_87021$$)($val_addset_86173__$1$$);
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addset_86168__$1$$,$val_addset_86173__$2$$)}catch($e86222$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86222$$)}}}});Object.defineProperty($obj_86113$$,"getThemeById",{enumerable:!1,get:function(){var $internal_fn_getthemebyid_86175__$1$$=function($theme_id$jscomp$11$$){try{return $app$plugins$utils$locate_token_theme$$($file_id$jscomp$478$$,$theme_id$jscomp$11$$)!=null?$app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$29$$,
$file_id$jscomp$478$$,$theme_id$jscomp$11$$):null}catch($e86223$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86223$$)}}.bind(this);return function(){try{var $val_getthemebyid_86180$$=Array.from(arguments),$val_getthemebyid_86180__$1$$=$APP.$app$common$json$__GT_clj$$($val_getthemebyid_86180$$,null),$schema_getthemebyid_86178__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_getthemebyid_86178_87024$$)?$schema_getthemebyid_86178_87024$$($val_getthemebyid_86180__$1$$):$schema_getthemebyid_86178_87024$$,
$val_getthemebyid_86180__$2$$=($coercer_fn_getthemebyid_86176_87025$$==null?$APP.$app$common$schema$coercer$$($schema_getthemebyid_86178__$1$$):$coercer_fn_getthemebyid_86176_87025$$)($val_getthemebyid_86180__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_getthemebyid_86175__$1$$,$val_getthemebyid_86180__$2$$)}catch($e86224$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86224$$)}}}});Object.defineProperty($obj_86113$$,"getSetById",{enumerable:!1,
get:function(){var $internal_fn_getsetbyid_86182__$1$$=function($set_id$jscomp$48$$){try{return $app$plugins$utils$locate_token_set$$($file_id$jscomp$478$$,$set_id$jscomp$48$$)!=null?$app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$($plugin_id$jscomp$29$$,$file_id$jscomp$478$$,$set_id$jscomp$48$$,null):null}catch($e86225$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86225$$)}}.bind(this);return function(){try{var $val_getsetbyid_86187$$=Array.from(arguments),
$val_getsetbyid_86187__$1$$=$APP.$app$common$json$__GT_clj$$($val_getsetbyid_86187$$,null),$schema_getsetbyid_86185__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_getsetbyid_86185_87028$$)?$schema_getsetbyid_86185_87028$$($val_getsetbyid_86187__$1$$):$schema_getsetbyid_86185_87028$$,$val_getsetbyid_86187__$2$$=($coercer_fn_getsetbyid_86183_87029$$==null?$APP.$app$common$schema$coercer$$($schema_getsetbyid_86185__$1$$):$coercer_fn_getsetbyid_86183_87029$$)($val_getsetbyid_86187__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_getsetbyid_86182__$1$$,
$val_getsetbyid_86187__$2$$)}catch($e86226$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e86226$$)}}}});return $obj_86113$$},$app$plugins$shape$interaction_proxy$$=function($plugin_id$jscomp$30$$,$file_id$jscomp$479$$,$page_id$jscomp$487$$,$shape_id$jscomp$182$$,$index$jscomp$607$$){var $obj_86296$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_86296$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"InteractionProxy"}});Object.defineProperty($obj_86296$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"InteractionProxy"}});Object.defineProperty($obj_86296$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$30$$}});Object.defineProperty($obj_86296$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$479$$}});Object.defineProperty($obj_86296$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$487$$}});Object.defineProperty($obj_86296$$,"$shape",{enumerable:!1,get:function(){return $shape_id$jscomp$182$$}});
Object.defineProperty($obj_86296$$,"$index",{enumerable:!1,get:function(){return $index$jscomp$607$$}});Object.defineProperty($obj_86296$$,"shape",{enumerable:!1,get:function(){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$30$$,$file_id$jscomp$479$$,$page_id$jscomp$487$$,$shape_id$jscomp$182$$):$app$plugins$shape$shape_proxy$$($plugin_id$jscomp$30$$,$file_id$jscomp$479$$,$page_id$jscomp$487$$,
$shape_id$jscomp$182$$)}});Object.defineProperty($obj_86296$$,"trigger",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_interaction$$(this)))},set:function($val_trigger_86361$$){return function($_$jscomp$3269$$,$value$jscomp$1117$$){var $value__$1$jscomp$112$$=$app$plugins$parser$parse_keyword$$($value$jscomp$1117$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$interactions$event_types$$,
$value__$1$jscomp$112$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$shape_id$jscomp$182$$],null),$index$jscomp$607$$,function($p1__86290_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86290_SHARP_$$,$APP.$cljs$cst$1557$event_type$$,$value__$1$jscomp$112$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$487$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$30$$,$APP.$cljs$cst$4424$trigger$$,$value__$1$jscomp$112$$)}.call(this,this,$val_trigger_86361$$)}});Object.defineProperty($obj_86296$$,"delay",{enumerable:!0,get:function(){return $APP.$cljs$cst$1325$delay$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_interaction$$(this))},set:function($val_delay_86369$$){return function($_$jscomp$3270$$,$value$jscomp$1118$$){return typeof $value$jscomp$1118$$===
"number"&&$value$jscomp$1118$$>0?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$shape_id$jscomp$182$$],null),$index$jscomp$607$$,function($p1__86292_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86292_SHARP_$$,$APP.$cljs$cst$1325$delay$$,$value$jscomp$1118$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$487$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$30$$,$APP.$cljs$cst$1325$delay$$,$value$jscomp$1118$$)}.call(this,this,$val_delay_86369$$)}});Object.defineProperty($obj_86296$$,"action",{enumerable:!0,get:function(){return $app$plugins$format$format_action$$($app$plugins$utils$proxy__GT_interaction$$(this),$plugin_id$jscomp$30$$,$file_id$jscomp$479$$,$page_id$jscomp$487$$)},set:function($val_action_86377$$){return function($interaction$jscomp$57_self$jscomp$172$$,
$value$jscomp$1119$$){var $params$jscomp$471$$=$app$plugins$parser$parse_action$$($value$jscomp$1119$$);$interaction$jscomp$57_self$jscomp$172$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$proxy__GT_interaction$$($interaction$jscomp$57_self$jscomp$172$$),$params$jscomp$471$$);return $APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$interactions$schema_COLON_interaction$$,$interaction$jscomp$57_self$jscomp$172$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$30$$,$APP.$cljs$cst$2683$action$$,$interaction$jscomp$57_self$jscomp$172$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$shape_id$jscomp$182$$],null),$index$jscomp$607$$,function($p1__86294_SHARP_$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($p1__86294_SHARP_$$,
$params$jscomp$471$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$487$$],null)))}.call(this,this,$val_action_86377$$)}});Object.defineProperty($obj_86296$$,"remove",{enumerable:!1,get:function(){return function(){var $JSCompiler_temp_const$jscomp$1266$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1268$$=$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$shape_id$jscomp$182$$],null),$index$jscomp$607$$);return $JSCompiler_temp_const$jscomp$1266$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1268$$)}.bind(this)}});return $obj_86296$$},$app$plugins$shape$blur_defaults$$=function($blur$jscomp$18$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$cst$260$value$$,4,$APP.$cljs$cst$1620$hidden$$,!1],null),$blur$jscomp$18$$)},$app$plugins$shape$shape_proxy_QMARK_$$=function($p$jscomp$278$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$278$$,"ShapeProxy")},$app$plugins$shape$token_proxy_QMARK_$$=function($t$jscomp$105$$){return $app$util$object$type_of_QMARK_$$($t$jscomp$105$$,"TokenProxy")},$app$plugins$user$add_session_properties$$=function($user_proxy$$,$session_id$jscomp$12$$){var $get_fn85307_85608$$=
$APP.$cljs$core$constantly$$($session_id$jscomp$12$$);Object.defineProperty($user_proxy$$,"$session",function(){return{enumerable:!1,get:function(){return $get_fn85307_85608$$.$cljs$core$IFn$_invoke$arity$1$?$get_fn85307_85608$$.$cljs$core$IFn$_invoke$arity$1$(this):$get_fn85307_85608$$(this)}}}());Object.defineProperty($user_proxy$$,"id",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_profile$$($session_id$jscomp$12$$)))}}}());
Object.defineProperty($user_proxy$$,"name",function(){return{enumerable:!0,get:function(){return $APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_profile$$($session_id$jscomp$12$$))}}}());Object.defineProperty($user_proxy$$,"avatarUrl",function(){return{enumerable:!0,get:function(){return $APP.$app$config$resolve_profile_photo_url$$($app$plugins$utils$locate_profile$$($session_id$jscomp$12$$))}}}());Object.defineProperty($user_proxy$$,"color",function(){return{enumerable:!0,
get:function(){return $APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_presence$$($session_id$jscomp$12$$))}}}());Object.defineProperty($user_proxy$$,"sessionId",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($session_id$jscomp$12$$)}}}());return $user_proxy$$},$app$plugins$user$current_user_proxy$$=function($plugin_id$jscomp$34$$){var $session_id$jscomp$13$$=$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return $app$plugins$user$add_session_properties$$(function(){var $obj_85331$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85331$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"CurrentUserProxy"}});Object.defineProperty($obj_85331$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"CurrentUserProxy"}});Object.defineProperty($obj_85331$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$34$$}});return $obj_85331$$}(),$session_id$jscomp$13$$)},
$app$plugins$user$active_user_proxy$$=function($plugin_id$jscomp$35$$,$session_id$jscomp$14$$){return $app$plugins$user$add_session_properties$$(function(){var $obj_85365$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85365$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ActiveUserProxy"}});Object.defineProperty($obj_85365$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ActiveUserProxy"}});Object.defineProperty($obj_85365$$,"$plugin",{enumerable:!1,
get:function(){return $plugin_id$jscomp$35$$}});Object.defineProperty($obj_85365$$,"position",{enumerable:!0,get:function(){return $app$plugins$format$format_point$$($APP.$cljs$cst$2163$point$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_presence$$($session_id$jscomp$14$$)))}});Object.defineProperty($obj_85365$$,"zoom",{enumerable:!0,get:function(){return $APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_presence$$($session_id$jscomp$14$$))}});return $obj_85365$$}(),
$session_id$jscomp$14$$)},$app$plugins$user$add_user_properties$$=function($user_proxy$jscomp$1$$,$data$jscomp$533$$){Object.defineProperty($user_proxy$jscomp$1$$,"id",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$533$$))}}}());Object.defineProperty($user_proxy$jscomp$1$$,"name",function(){return{enumerable:!0,get:function(){return $APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$533$$)}}}());
Object.defineProperty($user_proxy$jscomp$1$$,"avatarUrl",function(){return{enumerable:!0,get:function(){return $APP.$app$config$resolve_profile_photo_url$$($data$jscomp$533$$)}}}());return $user_proxy$jscomp$1$$},$app$plugins$user$user_proxy$$=function($plugin_id$jscomp$36$$,$data$jscomp$534$$){return $app$plugins$user$add_user_properties$$(function(){var $obj_85435$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85435$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"UserProxy"}});
Object.defineProperty($obj_85435$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"UserProxy"}});Object.defineProperty($obj_85435$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$36$$}});return $obj_85435$$}(),$data$jscomp$534$$)},$app$plugins$user$user_proxy_QMARK_$$=function($p$jscomp$281$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$281$$,"UserProxy")||$app$util$object$type_of_QMARK_$$($p$jscomp$281$$,"CurrentUserProxy")||$app$util$object$type_of_QMARK_$$($p$jscomp$281$$,
"ActiveUserProxy")},$app$plugins$comments$comment_proxy$$=function($plugin_id$jscomp$37$$,$file_id$jscomp$481$$,$page_id$jscomp$490$$,$thread_id$jscomp$17$$,$data$jscomp$535$$){var $data_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$535$$),$obj_87777$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_87777$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"CommentProxy"}});Object.defineProperty($obj_87777$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,
get:function(){return"CommentProxy"}});Object.defineProperty($obj_87777$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$37$$}});Object.defineProperty($obj_87777$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$481$$}});Object.defineProperty($obj_87777$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$490$$}});Object.defineProperty($obj_87777$$,"$thread",{enumerable:!1,get:function(){return $thread_id$jscomp$17$$}});Object.defineProperty($obj_87777$$,"$id",
{enumerable:!1,get:function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$)}});Object.defineProperty($obj_87777$$,"user",{enumerable:!0,get:function(){return $app$plugins$user$user_proxy$$($plugin_id$jscomp$37$$,$APP.$app$main$data$comments$get_owner$$($data$jscomp$535$$))}});Object.defineProperty($obj_87777$$,"owner",{enumerable:!0,get:function(){return $app$plugins$user$user_proxy$$($plugin_id$jscomp$37$$,$APP.$app$main$data$comments$get_owner$$($data$jscomp$535$$))}});
Object.defineProperty($obj_87777$$,"date",{enumerable:!0,get:function(){return $APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$)}});Object.defineProperty($obj_87777$$,"content",{enumerable:!0,get:function(){return $APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data_STAR_$$))},set:function($val_content_87856$$){return function($content$jscomp$281$$){var $profile$jscomp$89$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return typeof $content$jscomp$281$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($content$jscomp$281$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$37$$,$APP.$cljs$cst$1637$content$$,"Not valid"):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$89$$),$APP.$cljs$cst$3324$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$37$$,$APP.$cljs$cst$1637$content$$,
"Cannot change content from another user's comments"):$app$plugins$register$check_permission$$($plugin_id$jscomp$37$$,"comment:write")?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$37$$,"update-comment",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3430$thread_id$$,$thread_id$jscomp$17$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$),$APP.$cljs$cst$3437$content_size$$,$APP.$cljs$core$count$$($content$jscomp$281$$)])));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($data_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$281$$)},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$retrieve_comment_threads$$($file_id$jscomp$481$$))},
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3451$update_comment$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$),$APP.$cljs$cst$1637$content$$,$content$jscomp$281$$],null)))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$37$$,$APP.$cljs$cst$1637$content$$,"Plugin doesn't have 'comment:write' permission")}.call(this,$val_content_87856$$)}});Object.defineProperty($obj_87777$$,
"remove",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$44$$,$reject$jscomp$31$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$37$$,"comment:write"))return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$37$$,"update-comment",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3430$thread_id$$,
$thread_id$jscomp$17$$])));return $resolve$jscomp$44$$.$cljs$core$IFn$_invoke$arity$0$?$resolve$jscomp$44$$.$cljs$core$IFn$_invoke$arity$0$():$resolve$jscomp$44$$()},$reject$jscomp$31$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$retrieve_comment_threads$$($file_id$jscomp$481$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3456$delete_comment$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$)],null))));$app$plugins$utils$not_valid$$($plugin_id$jscomp$37$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'comment:write' permission");return $reject$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$("Plugin doesn't have 'comment:write' permission"):$reject$jscomp$31$$("Plugin doesn't have 'comment:write' permission")})}.bind(this)}});
return $obj_87777$$},$app$plugins$comments$comment_thread_proxy$$=function($plugin_id$jscomp$38$$,$file_id$jscomp$482$$,$page_id$jscomp$491$$,$data$jscomp$536$$){var $data_STAR_$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$536$$),$obj_88314$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_88314$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"CommentThreadProxy"}});Object.defineProperty($obj_88314$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,
get:function(){return"CommentThreadProxy"}});Object.defineProperty($obj_88314$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$38$$}});Object.defineProperty($obj_88314$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$482$$}});Object.defineProperty($obj_88314$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$491$$}});Object.defineProperty($obj_88314$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)}});
Object.defineProperty($obj_88314$$,"page",{enumerable:!1,get:function(){return $app$plugins$utils$locate_page$$($file_id$jscomp$482$$,$page_id$jscomp$491$$)}});Object.defineProperty($obj_88314$$,"seqNumber",{enumerable:!0,get:function(){return $APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)}});Object.defineProperty($obj_88314$$,"board",{enumerable:!0,get:function(){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$38$$,$file_id$jscomp$482$$,
$page_id$jscomp$491$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$))}});Object.defineProperty($obj_88314$$,"owner",{enumerable:!0,get:function(){return $app$plugins$user$user_proxy$$($plugin_id$jscomp$38$$,$APP.$app$main$data$comments$get_owner$$($data$jscomp$536$$))}});Object.defineProperty($obj_88314$$,"position",{enumerable:!0,get:function(){return $app$plugins$format$format_point$$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$)))},
set:function($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$){$JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$=$app$plugins$parser$parse_point$$($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$);$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$)))||
$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$)))?$JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$APP.$cljs$cst$1676$position$$,"Not valid point"):$app$plugins$register$check_permission$$($plugin_id$jscomp$38$$,"comment:write")?
($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$)],
null))),$JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$=$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($data_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1676$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$))):$JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,
$APP.$cljs$cst$1676$position$$,"Plugin doesn't have 'comment:write' permission");return $JSCompiler_inline_result$jscomp$2238_position__$1$jscomp$inline_10493_val_position_88393$$}});Object.defineProperty($obj_88314$$,"resolved",{enumerable:!0,get:function(){return $APP.$cljs$cst$3445$is_resolved$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$))},set:function($JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$){$APP.$cljs$core$boolean_QMARK_$$($JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$38$$,"comment:write")?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$comments$update_comment_thread$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$),$APP.$cljs$cst$3445$is_resolved$$,$JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$)),$plugin_id$jscomp$38$$)),$JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$=
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($data_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3445$is_resolved$$,$JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$)):$JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$APP.$cljs$cst$5113$resolved$$,"Plugin doesn't have 'comment:write' permission"):$JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,
$APP.$cljs$cst$5113$resolved$$,"Not a boolean type");return $JSCompiler_inline_result$jscomp$2239_val_resolved_88401$$}});Object.defineProperty($obj_88314$$,"findComments",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$45$$,$reject$jscomp$32$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$38$$,"comment:read"))return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__88897_comments$jscomp$4$$){$G__88897_comments$jscomp$4$$=
$app$plugins$format$format_array$$(function($p1__88284_SHARP_$$){return $app$plugins$comments$comment_proxy$$($plugin_id$jscomp$38$$,$file_id$jscomp$482$$,$page_id$jscomp$491$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),$p1__88284_SHARP_$$)},$G__88897_comments$jscomp$4$$);return $resolve$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$($G__88897_comments$jscomp$4$$):$resolve$jscomp$45$$($G__88897_comments$jscomp$4$$)},
$reject$jscomp$32$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3462$get_comments$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3430$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)],null)));$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$cljs$cst$6559$findComments$$,"Plugin doesn't have 'comment:read' permission");return $reject$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$("Plugin doesn't have 'comment:read' permission"):
$reject$jscomp$32$$("Plugin doesn't have 'comment:read' permission")})}.bind(this)}});Object.defineProperty($obj_88314$$,"reply",{enumerable:!1,get:function(){return function($content$jscomp$282$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$38$$,"comment:write")?typeof $content$jscomp$282$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($content$jscomp$282$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$cljs$cst$6560$reply$$,"Not valid"):new Promise(function($resolve$jscomp$46$$,
$reject$jscomp$33$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__88898_result$jscomp$389$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$38$$,"create-comment",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3430$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),$APP.$cljs$cst$1644$file_id$$,
$file_id$jscomp$482$$,$APP.$cljs$cst$3437$content_size$$,$APP.$cljs$core$count$$($content$jscomp$282$$)])));$G__88898_result$jscomp$389$$=$app$plugins$comments$comment_proxy$$($plugin_id$jscomp$38$$,$file_id$jscomp$482$$,$page_id$jscomp$491$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),$G__88898_result$jscomp$389$$);return $resolve$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$($G__88898_result$jscomp$389$$):$resolve$jscomp$46$$($G__88898_result$jscomp$389$$)},
$reject$jscomp$33$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3449$create_comment$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3430$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),$APP.$cljs$cst$1637$content$$,$content$jscomp$282$$],null)))}):$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$cljs$cst$6560$reply$$,"Plugin doesn't have 'comment:write' permission")}.bind(this)}});Object.defineProperty($obj_88314$$,
"remove",{enumerable:!1,get:function(){return function(){var $profile$jscomp$90$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$owner$jscomp$7$$=$app$main$data$helpers$lookup_profile$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$3324$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$));return $app$plugins$register$check_permission$$($plugin_id$jscomp$38$$,
"comment:write")?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$90$$),$owner$jscomp$7$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$APP.$cljs$cst$2590$remove$$,"Cannot change content from another user's comments"):new Promise(function($resolve$jscomp$47$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$comments$delete_comment_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)],null),function(){return $resolve$jscomp$47$$.$cljs$core$IFn$_invoke$arity$0$?$resolve$jscomp$47$$.$cljs$core$IFn$_invoke$arity$0$():$resolve$jscomp$47$$()}),$plugin_id$jscomp$38$$))}):$app$plugins$utils$not_valid$$($plugin_id$jscomp$38$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'comment:write' permission")}.bind(this)}});return $obj_88314$$},$app$plugins$page$flow_proxy$$=function($plugin_id$jscomp$39$$,
$file_id$jscomp$483$$,$page_id$jscomp$492$$,$id$jscomp$1118$$){var $obj_89070$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89070$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FlowProxy"}});Object.defineProperty($obj_89070$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FlowProxy"}});Object.defineProperty($obj_89070$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$39$$}});Object.defineProperty($obj_89070$$,"$file",{enumerable:!1,
get:function(){return $file_id$jscomp$483$$}});Object.defineProperty($obj_89070$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$492$$}});Object.defineProperty($obj_89070$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1118$$}});Object.defineProperty($obj_89070$$,"page",{enumerable:!1,get:function(){return $app$plugins$page$page_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$page$page_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$39$$,$file_id$jscomp$483$$,
$page_id$jscomp$492$$):$app$plugins$page$page_proxy$$($plugin_id$jscomp$39$$,$file_id$jscomp$483$$,$page_id$jscomp$492$$)}});Object.defineProperty($obj_89070$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_flow$$(this))},set:function($val_name_89138$$){return function($_$jscomp$3286$$,$value$jscomp$1162$$){return typeof $value$jscomp$1162$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($value$jscomp$1162$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$39$$,
$APP.$cljs$cst$725$name$$,$value$jscomp$1162$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_flow$$($page_id$jscomp$492$$,$id$jscomp$1118$$,function($p1__89057_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__89057_SHARP_$$,$APP.$cljs$cst$725$name$$,$value$jscomp$1162$$)}))}.call(this,this,$val_name_89138$$)}});Object.defineProperty($obj_89070$$,"startingBoard",{enumerable:!0,get:function(){var $temp__5825__auto__$jscomp$inline_10498$$=
$APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_flow$$(this));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_10498$$)?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$3$($file_id$jscomp$483$$,$page_id$jscomp$492$$,$temp__5825__auto__$jscomp$inline_10498$$):null},set:function($val_startingboard_89146$$){return function($_$jscomp$3287$$,$value$jscomp$1163$$){return $app$plugins$shape$shape_proxy_QMARK_$$($value$jscomp$1163$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_flow$$($page_id$jscomp$492$$,$id$jscomp$1118$$,function($p1__89060_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__89060_SHARP_$$,$APP.$cljs$cst$2053$starting_frame$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$1163$$,"$id"))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$39$$,$cljs$cst$6561$startingBoard$$,$value$jscomp$1163$$)}.call(this,
this,$val_startingboard_89146$$)}});Object.defineProperty($obj_89070$$,"remove",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$($page_id$jscomp$492$$,$id$jscomp$1118$$))}.bind(this)}});return $obj_89070$$},$app$plugins$page$page_proxy$$=function($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$){var $obj_89417$$=new $APP.$app$util$object$Proxy$$;
Object.defineProperty($obj_89417$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PageProxy"}});Object.defineProperty($obj_89417$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PageProxy"}});Object.defineProperty($obj_89417$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$40$$}});Object.defineProperty($obj_89417$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$484$$}});Object.defineProperty($obj_89417$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1119$$}});
Object.defineProperty($obj_89417$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1119$$??"")}});Object.defineProperty($obj_89417$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$(this))},set:function($val_name_89468$$){return typeof $val_name_89468$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$725$name$$,$val_name_89468$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$rename_page$$($id$jscomp$1119$$,$val_name_89468$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_89417$$,"getRoot",{enumerable:!1,get:function(){return function(){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,
$id$jscomp$1119$$,$APP.$app$common$uuid$zero$$)}.bind(this)}});Object.defineProperty($obj_89417$$,"root",{enumerable:!1,get:function(){return this.getRoot()}});Object.defineProperty($obj_89417$$,"background",{enumerable:!0,get:function(){var $or__5025__auto__$jscomp$inline_10504$$=$APP.$cljs$cst$2058$background$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$(this));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_10504$$)?$or__5025__auto__$jscomp$inline_10504$$:
"#E8E9EA"},set:function($val_background_89490$$){return typeof $val_background_89490$$==="string"&&$APP.$app$common$types$color$valid_hex_color_QMARK_$$($val_background_89490$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$change_canvas_color$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1119$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1298$color$$,
$val_background_89490$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2058$background$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2058$background$$,$val_background_89490$$)}});Object.defineProperty($obj_89417$$,"flows",{enumerable:!0,get:function(){return function($flows$jscomp$13_self$jscomp$222$$){$flows$jscomp$13_self$jscomp$222$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$($flows$jscomp$13_self$jscomp$222$$)),
$APP.$cljs$core$PersistentVector$EMPTY$$);return $app$plugins$format$format_array$$(function($p1__89410_SHARP_$$){return $app$plugins$page$flow_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__89410_SHARP_$$))},$APP.$cljs$core$vals$$($flows$jscomp$13_self$jscomp$222$$))}.call(this,this)}});Object.defineProperty($obj_89417$$,"rulerGuides",{enumerable:!0,get:function(){return function($guides$jscomp$15_self$jscomp$223$$){$guides$jscomp$15_self$jscomp$223$$=
$APP.$cljs$cst$2057$guides$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$($guides$jscomp$15_self$jscomp$223$$));return $app$plugins$format$format_array$$(function($p1__89412_SHARP_$$){return $app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__89412_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__89411_SHARP_$$){return $APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__89411_SHARP_$$)==
null},$APP.$cljs$core$vals$$($guides$jscomp$15_self$jscomp$223$$)))}.call(this,this)}});Object.defineProperty($obj_89417$$,"getShapeById",{enumerable:!1,get:function(){return function($shape_id$jscomp$183_shape_id__$1$jscomp$8$$){if(typeof $shape_id$jscomp$183_shape_id__$1$jscomp$8$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6562$getShapeById$$,$shape_id$jscomp$183_shape_id__$1$jscomp$8$$);$shape_id$jscomp$183_shape_id__$1$jscomp$8$$=$APP.$app$common$uuid$parse$$($shape_id$jscomp$183_shape_id__$1$jscomp$8$$);
return $app$plugins$utils$locate_shape$$($file_id$jscomp$484$$,$id$jscomp$1119$$,$shape_id$jscomp$183_shape_id__$1$jscomp$8$$)!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,$shape_id$jscomp$183_shape_id__$1$jscomp$8$$):null}.bind(this)}});Object.defineProperty($obj_89417$$,"findShapes",{enumerable:!1,get:function(){return function($criteria$jscomp$1_page$jscomp$191$$){var $criteria__$1$$=$criteria$jscomp$1_page$jscomp$191$$!=
null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($criteria$jscomp$1_page$jscomp$191$$,"name"),$cljs$cst$6398$name_like$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($criteria$jscomp$1_page$jscomp$191$$,"nameLike"),$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_shape_type$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($criteria$jscomp$1_page$jscomp$191$$,
"type"))],null)):null,$match_criteria_QMARK__xf$jscomp$5$$=$criteria__$1$$!=null?function($p__89619_shape$jscomp$1173$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__89619_shape$jscomp$1173$$,0,null);$p__89619_shape$jscomp$1173$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__89619_shape$jscomp$1173$$,1,null);var $and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$=$APP.$cljs$core$not$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$)),$APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__89619_shape$jscomp$1173$$)));return $and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$?($and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$=($and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$=
$APP.$cljs$core$not$$($cljs$cst$6398$name_like$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$)))?$and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$:$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__89619_shape$jscomp$1173$$)),$APP.$cuerdas$core$lower$$($cljs$cst$6398$name_like$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$))),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$)?
$APP.$cljs$core$not$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p__89619_shape$jscomp$1173$$)):$and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$):$and__5023__auto__$jscomp$1039_and__5023__auto____$1$jscomp$172_or__5025__auto__$jscomp$inline_10509$$}:
$APP.$cljs$core$identity$$;return $file_id$jscomp$484$$!=null&&$id$jscomp$1119$$!=null?($criteria$jscomp$1_page$jscomp$191$$=$app$plugins$utils$locate_page$$($file_id$jscomp$484$$,$id$jscomp$1119$$),$match_criteria_QMARK__xf$jscomp$5$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($match_criteria_QMARK__xf$jscomp$5$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__89413_SHARP_$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,
$file_id$jscomp$484$$,$id$jscomp$1119$$,$APP.$cljs$core$first$$($p1__89413_SHARP_$$))})),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($match_criteria_QMARK__xf$jscomp$5$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($criteria$jscomp$1_page$jscomp$191$$)))):null}.bind(this)}});Object.defineProperty($obj_89417$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$440$$){if(typeof $key$jscomp$440$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6563$page_plugin_data_key$$,$key$jscomp$440$$);var $page$jscomp$192$$=$app$plugins$utils$locate_page$$($file_id$jscomp$484$$,$id$jscomp$1119$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$192$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$40$$))),$key$jscomp$440$$)}.bind(this)}});Object.defineProperty($obj_89417$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$441$$,$value$jscomp$1166$$){return typeof $key$jscomp$441$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6524$setPluginData_key$$,$key$jscomp$441$$):$value$jscomp$1166$$!=null&&typeof $value$jscomp$1166$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6525$setPluginData_value$$,$value$jscomp$1166$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$484$$,$APP.$cljs$cst$1624$page$$,$id$jscomp$1119$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$40$$)),$key$jscomp$441$$,
$value$jscomp$1166$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6526$setPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_89417$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $page$jscomp$193$$=$app$plugins$utils$locate_page$$($file_id$jscomp$484$$,$id$jscomp$1119$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$193$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$40$$)))))}.bind(this)}});Object.defineProperty($obj_89417$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$21$$,$key$jscomp$442$$){if(typeof $namespace$jscomp$21$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6564$page_plugin_data_namespace$$,$namespace$jscomp$21$$);
if(typeof $key$jscomp$442$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6563$page_plugin_data_key$$,$key$jscomp$442$$);var $page$jscomp$194$$=$app$plugins$utils$locate_page$$($file_id$jscomp$484$$,$id$jscomp$1119$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$194$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",
$namespace$jscomp$21$$)),$key$jscomp$442$$)}.bind(this)}});Object.defineProperty($obj_89417$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$22$$,$key$jscomp$443$$,$value$jscomp$1167$$){return typeof $namespace$jscomp$22$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6529$setSharedPluginData_namespace$$,$namespace$jscomp$22$$):typeof $key$jscomp$443$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6530$setSharedPluginData_key$$,
$key$jscomp$443$$):$value$jscomp$1167$$!=null&&typeof $value$jscomp$1167$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1167$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$484$$,$APP.$cljs$cst$1624$page$$,$id$jscomp$1119$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",
$namespace$jscomp$22$$),$key$jscomp$443$$,$value$jscomp$1167$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6532$setSharedPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_89417$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($page$jscomp$195_self$jscomp$224$$,$namespace$jscomp$23$$){if(typeof $namespace$jscomp$23$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6564$page_plugin_data_namespace$$,
$namespace$jscomp$23$$);$page$jscomp$195_self$jscomp$224$$=$app$plugins$utils$proxy__GT_page$$($page$jscomp$195_self$jscomp$224$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$195_self$jscomp$224$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$23$$))))}.bind(this)}});
Object.defineProperty($obj_89417$$,"openPage",{enumerable:!1,get:function(){return function($new_window$jscomp$3$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:read")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$id$jscomp$1119$$,$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,
$APP.$cljs$core$boolean_QMARK_$$($new_window$jscomp$3$$)?$new_window$jscomp$3$$:!1]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6565$openPage$$,"Plugin doesn't have 'content:read' permission")}.bind(this)}});Object.defineProperty($obj_89417$$,"createFlow",{enumerable:!1,get:function(){return function($name$jscomp$516$$,$frame$jscomp$121$$){if(typeof $name$jscomp$516$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($name$jscomp$516$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6566$createFlow_name$$,$name$jscomp$516$$);if($app$plugins$shape$shape_proxy_QMARK_$$($frame$jscomp$121$$)){var $flow_id$jscomp$13$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$04$$($flow_id$jscomp$13$$,$id$jscomp$1119$$,$name$jscomp$516$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$121$$,"$id")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$40$$,
"add-flow")]));return $app$plugins$page$flow_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,$flow_id$jscomp$13$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6567$createFlow_frame$$,$frame$jscomp$121$$)}.bind(this)}});Object.defineProperty($obj_89417$$,"removeFlow",{enumerable:!1,get:function(){return function($flow$jscomp$13$$){return $app$util$object$type_of_QMARK_$$($flow$jscomp$13$$,"FlowProxy")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1119$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($flow$jscomp$13$$,"$id")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$40$$,"remove-flow")])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6568$removeFlow_flow$$,$flow$jscomp$13$$)}.bind(this)}});Object.defineProperty($obj_89417$$,"addRulerGuide",{enumerable:!1,get:function(){return function($orientation$jscomp$10$$,$value$jscomp$1168$$,$board$$){var $ruler_id$jscomp$3_shape$jscomp$1174$$=
$app$plugins$utils$proxy__GT_shape$$($board$$);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1168$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6551$addRulerGuide$$,"Value not a safe number"):$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["vertical",null,"horizontal",null],null),null),$orientation$jscomp$10$$)?$ruler_id$jscomp$3_shape$jscomp$1174$$==
null||$app$plugins$shape$shape_proxy_QMARK_$$($board$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ruler_id$jscomp$3_shape$jscomp$1174$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?($ruler_id$jscomp$3_shape$jscomp$1174$$=$APP.$app$common$uuid$next$$(),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$266$id$$,$ruler_id$jscomp$3_shape$jscomp$1174$$,$APP.$cljs$cst$2054$axis$$,$app$plugins$parser$orientation__GT_axis$$($orientation$jscomp$10$$),$APP.$cljs$cst$1676$position$$,$value$jscomp$1168$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$core$truth_$$($board$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($board$$,"$id"):null],null))),$plugin_id$jscomp$40$$)),$app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,
$ruler_id$jscomp$3_shape$jscomp$1174$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6551$addRulerGuide$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6551$addRulerGuide$$,"The shape is not a board"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6551$addRulerGuide$$,"Orientation should be either 'vertical' or 'horizontal'")}.bind(this)}});Object.defineProperty($obj_89417$$,"removeRulerGuide",
{enumerable:!1,get:function(){return function($guide$jscomp$32_value$jscomp$1169$$){return $app$util$object$type_of_QMARK_$$($guide$jscomp$32_value$jscomp$1169$$,"RulerGuideProxy")?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?($guide$jscomp$32_value$jscomp$1169$$=$app$plugins$utils$proxy__GT_ruler_guide$$($guide$jscomp$32_value$jscomp$1169$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$32_value$jscomp$1169$$),
$plugin_id$jscomp$40$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6552$removeRulerGuide$$,"Plugin doesn't have 'comment:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6552$removeRulerGuide$$,"Guide not provided")}.bind(this)}});Object.defineProperty($obj_89417$$,"addCommentThread",{enumerable:!1,get:function(){return function($content$jscomp$283$$,$position$jscomp$250_position__$1$jscomp$12$$,$board$jscomp$1$$){var $shape$jscomp$1175$$=
$APP.$cljs$core$truth_$$($board$jscomp$1$$)?$app$plugins$utils$proxy__GT_shape$$($board$jscomp$1$$):null;$position$jscomp$250_position__$1$jscomp$12$$=$app$plugins$parser$parse_point$$($position$jscomp$250_position__$1$jscomp$12$$);if(typeof $content$jscomp$283$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($content$jscomp$283$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6569$addCommentThread$$,"Content not valid");if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$250_position__$1$jscomp$12$$)))||
$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$250_position__$1$jscomp$12$$))))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6569$addCommentThread$$,"Position not valid");if($board$jscomp$1$$==null||$app$plugins$shape$shape_proxy_QMARK_$$($board$jscomp$1$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1175$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"comment:write")){var $position__$2$$=$board$jscomp$1$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($position$jscomp$250_position__$1$jscomp$12$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($board$jscomp$1$$)),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($board$jscomp$1$$)):$position$jscomp$250_position__$1$jscomp$12$$;
return new Promise(function($resolve$jscomp$48$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$comments$create_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$484$$,$APP.$cljs$cst$2043$page_id$$,$id$jscomp$1119$$,$APP.$cljs$cst$1676$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($position__$2$$),
$APP.$cljs$cst$1637$content$$,$content$jscomp$283$$],null),function($G__89785_data$jscomp$537$$){$G__89785_data$jscomp$537$$=$app$plugins$comments$comment_thread_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,$G__89785_data$jscomp$537$$);return $resolve$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($G__89785_data$jscomp$537$$):$resolve$jscomp$48$$($G__89785_data$jscomp$537$$)},!1),$plugin_id$jscomp$40$$))})}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6569$addCommentThread$$,"Plugin doesn't have 'comment:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6569$addCommentThread$$,"Board not valid")}.bind(this)}});Object.defineProperty($obj_89417$$,"removeCommentThread",{enumerable:!1,get:function(){return function($thread$jscomp$48$$){return $app$util$object$type_of_QMARK_$$($thread$jscomp$48$$,"CommentThreadProxy")?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"comment:write")?
new Promise(function($resolve$jscomp$49$$){return new Promise($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$delete_comment_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($thread$jscomp$48$$,"$id")],null),function(){return $resolve$jscomp$49$$.$cljs$core$IFn$_invoke$arity$0$?$resolve$jscomp$49$$.$cljs$core$IFn$_invoke$arity$0$():
$resolve$jscomp$49$$()})))}):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6570$removeCommentThread$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6570$removeCommentThread$$,"Comment thread not valid")}.bind(this)}});Object.defineProperty($obj_89417$$,"findCommentThreads",{enumerable:!1,get:function(){return function($criteria$jscomp$2$$){var $only_yours$$=$APP.$cljs$core$boolean$0$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($criteria$jscomp$2$$,
"onlyYours",!1)),$show_resolved$$=$APP.$cljs$core$boolean$0$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($criteria$jscomp$2$$,"showResolved",!0)),$user_id$jscomp$1$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return new Promise(function($resolve$jscomp$50$$,$reject$jscomp$34$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"comment:read"))return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($threads$jscomp$13$$){var $G__89787_threads__$1$jscomp$1$$=
function(){var $G__89786__$1$$=$show_resolved$$?$threads$jscomp$13$$:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$APP.$cljs$cst$3445$is_resolved$$),$threads$jscomp$13$$);return $only_yours$$?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__89414_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3427$participants$$.$cljs$core$IFn$_invoke$arity$1$($p1__89414_SHARP_$$),$user_id$jscomp$1$$)},
$G__89786__$1$$):$G__89786__$1$$}();$G__89787_threads__$1$jscomp$1$$=$app$plugins$format$format_array$$(function($p1__89415_SHARP_$$){return $app$plugins$comments$comment_thread_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$484$$,$id$jscomp$1119$$,$p1__89415_SHARP_$$)},$G__89787_threads__$1$jscomp$1$$);return $resolve$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$($G__89787_threads__$1$jscomp$1$$):$resolve$jscomp$50$$($G__89787_threads__$1$jscomp$1$$)},
$reject$jscomp$34$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3460$get_comment_threads$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$484$$],null)));$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6571$findCommentThreads$$,"Plugin doesn't have 'comment:read' permission");return $reject$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$("Plugin doesn't have 'comment:read' permission"):
$reject$jscomp$34$$("Plugin doesn't have 'comment:read' permission")})}.bind(this)}});return $obj_89417$$},$app$plugins$file$file_proxy$$=function($plugin_id$jscomp$42$$,$id$jscomp$1120$$){var $obj_90315$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_90315$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FileProxy"}});Object.defineProperty($obj_90315$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FileProxy"}});Object.defineProperty($obj_90315$$,
"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$42$$}});Object.defineProperty($obj_90315$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1120$$}});Object.defineProperty($obj_90315$$,"id",{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($id$jscomp$1120$$)}});Object.defineProperty($obj_90315$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_file$$($id$jscomp$1120$$))}});Object.defineProperty($obj_90315$$,
"pages",{enumerable:!0,get:function(){return this.getPages()}});Object.defineProperty($obj_90315$$,"getPages",{enumerable:!1,get:function(){return function(){var $file$jscomp$211$$=$app$plugins$utils$locate_file$$($id$jscomp$1120$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__90280_SHARP_$$){return $app$plugins$page$page_proxy$$($plugin_id$jscomp$42$$,
$id$jscomp$1120$$,$p1__90280_SHARP_$$)}),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$211$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2228$pages$$)))}.bind(this)}});Object.defineProperty($obj_90315$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$444$$){if(typeof $key$jscomp$444$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6575$getPluginData_key$$,$key$jscomp$444$$);
var $file$jscomp$212$$=$app$plugins$utils$locate_file$$($id$jscomp$1120$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$212$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$42$$))),
$key$jscomp$444$$)}.bind(this)}});Object.defineProperty($obj_90315$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$445$$,$value$jscomp$1171$$){return typeof $key$jscomp$445$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($key$jscomp$445$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6524$setPluginData_key$$,$key$jscomp$445$$):typeof $value$jscomp$1171$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6525$setPluginData_value$$,
$value$jscomp$1171$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$42$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($id$jscomp$1120$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$42$$)),$key$jscomp$445$$,$value$jscomp$1171$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,
$cljs$cst$6526$setPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_90315$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $file$jscomp$213$$=$app$plugins$utils$locate_file$$($id$jscomp$1120$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$213$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",""+($plugin_id$jscomp$42$$??"")))))}.bind(this)}});Object.defineProperty($obj_90315$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$24$$,$key$jscomp$446$$){if(typeof $namespace$jscomp$24$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6527$getSharedPluginData_namespace$$,$namespace$jscomp$24$$);
if(typeof $key$jscomp$446$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6528$getSharedPluginData_key$$,$key$jscomp$446$$);var $file$jscomp$214$$=$app$plugins$utils$locate_file$$($id$jscomp$1120$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$214$$,$APP.$cljs$cst$142$data$$),
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$24$$)),$key$jscomp$446$$)}.bind(this)}});Object.defineProperty($obj_90315$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$25$$,$key$jscomp$447$$,$value$jscomp$1172$$){return typeof $namespace$jscomp$25$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($namespace$jscomp$25$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6529$setSharedPluginData_namespace$$,
$namespace$jscomp$25$$):typeof $key$jscomp$447$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($key$jscomp$447$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6530$setSharedPluginData_key$$,$key$jscomp$447$$):typeof $value$jscomp$1172$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1172$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$42$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($id$jscomp$1120$$,
$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$25$$),$key$jscomp$447$$,$value$jscomp$1172$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6532$setSharedPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_90315$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$26$$){if(typeof $namespace$jscomp$26$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,
$cljs$cst$6533$getSharedPluginDataKeys$$,$namespace$jscomp$26$$);var $file$jscomp$215$$=$app$plugins$utils$locate_file$$($id$jscomp$1120$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$215$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",
$namespace$jscomp$26$$))))}.bind(this)}});Object.defineProperty($obj_90315$$,"createPage",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$42$$,"content:write")){var $page_id$jscomp$493$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$pages$create_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,
$page_id$jscomp$493$$,$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1120$$],null)),$plugin_id$jscomp$42$$));return $app$plugins$page$page_proxy$$($plugin_id$jscomp$42$$,$id$jscomp$1120$$,$page_id$jscomp$493$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$42$$,$cljs$cst$6576$createPage$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_90315$$,"export",{enumerable:!1,get:function(){return function($format$jscomp$45$$,$type$jscomp$746$$){return new Promise(function($resolve$jscomp$54$$,
$reject$jscomp$38$$){var $type__$1$jscomp$26$$=function(){var $or__5025__auto__$jscomp$1455$$=$app$plugins$parser$parse_keyword$$($type$jscomp$746$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1455$$)?$or__5025__auto__$jscomp$1455$$:$APP.$cljs$cst$2124$all$$}();if($format$jscomp$45$$==null||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["penpot",null,"zip",null],null),null),$format$jscomp$45$$)){if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($APP.$app$main$data$exports$files$valid_types$$),
$type__$1$jscomp$26$$)){var $file$jscomp$216$$=$app$plugins$utils$locate_file$$($id$jscomp$1120$$),$features__$1$jscomp$35$$=$APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$team_id$jscomp$176$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));a:switch($format$jscomp$45$$){case "zip":var $format__$1$jscomp$3$$=$APP.$cljs$cst$2482$legacy_zip$$;break a;default:$format__$1$jscomp$3$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$6577$export_file_v3$$)?$APP.$cljs$cst$2483$binfile_v3$$:$APP.$cljs$cst$2481$binfile_v1$$}return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$54$$,$reject$jscomp$38$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$42$$,
"export-binary-files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$954$format$$,$format__$1$jscomp$3$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$26$$])))},$APP.$beicon$v2$core$map$$(function($p1__90297_SHARP_$$){return new Uint8Array($APP.$cljs$cst$1581$body$$.$cljs$core$IFn$_invoke$arity$1$($p1__90297_SHARP_$$))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($msg$jscomp$50$$){console.log($msg$jscomp$50$$);var $G__90605_G__90605__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$50$$);
$G__90605_G__90605__$1$$=$G__90605_G__90605__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__90605_G__90605__$1$$.$fqn$:null;switch($G__90605_G__90605__$1$$){case "error":return $APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("cannot export file",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$6578$export_file$$],null)));case "progress":return $APP.$beicon$v2$core$empty$$();case "finish":return $APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$APP.$cljs$cst$1579$uri$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$50$$),$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$3697$no_cors$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$194$buffer$$],null));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__90605_G__90605__$1$$)].join(""));}},$APP.$app$main$worker$ask_many_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$6579$export_files$$,$APP.$cljs$cst$954$format$$,$format__$1$jscomp$3$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$26$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$176$$,$APP.$cljs$cst$227$features$$,$features__$1$jscomp$35$$,$APP.$cljs$cst$1916$files$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$216$$],null)],null)))))))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$38$$,$APP.$cljs$cst$954$format$$,
"Invalid type: "+($type__$1$jscomp$26$$??""))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$38$$,$APP.$cljs$cst$954$format$$,"Invalid format: "+($format$jscomp$45$$??""))})}.bind(this)}});Object.defineProperty($obj_90315$$,"findVersions",{enumerable:!1,get:function(){return function($criteria$jscomp$3$$){var $user$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($criteria$jscomp$3$$,"createdBy",null);return new Promise(function($resolve$jscomp$55$$,$reject$jscomp$39$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$42$$,
"content:read")?$user$jscomp$9$$==null||$app$plugins$user$user_proxy_QMARK_$$($user$jscomp$9$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__90640_snapshots$jscomp$1$$){var $G__90648_users$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__90640_snapshots$jscomp$1$$,0,null);$p__90640_snapshots$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__90640_snapshots$jscomp$1$$,1,null);var $users__$1$jscomp$1$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$G__90648_users$jscomp$12$$);$G__90648_users$jscomp$12$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90305_SHARP_$$){return $app$plugins$file$file_version_proxy$$($plugin_id$jscomp$42$$,$id$jscomp$1120$$,$users__$1$jscomp$1$$,$p1__90305_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90304_SHARP_$$){return $APP.$cljs$core$not$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($user$jscomp$9$$,
"id"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(""+($APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__90304_SHARP_$$)??""),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($user$jscomp$9$$,"id"))},$p__90640_snapshots$jscomp$1$$))));return $resolve$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$($G__90648_users$jscomp$12$$):$resolve$jscomp$55$$($G__90648_users$jscomp$12$$)},$reject$jscomp$39$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$zip$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6574$get_team_users$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1120$$],null)),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5025$get_file_snapshots$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1120$$],null))))):$app$plugins$utils$reject_not_valid$$($reject$jscomp$39$$,$cljs$cst$6581$findVersions_user$$,"Created by user is not a valid user object"):$app$plugins$utils$reject_not_valid$$($reject$jscomp$39$$,
$cljs$cst$6580$findVersions$$,"Plugin doesn't have 'content:read' permission")})}.bind(this)}});Object.defineProperty($obj_90315$$,"saveVersion",{enumerable:!1,get:function(){return function($label$jscomp$57$$){var $users_promise$$=new Promise(function($resolve$jscomp$56$$,$reject$jscomp$40$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$56$$,$reject$jscomp$40$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6574$get_team_users$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1120$$],null)))}),$create_version_promise$$=new Promise(function($resolve$jscomp$57$$,$reject$jscomp$41$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$42$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$create_version_from_plugins$$($id$jscomp$1120$$,$label$jscomp$57$$,$resolve$jscomp$57$$,$reject$jscomp$41$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$42$$,"create-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1120$$]))])):$app$plugins$utils$reject_not_valid$$($reject$jscomp$41$$,$cljs$cst$6580$findVersions$$,"Plugin doesn't have 'content:write' permission")});return Promise.all([$users_promise$$,$create_version_promise$$]).then(function($data$jscomp$539_p__90704$$){var $users$jscomp$13_users__$1$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$539_p__90704$$,0,null);$data$jscomp$539_p__90704$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$539_p__90704$$,1,null);$users$jscomp$13_users__$1$jscomp$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$users$jscomp$13_users__$1$jscomp$2$$);return $app$plugins$file$file_version_proxy$$($plugin_id$jscomp$42$$,$id$jscomp$1120$$,$users$jscomp$13_users__$1$jscomp$2$$,
$data$jscomp$539_p__90704$$)})}.bind(this)}});return $obj_90315$$},$app$plugins$events$get_theme$$=function($state$jscomp$1237_theme$jscomp$44$$){$state$jscomp$1237_theme$jscomp$44$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1237_theme$jscomp$44$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$3184$theme$$],null));return $APP.$cljs$core$not$$($state$jscomp$1237_theme$jscomp$44$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1237_theme$jscomp$44$$,"system")?$app$util$theme$get_system_theme$$():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1237_theme$jscomp$44$$,"default")?"dark":$state$jscomp$1237_theme$jscomp$44$$},$app$plugins$events$add_listener$$=function($type$jscomp$748$$,$key$jscomp$448_plugin_id$jscomp$46$$,$callback$jscomp$93$$,$props$jscomp$464$$){var $plugin_id__$1$$=$app$plugins$parser$parse_id$$($key$jscomp$448_plugin_id$jscomp$46$$);
$key$jscomp$448_plugin_id$jscomp$46$$=Symbol();var $debounced_callback$$=$APP.$goog$functions$debounce$$(function($value$jscomp$1173$$){try{return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6583$app_DOT_plugins_DOT_events_SLASH_void$$,$value$jscomp$1173$$)?$callback$jscomp$93$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$93$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$93$$():$callback$jscomp$93$$.$cljs$core$IFn$_invoke$arity$1$?$callback$jscomp$93$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1173$$):
$callback$jscomp$93$$($value$jscomp$1173$$)}catch($e90917$$){return console.error($e90917$$)}},10);$APP.$cljs$core$add_watch$$($APP.$app$main$store$state$$,$key$jscomp$448_plugin_id$jscomp$46$$,function($_$jscomp$3300_result$jscomp$390$$,$___$1$jscomp$2116$$,$old_val$jscomp$16$$,$new_val$jscomp$17$$){$_$jscomp$3300_result$jscomp$390$$=$app$plugins$events$handle_state_change$$.$cljs$core$IFn$_invoke$arity$5$($type$jscomp$748$$,$plugin_id__$1$$,$old_val$jscomp$16$$,$new_val$jscomp$17$$,$props$jscomp$464$$);
return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$,$_$jscomp$3300_result$jscomp$390$$)?$debounced_callback$$.$cljs$core$IFn$_invoke$arity$1$?$debounced_callback$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3300_result$jscomp$390$$):$debounced_callback$$($_$jscomp$3300_result$jscomp$390$$):null});return $key$jscomp$448_plugin_id$jscomp$46$$},$app$plugins$fonts$font_variant_proxy$$=function($name$jscomp$517$$,$id$jscomp$1121$$,
$weight$jscomp$15$$,$style$jscomp$87$$){var $obj_87871$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_87871$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FontVariantProxy"}});Object.defineProperty($obj_87871$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FontVariantProxy"}});Object.defineProperty($obj_87871$$,"name",{enumerable:!0,get:function(){return $name$jscomp$517$$}});Object.defineProperty($obj_87871$$,"fontVariantId",{enumerable:!0,get:function(){return $id$jscomp$1121$$}});
Object.defineProperty($obj_87871$$,"fontWeight",{enumerable:!0,get:function(){return $weight$jscomp$15$$}});Object.defineProperty($obj_87871$$,"fontStyle",{enumerable:!0,get:function(){return $style$jscomp$87$$}});return $obj_87871$$},$app$plugins$fonts$font_proxy$$=function($plugin_id$jscomp$47$$,$map__88035__$1_obj_88047_p__88034$$){$map__88035__$1_obj_88047_p__88034$$=$APP.$cljs$core$__destructure_map$$($map__88035__$1_obj_88047_p__88034$$);var $id$jscomp$1122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88035__$1_obj_88047_p__88034$$,
$APP.$cljs$cst$266$id$$),$family$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88035__$1_obj_88047_p__88034$$,$APP.$cljs$cst$2675$family$$),$name$jscomp$518$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88035__$1_obj_88047_p__88034$$,$APP.$cljs$cst$725$name$$),$variants$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88035__$1_obj_88047_p__88034$$,$APP.$cljs$cst$2676$variants$$);if($map__88035__$1_obj_88047_p__88034$$!=null){var $default_variant$$=
$APP.$app$main$fonts$get_default_variant$$($map__88035__$1_obj_88047_p__88034$$);$map__88035__$1_obj_88047_p__88034$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FontProxy"}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FontProxy"}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"name",{enumerable:!0,
get:function(){return $name$jscomp$518$$}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"fontId",{enumerable:!0,get:function(){return $id$jscomp$1122$$}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"fontFamily",{enumerable:!0,get:function(){return $family$jscomp$10$$}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"fontStyle",{enumerable:!0,get:function(){return $APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,
"fontVariantId",{enumerable:!0,get:function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"fontWeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"variants",{enumerable:!0,get:function(){return function(){return $app$plugins$format$format_array$$(function($id__$1$jscomp$59_p__88418$$){var $map__88426__$1_weight$jscomp$16$$=
$APP.$cljs$core$__destructure_map$$($id__$1$jscomp$59_p__88418$$);$id__$1$jscomp$59_p__88418$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88426__$1_weight$jscomp$16$$,$APP.$cljs$cst$266$id$$);var $name__$1$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88426__$1_weight$jscomp$16$$,$APP.$cljs$cst$725$name$$),$style$jscomp$88$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88426__$1_weight$jscomp$16$$,$APP.$cljs$cst$1904$style$$);$map__88426__$1_weight$jscomp$16$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88426__$1_weight$jscomp$16$$,$APP.$cljs$cst$1996$weight$$);return $app$plugins$fonts$font_variant_proxy$$($name__$1$jscomp$27$$,$id__$1$jscomp$59_p__88418$$,$map__88426__$1_weight$jscomp$16$$,$style$jscomp$88$$)},$variants$jscomp$13$$)}.call(this)}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"applyToText",{enumerable:!1,get:function(){return function($id__$1$jscomp$60_text$jscomp$153$$,$values$jscomp$103_variant$jscomp$44$$){return $app$plugins$shape$shape_proxy_QMARK_$$($id__$1$jscomp$60_text$jscomp$153$$)?
$app$plugins$register$check_permission$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$60_text$jscomp$153$$,"$plugin"),"content:write")?($id__$1$jscomp$60_text$jscomp$153$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$60_text$jscomp$153$$,"$id"),$values$jscomp$103_variant$jscomp$44$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,$id__$1$jscomp$60_text$jscomp$153$$,$APP.$cljs$cst$1758$font_family$$,$family$jscomp$10$$,
$APP.$cljs$cst$1762$font_style$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$103_variant$jscomp$44$$,"fontStyle"),$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1759$font_variant_id$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$103_variant$jscomp$44$$,"fontVariantId"),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1761$font_weight$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$103_variant$jscomp$44$$,"fontWeight"),$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$))],null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id__$1$jscomp$60_text$jscomp$153$$,
$values$jscomp$103_variant$jscomp$44$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6584$applyToText$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6584$applyToText$$,$id__$1$jscomp$60_text$jscomp$153$$)}.bind(this)}});Object.defineProperty($map__88035__$1_obj_88047_p__88034$$,"applyToRange",{enumerable:!1,get:function(){return function($end$jscomp$115_range$jscomp$19$$,$values$jscomp$104_variant$jscomp$45$$){if($app$util$object$type_of_QMARK_$$($end$jscomp$115_range$jscomp$19$$,
"TextRange")){if($app$plugins$register$check_permission$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"$plugin"),"content:write")){var $id__$1$jscomp$61$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"$id"),$start$jscomp$259$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"start");$end$jscomp$115_range$jscomp$19$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,
"end");$values$jscomp$104_variant$jscomp$45$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,$id__$1$jscomp$61$$,$APP.$cljs$cst$1758$font_family$$,$family$jscomp$10$$,$APP.$cljs$cst$1762$font_style$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$104_variant$jscomp$45$$,"fontStyle"),$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1759$font_variant_id$$,
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$104_variant$jscomp$45$$,"fontVariantId"),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1761$font_weight$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$104_variant$jscomp$45$$,"fontWeight"),$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$))],
null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id__$1$jscomp$61$$,$start$jscomp$259$$,$end$jscomp$115_range$jscomp$19$$,$values$jscomp$104_variant$jscomp$45$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6585$applyToRange$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6585$applyToRange$$,$end$jscomp$115_range$jscomp$19$$)}.bind(this)}});
return $map__88035__$1_obj_88047_p__88034$$}return null},$app$plugins$fonts$fonts_subcontext$$=function($plugin_id$jscomp$48$$){var $obj_88689$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_88689$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PenpotFontsSubcontext"}});Object.defineProperty($obj_88689$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PenpotFontsSubcontext"}});Object.defineProperty($obj_88689$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$48$$).call(this)}});
Object.defineProperty($obj_88689$$,"all",{enumerable:!0,get:function(){return $app$plugins$format$format_array$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$fonts$font_proxy$$,$plugin_id$jscomp$48$$),$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))}});Object.defineProperty($obj_88689$$,"findById",{enumerable:!1,get:function(){return function($id$jscomp$1123$$){return typeof $id$jscomp$1123$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$48$$,
$cljs$cst$6586$findbyId$$,$id$jscomp$1123$$):$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$48$$,$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__88495_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__88495_SHARP_$$)),$APP.$cuerdas$core$lower$$($id$jscomp$1123$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$))))}.bind(this)}});Object.defineProperty($obj_88689$$,
"findByName",{enumerable:!1,get:function(){return function($name$jscomp$519$$){return typeof $name$jscomp$519$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$48$$,$cljs$cst$6587$findByName$$,$name$jscomp$519$$):$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$48$$,$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__88505_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__88505_SHARP_$$)),
$APP.$cuerdas$core$lower$$($name$jscomp$519$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$))))}.bind(this)}});Object.defineProperty($obj_88689$$,"findAllById",{enumerable:!1,get:function(){return function($id$jscomp$1124$$){return typeof $id$jscomp$1124$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$48$$,$cljs$cst$6588$findAllById$$,$APP.$cljs$core$name$$):$app$plugins$format$format_array$$(function($font$jscomp$72$$){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$72$$)),
$APP.$cuerdas$core$lower$$($id$jscomp$1124$$)))?$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$48$$,$font$jscomp$72$$):null},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))}.bind(this)}});Object.defineProperty($obj_88689$$,"findAllByName",{enumerable:!1,get:function(){return function($name$jscomp$520$$){return typeof $name$jscomp$520$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$48$$,$cljs$cst$6589$findAllByName$$,$name$jscomp$520$$):$app$plugins$format$format_array$$(function($font$jscomp$73$$){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$73$$)),
$APP.$cuerdas$core$lower$$($name$jscomp$520$$)))?$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$48$$,$font$jscomp$73$$):null},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))}.bind(this)}});return $obj_88689$$},$app$plugins$history$history_subcontext$$=function($plugin_id$jscomp$49$$){var $obj_87271$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_87271$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"HistorySubcontext"}});Object.defineProperty($obj_87271$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"HistorySubcontext"}});Object.defineProperty($obj_87271$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$49$$}});Object.defineProperty($obj_87271$$,"undoBlockBegin",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,"content:write")){var $id$jscomp$1125$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($id$jscomp$1125$$));
return $id$jscomp$1125$$}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$APP.$cljs$cst$1799$resize$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_87271$$,"undoBlockFinish",{enumerable:!1,get:function(){return function($block_id$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,"content:write")?$APP.$cljs$core$not$$($block_id$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6590$undoBlockFinish$$,
$block_id$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($block_id$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$APP.$cljs$cst$1799$resize$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});return $obj_87271$$},$app$plugins$library$get_variant_components$$=function($file_id$jscomp$489$$,$variant_id$jscomp$56$$){return $app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_file$$($file_id$jscomp$489$$)),
$variant_id$jscomp$56$$)},$app$plugins$library$variant_proxy$$=function($plugin_id$jscomp$52$$,$file_id$jscomp$490$$,$id$jscomp$1128$$){var $obj_89680$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89680$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"VariantProxy"}});Object.defineProperty($obj_89680$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"VariantProxy"}});Object.defineProperty($obj_89680$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$52$$).call(this)}});
Object.defineProperty($obj_89680$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$490$$).call(this)}});Object.defineProperty($obj_89680$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1128$$).call(this)}});Object.defineProperty($obj_89680$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1128$$??"")}});Object.defineProperty($obj_89680$$,"libraryId",{enumerable:!0,get:function(){return""+($file_id$jscomp$490$$??
"")}});Object.defineProperty($obj_89680$$,"properties",{enumerable:!0,get:function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2001$variant_properties$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$library$get_variant_components$$($file_id$jscomp$490$$,
$id$jscomp$1128$$)])))))}});Object.defineProperty($obj_89680$$,"currentValues",{enumerable:!1,get:function(){return function($property$jscomp$88$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$260$value$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__89783__$1_p__89782_variant_properties$jscomp$6$$){$map__89783__$1_p__89782_variant_properties$jscomp$6$$=
$APP.$cljs$core$__destructure_map$$($map__89783__$1_p__89782_variant_properties$jscomp$6$$);$map__89783__$1_p__89782_variant_properties$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89783__$1_p__89782_variant_properties$jscomp$6$$,$APP.$cljs$cst$2001$variant_properties$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__89677_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__89677_SHARP_$$),
$property$jscomp$88$$)},$map__89783__$1_p__89782_variant_properties$jscomp$6$$)},$app$plugins$library$get_variant_components$$($file_id$jscomp$490$$,$id$jscomp$1128$$)))))}.bind(this)}});Object.defineProperty($obj_89680$$,"variantComponents",{enumerable:!1,get:function(){return function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__89678_SHARP_$$){return $app$plugins$library$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$?
$app$plugins$library$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$52$$,$file_id$jscomp$490$$,$p1__89678_SHARP_$$):$app$plugins$library$lib_component_proxy$$($plugin_id$jscomp$52$$,$file_id$jscomp$490$$,$p1__89678_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$app$plugins$library$get_variant_components$$($file_id$jscomp$490$$,$id$jscomp$1128$$))))}.bind(this)}});Object.defineProperty($obj_89680$$,"addVariant",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$52$$,
"add-new-variant"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1128$$)]))}.bind(this)}});Object.defineProperty($obj_89680$$,"addProperty",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$52$$,"add-new-property"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$1128$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3520$property_value$$,"Value 1"],null)]))]))}.bind(this)}});Object.defineProperty($obj_89680$$,"removeProperty",{enumerable:!1,get:function(){return function($pos$jscomp$165$$){return $APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$165$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$52$$,"remove-property"),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$remove_property$$($id$jscomp$1128$$,$pos$jscomp$165$$)])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$52$$,$APP.$cljs$cst$1406$pos$$,$pos$jscomp$165$$)}.bind(this)}});Object.defineProperty($obj_89680$$,"renameProperty",{enumerable:!1,get:function(){return function($pos$jscomp$166$$,$name$jscomp$521$$){return $APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$166$$)?typeof $name$jscomp$521$$!=="string"?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$52$$,$APP.$cljs$cst$725$name$$,$name$jscomp$521$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_property_name$$($id$jscomp$1128$$,$pos$jscomp$166$$,$name$jscomp$521$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4424$trigger$$,"plugin:rename-property"],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$52$$,$APP.$cljs$cst$1406$pos$$,$pos$jscomp$166$$)}.bind(this)}});
return $obj_89680$$},$app$plugins$library$lib_component_proxy$$=function($plugin_id$jscomp$53$$,$file_id$jscomp$491$$,$id$jscomp$1129$$){var $obj_89897$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89897$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryComponentProxy"}});Object.defineProperty($obj_89897$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryComponentProxy"}});Object.defineProperty($obj_89897$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$53$$).call(this)}});
Object.defineProperty($obj_89897$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1129$$).call(this)}});Object.defineProperty($obj_89897$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$491$$).call(this)}});Object.defineProperty($obj_89897$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1129$$??"")}});Object.defineProperty($obj_89897$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_component$$(this))},
set:function($JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$){if(typeof $JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$!=="string")$JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$53$$,
"library:write")){var $component$jscomp$inline_10583$$=$app$plugins$utils$proxy__GT_library_component$$(this);$JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$=""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_10583$$),"")??"")+" / "+($JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$??"");$JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($id$jscomp$1129$$,$JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$))}else $JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2260_val_name_89948_value__$1$jscomp$inline_10584$$}});
Object.defineProperty($obj_89897$$,"path",{enumerable:!0,get:function(){return $APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_component$$(this))},set:function($JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$){if(typeof $JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$!=="string")$JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,
$APP.$cljs$cst$296$path$$,$JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$53$$,"library:write")){var $component$jscomp$inline_10588$$=$app$plugins$utils$proxy__GT_library_component$$(this);$JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$=""+($JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$??"")+" / "+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_10588$$)??
"");$JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$rename_component$$($id$jscomp$1129$$,$JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$))}else $JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$APP.$cljs$cst$296$path$$,"Plugin doesn't have 'library:write' permission");
return $JSCompiler_inline_result$jscomp$2261_val_path_89956_value__$1$jscomp$inline_10589$$}});Object.defineProperty($obj_89897$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$53$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$delete_component$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1129$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,
$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89897$$,"instance",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$53$$,"content:write")){var $id_ref$jscomp$6$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$instantiate_component$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$491$$,
$id$jscomp$1129$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3931$id_ref$$,$id_ref$jscomp$6$$,$APP.$cljs$cst$1786$origin$$,"plugin"],null)),$plugin_id$jscomp$53$$));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$53$$,$APP.$cljs$core$_deref$$($id_ref$jscomp$6$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$APP.$cljs$cst$3118$instance$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});
Object.defineProperty($obj_89897$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$458$$){if(typeof $key$jscomp$458$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6596$component_plugin_data_key$$,$key$jscomp$458$$);var $component$jscomp$147$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$147$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$53$$))),$key$jscomp$458$$)}.bind(this)}});Object.defineProperty($obj_89897$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$459$$,$value$jscomp$1197$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$491$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6591$setPluginData_non_local_library$$,$file_id$jscomp$491$$):typeof $key$jscomp$459$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6524$setPluginData_key$$,$key$jscomp$459$$):$value$jscomp$1197$$!=null&&typeof $value$jscomp$1197$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6525$setPluginData_value$$,$value$jscomp$1197$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$53$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$491$$,$APP.$cljs$cst$1625$component$$,$id$jscomp$1129$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$53$$)),$key$jscomp$459$$,$value$jscomp$1197$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6526$setPluginData$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89897$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $component$jscomp$148$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$148$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$53$$)))))}.bind(this)}});Object.defineProperty($obj_89897$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$33$$,$key$jscomp$460$$){if(typeof $namespace$jscomp$33$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6597$component_plugin_data_namespace$$,$namespace$jscomp$33$$);
if(typeof $key$jscomp$460$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6596$component_plugin_data_key$$,$key$jscomp$460$$);var $component$jscomp$149$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$149$$,$APP.$cljs$cst$1738$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$33$$)),$key$jscomp$460$$)}.bind(this)}});Object.defineProperty($obj_89897$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$34$$,$key$jscomp$461$$,$value$jscomp$1198$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$491$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6592$setSharedPluginData_non_local_library$$,$file_id$jscomp$491$$):typeof $namespace$jscomp$34$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6529$setSharedPluginData_namespace$$,$namespace$jscomp$34$$):typeof $key$jscomp$461$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6530$setSharedPluginData_key$$,$key$jscomp$461$$):$value$jscomp$1198$$!=null&&typeof $value$jscomp$1198$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1198$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$53$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$491$$,$APP.$cljs$cst$1625$component$$,$id$jscomp$1129$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$34$$),
$key$jscomp$461$$,$value$jscomp$1198$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6532$setSharedPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89897$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$35$$){if(typeof $namespace$jscomp$35$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$cljs$cst$6597$component_plugin_data_namespace$$,$namespace$jscomp$35$$);
var $component$jscomp$150$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$150$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$35$$))))}.bind(this)}});
Object.defineProperty($obj_89897$$,"mainInstance",{enumerable:!1,get:function(){return function(){var $file$jscomp$217_root$jscomp$71$$=$app$plugins$utils$locate_file$$($file_id$jscomp$491$$),$component$jscomp$151$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);$file$jscomp$217_root$jscomp$71$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$217_root$jscomp$71$$),$component$jscomp$151$$);
return $file$jscomp$217_root$jscomp$71$$!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$53$$,$file_id$jscomp$491$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$151$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$217_root$jscomp$71$$)):null}.bind(this)}});Object.defineProperty($obj_89897$$,"isVariant",{enumerable:!1,get:function(){return function(){var $component$jscomp$152$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,
$id$jscomp$1129$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$152$$)}.bind(this)}});Object.defineProperty($obj_89897$$,"variants",{enumerable:!1,get:function(){var $component$jscomp$inline_10591$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$inline_10591$$)?$app$plugins$library$variant_proxy$$($plugin_id$jscomp$53$$,$file_id$jscomp$491$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_10591$$)):
null}});Object.defineProperty($obj_89897$$,"variantProps",{enumerable:!0,get:function(){return function(){var $component$jscomp$154$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$154$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$172$$,$name$jscomp$522_p__90251$$){var $map__90252__$1_value$jscomp$1199$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$522_p__90251$$);
$name$jscomp$522_p__90251$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__90252__$1_value$jscomp$1199$$,$APP.$cljs$cst$725$name$$);$map__90252__$1_value$jscomp$1199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__90252__$1_value$jscomp$1199$$,$APP.$cljs$cst$260$value$$);return $APP.$app$util$object$set_BANG_$$($acc$jscomp$172$$,$name$jscomp$522_p__90251$$,$map__90252__$1_value$jscomp$1199$$)},{},$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$154$$)):
null}.call(this)}});Object.defineProperty($obj_89897$$,"variantError",{enumerable:!0,get:function(){var $file$jscomp$inline_10593_root$jscomp$inline_10595$$=$app$plugins$utils$locate_file$$($file_id$jscomp$491$$),$component$jscomp$inline_10594$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);$file$jscomp$inline_10593_root$jscomp$inline_10595$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$inline_10593_root$jscomp$inline_10595$$),
$component$jscomp$inline_10594$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$inline_10594$$)?$APP.$cljs$cst$2003$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$inline_10593_root$jscomp$inline_10595$$):null}});Object.defineProperty($obj_89897$$,"transformInVariant",{enumerable:!1,get:function(){return function(){var $component$jscomp$156$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$156$$)?
!$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$156$$):$component$jscomp$156$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$53$$,"transform-in-variant"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$156$$))])):
null}.bind(this)}});Object.defineProperty($obj_89897$$,"addVariant",{enumerable:!1,get:function(){return function(){var $component$jscomp$157$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$491$$,$id$jscomp$1129$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$157$$)?$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$157$$):$component$jscomp$157$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$53$$,
"add-new-variant"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$157$$))])):null}.bind(this)}});Object.defineProperty($obj_89897$$,"setVariantProperty",{enumerable:!1,get:function(){return function($pos$jscomp$167$$,$value$jscomp$1200$$){return $APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$167$$)?typeof $value$jscomp$1200$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,$APP.$cljs$cst$725$name$$,$value$jscomp$1200$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$53$$,"variant-edit-property-value"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$update_property_value$$($id$jscomp$1129$$,$pos$jscomp$167$$,$value$jscomp$1200$$)])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$53$$,
$APP.$cljs$cst$1406$pos$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$167$$))}.bind(this)}});return $obj_89897$$},$app$plugins$library$library_proxy$$=function($plugin_id$jscomp$54$$,$file_id$jscomp$492$$){var $obj_90467$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_90467$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryProxy"}});Object.defineProperty($obj_90467$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryProxy"}});
Object.defineProperty($obj_90467$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$54$$).call(this)}});Object.defineProperty($obj_90467$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$492$$).call(this)}});Object.defineProperty($obj_90467$$,"id",{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_file$$(this)))}});
Object.defineProperty($obj_90467$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_file$$(this))}});Object.defineProperty($obj_90467$$,"colors",{enumerable:!0,get:function(){return function(){var $colors$jscomp$28_file$jscomp$219$$=$app$plugins$utils$locate_file$$($file_id$jscomp$492$$);$colors$jscomp$28_file$jscomp$219$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90461_SHARP_$$){return $app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$54$$,
$file_id$jscomp$492$$,$p1__90461_SHARP_$$)},$APP.$cljs$core$keys$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$28_file$jscomp$219$$))));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$colors$jscomp$28_file$jscomp$219$$)}.call(this,this)}});Object.defineProperty($obj_90467$$,"typographies",{enumerable:!0,get:function(){return function(){var $file$jscomp$220_typographies$jscomp$13$$=
$app$plugins$utils$locate_file$$($file_id$jscomp$492$$);$file$jscomp$220_typographies$jscomp$13$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90462_SHARP_$$){return $app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$54$$,$file_id$jscomp$492$$,$p1__90462_SHARP_$$)},$APP.$cljs$core$keys$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$220_typographies$jscomp$13$$))));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$file$jscomp$220_typographies$jscomp$13$$)}.call(this,this)}});Object.defineProperty($obj_90467$$,"components",{enumerable:!0,get:function(){return function(){var $components$jscomp$26_file$jscomp$221$$=$app$plugins$utils$locate_file$$($file_id$jscomp$492$$),$data$jscomp$540$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$26_file$jscomp$221$$);$components$jscomp$26_file$jscomp$221$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90464_SHARP_$$){return $app$plugins$library$lib_component_proxy$$($plugin_id$jscomp$54$$,
$file_id$jscomp$492$$,$p1__90464_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90463_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__90463_SHARP_$$,$data$jscomp$540$$)},$APP.$cljs$core$second$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2541$deleted$$,
$APP.$cljs$core$second$$),$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$540$$)))));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$components$jscomp$26_file$jscomp$221$$)}.call(this,this)}});Object.defineProperty($obj_90467$$,"tokens",{enumerable:!0,get:function(){return $app$plugins$tokens$tokens_catalog$$($plugin_id$jscomp$54$$,$file_id$jscomp$492$$)}});Object.defineProperty($obj_90467$$,"createColor",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$54$$,
"library:write")){var $color_id$jscomp$13$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$color_id$jscomp$13$$,$APP.$cljs$cst$725$name$$,"Color",$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,1],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3902$rename_QMARK_$$,!1],null)),$plugin_id$jscomp$54$$));return $app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$54$$,$file_id$jscomp$492$$,$color_id$jscomp$13$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6598$createColor$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90467$$,"createTypography",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$54$$,
"library:write")){var $typography_id$jscomp$11$$=$APP.$app$common$uuid$next$$(),$JSCompiler_temp_const$jscomp$11065$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$,$id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$typography_id$jscomp$11$$,$APP.$cljs$cst$725$name$$,"Typography"],null));var $JSCompiler_inline_result$jscomp$11067_letter_spacing$jscomp$inline_14014$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1766$letter_spacing$$);var $font_family$jscomp$inline_14015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1758$font_family$$),$line_height$jscomp$inline_14016$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1765$line_height$$),
$path$jscomp$inline_14017$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$296$path$$),$font_style$jscomp$inline_14018$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1762$font_style$$),$text_transform$jscomp$inline_14019$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,
$APP.$cljs$cst$1769$text_transform$$),$font_id$jscomp$inline_14020$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1757$font_id$$),$font_size$jscomp$inline_14021$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1760$font_size$$),$font_weight$jscomp$inline_14022$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,
$APP.$cljs$cst$1761$font_weight$$),$name$jscomp$inline_14023$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$725$name$$),$font_variant_id$jscomp$inline_14024$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,$APP.$cljs$cst$1759$font_variant_id$$);$id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$,
$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$11067_letter_spacing$jscomp$inline_14014$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1769$text_transform$$,$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1759$font_variant_id$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1758$font_family$$],[$APP.$cljs$core$truth_$$($line_height$jscomp$inline_14016$$)?$line_height$jscomp$inline_14016$$:"1.2",$path$jscomp$inline_14017$$,$APP.$cljs$core$truth_$$($font_style$jscomp$inline_14018$$)?$font_style$jscomp$inline_14018$$:"normal",$APP.$cljs$core$truth_$$($text_transform$jscomp$inline_14019$$)?$text_transform$jscomp$inline_14019$$:"none",$APP.$cljs$core$truth_$$($font_id$jscomp$inline_14020$$)?$font_id$jscomp$inline_14020$$:
"sourcesanspro",$APP.$cljs$core$truth_$$($font_size$jscomp$inline_14021$$)?$font_size$jscomp$inline_14021$$:"14",$APP.$cljs$core$truth_$$($font_weight$jscomp$inline_14022$$)?$font_weight$jscomp$inline_14022$$:"480",$APP.$cljs$core$truth_$$($name$jscomp$inline_14023$$)?$name$jscomp$inline_14023$$:"Typography 1",$APP.$cljs$core$truth_$$($font_variant_id$jscomp$inline_14024$$)?$font_variant_id$jscomp$inline_14024$$:"regular",$APP.$cljs$core$truth_$$($id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$)?
$id$jscomp$inline_14025_map__51572__$1$jscomp$inline_14013$$:$APP.$app$common$uuid$next$$(),$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11067_letter_spacing$jscomp$inline_14014$$)?$JSCompiler_inline_result$jscomp$11067_letter_spacing$jscomp$inline_14014$$:"0",$APP.$cljs$core$truth_$$($font_family$jscomp$inline_14015$$)?$font_family$jscomp$inline_14015$$:"sourcesanspro"]));$JSCompiler_temp_const$jscomp$11065$$.call($APP.$app$main$store$emit_BANG_$$,$app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11067_letter_spacing$jscomp$inline_14014$$,
!1),$plugin_id$jscomp$54$$));return $app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$54$$,$file_id$jscomp$492$$,$typography_id$jscomp$11$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6599$createTypography$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90467$$,"createComponent",{enumerable:!1,get:function(){return function($ids$jscomp$324_shapes$jscomp$241$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$54$$,
"library:write")){var $id_ref$jscomp$7$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$ids$jscomp$324_shapes$jscomp$241$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__90465_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__90465_SHARP_$$,"$id")}),$ids$jscomp$324_shapes$jscomp$241$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_component$cljs$0core$0IFn$0_invoke$0arity$02$$($id_ref$jscomp$7$$,
$ids$jscomp$324_shapes$jscomp$241$$),$plugin_id$jscomp$54$$));return $app$plugins$library$lib_component_proxy$$($plugin_id$jscomp$54$$,$file_id$jscomp$492$$,$APP.$cljs$core$_deref$$($id_ref$jscomp$7$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6600$createComponent$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90467$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$462$$){if(typeof $key$jscomp$462$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6601$file_plugin_data_key$$,$key$jscomp$462$$);var $file$jscomp$222$$=$app$plugins$utils$locate_file$$($file_id$jscomp$492$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$222$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$54$$))),$key$jscomp$462$$)}.bind(this)}});Object.defineProperty($obj_90467$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$463$$,$value$jscomp$1201$$){return typeof $key$jscomp$463$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6524$setPluginData_key$$,$key$jscomp$463$$):$value$jscomp$1201$$!=null&&typeof $value$jscomp$1201$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6525$setPluginData_value$$,$value$jscomp$1201$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$54$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($file_id$jscomp$492$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$54$$)),
$key$jscomp$463$$,$value$jscomp$1201$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6526$setPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90467$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $file$jscomp$223$$=$app$plugins$utils$locate_file$$($file_id$jscomp$492$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$223$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$54$$)))))}.bind(this)}});Object.defineProperty($obj_90467$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$36$$,$key$jscomp$464$$){if(typeof $namespace$jscomp$36$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6602$file_plugin_data_namespace$$,
$namespace$jscomp$36$$);if(typeof $key$jscomp$464$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6601$file_plugin_data_key$$,$key$jscomp$464$$);var $file$jscomp$224$$=$app$plugins$utils$locate_file$$($file_id$jscomp$492$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$224$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$36$$)),$key$jscomp$464$$)}.bind(this)}});Object.defineProperty($obj_90467$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$37$$,$key$jscomp$465$$,$value$jscomp$1202$$){return typeof $namespace$jscomp$37$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6529$setSharedPluginData_namespace$$,
$namespace$jscomp$37$$):typeof $key$jscomp$465$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6530$setSharedPluginData_key$$,$key$jscomp$465$$):$value$jscomp$1202$$!=null&&typeof $value$jscomp$1202$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1202$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$54$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($file_id$jscomp$492$$,
$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$37$$),$key$jscomp$465$$,$value$jscomp$1202$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6532$setSharedPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90467$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$38$$){if(typeof $namespace$jscomp$38$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,
$APP.$cljs$cst$394$namespace$$,$namespace$jscomp$38$$);var $file$jscomp$225$$=$app$plugins$utils$locate_file$$($file_id$jscomp$492$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$225$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",
$namespace$jscomp$38$$))))}.bind(this)}});return $obj_90467$$},$app$plugins$library$library_subcontext$$=function($plugin_id$jscomp$55$$){var $obj_90651$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_90651$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PenpotLibrarySubcontext"}});Object.defineProperty($obj_90651$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PenpotLibrarySubcontext"}});Object.defineProperty($obj_90651$$,"$plugin",{enumerable:!1,
get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$55$$).call(this)}});Object.defineProperty($obj_90651$$,"local",{enumerable:!0,get:function(){return $app$plugins$library$library_proxy$$($plugin_id$jscomp$55$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))}});Object.defineProperty($obj_90651$$,"connected",{enumerable:!0,get:function(){var $libraries$jscomp$inline_10598$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1916$files$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$library$library_proxy$$,$plugin_id$jscomp$55$$),$APP.$cljs$core$keys$$($libraries$jscomp$inline_10598$$)))}});Object.defineProperty($obj_90651$$,"availableLibraries",{enumerable:!1,get:function(){return function(){var $team_id$jscomp$177$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return new Promise(function($resolve$jscomp$58$$,$reject$jscomp$42$$){var $current_libs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1916$files$$));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$58$$,
$reject$jscomp$42$$,$APP.$beicon$v2$core$map$$(function($result$jscomp$391$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$1130_p__90710$$){var $library_summary_map__90713__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1130_p__90710$$);$id$jscomp$1130_p__90710$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_summary_map__90713__$1$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$523$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_summary_map__90713__$1$$,$APP.$cljs$cst$725$name$$);$library_summary_map__90713__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_summary_map__90713__$1$$,$APP.$cljs$cst$3982$library_summary$$);return{id:""+($id$jscomp$1130_p__90710$$??""),name:$name$jscomp$523$$,numColors:$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($library_summary_map__90713__$1$$)),
numComponents:$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($library_summary_map__90713__$1$$)),numTypographies:$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($library_summary_map__90713__$1$$))}},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90649_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($current_libs$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__90649_SHARP_$$))},
$result$jscomp$391$$)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3322$get_team_shared_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$177$$],null))))})}.bind(this)}});Object.defineProperty($obj_90651$$,"connectLibrary",{enumerable:!1,get:function(){return function($library_id$jscomp$61$$){return new Promise(function($resolve$jscomp$59$$,$reject$jscomp$43$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$55$$,
"library:write")){if(typeof $library_id$jscomp$61$$!=="string")return $app$plugins$utils$reject_not_valid$$($reject$jscomp$43$$,$cljs$cst$6603$connectLibrary$$,$library_id$jscomp$61$$);var $file_id$jscomp$493$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$library_id__$1$$=$APP.$app$common$uuid$parse$$($library_id$jscomp$61$$);$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){var $G__90732$$=
$app$plugins$library$library_proxy$$($plugin_id$jscomp$55$$,$library_id__$1$$);return $resolve$jscomp$59$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$59$$.$cljs$core$IFn$_invoke$arity$1$($G__90732$$):$resolve$jscomp$59$$($G__90732$$)},$reject$jscomp$43$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3984$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library_finished$$),$APP.$app$main$store$stream$$)));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$link_file_to_library$$($file_id$jscomp$493$$,$library_id__$1$$),$plugin_id$jscomp$55$$))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$43$$,$cljs$cst$6603$connectLibrary$$,"Plugin doesn't have 'library:write' permission")})}.bind(this)}});return $obj_90651$$},$app$plugins$local_storage$prefix_key$$=function($plugin_id$jscomp$56$$,$key$jscomp$466$$){return"penpot-plugins:"+
($plugin_id$jscomp$56$$??"")+"/"+($key$jscomp$466$$??"")},$app$plugins$local_storage$local_storage_proxy$$=function($plugin_id$jscomp$57$$){var $obj_87371$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_87371$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LocalStorageProxy"}});Object.defineProperty($obj_87371$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LocalStorageProxy"}});Object.defineProperty($obj_87371$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$57$$}});
Object.defineProperty($obj_87371$$,"getItem",{enumerable:!1,get:function(){return function($key$jscomp$467$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"allow:localstorage")?typeof $key$jscomp$467$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6604$getItem$$,"The key must be a string"):$app$plugins$local_storage$local_storage$$.getItem($app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$57$$,$key$jscomp$467$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,
$cljs$cst$6604$getItem$$,"Plugin doesn't have 'allow:localstorage' permission")}.bind(this)}});Object.defineProperty($obj_87371$$,"setItem",{enumerable:!1,get:function(){return function($key$jscomp$468$$,$value$jscomp$1203$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"allow:localstorage")?typeof $key$jscomp$468$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6605$setItem$$,"The key must be a string"):$app$plugins$local_storage$local_storage$$.setItem($app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$57$$,
$key$jscomp$468$$),$value$jscomp$1203$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6605$setItem$$,"Plugin doesn't have 'allow:localstorage' permission")}.bind(this)}});Object.defineProperty($obj_87371$$,"removeItem",{enumerable:!1,get:function(){return function($key$jscomp$469$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"allow:localstorage")?typeof $key$jscomp$469$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6606$removeItem$$,
"The key must be a string"):$app$plugins$local_storage$local_storage$$.getItem($app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$57$$,$key$jscomp$469$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6606$removeItem$$,"Plugin doesn't have 'allow:localstorage' permission")}.bind(this)}});Object.defineProperty($obj_87371$$,"getKeys",{enumerable:!1,get:function(){return function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__87368_SHARP_$$){return $APP.$cuerdas$core$replace$$($p1__87368_SHARP_$$,
$app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$57$$,""),"")},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__87367_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__87367_SHARP_$$,$app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$57$$,""))},Object.keys($app$plugins$local_storage$local_storage$$))))}.bind(this)}});return $obj_87371$$},$app$plugins$viewport$viewport_proxy$$=function($plugin_id$jscomp$58$$){var $obj_87869$$=new $APP.$app$util$object$Proxy$$;
Object.defineProperty($obj_87869$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ViewportProxy"}});Object.defineProperty($obj_87869$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ViewportProxy"}});Object.defineProperty($obj_87869$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$58$$}});Object.defineProperty($obj_87869$$,"center",{enumerable:!0,get:function(){var $vp$jscomp$inline_10602_y$jscomp$inline_10604$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1925$vbox$$),$x$jscomp$inline_10603$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10602_y$jscomp$inline_10604$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10602_y$jscomp$inline_10604$$)/2;$vp$jscomp$inline_10602_y$jscomp$inline_10604$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10602_y$jscomp$inline_10604$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10602_y$jscomp$inline_10604$$)/
2;return Object.freeze({x:$x$jscomp$inline_10603$$,y:$vp$jscomp$inline_10602_y$jscomp$inline_10604$$})},set:function($val_center_87931$$){return function($new_y$jscomp$4_value$jscomp$1204$$){var $new_x$jscomp$4$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($new_y$jscomp$4_value$jscomp$1204$$,"x");$new_y$jscomp$4_value$jscomp$1204$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($new_y$jscomp$4_value$jscomp$1204$$,"y");if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($new_x$jscomp$4$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,
$cljs$cst$6607$center_x$$,$new_x$jscomp$4$$);if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($new_y$jscomp$4_value$jscomp$1204$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6608$center_y$$,$new_y$jscomp$4_value$jscomp$1204$$);var $old_y_vb$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$1925$vbox$$),$old_x$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)/2;$old_y_vb$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)/2;var $delta_x$jscomp$9$$=$new_x$jscomp$4$$-$old_x$$,$delta_y$jscomp$7$$=$new_y$jscomp$4_value$jscomp$1204$$-$old_y_vb$jscomp$1$$;
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,function($p1__87866_SHARP_$$){return $p1__87866_SHARP_$$+$delta_x$jscomp$9$$},$APP.$cljs$cst$1511$y$$,function($p1__87867_SHARP_$$){return $p1__87867_SHARP_$$+$delta_y$jscomp$7$$}],null)))}.call(this,$val_center_87931$$)}});Object.defineProperty($obj_87869$$,"zoom",{enumerable:!0,get:function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2196$zoom$$)},set:function($JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$)))$JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$APP.$cljs$cst$2196$zoom$$,$JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$);else{var $z$jscomp$inline_10607$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2196$zoom$$);$JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$/$z$jscomp$inline_10607$$))}return $JSCompiler_inline_result$jscomp$2266_val_zoom_87954$$}});Object.defineProperty($obj_87869$$,"bounds",{enumerable:!0,get:function(){var $vbox$jscomp$inline_10609$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1925$vbox$$);return Object.freeze($app$plugins$format$format_bounds$$($vbox$jscomp$inline_10609$$))}});Object.defineProperty($obj_87869$$,"zoomReset",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}.bind(this)}});
Object.defineProperty($obj_87869$$,"zoomToFitAll",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}.bind(this)}});Object.defineProperty($obj_87869$$,"zoomIntoView",{enumerable:!1,get:function(){return function($ids$jscomp$325_shapes$jscomp$242$$){return $APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$325_shapes$jscomp$242$$)?($ids$jscomp$325_shapes$jscomp$242$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$1177$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1177$$,"$id")},$ids$jscomp$325_shapes$jscomp$242$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$zoom$fit_to_shapes$$($ids$jscomp$325_shapes$jscomp$242$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6609$zoomIntoView$$,"Argument should be valid shapes")}.bind(this)}});
return $obj_87869$$},$app$plugins$api$create_shape$$=function($plugin_id$jscomp$59$$,$type$jscomp$749$$){var $changes$jscomp$335_page$jscomp$196$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shape$jscomp$1178$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$type$jscomp$749$$,$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,0,$APP.$cljs$cst$290$width$$,
100,$APP.$cljs$cst$1522$height$$,100],null));$changes$jscomp$335_page$jscomp$196$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$changes$jscomp$335_page$jscomp$196$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$335_page$jscomp$196$$)),
$shape$jscomp$1178$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$335_page$jscomp$196$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$59$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$type$jscomp$749$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$59$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1178$$))},$app$plugins$api$create_context$$=function($plugin_id$jscomp$60$$){var $obj_91052$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_91052$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PenpotContext"}});Object.defineProperty($obj_91052$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PenpotContext"}});Object.defineProperty($obj_91052$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$60$$}});
Object.defineProperty($obj_91052$$,"version",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)).call(this,this)}});Object.defineProperty($obj_91052$$,"root",{enumerable:!0,get:function(){return this.getRoot()}});Object.defineProperty($obj_91052$$,"currentFile",{enumerable:!0,get:function(){return this.getFile()}});Object.defineProperty($obj_91052$$,"currentPage",{enumerable:!0,get:function(){return this.getPage()}});
Object.defineProperty($obj_91052$$,"theme",{enumerable:!0,get:function(){return this.getTheme()}});Object.defineProperty($obj_91052$$,"localStorage",{enumerable:!0,get:function(){return $app$plugins$local_storage$local_storage_proxy$$($plugin_id$jscomp$60$$)}});Object.defineProperty($obj_91052$$,"selection",{enumerable:!0,get:function(){return this.getSelectedShapes()},set:function($val_selection_91124$$){return function($_$jscomp$3307_ids$jscomp$326$$,$shapes$jscomp$243$$){return $APP.$cljs$core$array_QMARK_$$($shapes$jscomp$243$$)&&
$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$243$$)?($_$jscomp$3307_ids$jscomp$326$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91025_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91025_SHARP_$$,"$id")}),$shapes$jscomp$243$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shapes$$($_$jscomp$3307_ids$jscomp$326$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6610$selection$$,$shapes$jscomp$243$$)}.call(this,this,$val_selection_91124$$)}});Object.defineProperty($obj_91052$$,"viewport",{enumerable:!0,get:function(){return this.getViewport()}});Object.defineProperty($obj_91052$$,"currentUser",{enumerable:!0,get:function(){return this.getCurrentUser()}});Object.defineProperty($obj_91052$$,"activeUsers",{enumerable:!0,get:function(){return this.getActiveUsers()}});Object.defineProperty($obj_91052$$,
"fonts",{enumerable:!0,get:function(){return $app$plugins$fonts$fonts_subcontext$$($plugin_id$jscomp$60$$)}});Object.defineProperty($obj_91052$$,"flags",{enumerable:!0,get:function(){return $app$plugins$flags$flags_proxy$$($plugin_id$jscomp$60$$)}});Object.defineProperty($obj_91052$$,"library",{enumerable:!0,get:function(){return $app$plugins$library$library_subcontext$$($plugin_id$jscomp$60$$)}});Object.defineProperty($obj_91052$$,"history",{enumerable:!0,get:function(){return $app$plugins$history$history_subcontext$$($plugin_id$jscomp$60$$)}});
Object.defineProperty($obj_91052$$,"addListener",{enumerable:!1,get:function(){return function($type$jscomp$750$$,$callback$jscomp$94$$,$props$jscomp$465$$){return $app$plugins$events$add_listener$$($type$jscomp$750$$,$plugin_id$jscomp$60$$,$callback$jscomp$94$$,$props$jscomp$465$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"removeListener",{enumerable:!1,get:function(){return function($listener_id$$){return $APP.$cljs$core$remove_watch$$($APP.$app$main$store$state$$,$listener_id$$)}.bind(this)}});
Object.defineProperty($obj_91052$$,"getViewport",{enumerable:!1,get:function(){return function(){return $app$plugins$viewport$viewport_proxy$$($plugin_id$jscomp$60$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"getFile",{enumerable:!1,get:function(){return function(){return $APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))!=null?$app$plugins$file$file_proxy$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))):
null}.bind(this)}});Object.defineProperty($obj_91052$$,"getPage",{enumerable:!1,get:function(){return function(){var $file_id$jscomp$494$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$495$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $file_id$jscomp$494$$!=null&&$page_id$jscomp$495$$!=null?$app$plugins$page$page_proxy$$($plugin_id$jscomp$60$$,
$file_id$jscomp$494$$,$page_id$jscomp$495$$):null}.bind(this)}});Object.defineProperty($obj_91052$$,"getSelectedShapes",{enumerable:!1,get:function(){return function(){var $selection$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$shape$shape_proxy$$,$plugin_id$jscomp$60$$)),$selection$jscomp$18$$))}.bind(this)}});Object.defineProperty($obj_91052$$,"shapesColors",{enumerable:!1,get:function(){return function($shapes$jscomp$244_shapes__$1$jscomp$41$$){if($APP.$cljs$core$array_QMARK_$$($shapes$jscomp$244_shapes__$1$jscomp$41$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,
$shapes$jscomp$244_shapes__$1$jscomp$41$$)){var $objects$jscomp$863$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$();$shapes$jscomp$244_shapes__$1$jscomp$41$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__91030_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$863$$,$p1__91030_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91029_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91029_SHARP_$$,
"$id")},$shapes$jscomp$244_shapes__$1$jscomp$41$$)]));var $file_id$jscomp$495$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shared_libs$$=$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $app$plugins$format$format_array$$($app$plugins$format$format_color_result$$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$2645$attrs$$,$APP.$app$main$data$workspace$colors$extract_all_colors$$($shapes$jscomp$244_shapes__$1$jscomp$41$$,
$file_id$jscomp$495$$,$shared_libs$$)))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6611$shapesColors_shapes$$,$shapes$jscomp$244_shapes__$1$jscomp$41$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"replaceColor",{enumerable:!1,get:function(){return function($shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$,$new_color$jscomp$6_new_color__$1$$){$old_color$jscomp$6_old_color__$1$jscomp$2$$=
$app$plugins$parser$parse_color_data$$($old_color$jscomp$6_old_color__$1$jscomp$2$$);$new_color$jscomp$6_new_color__$1$$=$app$plugins$parser$parse_color_data$$($new_color$jscomp$6_new_color__$1$$);if($APP.$cljs$core$array_QMARK_$$($shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$)){if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_color$$,
$old_color$jscomp$6_old_color__$1$jscomp$2$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6613$replaceColor_oldColor$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$);if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_color$$,$new_color$jscomp$6_new_color__$1$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6614$replaceColor_newColor$$,$new_color$jscomp$6_new_color__$1$$);
var $file_id$jscomp$496$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shared_libs$jscomp$1$$=$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$objects$jscomp$864$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$();$shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__91032_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$864$$,
$p1__91032_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91031_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91031_SHARP_$$,"$id")},$shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$)]));$shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$2645$attrs$$,
$APP.$app$main$data$workspace$colors$extract_all_colors$$($shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$,$file_id$jscomp$496$$,$shared_libs$jscomp$1$$));$shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$);return $APP.$cljs$core$truth_$$($shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_color_in_selected$$($shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$,$new_color$jscomp$6_new_color__$1$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$)):null}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6612$replaceColor_shapes$$,$shapes$jscomp$245_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$468$$)}.bind(this)}});
Object.defineProperty($obj_91052$$,"getRoot",{enumerable:!1,get:function(){return function(){return $APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))!=null&&$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$60$$,$APP.$app$common$uuid$zero$$):null}.bind(this)}});
Object.defineProperty($obj_91052$$,"getTheme",{enumerable:!1,get:function(){return function(){var $theme$jscomp$45$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$3184$theme$$],null));return $APP.$cljs$core$not$$($theme$jscomp$45$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$45$$,
"system")?$app$util$theme$get_system_theme$$():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$45$$,"default")?"dark":$theme$jscomp$45$$}.bind(this)}});Object.defineProperty($obj_91052$$,"getCurrentUser",{enumerable:!1,get:function(){return function(){return $app$plugins$user$current_user_proxy$$($plugin_id$jscomp$60$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"getActiveUsers",{enumerable:!1,get:function(){return function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91034_SHARP_$$){return $app$plugins$user$active_user_proxy$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__91034_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91033_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__91033_SHARP_$$),$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))},
$APP.$cljs$core$vals$$($APP.$cljs$cst$2216$workspace_presence$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))))))}.bind(this)}});Object.defineProperty($obj_91052$$,"uploadMediaUrl",{enumerable:!1,get:function(){return function($name$jscomp$524$$,$url$jscomp$105$$){if(typeof $name$jscomp$524$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6615$uploadMedia_name$$,$name$jscomp$524$$);if(typeof $url$jscomp$105$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,
$cljs$cst$6616$uploadMedia_url$$,$url$jscomp$105$$);var $file_id$jscomp$497$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return new Promise(function($resolve$jscomp$60$$,$reject$jscomp$44$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$60$$,$reject$jscomp$44$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,
"add-media"))},$APP.$beicon$v2$core$map$$($app$plugins$format$format_image$$,$APP.$beicon$v2$core$take$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3682$create_file_media_object_from_url$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,$name$jscomp$524$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$497$$,$APP.$cljs$cst$1975$url$$,$url$jscomp$105$$,$APP.$cljs$cst$2574$is_local$$,!0],null))))))})}.bind(this)}});Object.defineProperty($obj_91052$$,
"uploadMediaData",{enumerable:!1,get:function(){return function($name$jscomp$525$$,$data$jscomp$541$$,$mime_type$$){var $file_id$jscomp$498$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return new Promise(function($resolve$jscomp$61$$,$reject$jscomp$45$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$61$$,$reject$jscomp$45$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,
"add-media"))},$APP.$beicon$v2$core$map$$($app$plugins$format$format_image$$,$APP.$beicon$v2$core$take$$($APP.$app$main$data$workspace$media$process_blobs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$498$$,$APP.$cljs$cst$3693$local_QMARK_$$,!1,$APP.$cljs$cst$725$name$$,$name$jscomp$525$$,$APP.$cljs$cst$3698$blobs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new Blob([$data$jscomp$541$$ instanceof
Uint8Array?$data$jscomp$541$$:$data$jscomp$541$$ instanceof ArrayBuffer?new Uint8Array($data$jscomp$541$$):$APP.$cljs$core$array_QMARK_$$($data$jscomp$541$$)?Uint8Array.from($data$jscomp$541$$):$data$jscomp$541$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$type$$($data$jscomp$541$$),Object)?Uint8Array.from(Object.values($data$jscomp$541$$)):$data$jscomp$541$$],{type:$mime_type$$})],null),$APP.$cljs$cst$3695$on_image$$,$APP.$cljs$core$identity$$,$APP.$cljs$cst$3696$on_svg$$,
$APP.$cljs$core$identity$$],null))))))})}.bind(this)}});Object.defineProperty($obj_91052$$,"group",{enumerable:!1,get:function(){return function($ids$jscomp$327_shapes$jscomp$246$$){if($APP.$cljs$core$array_QMARK_$$($ids$jscomp$327_shapes$jscomp$246$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$327_shapes$jscomp$246$$)){var $file_id$jscomp$499$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$page_id$jscomp$496$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$id$jscomp$1131$$=$APP.$app$common$uuid$next$$();$ids$jscomp$327_shapes$jscomp$246$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91035_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91035_SHARP_$$,
"$id")}),$ids$jscomp$327_shapes$jscomp$246$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$groups$group_shapes$$($id$jscomp$1131$$,$ids$jscomp$327_shapes$jscomp$246$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$60$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$core$type$$]))]));
return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$60$$,$file_id$jscomp$499$$,$page_id$jscomp$496$$,$id$jscomp$1131$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6617$group_shapes$$,$ids$jscomp$327_shapes$jscomp$246$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"ungroup",{enumerable:!1,get:function(){return function(){function $G__91909$$($group$jscomp$65$$,$var_args$jscomp$1514$$){var $G__91910__i_rest$jscomp$22$$=null;if(arguments.length>
1){$G__91910__i_rest$jscomp$22$$=0;for(var $G__91910__a$$=Array(arguments.length-1);$G__91910__i_rest$jscomp$22$$<$G__91910__a$$.length;)$G__91910__a$$[$G__91910__i_rest$jscomp$22$$]=arguments[$G__91910__i_rest$jscomp$22$$+1],++$G__91910__i_rest$jscomp$22$$;$G__91910__i_rest$jscomp$22$$=new $APP.$cljs$core$IndexedSeq$$($G__91910__a$$,0,null)}return $G__91909__delegate$$.call(this,$group$jscomp$65$$,$G__91910__i_rest$jscomp$22$$)}function $G__91909__delegate$$($group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$,
$rest$jscomp$21$$){return $app$plugins$shape$shape_proxy_QMARK_$$($group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$)?$rest$jscomp$21$$==null||$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$rest$jscomp$21$$)?($group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$],null),$rest$jscomp$21$$),
$group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91036_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91036_SHARP_$$,"$id")}),$group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$groups$ungroup_shapes$$($group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$4861$ungroup$$,$rest$jscomp$21$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$4861$ungroup$$,$group$jscomp$64_ids$jscomp$328_shapes$jscomp$247$$)}$G__91909$$.$cljs$lang$maxFixedArity$=1;$G__91909$$.$cljs$lang$applyTo$=function($arglist__91911_rest$jscomp$23$$){var $group$jscomp$66$$=$APP.$cljs$core$first$$($arglist__91911_rest$jscomp$23$$);$arglist__91911_rest$jscomp$23$$=$APP.$cljs$core$rest$$($arglist__91911_rest$jscomp$23$$);
return $G__91909__delegate$$($group$jscomp$66$$,$arglist__91911_rest$jscomp$23$$)};$G__91909$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__91909__delegate$$;return $G__91909$$}().bind(this)}});Object.defineProperty($obj_91052$$,"createBoard",{enumerable:!1,get:function(){return function(){return $app$plugins$api$create_shape$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$1606$frame$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"createRectangle",{enumerable:!1,get:function(){return function(){return $app$plugins$api$create_shape$$($plugin_id$jscomp$60$$,
$APP.$cljs$cst$1611$rect$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"createEllipse",{enumerable:!1,get:function(){return function(){return $app$plugins$api$create_shape$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$1417$circle$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"createPath",{enumerable:!1,get:function(){return function(){var $changes$jscomp$336_page$jscomp$197$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$shape$jscomp$1179$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,
0,$APP.$cljs$cst$1511$y$$,0],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,100,$APP.$cljs$cst$1511$y$$,100],null)],null)],null)],null));$changes$jscomp$336_page$jscomp$197$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$changes$jscomp$336_page$jscomp$197$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$336_page$jscomp$197$$)),$shape$jscomp$1179$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$336_page$jscomp$197$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$60$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$296$path$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$60$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1179$$))}.bind(this)}});Object.defineProperty($obj_91052$$,"createText",{enumerable:!1,get:function(){return function($shape$jscomp$1180_text$jscomp$154$$){if(typeof $shape$jscomp$1180_text$jscomp$154$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($shape$jscomp$1180_text$jscomp$154$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,
$cljs$cst$6618$createText$$,$shape$jscomp$1180_text$jscomp$154$$);var $changes$jscomp$337_page$jscomp$198$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));$shape$jscomp$1180_text$jscomp$154$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,0,$APP.$cljs$cst$290$width$$,1,$APP.$cljs$cst$1522$height$$,1,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$2036$auto_width$$],null)),$APP.$cljs$cst$1637$content$$,$app$common$types$text$change_text$$,$shape$jscomp$1180_text$jscomp$154$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1746$fill_color$$,"#000000",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null)],null)),$APP.$cljs$cst$1891$position_data$$);$changes$jscomp$337_page$jscomp$198$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$changes$jscomp$337_page$jscomp$198$$),
$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$337_page$jscomp$198$$)),$shape$jscomp$1180_text$jscomp$154$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$337_page$jscomp$198$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$60$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1588$text$$]))]));$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1180_text$jscomp$154$$)));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$60$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1180_text$jscomp$154$$))}.bind(this)}});Object.defineProperty($obj_91052$$,"createShapeFromSvg",{enumerable:!1,get:function(){return function($svg_string$jscomp$4$$){if(typeof $svg_string$jscomp$4$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($svg_string$jscomp$4$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6619$createShapeFromSvg$$,$svg_string$jscomp$4$$);var $id$jscomp$1132$$=$APP.$app$common$uuid$next$$(),
$file_id$jscomp$500$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$497$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$media$create_svg_shape$$($id$jscomp$1132$$,$svg_string$jscomp$4$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$60$$,
"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1538$svg$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$60$$,$file_id$jscomp$500$$,$page_id$jscomp$497$$,$id$jscomp$1132$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"createShapeFromSvgWithImages",{enumerable:!1,get:function(){return function($svg_string$jscomp$5$$){return new Promise(function($resolve$jscomp$62$$,$reject$jscomp$46$$){if(typeof $svg_string$jscomp$5$$!==
"string"||$APP.$cljs$core$empty_QMARK_$$($svg_string$jscomp$5$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6619$createShapeFromSvg$$,"Svg not valid"),$reject$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$("Svg not valid"):$reject$jscomp$46$$("Svg not valid");var $id$jscomp$1133$$=$APP.$app$common$uuid$next$$(),$file_id$jscomp$501$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$page_id$jscomp$498$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$media$create_svg_shape_with_images$$($file_id$jscomp$501$$,$id$jscomp$1133$$,$svg_string$jscomp$5$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),function(){var $G__91610$$=$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$60$$,
$file_id$jscomp$501$$,$page_id$jscomp$498$$,$id$jscomp$1133$$);return $resolve$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__91610$$):$resolve$jscomp$62$$($G__91610$$)},$reject$jscomp$46$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$60$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1588$text$$]))]))})}.bind(this)}});Object.defineProperty($obj_91052$$,"createBoolean",{enumerable:!1,get:function(){return function($bool_type$jscomp$11_bool_type__$1$jscomp$1$$,$ids$jscomp$329_shapes$jscomp$248$$){$bool_type$jscomp$11_bool_type__$1$jscomp$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$11_bool_type__$1$jscomp$1$$);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$bool_types$$,$bool_type$jscomp$11_bool_type__$1$jscomp$1$$)){if($APP.$cljs$core$array_QMARK_$$($ids$jscomp$329_shapes$jscomp$248$$)&&
!$APP.$cljs$core$empty_QMARK_$$($ids$jscomp$329_shapes$jscomp$248$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$329_shapes$jscomp$248$$)){$ids$jscomp$329_shapes$jscomp$248$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91037_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91037_SHARP_$$,"$id")}),$ids$jscomp$329_shapes$jscomp$248$$);
var $shape_id$jscomp$187$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$bool$create_bool$$.$cljs$core$IFn$_invoke$arity$variadic$($bool_type$jscomp$11_bool_type__$1$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1723$ids$$,$ids$jscomp$329_shapes$jscomp$248$$,$APP.$cljs$cst$3656$force_shape_id$$,$shape_id$jscomp$187$$])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$60$$,
"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$421$boolean$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$60$$,$shape_id$jscomp$187$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6621$createBoolean_shapes$$,$ids$jscomp$329_shapes$jscomp$248$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6620$createBoolean_boolType$$,$bool_type$jscomp$11_bool_type__$1$jscomp$1$$)}.bind(this)}});
Object.defineProperty($obj_91052$$,"generateMarkup",{enumerable:!1,get:function(){return function($resolved_code_shapes$jscomp$249$$,$options$jscomp$651$$){var $type$jscomp$751$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($options$jscomp$651$$,"type"),"html");return $APP.$cljs$core$array_QMARK_$$($resolved_code_shapes$jscomp$249$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$resolved_code_shapes$jscomp$249$$)?
$type$jscomp$751$$==null||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["svg",null,"html",null],null),null),$type$jscomp$751$$)?($resolved_code_shapes$jscomp$249$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$173$$,$_$jscomp$3308_shape$jscomp$1181$$,$resolved_shapes_shapes__$1$jscomp$43$$){$_$jscomp$3308_shape$jscomp$1181$$=$APP.$cljs$core$first$$($resolved_shapes_shapes__$1$jscomp$43$$);var $objects$jscomp$865$$=
$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3308_shape$jscomp$1181$$),$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3308_shape$jscomp$1181$$));$resolved_shapes_shapes__$1$jscomp$43$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__91038_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$865$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__91038_SHARP_$$))},
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$865$$,$resolved_shapes_shapes__$1$jscomp$43$$)]));return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$173$$,$APP.$app$util$code_gen$generate_formatted_markup_code$$($objects$jscomp$865$$,$type$jscomp$751$$,$resolved_shapes_shapes__$1$jscomp$43$$))},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($s$jscomp$612$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_shape$$($s$jscomp$612$$),$APP.$cljs$cst$2043$page_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$612$$,"$page")),$APP.$cljs$cst$1644$file_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$612$$,"$file"))}),$resolved_code_shapes$jscomp$249$$))),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,"copy-inspect-code")),$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$resolved_code_shapes$jscomp$249$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6623$generateMarkup_type$$,$type$jscomp$751$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6622$generateMarkup_shapes$$,$resolved_code_shapes$jscomp$249$$)}.bind(this)}});
Object.defineProperty($obj_91052$$,"generateStyle",{enumerable:!1,get:function(){return function($resolved_styles_shapes$jscomp$250$$,$JSCompiler_temp$jscomp$2047_options$jscomp$652$$){var $type$jscomp$752$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$2047_options$jscomp$652$$,"type"),"css"),$prelude_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$2047_options$jscomp$652$$,
"withPrelude"),!1),$children_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$2047_options$jscomp$652$$,"includeChildren"),!0);if($APP.$cljs$core$array_QMARK_$$($resolved_styles_shapes$jscomp$250$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$resolved_styles_shapes$jscomp$250$$)){if($type$jscomp$752$$==null||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,["css",null],null),null),$type$jscomp$752$$)){if($prelude_QMARK_$$==null||$APP.$cljs$core$boolean_QMARK_$$($prelude_QMARK_$$)){if($children_QMARK_$$==null||$APP.$cljs$core$boolean_QMARK_$$($children_QMARK_$$)){$resolved_styles_shapes$jscomp$250$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$174$$,$_$jscomp$3309_resolved_shapes$jscomp$1_shape$jscomp$1182$$,$shapes__$1$jscomp$44$$){$_$jscomp$3309_resolved_shapes$jscomp$1_shape$jscomp$1182$$=$APP.$cljs$core$first$$($shapes__$1$jscomp$44$$);
var $objects$jscomp$866$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3309_resolved_shapes$jscomp$1_shape$jscomp$1182$$),$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3309_resolved_shapes$jscomp$1_shape$jscomp$1182$$));$_$jscomp$3309_resolved_shapes$jscomp$1_shape$jscomp$1182$$=function(){var $G__91621$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$866$$,$shapes__$1$jscomp$44$$);
return $APP.$cljs$core$truth_$$($children_QMARK_$$)?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__91039_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$866$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__91039_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__91621$$])):$G__91621$$}();return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$174$$,$APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$5$($objects$jscomp$866$$,
$type$jscomp$752$$,$shapes__$1$jscomp$44$$,$_$jscomp$3309_resolved_shapes$jscomp$1_shape$jscomp$1182$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4097$with_prelude_QMARK_$$,$prelude_QMARK_$$],null)))},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($s$jscomp$613$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_shape$$($s$jscomp$613$$),
$APP.$cljs$cst$2043$page_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$613$$,"$page")),$APP.$cljs$cst$1644$file_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$613$$,"$file"))}),$resolved_styles_shapes$jscomp$250$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,"copy-inspect-style"));if($APP.$cljs$core$truth_$$($prelude_QMARK_$$))a:switch($type$jscomp$752$$){case "css":$JSCompiler_temp$jscomp$2047_options$jscomp$652$$=
"\nhtml, body {\n  margin: 0;\n  min-height: 100%;\n  min-width: 100%;\n  padding: 0;\n}\n\nbody {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  width: 100vw;\n  min-height: 100vh;\n}\n\n* {\n  box-sizing: border-box;\n}\n\n.text-node { background-clip: text !important; -webkit-background-clip: text !important; }\n\n";break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$752$$)].join(""));}else $JSCompiler_temp$jscomp$2047_options$jscomp$652$$=
"";return""+($JSCompiler_temp$jscomp$2047_options$jscomp$652$$??"")+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n\n",$resolved_styles_shapes$jscomp$250$$)??"")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6627$generateStyle_includeChildren$$,$children_QMARK_$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6626$generateStyle_withPrelude$$,$prelude_QMARK_$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6625$generateStyle_type$$,
$type$jscomp$752$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6624$generateStyle_shapes$$,$resolved_styles_shapes$jscomp$250$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"generateFontFaces",{enumerable:!1,get:function(){return function($shapes$jscomp$251$$){return new Promise(function($resolve$jscomp$63$$,$reject$jscomp$47$$){var $all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$();
$all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$),$APP.$app$common$files$helpers$selected_with_children$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91040_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91040_SHARP_$$,"$id")},
$shapes$jscomp$251$$)));$all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$=$APP.$app$main$ui$shapes$text$fontfaces$shapes__GT_fonts$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__91042_SHARP_$$){return $resolve$jscomp$63$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$63$$.$cljs$core$IFn$_invoke$arity$1$($p1__91042_SHARP_$$):$resolve$jscomp$63$$($p1__91042_SHARP_$$)},$reject$jscomp$47$$,
$APP.$beicon$v2$core$first$$($APP.$beicon$v2$core$map$$(function($p1__91041_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$p1__91041_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$fonts$fetch_font_css$$,$APP.$beicon$v2$core$from$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$867$$))))))})}.bind(this)}});Object.defineProperty($obj_91052$$,
"openViewer",{enumerable:!1,get:function(){return function(){var $params$jscomp$473$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1366$section$$,"interactions"],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$473$$])))}.bind(this)}});
Object.defineProperty($obj_91052$$,"createPage",{enumerable:!1,get:function(){return function(){var $file_id$jscomp$502$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$id$jscomp$1134$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$pages$create_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,
$id$jscomp$1134$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$502$$],null)),$plugin_id$jscomp$60$$));return $app$plugins$page$page_proxy$$($plugin_id$jscomp$60$$,$file_id$jscomp$502$$,$id$jscomp$1134$$)}.bind(this)}});Object.defineProperty($obj_91052$$,"openPage",{enumerable:!1,get:function(){return function($id$jscomp$1135_page$jscomp$199$$,$new_window$jscomp$4_new_window__$1$jscomp$1$$){$id$jscomp$1135_page$jscomp$199$$=$app$util$object$type_of_QMARK_$$($id$jscomp$1135_page$jscomp$199$$,"PageProxy")?
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1135_page$jscomp$199$$,"$id"):typeof $id$jscomp$1135_page$jscomp$199$$==="string"?$APP.$app$common$uuid$parse_STAR_$$($id$jscomp$1135_page$jscomp$199$$):null;$new_window$jscomp$4_new_window__$1$jscomp$1$$=$APP.$cljs$core$boolean_QMARK_$$($new_window$jscomp$4_new_window__$1$jscomp$1$$)?$new_window$jscomp$4_new_window__$1$jscomp$1$$:!1;return $id$jscomp$1135_page$jscomp$199$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,
$cljs$cst$6565$openPage$$,"Expected a Page object or a page UUID string"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$id$jscomp$1135_page$jscomp$199$$,$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,$new_window$jscomp$4_new_window__$1$jscomp$1$$])))}.bind(this)}});Object.defineProperty($obj_91052$$,
"alignHorizontal",{enumerable:!1,get:function(){return function($ids$jscomp$330_shapes$jscomp$252$$,$direction$jscomp$34$$){var $dir$jscomp$11$$=function(){switch($direction$jscomp$34$$){case "left":return $APP.$cljs$cst$3419$hleft$$;case "center":return $APP.$cljs$cst$3417$hcenter$$;case "right":return $APP.$cljs$cst$3418$hright$$;default:return null}}();return $dir$jscomp$11$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6628$alignHorizontal_direction$$,"Direction not valid"):
$APP.$cljs$core$array_QMARK_$$($ids$jscomp$330_shapes$jscomp$252$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$330_shapes$jscomp$252$$)?($ids$jscomp$330_shapes$jscomp$252$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91043_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91043_SHARP_$$,"$id")}),$ids$jscomp$330_shapes$jscomp$252$$),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($dir$jscomp$11$$,$ids$jscomp$330_shapes$jscomp$252$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6629$alignHorizontal_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_91052$$,"alignVertical",{enumerable:!1,get:function(){return function($ids$jscomp$331_shapes$jscomp$253$$,$direction$jscomp$35$$){var $dir$jscomp$12$$=
function(){switch($direction$jscomp$35$$){case "top":return $APP.$cljs$cst$3415$vtop$$;case "center":return $APP.$cljs$cst$3420$vcenter$$;case "bottom":return $APP.$cljs$cst$3416$vbottom$$;default:return null}}();return $dir$jscomp$12$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6630$alignVertical_direction$$,"Direction not valid"):$APP.$cljs$core$array_QMARK_$$($ids$jscomp$331_shapes$jscomp$253$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,
$ids$jscomp$331_shapes$jscomp$253$$)?($ids$jscomp$331_shapes$jscomp$253$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91044_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91044_SHARP_$$,"$id")}),$ids$jscomp$331_shapes$jscomp$253$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($dir$jscomp$12$$,
$ids$jscomp$331_shapes$jscomp$253$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6631$alignVertical_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_91052$$,"distributeHorizontal",{enumerable:!1,get:function(){return function($ids$jscomp$332_shapes$jscomp$254$$){return $APP.$cljs$core$array_QMARK_$$($ids$jscomp$332_shapes$jscomp$254$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$332_shapes$jscomp$254$$)?($ids$jscomp$332_shapes$jscomp$254$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91045_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91045_SHARP_$$,"$id")}),$ids$jscomp$332_shapes$jscomp$254$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1909$horizontal$$,
$ids$jscomp$332_shapes$jscomp$254$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6632$distributeHorizontal_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_91052$$,"distributeVertical",{enumerable:!1,get:function(){return function($ids$jscomp$333_shapes$jscomp$255$$){return $APP.$cljs$core$array_QMARK_$$($ids$jscomp$333_shapes$jscomp$255$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$333_shapes$jscomp$255$$)?($ids$jscomp$333_shapes$jscomp$255$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91046_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91046_SHARP_$$,"$id")}),$ids$jscomp$333_shapes$jscomp$255$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1910$vertical$$,$ids$jscomp$333_shapes$jscomp$255$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6633$distributeVertical_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_91052$$,"flatten",{enumerable:!1,get:function(){return function($ids$jscomp$334_shapes$jscomp$256$$){return $APP.$cljs$core$array_QMARK_$$($ids$jscomp$334_shapes$jscomp$256$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$334_shapes$jscomp$256$$)?($ids$jscomp$334_shapes$jscomp$256$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91048_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91048_SHARP_$$,"$id")}),$ids$jscomp$334_shapes$jscomp$256$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$convert_selected_to_path$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$334_shapes$jscomp$256$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6634$flatten_shapes$$,"Not valid shapes")}.bind(this)}});
Object.defineProperty($obj_91052$$,"createVariantFromComponents",{enumerable:!1,get:function(){return function($ids$jscomp$335_shapes$jscomp$257$$){if($APP.$cljs$core$not$$($APP.$cljs$core$seq$$($ids$jscomp$335_shapes$jscomp$257$$))||!$APP.$cljs$core$every_QMARK_$$($app$plugins$utils$is_main_component_proxy_QMARK_$$,$ids$jscomp$335_shapes$jscomp$257$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$1614$shapes$$,$ids$jscomp$335_shapes$jscomp$257$$);var $file_id$jscomp$503$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$first$$($ids$jscomp$335_shapes$jscomp$257$$),"$file"),$page_id$jscomp$499$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$first$$($ids$jscomp$335_shapes$jscomp$257$$),"$page");$ids$jscomp$335_shapes$jscomp$257$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91049_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91049_SHARP_$$,
"$id")},$ids$jscomp$335_shapes$jscomp$257$$));if($APP.$cljs$core$every_QMARK_$$(function($component$jscomp$158_id$jscomp$1136_shape$jscomp$1183$$){$component$jscomp$158_id$jscomp$1136_shape$jscomp$1183$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$503$$,$page_id$jscomp$499$$,$component$jscomp$158_id$jscomp$1136_shape$jscomp$1183$$);$component$jscomp$158_id$jscomp$1136_shape$jscomp$1183$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$503$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$158_id$jscomp$1136_shape$jscomp$1183$$));
return!$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$158_id$jscomp$1136_shape$jscomp$1183$$)},$ids$jscomp$335_shapes$jscomp$257$$)){var $variant_id$jscomp$57$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids$jscomp$335_shapes$jscomp$257$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4424$trigger$$,"plugin:combine-as-variants",
$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$57$$],null)),$plugin_id$jscomp$60$$));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$60$$,$variant_id$jscomp$57$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$1614$shapes$$,"One of the components is not on the same page or is already a variant")}.bind(this)}});return $obj_91052$$},$app$plugins$init_plugins_runtime_BANG_$$=function(){return $shadow$js$shim$module$0$0penpot$0plugins_runtime$$.initPluginsRuntime(function($plugin_id$jscomp$62$$){return $app$plugins$api$create_context$$($plugin_id$jscomp$62$$)})},
$app$plugins$initialize$$=function(){typeof $app$plugins$initialize_91730$$==="undefined"&&($app$plugins$initialize_91730$$=function($meta91731$$){this.$meta91731$=$meta91731$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$plugins$initialize_91730$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$initialize_91730$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6636$app_DOT_plugins_SLASH_initialize$$},
$app$plugins$initialize_91730$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_91732$$,$meta91731__$1$$){return new $app$plugins$initialize_91730$$($meta91731__$1$$)},$app$plugins$initialize_91730$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta91731$},$app$plugins$initialize_91730$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$initialize_91730$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3310$$,
$___$1$jscomp$2117$$,$stream$jscomp$112$$){$APP.$app$main$errors$is_plugin_error_QMARK_$$=$shadow$js$shim$module$0$0penpot$0plugins_runtime$$.isPluginError;return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$init_plugins_runtime_BANG_$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function(){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3108$app_DOT_main_DOT_features_SLASH_initialize$$),$stream$jscomp$112$$))))))});return new $app$plugins$initialize_91730$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$initialize_rasterizer$$=function(){typeof $app$main$initialize_rasterizer_91903$$==="undefined"&&($app$main$initialize_rasterizer_91903$$=function($meta91904$$){this.$meta91904$=$meta91904$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$initialize_rasterizer_91903$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_rasterizer_91903$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6639$app_DOT_main_SLASH_initialize_rasterizer$$},$app$main$initialize_rasterizer_91903$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_91905$$,$meta91904__$1$$){return new $app$main$initialize_rasterizer_91903$$($meta91904__$1$$)},
$app$main$initialize_rasterizer_91903$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta91904$},$app$main$initialize_rasterizer_91903$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_rasterizer_91903$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $app$main$rasterizer$init_BANG_$$()});return new $app$main$initialize_rasterizer_91903$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$initialize$$=
function(){typeof $app$main$initialize_91906$$==="undefined"&&($app$main$initialize_91906$$=function($meta91907$$){this.$meta91907$=$meta91907$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$initialize_91906$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_91906$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6640$app_DOT_main_SLASH_initialize$$},$app$main$initialize_91906$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_91908$$,$meta91907__$1$$){return new $app$main$initialize_91906$$($meta91907__$1$$)},$app$main$initialize_91906$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta91907$},$app$main$initialize_91906$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_91906$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$3312$$,$state$jscomp$1238$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1238$$,
$APP.$cljs$cst$2332$session_id$$,$APP.$app$config$session_id$$)},$app$main$initialize_91906$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_91906$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3313$$,$___$1$jscomp$2120$$,$stream$jscomp$113$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$event$initialize$$(),$APP.$app$main$data$profile$refresh_profile$$()),$APP.$beicon$v2$core$map$$($APP.$app$main$data$auth$logged_out$$,
$APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_deleted_event_QMARK_$$,$stream$jscomp$113$$)),$APP.$beicon$v2$core$map$$(function(){return $app$main$ui$routes$init_routes$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$113$$))),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$websocket$initialize$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$is_authenticated_QMARK_$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$113$$))))),$APP.$beicon$v2$core$map$$(function(){return $app$main$initialize_rasterizer$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3108$app_DOT_main_DOT_features_SLASH_initialize$$),$stream$jscomp$113$$))))});return new $app$main$initialize_91906$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$init$$=function($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$){globalThis.penpotStartDate=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$time$now$$(),null));if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("2.16.0-1782912112",$APP.$app$config$version_tag$$))return $APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$984$reason$$,
"stale JS: compiled\x3d2.16.0-1782912112 expected\x3d"+($APP.$app$config$version_tag$$??"")]));$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$=$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$.defaultTranslations;$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$!=
null&&($APP.$app$util$i18n$get_translations$$().en=$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$);$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$=$app$util$worker$init$$();$APP.$app$util$worker$ask_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3126$configure$$,$APP.$cljs$cst$3127$config$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3128$public_uri$$,$APP.$app$config$public_uri$$,$APP.$cljs$cst$3129$build_data$$,$APP.$app$config$build_date$$,$APP.$cljs$cst$2289$version$$,$APP.$app$config$version$$],null)],null),null);$APP.$app$main$worker$instance$$=$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$;
$APP.$app$util$i18n$load$$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$,"en")||$APP.$app$util$i18n$load$$("en");$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$=$APP.$goog$dom$getElement$$("css-cursors");$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$!=
null?$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$={add:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$css$add_rule$$,$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$.sheet)}:($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$=
$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("style"),$APP.$app$util$dom$set_attribute_BANG_$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"id","css-cursors"),$APP.$app$util$dom$set_attribute_BANG_$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"type","text/css"),$APP.$app$util$dom$append_child_BANG_$$(document.head,
$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$),$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$={add:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$css$add_rule$$,$G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$.sheet)});
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"comments","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%6D%36%2E%39%20%31%32%2E%35%31%39%2D%32%2E%35%33%34%39%20%32%2E%30%32%32%32%2D%30%2E%31%37%30%33%39%2D%32%2E%38%30%32%31%63%2D%30%2E%39%34%31%37%38%2D%30%2E%35%35%39%39%36%2D%32%2E%39%33%33%2D%32%2E%32%39%34%38%2D%33%2E%33%36%32%31%2D%34%2E%37%35%31%35%2D%30%2E%34%32%39%30%37%2D%32%2E%34%35%35%31%20%32%2E%36%36%34%32%2D%34%2E%37%37%35%35%20%34%2E%32%36%33%36%2D%35%2E%36%32%38%32%20%33%2E%37%30%33%36%2D%30%2E%34%39%35%36%37%20%31%30%2E%38%36%32%2D%30%2E%31%32%31%35%39%20%39%2E%38%36%38%35%20%35%2E%33%33%36%32%2D%30%2E%39%39%34%34%34%20%35%2E%34%35%37%38%2D%35%2E%37%39%30%38%20%36%2E%31%35%36%34%2D%38%2E%30%36%35%35%20%35%2E%38%32%33%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%6D%37%2E%38%36%34%32%20%30%2E%33%38%36%39%38%63%2D%32%2E%32%36%20%30%2E%30%32%37%38%38%32%2D%34%2E%35%36%38%37%20%30%2E%38%38%36%37%39%2D%36%2E%31%30%31%34%20%32%2E%35%38%36%2D%31%2E%30%31%34%36%20%31%2E%31%30%35%32%2D%31%2E%36%31%34%38%20%32%2E%36%32%30%31%2D%31%2E%34%38%31%36%20%34%2E%31%32%39%36%20%30%2E%31%30%35%33%33%20%31%2E%37%34%38%38%20%31%2E%31%32%39%32%20%33%2E%33%33%39%36%20%32%2E%34%39%33%39%20%34%2E%33%39%32%39%20%30%2E%32%35%30%39%33%20%30%2E%31%39%38%32%37%20%30%2E%35%31%32%37%31%20%30%2E%33%38%32%36%20%30%2E%37%37%39%39%31%20%30%2E%35%35%38%34%31%20%30%2E%30%32%39%34%33%31%20%30%2E%39%38%39%30%32%2D%30%2E%30%32%36%33%33%33%20%31%2E%39%38%35%38%20%30%2E%30%37%32%38%30%32%20%32%2E%39%36%39%34%20%30%2E%31%36%33%34%32%20%30%2E%33%39%37%33%31%20%30%2E%37%33%37%33%31%20%30%2E%34%39%35%36%37%20%31%2E%30%34%33%32%20%30%2E%32%30%33%36%39%20%30%2E%38%31%32%34%34%2D%30%2E%36%36%39%39%33%20%31%2E%36%33%33%34%2D%31%2E%33%33%30%36%20%32%2E%34%34%36%36%2D%32%2E%30%30%31%33%20%30%2E%37%36%30%35%35%20%30%2E%30%37%37%34%35%20%31%2E%35%33%31%39%20%30%2E%30%33%34%38%36%20%32%2E%32%38%37%38%2D%30%2E%30%36%38%31%35%20%32%2E%31%32%38%33%2D%30%2E%33%34%36%32%20%34%2E%31%38%30%37%2D%31%2E%34%39%39%34%20%35%2E%33%37%34%39%2D%33%2E%33%32%35%37%20%30%2E%38%31%30%38%39%2D%31%2E%32%32%31%34%20%31%2E%31%37%37%32%2D%32%2E%37%36%31%38%20%30%2E%38%35%35%38%31%2D%34%2E%32%30%35%35%2D%30%2E%33%31%32%31%32%2D%31%2E%34%38%34%37%2D%31%2E%32%37%36%34%2D%32%2E%37%37%31%31%2D%32%2E%34%39%36%32%2D%33%2E%36%34%34%37%2D%31%2E%35%31%36%34%2D%31%2E%31%30%33%36%2D%33%2E%34%31%30%31%2D%31%2E%36%33%30%33%2D%35%2E%32%37%35%38%2D%31%2E%35%39%34%37%7A%6D%30%2E%31%37%34%32%36%20%31%2E%33%30%38%39%63%31%2E%38%36%39%36%20%30%2E%30%30%36%39%37%20%33%2E%38%30%32%37%20%30%2E%36%35%36%37%37%20%35%2E%31%32%31%37%20%32%2E%30%33%30%37%20%30%2E%38%30%33%39%32%20%30%2E%38%32%32%35%31%20%31%2E%33%32%38%32%20%31%2E%39%35%33%33%20%31%2E%32%36%38%36%20%33%2E%31%30%37%32%2D%30%2E%30%32%34%37%38%20%31%2E%33%30%38%39%2D%30%2E%37%32%36%34%37%20%32%2E%35%33%36%34%2D%31%2E%36%39%36%31%20%33%2E%33%38%39%32%2D%31%2E%33%38%34%38%20%31%2E%32%33%31%34%2D%33%2E%32%37%39%32%20%31%2E%38%32%31%36%2D%35%2E%31%31%30%31%20%31%2E%37%32%30%39%2D%30%2E%33%31%35%39%39%20%30%2E%30%31%30%38%34%2D%30%2E%36%33%39%37%33%2D%30%2E%30%38%38%32%39%2D%30%2E%39%34%36%34%32%2D%30%2E%30%34%39%35%37%2D%30%2E%35%39%38%36%38%20%30%2E%34%38%37%31%35%2D%31%2E%31%39%36%36%20%30%2E%39%37%34%33%31%2D%31%2E%37%39%33%37%20%31%2E%34%36%32%32%2D%30%2E%30%31%35%34%39%2D%30%2E%36%38%39%33%2D%30%2E%30%31%32%33%39%32%2D%31%2E%33%37%39%34%2D%30%2E%30%32%30%31%33%37%2D%32%2E%30%36%39%34%2D%31%2E%33%36%37%37%2D%30%2E%36%38%39%32%39%2D%32%2E%36%30%39%33%2D%31%2E%38%30%34%36%2D%33%2E%30%38%37%31%2D%33%2E%32%39%33%39%2D%30%2E%34%31%32%30%33%2D%31%2E%32%35%34%37%2D%30%2E%31%37%35%30%33%2D%32%2E%37%30%36%38%20%30%2E%36%34%35%31%35%2D%33%2E%37%35%36%33%20%31%2E%32%39%31%31%2D%31%2E%37%33%37%32%20%33%2E%35%31%2D%32%2E%35%35%31%39%20%35%2E%36%31%38%31%2D%32%2E%35%34%30%33%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 2 20, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"create-artboard","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%34%2D%31%76%35%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%35%20%34%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%76%2D%32%7A%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%33%2E%35%2D%31%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%39%20%39%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"create-ellipse","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%34%61%33%20%33%20%30%20%31%31%2D%36%20%30%20%33%20%33%20%30%20%30%31%36%20%30%7A%6D%2D%31%20%30%61%32%20%32%20%30%20%31%31%2D%34%20%30%20%32%20%32%20%30%20%30%31%34%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%36%2D%33%2E%35%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%4D%31%35%2E%35%20%34%61%33%2E%35%20%33%2E%35%20%30%20%31%31%2D%37%20%30%20%33%2E%35%20%33%2E%35%20%30%20%30%31%37%20%30%7A%4D%31%32%20%37%61%33%20%33%20%30%20%31%30%30%2D%36%20%33%20%33%20%30%20%30%30%30%20%36%7A%6D%30%2D%31%61%32%20%32%20%30%20%31%30%30%2D%34%20%32%20%32%20%30%20%30%30%30%20%34%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"create-polygon","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%73%74%72%6F%6B%65%3D%27%23%66%66%66%27%20%73%74%72%6F%6B%65%2D%77%69%64%74%68%3D%27%2E%35%27%20%64%3D%27%4D%31%32%2E%32%2E%39%4C%31%32%20%2E%35%6C%2D%2E%33%2E%34%2D%33%2E%34%20%36%2D%2E%32%2E%33%48%31%35%2E%39%6C%2D%2E%33%2D%2E%33%2D%33%2E%34%2D%36%7A%6D%31%20%34%2E%38%68%2D%32%2E%35%4C%31%32%20%33%2E%35%6C%31%2E%33%20%32%2E%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"create-rectangle","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%39%20%37%56%31%68%36%76%36%48%39%7A%6D%31%2D%35%68%34%76%34%68%2D%34%56%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%38%2E%35%2E%35%68%37%76%37%68%2D%37%76%2D%37%7A%6D%2D%33%20%33%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%34%2D%37%68%34%76%34%68%2D%34%56%32%7A%6D%2E%35%20%33%2E%35%68%33%76%2D%33%68%2D%33%76%33%7A%4D%39%20%37%56%31%68%36%76%36%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"create-shape","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%37%20%37%56%31%68%31%76%36%68%36%76%31%48%38%76%36%48%37%56%38%48%31%56%37%68%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%36%2E%35%2E%35%68%32%76%36%68%36%76%32%68%2D%36%76%36%68%2D%32%76%2D%36%68%2D%36%76%2D%32%68%36%76%2D%36%7A%4D%37%20%37%48%31%76%31%68%36%76%36%68%31%56%38%68%36%56%37%48%38%56%31%48%37%76%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"duplicate","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%35%2E%31%20%30%4C%31%36%20%31%30%2E%39%48%39%2E%32%4C%35%2E%31%20%31%35%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%35%2E%37%20%31%2E%35%6C%38%2E%37%20%38%2E%36%48%39%6C%2D%33%2E%33%20%33%2E%34%7A%6D%33%20%37%2E%39%68%34%4C%36%2E%35%20%33%2E%33%76%38%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%30%20%30%76%31%35%6C%34%2E%31%2D%34%2E%31%68%32%2E%34%76%2E%38%6C%2E%38%2D%2E%38%68%33%2E%36%4C%39%2E%33%20%39%2E%35%68%33%2E%34%4C%36%2E%35%20%33%2E%33%76%33%2E%32%7A%6D%31%20%32%2E%33%6C%35%2E%34%20%35%2E%35%76%32%2E%31%48%33%2E%37%4C%31%20%31%32%2E%37%7A%6D%37%2E%34%20%37%2E%34%6C%2E%32%2E%32%68%2D%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%32%2E%37%56%32%2E%33%6C%37%2E%37%20%37%2E%36%68%2D%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"hand","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%33%2E%35%20%35%2E%33%38%76%2D%33%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%2D%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%38%2D%2E%32%34%20%31%2E%32%34%2D%2E%31%35%20%32%20%2E%35%76%37%2E%35%63%30%20%33%2D%33%20%34%2D%33%20%34%68%2D%37%73%2D%33%2D%31%2E%31%35%2D%33%2D%34%76%2D%35%2E%35%63%2E%38%32%2D%2E%38%36%20%31%2E%32%35%2D%2E%39%20%32%2D%2E%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%30%63%2D%2E%37%33%20%30%2D%31%2E%36%2E%32%39%2D%31%2E%39%38%20%31%2E%30%34%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2E%31%37%63%2D%2E%33%33%2D%2E%31%33%2D%2E%36%39%2D%2E%32%2D%31%2E%30%32%2D%2E%32%2D%2E%37%33%20%30%2D%31%2E%36%2E%33%2D%31%2E%39%38%20%31%2E%30%35%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2E%32%33%56%34%2E%36%61%31%2E%34%39%20%31%2E%34%39%20%30%20%30%30%2D%2E%35%39%20%30%63%2D%2E%34%37%2E%31%2D%2E%38%37%2E%34%33%2D%31%2E%33%2E%38%38%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%31%34%2E%33%35%76%35%2E%35%39%63%30%20%31%2E%36%35%2E%38%37%20%32%2E%38%20%31%2E%37%20%33%2E%35%61%36%2E%35%34%20%36%2E%35%34%20%30%20%30%30%31%2E%35%32%2E%39%37%6C%2E%31%2E%30%35%2E%30%34%2E%30%31%68%2E%30%31%61%2E%35%2E%35%20%30%20%30%30%2E%31%38%2E%30%34%68%37%2E%31%31%63%2E%30%36%20%30%20%2E%31%31%20%30%20%2E%31%37%2D%2E%30%33%68%2E%30%31%6C%2E%30%33%2D%2E%30%31%2E%31%32%2D%2E%30%35%41%35%2E%34%20%35%2E%34%20%30%20%30%30%31%33%2E%34%20%31%35%63%2E%38%34%2D%2E%37%20%31%2E%37%31%2D%31%2E%38%34%20%31%2E%37%31%2D%33%2E%35%36%56%33%2E%38%61%2E%35%2E%35%20%30%20%30%30%2D%2E%31%38%2D%2E%33%39%20%33%20%33%20%30%20%30%30%2D%31%2E%32%2D%2E%37%20%31%2E%39%35%20%31%2E%39%35%20%30%20%30%30%2D%2E%36%35%2D%2E%30%34%76%2D%2E%34%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2D%2E%32%32%63%2D%2E%33%38%2D%2E%37%35%2D%31%2E%32%35%2D%31%2E%30%34%2D%31%2E%39%38%2D%31%2E%30%34%2D%2E%33%33%20%30%2D%2E%37%2E%30%36%2D%31%2E%30%32%2E%32%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2D%2E%31%38%43%39%2E%36%2E%33%20%38%2E%37%33%20%30%20%38%20%30%7A%6D%30%20%31%2E%30%32%63%2E%34%38%20%30%20%2E%38%35%2E%31%37%20%31%2E%30%32%2E%33%39%76%33%2E%39%32%68%31%2E%30%31%56%32%2E%34%35%63%2E%31%36%2D%2E%32%33%2E%35%32%2D%2E%34%32%20%31%2E%30%32%2D%2E%34%32%2E%34%38%20%30%20%2E%38%34%2E%31%38%20%31%2E%30%31%2E%34%76%32%2E%39%68%31%2E%30%32%56%33%2E%37%31%63%2E%31%36%2D%2E%30%32%2E%33%2D%2E%30%32%2E%34%20%30%20%2E%31%37%2E%30%34%2E%33%35%2E%31%34%2E%36%32%2E%33%34%76%37%2E%33%38%63%30%20%31%2E%33%33%2D%2E%36%36%20%32%2E%32%31%2D%31%2E%33%35%20%32%2E%37%38%61%34%2E%39%38%20%34%2E%39%38%20%30%20%30%31%2D%31%2E%32%35%2E%37%36%6C%2D%2E%30%34%2E%30%31%48%34%2E%35%32%61%34%2E%37%35%20%34%2E%37%35%20%30%20%30%31%2D%31%2E%32%37%2D%2E%38%32%20%33%2E%35%35%20%33%2E%35%35%20%30%20%30%31%2D%31%2E%33%35%2D%32%2E%37%33%56%36%2E%30%35%63%2E%33%32%2D%2E%33%31%2E%35%31%2D%2E%34%31%2E%36%35%2D%2E%34%34%2E%30%38%2D%2E%30%32%2E%32%20%30%20%2E%33%37%2E%30%36%76%32%2E%37%31%68%31%2E%30%32%56%32%2E%34%33%63%2E%31%36%2D%2E%32%32%2E%35%33%2D%2E%34%20%31%2E%30%31%2D%2E%34%2E%35%20%30%20%2E%38%36%2E%31%39%20%31%2E%30%32%2E%34%32%76%32%2E%38%38%68%31%2E%30%31%56%31%2E%34%31%63%2E%31%37%2D%2E%32%32%2E%35%34%2D%2E%34%20%31%2E%30%32%2D%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"move-pointer","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%36%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%7A%4D%38%20%31%31%76%33%2E%32%7A%27%20%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%31%4C%36%20%33%6C%2E%35%2E%35%20%31%2D%31%56%37%68%2D%35%6C%31%2D%31%2D%2E%35%2D%2E%35%2D%32%20%32%20%32%20%32%20%2E%35%2D%2E%35%2D%31%2D%31%68%35%76%35%2E%35%6C%2D%31%2D%31%2D%2E%35%2E%35%20%32%20%32%20%32%2D%32%2D%2E%35%2D%2E%35%2D%31%20%31%56%38%68%35%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%68%2D%35%56%32%2E%35%6C%31%20%31%4C%31%30%20%33%20%38%20%31%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%35%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%20%38%20%2E%33%7A%4D%38%20%31%6C%32%20%32%2D%2E%35%2E%35%2D%31%2D%31%56%37%68%35%6C%2D%31%2D%31%20%2E%35%2D%2E%35%20%32%20%32%2D%32%20%32%2D%2E%35%2D%2E%35%20%31%2D%31%68%2D%35%76%35%2E%35%6C%31%2D%31%20%2E%35%2E%35%2D%32%20%32%2D%32%2D%32%20%2E%35%2D%2E%35%20%31%20%31%56%38%68%2D%35%6C%31%20%31%2D%2E%35%2E%35%2D%32%2D%32%20%32%2D%32%20%2E%35%2E%35%2D%31%20%31%68%35%56%32%2E%35%6C%2D%31%20%31%4C%36%20%33%6C%32%2D%32%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"pen","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%63%2D%2E%37%2E%32%20%30%20%2E%33%2D%2E%37%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%6C%2D%2E%33%2E%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%20%2E%37%2D%2E%37%20%32%2E%33%20%32%2E%33%20%32%2E%36%2D%32%2E%36%4C%31%32%20%39%2E%34%6C%2E%37%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%32%2E%33%20%31%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%63%30%20%2E%38%20%30%20%31%2E%35%2D%2E%33%20%32%2E%31%6C%2D%2E%38%2D%2E%38%4C%31%32%20%38%63%30%2D%32%2E%39%2D%32%2D%34%2E%36%2D%35%2D%35%61%34%36%2E%34%20%34%36%2E%34%20%30%20%30%31%2D%35%2D%31%6C%2E%33%20%31%2E%31%63%2E%32%2E%39%2E%35%20%32%2E%32%2E%37%20%33%2E%39%2E%34%20%33%20%32%2E%31%20%35%20%35%20%35%68%31%2E%33%6C%2E%38%2E%37%63%2D%2E%36%2E%32%2D%31%2E%33%2E%33%2D%32%2E%31%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%2E%36%20%31%2E%36%63%2E%32%2D%2E%31%2E%36%2D%2E%31%2E%38%20%30%6C%35%20%35%61%2E%35%2E%35%20%30%20%31%31%2D%2E%38%2E%38%6C%2D%35%2D%35%61%2E%35%2E%35%20%30%20%30%31%30%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%37%2E%35%20%39%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"pen-node","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'36px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%37%20%30%2D%2E%30%30%31%2D%2E%31%30%31%2E%36%39%39%2D%2E%33%30%31%6C%33%20%33%20%34%2D%34%2E%31%2D%33%2D%33%20%2E%33%2D%2E%36%63%30%2D%31%2E%37%2D%2E%36%2D%33%2E%30%39%39%2D%31%2E%38%2D%34%2E%30%39%39%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%33%2E%36%32%39%20%31%33%2E%38%30%38%61%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%20%36%2E%39%37%39%20%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%2D%36%2E%39%37%39%7A%6D%30%20%31%2E%38%36%36%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%31%2E%30%30%32%20%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%31%2D%2E%30%30%32%2D%33%2E%32%34%38%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%33%33%33%20%30%20%2E%36%33%39%2D%2E%30%32%38%2E%39%33%37%2D%2E%30%36%33%6C%32%2E%37%36%32%20%32%2E%37%36%32%20%34%2D%34%2E%31%2D%32%2E%37%32%39%2D%32%2E%37%32%38%63%2E%30%31%38%2D%2E%32%38%2E%30%33%2D%2E%35%36%32%2E%30%33%2D%2E%38%37%31%20%30%2D%31%2E%37%2D%2E%36%30%31%2D%33%2E%31%2D%31%2E%38%30%31%2D%34%2E%31%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%32%2E%35%33%37%20%31%2E%37%33%36%63%31%2E%33%31%2E%33%30%36%20%32%2E%36%33%2E%35%37%33%20%33%2E%39%36%33%2E%37%36%34%20%33%20%2E%34%20%35%20%32%2E%31%20%35%20%35%6C%2D%2E%31%20%31%2E%33%2E%31%2E%31%2E%36%39%39%2E%37%20%31%2E%36%30%32%20%31%2E%35%39%39%2D%32%2E%36%30%32%20%32%2E%36%30%32%2D%31%2E%36%2D%31%2E%36%30%32%2D%2E%30%30%34%2D%2E%30%30%34%2D%2E%36%39%35%2D%2E%36%39%35%2D%2E%30%34%37%2E%30%34%37%2D%2E%30%35%32%2D%2E%30%34%37%48%38%2E%32%31%39%63%2D%32%2E%39%20%30%2D%34%2E%36%2D%32%2D%35%2D%35%2D%2E%32%2D%31%2E%37%2D%2E%35%2D%32%2E%39%39%39%2D%2E%37%2D%33%2E%38%39%39%4C%36%2E%33%33%20%37%2E%31%33%63%2D%2E%33%34%2E%38%38%34%2E%31%32%20%32%2E%30%38%39%20%31%2E%33%38%39%20%32%2E%30%38%39%20%32%20%30%20%32%2D%33%20%30%2D%33%2D%2E%32%32%34%20%30%2D%2E%34%31%39%2E%30%34%2D%2E%35%39%32%2E%31%30%37%6C%2D%33%2E%38%37%31%2D%33%2E%38%37%7A%4D%34%2E%33%34%38%20%31%34%2E%39%35%61%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%20%36%2E%31%33%35%20%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%2D%36%2E%31%33%35%7A%6D%30%20%31%2E%30%32%34%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%30%20%34%2E%30%39%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%30%2D%34%2E%30%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"pencil","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%6D%30%20%31%2E%35%4C%31%32%2E%35%20%33%20%32%2E%36%20%31%33%6C%2D%31%2E%31%2D%31%2E%32%20%39%2E%39%2D%31%30%7A%6D%32%20%32%4C%31%34%2E%35%20%35%20%34%2E%36%20%31%35%6C%2D%31%2E%32%2D%31%2E%32%20%31%30%2D%31%30%7A%4D%31%20%31%32%2E%39%6C%32%2E%34%20%32%2E%33%48%31%76%2D%32%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"picker","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%30%37%20%31%33%2E%30%37%36%76%32%2E%34%30%31%6C%32%2E%32%32%34%2E%30%32%35%20%37%2E%38%36%2D%37%2E%34%30%35%73%2D%2E%30%35%2D%2E%38%38%35%2D%2E%32%35%33%2D%31%2E%30%38%37%63%2D%2E%32%30%32%2D%2E%32%30%32%2D%32%2E%32%35%2D%31%2E%37%34%34%2D%32%2E%32%35%2D%31%2E%37%34%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%2E%33%34%33%20%31%35%2E%39%37%34%61%2E%35%31%34%2E%35%31%34%20%30%20%30%31%2D%2E%33%31%37%2D%2E%33%32%31%63%2D%2E%30%32%33%2D%2E%30%37%2D%2E%30%32%36%2D%2E%32%33%2D%2E%30%32%36%2D%31%2E%34%33%20%30%2D%31%2E%34%36%38%2D%2E%30%30%31%2D%31%2E%34%34%35%2E%30%39%2D%31%2E%35%38%36%2E%30%32%2D%2E%30%33%32%20%31%2E%37%30%33%2D%31%2E%37%32%34%20%33%2E%37%34%2D%33%2E%37%35%39%61%35%39%36%2E%38%30%35%20%35%39%36%2E%38%30%35%20%30%20%30%30%33%2E%37%2D%33%2E%37%31%36%63%30%2D%2E%30%30%39%2D%2E%33%36%37%2D%2E%33%38%34%2D%2E%38%31%36%2D%2E%38%33%33%61%32%39%2E%39%20%32%39%2E%39%20%30%20%30%31%2D%2E%38%31%37%2D%2E%38%33%33%63%30%2D%2E%30%31%2E%34%37%34%2D%2E%34%39%20%31%2E%30%35%34%2D%31%2E%30%37%6C%31%2E%30%35%33%2D%31%2E%30%35%33%2E%39%34%38%2E%39%34%36%2E%39%34%37%2E%39%34%37%20%31%2E%34%31%37%2D%31%2E%34%31%33%43%31%32%2E%33%36%36%2E%38%30%36%20%31%32%2E%37%36%35%2E%34%31%38%20%31%32%2E%38%35%36%2E%33%35%37%63%2E%32%33%38%2D%2E%31%36%31%2E%35%32%2D%2E%32%38%2E%37%39%32%2D%2E%33%33%34%2E%31%37%2D%2E%30%33%34%2E%35%38%36%2D%2E%30%33%2E%37%36%2E%30%30%38%2E%38%30%31%2E%31%37%33%20%31%2E%34%31%2E%37%39%34%20%31%2E%35%37%20%31%2E%36%30%33%2E%30%33%2E%31%35%2E%30%33%2E%35%36%39%20%30%20%2E%37%31%38%61%32%2E%32%32%37%20%32%2E%32%32%37%20%30%20%30%31%2D%2E%33%33%34%2E%37%39%33%63%2D%2E%30%36%31%2E%30%39%2D%2E%34%35%2E%34%39%2D%31%2E%34%39%36%20%31%2E%35%34%4C%31%32%2E%37%33%34%20%36%2E%31%6C%2E%39%34%37%2E%39%34%38%2E%39%34%37%2E%39%34%37%2D%31%2E%30%35%33%20%31%2E%30%35%34%63%2D%2E%35%38%2E%35%38%2D%31%2E%30%36%31%20%31%2E%30%35%34%2D%31%2E%30%37%20%31%2E%30%35%34%2D%2E%30%31%20%30%2D%2E%33%38%34%2D%2E%33%36%38%2D%2E%38%33%33%2D%2E%38%31%37%2D%2E%34%35%2D%2E%34%35%2D%2E%38%32%34%2D%2E%38%31%37%2D%2E%38%33%34%2D%2E%38%31%37%2D%2E%30%30%39%20%30%2D%31%2E%36%38%20%31%2E%36%36%36%2D%33%2E%37%31%36%20%33%2E%37%30%31%61%34%39%33%2E%30%39%33%20%34%39%33%2E%30%39%33%20%30%20%30%31%2D%33%2E%37%35%39%20%33%2E%37%34%63%2D%2E%31%34%2E%30%39%31%2D%2E%31%31%37%2E%30%39%2D%31%2E%35%39%2E%30%38%39%2D%31%2E%31%38%37%20%30%2D%31%2E%33%36%36%2D%2E%30%30%34%2D%31%2E%34%33%2D%2E%30%32%37%7A%6D%36%2E%30%32%34%2D%34%2E%36%33%33%61%35%39%32%2E%37%32%33%20%35%39%32%2E%37%32%33%20%30%20%30%30%33%2E%36%36%33%2D%33%2E%36%38%63%30%2D%2E%30%32%2D%31%2E%36%37%2D%31%2E%36%39%2D%31%2E%36%39%2D%31%2E%36%39%2D%2E%30%31%20%30%2D%31%2E%36%36%36%20%31%2E%36%34%38%2D%33%2E%36%38%20%33%2E%36%36%33%4C%2E%39%39%36%20%31%33%2E%32%39%37%76%2E%38%33%34%63%30%20%2E%36%32%37%2E%30%30%35%2E%38%33%39%2E%30%32%2E%38%35%34%2E%30%31%35%2E%30%31%34%2E%32%32%37%2E%30%32%2E%38%35%34%2E%30%32%68%2E%38%33%33%6C%33%2E%36%36%34%2D%33%2E%36%36%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"pointer-inner","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%20%31%34%2E%36%56%33%2E%34%6C%38%2E%32%20%38%2E%32%48%34%6C%2D%33%20%33%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%30%20%31%37%56%31%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%4C%30%20%31%37%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%33%2E%34%76%31%31%2E%32%6C%33%2D%33%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"pointer-move","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'42px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%31%37%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%20%31%2E%32%36%33%20%31%2E%32%36%33%2E%35%32%36%2D%2E%35%32%36%76%31%2E%32%36%33%68%2D%2E%39%34%37%6C%2E%35%32%36%2D%2E%35%32%37%4C%36%2E%32%20%31%37%2E%32%32%32%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%4C%36%2E%32%20%32%32%2E%39%30%37%6C%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%36%2D%2E%35%32%36%68%2E%39%34%37%76%31%2E%34%37%34%6C%2D%2E%35%32%36%2D%2E%36%33%32%2D%31%2E%32%36%33%20%31%2E%33%36%39%20%32%2E%38%34%32%20%32%2E%38%34%32%20%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%37%2E%35%32%37%76%2D%31%2E%34%37%34%68%2E%39%34%38%6C%2D%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%34%20%31%2E%32%36%34%20%32%2E%38%34%32%2D%32%2E%38%34%33%2D%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%34%20%31%2E%32%36%33%2E%35%32%37%2E%35%32%37%68%2D%2E%39%34%38%76%2D%31%2E%32%36%33%6C%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%33%2D%31%2E%32%36%33%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%39%30%37%6C%2D%32%2E%31%30%35%20%32%2E%31%30%35%2E%35%32%36%2E%35%32%36%20%31%2E%30%35%32%2D%31%2E%30%35%33%76%33%2E%30%35%33%48%35%2E%36%37%34%6C%31%2E%30%35%32%2D%31%2E%30%35%33%2D%2E%35%32%36%2D%2E%35%32%36%2D%32%2E%31%30%35%20%32%2E%31%30%35%4C%36%2E%32%20%32%32%2E%31%37%6C%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%32%2D%31%2E%30%35%32%48%38%2E%34%31%76%33%2E%32%36%33%4C%37%2E%33%35%38%20%32%32%2E%38%6C%2D%2E%35%32%36%2E%35%32%37%20%32%2E%31%30%35%20%32%2E%31%30%35%20%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%33%20%31%2E%30%35%33%56%32%30%2E%35%39%48%31%32%2E%32%6C%2D%31%2E%30%35%33%20%31%2E%30%35%32%2E%35%32%37%2E%35%32%37%20%32%2E%31%30%35%2D%32%2E%31%30%36%2D%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%37%2E%35%32%36%20%31%2E%30%35%33%20%31%2E%30%35%33%48%39%2E%34%36%33%76%2D%33%2E%30%35%33%6C%31%2E%30%35%33%20%31%2E%30%35%33%2E%35%32%36%2D%2E%35%32%36%7A%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"pointer-node","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'32px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%39%2E%31%34%33%20%31%39%2E%34%32%39%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%30%30%2D%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%30%30%20%33%2E%32%34%38%7A%6D%33%2E%34%38%39%2D%31%2E%36%32%34%61%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%31%31%2D%36%2E%39%37%38%20%30%20%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%30%31%36%2E%39%37%38%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%31%32%2E%32%31%20%31%37%2E%38%30%35%61%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%31%31%2D%36%2E%31%33%35%20%30%20%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%30%31%36%2E%31%33%35%20%30%7A%6D%2D%31%2E%30%32%32%20%30%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%2D%34%2E%30%39%20%30%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%34%2E%30%39%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"resize-alt","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%2E%35%2E%35%76%34%2E%39%68%2D%31%2E%38%56%33%2E%36%4C%39%2E%32%20%38%6C%34%2E%35%20%34%2E%34%76%2D%31%2E%38%68%31%2E%38%76%34%2E%39%68%2D%34%2E%39%76%2D%31%2E%38%68%31%2E%38%4C%38%20%39%2E%32%6C%2D%34%2E%34%20%34%2E%35%68%31%2E%38%76%31%2E%38%48%2E%35%76%2D%34%2E%39%68%31%2E%38%76%31%2E%38%4C%36%2E%38%20%38%20%32%2E%33%20%33%2E%35%76%32%48%2E%35%76%2D%35%68%34%2E%39%76%31%2E%38%48%33%2E%35%4C%38%20%36%2E%38%6C%34%2E%34%2D%34%2E%35%68%2D%31%2E%38%56%2E%35%68%34%2E%39%7A%6D%2D%31%2E%39%20%31%2E%33%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"zoom","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%34%39%36%34%39%30%35%2C%30%2E%30%33%33%32%31%39%31%31%20%30%2E%30%30%37%34%34%2C%30%2E%30%30%37%34%35%33%34%20%43%20%34%2E%36%39%39%39%39%32%37%2C%30%2E%30%33%31%30%39%32%20%32%2E%39%34%35%30%35%32%32%2C%30%2E%38%33%30%37%34%37%36%34%20%31%2E%37%34%38%36%31%39%36%2C%32%2E%31%36%34%39%31%36%33%20%30%2E%35%36%31%38%32%38%38%38%2C%33%2E%34%32%36%30%30%33%39%20%2D%30%2E%30%34%39%37%31%31%33%35%2C%35%2E%31%35%36%33%33%38%20%30%2E%30%34%31%37%37%31%31%35%2C%36%2E%38%36%38%30%36%36%31%20%30%2E%31%30%32%38%38%36%37%39%2C%38%2E%37%36%30%35%39%39%37%20%31%2E%30%36%33%37%35%33%39%2C%31%30%2E%35%35%36%38%31%34%20%32%2E%35%34%36%31%34%32%36%2C%31%31%2E%37%31%32%38%33%33%20%63%20%30%2E%30%30%31%39%32%2C%30%2E%30%30%31%35%20%30%2E%30%30%35%35%33%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%34%35%2C%30%20%31%2E%32%39%32%32%33%36%35%2C%31%2E%30%32%33%32%35%34%20%32%2E%39%37%36%36%34%30%37%2C%31%2E%35%31%31%32%35%34%20%34%2E%36%31%33%37%30%38%35%2C%31%2E%33%34%39%30%38%31%20%31%2E%31%31%36%31%30%39%34%2C%2D%30%2E%30%37%37%35%33%20%32%2E%31%30%37%31%37%31%35%2C%2D%30%2E%35%38%30%35%31%39%20%33%2E%30%31%31%32%30%38%39%2C%2D%31%2E%31%36%32%37%34%34%20%31%2E%32%39%36%38%37%33%2C%31%2E%31%37%34%38%34%36%20%32%2E%37%38%34%35%35%2C%32%2E%37%30%33%30%36%31%20%33%2E%39%38%30%31%36%32%2C%33%2E%38%30%38%37%33%31%20%6C%20%30%2E%30%32%39%38%2C%30%2E%30%32%32%33%36%20%30%2E%30%33%37%32%38%2C%30%2E%30%32%32%33%36%20%63%20%30%2E%37%30%30%37%31%35%2C%30%2E%34%36%33%35%38%38%20%31%2E%36%35%37%32%34%33%2C%2D%30%2E%30%31%33%30%34%20%31%2E%36%39%39%33%38%38%2C%2D%30%2E%38%35%37%31%35%36%20%30%2E%30%32%38%33%38%2C%2D%30%2E%33%35%32%32%31%37%20%2D%30%2E%31%33%36%30%33%32%2C%2D%30%2E%36%35%39%31%39%39%20%2D%30%2E%32%39%30%36%38%36%2C%2D%30%2E%38%34%32%32%34%33%20%2D%30%2E%31%35%38%37%34%35%2C%2D%30%2E%31%38%37%38%38%38%20%2D%30%2E%33%30%38%36%35%31%2C%2D%30%2E%33%31%32%33%34%31%20%2D%30%2E%33%37%32%36%37%34%2C%2D%30%2E%33%38%37%35%38%32%20%6C%20%2D%30%2E%30%30%37%34%2C%2D%30%2E%30%30%37%34%20%2D%30%2E%30%31%34%39%32%2C%2D%30%2E%30%31%34%39%32%20%43%20%31%34%2E%31%31%36%32%34%2C%31%32%2E%34%37%37%39%34%20%31%32%2E%39%37%30%32%32%35%2C%31%31%2E%33%35%32%31%39%36%20%31%31%2E%38%34%30%36%34%2C%31%30%2E%32%31%34%36%38%32%20%31%32%2E%35%32%37%35%39%35%2C%39%2E%31%37%36%30%30%33%37%20%31%33%2E%30%39%39%38%31%36%2C%38%2E%30%31%30%31%30%38%37%20%31%33%2E%31%30%30%32%38%2C%36%2E%37%32%36%34%35%30%31%20%31%33%2E%31%33%34%36%33%31%2C%35%2E%36%35%32%31%33%37%32%20%31%32%2E%39%30%37%35%31%39%2C%34%2E%35%36%30%30%35%36%20%31%32%2E%33%39%39%36%35%32%2C%33%2E%35%39%35%39%38%35%37%20%31%31%2E%34%31%35%30%31%31%2C%31%2E%36%35%37%39%31%30%34%20%39%2E%34%34%35%37%33%33%38%2C%30%2E%32%36%30%36%33%30%36%39%20%37%2E%32%35%36%37%34%35%39%2C%30%2E%30%36%33%30%33%33%30%35%20%68%20%2D%30%2E%30%30%37%34%34%20%43%20%37%2E%31%37%30%32%35%31%2C%30%2E%30%35%35%34%37%31%39%37%20%37%2E%30%38%39%38%36%30%34%2C%30%2E%30%36%30%32%39%31%31%36%20%37%2E%30%31%30%37%38%31%2C%30%2E%30%35%35%35%37%39%35%38%20%56%20%30%2E%30%33%33%32%31%39%31%31%20%48%20%36%2E%35%31%31%33%39%37%33%20%63%20%2D%30%2E%30%30%34%39%32%2C%36%2E%30%39%38%65%2D%35%20%2D%30%2E%30%31%2C%2D%37%2E%31%31%34%65%2D%35%20%2D%30%2E%30%31%34%39%32%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%34%34%2C%31%2E%30%30%36%32%32%30%36%39%20%68%20%30%2E%30%30%37%34%34%20%63%20%30%2E%32%31%35%37%36%33%33%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%35%33%32%39%34%2C%30%2E%30%30%39%31%38%20%30%2E%36%34%38%34%35%33%35%2C%30%2E%30%32%39%38%31%36%20%31%2E%38%31%33%36%36%31%34%2C%30%2E%31%36%31%37%32%31%31%20%33%2E%35%31%32%31%33%38%2C%31%2E%33%36%33%34%33%36%39%20%34%2E%33%33%37%39%32%39%2C%32%2E%39%38%38%38%34%38%20%68%20%30%2E%30%30%37%34%20%76%20%30%2E%30%30%37%34%34%20%63%20%30%2E%34%32%33%30%35%35%2C%30%2E%38%30%30%35%33%34%32%20%30%2E%36%32%30%31%39%32%2C%31%2E%37%32%31%38%30%32%35%20%30%2E%35%38%38%38%36%31%2C%32%2E%36%33%38%35%34%34%34%20%6C%20%2D%30%2E%30%30%37%34%2C%30%2E%30%30%37%34%34%20%76%20%30%2E%30%30%37%34%34%20%43%20%31%32%2E%30%38%37%31%35%35%2C%37%2E%32%39%33%30%35%35%36%20%31%31%2E%36%39%36%35%35%36%2C%37%2E%37%38%38%30%31%35%35%20%31%31%2E%34%39%37%37%38%2C%38%2E%33%33%36%34%30%33%32%20%31%31%2E%39%35%39%30%37%33%2C%37%2E%30%35%32%39%34%34%32%20%31%31%2E%39%35%34%36%34%38%2C%35%2E%36%31%31%36%30%30%35%20%31%31%2E%33%37%38%35%32%34%2C%34%2E%33%37%31%31%34%38%34%20%31%30%2E%35%36%36%30%35%32%2C%32%2E%35%35%36%33%39%35%35%20%38%2E%36%39%39%37%34%30%39%2C%31%2E%32%38%37%32%38%32%38%20%36%2E%36%39%30%32%38%31%2C%31%2E%32%38%35%34%30%34%39%20%63%20%2D%30%2E%30%31%36%34%34%38%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%34%35%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%32%38%34%2C%30%20%43%20%35%2E%36%38%33%35%30%30%36%2C%31%2E%32%34%36%39%38%39%39%20%34%2E%38%30%35%34%30%36%37%2C%31%2E%36%38%38%34%39%33%39%20%33%2E%39%38%34%36%36%35%38%2C%32%2E%31%37%32%33%36%39%38%20%34%2E%38%30%35%31%35%39%38%2C%31%2E%36%39%32%34%31%37%36%20%35%2E%35%36%30%36%32%34%2C%31%2E%30%33%32%38%31%34%37%20%36%2E%35%30%33%39%34%34%31%2C%31%2E%30%33%39%34%33%39%38%20%5A%20%6D%20%30%2E%31%30%34%33%36%30%38%2C%31%2E%32%35%32%31%38%35%37%20%68%20%30%2E%30%31%34%39%32%31%20%30%2E%30%30%37%34%34%20%63%20%30%2E%30%32%35%39%38%38%2C%30%20%30%2E%30%34%35%38%38%36%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%35%39%36%32%38%2C%30%20%31%2E%35%37%37%39%34%32%36%2C%30%2E%30%30%31%34%37%20%33%2E%31%32%37%34%36%30%37%2C%31%2E%30%35%33%33%34%20%33%2E%37%37%31%34%36%34%37%2C%32%2E%34%39%36%39%31%38%31%20%76%20%30%2E%30%30%37%34%35%20%63%20%30%2E%34%37%35%33%31%31%2C%31%2E%30%32%33%33%39%37%38%20%30%2E%35%30%39%31%35%36%2C%32%2E%32%36%35%35%39%33%36%20%30%2E%30%39%36%38%39%2C%33%2E%33%31%36%38%30%31%35%20%43%20%31%30%2E%30%30%34%33%39%37%2C%39%2E%35%33%33%30%32%37%36%20%38%2E%36%32%36%32%30%35%37%2C%31%30%2E%36%33%34%34%38%37%20%37%2E%31%31%35%31%33%2C%31%30%2E%38%30%33%35%30%37%20%36%2E%34%33%36%39%35%36%31%2C%31%30%2E%38%37%39%38%35%32%20%35%2E%37%35%32%30%39%34%34%2C%31%30%2E%38%32%39%39%31%38%20%35%2E%31%34%37%34%30%39%35%2C%31%30%2E%35%39%34%38%31%20%68%20%2D%30%2E%30%30%37%34%34%20%6C%20%2D%30%2E%30%31%34%39%32%31%2C%2D%30%2E%30%30%37%34%20%43%20%33%2E%35%31%39%36%39%36%39%2C%31%30%2E%30%34%31%30%32%39%20%32%2E%33%31%37%32%33%33%39%2C%38%2E%33%38%34%35%36%33%31%20%32%2E%33%30%30%31%37%37%36%2C%36%2E%36%38%39%31%38%32%34%20%76%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%43%20%32%2E%32%34%32%32%35%39%35%2C%35%2E%33%34%37%35%38%33%35%20%32%2E%38%39%38%33%39%31%39%2C%33%2E%39%39%37%39%32%36%36%20%33%2E%39%35%34%38%35%31%37%2C%33%2E%31%38%36%30%34%33%39%20%76%20%2D%30%2E%30%30%37%34%35%20%43%20%34%2E%37%30%38%33%33%32%36%2C%32%2E%35%39%30%31%34%20%35%2E%36%36%36%32%34%32%38%2C%32%2E%32%35%34%32%39%38%35%20%36%2E%36%30%38%32%39%32%39%2C%32%2E%32%39%31%36%32%35%35%20%5A%20%4D%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%43%20%32%2E%30%32%32%37%35%31%32%2C%33%2E%35%30%33%31%33%37%32%20%31%2E%32%33%33%35%31%35%36%2C%35%2E%30%37%36%31%32%39%31%20%31%2E%33%30%31%34%31%30%34%2C%36%2E%37%31%31%35%34%33%20%63%20%30%2E%30%32%35%36%31%2C%32%2E%30%36%38%39%30%33%39%20%31%2E%34%35%35%36%36%38%36%2C%33%2E%38%39%33%31%20%33%2E%33%36%38%39%37%36%2C%34%2E%36%35%30%39%37%36%20%43%20%34%2E%31%37%32%37%36%37%37%2C%31%31%2E%31%36%38%37%36%33%20%33%2E%35%38%38%30%32%31%2C%31%31%2E%32%35%32%38%30%37%20%33%2E%31%37%32%32%33%35%35%2C%31%30%2E%39%32%32%37%36%33%20%31%2E%39%32%31%31%31%36%2C%39%2E%39%35%30%33%35%38%34%20%31%2E%31%30%34%34%36%37%34%2C%38%2E%34%30%35%30%36%31%20%31%2E%30%35%35%34%34%35%33%2C%36%2E%38%33%30%37%39%38%38%20%76%20%2D%30%2E%30%30%37%34%35%20%2D%30%2E%30%30%37%34%35%20%43%20%30%2E%39%37%37%30%35%35%31%36%2C%35%2E%33%38%30%30%34%31%36%20%31%2E%34%39%37%38%37%37%33%2C%33%2E%39%30%31%31%36%36%35%20%32%2E%34%38%36%35%31%34%37%2C%32%2E%38%35%30%36%33%37%20%6C%20%30%2E%30%30%37%34%35%2C%2D%30%2E%30%30%37%34%35%20%43%20%32%2E%36%39%32%30%39%38%2C%32%2E%36%32%31%35%32%35%35%20%33%2E%30%35%30%39%35%31%36%2C%32%2E%36%37%31%32%32%34%34%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%5A%20%6D%20%38%2E%31%33%39%32%30%37%32%2C%36%2E%30%35%32%32%33%31%33%20%63%20%2D%30%2E%32%30%37%37%37%34%2C%30%2E%35%31%31%36%32%36%34%20%2D%30%2E%32%31%34%36%32%39%2C%31%2E%30%38%32%30%36%30%39%20%2D%30%2E%35%35%31%35%35%38%2C%31%2E%35%32%37%39%36%34%35%20%6C%20%2D%30%2E%32%36%30%38%37%2C%30%2E%33%35%30%33%31%34%20%30%2E%33%30%35%35%39%32%2C%30%2E%33%31%33%30%34%36%20%63%20%31%2E%32%30%32%31%30%35%2C%31%2E%32%31%35%33%31%33%20%32%2E%34%32%35%35%34%32%2C%32%2E%33%39%36%33%36%38%20%33%2E%36%30%30%30%33%34%2C%33%2E%36%31%34%39%34%31%20%30%2E%31%34%34%30%35%2C%30%2E%31%36%33%37%31%38%20%30%2E%32%38%32%30%31%32%2C%30%2E%32%38%34%33%38%32%20%30%2E%33%35%30%33%31%35%2C%30%2E%33%36%35%32%32%20%30%2E%30%37%32%35%37%2C%30%2E%30%38%35%38%39%20%30%2E%30%36%32%32%38%2C%30%2E%30%38%30%32%37%20%30%2E%30%35%39%36%33%2C%30%2E%31%30%34%33%35%20%76%20%30%2E%30%31%34%39%32%20%30%2E%30%31%34%39%32%20%63%20%2D%36%2E%35%39%65%2D%34%2C%30%2E%30%31%37%32%35%20%2D%30%2E%31%33%31%30%35%35%2C%30%2E%30%37%34%30%37%20%2D%30%2E%31%34%31%36%31%34%2C%30%2E%30%36%37%30%38%20%2D%31%2E%32%31%31%30%37%2C%2D%31%2E%31%32%34%37%35%34%20%2D%32%2E%37%36%37%34%39%34%2C%2D%32%2E%37%34%36%36%30%32%20%2D%34%2E%31%33%36%36%38%39%2C%2D%33%2E%39%36%35%32%38%33%20%4C%20%31%30%2E%33%34%32%34%39%2C%31%30%2E%36%37%36%38%20%31%30%2E%30%31%34%35%33%38%2C%31%30%2E%39%31%35%33%31%31%20%43%20%39%2E%31%33%38%31%38%34%34%2C%31%31%2E%35%34%37%32%33%20%38%2E%31%32%38%32%30%32%2C%31%31%2E%39%39%33%31%36%34%20%37%2E%30%39%32%37%36%39%34%2C%31%32%2E%30%36%33%31%34%37%20%68%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%63%20%2D%30%2E%35%32%39%38%39%31%38%2C%30%2E%30%35%33%39%34%20%2D%30%2E%39%37%39%37%37%37%37%2C%2D%30%2E%33%33%34%30%34%36%20%2D%31%2E%35%30%35%36%32%38%31%2C%2D%30%2E%34%33%39%37%35%36%20%30%2E%35%35%33%33%39%36%38%2C%30%2E%31%30%35%37%34%33%20%31%2E%31%31%31%31%32%35%2C%30%2E%32%34%37%35%32%37%20%31%2E%36%35%34%36%37%33%38%2C%30%2E%31%38%36%33%33%37%20%31%2E%38%38%31%32%39%35%37%2C%2D%30%2E%32%31%30%34%33%32%20%33%2E%34%38%30%35%34%35%39%2C%2D%31%2E%35%34%34%39%31%39%20%34%2E%31%39%36%33%31%32%39%2C%2D%33%2E%32%37%32%30%38%30%35%20%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%36%39%30%36%33%31%20%43%20%34%2E%38%34%39%35%32%30%38%2C%30%2E%35%32%35%32%37%34%30%35%20%33%2E%32%31%38%34%36%38%36%2C%31%2E%32%37%35%31%39%38%31%20%32%2E%31%31%36%38%30%37%38%2C%32%2E%35%30%37%36%38%34%34%20%31%2E%30%32%38%32%36%31%36%2C%33%2E%36%36%34%33%37%37%33%20%30%2E%34%36%32%30%33%33%35%2C%35%2E%32%36%39%39%32%34%39%20%30%2E%35%34%38%30%31%38%33%37%2C%36%2E%38%34%34%38%38%37%34%20%30%2E%36%30%32%30%38%39%35%39%2C%38%2E%35%38%31%32%39%34%33%20%31%2E%34%39%31%39%38%33%32%2C%31%30%2E%32%35%35%39%35%37%20%32%2E%38%36%31%39%37%33%38%2C%31%31%2E%33%32%30%37%35%31%20%63%20%31%2E%31%39%30%34%34%38%36%2C%30%2E%39%34%34%39%35%39%20%32%2E%37%35%37%30%39%31%38%2C%31%2E%34%30%31%31%36%31%20%34%2E%32%36%36%37%32%35%38%2C%31%2E%32%34%37%34%37%37%20%31%2E%31%35%36%34%33%37%33%2C%2D%30%2E%30%37%38%31%36%20%32%2E%32%34%38%31%31%36%39%2C%2D%30%2E%35%37%30%35%36%36%20%33%2E%31%38%31%32%31%31%34%2C%2D%31%2E%32%34%33%34%30%32%20%31%2E%33%36%33%39%38%37%2C%31%2E%32%31%34%30%34%35%20%32%2E%39%35%36%32%32%2C%32%2E%38%36%35%38%30%31%20%34%2E%31%39%33%31%36%31%2C%34%2E%30%30%39%36%39%31%20%30%2E%33%35%37%34%38%35%2C%30%2E%32%33%36%35%31%20%30%2E%39%30%38%35%33%35%2C%2D%30%2E%30%33%34%31%35%20%30%2E%39%32%35%31%35%2C%2D%30%2E%34%36%38%39%38%36%20%30%2E%30%34%32%37%2C%2D%30%2E%33%38%38%32%39%32%20%2D%30%2E%33%33%32%30%38%32%2C%2D%30%2E%36%31%33%33%37%36%20%2D%30%2E%35%35%30%34%36%34%2C%2D%30%2E%38%37%30%30%32%32%20%43%20%31%33%2E%36%39%35%38%30%38%2C%31%32%2E%37%36%39%32%20%31%32%2E%34%37%35%31%36%31%2C%31%31%2E%35%38%31%30%38%31%20%31%31%2E%32%37%37%35%34%35%2C%31%30%2E%33%37%30%33%30%35%20%31%32%2E%30%37%30%31%31%38%2C%39%2E%33%32%31%33%38%37%33%20%31%32%2E%35%39%36%34%32%35%2C%38%2E%30%34%33%30%38%38%36%20%31%32%2E%35%39%35%31%36%31%2C%36%2E%37%32%31%33%34%39%20%31%32%2E%36%32%39%33%30%37%2C%35%2E%37%32%32%32%32%34%35%20%31%32%2E%34%31%38%38%30%31%2C%34%2E%37%31%33%33%32%31%37%20%31%31%2E%39%35%30%39%38%35%2C%33%2E%38%32%38%30%32%34%33%20%31%31%2E%30%34%35%32%38%33%2C%32%2E%30%34%35%33%32%34%38%20%39%2E%32%30%38%33%37%30%31%2C%30%2E%37%34%33%37%37%32%38%35%20%37%2E%32%30%35%37%35%30%33%2C%30%2E%35%36%35%32%30%32%37%31%20%36%2E%39%37%33%31%38%30%31%2C%30%2E%35%34%32%36%38%38%36%33%20%36%2E%37%33%39%33%39%30%37%2C%30%2E%35%33%33%36%38%33%30%35%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%37%30%36%30%31%34%20%5A%20%4D%20%36%2E%36%39%31%35%36%38%32%2C%31%2E%37%38%39%39%33%36%37%20%43%20%38%2E%34%38%36%33%38%36%2C%31%2E%37%39%31%36%31%34%20%31%30%2E%31%39%33%39%35%32%2C%32%2E%39%34%39%37%34%34%20%31%30%2E%39%32%31%34%37%31%2C%34%2E%35%38%30%35%32%36%31%20%31%31%2E%34%35%37%34%38%35%2C%35%2E%37%33%34%36%31%38%37%20%31%31%2E%34%39%35%39%35%38%2C%37%2E%31%31%30%38%36%31%20%31%31%2E%30%33%31%36%37%37%2C%38%2E%32%39%34%37%30%35%37%20%31%30%2E%34%30%37%39%30%33%2C%39%2E%38%39%33%31%30%31%35%20%38%2E%38%38%33%36%36%31%32%2C%31%31%2E%31%31%37%30%32%39%20%37%2E%31%36%39%35%36%32%35%2C%31%31%2E%33%30%38%37%35%38%20%36%2E%34%32%38%39%32%35%37%2C%31%31%2E%33%39%32%31%33%35%20%35%2E%36%36%35%32%39%34%35%2C%31%31%2E%33%33%38%30%32%37%20%34%2E%39%36%35%39%39%37%33%2C%31%31%2E%30%36%36%31%33%32%20%33%2E%31%34%35%33%30%39%32%2C%31%30%2E%34%34%36%35%32%33%20%31%2E%38%31%36%32%30%34%32%2C%38%2E%36%32%31%32%31%39%33%20%31%2E%37%39%36%38%34%32%31%2C%36%2E%36%39%36%36%35%31%31%20%31%2E%37%33%31%32%31%33%37%2C%35%2E%31%39%33%33%34%33%36%20%32%2E%34%35%37%30%34%37%35%2C%33%2E%36%39%37%38%34%30%37%20%33%2E%36%34%35%38%34%38%37%2C%32%2E%37%38%34%32%35%34%35%20%34%2E%34%38%38%36%32%38%34%2C%32%2E%31%32%36%30%36%33%39%20%35%2E%35%35%37%39%30%36%33%2C%31%2E%37%34%37%37%34%39%31%20%36%2E%36%33%31%35%32%35%38%2C%31%2E%37%39%30%32%38%39%34%20%63%20%30%2E%30%31%39%38%38%32%2C%30%20%30%2E%30%34%30%30%33%39%2C%2D%33%2E%36%30%32%65%2D%34%20%30%2E%30%36%30%30%33%36%2C%2D%33%2E%34%38%39%65%2D%34%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"zoom-in","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%31%33%36%34%30%32%2C%30%2E%30%33%33%34%30%32%37%38%20%30%2E%30%30%37%39%32%2C%30%2E%30%30%37%39%30%38%33%20%43%20%34%2E%37%31%33%30%35%39%36%2C%30%2E%30%33%31%37%30%36%33%20%32%2E%39%35%34%33%35%30%35%2C%30%2E%38%33%33%30%35%31%38%35%20%31%2E%37%35%34%39%30%30%31%2C%32%2E%31%37%30%35%38%35%35%20%30%2E%35%36%35%31%31%35%36%36%2C%33%2E%34%33%34%38%35%34%31%20%2D%30%2E%30%34%38%39%33%31%37%39%2C%35%2E%31%36%39%37%38%35%39%20%30%2E%30%34%32%37%38%30%36%39%2C%36%2E%38%38%35%38%33%31%37%20%30%2E%31%30%34%30%35%30%39%33%2C%38%2E%37%38%33%31%33%38%34%20%31%2E%30%36%37%34%39%37%33%2C%31%30%2E%35%38%34%34%39%20%32%2E%35%35%33%36%32%34%37%2C%31%31%2E%37%34%33%34%32%34%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%31%2C%30%20%31%2E%32%39%35%34%39%36%34%2C%31%2E%30%32%35%38%33%36%20%32%2E%39%38%35%30%38%33%34%2C%31%2E%35%31%34%38%38%31%20%34%2E%36%32%36%32%37%39%36%2C%31%2E%33%35%32%32%39%38%20%31%2E%31%31%38%39%32%34%34%2C%2D%30%2E%30%37%37%37%32%20%32%2E%31%31%32%36%32%35%36%2C%2D%30%2E%35%38%32%37%36%32%20%33%2E%30%31%38%39%34%33%37%2C%2D%31%2E%31%36%36%34%35%35%20%31%2E%33%30%30%31%34%35%2C%31%2E%31%37%37%38%30%39%20%32%2E%37%39%31%30%34%34%2C%32%2E%37%30%39%32%30%39%20%33%2E%39%38%39%36%37%31%2C%33%2E%38%31%37%36%36%39%20%6C%20%30%2E%30%32%39%36%35%2C%30%2E%30%32%33%37%32%20%30%2E%30%33%37%35%37%2C%30%2E%30%32%31%37%33%20%63%20%30%2E%37%30%32%34%39%34%2C%30%2E%34%36%34%37%37%39%20%31%2E%36%36%31%39%35%39%2C%2D%30%2E%30%31%33%37%33%20%31%2E%37%30%34%32%31%2C%2D%30%2E%38%35%39%39%39%32%20%30%2E%30%32%38%34%36%2C%2D%30%2E%33%35%33%31%30%37%20%2D%30%2E%31%33%37%35%35%37%2C%2D%30%2E%36%36%30%36%39%31%20%2D%30%2E%32%39%32%36%30%32%2C%2D%30%2E%38%34%34%31%39%37%20%2D%30%2E%31%35%39%31%34%36%2C%2D%30%2E%31%38%38%33%36%20%2D%30%2E%33%30%39%34%37%37%2C%2D%30%2E%33%31%32%30%36%38%20%2D%30%2E%33%37%33%36%36%33%2C%2D%30%2E%33%38%37%35%30%31%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%35%2C%2D%30%2E%30%31%35%38%20%43%20%31%34%2E%31%35%33%38%32%36%2C%31%32%2E%35%30%38%36%38%39%20%31%33%2E%30%30%33%38%36%2C%31%31%2E%33%38%31%32%35%36%20%31%31%2E%38%37%31%34%32%35%2C%31%30%2E%32%34%30%38%37%33%20%31%32%2E%35%36%30%31%31%33%2C%39%2E%31%39%39%35%37%34%34%20%31%33%2E%31%33%34%32%39%2C%38%2E%30%33%30%33%38%30%37%20%31%33%2E%31%33%34%37%35%35%2C%36%2E%37%34%33%34%38%34%34%20%31%33%2E%31%36%39%31%39%33%2C%35%2E%36%36%36%34%36%31%38%20%31%32%2E%39%34%32%30%35%33%2C%34%2E%35%37%32%34%32%30%37%20%31%32%2E%34%33%32%39%30%36%2C%33%2E%36%30%35%39%31%38%32%20%31%31%2E%34%34%35%37%38%31%2C%31%2E%36%36%32%39%35%34%39%20%39%2E%34%37%31%32%38%37%35%2C%30%2E%32%36%31%31%35%34%34%36%20%37%2E%32%37%36%37%37%39%32%2C%30%2E%30%36%33%30%35%38%34%33%20%68%20%2D%30%2E%30%30%37%39%32%20%43%20%37%2E%31%38%39%36%31%38%31%2C%30%2E%30%35%35%34%37%38%32%38%20%37%2E%31%30%38%39%32%37%39%2C%30%2E%30%35%39%38%37%33%37%31%20%37%2E%30%32%39%36%34%38%37%2C%30%2E%30%35%35%31%35%30%32%35%20%56%20%30%2E%30%33%33%34%30%32%37%38%20%48%20%36%2E%35%32%39%34%35%36%35%20%63%20%2D%30%2E%30%30%34%39%34%2C%36%2E%31%31%37%65%2D%35%20%2D%30%2E%30%31%30%38%36%35%2C%2D%37%2E%31%33%32%65%2D%35%20%2D%30%2E%30%31%35%38%30%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%32%2C%31%2E%30%30%38%32%39%31%36%32%20%68%20%30%2E%30%30%37%39%32%20%63%20%30%2E%32%31%36%33%30%37%35%2C%2D%30%2E%30%30%33%31%33%20%30%2E%34%33%36%37%38%36%33%2C%30%2E%30%30%38%39%37%20%30%2E%36%35%30%34%34%36%37%2C%30%2E%30%32%39%36%35%34%20%31%2E%38%31%38%32%33%36%34%2C%30%2E%31%36%32%31%32%39%20%33%2E%35%31%39%36%34%32%31%2C%31%2E%33%36%37%36%38%35%32%20%34%2E%33%34%37%35%31%36%31%2C%32%2E%39%39%37%31%39%36%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%32%34%31%32%31%2C%30%2E%38%30%32%35%35%33%33%20%30%2E%36%32%32%35%34%35%2C%31%2E%37%32%36%32%32%38%33%20%30%2E%35%39%31%31%33%35%2C%32%2E%36%34%35%32%38%32%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%33%20%76%20%30%2E%30%30%37%39%32%20%43%20%31%32%2E%31%31%39%30%39%36%2C%37%2E%33%31%31%31%30%38%36%20%31%31%2E%37%32%38%36%37%35%2C%37%2E%38%30%36%39%38%31%35%20%31%31%2E%35%32%39%33%39%39%2C%38%2E%33%35%36%37%35%32%34%20%31%31%2E%39%39%31%38%35%34%2C%37%2E%30%37%30%30%35%36%31%20%31%31%2E%39%38%36%33%37%35%2C%35%2E%36%32%36%34%37%38%20%31%31%2E%34%30%38%37%39%39%2C%34%2E%33%38%32%38%39%37%31%20%31%30%2E%35%39%34%32%37%36%2C%32%2E%35%36%33%35%36%35%37%20%38%2E%37%32%33%38%39%35%39%2C%31%2E%32%39%30%37%30%37%33%20%36%2E%37%30%39%33%36%37%39%2C%31%2E%32%38%38%38%32%34%37%20%63%20%2D%30%2E%30%31%36%34%38%39%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%39%30%31%2C%2D%31%2E%30%36%36%65%2D%34%20%2D%30%2E%30%33%37%35%37%2C%30%20%43%20%35%2E%36%39%39%38%36%32%34%2C%31%2E%32%35%30%33%31%32%35%20%34%2E%38%31%39%36%37%36%35%2C%31%2E%36%39%33%33%39%37%34%20%33%2E%39%39%36%38%36%35%36%2C%32%2E%31%37%38%34%39%33%38%20%34%2E%38%31%39%34%32%39%34%2C%31%2E%36%39%37%33%33%31%20%35%2E%35%37%35%38%34%39%31%2C%31%2E%30%33%35%30%35%32%36%20%36%2E%35%32%31%35%34%38%39%2C%31%2E%30%34%31%36%39%34%34%20%5A%20%6D%20%2D%30%2E%30%37%33%31%34%39%2C%31%2E%32%35%33%34%34%34%38%20%63%20%30%2E%30%35%39%30%39%37%2C%2D%35%2E%35%34%34%65%2D%34%20%30%2E%31%31%38%39%30%36%32%2C%2D%33%2E%36%31%37%65%2D%34%20%30%2E%31%37%37%39%33%34%36%2C%30%2E%30%30%31%39%38%20%68%20%30%2E%30%31%35%38%30%31%20%30%2E%30%30%35%39%33%20%63%20%30%2E%30%32%36%30%35%34%2C%30%20%30%2E%30%34%37%35%31%33%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%36%31%32%38%39%2C%30%20%31%2E%35%38%31%39%32%32%36%2C%30%2E%30%30%31%34%38%20%33%2E%31%33%34%34%37%36%36%2C%31%2E%30%35%35%37%31%36%33%20%33%2E%37%38%30%31%30%35%32%2C%32%2E%35%30%32%39%33%35%37%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%37%36%35%31%2C%31%2E%30%32%35%39%37%39%31%20%30%2E%35%31%30%31%37%38%2C%32%2E%32%37%31%35%32%36%20%30%2E%30%39%36%38%37%2C%33%2E%33%32%35%33%38%35%33%20%2D%30%2E%35%35%35%36%34%2C%31%2E%34%32%33%38%31%39%36%20%2D%31%2E%39%33%37%30%32%37%2C%32%2E%35%32%37%32%33%35%38%20%2D%33%2E%34%35%31%39%31%33%33%2C%32%2E%36%39%36%36%38%32%38%20%2D%30%2E%36%37%39%38%38%34%38%2C%30%2E%30%37%36%35%33%20%2D%31%2E%33%36%36%38%37%38%37%2C%30%2E%30%32%38%31%32%20%2D%31%2E%39%37%33%30%38%38%37%2C%2D%30%2E%32%30%37%35%38%39%20%68%20%2D%30%2E%30%30%35%39%33%20%6C%20%2D%30%2E%30%31%35%38%30%31%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%33%30%31%39%36%39%2C%31%30%2E%30%36%36%38%31%36%20%32%2E%33%32%35%35%37%30%39%2C%38%2E%34%30%35%35%37%37%36%20%32%2E%33%30%38%34%37%31%2C%36%2E%37%30%35%39%32%30%37%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%35%39%33%20%43%20%32%2E%32%35%30%34%30%37%36%2C%35%2E%33%36%32%30%31%39%34%20%32%2E%39%30%38%30%38%34%38%2C%34%2E%30%30%38%36%32%34%31%20%33%2E%39%36%37%32%30%39%38%2C%33%2E%31%39%34%36%39%33%35%20%76%20%2D%30%2E%30%30%37%39%31%20%43%20%34%2E%36%37%35%33%37%39%39%2C%32%2E%36%33%33%37%32%31%31%20%35%2E%35%36%31%39%34%34%32%2C%32%2E%33%30%33%34%35%35%33%20%36%2E%34%34%38%33%39%37%39%2C%32%2E%32%39%35%31%33%39%32%20%5A%20%4D%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%43%20%32%2E%30%32%38%35%37%30%39%2C%33%2E%35%31%31%31%35%34%34%20%31%2E%32%33%38%30%34%35%35%2C%35%2E%30%38%38%31%32%39%33%20%31%2E%33%30%36%31%31%30%39%2C%36%2E%37%32%37%36%36%38%31%20%31%2E%33%33%31%37%38%35%35%2C%38%2E%38%30%31%37%39%30%34%20%32%2E%37%36%34%37%36%36%2C%31%30%2E%36%33%31%37%32%34%20%34%2E%36%38%32%38%39%39%36%2C%31%31%2E%33%39%31%35%31%31%20%34%2E%31%38%34%30%32%35%37%2C%31%31%2E%31%39%37%32%36%37%20%33%2E%35%39%39%31%35%38%31%2C%31%31%2E%32%38%31%35%30%37%20%33%2E%31%38%32%33%32%34%35%2C%31%30%2E%39%35%30%36%33%20%31%2E%39%32%38%30%34%38%38%2C%39%2E%39%37%35%37%37%32%39%20%31%2E%31%30%38%31%32%36%38%2C%38%2E%34%32%36%35%30%30%36%20%31%2E%30%35%38%39%38%31%32%2C%36%2E%38%34%38%32%36%37%36%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%30%2E%39%38%30%33%39%30%34%38%2C%35%2E%33%39%32%39%37%39%34%20%31%2E%35%30%33%31%38%33%2C%33%2E%39%31%31%37%37%35%36%20%32%2E%34%39%34%33%31%33%32%2C%32%2E%38%35%38%35%39%36%34%20%6C%20%30%2E%30%30%37%39%31%2C%2D%30%2E%30%30%37%39%31%20%43%20%32%2E%37%30%30%38%34%39%38%2C%32%2E%36%32%38%34%37%30%35%20%33%2E%30%35%39%33%36%35%2C%32%2E%36%37%37%31%34%33%32%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%5A%20%4D%20%35%2E%35%31%33%32%35%36%39%2C%33%2E%33%34%32%39%37%31%37%20%56%20%33%2E%38%34%35%31%34%30%33%20%35%2E%34%38%38%30%36%32%37%20%48%20%33%2E%33%36%38%31%36%36%37%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%35%2E%35%31%33%32%35%36%39%20%56%20%39%2E%37%39%39%39%39%31%38%20%48%20%37%2E%36%38%38%30%30%34%31%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%39%2E%38%33%33%30%39%34%34%20%56%20%35%2E%34%38%38%30%36%32%37%20%48%20%37%2E%36%38%38%30%30%34%31%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%20%6D%20%31%2E%30%31%36%31%39%39%36%2C%31%2E%30%31%30%32%36%38%34%20%68%20%30%2E%31%34%32%33%34%36%39%20%76%20%32%2E%31%34%33%31%31%34%32%20%68%20%32%2E%31%34%35%30%39%31%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%36%2E%36%37%31%38%30%33%38%20%56%20%38%2E%37%39%31%37%30%30%36%20%48%20%36%2E%35%32%39%34%35%36%35%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%34%2E%33%38%34%33%36%36%32%20%56%20%36%2E%34%39%36%33%35%34%33%20%48%20%36%2E%35%32%39%34%35%36%35%20%5A%20%4D%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%43%20%31%31%2E%32%34%35%39%37%33%2C%39%2E%30%37%31%33%32%36%20%31%31%2E%32%33%38%34%37%35%2C%39%2E%36%34%33%35%38%38%38%20%31%30%2E%39%30%30%36%39%38%2C%31%30%2E%30%39%30%36%31%37%20%6C%20%2D%30%2E%32%36%30%39%37%2C%30%2E%33%35%31%39%31%34%20%30%2E%33%30%36%34%34%33%2C%30%2E%33%31%34%33%34%37%20%63%20%31%2E%32%30%35%31%33%37%2C%31%2E%32%31%38%33%37%39%20%32%2E%34%33%30%36%34%37%2C%32%2E%34%30%32%32%37%32%20%33%2E%36%30%38%31%30%32%2C%33%2E%36%32%33%39%31%39%20%30%2E%31%34%34%34%31%33%2C%30%2E%31%36%34%31%33%31%20%30%2E%32%38%33%34%33%39%2C%30%2E%32%38%34%37%31%33%20%30%2E%33%35%31%39%31%34%2C%30%2E%33%36%35%37%35%31%20%30%2E%30%37%32%37%35%2C%30%2E%30%38%36%31%20%30%2E%30%36%31%39%37%2C%30%2E%30%38%30%36%34%20%30%2E%30%35%39%33%31%2C%30%2E%31%30%34%37%38%35%20%76%20%30%2E%30%31%33%38%35%20%30%2E%30%31%35%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%39%20%2D%30%2E%31%33%31%37%36%31%2C%30%2E%30%37%34%32%33%20%2D%30%2E%31%34%32%33%34%37%2C%30%2E%30%36%37%32%32%20%2D%31%2E%32%31%34%31%32%35%2C%2D%31%2E%31%32%37%35%38%34%20%2D%32%2E%37%37%33%32%31%31%2C%2D%32%2E%37%35%34%30%37%20%2D%34%2E%31%34%35%38%35%39%2C%2D%33%2E%39%37%35%38%32%34%20%6C%20%2D%30%2E%33%30%36%34%34%33%2C%2D%30%2E%32%36%38%38%37%38%20%2D%30%2E%33%33%30%31%36%38%2C%30%2E%32%33%39%32%32%20%63%20%2D%30%2E%38%37%38%35%36%31%39%2C%30%2E%36%33%33%35%31%34%20%2D%31%2E%38%38%39%39%35%32%2C%31%2E%30%38%30%34%38%31%20%2D%32%2E%39%32%37%39%39%36%39%2C%31%2E%31%35%30%36%34%31%20%68%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%36%2E%35%36%35%36%33%39%35%2C%31%32%2E%31%34%37%34%33%39%20%36%2E%31%31%35%35%36%31%35%2C%31%31%2E%37%35%38%34%35%37%20%35%2E%35%38%38%33%38%34%37%2C%31%31%2E%36%35%32%34%38%31%20%36%2E%31%34%33%31%37%37%34%2C%31%31%2E%37%35%38%34%39%20%36%2E%37%30%32%32%30%33%33%2C%31%31%2E%39%30%31%36%34%35%20%37%2E%32%34%37%31%32%33%34%2C%31%31%2E%38%34%30%33%30%32%20%39%2E%31%33%33%31%36%33%39%2C%31%31%2E%36%32%39%33%33%39%20%31%30%2E%37%33%36%36%39%37%2C%31%30%2E%32%38%39%39%32%39%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%5A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%43%20%34%2E%38%35%37%38%35%32%37%2C%30%2E%35%33%30%35%30%31%31%36%20%33%2E%32%32%33%38%31%38%31%2C%31%2E%32%38%33%36%31%30%32%20%32%2E%31%31%39%33%37%39%31%2C%32%2E%35%31%39%32%30%35%31%20%31%2E%30%32%38%30%38%37%32%2C%33%2E%36%37%38%38%31%35%34%20%30%2E%34%35%39%34%35%32%30%35%2C%35%2E%32%38%37%37%38%36%35%20%30%2E%35%34%35%36%35%32%38%38%2C%36%2E%38%36%36%37%32%31%34%20%30%2E%35%39%39%38%36%31%36%37%2C%38%2E%36%30%37%35%30%38%31%20%31%2E%34%39%31%32%37%37%36%2C%31%30%2E%32%38%37%31%32%38%20%32%2E%38%36%34%37%32%33%39%2C%31%31%2E%33%35%34%36%30%38%20%63%20%31%2E%31%39%33%34%35%31%2C%30%2E%39%34%37%33%34%32%20%32%2E%37%36%34%38%37%38%32%2C%31%2E%34%30%33%35%36%32%20%34%2E%32%37%38%33%31%39%31%2C%31%2E%32%34%39%34%39%31%20%31%2E%31%35%39%33%35%34%35%2C%2D%30%2E%30%37%38%33%36%20%32%2E%32%35%33%35%32%32%32%2C%2D%30%2E%35%37%31%30%30%34%20%33%2E%31%38%38%39%37%2C%2D%31%2E%32%34%35%35%33%37%20%31%2E%33%36%37%34%32%37%2C%31%2E%32%31%37%31%30%37%20%32%2E%39%36%33%31%33%32%2C%32%2E%38%37%32%35%35%32%20%34%2E%32%30%33%31%39%32%2C%34%2E%30%31%39%33%32%37%20%30%2E%33%35%38%33%38%37%2C%30%2E%32%33%37%31%30%34%20%30%2E%39%31%32%35%35%33%2C%2D%30%2E%30%33%34%35%38%20%30%2E%39%32%39%32%31%2C%2D%30%2E%34%37%30%35%33%37%20%30%2E%30%34%32%38%31%2C%2D%30%2E%33%38%39%32%37%31%20%2D%30%2E%33%33%34%36%33%39%2C%2D%30%2E%36%31%34%35%38%33%20%2D%30%2E%35%35%33%35%37%31%2C%2D%30%2E%38%37%31%38%37%35%20%43%20%31%33%2E%37%32%35%39%31%33%2C%31%32%2E%38%30%36%30%37%34%20%31%32%2E%35%30%33%33%37%37%2C%31%31%2E%36%31%35%35%30%32%20%31%31%2E%33%30%32%37%34%31%2C%31%30%2E%34%30%31%36%37%33%20%31%32%2E%30%39%37%33%31%33%2C%39%2E%33%35%30%31%30%39%34%20%31%32%2E%36%32%34%36%37%34%2C%38%2E%30%36%37%32%34%30%39%20%31%32%2E%36%32%33%34%30%35%2C%36%2E%37%34%32%31%36%37%36%20%31%32%2E%36%35%37%36%33%37%2C%35%2E%37%34%30%35%32%32%39%20%31%32%2E%34%34%35%39%30%38%2C%34%2E%37%32%39%33%37%36%39%20%31%31%2E%39%37%36%39%31%32%2C%33%2E%38%34%31%38%34%36%36%20%31%31%2E%30%36%38%39%32%36%2C%32%2E%30%35%34%36%35%30%34%20%39%2E%32%32%37%38%31%38%36%2C%30%2E%37%35%30%38%33%38%39%33%20%37%2E%32%32%30%31%34%38%2C%30%2E%35%37%31%38%31%38%33%39%20%36%2E%39%38%36%39%39%31%37%2C%30%2E%35%34%39%32%34%36%31%31%20%36%2E%37%35%32%34%38%39%34%2C%30%2E%35%33%38%37%38%32%35%31%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%5A%20%4D%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%63%20%30%2E%30%36%37%31%38%31%2C%2D%35%2E%39%36%33%65%2D%34%20%30%2E%31%33%34%33%38%39%32%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%36%35%38%35%2C%30%2E%30%30%33%39%36%20%30%2E%30%31%39%39%33%32%2C%30%20%30%2E%30%33%39%32%36%34%2C%2D%31%2E%31%33%65%2D%35%20%30%2E%30%35%39%33%31%31%2C%30%20%31%2E%37%39%39%33%34%34%39%2C%30%2E%30%30%31%36%38%20%33%2E%35%31%31%34%30%33%32%2C%31%2E%31%36%32%36%31%39%34%20%34%2E%32%34%30%37%35%36%32%2C%32%2E%37%39%37%35%31%35%20%30%2E%35%33%37%33%36%36%2C%31%2E%31%35%37%30%30%33%35%20%30%2E%35%37%36%31%36%36%2C%32%2E%35%33%35%39%34%20%30%2E%31%31%30%37%31%35%2C%33%2E%37%32%32%37%37%31%31%20%43%20%31%30%2E%34%33%30%32%36%34%2C%39%2E%39%32%32%32%37%35%20%38%2E%39%30%32%39%38%34%2C%31%31%2E%31%35%30%35%33%32%20%37%2E%31%38%34%35%36%31%35%2C%31%31%2E%33%34%32%37%34%35%20%36%2E%34%34%32%30%35%37%2C%31%31%2E%34%32%36%33%33%33%20%35%2E%36%37%35%32%38%38%38%2C%31%31%2E%33%37%32%31%35%20%34%2E%39%37%34%32%32%37%38%2C%31%31%2E%30%39%39%35%37%20%33%2E%31%34%38%39%34%37%33%2C%31%30%2E%34%37%38%33%39%38%20%31%2E%38%31%36%35%33%32%34%2C%38%2E%36%34%37%38%36%35%34%20%31%2E%37%39%37%31%32%30%36%2C%36%2E%37%31%38%34%34%33%33%20%31%2E%37%33%31%33%32%37%36%2C%35%2E%32%31%31%33%34%34%31%20%32%2E%34%35%39%37%38%37%32%2C%33%2E%37%31%31%38%38%31%35%20%33%2E%36%35%31%35%38%37%31%2C%32%2E%37%39%35%39%39%31%31%20%34%2E%34%34%33%36%38%35%34%2C%32%2E%31%37%37%33%38%31%20%35%2E%34%33%35%34%33%39%32%2C%31%2E%38%30%34%35%35%31%33%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%5A%20%4D%20%36%2E%30%31%36%31%32%39%31%2C%33%2E%38%35%31%37%33%31%38%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%33%2E%38%37%31%30%33%38%39%20%76%20%31%2E%31%35%36%35%36%39%37%20%68%20%32%2E%31%34%35%30%39%30%32%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%37%2E%31%37%32%36%39%38%38%20%56%20%37%2E%31%35%33%33%39%32%35%20%48%20%39%2E%33%31%37%37%39%30%32%20%56%20%35%2E%39%39%36%38%32%32%38%20%48%20%37%2E%31%37%32%36%39%38%38%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"zoom-out","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%30%33%35%37%30%34%2C%30%2E%30%33%33%34%30%34%35%36%20%30%2E%30%30%37%39%31%2C%30%2E%30%30%37%38%39%35%37%20%43%20%34%2E%37%30%35%38%36%31%34%2C%30%2E%30%33%31%37%31%30%37%35%20%32%2E%39%34%39%39%35%31%35%2C%30%2E%38%33%31%37%37%39%31%36%20%31%2E%37%35%32%34%31%33%38%2C%32%2E%31%36%37%31%38%31%31%20%30%2E%35%36%34%35%32%35%35%39%2C%33%2E%34%32%39%34%33%34%37%20%2D%30%2E%30%34%38%35%34%32%32%31%2C%35%2E%31%36%31%36%30%31%33%20%30%2E%30%34%33%30%32%34%31%31%2C%36%2E%38%37%34%39%31%32%31%20%30%2E%31%30%34%31%37%37%34%38%2C%38%2E%37%36%39%31%39%34%39%20%31%2E%30%36%36%31%30%36%35%2C%31%30%2E%35%36%37%36%37%35%20%32%2E%35%34%39%38%36%36%34%2C%31%31%2E%37%32%34%37%36%32%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%33%37%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%2C%30%20%31%2E%32%39%33%34%33%30%34%2C%31%2E%30%32%34%32%30%32%20%32%2E%39%37%38%33%34%36%37%2C%31%2E%35%31%32%34%36%37%20%34%2E%36%31%36%39%33%31%34%2C%31%2E%33%35%30%31%34%33%20%31%2E%31%31%37%31%34%2C%2D%30%2E%30%37%37%36%20%32%2E%31%30%39%32%36%31%36%2C%2D%30%2E%35%38%31%38%33%33%20%33%2E%30%31%34%31%33%33%32%2C%2D%31%2E%31%36%34%35%39%36%20%31%2E%32%39%38%30%37%31%2C%31%2E%31%37%35%39%33%32%20%32%2E%37%38%38%35%37%2C%32%2E%37%30%34%38%39%31%20%33%2E%39%38%35%32%38%36%2C%33%2E%38%31%31%35%38%34%20%6C%20%30%2E%30%32%39%36%2C%30%2E%30%32%33%36%38%20%30%2E%30%33%37%35%31%2C%30%2E%30%32%31%37%20%63%20%30%2E%37%30%31%33%37%32%2C%30%2E%34%36%34%30%31%37%20%31%2E%36%35%37%33%34%2C%2D%30%2E%30%31%33%37%35%20%31%2E%36%39%39%35%32%31%2C%2D%30%2E%38%35%38%36%34%33%20%30%2E%30%32%38%32%37%2C%2D%30%2E%33%35%32%35%34%34%20%2D%30%2E%31%33%35%33%38%36%2C%2D%30%2E%36%35%39%36%33%38%20%2D%30%2E%32%39%30%31%36%31%2C%2D%30%2E%38%34%32%38%35%31%20%2D%30%2E%31%35%38%39%2C%2D%30%2E%31%38%38%30%36%20%2D%30%2E%33%30%38%39%37%32%2C%2D%30%2E%33%31%31%35%37%20%2D%30%2E%33%37%33%30%36%37%2C%2D%30%2E%33%38%36%38%38%33%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%33%2C%2D%30%2E%30%31%35%37%38%20%43%20%31%34%2E%31%33%31%32%38%32%2C%31%32%2E%34%38%38%38%30%38%20%31%32%2E%39%38%33%34%34%34%2C%31%31%2E%33%36%33%31%37%32%20%31%31%2E%38%35%32%38%31%36%2C%31%30%2E%32%32%34%36%30%36%20%31%32%2E%35%34%30%34%30%37%2C%39%2E%31%38%34%39%36%37%32%20%31%33%2E%31%31%33%36%37%31%2C%38%2E%30%31%37%36%33%37%20%31%33%2E%31%31%34%31%33%33%2C%36%2E%37%33%32%37%39%31%37%20%31%33%2E%31%34%38%35%31%38%2C%35%2E%36%35%37%34%38%35%36%20%31%32%2E%39%32%31%37%34%2C%34%2E%35%36%35%31%38%38%32%20%31%32%2E%34%31%33%34%30%32%2C%33%2E%36%30%30%32%32%36%31%20%31%31%2E%34%32%37%38%35%2C%31%2E%36%36%30%33%35%39%35%20%39%2E%34%35%36%35%30%33%2C%30%2E%32%36%30%37%39%33%32%36%20%37%2E%32%36%35%34%39%33%31%2C%30%2E%30%36%33%30%31%32%39%35%20%68%20%2D%30%2E%30%30%37%39%31%20%43%20%37%2E%31%37%38%34%39%31%31%2C%30%2E%30%35%35%34%34%34%39%36%20%37%2E%30%39%37%39%30%31%33%2C%30%2E%30%35%39%38%33%33%32%33%20%37%2E%30%31%38%37%35%36%35%2C%30%2E%30%35%35%31%31%37%33%38%20%56%20%30%2E%30%33%33%34%30%34%35%36%20%68%20%2D%30%2E%34%39%39%33%39%35%20%63%20%2D%30%2E%30%30%34%39%37%2C%36%2E%31%30%38%65%2D%35%20%2D%30%2E%30%31%30%38%31%2C%2D%37%2E%31%32%65%2D%35%20%2D%30%2E%30%31%35%37%37%35%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%31%2C%31%2E%30%30%36%36%38%34%36%34%20%68%20%30%2E%30%30%37%39%31%20%63%20%30%2E%32%31%35%39%36%36%36%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%36%30%39%30%39%2C%30%2E%30%30%38%39%35%20%30%2E%36%34%39%34%31%31%32%2C%30%2E%30%32%39%36%30%37%20%31%2E%38%31%35%33%33%37%33%2C%30%2E%31%36%31%38%37%30%36%20%33%2E%35%31%34%30%33%31%34%2C%31%2E%33%36%35%35%30%35%34%20%34%2E%33%34%30%35%38%35%34%2C%32%2E%39%39%32%34%31%39%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%32%33%34%34%36%2C%30%2E%38%30%31%32%37%34%32%20%30%2E%36%32%31%35%35%33%2C%31%2E%37%32%33%34%37%37%31%20%30%2E%35%39%30%31%39%33%2C%32%2E%36%34%31%30%36%36%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%32%20%76%20%30%2E%30%30%37%39%31%20%43%20%31%32%2E%31%30%30%30%39%32%2C%37%2E%32%39%39%35%30%39%39%20%31%31%2E%37%30%38%33%32%2C%37%2E%37%39%34%35%39%32%35%20%31%31%2E%35%30%39%33%35%39%2C%38%2E%33%34%33%34%38%37%31%20%31%31%2E%39%37%31%30%37%39%2C%37%2E%30%35%38%38%34%31%36%20%31%31%2E%39%36%37%35%38%34%2C%35%2E%36%31%37%35%36%34%32%20%31%31%2E%33%39%30%39%32%36%2C%34%2E%33%37%35%39%36%35%34%20%31%30%2E%35%37%37%37%30%36%2C%32%2E%35%35%39%35%33%35%20%38%2E%37%31%30%33%30%31%35%2C%31%2E%32%38%38%37%30%35%32%20%36%2E%36%39%38%39%38%36%31%2C%31%2E%32%38%36%38%32%35%36%20%63%20%2D%30%2E%30%31%36%34%32%35%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%36%38%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%35%30%39%2C%30%20%43%20%35%2E%36%39%31%30%38%37%36%2C%31%2E%32%34%38%33%37%34%39%20%34%2E%38%31%32%33%30%38%34%2C%31%2E%36%39%30%37%35%33%35%20%33%2E%39%39%30%38%30%37%2C%32%2E%31%37%35%30%37%36%38%20%34%2E%38%31%32%30%36%30%39%2C%31%2E%36%39%34%36%38%30%39%20%35%2E%35%36%37%32%37%35%31%2C%31%2E%30%33%33%34%35%37%39%20%36%2E%35%31%31%34%36%36%35%2C%31%2E%30%34%30%30%38%39%32%20%5A%20%6D%20%2D%30%2E%30%37%33%30%33%33%2C%31%2E%32%35%31%34%34%37%31%20%63%20%30%2E%30%35%39%30%30%33%2C%2D%35%2E%35%33%36%65%2D%34%20%30%2E%31%31%38%37%31%36%37%2C%2D%33%2E%36%31%32%65%2D%34%20%30%2E%31%37%37%36%35%31%2C%30%2E%30%30%31%39%37%20%68%20%30%2E%30%31%35%37%37%35%20%30%2E%30%30%35%39%32%20%63%20%30%2E%30%32%35%39%37%34%2C%30%20%30%2E%30%34%37%34%30%33%2C%2D%37%2E%36%65%2D%36%20%30%2E%30%36%31%31%39%32%2C%30%20%31%2E%35%37%39%34%30%31%33%2C%30%2E%30%30%31%34%38%20%33%2E%31%32%39%34%38%30%39%2C%31%2E%30%35%34%30%33%33%38%20%33%2E%37%37%34%30%38%30%36%2C%32%2E%34%39%38%39%34%36%35%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%37%35%37%34%39%2C%31%2E%30%32%34%33%34%33%39%20%30%2E%35%30%39%33%36%33%2C%32%2E%32%36%37%39%30%35%37%20%30%2E%30%39%36%37%32%2C%33%2E%33%32%30%30%38%35%33%20%2D%30%2E%35%35%34%37%36%2C%31%2E%34%32%31%35%35%34%20%2D%31%2E%39%33%33%39%34%31%33%2C%32%2E%35%32%33%32%31%30%39%20%2D%33%2E%34%34%36%34%31%33%32%2C%32%2E%36%39%32%33%38%37%39%20%2D%30%2E%36%37%38%38%30%31%32%2C%30%2E%30%37%36%34%31%20%2D%31%2E%33%36%34%37%30%32%35%2C%30%2E%30%32%38%30%37%20%2D%31%2E%39%36%39%39%34%33%37%2C%2D%30%2E%32%30%37%32%35%38%20%68%20%2D%30%2E%30%30%37%39%31%20%6C%20%2D%30%2E%30%31%33%38%32%37%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%32%34%36%35%39%38%2C%31%30%2E%30%35%30%38%32%35%20%32%2E%33%32%30%32%30%30%32%2C%38%2E%33%39%32%32%33%35%38%20%32%2E%33%30%33%31%32%39%36%2C%36%2E%36%39%35%32%38%37%38%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%35%39%32%20%43%20%32%2E%32%34%35%31%34%36%36%2C%35%2E%33%35%33%35%32%38%35%20%32%2E%39%30%31%37%38%36%38%2C%34%2E%30%30%32%32%39%30%31%20%33%2E%39%35%39%32%32%34%34%2C%33%2E%31%38%39%36%35%36%39%20%76%20%2D%30%2E%30%30%37%39%20%43%20%34%2E%36%36%36%32%36%34%2C%32%2E%36%32%39%35%37%38%36%20%35%2E%35%35%33%33%39%32%2C%32%2E%32%39%39%38%33%39%31%20%36%2E%34%33%38%34%33%32%31%2C%32%2E%32%39%31%35%33%36%33%20%5A%20%4D%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%43%20%32%2E%30%32%35%34%35%30%33%2C%33%2E%35%30%35%36%31%33%32%20%31%2E%32%33%36%33%38%34%39%2C%35%2E%30%38%30%30%37%34%38%20%31%2E%33%30%34%33%34%30%38%2C%36%2E%37%31%37%30%30%30%36%20%31%2E%33%32%39%39%33%33%31%2C%38%2E%37%38%37%38%31%37%32%20%32%2E%37%36%30%36%36%39%32%2C%31%30%2E%36%31%34%38%33%34%20%34%2E%36%37%35%37%34%38%2C%31%31%2E%33%37%33%34%31%20%34%2E%31%37%37%36%36%38%38%2C%31%31%2E%31%37%39%34%37%36%20%33%2E%35%39%33%37%33%33%34%2C%31%31%2E%32%36%33%35%38%32%20%33%2E%31%37%37%35%36%34%31%2C%31%30%2E%39%33%33%32%33%32%20%31%2E%39%32%35%32%38%36%35%2C%39%2E%39%35%39%39%32%38%36%20%31%2E%31%30%36%36%37%32%32%2C%38%2E%34%31%33%31%32%35%35%20%31%2E%30%35%37%36%30%34%2C%36%2E%38%33%37%34%30%37%39%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%43%20%30%2E%39%37%39%31%34%37%36%34%2C%35%2E%33%38%34%34%33%39%31%20%31%2E%35%30%31%30%39%39%38%2C%33%2E%39%30%35%35%39%36%20%32%2E%34%39%30%36%34%39%34%2C%32%2E%38%35%34%30%39%35%34%20%6C%20%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%43%20%32%2E%36%39%36%38%36%34%32%2C%32%2E%36%32%34%33%33%36%36%20%33%2E%30%35%34%38%30%30%39%2C%32%2E%36%37%32%39%33%31%38%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%5A%20%6D%20%30%2E%30%37%35%30%30%37%2C%32%2E%39%39%30%34%34%35%32%20%76%20%30%2E%35%30%37%32%39%20%31%2E%36%35%36%30%39%35%20%48%20%39%2E%38%31%35%37%36%30%34%20%56%20%35%2E%34%37%37%33%39%36%38%20%5A%20%4D%20%34%2E%33%37%37%36%39%2C%36%2E%34%39%31%39%37%37%31%20%48%20%38%2E%38%30%31%31%38%30%35%20%56%20%36%2E%36%33%34%30%39%37%32%20%48%20%34%2E%33%37%37%36%39%20%5A%20%6D%20%37%2E%30%35%36%36%36%32%2C%32%2E%30%35%32%38%34%37%31%20%68%20%30%2E%30%30%32%20%63%20%2D%30%2E%32%30%37%39%34%36%2C%30%2E%35%31%32%30%39%39%20%2D%30%2E%32%31%35%34%34%34%2C%31%2E%30%38%33%34%34%39%37%20%2D%30%2E%35%35%32%36%39%2C%31%2E%35%32%39%37%36%35%38%20%6C%20%2D%30%2E%32%36%30%35%35%34%2C%30%2E%33%35%31%33%35%32%20%30%2E%33%30%35%39%35%35%2C%30%2E%33%31%33%38%34%37%20%63%20%31%2E%32%30%33%32%31%34%2C%31%2E%32%31%36%34%33%37%20%32%2E%34%32%36%37%37%34%2C%32%2E%33%39%38%34%34%33%20%33%2E%36%30%32%33%35%32%2C%33%2E%36%31%38%31%34%33%20%30%2E%31%34%34%31%39%34%2C%30%2E%31%36%33%38%36%39%20%30%2E%32%38%32%39%38%2C%30%2E%32%38%34%32%35%39%20%30%2E%33%35%31%33%35%32%2C%30%2E%33%36%35%31%36%38%20%30%2E%30%37%32%36%35%2C%30%2E%30%38%35%39%37%20%30%2E%30%36%31%38%35%2C%30%2E%30%38%30%35%31%20%30%2E%30%35%39%32%32%2C%30%2E%31%30%34%36%31%38%20%76%20%30%2E%30%31%33%38%33%20%30%2E%30%31%35%37%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%37%20%2D%30%2E%31%33%31%35%33%39%2C%30%2E%30%37%34%31%31%20%2D%30%2E%31%34%32%31%32%2C%30%2E%30%36%37%31%31%20%2D%31%2E%32%31%32%34%32%35%2C%2D%31%2E%31%32%35%37%38%37%20%2D%32%2E%37%37%30%37%36%36%2C%2D%32%2E%37%34%39%36%38%31%20%2D%34%2E%31%34%31%32%32%36%2C%2D%33%2E%39%36%39%34%38%38%20%6C%20%2D%30%2E%33%30%35%39%35%32%2C%2D%30%2E%32%36%38%34%35%20%2D%30%2E%33%32%37%36%36%36%2C%30%2E%32%33%38%38%33%39%20%63%20%2D%30%2E%38%37%37%31%36%33%35%2C%30%2E%36%33%32%35%30%34%20%2D%31%2E%38%38%36%39%34%32%38%2C%31%2E%30%37%38%37%35%39%20%2D%32%2E%39%32%33%33%33%34%35%2C%31%2E%31%34%38%38%30%37%20%68%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%63%20%2D%30%2E%35%33%30%33%35%35%33%2C%30%2E%30%35%33%39%39%20%2D%30%2E%39%37%39%37%31%38%39%2C%2D%30%2E%33%33%34%33%37%20%2D%31%2E%35%30%36%30%35%36%33%2C%2D%30%2E%34%34%30%31%37%38%20%30%2E%35%35%33%39%30%38%34%2C%30%2E%31%30%35%38%34%31%20%31%2E%31%31%32%30%34%31%35%2C%30%2E%32%34%38%37%36%35%20%31%2E%36%35%36%30%39%35%2C%30%2E%31%38%37%35%32%20%31%2E%38%38%33%30%33%34%39%2C%2D%30%2E%32%31%30%36%32%37%20%33%2E%34%38%32%30%33%38%38%2C%2D%31%2E%35%34%37%39%30%32%20%34%2E%31%39%38%34%36%37%38%2C%2D%33%2E%32%37%36%36%35%39%38%20%7A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%43%20%34%2E%38%35%30%34%32%37%33%2C%30%2E%35%32%39%37%30%35%39%38%20%33%2E%32%31%37%30%32%38%2C%31%2E%32%38%31%36%31%34%32%20%32%2E%31%31%34%33%34%36%32%2C%32%2E%35%31%35%32%33%39%38%20%31%2E%30%32%34%37%39%35%35%2C%33%2E%36%37%33%30%30%31%39%20%30%2E%34%35%39%30%33%36%34%32%2C%35%2E%32%37%39%34%30%38%35%20%30%2E%35%34%35%31%30%31%38%39%2C%36%2E%38%35%35%38%32%36%39%20%30%2E%35%39%39%32%32%37%33%2C%38%2E%35%39%33%38%33%39%31%20%31%2E%34%38%39%32%31%39%35%2C%31%30%2E%32%37%30%37%38%32%20%32%2E%38%36%30%34%37%36%38%2C%31%31%2E%33%33%36%35%36%31%20%63%20%31%2E%31%39%31%35%34%37%39%2C%30%2E%39%34%35%38%33%32%20%32%2E%37%36%30%34%36%38%37%2C%31%2E%34%30%31%33%32%35%20%34%2E%32%37%31%35%30%31%33%2C%31%2E%32%34%37%34%39%39%20%31%2E%31%35%37%35%30%32%35%2C%2D%30%2E%30%37%38%32%33%20%32%2E%32%34%39%39%32%38%36%2C%2D%30%2E%35%37%30%30%39%34%20%33%2E%31%38%33%38%38%35%39%2C%2D%31%2E%32%34%33%35%35%32%20%31%2E%33%36%35%32%34%36%2C%31%2E%32%31%35%31%36%37%20%32%2E%39%35%38%34%31%2C%32%2E%38%36%37%39%37%34%20%34%2E%31%39%36%34%39%34%2C%34%2E%30%31%32%39%32%31%20%30%2E%33%35%37%38%33%2C%30%2E%32%33%36%37%32%37%20%30%2E%39%30%39%31%32%33%2C%2D%30%2E%30%33%34%35%35%20%30%2E%39%32%35%37%35%35%2C%2D%30%2E%34%36%39%37%38%36%20%30%2E%30%34%32%37%34%2C%2D%30%2E%33%38%38%36%35%31%20%2D%30%2E%33%33%32%31%33%37%2C%2D%30%2E%36%31%33%36%30%34%20%2D%30%2E%35%35%30%37%31%36%2C%2D%30%2E%38%37%30%34%38%36%20%2D%31%2E%31%38%33%30%34%32%2C%2D%31%2E%32%32%37%34%34%33%20%2D%32%2E%34%30%33%36%33%2C%2D%32%2E%34%31%36%31%31%38%20%2D%33%2E%36%30%32%33%35%32%2C%2D%33%2E%36%32%38%30%31%33%20%30%2E%37%39%33%33%30%35%2C%2D%31%2E%30%34%39%38%38%37%31%20%31%2E%33%31%39%38%32%34%2C%2D%32%2E%33%33%30%37%31%31%20%31%2E%33%31%38%35%36%2C%2D%33%2E%36%35%33%36%37%32%34%20%30%2E%30%33%34%2C%2D%31%2E%30%30%30%30%34%38%32%20%2D%30%2E%31%37%37%32%30%31%2C%2D%32%2E%30%30%39%35%38%32%37%20%2D%30%2E%36%34%35%34%36%33%2C%2D%32%2E%38%39%35%36%39%38%34%20%43%20%31%31%2E%30%35%31%36%30%32%2C%32%2E%30%35%31%34%32%35%35%20%39%2E%32%31%33%34%33%30%33%2C%30%2E%37%34%39%36%39%32%30%34%20%37%2E%32%30%38%39%35%39%31%2C%30%2E%35%37%30%39%35%36%38%32%20%36%2E%39%37%36%31%38%35%38%2C%30%2E%35%34%38%34%32%30%35%31%20%36%2E%37%34%32%30%34%33%39%2C%30%2E%35%33%37%39%37%33%36%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%5A%20%4D%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%63%20%30%2E%30%36%37%30%37%34%2C%2D%35%2E%39%35%32%65%2D%34%20%30%2E%31%33%34%31%37%35%31%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%33%33%37%31%2C%30%2E%30%30%33%39%35%20%30%2E%30%31%39%38%36%33%2C%30%20%30%2E%30%33%39%32%30%32%2C%2D%31%2E%31%32%65%2D%35%20%30%2E%30%35%39%32%31%37%2C%30%20%31%2E%37%39%36%34%37%36%2C%30%2E%30%30%31%36%38%20%33%2E%35%30%35%38%30%37%35%2C%31%2E%31%36%30%37%36%36%35%20%34%2E%32%33%33%39%39%36%35%2C%32%2E%37%39%33%30%35%36%32%20%43%20%31%31%2E%34%36%34%32%38%31%2C%35%2E%37%34%34%39%36%31%32%20%31%31%2E%35%30%33%30%31%35%2C%37%2E%31%32%31%37%20%31%31%2E%30%33%38%33%31%2C%38%2E%33%30%36%36%33%39%35%20%31%30%2E%34%31%33%39%35%37%2C%39%2E%39%30%36%35%31%30%36%20%38%2E%38%38%39%31%31%34%35%2C%31%31%2E%31%33%32%38%31%20%37%2E%31%37%33%34%32%39%33%2C%31%31%2E%33%32%34%37%31%37%20%36%2E%34%33%32%31%31%31%32%2C%31%31%2E%34%30%38%31%37%20%35%2E%36%36%36%35%36%32%34%2C%31%31%2E%33%35%34%30%37%35%20%34%2E%39%36%36%36%31%38%37%2C%31%31%2E%30%38%31%39%32%39%20%33%2E%31%34%34%32%34%39%33%2C%31%30%2E%34%36%31%37%34%37%20%31%2E%38%31%33%39%35%36%39%2C%38%2E%36%33%34%31%33%32%31%20%31%2E%37%39%34%35%37%36%2C%36%2E%37%30%37%37%38%35%32%20%31%2E%37%32%38%38%37%36%38%2C%35%2E%32%30%33%30%38%37%39%20%32%2E%34%35%36%31%38%33%35%2C%33%2E%37%30%36%30%31%35%33%20%33%2E%36%34%36%30%38%35%38%2C%32%2E%37%39%31%35%38%34%36%20%34%2E%34%33%36%39%32%33%38%2C%32%2E%31%37%33%39%36%30%35%20%35%2E%34%32%37%30%39%36%32%2C%31%2E%38%30%31%37%32%35%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%5A%20%4D%20%33%2E%38%36%35%31%38%38%31%2C%35%2E%39%38%37%33%31%34%37%20%56%20%37%2E%31%34%32%30%34%31%31%20%48%20%39%2E%33%30%33%32%35%38%34%20%56%20%35%2E%39%38%37%33%31%34%37%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"resize-ew",$app$main$ui$cursors$resize_ew$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"resize-nesw",$app$main$ui$cursors$resize_nesw$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,
"resize-ns",$app$main$ui$cursors$resize_ns$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"resize-nwse",$app$main$ui$cursors$resize_nwse$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"rotate",$app$main$ui$cursors$rotate$$);
$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"text",$app$main$ui$cursors$text$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"scale-ew",$app$main$ui$cursors$scale_ew$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,
"scale-nesw",$app$main$ui$cursors$scale_nesw$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"scale-ns",$app$main$ui$cursors$scale_ns$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"scale-nwse",$app$main$ui$cursors$scale_nwse$$);
$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"resize-ew-2",$app$main$ui$cursors$resize_ew_2$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__91912_91916_element$jscomp$inline_14033_options$jscomp$653_style$jscomp$inline_10621_style$jscomp$inline_14034_worker$jscomp$inline_10618$$,"resize-ns-2",$app$main$ui$cursors$resize_ns_2$$);$rumext$v2$render_BANG_$$();
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$initialize$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$initialize$$()]))},$app$main$ui$cursors$default$0$$={Picker:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%30%37%20%31%33%2E%30%37%36%76%32%2E%34%30%31%6C%32%2E%32%32%34%2E%30%32%35%20%37%2E%38%36%2D%37%2E%34%30%35%73%2D%2E%30%35%2D%2E%38%38%35%2D%2E%32%35%33%2D%31%2E%30%38%37%63%2D%2E%32%30%32%2D%2E%32%30%32%2D%32%2E%32%35%2D%31%2E%37%34%34%2D%32%2E%32%35%2D%31%2E%37%34%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%2E%33%34%33%20%31%35%2E%39%37%34%61%2E%35%31%34%2E%35%31%34%20%30%20%30%31%2D%2E%33%31%37%2D%2E%33%32%31%63%2D%2E%30%32%33%2D%2E%30%37%2D%2E%30%32%36%2D%2E%32%33%2D%2E%30%32%36%2D%31%2E%34%33%20%30%2D%31%2E%34%36%38%2D%2E%30%30%31%2D%31%2E%34%34%35%2E%30%39%2D%31%2E%35%38%36%2E%30%32%2D%2E%30%33%32%20%31%2E%37%30%33%2D%31%2E%37%32%34%20%33%2E%37%34%2D%33%2E%37%35%39%61%35%39%36%2E%38%30%35%20%35%39%36%2E%38%30%35%20%30%20%30%30%33%2E%37%2D%33%2E%37%31%36%63%30%2D%2E%30%30%39%2D%2E%33%36%37%2D%2E%33%38%34%2D%2E%38%31%36%2D%2E%38%33%33%61%32%39%2E%39%20%32%39%2E%39%20%30%20%30%31%2D%2E%38%31%37%2D%2E%38%33%33%63%30%2D%2E%30%31%2E%34%37%34%2D%2E%34%39%20%31%2E%30%35%34%2D%31%2E%30%37%6C%31%2E%30%35%33%2D%31%2E%30%35%33%2E%39%34%38%2E%39%34%36%2E%39%34%37%2E%39%34%37%20%31%2E%34%31%37%2D%31%2E%34%31%33%43%31%32%2E%33%36%36%2E%38%30%36%20%31%32%2E%37%36%35%2E%34%31%38%20%31%32%2E%38%35%36%2E%33%35%37%63%2E%32%33%38%2D%2E%31%36%31%2E%35%32%2D%2E%32%38%2E%37%39%32%2D%2E%33%33%34%2E%31%37%2D%2E%30%33%34%2E%35%38%36%2D%2E%30%33%2E%37%36%2E%30%30%38%2E%38%30%31%2E%31%37%33%20%31%2E%34%31%2E%37%39%34%20%31%2E%35%37%20%31%2E%36%30%33%2E%30%33%2E%31%35%2E%30%33%2E%35%36%39%20%30%20%2E%37%31%38%61%32%2E%32%32%37%20%32%2E%32%32%37%20%30%20%30%31%2D%2E%33%33%34%2E%37%39%33%63%2D%2E%30%36%31%2E%30%39%2D%2E%34%35%2E%34%39%2D%31%2E%34%39%36%20%31%2E%35%34%4C%31%32%2E%37%33%34%20%36%2E%31%6C%2E%39%34%37%2E%39%34%38%2E%39%34%37%2E%39%34%37%2D%31%2E%30%35%33%20%31%2E%30%35%34%63%2D%2E%35%38%2E%35%38%2D%31%2E%30%36%31%20%31%2E%30%35%34%2D%31%2E%30%37%20%31%2E%30%35%34%2D%2E%30%31%20%30%2D%2E%33%38%34%2D%2E%33%36%38%2D%2E%38%33%33%2D%2E%38%31%37%2D%2E%34%35%2D%2E%34%35%2D%2E%38%32%34%2D%2E%38%31%37%2D%2E%38%33%34%2D%2E%38%31%37%2D%2E%30%30%39%20%30%2D%31%2E%36%38%20%31%2E%36%36%36%2D%33%2E%37%31%36%20%33%2E%37%30%31%61%34%39%33%2E%30%39%33%20%34%39%33%2E%30%39%33%20%30%20%30%31%2D%33%2E%37%35%39%20%33%2E%37%34%63%2D%2E%31%34%2E%30%39%31%2D%2E%31%31%37%2E%30%39%2D%31%2E%35%39%2E%30%38%39%2D%31%2E%31%38%37%20%30%2D%31%2E%33%36%36%2D%2E%30%30%34%2D%31%2E%34%33%2D%2E%30%32%37%7A%6D%36%2E%30%32%34%2D%34%2E%36%33%33%61%35%39%32%2E%37%32%33%20%35%39%32%2E%37%32%33%20%30%20%30%30%33%2E%36%36%33%2D%33%2E%36%38%63%30%2D%2E%30%32%2D%31%2E%36%37%2D%31%2E%36%39%2D%31%2E%36%39%2D%31%2E%36%39%2D%2E%30%31%20%30%2D%31%2E%36%36%36%20%31%2E%36%34%38%2D%33%2E%36%38%20%33%2E%36%36%33%4C%2E%39%39%36%20%31%33%2E%32%39%37%76%2E%38%33%34%63%30%20%2E%36%32%37%2E%30%30%35%2E%38%33%39%2E%30%32%2E%38%35%34%2E%30%31%35%2E%30%31%34%2E%32%32%37%2E%30%32%2E%38%35%34%2E%30%32%68%2E%38%33%33%6C%33%2E%36%36%34%2D%33%2E%36%36%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto",
Pencil:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%6D%30%20%31%2E%35%4C%31%32%2E%35%20%33%20%32%2E%36%20%31%33%6C%2D%31%2E%31%2D%31%2E%32%20%39%2E%39%2D%31%30%7A%6D%32%20%32%4C%31%34%2E%35%20%35%20%34%2E%36%20%31%35%6C%2D%31%2E%32%2D%31%2E%32%20%31%30%2D%31%30%7A%4D%31%20%31%32%2E%39%6C%32%2E%34%20%32%2E%33%48%31%76%2D%32%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto",
ResizeNs:$app$main$ui$cursors$resize_ns$$,CreateShape:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%37%20%37%56%31%68%31%76%36%68%36%76%31%48%38%76%36%48%37%56%38%48%31%56%37%68%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%36%2E%35%2E%35%68%32%76%36%68%36%76%32%68%2D%36%76%36%68%2D%32%76%2D%36%68%2D%36%76%2D%32%68%36%76%2D%36%7A%4D%37%20%37%48%31%76%31%68%36%76%36%68%31%56%38%68%36%56%37%48%38%56%31%48%37%76%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
Comments:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%6D%36%2E%39%20%31%32%2E%35%31%39%2D%32%2E%35%33%34%39%20%32%2E%30%32%32%32%2D%30%2E%31%37%30%33%39%2D%32%2E%38%30%32%31%63%2D%30%2E%39%34%31%37%38%2D%30%2E%35%35%39%39%36%2D%32%2E%39%33%33%2D%32%2E%32%39%34%38%2D%33%2E%33%36%32%31%2D%34%2E%37%35%31%35%2D%30%2E%34%32%39%30%37%2D%32%2E%34%35%35%31%20%32%2E%36%36%34%32%2D%34%2E%37%37%35%35%20%34%2E%32%36%33%36%2D%35%2E%36%32%38%32%20%33%2E%37%30%33%36%2D%30%2E%34%39%35%36%37%20%31%30%2E%38%36%32%2D%30%2E%31%32%31%35%39%20%39%2E%38%36%38%35%20%35%2E%33%33%36%32%2D%30%2E%39%39%34%34%34%20%35%2E%34%35%37%38%2D%35%2E%37%39%30%38%20%36%2E%31%35%36%34%2D%38%2E%30%36%35%35%20%35%2E%38%32%33%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%6D%37%2E%38%36%34%32%20%30%2E%33%38%36%39%38%63%2D%32%2E%32%36%20%30%2E%30%32%37%38%38%32%2D%34%2E%35%36%38%37%20%30%2E%38%38%36%37%39%2D%36%2E%31%30%31%34%20%32%2E%35%38%36%2D%31%2E%30%31%34%36%20%31%2E%31%30%35%32%2D%31%2E%36%31%34%38%20%32%2E%36%32%30%31%2D%31%2E%34%38%31%36%20%34%2E%31%32%39%36%20%30%2E%31%30%35%33%33%20%31%2E%37%34%38%38%20%31%2E%31%32%39%32%20%33%2E%33%33%39%36%20%32%2E%34%39%33%39%20%34%2E%33%39%32%39%20%30%2E%32%35%30%39%33%20%30%2E%31%39%38%32%37%20%30%2E%35%31%32%37%31%20%30%2E%33%38%32%36%20%30%2E%37%37%39%39%31%20%30%2E%35%35%38%34%31%20%30%2E%30%32%39%34%33%31%20%30%2E%39%38%39%30%32%2D%30%2E%30%32%36%33%33%33%20%31%2E%39%38%35%38%20%30%2E%30%37%32%38%30%32%20%32%2E%39%36%39%34%20%30%2E%31%36%33%34%32%20%30%2E%33%39%37%33%31%20%30%2E%37%33%37%33%31%20%30%2E%34%39%35%36%37%20%31%2E%30%34%33%32%20%30%2E%32%30%33%36%39%20%30%2E%38%31%32%34%34%2D%30%2E%36%36%39%39%33%20%31%2E%36%33%33%34%2D%31%2E%33%33%30%36%20%32%2E%34%34%36%36%2D%32%2E%30%30%31%33%20%30%2E%37%36%30%35%35%20%30%2E%30%37%37%34%35%20%31%2E%35%33%31%39%20%30%2E%30%33%34%38%36%20%32%2E%32%38%37%38%2D%30%2E%30%36%38%31%35%20%32%2E%31%32%38%33%2D%30%2E%33%34%36%32%20%34%2E%31%38%30%37%2D%31%2E%34%39%39%34%20%35%2E%33%37%34%39%2D%33%2E%33%32%35%37%20%30%2E%38%31%30%38%39%2D%31%2E%32%32%31%34%20%31%2E%31%37%37%32%2D%32%2E%37%36%31%38%20%30%2E%38%35%35%38%31%2D%34%2E%32%30%35%35%2D%30%2E%33%31%32%31%32%2D%31%2E%34%38%34%37%2D%31%2E%32%37%36%34%2D%32%2E%37%37%31%31%2D%32%2E%34%39%36%32%2D%33%2E%36%34%34%37%2D%31%2E%35%31%36%34%2D%31%2E%31%30%33%36%2D%33%2E%34%31%30%31%2D%31%2E%36%33%30%33%2D%35%2E%32%37%35%38%2D%31%2E%35%39%34%37%7A%6D%30%2E%31%37%34%32%36%20%31%2E%33%30%38%39%63%31%2E%38%36%39%36%20%30%2E%30%30%36%39%37%20%33%2E%38%30%32%37%20%30%2E%36%35%36%37%37%20%35%2E%31%32%31%37%20%32%2E%30%33%30%37%20%30%2E%38%30%33%39%32%20%30%2E%38%32%32%35%31%20%31%2E%33%32%38%32%20%31%2E%39%35%33%33%20%31%2E%32%36%38%36%20%33%2E%31%30%37%32%2D%30%2E%30%32%34%37%38%20%31%2E%33%30%38%39%2D%30%2E%37%32%36%34%37%20%32%2E%35%33%36%34%2D%31%2E%36%39%36%31%20%33%2E%33%38%39%32%2D%31%2E%33%38%34%38%20%31%2E%32%33%31%34%2D%33%2E%32%37%39%32%20%31%2E%38%32%31%36%2D%35%2E%31%31%30%31%20%31%2E%37%32%30%39%2D%30%2E%33%31%35%39%39%20%30%2E%30%31%30%38%34%2D%30%2E%36%33%39%37%33%2D%30%2E%30%38%38%32%39%2D%30%2E%39%34%36%34%32%2D%30%2E%30%34%39%35%37%2D%30%2E%35%39%38%36%38%20%30%2E%34%38%37%31%35%2D%31%2E%31%39%36%36%20%30%2E%39%37%34%33%31%2D%31%2E%37%39%33%37%20%31%2E%34%36%32%32%2D%30%2E%30%31%35%34%39%2D%30%2E%36%38%39%33%2D%30%2E%30%31%32%33%39%32%2D%31%2E%33%37%39%34%2D%30%2E%30%32%30%31%33%37%2D%32%2E%30%36%39%34%2D%31%2E%33%36%37%37%2D%30%2E%36%38%39%32%39%2D%32%2E%36%30%39%33%2D%31%2E%38%30%34%36%2D%33%2E%30%38%37%31%2D%33%2E%32%39%33%39%2D%30%2E%34%31%32%30%33%2D%31%2E%32%35%34%37%2D%30%2E%31%37%35%30%33%2D%32%2E%37%30%36%38%20%30%2E%36%34%35%31%35%2D%33%2E%37%35%36%33%20%31%2E%32%39%31%31%2D%31%2E%37%33%37%32%20%33%2E%35%31%2D%32%2E%35%35%31%39%20%35%2E%36%31%38%31%2D%32%2E%35%34%30%33%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 2 20, auto",
ScaleEw:$app$main$ui$cursors$scale_ew$$,CreatePolygon:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%73%74%72%6F%6B%65%3D%27%23%66%66%66%27%20%73%74%72%6F%6B%65%2D%77%69%64%74%68%3D%27%2E%35%27%20%64%3D%27%4D%31%32%2E%32%2E%39%4C%31%32%20%2E%35%6C%2D%2E%33%2E%34%2D%33%2E%34%20%36%2D%2E%32%2E%33%48%31%35%2E%39%6C%2D%2E%33%2D%2E%33%2D%33%2E%34%2D%36%7A%6D%31%20%34%2E%38%68%2D%32%2E%35%4C%31%32%20%33%2E%35%6C%31%2E%33%20%32%2E%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
PointerMove:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'42px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%31%37%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%20%31%2E%32%36%33%20%31%2E%32%36%33%2E%35%32%36%2D%2E%35%32%36%76%31%2E%32%36%33%68%2D%2E%39%34%37%6C%2E%35%32%36%2D%2E%35%32%37%4C%36%2E%32%20%31%37%2E%32%32%32%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%4C%36%2E%32%20%32%32%2E%39%30%37%6C%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%36%2D%2E%35%32%36%68%2E%39%34%37%76%31%2E%34%37%34%6C%2D%2E%35%32%36%2D%2E%36%33%32%2D%31%2E%32%36%33%20%31%2E%33%36%39%20%32%2E%38%34%32%20%32%2E%38%34%32%20%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%37%2E%35%32%37%76%2D%31%2E%34%37%34%68%2E%39%34%38%6C%2D%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%34%20%31%2E%32%36%34%20%32%2E%38%34%32%2D%32%2E%38%34%33%2D%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%34%20%31%2E%32%36%33%2E%35%32%37%2E%35%32%37%68%2D%2E%39%34%38%76%2D%31%2E%32%36%33%6C%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%33%2D%31%2E%32%36%33%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%39%30%37%6C%2D%32%2E%31%30%35%20%32%2E%31%30%35%2E%35%32%36%2E%35%32%36%20%31%2E%30%35%32%2D%31%2E%30%35%33%76%33%2E%30%35%33%48%35%2E%36%37%34%6C%31%2E%30%35%32%2D%31%2E%30%35%33%2D%2E%35%32%36%2D%2E%35%32%36%2D%32%2E%31%30%35%20%32%2E%31%30%35%4C%36%2E%32%20%32%32%2E%31%37%6C%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%32%2D%31%2E%30%35%32%48%38%2E%34%31%76%33%2E%32%36%33%4C%37%2E%33%35%38%20%32%32%2E%38%6C%2D%2E%35%32%36%2E%35%32%37%20%32%2E%31%30%35%20%32%2E%31%30%35%20%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%33%20%31%2E%30%35%33%56%32%30%2E%35%39%48%31%32%2E%32%6C%2D%31%2E%30%35%33%20%31%2E%30%35%32%2E%35%32%37%2E%35%32%37%20%32%2E%31%30%35%2D%32%2E%31%30%36%2D%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%37%2E%35%32%36%20%31%2E%30%35%33%20%31%2E%30%35%33%48%39%2E%34%36%33%76%2D%33%2E%30%35%33%6C%31%2E%30%35%33%20%31%2E%30%35%33%2E%35%32%36%2D%2E%35%32%36%7A%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto",
ResizeEw:$app$main$ui$cursors$resize_ew$$,Pen:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%63%2D%2E%37%2E%32%20%30%20%2E%33%2D%2E%37%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%6C%2D%2E%33%2E%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%20%2E%37%2D%2E%37%20%32%2E%33%20%32%2E%33%20%32%2E%36%2D%32%2E%36%4C%31%32%20%39%2E%34%6C%2E%37%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%32%2E%33%20%31%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%63%30%20%2E%38%20%30%20%31%2E%35%2D%2E%33%20%32%2E%31%6C%2D%2E%38%2D%2E%38%4C%31%32%20%38%63%30%2D%32%2E%39%2D%32%2D%34%2E%36%2D%35%2D%35%61%34%36%2E%34%20%34%36%2E%34%20%30%20%30%31%2D%35%2D%31%6C%2E%33%20%31%2E%31%63%2E%32%2E%39%2E%35%20%32%2E%32%2E%37%20%33%2E%39%2E%34%20%33%20%32%2E%31%20%35%20%35%20%35%68%31%2E%33%6C%2E%38%2E%37%63%2D%2E%36%2E%32%2D%31%2E%33%2E%33%2D%32%2E%31%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%2E%36%20%31%2E%36%63%2E%32%2D%2E%31%2E%36%2D%2E%31%2E%38%20%30%6C%35%20%35%61%2E%35%2E%35%20%30%20%31%31%2D%2E%38%2E%38%6C%2D%35%2D%35%61%2E%35%2E%35%20%30%20%30%31%30%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%37%2E%35%20%39%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto",
ScaleNs:$app$main$ui$cursors$scale_ns$$,PointerNode:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'32px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%39%2E%31%34%33%20%31%39%2E%34%32%39%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%30%30%2D%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%30%30%20%33%2E%32%34%38%7A%6D%33%2E%34%38%39%2D%31%2E%36%32%34%61%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%31%31%2D%36%2E%39%37%38%20%30%20%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%30%31%36%2E%39%37%38%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%31%32%2E%32%31%20%31%37%2E%38%30%35%61%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%31%31%2D%36%2E%31%33%35%20%30%20%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%30%31%36%2E%31%33%35%20%30%7A%6D%2D%31%2E%30%32%32%20%30%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%2D%34%2E%30%39%20%30%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%34%2E%30%39%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto",
Hand:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%33%2E%35%20%35%2E%33%38%76%2D%33%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%2D%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%38%2D%2E%32%34%20%31%2E%32%34%2D%2E%31%35%20%32%20%2E%35%76%37%2E%35%63%30%20%33%2D%33%20%34%2D%33%20%34%68%2D%37%73%2D%33%2D%31%2E%31%35%2D%33%2D%34%76%2D%35%2E%35%63%2E%38%32%2D%2E%38%36%20%31%2E%32%35%2D%2E%39%20%32%2D%2E%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%30%63%2D%2E%37%33%20%30%2D%31%2E%36%2E%32%39%2D%31%2E%39%38%20%31%2E%30%34%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2E%31%37%63%2D%2E%33%33%2D%2E%31%33%2D%2E%36%39%2D%2E%32%2D%31%2E%30%32%2D%2E%32%2D%2E%37%33%20%30%2D%31%2E%36%2E%33%2D%31%2E%39%38%20%31%2E%30%35%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2E%32%33%56%34%2E%36%61%31%2E%34%39%20%31%2E%34%39%20%30%20%30%30%2D%2E%35%39%20%30%63%2D%2E%34%37%2E%31%2D%2E%38%37%2E%34%33%2D%31%2E%33%2E%38%38%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%31%34%2E%33%35%76%35%2E%35%39%63%30%20%31%2E%36%35%2E%38%37%20%32%2E%38%20%31%2E%37%20%33%2E%35%61%36%2E%35%34%20%36%2E%35%34%20%30%20%30%30%31%2E%35%32%2E%39%37%6C%2E%31%2E%30%35%2E%30%34%2E%30%31%68%2E%30%31%61%2E%35%2E%35%20%30%20%30%30%2E%31%38%2E%30%34%68%37%2E%31%31%63%2E%30%36%20%30%20%2E%31%31%20%30%20%2E%31%37%2D%2E%30%33%68%2E%30%31%6C%2E%30%33%2D%2E%30%31%2E%31%32%2D%2E%30%35%41%35%2E%34%20%35%2E%34%20%30%20%30%30%31%33%2E%34%20%31%35%63%2E%38%34%2D%2E%37%20%31%2E%37%31%2D%31%2E%38%34%20%31%2E%37%31%2D%33%2E%35%36%56%33%2E%38%61%2E%35%2E%35%20%30%20%30%30%2D%2E%31%38%2D%2E%33%39%20%33%20%33%20%30%20%30%30%2D%31%2E%32%2D%2E%37%20%31%2E%39%35%20%31%2E%39%35%20%30%20%30%30%2D%2E%36%35%2D%2E%30%34%76%2D%2E%34%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2D%2E%32%32%63%2D%2E%33%38%2D%2E%37%35%2D%31%2E%32%35%2D%31%2E%30%34%2D%31%2E%39%38%2D%31%2E%30%34%2D%2E%33%33%20%30%2D%2E%37%2E%30%36%2D%31%2E%30%32%2E%32%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2D%2E%31%38%43%39%2E%36%2E%33%20%38%2E%37%33%20%30%20%38%20%30%7A%6D%30%20%31%2E%30%32%63%2E%34%38%20%30%20%2E%38%35%2E%31%37%20%31%2E%30%32%2E%33%39%76%33%2E%39%32%68%31%2E%30%31%56%32%2E%34%35%63%2E%31%36%2D%2E%32%33%2E%35%32%2D%2E%34%32%20%31%2E%30%32%2D%2E%34%32%2E%34%38%20%30%20%2E%38%34%2E%31%38%20%31%2E%30%31%2E%34%76%32%2E%39%68%31%2E%30%32%56%33%2E%37%31%63%2E%31%36%2D%2E%30%32%2E%33%2D%2E%30%32%2E%34%20%30%20%2E%31%37%2E%30%34%2E%33%35%2E%31%34%2E%36%32%2E%33%34%76%37%2E%33%38%63%30%20%31%2E%33%33%2D%2E%36%36%20%32%2E%32%31%2D%31%2E%33%35%20%32%2E%37%38%61%34%2E%39%38%20%34%2E%39%38%20%30%20%30%31%2D%31%2E%32%35%2E%37%36%6C%2D%2E%30%34%2E%30%31%48%34%2E%35%32%61%34%2E%37%35%20%34%2E%37%35%20%30%20%30%31%2D%31%2E%32%37%2D%2E%38%32%20%33%2E%35%35%20%33%2E%35%35%20%30%20%30%31%2D%31%2E%33%35%2D%32%2E%37%33%56%36%2E%30%35%63%2E%33%32%2D%2E%33%31%2E%35%31%2D%2E%34%31%2E%36%35%2D%2E%34%34%2E%30%38%2D%2E%30%32%2E%32%20%30%20%2E%33%37%2E%30%36%76%32%2E%37%31%68%31%2E%30%32%56%32%2E%34%33%63%2E%31%36%2D%2E%32%32%2E%35%33%2D%2E%34%20%31%2E%30%31%2D%2E%34%2E%35%20%30%20%2E%38%36%2E%31%39%20%31%2E%30%32%2E%34%32%76%32%2E%38%38%68%31%2E%30%31%56%31%2E%34%31%63%2E%31%37%2D%2E%32%32%2E%35%34%2D%2E%34%20%31%2E%30%32%2D%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
PointerInner:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%20%31%34%2E%36%56%33%2E%34%6C%38%2E%32%20%38%2E%32%48%34%6C%2D%33%20%33%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%30%20%31%37%56%31%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%4C%30%20%31%37%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%33%2E%34%76%31%31%2E%32%6C%33%2D%33%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto",
ScaleNwse:$app$main$ui$cursors$scale_nwse$$,ResizeNesw:$app$main$ui$cursors$resize_nesw$$,Zoom:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%34%39%36%34%39%30%35%2C%30%2E%30%33%33%32%31%39%31%31%20%30%2E%30%30%37%34%34%2C%30%2E%30%30%37%34%35%33%34%20%43%20%34%2E%36%39%39%39%39%32%37%2C%30%2E%30%33%31%30%39%32%20%32%2E%39%34%35%30%35%32%32%2C%30%2E%38%33%30%37%34%37%36%34%20%31%2E%37%34%38%36%31%39%36%2C%32%2E%31%36%34%39%31%36%33%20%30%2E%35%36%31%38%32%38%38%38%2C%33%2E%34%32%36%30%30%33%39%20%2D%30%2E%30%34%39%37%31%31%33%35%2C%35%2E%31%35%36%33%33%38%20%30%2E%30%34%31%37%37%31%31%35%2C%36%2E%38%36%38%30%36%36%31%20%30%2E%31%30%32%38%38%36%37%39%2C%38%2E%37%36%30%35%39%39%37%20%31%2E%30%36%33%37%35%33%39%2C%31%30%2E%35%35%36%38%31%34%20%32%2E%35%34%36%31%34%32%36%2C%31%31%2E%37%31%32%38%33%33%20%63%20%30%2E%30%30%31%39%32%2C%30%2E%30%30%31%35%20%30%2E%30%30%35%35%33%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%34%35%2C%30%20%31%2E%32%39%32%32%33%36%35%2C%31%2E%30%32%33%32%35%34%20%32%2E%39%37%36%36%34%30%37%2C%31%2E%35%31%31%32%35%34%20%34%2E%36%31%33%37%30%38%35%2C%31%2E%33%34%39%30%38%31%20%31%2E%31%31%36%31%30%39%34%2C%2D%30%2E%30%37%37%35%33%20%32%2E%31%30%37%31%37%31%35%2C%2D%30%2E%35%38%30%35%31%39%20%33%2E%30%31%31%32%30%38%39%2C%2D%31%2E%31%36%32%37%34%34%20%31%2E%32%39%36%38%37%33%2C%31%2E%31%37%34%38%34%36%20%32%2E%37%38%34%35%35%2C%32%2E%37%30%33%30%36%31%20%33%2E%39%38%30%31%36%32%2C%33%2E%38%30%38%37%33%31%20%6C%20%30%2E%30%32%39%38%2C%30%2E%30%32%32%33%36%20%30%2E%30%33%37%32%38%2C%30%2E%30%32%32%33%36%20%63%20%30%2E%37%30%30%37%31%35%2C%30%2E%34%36%33%35%38%38%20%31%2E%36%35%37%32%34%33%2C%2D%30%2E%30%31%33%30%34%20%31%2E%36%39%39%33%38%38%2C%2D%30%2E%38%35%37%31%35%36%20%30%2E%30%32%38%33%38%2C%2D%30%2E%33%35%32%32%31%37%20%2D%30%2E%31%33%36%30%33%32%2C%2D%30%2E%36%35%39%31%39%39%20%2D%30%2E%32%39%30%36%38%36%2C%2D%30%2E%38%34%32%32%34%33%20%2D%30%2E%31%35%38%37%34%35%2C%2D%30%2E%31%38%37%38%38%38%20%2D%30%2E%33%30%38%36%35%31%2C%2D%30%2E%33%31%32%33%34%31%20%2D%30%2E%33%37%32%36%37%34%2C%2D%30%2E%33%38%37%35%38%32%20%6C%20%2D%30%2E%30%30%37%34%2C%2D%30%2E%30%30%37%34%20%2D%30%2E%30%31%34%39%32%2C%2D%30%2E%30%31%34%39%32%20%43%20%31%34%2E%31%31%36%32%34%2C%31%32%2E%34%37%37%39%34%20%31%32%2E%39%37%30%32%32%35%2C%31%31%2E%33%35%32%31%39%36%20%31%31%2E%38%34%30%36%34%2C%31%30%2E%32%31%34%36%38%32%20%31%32%2E%35%32%37%35%39%35%2C%39%2E%31%37%36%30%30%33%37%20%31%33%2E%30%39%39%38%31%36%2C%38%2E%30%31%30%31%30%38%37%20%31%33%2E%31%30%30%32%38%2C%36%2E%37%32%36%34%35%30%31%20%31%33%2E%31%33%34%36%33%31%2C%35%2E%36%35%32%31%33%37%32%20%31%32%2E%39%30%37%35%31%39%2C%34%2E%35%36%30%30%35%36%20%31%32%2E%33%39%39%36%35%32%2C%33%2E%35%39%35%39%38%35%37%20%31%31%2E%34%31%35%30%31%31%2C%31%2E%36%35%37%39%31%30%34%20%39%2E%34%34%35%37%33%33%38%2C%30%2E%32%36%30%36%33%30%36%39%20%37%2E%32%35%36%37%34%35%39%2C%30%2E%30%36%33%30%33%33%30%35%20%68%20%2D%30%2E%30%30%37%34%34%20%43%20%37%2E%31%37%30%32%35%31%2C%30%2E%30%35%35%34%37%31%39%37%20%37%2E%30%38%39%38%36%30%34%2C%30%2E%30%36%30%32%39%31%31%36%20%37%2E%30%31%30%37%38%31%2C%30%2E%30%35%35%35%37%39%35%38%20%56%20%30%2E%30%33%33%32%31%39%31%31%20%48%20%36%2E%35%31%31%33%39%37%33%20%63%20%2D%30%2E%30%30%34%39%32%2C%36%2E%30%39%38%65%2D%35%20%2D%30%2E%30%31%2C%2D%37%2E%31%31%34%65%2D%35%20%2D%30%2E%30%31%34%39%32%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%34%34%2C%31%2E%30%30%36%32%32%30%36%39%20%68%20%30%2E%30%30%37%34%34%20%63%20%30%2E%32%31%35%37%36%33%33%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%35%33%32%39%34%2C%30%2E%30%30%39%31%38%20%30%2E%36%34%38%34%35%33%35%2C%30%2E%30%32%39%38%31%36%20%31%2E%38%31%33%36%36%31%34%2C%30%2E%31%36%31%37%32%31%31%20%33%2E%35%31%32%31%33%38%2C%31%2E%33%36%33%34%33%36%39%20%34%2E%33%33%37%39%32%39%2C%32%2E%39%38%38%38%34%38%20%68%20%30%2E%30%30%37%34%20%76%20%30%2E%30%30%37%34%34%20%63%20%30%2E%34%32%33%30%35%35%2C%30%2E%38%30%30%35%33%34%32%20%30%2E%36%32%30%31%39%32%2C%31%2E%37%32%31%38%30%32%35%20%30%2E%35%38%38%38%36%31%2C%32%2E%36%33%38%35%34%34%34%20%6C%20%2D%30%2E%30%30%37%34%2C%30%2E%30%30%37%34%34%20%76%20%30%2E%30%30%37%34%34%20%43%20%31%32%2E%30%38%37%31%35%35%2C%37%2E%32%39%33%30%35%35%36%20%31%31%2E%36%39%36%35%35%36%2C%37%2E%37%38%38%30%31%35%35%20%31%31%2E%34%39%37%37%38%2C%38%2E%33%33%36%34%30%33%32%20%31%31%2E%39%35%39%30%37%33%2C%37%2E%30%35%32%39%34%34%32%20%31%31%2E%39%35%34%36%34%38%2C%35%2E%36%31%31%36%30%30%35%20%31%31%2E%33%37%38%35%32%34%2C%34%2E%33%37%31%31%34%38%34%20%31%30%2E%35%36%36%30%35%32%2C%32%2E%35%35%36%33%39%35%35%20%38%2E%36%39%39%37%34%30%39%2C%31%2E%32%38%37%32%38%32%38%20%36%2E%36%39%30%32%38%31%2C%31%2E%32%38%35%34%30%34%39%20%63%20%2D%30%2E%30%31%36%34%34%38%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%34%35%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%32%38%34%2C%30%20%43%20%35%2E%36%38%33%35%30%30%36%2C%31%2E%32%34%36%39%38%39%39%20%34%2E%38%30%35%34%30%36%37%2C%31%2E%36%38%38%34%39%33%39%20%33%2E%39%38%34%36%36%35%38%2C%32%2E%31%37%32%33%36%39%38%20%34%2E%38%30%35%31%35%39%38%2C%31%2E%36%39%32%34%31%37%36%20%35%2E%35%36%30%36%32%34%2C%31%2E%30%33%32%38%31%34%37%20%36%2E%35%30%33%39%34%34%31%2C%31%2E%30%33%39%34%33%39%38%20%5A%20%6D%20%30%2E%31%30%34%33%36%30%38%2C%31%2E%32%35%32%31%38%35%37%20%68%20%30%2E%30%31%34%39%32%31%20%30%2E%30%30%37%34%34%20%63%20%30%2E%30%32%35%39%38%38%2C%30%20%30%2E%30%34%35%38%38%36%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%35%39%36%32%38%2C%30%20%31%2E%35%37%37%39%34%32%36%2C%30%2E%30%30%31%34%37%20%33%2E%31%32%37%34%36%30%37%2C%31%2E%30%35%33%33%34%20%33%2E%37%37%31%34%36%34%37%2C%32%2E%34%39%36%39%31%38%31%20%76%20%30%2E%30%30%37%34%35%20%63%20%30%2E%34%37%35%33%31%31%2C%31%2E%30%32%33%33%39%37%38%20%30%2E%35%30%39%31%35%36%2C%32%2E%32%36%35%35%39%33%36%20%30%2E%30%39%36%38%39%2C%33%2E%33%31%36%38%30%31%35%20%43%20%31%30%2E%30%30%34%33%39%37%2C%39%2E%35%33%33%30%32%37%36%20%38%2E%36%32%36%32%30%35%37%2C%31%30%2E%36%33%34%34%38%37%20%37%2E%31%31%35%31%33%2C%31%30%2E%38%30%33%35%30%37%20%36%2E%34%33%36%39%35%36%31%2C%31%30%2E%38%37%39%38%35%32%20%35%2E%37%35%32%30%39%34%34%2C%31%30%2E%38%32%39%39%31%38%20%35%2E%31%34%37%34%30%39%35%2C%31%30%2E%35%39%34%38%31%20%68%20%2D%30%2E%30%30%37%34%34%20%6C%20%2D%30%2E%30%31%34%39%32%31%2C%2D%30%2E%30%30%37%34%20%43%20%33%2E%35%31%39%36%39%36%39%2C%31%30%2E%30%34%31%30%32%39%20%32%2E%33%31%37%32%33%33%39%2C%38%2E%33%38%34%35%36%33%31%20%32%2E%33%30%30%31%37%37%36%2C%36%2E%36%38%39%31%38%32%34%20%76%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%43%20%32%2E%32%34%32%32%35%39%35%2C%35%2E%33%34%37%35%38%33%35%20%32%2E%38%39%38%33%39%31%39%2C%33%2E%39%39%37%39%32%36%36%20%33%2E%39%35%34%38%35%31%37%2C%33%2E%31%38%36%30%34%33%39%20%76%20%2D%30%2E%30%30%37%34%35%20%43%20%34%2E%37%30%38%33%33%32%36%2C%32%2E%35%39%30%31%34%20%35%2E%36%36%36%32%34%32%38%2C%32%2E%32%35%34%32%39%38%35%20%36%2E%36%30%38%32%39%32%39%2C%32%2E%32%39%31%36%32%35%35%20%5A%20%4D%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%43%20%32%2E%30%32%32%37%35%31%32%2C%33%2E%35%30%33%31%33%37%32%20%31%2E%32%33%33%35%31%35%36%2C%35%2E%30%37%36%31%32%39%31%20%31%2E%33%30%31%34%31%30%34%2C%36%2E%37%31%31%35%34%33%20%63%20%30%2E%30%32%35%36%31%2C%32%2E%30%36%38%39%30%33%39%20%31%2E%34%35%35%36%36%38%36%2C%33%2E%38%39%33%31%20%33%2E%33%36%38%39%37%36%2C%34%2E%36%35%30%39%37%36%20%43%20%34%2E%31%37%32%37%36%37%37%2C%31%31%2E%31%36%38%37%36%33%20%33%2E%35%38%38%30%32%31%2C%31%31%2E%32%35%32%38%30%37%20%33%2E%31%37%32%32%33%35%35%2C%31%30%2E%39%32%32%37%36%33%20%31%2E%39%32%31%31%31%36%2C%39%2E%39%35%30%33%35%38%34%20%31%2E%31%30%34%34%36%37%34%2C%38%2E%34%30%35%30%36%31%20%31%2E%30%35%35%34%34%35%33%2C%36%2E%38%33%30%37%39%38%38%20%76%20%2D%30%2E%30%30%37%34%35%20%2D%30%2E%30%30%37%34%35%20%43%20%30%2E%39%37%37%30%35%35%31%36%2C%35%2E%33%38%30%30%34%31%36%20%31%2E%34%39%37%38%37%37%33%2C%33%2E%39%30%31%31%36%36%35%20%32%2E%34%38%36%35%31%34%37%2C%32%2E%38%35%30%36%33%37%20%6C%20%30%2E%30%30%37%34%35%2C%2D%30%2E%30%30%37%34%35%20%43%20%32%2E%36%39%32%30%39%38%2C%32%2E%36%32%31%35%32%35%35%20%33%2E%30%35%30%39%35%31%36%2C%32%2E%36%37%31%32%32%34%34%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%5A%20%6D%20%38%2E%31%33%39%32%30%37%32%2C%36%2E%30%35%32%32%33%31%33%20%63%20%2D%30%2E%32%30%37%37%37%34%2C%30%2E%35%31%31%36%32%36%34%20%2D%30%2E%32%31%34%36%32%39%2C%31%2E%30%38%32%30%36%30%39%20%2D%30%2E%35%35%31%35%35%38%2C%31%2E%35%32%37%39%36%34%35%20%6C%20%2D%30%2E%32%36%30%38%37%2C%30%2E%33%35%30%33%31%34%20%30%2E%33%30%35%35%39%32%2C%30%2E%33%31%33%30%34%36%20%63%20%31%2E%32%30%32%31%30%35%2C%31%2E%32%31%35%33%31%33%20%32%2E%34%32%35%35%34%32%2C%32%2E%33%39%36%33%36%38%20%33%2E%36%30%30%30%33%34%2C%33%2E%36%31%34%39%34%31%20%30%2E%31%34%34%30%35%2C%30%2E%31%36%33%37%31%38%20%30%2E%32%38%32%30%31%32%2C%30%2E%32%38%34%33%38%32%20%30%2E%33%35%30%33%31%35%2C%30%2E%33%36%35%32%32%20%30%2E%30%37%32%35%37%2C%30%2E%30%38%35%38%39%20%30%2E%30%36%32%32%38%2C%30%2E%30%38%30%32%37%20%30%2E%30%35%39%36%33%2C%30%2E%31%30%34%33%35%20%76%20%30%2E%30%31%34%39%32%20%30%2E%30%31%34%39%32%20%63%20%2D%36%2E%35%39%65%2D%34%2C%30%2E%30%31%37%32%35%20%2D%30%2E%31%33%31%30%35%35%2C%30%2E%30%37%34%30%37%20%2D%30%2E%31%34%31%36%31%34%2C%30%2E%30%36%37%30%38%20%2D%31%2E%32%31%31%30%37%2C%2D%31%2E%31%32%34%37%35%34%20%2D%32%2E%37%36%37%34%39%34%2C%2D%32%2E%37%34%36%36%30%32%20%2D%34%2E%31%33%36%36%38%39%2C%2D%33%2E%39%36%35%32%38%33%20%4C%20%31%30%2E%33%34%32%34%39%2C%31%30%2E%36%37%36%38%20%31%30%2E%30%31%34%35%33%38%2C%31%30%2E%39%31%35%33%31%31%20%43%20%39%2E%31%33%38%31%38%34%34%2C%31%31%2E%35%34%37%32%33%20%38%2E%31%32%38%32%30%32%2C%31%31%2E%39%39%33%31%36%34%20%37%2E%30%39%32%37%36%39%34%2C%31%32%2E%30%36%33%31%34%37%20%68%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%63%20%2D%30%2E%35%32%39%38%39%31%38%2C%30%2E%30%35%33%39%34%20%2D%30%2E%39%37%39%37%37%37%37%2C%2D%30%2E%33%33%34%30%34%36%20%2D%31%2E%35%30%35%36%32%38%31%2C%2D%30%2E%34%33%39%37%35%36%20%30%2E%35%35%33%33%39%36%38%2C%30%2E%31%30%35%37%34%33%20%31%2E%31%31%31%31%32%35%2C%30%2E%32%34%37%35%32%37%20%31%2E%36%35%34%36%37%33%38%2C%30%2E%31%38%36%33%33%37%20%31%2E%38%38%31%32%39%35%37%2C%2D%30%2E%32%31%30%34%33%32%20%33%2E%34%38%30%35%34%35%39%2C%2D%31%2E%35%34%34%39%31%39%20%34%2E%31%39%36%33%31%32%39%2C%2D%33%2E%32%37%32%30%38%30%35%20%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%36%39%30%36%33%31%20%43%20%34%2E%38%34%39%35%32%30%38%2C%30%2E%35%32%35%32%37%34%30%35%20%33%2E%32%31%38%34%36%38%36%2C%31%2E%32%37%35%31%39%38%31%20%32%2E%31%31%36%38%30%37%38%2C%32%2E%35%30%37%36%38%34%34%20%31%2E%30%32%38%32%36%31%36%2C%33%2E%36%36%34%33%37%37%33%20%30%2E%34%36%32%30%33%33%35%2C%35%2E%32%36%39%39%32%34%39%20%30%2E%35%34%38%30%31%38%33%37%2C%36%2E%38%34%34%38%38%37%34%20%30%2E%36%30%32%30%38%39%35%39%2C%38%2E%35%38%31%32%39%34%33%20%31%2E%34%39%31%39%38%33%32%2C%31%30%2E%32%35%35%39%35%37%20%32%2E%38%36%31%39%37%33%38%2C%31%31%2E%33%32%30%37%35%31%20%63%20%31%2E%31%39%30%34%34%38%36%2C%30%2E%39%34%34%39%35%39%20%32%2E%37%35%37%30%39%31%38%2C%31%2E%34%30%31%31%36%31%20%34%2E%32%36%36%37%32%35%38%2C%31%2E%32%34%37%34%37%37%20%31%2E%31%35%36%34%33%37%33%2C%2D%30%2E%30%37%38%31%36%20%32%2E%32%34%38%31%31%36%39%2C%2D%30%2E%35%37%30%35%36%36%20%33%2E%31%38%31%32%31%31%34%2C%2D%31%2E%32%34%33%34%30%32%20%31%2E%33%36%33%39%38%37%2C%31%2E%32%31%34%30%34%35%20%32%2E%39%35%36%32%32%2C%32%2E%38%36%35%38%30%31%20%34%2E%31%39%33%31%36%31%2C%34%2E%30%30%39%36%39%31%20%30%2E%33%35%37%34%38%35%2C%30%2E%32%33%36%35%31%20%30%2E%39%30%38%35%33%35%2C%2D%30%2E%30%33%34%31%35%20%30%2E%39%32%35%31%35%2C%2D%30%2E%34%36%38%39%38%36%20%30%2E%30%34%32%37%2C%2D%30%2E%33%38%38%32%39%32%20%2D%30%2E%33%33%32%30%38%32%2C%2D%30%2E%36%31%33%33%37%36%20%2D%30%2E%35%35%30%34%36%34%2C%2D%30%2E%38%37%30%30%32%32%20%43%20%31%33%2E%36%39%35%38%30%38%2C%31%32%2E%37%36%39%32%20%31%32%2E%34%37%35%31%36%31%2C%31%31%2E%35%38%31%30%38%31%20%31%31%2E%32%37%37%35%34%35%2C%31%30%2E%33%37%30%33%30%35%20%31%32%2E%30%37%30%31%31%38%2C%39%2E%33%32%31%33%38%37%33%20%31%32%2E%35%39%36%34%32%35%2C%38%2E%30%34%33%30%38%38%36%20%31%32%2E%35%39%35%31%36%31%2C%36%2E%37%32%31%33%34%39%20%31%32%2E%36%32%39%33%30%37%2C%35%2E%37%32%32%32%32%34%35%20%31%32%2E%34%31%38%38%30%31%2C%34%2E%37%31%33%33%32%31%37%20%31%31%2E%39%35%30%39%38%35%2C%33%2E%38%32%38%30%32%34%33%20%31%31%2E%30%34%35%32%38%33%2C%32%2E%30%34%35%33%32%34%38%20%39%2E%32%30%38%33%37%30%31%2C%30%2E%37%34%33%37%37%32%38%35%20%37%2E%32%30%35%37%35%30%33%2C%30%2E%35%36%35%32%30%32%37%31%20%36%2E%39%37%33%31%38%30%31%2C%30%2E%35%34%32%36%38%38%36%33%20%36%2E%37%33%39%33%39%30%37%2C%30%2E%35%33%33%36%38%33%30%35%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%37%30%36%30%31%34%20%5A%20%4D%20%36%2E%36%39%31%35%36%38%32%2C%31%2E%37%38%39%39%33%36%37%20%43%20%38%2E%34%38%36%33%38%36%2C%31%2E%37%39%31%36%31%34%20%31%30%2E%31%39%33%39%35%32%2C%32%2E%39%34%39%37%34%34%20%31%30%2E%39%32%31%34%37%31%2C%34%2E%35%38%30%35%32%36%31%20%31%31%2E%34%35%37%34%38%35%2C%35%2E%37%33%34%36%31%38%37%20%31%31%2E%34%39%35%39%35%38%2C%37%2E%31%31%30%38%36%31%20%31%31%2E%30%33%31%36%37%37%2C%38%2E%32%39%34%37%30%35%37%20%31%30%2E%34%30%37%39%30%33%2C%39%2E%38%39%33%31%30%31%35%20%38%2E%38%38%33%36%36%31%32%2C%31%31%2E%31%31%37%30%32%39%20%37%2E%31%36%39%35%36%32%35%2C%31%31%2E%33%30%38%37%35%38%20%36%2E%34%32%38%39%32%35%37%2C%31%31%2E%33%39%32%31%33%35%20%35%2E%36%36%35%32%39%34%35%2C%31%31%2E%33%33%38%30%32%37%20%34%2E%39%36%35%39%39%37%33%2C%31%31%2E%30%36%36%31%33%32%20%33%2E%31%34%35%33%30%39%32%2C%31%30%2E%34%34%36%35%32%33%20%31%2E%38%31%36%32%30%34%32%2C%38%2E%36%32%31%32%31%39%33%20%31%2E%37%39%36%38%34%32%31%2C%36%2E%36%39%36%36%35%31%31%20%31%2E%37%33%31%32%31%33%37%2C%35%2E%31%39%33%33%34%33%36%20%32%2E%34%35%37%30%34%37%35%2C%33%2E%36%39%37%38%34%30%37%20%33%2E%36%34%35%38%34%38%37%2C%32%2E%37%38%34%32%35%34%35%20%34%2E%34%38%38%36%32%38%34%2C%32%2E%31%32%36%30%36%33%39%20%35%2E%35%35%37%39%30%36%33%2C%31%2E%37%34%37%37%34%39%31%20%36%2E%36%33%31%35%32%35%38%2C%31%2E%37%39%30%32%38%39%34%20%63%20%30%2E%30%31%39%38%38%32%2C%30%20%30%2E%30%34%30%30%33%39%2C%2D%33%2E%36%30%32%65%2D%34%20%30%2E%30%36%30%30%33%36%2C%2D%33%2E%34%38%39%65%2D%34%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
CreateEllipse:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%34%61%33%20%33%20%30%20%31%31%2D%36%20%30%20%33%20%33%20%30%20%30%31%36%20%30%7A%6D%2D%31%20%30%61%32%20%32%20%30%20%31%31%2D%34%20%30%20%32%20%32%20%30%20%30%31%34%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%36%2D%33%2E%35%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%4D%31%35%2E%35%20%34%61%33%2E%35%20%33%2E%35%20%30%20%31%31%2D%37%20%30%20%33%2E%35%20%33%2E%35%20%30%20%30%31%37%20%30%7A%4D%31%32%20%37%61%33%20%33%20%30%20%31%30%30%2D%36%20%33%20%33%20%30%20%30%30%30%20%36%7A%6D%30%2D%31%61%32%20%32%20%30%20%31%30%30%2D%34%20%32%20%32%20%30%20%30%30%30%20%34%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
MovePointer:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%36%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%7A%4D%38%20%31%31%76%33%2E%32%7A%27%20%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%31%4C%36%20%33%6C%2E%35%2E%35%20%31%2D%31%56%37%68%2D%35%6C%31%2D%31%2D%2E%35%2D%2E%35%2D%32%20%32%20%32%20%32%20%2E%35%2D%2E%35%2D%31%2D%31%68%35%76%35%2E%35%6C%2D%31%2D%31%2D%2E%35%2E%35%20%32%20%32%20%32%2D%32%2D%2E%35%2D%2E%35%2D%31%20%31%56%38%68%35%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%68%2D%35%56%32%2E%35%6C%31%20%31%4C%31%30%20%33%20%38%20%31%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%35%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%20%38%20%2E%33%7A%4D%38%20%31%6C%32%20%32%2D%2E%35%2E%35%2D%31%2D%31%56%37%68%35%6C%2D%31%2D%31%20%2E%35%2D%2E%35%20%32%20%32%2D%32%20%32%2D%2E%35%2D%2E%35%20%31%2D%31%68%2D%35%76%35%2E%35%6C%31%2D%31%20%2E%35%2E%35%2D%32%20%32%2D%32%2D%32%20%2E%35%2D%2E%35%20%31%20%31%56%38%68%2D%35%6C%31%20%31%2D%2E%35%2E%35%2D%32%2D%32%20%32%2D%32%20%2E%35%2E%35%2D%31%20%31%68%35%56%32%2E%35%6C%2D%31%20%31%4C%36%20%33%6C%32%2D%32%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ScaleNesw:$app$main$ui$cursors$scale_nesw$$,Rotate:$app$main$ui$cursors$rotate$$,PenNode:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'36px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%37%20%30%2D%2E%30%30%31%2D%2E%31%30%31%2E%36%39%39%2D%2E%33%30%31%6C%33%20%33%20%34%2D%34%2E%31%2D%33%2D%33%20%2E%33%2D%2E%36%63%30%2D%31%2E%37%2D%2E%36%2D%33%2E%30%39%39%2D%31%2E%38%2D%34%2E%30%39%39%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%33%2E%36%32%39%20%31%33%2E%38%30%38%61%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%20%36%2E%39%37%39%20%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%2D%36%2E%39%37%39%7A%6D%30%20%31%2E%38%36%36%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%31%2E%30%30%32%20%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%31%2D%2E%30%30%32%2D%33%2E%32%34%38%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%33%33%33%20%30%20%2E%36%33%39%2D%2E%30%32%38%2E%39%33%37%2D%2E%30%36%33%6C%32%2E%37%36%32%20%32%2E%37%36%32%20%34%2D%34%2E%31%2D%32%2E%37%32%39%2D%32%2E%37%32%38%63%2E%30%31%38%2D%2E%32%38%2E%30%33%2D%2E%35%36%32%2E%30%33%2D%2E%38%37%31%20%30%2D%31%2E%37%2D%2E%36%30%31%2D%33%2E%31%2D%31%2E%38%30%31%2D%34%2E%31%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%32%2E%35%33%37%20%31%2E%37%33%36%63%31%2E%33%31%2E%33%30%36%20%32%2E%36%33%2E%35%37%33%20%33%2E%39%36%33%2E%37%36%34%20%33%20%2E%34%20%35%20%32%2E%31%20%35%20%35%6C%2D%2E%31%20%31%2E%33%2E%31%2E%31%2E%36%39%39%2E%37%20%31%2E%36%30%32%20%31%2E%35%39%39%2D%32%2E%36%30%32%20%32%2E%36%30%32%2D%31%2E%36%2D%31%2E%36%30%32%2D%2E%30%30%34%2D%2E%30%30%34%2D%2E%36%39%35%2D%2E%36%39%35%2D%2E%30%34%37%2E%30%34%37%2D%2E%30%35%32%2D%2E%30%34%37%48%38%2E%32%31%39%63%2D%32%2E%39%20%30%2D%34%2E%36%2D%32%2D%35%2D%35%2D%2E%32%2D%31%2E%37%2D%2E%35%2D%32%2E%39%39%39%2D%2E%37%2D%33%2E%38%39%39%4C%36%2E%33%33%20%37%2E%31%33%63%2D%2E%33%34%2E%38%38%34%2E%31%32%20%32%2E%30%38%39%20%31%2E%33%38%39%20%32%2E%30%38%39%20%32%20%30%20%32%2D%33%20%30%2D%33%2D%2E%32%32%34%20%30%2D%2E%34%31%39%2E%30%34%2D%2E%35%39%32%2E%31%30%37%6C%2D%33%2E%38%37%31%2D%33%2E%38%37%7A%4D%34%2E%33%34%38%20%31%34%2E%39%35%61%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%20%36%2E%31%33%35%20%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%2D%36%2E%31%33%35%7A%6D%30%20%31%2E%30%32%34%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%30%20%34%2E%30%39%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%30%2D%34%2E%30%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto",
ZoomIn:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%31%33%36%34%30%32%2C%30%2E%30%33%33%34%30%32%37%38%20%30%2E%30%30%37%39%32%2C%30%2E%30%30%37%39%30%38%33%20%43%20%34%2E%37%31%33%30%35%39%36%2C%30%2E%30%33%31%37%30%36%33%20%32%2E%39%35%34%33%35%30%35%2C%30%2E%38%33%33%30%35%31%38%35%20%31%2E%37%35%34%39%30%30%31%2C%32%2E%31%37%30%35%38%35%35%20%30%2E%35%36%35%31%31%35%36%36%2C%33%2E%34%33%34%38%35%34%31%20%2D%30%2E%30%34%38%39%33%31%37%39%2C%35%2E%31%36%39%37%38%35%39%20%30%2E%30%34%32%37%38%30%36%39%2C%36%2E%38%38%35%38%33%31%37%20%30%2E%31%30%34%30%35%30%39%33%2C%38%2E%37%38%33%31%33%38%34%20%31%2E%30%36%37%34%39%37%33%2C%31%30%2E%35%38%34%34%39%20%32%2E%35%35%33%36%32%34%37%2C%31%31%2E%37%34%33%34%32%34%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%31%2C%30%20%31%2E%32%39%35%34%39%36%34%2C%31%2E%30%32%35%38%33%36%20%32%2E%39%38%35%30%38%33%34%2C%31%2E%35%31%34%38%38%31%20%34%2E%36%32%36%32%37%39%36%2C%31%2E%33%35%32%32%39%38%20%31%2E%31%31%38%39%32%34%34%2C%2D%30%2E%30%37%37%37%32%20%32%2E%31%31%32%36%32%35%36%2C%2D%30%2E%35%38%32%37%36%32%20%33%2E%30%31%38%39%34%33%37%2C%2D%31%2E%31%36%36%34%35%35%20%31%2E%33%30%30%31%34%35%2C%31%2E%31%37%37%38%30%39%20%32%2E%37%39%31%30%34%34%2C%32%2E%37%30%39%32%30%39%20%33%2E%39%38%39%36%37%31%2C%33%2E%38%31%37%36%36%39%20%6C%20%30%2E%30%32%39%36%35%2C%30%2E%30%32%33%37%32%20%30%2E%30%33%37%35%37%2C%30%2E%30%32%31%37%33%20%63%20%30%2E%37%30%32%34%39%34%2C%30%2E%34%36%34%37%37%39%20%31%2E%36%36%31%39%35%39%2C%2D%30%2E%30%31%33%37%33%20%31%2E%37%30%34%32%31%2C%2D%30%2E%38%35%39%39%39%32%20%30%2E%30%32%38%34%36%2C%2D%30%2E%33%35%33%31%30%37%20%2D%30%2E%31%33%37%35%35%37%2C%2D%30%2E%36%36%30%36%39%31%20%2D%30%2E%32%39%32%36%30%32%2C%2D%30%2E%38%34%34%31%39%37%20%2D%30%2E%31%35%39%31%34%36%2C%2D%30%2E%31%38%38%33%36%20%2D%30%2E%33%30%39%34%37%37%2C%2D%30%2E%33%31%32%30%36%38%20%2D%30%2E%33%37%33%36%36%33%2C%2D%30%2E%33%38%37%35%30%31%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%35%2C%2D%30%2E%30%31%35%38%20%43%20%31%34%2E%31%35%33%38%32%36%2C%31%32%2E%35%30%38%36%38%39%20%31%33%2E%30%30%33%38%36%2C%31%31%2E%33%38%31%32%35%36%20%31%31%2E%38%37%31%34%32%35%2C%31%30%2E%32%34%30%38%37%33%20%31%32%2E%35%36%30%31%31%33%2C%39%2E%31%39%39%35%37%34%34%20%31%33%2E%31%33%34%32%39%2C%38%2E%30%33%30%33%38%30%37%20%31%33%2E%31%33%34%37%35%35%2C%36%2E%37%34%33%34%38%34%34%20%31%33%2E%31%36%39%31%39%33%2C%35%2E%36%36%36%34%36%31%38%20%31%32%2E%39%34%32%30%35%33%2C%34%2E%35%37%32%34%32%30%37%20%31%32%2E%34%33%32%39%30%36%2C%33%2E%36%30%35%39%31%38%32%20%31%31%2E%34%34%35%37%38%31%2C%31%2E%36%36%32%39%35%34%39%20%39%2E%34%37%31%32%38%37%35%2C%30%2E%32%36%31%31%35%34%34%36%20%37%2E%32%37%36%37%37%39%32%2C%30%2E%30%36%33%30%35%38%34%33%20%68%20%2D%30%2E%30%30%37%39%32%20%43%20%37%2E%31%38%39%36%31%38%31%2C%30%2E%30%35%35%34%37%38%32%38%20%37%2E%31%30%38%39%32%37%39%2C%30%2E%30%35%39%38%37%33%37%31%20%37%2E%30%32%39%36%34%38%37%2C%30%2E%30%35%35%31%35%30%32%35%20%56%20%30%2E%30%33%33%34%30%32%37%38%20%48%20%36%2E%35%32%39%34%35%36%35%20%63%20%2D%30%2E%30%30%34%39%34%2C%36%2E%31%31%37%65%2D%35%20%2D%30%2E%30%31%30%38%36%35%2C%2D%37%2E%31%33%32%65%2D%35%20%2D%30%2E%30%31%35%38%30%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%32%2C%31%2E%30%30%38%32%39%31%36%32%20%68%20%30%2E%30%30%37%39%32%20%63%20%30%2E%32%31%36%33%30%37%35%2C%2D%30%2E%30%30%33%31%33%20%30%2E%34%33%36%37%38%36%33%2C%30%2E%30%30%38%39%37%20%30%2E%36%35%30%34%34%36%37%2C%30%2E%30%32%39%36%35%34%20%31%2E%38%31%38%32%33%36%34%2C%30%2E%31%36%32%31%32%39%20%33%2E%35%31%39%36%34%32%31%2C%31%2E%33%36%37%36%38%35%32%20%34%2E%33%34%37%35%31%36%31%2C%32%2E%39%39%37%31%39%36%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%32%34%31%32%31%2C%30%2E%38%30%32%35%35%33%33%20%30%2E%36%32%32%35%34%35%2C%31%2E%37%32%36%32%32%38%33%20%30%2E%35%39%31%31%33%35%2C%32%2E%36%34%35%32%38%32%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%33%20%76%20%30%2E%30%30%37%39%32%20%43%20%31%32%2E%31%31%39%30%39%36%2C%37%2E%33%31%31%31%30%38%36%20%31%31%2E%37%32%38%36%37%35%2C%37%2E%38%30%36%39%38%31%35%20%31%31%2E%35%32%39%33%39%39%2C%38%2E%33%35%36%37%35%32%34%20%31%31%2E%39%39%31%38%35%34%2C%37%2E%30%37%30%30%35%36%31%20%31%31%2E%39%38%36%33%37%35%2C%35%2E%36%32%36%34%37%38%20%31%31%2E%34%30%38%37%39%39%2C%34%2E%33%38%32%38%39%37%31%20%31%30%2E%35%39%34%32%37%36%2C%32%2E%35%36%33%35%36%35%37%20%38%2E%37%32%33%38%39%35%39%2C%31%2E%32%39%30%37%30%37%33%20%36%2E%37%30%39%33%36%37%39%2C%31%2E%32%38%38%38%32%34%37%20%63%20%2D%30%2E%30%31%36%34%38%39%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%39%30%31%2C%2D%31%2E%30%36%36%65%2D%34%20%2D%30%2E%30%33%37%35%37%2C%30%20%43%20%35%2E%36%39%39%38%36%32%34%2C%31%2E%32%35%30%33%31%32%35%20%34%2E%38%31%39%36%37%36%35%2C%31%2E%36%39%33%33%39%37%34%20%33%2E%39%39%36%38%36%35%36%2C%32%2E%31%37%38%34%39%33%38%20%34%2E%38%31%39%34%32%39%34%2C%31%2E%36%39%37%33%33%31%20%35%2E%35%37%35%38%34%39%31%2C%31%2E%30%33%35%30%35%32%36%20%36%2E%35%32%31%35%34%38%39%2C%31%2E%30%34%31%36%39%34%34%20%5A%20%6D%20%2D%30%2E%30%37%33%31%34%39%2C%31%2E%32%35%33%34%34%34%38%20%63%20%30%2E%30%35%39%30%39%37%2C%2D%35%2E%35%34%34%65%2D%34%20%30%2E%31%31%38%39%30%36%32%2C%2D%33%2E%36%31%37%65%2D%34%20%30%2E%31%37%37%39%33%34%36%2C%30%2E%30%30%31%39%38%20%68%20%30%2E%30%31%35%38%30%31%20%30%2E%30%30%35%39%33%20%63%20%30%2E%30%32%36%30%35%34%2C%30%20%30%2E%30%34%37%35%31%33%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%36%31%32%38%39%2C%30%20%31%2E%35%38%31%39%32%32%36%2C%30%2E%30%30%31%34%38%20%33%2E%31%33%34%34%37%36%36%2C%31%2E%30%35%35%37%31%36%33%20%33%2E%37%38%30%31%30%35%32%2C%32%2E%35%30%32%39%33%35%37%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%37%36%35%31%2C%31%2E%30%32%35%39%37%39%31%20%30%2E%35%31%30%31%37%38%2C%32%2E%32%37%31%35%32%36%20%30%2E%30%39%36%38%37%2C%33%2E%33%32%35%33%38%35%33%20%2D%30%2E%35%35%35%36%34%2C%31%2E%34%32%33%38%31%39%36%20%2D%31%2E%39%33%37%30%32%37%2C%32%2E%35%32%37%32%33%35%38%20%2D%33%2E%34%35%31%39%31%33%33%2C%32%2E%36%39%36%36%38%32%38%20%2D%30%2E%36%37%39%38%38%34%38%2C%30%2E%30%37%36%35%33%20%2D%31%2E%33%36%36%38%37%38%37%2C%30%2E%30%32%38%31%32%20%2D%31%2E%39%37%33%30%38%38%37%2C%2D%30%2E%32%30%37%35%38%39%20%68%20%2D%30%2E%30%30%35%39%33%20%6C%20%2D%30%2E%30%31%35%38%30%31%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%33%30%31%39%36%39%2C%31%30%2E%30%36%36%38%31%36%20%32%2E%33%32%35%35%37%30%39%2C%38%2E%34%30%35%35%37%37%36%20%32%2E%33%30%38%34%37%31%2C%36%2E%37%30%35%39%32%30%37%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%35%39%33%20%43%20%32%2E%32%35%30%34%30%37%36%2C%35%2E%33%36%32%30%31%39%34%20%32%2E%39%30%38%30%38%34%38%2C%34%2E%30%30%38%36%32%34%31%20%33%2E%39%36%37%32%30%39%38%2C%33%2E%31%39%34%36%39%33%35%20%76%20%2D%30%2E%30%30%37%39%31%20%43%20%34%2E%36%37%35%33%37%39%39%2C%32%2E%36%33%33%37%32%31%31%20%35%2E%35%36%31%39%34%34%32%2C%32%2E%33%30%33%34%35%35%33%20%36%2E%34%34%38%33%39%37%39%2C%32%2E%32%39%35%31%33%39%32%20%5A%20%4D%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%43%20%32%2E%30%32%38%35%37%30%39%2C%33%2E%35%31%31%31%35%34%34%20%31%2E%32%33%38%30%34%35%35%2C%35%2E%30%38%38%31%32%39%33%20%31%2E%33%30%36%31%31%30%39%2C%36%2E%37%32%37%36%36%38%31%20%31%2E%33%33%31%37%38%35%35%2C%38%2E%38%30%31%37%39%30%34%20%32%2E%37%36%34%37%36%36%2C%31%30%2E%36%33%31%37%32%34%20%34%2E%36%38%32%38%39%39%36%2C%31%31%2E%33%39%31%35%31%31%20%34%2E%31%38%34%30%32%35%37%2C%31%31%2E%31%39%37%32%36%37%20%33%2E%35%39%39%31%35%38%31%2C%31%31%2E%32%38%31%35%30%37%20%33%2E%31%38%32%33%32%34%35%2C%31%30%2E%39%35%30%36%33%20%31%2E%39%32%38%30%34%38%38%2C%39%2E%39%37%35%37%37%32%39%20%31%2E%31%30%38%31%32%36%38%2C%38%2E%34%32%36%35%30%30%36%20%31%2E%30%35%38%39%38%31%32%2C%36%2E%38%34%38%32%36%37%36%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%30%2E%39%38%30%33%39%30%34%38%2C%35%2E%33%39%32%39%37%39%34%20%31%2E%35%30%33%31%38%33%2C%33%2E%39%31%31%37%37%35%36%20%32%2E%34%39%34%33%31%33%32%2C%32%2E%38%35%38%35%39%36%34%20%6C%20%30%2E%30%30%37%39%31%2C%2D%30%2E%30%30%37%39%31%20%43%20%32%2E%37%30%30%38%34%39%38%2C%32%2E%36%32%38%34%37%30%35%20%33%2E%30%35%39%33%36%35%2C%32%2E%36%37%37%31%34%33%32%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%5A%20%4D%20%35%2E%35%31%33%32%35%36%39%2C%33%2E%33%34%32%39%37%31%37%20%56%20%33%2E%38%34%35%31%34%30%33%20%35%2E%34%38%38%30%36%32%37%20%48%20%33%2E%33%36%38%31%36%36%37%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%35%2E%35%31%33%32%35%36%39%20%56%20%39%2E%37%39%39%39%39%31%38%20%48%20%37%2E%36%38%38%30%30%34%31%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%39%2E%38%33%33%30%39%34%34%20%56%20%35%2E%34%38%38%30%36%32%37%20%48%20%37%2E%36%38%38%30%30%34%31%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%20%6D%20%31%2E%30%31%36%31%39%39%36%2C%31%2E%30%31%30%32%36%38%34%20%68%20%30%2E%31%34%32%33%34%36%39%20%76%20%32%2E%31%34%33%31%31%34%32%20%68%20%32%2E%31%34%35%30%39%31%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%36%2E%36%37%31%38%30%33%38%20%56%20%38%2E%37%39%31%37%30%30%36%20%48%20%36%2E%35%32%39%34%35%36%35%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%34%2E%33%38%34%33%36%36%32%20%56%20%36%2E%34%39%36%33%35%34%33%20%48%20%36%2E%35%32%39%34%35%36%35%20%5A%20%4D%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%43%20%31%31%2E%32%34%35%39%37%33%2C%39%2E%30%37%31%33%32%36%20%31%31%2E%32%33%38%34%37%35%2C%39%2E%36%34%33%35%38%38%38%20%31%30%2E%39%30%30%36%39%38%2C%31%30%2E%30%39%30%36%31%37%20%6C%20%2D%30%2E%32%36%30%39%37%2C%30%2E%33%35%31%39%31%34%20%30%2E%33%30%36%34%34%33%2C%30%2E%33%31%34%33%34%37%20%63%20%31%2E%32%30%35%31%33%37%2C%31%2E%32%31%38%33%37%39%20%32%2E%34%33%30%36%34%37%2C%32%2E%34%30%32%32%37%32%20%33%2E%36%30%38%31%30%32%2C%33%2E%36%32%33%39%31%39%20%30%2E%31%34%34%34%31%33%2C%30%2E%31%36%34%31%33%31%20%30%2E%32%38%33%34%33%39%2C%30%2E%32%38%34%37%31%33%20%30%2E%33%35%31%39%31%34%2C%30%2E%33%36%35%37%35%31%20%30%2E%30%37%32%37%35%2C%30%2E%30%38%36%31%20%30%2E%30%36%31%39%37%2C%30%2E%30%38%30%36%34%20%30%2E%30%35%39%33%31%2C%30%2E%31%30%34%37%38%35%20%76%20%30%2E%30%31%33%38%35%20%30%2E%30%31%35%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%39%20%2D%30%2E%31%33%31%37%36%31%2C%30%2E%30%37%34%32%33%20%2D%30%2E%31%34%32%33%34%37%2C%30%2E%30%36%37%32%32%20%2D%31%2E%32%31%34%31%32%35%2C%2D%31%2E%31%32%37%35%38%34%20%2D%32%2E%37%37%33%32%31%31%2C%2D%32%2E%37%35%34%30%37%20%2D%34%2E%31%34%35%38%35%39%2C%2D%33%2E%39%37%35%38%32%34%20%6C%20%2D%30%2E%33%30%36%34%34%33%2C%2D%30%2E%32%36%38%38%37%38%20%2D%30%2E%33%33%30%31%36%38%2C%30%2E%32%33%39%32%32%20%63%20%2D%30%2E%38%37%38%35%36%31%39%2C%30%2E%36%33%33%35%31%34%20%2D%31%2E%38%38%39%39%35%32%2C%31%2E%30%38%30%34%38%31%20%2D%32%2E%39%32%37%39%39%36%39%2C%31%2E%31%35%30%36%34%31%20%68%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%36%2E%35%36%35%36%33%39%35%2C%31%32%2E%31%34%37%34%33%39%20%36%2E%31%31%35%35%36%31%35%2C%31%31%2E%37%35%38%34%35%37%20%35%2E%35%38%38%33%38%34%37%2C%31%31%2E%36%35%32%34%38%31%20%36%2E%31%34%33%31%37%37%34%2C%31%31%2E%37%35%38%34%39%20%36%2E%37%30%32%32%30%33%33%2C%31%31%2E%39%30%31%36%34%35%20%37%2E%32%34%37%31%32%33%34%2C%31%31%2E%38%34%30%33%30%32%20%39%2E%31%33%33%31%36%33%39%2C%31%31%2E%36%32%39%33%33%39%20%31%30%2E%37%33%36%36%39%37%2C%31%30%2E%32%38%39%39%32%39%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%5A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%43%20%34%2E%38%35%37%38%35%32%37%2C%30%2E%35%33%30%35%30%31%31%36%20%33%2E%32%32%33%38%31%38%31%2C%31%2E%32%38%33%36%31%30%32%20%32%2E%31%31%39%33%37%39%31%2C%32%2E%35%31%39%32%30%35%31%20%31%2E%30%32%38%30%38%37%32%2C%33%2E%36%37%38%38%31%35%34%20%30%2E%34%35%39%34%35%32%30%35%2C%35%2E%32%38%37%37%38%36%35%20%30%2E%35%34%35%36%35%32%38%38%2C%36%2E%38%36%36%37%32%31%34%20%30%2E%35%39%39%38%36%31%36%37%2C%38%2E%36%30%37%35%30%38%31%20%31%2E%34%39%31%32%37%37%36%2C%31%30%2E%32%38%37%31%32%38%20%32%2E%38%36%34%37%32%33%39%2C%31%31%2E%33%35%34%36%30%38%20%63%20%31%2E%31%39%33%34%35%31%2C%30%2E%39%34%37%33%34%32%20%32%2E%37%36%34%38%37%38%32%2C%31%2E%34%30%33%35%36%32%20%34%2E%32%37%38%33%31%39%31%2C%31%2E%32%34%39%34%39%31%20%31%2E%31%35%39%33%35%34%35%2C%2D%30%2E%30%37%38%33%36%20%32%2E%32%35%33%35%32%32%32%2C%2D%30%2E%35%37%31%30%30%34%20%33%2E%31%38%38%39%37%2C%2D%31%2E%32%34%35%35%33%37%20%31%2E%33%36%37%34%32%37%2C%31%2E%32%31%37%31%30%37%20%32%2E%39%36%33%31%33%32%2C%32%2E%38%37%32%35%35%32%20%34%2E%32%30%33%31%39%32%2C%34%2E%30%31%39%33%32%37%20%30%2E%33%35%38%33%38%37%2C%30%2E%32%33%37%31%30%34%20%30%2E%39%31%32%35%35%33%2C%2D%30%2E%30%33%34%35%38%20%30%2E%39%32%39%32%31%2C%2D%30%2E%34%37%30%35%33%37%20%30%2E%30%34%32%38%31%2C%2D%30%2E%33%38%39%32%37%31%20%2D%30%2E%33%33%34%36%33%39%2C%2D%30%2E%36%31%34%35%38%33%20%2D%30%2E%35%35%33%35%37%31%2C%2D%30%2E%38%37%31%38%37%35%20%43%20%31%33%2E%37%32%35%39%31%33%2C%31%32%2E%38%30%36%30%37%34%20%31%32%2E%35%30%33%33%37%37%2C%31%31%2E%36%31%35%35%30%32%20%31%31%2E%33%30%32%37%34%31%2C%31%30%2E%34%30%31%36%37%33%20%31%32%2E%30%39%37%33%31%33%2C%39%2E%33%35%30%31%30%39%34%20%31%32%2E%36%32%34%36%37%34%2C%38%2E%30%36%37%32%34%30%39%20%31%32%2E%36%32%33%34%30%35%2C%36%2E%37%34%32%31%36%37%36%20%31%32%2E%36%35%37%36%33%37%2C%35%2E%37%34%30%35%32%32%39%20%31%32%2E%34%34%35%39%30%38%2C%34%2E%37%32%39%33%37%36%39%20%31%31%2E%39%37%36%39%31%32%2C%33%2E%38%34%31%38%34%36%36%20%31%31%2E%30%36%38%39%32%36%2C%32%2E%30%35%34%36%35%30%34%20%39%2E%32%32%37%38%31%38%36%2C%30%2E%37%35%30%38%33%38%39%33%20%37%2E%32%32%30%31%34%38%2C%30%2E%35%37%31%38%31%38%33%39%20%36%2E%39%38%36%39%39%31%37%2C%30%2E%35%34%39%32%34%36%31%31%20%36%2E%37%35%32%34%38%39%34%2C%30%2E%35%33%38%37%38%32%35%31%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%5A%20%4D%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%63%20%30%2E%30%36%37%31%38%31%2C%2D%35%2E%39%36%33%65%2D%34%20%30%2E%31%33%34%33%38%39%32%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%36%35%38%35%2C%30%2E%30%30%33%39%36%20%30%2E%30%31%39%39%33%32%2C%30%20%30%2E%30%33%39%32%36%34%2C%2D%31%2E%31%33%65%2D%35%20%30%2E%30%35%39%33%31%31%2C%30%20%31%2E%37%39%39%33%34%34%39%2C%30%2E%30%30%31%36%38%20%33%2E%35%31%31%34%30%33%32%2C%31%2E%31%36%32%36%31%39%34%20%34%2E%32%34%30%37%35%36%32%2C%32%2E%37%39%37%35%31%35%20%30%2E%35%33%37%33%36%36%2C%31%2E%31%35%37%30%30%33%35%20%30%2E%35%37%36%31%36%36%2C%32%2E%35%33%35%39%34%20%30%2E%31%31%30%37%31%35%2C%33%2E%37%32%32%37%37%31%31%20%43%20%31%30%2E%34%33%30%32%36%34%2C%39%2E%39%32%32%32%37%35%20%38%2E%39%30%32%39%38%34%2C%31%31%2E%31%35%30%35%33%32%20%37%2E%31%38%34%35%36%31%35%2C%31%31%2E%33%34%32%37%34%35%20%36%2E%34%34%32%30%35%37%2C%31%31%2E%34%32%36%33%33%33%20%35%2E%36%37%35%32%38%38%38%2C%31%31%2E%33%37%32%31%35%20%34%2E%39%37%34%32%32%37%38%2C%31%31%2E%30%39%39%35%37%20%33%2E%31%34%38%39%34%37%33%2C%31%30%2E%34%37%38%33%39%38%20%31%2E%38%31%36%35%33%32%34%2C%38%2E%36%34%37%38%36%35%34%20%31%2E%37%39%37%31%32%30%36%2C%36%2E%37%31%38%34%34%33%33%20%31%2E%37%33%31%33%32%37%36%2C%35%2E%32%31%31%33%34%34%31%20%32%2E%34%35%39%37%38%37%32%2C%33%2E%37%31%31%38%38%31%35%20%33%2E%36%35%31%35%38%37%31%2C%32%2E%37%39%35%39%39%31%31%20%34%2E%34%34%33%36%38%35%34%2C%32%2E%31%37%37%33%38%31%20%35%2E%34%33%35%34%33%39%32%2C%31%2E%38%30%34%35%35%31%33%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%5A%20%4D%20%36%2E%30%31%36%31%32%39%31%2C%33%2E%38%35%31%37%33%31%38%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%33%2E%38%37%31%30%33%38%39%20%76%20%31%2E%31%35%36%35%36%39%37%20%68%20%32%2E%31%34%35%30%39%30%32%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%37%2E%31%37%32%36%39%38%38%20%56%20%37%2E%31%35%33%33%39%32%35%20%48%20%39%2E%33%31%37%37%39%30%32%20%56%20%35%2E%39%39%36%38%32%32%38%20%48%20%37%2E%31%37%32%36%39%38%38%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ResizeNs2:$app$main$ui$cursors$resize_ns_2$$,Duplicate:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%35%2E%31%20%30%4C%31%36%20%31%30%2E%39%48%39%2E%32%4C%35%2E%31%20%31%35%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%35%2E%37%20%31%2E%35%6C%38%2E%37%20%38%2E%36%48%39%6C%2D%33%2E%33%20%33%2E%34%7A%6D%33%20%37%2E%39%68%34%4C%36%2E%35%20%33%2E%33%76%38%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%30%20%30%76%31%35%6C%34%2E%31%2D%34%2E%31%68%32%2E%34%76%2E%38%6C%2E%38%2D%2E%38%68%33%2E%36%4C%39%2E%33%20%39%2E%35%68%33%2E%34%4C%36%2E%35%20%33%2E%33%76%33%2E%32%7A%6D%31%20%32%2E%33%6C%35%2E%34%20%35%2E%35%76%32%2E%31%48%33%2E%37%4C%31%20%31%32%2E%37%7A%6D%37%2E%34%20%37%2E%34%6C%2E%32%2E%32%68%2D%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%32%2E%37%56%32%2E%33%6C%37%2E%37%20%37%2E%36%68%2D%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto",
Text:$app$main$ui$cursors$text$$,CreateArtboard:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%34%2D%31%76%35%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%35%20%34%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%76%2D%32%7A%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%33%2E%35%2D%31%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%39%20%39%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ZoomOut:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%30%33%35%37%30%34%2C%30%2E%30%33%33%34%30%34%35%36%20%30%2E%30%30%37%39%31%2C%30%2E%30%30%37%38%39%35%37%20%43%20%34%2E%37%30%35%38%36%31%34%2C%30%2E%30%33%31%37%31%30%37%35%20%32%2E%39%34%39%39%35%31%35%2C%30%2E%38%33%31%37%37%39%31%36%20%31%2E%37%35%32%34%31%33%38%2C%32%2E%31%36%37%31%38%31%31%20%30%2E%35%36%34%35%32%35%35%39%2C%33%2E%34%32%39%34%33%34%37%20%2D%30%2E%30%34%38%35%34%32%32%31%2C%35%2E%31%36%31%36%30%31%33%20%30%2E%30%34%33%30%32%34%31%31%2C%36%2E%38%37%34%39%31%32%31%20%30%2E%31%30%34%31%37%37%34%38%2C%38%2E%37%36%39%31%39%34%39%20%31%2E%30%36%36%31%30%36%35%2C%31%30%2E%35%36%37%36%37%35%20%32%2E%35%34%39%38%36%36%34%2C%31%31%2E%37%32%34%37%36%32%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%33%37%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%2C%30%20%31%2E%32%39%33%34%33%30%34%2C%31%2E%30%32%34%32%30%32%20%32%2E%39%37%38%33%34%36%37%2C%31%2E%35%31%32%34%36%37%20%34%2E%36%31%36%39%33%31%34%2C%31%2E%33%35%30%31%34%33%20%31%2E%31%31%37%31%34%2C%2D%30%2E%30%37%37%36%20%32%2E%31%30%39%32%36%31%36%2C%2D%30%2E%35%38%31%38%33%33%20%33%2E%30%31%34%31%33%33%32%2C%2D%31%2E%31%36%34%35%39%36%20%31%2E%32%39%38%30%37%31%2C%31%2E%31%37%35%39%33%32%20%32%2E%37%38%38%35%37%2C%32%2E%37%30%34%38%39%31%20%33%2E%39%38%35%32%38%36%2C%33%2E%38%31%31%35%38%34%20%6C%20%30%2E%30%32%39%36%2C%30%2E%30%32%33%36%38%20%30%2E%30%33%37%35%31%2C%30%2E%30%32%31%37%20%63%20%30%2E%37%30%31%33%37%32%2C%30%2E%34%36%34%30%31%37%20%31%2E%36%35%37%33%34%2C%2D%30%2E%30%31%33%37%35%20%31%2E%36%39%39%35%32%31%2C%2D%30%2E%38%35%38%36%34%33%20%30%2E%30%32%38%32%37%2C%2D%30%2E%33%35%32%35%34%34%20%2D%30%2E%31%33%35%33%38%36%2C%2D%30%2E%36%35%39%36%33%38%20%2D%30%2E%32%39%30%31%36%31%2C%2D%30%2E%38%34%32%38%35%31%20%2D%30%2E%31%35%38%39%2C%2D%30%2E%31%38%38%30%36%20%2D%30%2E%33%30%38%39%37%32%2C%2D%30%2E%33%31%31%35%37%20%2D%30%2E%33%37%33%30%36%37%2C%2D%30%2E%33%38%36%38%38%33%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%33%2C%2D%30%2E%30%31%35%37%38%20%43%20%31%34%2E%31%33%31%32%38%32%2C%31%32%2E%34%38%38%38%30%38%20%31%32%2E%39%38%33%34%34%34%2C%31%31%2E%33%36%33%31%37%32%20%31%31%2E%38%35%32%38%31%36%2C%31%30%2E%32%32%34%36%30%36%20%31%32%2E%35%34%30%34%30%37%2C%39%2E%31%38%34%39%36%37%32%20%31%33%2E%31%31%33%36%37%31%2C%38%2E%30%31%37%36%33%37%20%31%33%2E%31%31%34%31%33%33%2C%36%2E%37%33%32%37%39%31%37%20%31%33%2E%31%34%38%35%31%38%2C%35%2E%36%35%37%34%38%35%36%20%31%32%2E%39%32%31%37%34%2C%34%2E%35%36%35%31%38%38%32%20%31%32%2E%34%31%33%34%30%32%2C%33%2E%36%30%30%32%32%36%31%20%31%31%2E%34%32%37%38%35%2C%31%2E%36%36%30%33%35%39%35%20%39%2E%34%35%36%35%30%33%2C%30%2E%32%36%30%37%39%33%32%36%20%37%2E%32%36%35%34%39%33%31%2C%30%2E%30%36%33%30%31%32%39%35%20%68%20%2D%30%2E%30%30%37%39%31%20%43%20%37%2E%31%37%38%34%39%31%31%2C%30%2E%30%35%35%34%34%34%39%36%20%37%2E%30%39%37%39%30%31%33%2C%30%2E%30%35%39%38%33%33%32%33%20%37%2E%30%31%38%37%35%36%35%2C%30%2E%30%35%35%31%31%37%33%38%20%56%20%30%2E%30%33%33%34%30%34%35%36%20%68%20%2D%30%2E%34%39%39%33%39%35%20%63%20%2D%30%2E%30%30%34%39%37%2C%36%2E%31%30%38%65%2D%35%20%2D%30%2E%30%31%30%38%31%2C%2D%37%2E%31%32%65%2D%35%20%2D%30%2E%30%31%35%37%37%35%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%31%2C%31%2E%30%30%36%36%38%34%36%34%20%68%20%30%2E%30%30%37%39%31%20%63%20%30%2E%32%31%35%39%36%36%36%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%36%30%39%30%39%2C%30%2E%30%30%38%39%35%20%30%2E%36%34%39%34%31%31%32%2C%30%2E%30%32%39%36%30%37%20%31%2E%38%31%35%33%33%37%33%2C%30%2E%31%36%31%38%37%30%36%20%33%2E%35%31%34%30%33%31%34%2C%31%2E%33%36%35%35%30%35%34%20%34%2E%33%34%30%35%38%35%34%2C%32%2E%39%39%32%34%31%39%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%32%33%34%34%36%2C%30%2E%38%30%31%32%37%34%32%20%30%2E%36%32%31%35%35%33%2C%31%2E%37%32%33%34%37%37%31%20%30%2E%35%39%30%31%39%33%2C%32%2E%36%34%31%30%36%36%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%32%20%76%20%30%2E%30%30%37%39%31%20%43%20%31%32%2E%31%30%30%30%39%32%2C%37%2E%32%39%39%35%30%39%39%20%31%31%2E%37%30%38%33%32%2C%37%2E%37%39%34%35%39%32%35%20%31%31%2E%35%30%39%33%35%39%2C%38%2E%33%34%33%34%38%37%31%20%31%31%2E%39%37%31%30%37%39%2C%37%2E%30%35%38%38%34%31%36%20%31%31%2E%39%36%37%35%38%34%2C%35%2E%36%31%37%35%36%34%32%20%31%31%2E%33%39%30%39%32%36%2C%34%2E%33%37%35%39%36%35%34%20%31%30%2E%35%37%37%37%30%36%2C%32%2E%35%35%39%35%33%35%20%38%2E%37%31%30%33%30%31%35%2C%31%2E%32%38%38%37%30%35%32%20%36%2E%36%39%38%39%38%36%31%2C%31%2E%32%38%36%38%32%35%36%20%63%20%2D%30%2E%30%31%36%34%32%35%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%36%38%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%35%30%39%2C%30%20%43%20%35%2E%36%39%31%30%38%37%36%2C%31%2E%32%34%38%33%37%34%39%20%34%2E%38%31%32%33%30%38%34%2C%31%2E%36%39%30%37%35%33%35%20%33%2E%39%39%30%38%30%37%2C%32%2E%31%37%35%30%37%36%38%20%34%2E%38%31%32%30%36%30%39%2C%31%2E%36%39%34%36%38%30%39%20%35%2E%35%36%37%32%37%35%31%2C%31%2E%30%33%33%34%35%37%39%20%36%2E%35%31%31%34%36%36%35%2C%31%2E%30%34%30%30%38%39%32%20%5A%20%6D%20%2D%30%2E%30%37%33%30%33%33%2C%31%2E%32%35%31%34%34%37%31%20%63%20%30%2E%30%35%39%30%30%33%2C%2D%35%2E%35%33%36%65%2D%34%20%30%2E%31%31%38%37%31%36%37%2C%2D%33%2E%36%31%32%65%2D%34%20%30%2E%31%37%37%36%35%31%2C%30%2E%30%30%31%39%37%20%68%20%30%2E%30%31%35%37%37%35%20%30%2E%30%30%35%39%32%20%63%20%30%2E%30%32%35%39%37%34%2C%30%20%30%2E%30%34%37%34%30%33%2C%2D%37%2E%36%65%2D%36%20%30%2E%30%36%31%31%39%32%2C%30%20%31%2E%35%37%39%34%30%31%33%2C%30%2E%30%30%31%34%38%20%33%2E%31%32%39%34%38%30%39%2C%31%2E%30%35%34%30%33%33%38%20%33%2E%37%37%34%30%38%30%36%2C%32%2E%34%39%38%39%34%36%35%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%37%35%37%34%39%2C%31%2E%30%32%34%33%34%33%39%20%30%2E%35%30%39%33%36%33%2C%32%2E%32%36%37%39%30%35%37%20%30%2E%30%39%36%37%32%2C%33%2E%33%32%30%30%38%35%33%20%2D%30%2E%35%35%34%37%36%2C%31%2E%34%32%31%35%35%34%20%2D%31%2E%39%33%33%39%34%31%33%2C%32%2E%35%32%33%32%31%30%39%20%2D%33%2E%34%34%36%34%31%33%32%2C%32%2E%36%39%32%33%38%37%39%20%2D%30%2E%36%37%38%38%30%31%32%2C%30%2E%30%37%36%34%31%20%2D%31%2E%33%36%34%37%30%32%35%2C%30%2E%30%32%38%30%37%20%2D%31%2E%39%36%39%39%34%33%37%2C%2D%30%2E%32%30%37%32%35%38%20%68%20%2D%30%2E%30%30%37%39%31%20%6C%20%2D%30%2E%30%31%33%38%32%37%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%32%34%36%35%39%38%2C%31%30%2E%30%35%30%38%32%35%20%32%2E%33%32%30%32%30%30%32%2C%38%2E%33%39%32%32%33%35%38%20%32%2E%33%30%33%31%32%39%36%2C%36%2E%36%39%35%32%38%37%38%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%35%39%32%20%43%20%32%2E%32%34%35%31%34%36%36%2C%35%2E%33%35%33%35%32%38%35%20%32%2E%39%30%31%37%38%36%38%2C%34%2E%30%30%32%32%39%30%31%20%33%2E%39%35%39%32%32%34%34%2C%33%2E%31%38%39%36%35%36%39%20%76%20%2D%30%2E%30%30%37%39%20%43%20%34%2E%36%36%36%32%36%34%2C%32%2E%36%32%39%35%37%38%36%20%35%2E%35%35%33%33%39%32%2C%32%2E%32%39%39%38%33%39%31%20%36%2E%34%33%38%34%33%32%31%2C%32%2E%32%39%31%35%33%36%33%20%5A%20%4D%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%43%20%32%2E%30%32%35%34%35%30%33%2C%33%2E%35%30%35%36%31%33%32%20%31%2E%32%33%36%33%38%34%39%2C%35%2E%30%38%30%30%37%34%38%20%31%2E%33%30%34%33%34%30%38%2C%36%2E%37%31%37%30%30%30%36%20%31%2E%33%32%39%39%33%33%31%2C%38%2E%37%38%37%38%31%37%32%20%32%2E%37%36%30%36%36%39%32%2C%31%30%2E%36%31%34%38%33%34%20%34%2E%36%37%35%37%34%38%2C%31%31%2E%33%37%33%34%31%20%34%2E%31%37%37%36%36%38%38%2C%31%31%2E%31%37%39%34%37%36%20%33%2E%35%39%33%37%33%33%34%2C%31%31%2E%32%36%33%35%38%32%20%33%2E%31%37%37%35%36%34%31%2C%31%30%2E%39%33%33%32%33%32%20%31%2E%39%32%35%32%38%36%35%2C%39%2E%39%35%39%39%32%38%36%20%31%2E%31%30%36%36%37%32%32%2C%38%2E%34%31%33%31%32%35%35%20%31%2E%30%35%37%36%30%34%2C%36%2E%38%33%37%34%30%37%39%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%43%20%30%2E%39%37%39%31%34%37%36%34%2C%35%2E%33%38%34%34%33%39%31%20%31%2E%35%30%31%30%39%39%38%2C%33%2E%39%30%35%35%39%36%20%32%2E%34%39%30%36%34%39%34%2C%32%2E%38%35%34%30%39%35%34%20%6C%20%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%43%20%32%2E%36%39%36%38%36%34%32%2C%32%2E%36%32%34%33%33%36%36%20%33%2E%30%35%34%38%30%30%39%2C%32%2E%36%37%32%39%33%31%38%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%5A%20%6D%20%30%2E%30%37%35%30%30%37%2C%32%2E%39%39%30%34%34%35%32%20%76%20%30%2E%35%30%37%32%39%20%31%2E%36%35%36%30%39%35%20%48%20%39%2E%38%31%35%37%36%30%34%20%56%20%35%2E%34%37%37%33%39%36%38%20%5A%20%4D%20%34%2E%33%37%37%36%39%2C%36%2E%34%39%31%39%37%37%31%20%48%20%38%2E%38%30%31%31%38%30%35%20%56%20%36%2E%36%33%34%30%39%37%32%20%48%20%34%2E%33%37%37%36%39%20%5A%20%6D%20%37%2E%30%35%36%36%36%32%2C%32%2E%30%35%32%38%34%37%31%20%68%20%30%2E%30%30%32%20%63%20%2D%30%2E%32%30%37%39%34%36%2C%30%2E%35%31%32%30%39%39%20%2D%30%2E%32%31%35%34%34%34%2C%31%2E%30%38%33%34%34%39%37%20%2D%30%2E%35%35%32%36%39%2C%31%2E%35%32%39%37%36%35%38%20%6C%20%2D%30%2E%32%36%30%35%35%34%2C%30%2E%33%35%31%33%35%32%20%30%2E%33%30%35%39%35%35%2C%30%2E%33%31%33%38%34%37%20%63%20%31%2E%32%30%33%32%31%34%2C%31%2E%32%31%36%34%33%37%20%32%2E%34%32%36%37%37%34%2C%32%2E%33%39%38%34%34%33%20%33%2E%36%30%32%33%35%32%2C%33%2E%36%31%38%31%34%33%20%30%2E%31%34%34%31%39%34%2C%30%2E%31%36%33%38%36%39%20%30%2E%32%38%32%39%38%2C%30%2E%32%38%34%32%35%39%20%30%2E%33%35%31%33%35%32%2C%30%2E%33%36%35%31%36%38%20%30%2E%30%37%32%36%35%2C%30%2E%30%38%35%39%37%20%30%2E%30%36%31%38%35%2C%30%2E%30%38%30%35%31%20%30%2E%30%35%39%32%32%2C%30%2E%31%30%34%36%31%38%20%76%20%30%2E%30%31%33%38%33%20%30%2E%30%31%35%37%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%37%20%2D%30%2E%31%33%31%35%33%39%2C%30%2E%30%37%34%31%31%20%2D%30%2E%31%34%32%31%32%2C%30%2E%30%36%37%31%31%20%2D%31%2E%32%31%32%34%32%35%2C%2D%31%2E%31%32%35%37%38%37%20%2D%32%2E%37%37%30%37%36%36%2C%2D%32%2E%37%34%39%36%38%31%20%2D%34%2E%31%34%31%32%32%36%2C%2D%33%2E%39%36%39%34%38%38%20%6C%20%2D%30%2E%33%30%35%39%35%32%2C%2D%30%2E%32%36%38%34%35%20%2D%30%2E%33%32%37%36%36%36%2C%30%2E%32%33%38%38%33%39%20%63%20%2D%30%2E%38%37%37%31%36%33%35%2C%30%2E%36%33%32%35%30%34%20%2D%31%2E%38%38%36%39%34%32%38%2C%31%2E%30%37%38%37%35%39%20%2D%32%2E%39%32%33%33%33%34%35%2C%31%2E%31%34%38%38%30%37%20%68%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%63%20%2D%30%2E%35%33%30%33%35%35%33%2C%30%2E%30%35%33%39%39%20%2D%30%2E%39%37%39%37%31%38%39%2C%2D%30%2E%33%33%34%33%37%20%2D%31%2E%35%30%36%30%35%36%33%2C%2D%30%2E%34%34%30%31%37%38%20%30%2E%35%35%33%39%30%38%34%2C%30%2E%31%30%35%38%34%31%20%31%2E%31%31%32%30%34%31%35%2C%30%2E%32%34%38%37%36%35%20%31%2E%36%35%36%30%39%35%2C%30%2E%31%38%37%35%32%20%31%2E%38%38%33%30%33%34%39%2C%2D%30%2E%32%31%30%36%32%37%20%33%2E%34%38%32%30%33%38%38%2C%2D%31%2E%35%34%37%39%30%32%20%34%2E%31%39%38%34%36%37%38%2C%2D%33%2E%32%37%36%36%35%39%38%20%7A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%43%20%34%2E%38%35%30%34%32%37%33%2C%30%2E%35%32%39%37%30%35%39%38%20%33%2E%32%31%37%30%32%38%2C%31%2E%32%38%31%36%31%34%32%20%32%2E%31%31%34%33%34%36%32%2C%32%2E%35%31%35%32%33%39%38%20%31%2E%30%32%34%37%39%35%35%2C%33%2E%36%37%33%30%30%31%39%20%30%2E%34%35%39%30%33%36%34%32%2C%35%2E%32%37%39%34%30%38%35%20%30%2E%35%34%35%31%30%31%38%39%2C%36%2E%38%35%35%38%32%36%39%20%30%2E%35%39%39%32%32%37%33%2C%38%2E%35%39%33%38%33%39%31%20%31%2E%34%38%39%32%31%39%35%2C%31%30%2E%32%37%30%37%38%32%20%32%2E%38%36%30%34%37%36%38%2C%31%31%2E%33%33%36%35%36%31%20%63%20%31%2E%31%39%31%35%34%37%39%2C%30%2E%39%34%35%38%33%32%20%32%2E%37%36%30%34%36%38%37%2C%31%2E%34%30%31%33%32%35%20%34%2E%32%37%31%35%30%31%33%2C%31%2E%32%34%37%34%39%39%20%31%2E%31%35%37%35%30%32%35%2C%2D%30%2E%30%37%38%32%33%20%32%2E%32%34%39%39%32%38%36%2C%2D%30%2E%35%37%30%30%39%34%20%33%2E%31%38%33%38%38%35%39%2C%2D%31%2E%32%34%33%35%35%32%20%31%2E%33%36%35%32%34%36%2C%31%2E%32%31%35%31%36%37%20%32%2E%39%35%38%34%31%2C%32%2E%38%36%37%39%37%34%20%34%2E%31%39%36%34%39%34%2C%34%2E%30%31%32%39%32%31%20%30%2E%33%35%37%38%33%2C%30%2E%32%33%36%37%32%37%20%30%2E%39%30%39%31%32%33%2C%2D%30%2E%30%33%34%35%35%20%30%2E%39%32%35%37%35%35%2C%2D%30%2E%34%36%39%37%38%36%20%30%2E%30%34%32%37%34%2C%2D%30%2E%33%38%38%36%35%31%20%2D%30%2E%33%33%32%31%33%37%2C%2D%30%2E%36%31%33%36%30%34%20%2D%30%2E%35%35%30%37%31%36%2C%2D%30%2E%38%37%30%34%38%36%20%2D%31%2E%31%38%33%30%34%32%2C%2D%31%2E%32%32%37%34%34%33%20%2D%32%2E%34%30%33%36%33%2C%2D%32%2E%34%31%36%31%31%38%20%2D%33%2E%36%30%32%33%35%32%2C%2D%33%2E%36%32%38%30%31%33%20%30%2E%37%39%33%33%30%35%2C%2D%31%2E%30%34%39%38%38%37%31%20%31%2E%33%31%39%38%32%34%2C%2D%32%2E%33%33%30%37%31%31%20%31%2E%33%31%38%35%36%2C%2D%33%2E%36%35%33%36%37%32%34%20%30%2E%30%33%34%2C%2D%31%2E%30%30%30%30%34%38%32%20%2D%30%2E%31%37%37%32%30%31%2C%2D%32%2E%30%30%39%35%38%32%37%20%2D%30%2E%36%34%35%34%36%33%2C%2D%32%2E%38%39%35%36%39%38%34%20%43%20%31%31%2E%30%35%31%36%30%32%2C%32%2E%30%35%31%34%32%35%35%20%39%2E%32%31%33%34%33%30%33%2C%30%2E%37%34%39%36%39%32%30%34%20%37%2E%32%30%38%39%35%39%31%2C%30%2E%35%37%30%39%35%36%38%32%20%36%2E%39%37%36%31%38%35%38%2C%30%2E%35%34%38%34%32%30%35%31%20%36%2E%37%34%32%30%34%33%39%2C%30%2E%35%33%37%39%37%33%36%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%5A%20%4D%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%63%20%30%2E%30%36%37%30%37%34%2C%2D%35%2E%39%35%32%65%2D%34%20%30%2E%31%33%34%31%37%35%31%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%33%33%37%31%2C%30%2E%30%30%33%39%35%20%30%2E%30%31%39%38%36%33%2C%30%20%30%2E%30%33%39%32%30%32%2C%2D%31%2E%31%32%65%2D%35%20%30%2E%30%35%39%32%31%37%2C%30%20%31%2E%37%39%36%34%37%36%2C%30%2E%30%30%31%36%38%20%33%2E%35%30%35%38%30%37%35%2C%31%2E%31%36%30%37%36%36%35%20%34%2E%32%33%33%39%39%36%35%2C%32%2E%37%39%33%30%35%36%32%20%43%20%31%31%2E%34%36%34%32%38%31%2C%35%2E%37%34%34%39%36%31%32%20%31%31%2E%35%30%33%30%31%35%2C%37%2E%31%32%31%37%20%31%31%2E%30%33%38%33%31%2C%38%2E%33%30%36%36%33%39%35%20%31%30%2E%34%31%33%39%35%37%2C%39%2E%39%30%36%35%31%30%36%20%38%2E%38%38%39%31%31%34%35%2C%31%31%2E%31%33%32%38%31%20%37%2E%31%37%33%34%32%39%33%2C%31%31%2E%33%32%34%37%31%37%20%36%2E%34%33%32%31%31%31%32%2C%31%31%2E%34%30%38%31%37%20%35%2E%36%36%36%35%36%32%34%2C%31%31%2E%33%35%34%30%37%35%20%34%2E%39%36%36%36%31%38%37%2C%31%31%2E%30%38%31%39%32%39%20%33%2E%31%34%34%32%34%39%33%2C%31%30%2E%34%36%31%37%34%37%20%31%2E%38%31%33%39%35%36%39%2C%38%2E%36%33%34%31%33%32%31%20%31%2E%37%39%34%35%37%36%2C%36%2E%37%30%37%37%38%35%32%20%31%2E%37%32%38%38%37%36%38%2C%35%2E%32%30%33%30%38%37%39%20%32%2E%34%35%36%31%38%33%35%2C%33%2E%37%30%36%30%31%35%33%20%33%2E%36%34%36%30%38%35%38%2C%32%2E%37%39%31%35%38%34%36%20%34%2E%34%33%36%39%32%33%38%2C%32%2E%31%37%33%39%36%30%35%20%35%2E%34%32%37%30%39%36%32%2C%31%2E%38%30%31%37%32%35%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%5A%20%4D%20%33%2E%38%36%35%31%38%38%31%2C%35%2E%39%38%37%33%31%34%37%20%56%20%37%2E%31%34%32%30%34%31%31%20%48%20%39%2E%33%30%33%32%35%38%34%20%56%20%35%2E%39%38%37%33%31%34%37%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ResizeNwse:$app$main$ui$cursors$resize_nwse$$,ResizeEw2:$app$main$ui$cursors$resize_ew_2$$,CreateRectangle:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%39%20%37%56%31%68%36%76%36%48%39%7A%6D%31%2D%35%68%34%76%34%68%2D%34%56%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%38%2E%35%2E%35%68%37%76%37%68%2D%37%76%2D%37%7A%6D%2D%33%20%33%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%34%2D%37%68%34%76%34%68%2D%34%56%32%7A%6D%2E%35%20%33%2E%35%68%33%76%2D%33%68%2D%33%76%33%7A%4D%39%20%37%56%31%68%36%76%36%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ResizeAlt:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%2E%35%2E%35%76%34%2E%39%68%2D%31%2E%38%56%33%2E%36%4C%39%2E%32%20%38%6C%34%2E%35%20%34%2E%34%76%2D%31%2E%38%68%31%2E%38%76%34%2E%39%68%2D%34%2E%39%76%2D%31%2E%38%68%31%2E%38%4C%38%20%39%2E%32%6C%2D%34%2E%34%20%34%2E%35%68%31%2E%38%76%31%2E%38%48%2E%35%76%2D%34%2E%39%68%31%2E%38%76%31%2E%38%4C%36%2E%38%20%38%20%32%2E%33%20%33%2E%35%76%32%48%2E%35%76%2D%35%68%34%2E%39%76%31%2E%38%48%33%2E%35%4C%38%20%36%2E%38%6C%34%2E%34%2D%34%2E%35%68%2D%31%2E%38%56%2E%35%68%34%2E%39%7A%6D%2D%31%2E%39%20%31%2E%33%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$initialize_rasterizer_91903$$,$app$main$initialize_91906$$,$app$main$data$workspace$set_shape_index_71783$$,$app$main$data$workspace$reorder_children_71788$$,$app$main$data$event$snapshot_performance_info_50609$$,$app$main$data$event$store_performace_info_50628$$,$app$main$data$event$initialize_50642$$;$APP.$goog$inherits$$($goog$history$Event$$,$APP.$goog$events$Event$$);$APP.$goog$inherits$$($goog$history$Html5History$$,$APP.$goog$events$EventTarget$$);
$APP.$JSCompiler_prototypeAlias$$=$goog$history$Html5History$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$enabled_$=!1;$APP.$JSCompiler_prototypeAlias$$.$useFragment_$=!0;$APP.$JSCompiler_prototypeAlias$$.$pathPrefix_$="/";
$APP.$JSCompiler_prototypeAlias$$.getToken=function(){if(this.$useFragment_$)var $JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$=$JSCompiler_StaticMethods_getFragment_$$(this);else this.$transformer_$?($JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$=this.$window_$.location,$JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$=$JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$.pathname.substr(this.$pathPrefix_$.length)+
$JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$.search):$JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$=this.$window_$.location.pathname.slice(this.$pathPrefix_$.length);return $JSCompiler_temp$jscomp$2030_JSCompiler_temp$jscomp$2031_location$jscomp$inline_9631$$};
$APP.$JSCompiler_prototypeAlias$$.$setToken$=function($token$jscomp$58$$){$token$jscomp$58$$!=this.getToken()&&(this.$window_$.history.pushState(null,this.$window_$.document.title||"",$JSCompiler_StaticMethods_getUrl_$$(this,$token$jscomp$58$$)),this.dispatchEvent(new $goog$history$Event$$($token$jscomp$58$$,!1)))};
$APP.$JSCompiler_prototypeAlias$$.$replaceToken$=function($token$jscomp$59$$){this.$window_$.history.replaceState(null,this.$window_$.document.title||"",$JSCompiler_StaticMethods_getUrl_$$(this,$token$jscomp$59$$));this.dispatchEvent(new $goog$history$Event$$($token$jscomp$59$$,!1))};
$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$APP.$goog$events$unlisten$$(this.$window_$,"popstate",this.$onHistoryEvent_$,!1,this);this.$useFragment_$&&$APP.$goog$events$unlisten$$(this.$window_$,"hashchange",this.$onHistoryEvent_$,!1,this)};
$APP.$JSCompiler_prototypeAlias$$.$onHistoryEvent_$=function($e$jscomp$291$$){if(this.$enabled_$){const $fragment$jscomp$10$$=$JSCompiler_StaticMethods_getFragment_$$(this);if($e$jscomp$291$$.type=="popstate"||$fragment$jscomp$10$$!=this.$lastFragment_$)this.$lastFragment_$=$fragment$jscomp$10$$,this.dispatchEvent(new $goog$history$Event$$(this.getToken(),!0))}};
var $$jscomp$scope$m1810428007$0$TokenTransformer$$=class{},$app$main$router$initialize_router_52190$$,$app$main$router$navigated_52197$$,$app$main$router$initialize_history_52403$$,$app$main$data$common$create_team_access_request_52517$$,$app$main$features$toggle_feature_54804$$,$app$main$features$enable_feature_54819$$,$app$plugins$initialize_91730$$,$app$main$data$profile$mark_onboarding_as_viewed_55290$$,$app$main$data$profile$mark_questions_as_answered_55295$$,$app$main$data$team$team_initialized_55433$$,
$app$main$data$team$initialize_team_55441$$,$app$main$data$team$finalize_team_55444$$,$app$main$data$team$create_team_with_invitations_55569$$,$app$plugins$flags$set_flag_55472$$,$app$main$data$plugins$set_file_plugin_data_66358$$,$app$main$data$workspace$zoom$fit_to_shapes_66279$$,$app$main$data$workspace$media$create_svg_shape_67804$$,$app$main$data$workspace$media$create_svg_shape_with_images_67808$$,$app$main$data$workspace$libraries$update_color_data_69451$$,$app$main$data$workspace$texts$update_text_range_70135$$,
$app$main$data$workspace$interactions$add_interaction_70453$$,$app$main$data$workspace$tokens$library_edit$set_token_theme_active_72798$$,$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_72856$$,$app$main$data$workspace$versions$create_version_from_plugins_73422$$,$app$main$data$workspace$versions$restore_version_from_plugins_73429$$;$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50204$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50206$$,$meta50205__$1$$){return new $reitit$trie$t_reitit$0trie50204$$(this.$meta50198$,this.$_$,this.params,this.data,this.match,$meta50205__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50205$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$824$$,$i$jscomp$500$$,$max$jscomp$71$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$500$$,$max$jscomp$71$$)?this.match:null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return 1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52118$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52120$$,$meta52119__$1$$){return new $reitit$core$t_reitit$0core52118$$(this.$non_conflicting$,this.$map__52110$,this.names,this.$conflicting_paths$,this.$compiled_routes$,this.$conflicting$,this.$routes$,this.$conflicting_QMARK_$,this.$mixed_router$,this.$linear_router$,this.$opts$,$meta52119__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52119$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1513_or__5025__auto__$jscomp$436$$,$path$jscomp$222$$){$_$jscomp$1513_or__5025__auto__$jscomp$436$$=$reitit$core$match_by_path$$(this.$mixed_router$,$path$jscomp$222$$);return $APP.$cljs$core$truth_$$($_$jscomp$1513_or__5025__auto__$jscomp$436$$)?$_$jscomp$1513_or__5025__auto__$jscomp$436$$:$reitit$core$match_by_path$$(this.$linear_router$,$path$jscomp$222$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1514_or__5025__auto__$jscomp$437$$,$name$jscomp$248$$){$_$jscomp$1514_or__5025__auto__$jscomp$437$$=$APP.$reitit$core$match_by_name$$(this.$mixed_router$,$name$jscomp$248$$);return $APP.$cljs$core$truth_$$($_$jscomp$1514_or__5025__auto__$jscomp$437$$)?$_$jscomp$1514_or__5025__auto__$jscomp$437$$:$APP.$reitit$core$match_by_name$$(this.$linear_router$,$name$jscomp$248$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1515_or__5025__auto__$jscomp$438$$,$name$jscomp$249$$,$path_params$jscomp$18$$){$_$jscomp$1515_or__5025__auto__$jscomp$438$$=$APP.$reitit$core$match_by_name$$(this.$mixed_router$,$name$jscomp$249$$,$path_params$jscomp$18$$);return $APP.$cljs$core$truth_$$($_$jscomp$1515_or__5025__auto__$jscomp$438$$)?$_$jscomp$1515_or__5025__auto__$jscomp$438$$:$APP.$reitit$core$match_by_name$$(this.$linear_router$,$name$jscomp$249$$,
$path_params$jscomp$18$$)};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52097$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52099$$,$meta52098__$1$$){return new $reitit$core$t_reitit$0core52097$$(this.names,this.$compiled_routes$,this.$routes$,this.$__GT_static_router$,this.$lookup$,this.$wild$,this.$static_router$,this.$map__52095$,this.$opts$,this.$wildcard_router$,$meta52098__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52098$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1505_or__5025__auto__$jscomp$433$$,$path$jscomp$221$$){$_$jscomp$1505_or__5025__auto__$jscomp$433$$=$reitit$core$match_by_path$$(this.$static_router$,$path$jscomp$221$$);return $APP.$cljs$core$truth_$$($_$jscomp$1505_or__5025__auto__$jscomp$433$$)?$_$jscomp$1505_or__5025__auto__$jscomp$433$$:$reitit$core$match_by_path$$(this.$wildcard_router$,$path$jscomp$221$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1506_or__5025__auto__$jscomp$434$$,$name$jscomp$246$$){$_$jscomp$1506_or__5025__auto__$jscomp$434$$=$APP.$reitit$core$match_by_name$$(this.$static_router$,$name$jscomp$246$$);return $APP.$cljs$core$truth_$$($_$jscomp$1506_or__5025__auto__$jscomp$434$$)?$_$jscomp$1506_or__5025__auto__$jscomp$434$$:$APP.$reitit$core$match_by_name$$(this.$wildcard_router$,$name$jscomp$246$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1507_or__5025__auto__$jscomp$435$$,$name$jscomp$247$$,$path_params$jscomp$17$$){$_$jscomp$1507_or__5025__auto__$jscomp$435$$=$APP.$reitit$core$match_by_name$$(this.$static_router$,$name$jscomp$247$$,$path_params$jscomp$17$$);return $APP.$cljs$core$truth_$$($_$jscomp$1507_or__5025__auto__$jscomp$435$$)?$_$jscomp$1507_or__5025__auto__$jscomp$435$$:$APP.$reitit$core$match_by_name$$(this.$wildcard_router$,
$name$jscomp$247$$,$path_params$jscomp$17$$)};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50245$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50247$$,$meta50246__$1$$){return new $reitit$trie$t_reitit$0trie50245$$(this.$meta50198$,this.$_$,this.key,this.params,this.data,this.match,$meta50246__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50246$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$836$$,$i$jscomp$503$$,$max$jscomp$74$$,$path$jscomp$200$$){return $i$jscomp$503$$<=$max$jscomp$74$$?$reitit$trie$assoc_param$$(this.match,this.key,$reitit$trie$decode$$($path$jscomp$200$$,$i$jscomp$503$$,$max$jscomp$74$$,!0)):null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return 1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50210$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50212$$,$meta50211__$1$$){return new $reitit$trie$t_reitit$0trie50210$$(this.$meta50198$,this.$_$,this.path,this.$matcher$,this.size,$meta50211__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50211$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$828_j$jscomp$112$$,$i$jscomp$501$$,$max$jscomp$72$$,$p$jscomp$212$$){if($max$jscomp$72$$<$i$jscomp$501$$+this.size)return null;for($___$1$jscomp$828_j$jscomp$112$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($___$1$jscomp$828_j$jscomp$112$$,this.size))return $reitit$trie$match$$(this.$matcher$,$i$jscomp$501$$+this.size,$max$jscomp$72$$,$p$jscomp$212$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$212$$,
$i$jscomp$501$$+$___$1$jscomp$828_j$jscomp$112$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.path,$___$1$jscomp$828_j$jscomp$112$$)))$___$1$jscomp$828_j$jscomp$112$$+=1;else return null}};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return $reitit$trie$depth$$(this.$matcher$)+1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return $APP.$cljs$core$count$$(this.path)};
var $reitit$impl$accumulate$$=function $reitit$impl$accumulate$$($var_args$jscomp$1040$$){switch(arguments.length){case 1:return $reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$1141$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2394$reitit_DOT_impl_SLASH_accumulator$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($x$jscomp$1141$$)))?$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1141$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2394$reitit_DOT_impl_SLASH_accumulator$$,!0],
null)):$x$jscomp$1141$$};$reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$1142$$,$y$jscomp$384$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1142$$),$y$jscomp$384$$)};$reitit$impl$accumulate$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52081$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52083$$,$meta52082__$1$$){return new $reitit$core$t_reitit$0core52081$$(this.p,this.names,this.match,this.data,this.$compiled_routes$,this.$routes$,this.$vec__52075$,this.$vec__52078$,this.n,this.$vec__52072$,this.result,this.$opts$,$meta52082__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52082$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1497$$,$path$jscomp$220$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.p,$path$jscomp$220$$)?this.match:null};$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1498$$,$name$jscomp$244$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.n,$name$jscomp$244$$)?this.match:null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1499_a$jscomp$inline_9694$$,$name$jscomp$245$$,$JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.n,$name$jscomp$245$$)?($_$jscomp$1499_a$jscomp$inline_9694$$=this.match,$JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$=$reitit$impl$path_params$$($JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$),
$JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1499_a$jscomp$inline_9694$$,$APP.$cljs$cst$2395$path_params$$,$JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$)):$JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$=null;return $JSCompiler_temp$jscomp$2045_path_params$jscomp$16_v$jscomp$inline_9696$$};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52046$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52048$$,$meta52047__$1$$){return new $reitit$core$t_reitit$0core52046$$(this.$matcher$,this.names,this.$compiled_routes$,this.$routes$,this.$vec__52031$,this.$lookup$,this.pl,this.nl,this.$match_by_path$,this.$compiler$,this.$opts$,$meta52047__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52047$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$,$path$jscomp$218$$){$_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$=this.$match_by_path$;$_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$=$APP.$cljs$core$truth_$$($_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$)?this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$?
this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$218$$):this.$match_by_path$($path$jscomp$218$$):$_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$;return $APP.$cljs$core$truth_$$($_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$),
$APP.$cljs$cst$2395$path_params$$,$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1489_and__5023__auto__$jscomp$inline_9698_temp__5823__auto__$jscomp$141$$)),$APP.$cljs$cst$296$path$$,$path$jscomp$218$$):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1490_temp__5823__auto__$jscomp$142$$,$name$jscomp$241$$){$_$jscomp$1490_temp__5823__auto__$jscomp$142$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$241$$);return $APP.$cljs$core$truth_$$($_$jscomp$1490_temp__5823__auto__$jscomp$142$$)?$_$jscomp$1490_temp__5823__auto__$jscomp$142$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$1490_temp__5823__auto__$jscomp$142$$.$cljs$core$IFn$_invoke$arity$1$(null):
$_$jscomp$1490_temp__5823__auto__$jscomp$142$$(null):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1491_temp__5823__auto__$jscomp$143$$,$name$jscomp$242$$,$G__52067_path_params$jscomp$14$$){$_$jscomp$1491_temp__5823__auto__$jscomp$143$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$242$$);return $APP.$cljs$core$truth_$$($_$jscomp$1491_temp__5823__auto__$jscomp$143$$)?($G__52067_path_params$jscomp$14$$=$reitit$impl$path_params$$($G__52067_path_params$jscomp$14$$),$_$jscomp$1491_temp__5823__auto__$jscomp$143$$.$cljs$core$IFn$_invoke$arity$1$?
$_$jscomp$1491_temp__5823__auto__$jscomp$143$$.$cljs$core$IFn$_invoke$arity$1$($G__52067_path_params$jscomp$14$$):$_$jscomp$1491_temp__5823__auto__$jscomp$143$$($G__52067_path_params$jscomp$14$$)):null};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52001$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52003$$,$meta52002__$1$$){return new $reitit$core$t_reitit$0core52001$$(this.names,this.data,this.$compiled_routes$,this.$routes$,this.$lookup$,this.pl,this.$vec__51985$,this.nl,this.$opts$,$meta52002__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52002$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1481$$,$path$jscomp$217$$){return $reitit$impl$fast_get$$(this.data,$path$jscomp$217$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1482_temp__5823__auto__$jscomp$139$$,$name$jscomp$238$$){$_$jscomp$1482_temp__5823__auto__$jscomp$139$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$238$$);return $APP.$cljs$core$truth_$$($_$jscomp$1482_temp__5823__auto__$jscomp$139$$)?$_$jscomp$1482_temp__5823__auto__$jscomp$139$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$1482_temp__5823__auto__$jscomp$139$$.$cljs$core$IFn$_invoke$arity$1$(null):
$_$jscomp$1482_temp__5823__auto__$jscomp$139$$(null):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1483_temp__5823__auto__$jscomp$140$$,$name$jscomp$239$$,$G__52016_path_params$jscomp$13$$){$_$jscomp$1483_temp__5823__auto__$jscomp$140$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$239$$);return $APP.$cljs$core$truth_$$($_$jscomp$1483_temp__5823__auto__$jscomp$140$$)?($G__52016_path_params$jscomp$13$$=$reitit$impl$path_params$$($G__52016_path_params$jscomp$13$$),$_$jscomp$1483_temp__5823__auto__$jscomp$140$$.$cljs$core$IFn$_invoke$arity$1$?
$_$jscomp$1483_temp__5823__auto__$jscomp$140$$.$cljs$core$IFn$_invoke$arity$1$($G__52016_path_params$jscomp$13$$):$_$jscomp$1483_temp__5823__auto__$jscomp$140$$($G__52016_path_params$jscomp$13$$)):null};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core51955$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51957$$,$meta51956__$1$$){return new $reitit$core$t_reitit$0core51955$$(this.$vec__51918$,this.$matcher$,this.names,this.$compiled_routes$,this.$routes$,this.$lookup$,this.pl,this.nl,this.$match_by_path$,this.$compiler$,this.$opts$,$meta51956__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51956$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1473_temp__5823__auto__$jscomp$135$$,$path$jscomp$215$$){$_$jscomp$1473_temp__5823__auto__$jscomp$135$$=this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$?this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$215$$):this.$match_by_path$($path$jscomp$215$$);return $APP.$cljs$core$truth_$$($_$jscomp$1473_temp__5823__auto__$jscomp$135$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1473_temp__5823__auto__$jscomp$135$$),
$APP.$cljs$cst$2395$path_params$$,$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1473_temp__5823__auto__$jscomp$135$$)),$APP.$cljs$cst$296$path$$,$path$jscomp$215$$):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1474_temp__5823__auto__$jscomp$136$$,$name$jscomp$235$$){$_$jscomp$1474_temp__5823__auto__$jscomp$136$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$235$$);return $APP.$cljs$core$truth_$$($_$jscomp$1474_temp__5823__auto__$jscomp$136$$)?$_$jscomp$1474_temp__5823__auto__$jscomp$136$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$1474_temp__5823__auto__$jscomp$136$$.$cljs$core$IFn$_invoke$arity$1$(null):
$_$jscomp$1474_temp__5823__auto__$jscomp$136$$(null):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1475_temp__5823__auto__$jscomp$137$$,$name$jscomp$236$$,$G__51963_path_params$jscomp$11$$){$_$jscomp$1475_temp__5823__auto__$jscomp$137$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$236$$);return $APP.$cljs$core$truth_$$($_$jscomp$1475_temp__5823__auto__$jscomp$137$$)?($G__51963_path_params$jscomp$11$$=$reitit$impl$path_params$$($G__51963_path_params$jscomp$11$$),$_$jscomp$1475_temp__5823__auto__$jscomp$137$$.$cljs$core$IFn$_invoke$arity$1$?
$_$jscomp$1475_temp__5823__auto__$jscomp$137$$.$cljs$core$IFn$_invoke$arity$1$($G__51963_path_params$jscomp$11$$):$_$jscomp$1475_temp__5823__auto__$jscomp$137$$($G__51963_path_params$jscomp$11$$)):null};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50219$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50221$$,$meta50220__$1$$){return new $reitit$trie$t_reitit$0trie50219$$(this.$meta50198$,this.$_$,this.key,this.end,this.$matcher$,$meta50220__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50220$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$832_percent_QMARK_$jscomp$1$$,$i$jscomp$502$$,$max$jscomp$73$$,$path$jscomp$199$$){if($i$jscomp$502$$<$max$jscomp$73$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$199$$,$i$jscomp$502$$),this.end)){$___$1$jscomp$832_percent_QMARK_$jscomp$1$$=!1;for(var $G__50586_j$jscomp$113$$=$i$jscomp$502$$;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($max$jscomp$73$$,
$G__50586_j$jscomp$113$$)){var $JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$=$reitit$trie$match$$(this.$matcher$,$max$jscomp$73$$,$max$jscomp$73$$,$path$jscomp$199$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$)?$reitit$trie$assoc_param$$($JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$,this.key,$reitit$trie$decode$$($path$jscomp$199$$,
$i$jscomp$502$$,$max$jscomp$73$$,$___$1$jscomp$832_percent_QMARK_$jscomp$1$$)):null}var $G__50234$jscomp$inline_9702_c$jscomp$281_expr__50231$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$199$$,$G__50586_j$jscomp$113$$);$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$=$APP.$cljs$core$_EQ_$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$?
$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$(this.end,$G__50234$jscomp$inline_9702_c$jscomp$281_expr__50231$$):$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$(this.end,$G__50234$jscomp$inline_9702_c$jscomp$281_expr__50231$$)))return $JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$=$reitit$trie$match$$(this.$matcher$,
$G__50586_j$jscomp$113$$,$max$jscomp$73$$,$path$jscomp$199$$),$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$)?$reitit$trie$assoc_param$$($JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$,this.key,$reitit$trie$decode$$($path$jscomp$199$$,$i$jscomp$502$$,$G__50586_j$jscomp$113$$,$___$1$jscomp$832_percent_QMARK_$jscomp$1$$)):null;$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$=
$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$("%",$G__50234$jscomp$inline_9702_c$jscomp$281_expr__50231$$):$JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$("%",$G__50234$jscomp$inline_9702_c$jscomp$281_expr__50231$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2049_match$jscomp$30_pred__50230_temp__5823__auto__$jscomp$130$$)?
($G__50586_j$jscomp$113$$+=1,$___$1$jscomp$832_percent_QMARK_$jscomp$1$$=!0):$G__50586_j$jscomp$113$$+=1}}else return null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return $reitit$trie$depth$$(this.$matcher$)+1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50259$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50261$$,$meta50260__$1$$){return new $reitit$trie$t_reitit$0trie50259$$(this.$meta50198$,this.$_$,this.$matchers$,this.$ordered_QMARK_$,this.size,$meta50260__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50260$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$840_j$jscomp$114$$,$i$jscomp$504$$,$max$jscomp$75$$,$path$jscomp$201$$){for($___$1$jscomp$840_j$jscomp$114$$=0;;)if($___$1$jscomp$840_j$jscomp$114$$<this.size){var $or__5025__auto__$jscomp$427$$=$reitit$trie$match$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.$matchers$,$___$1$jscomp$840_j$jscomp$114$$),$i$jscomp$504$$,$max$jscomp$75$$,$path$jscomp$201$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$427$$))return $or__5025__auto__$jscomp$427$$;
$___$1$jscomp$840_j$jscomp$114$$+=1}else return null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$max$$,0,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($reitit$trie$depth$$,this.$matchers$))+1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};
var $app$main$data$workspace$texts$count_node_chars$$=function $app$main$data$workspace$texts$count_node_chars$$($var_args$jscomp$1282$$){switch(arguments.length){case 1:return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$=function($node$jscomp$313$$){return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$313$$,!1)};
$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$=function($node$jscomp$314$$,$last_QMARK_$jscomp$3$$){switch($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$314$$)){case "root":case "paragraph-set":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$texts$count_node_chars$$,
$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$314$$))),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70109_SHARP_$$){return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$($p1__70109_SHARP_$$,!0)},$cljs$core$take_last$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$314$$)))));case "paragraph":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_PLUS_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$texts$count_node_chars$$,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$314$$)))+($APP.$cljs$core$truth_$$($last_QMARK_$jscomp$3$$)?0:1);default:return $APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$314$$))}};$app$main$data$workspace$texts$count_node_chars$$.$cljs$lang$maxFixedArity$=2;
var $app$main$data$event$make_event$$=function $app$main$data$event$make_event$$($var_args$jscomp$1025$$){switch(arguments.length){case 1:return $app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$1$=function($result$jscomp$215$$){return $app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$215$$[1],$result$jscomp$215$$[0])};
$app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$2$=function($profile_id$jscomp$3$$,$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$){if($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$.$app$main$data$event$Event$$||($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$Event$$,
$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$Event$$,$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$)){var $JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$=$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$event$_data$$($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$),
$APP.$cljs$core$meta$$($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$));var $context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$=$APP.$potok$v2$core$type$$($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$);$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$=$APP.$cljs$core$name$$($context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$);$context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$2306$app_DOT_main_DOT_data_DOT_event_SLASH_context$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$),$APP.$cljs$cst$2307$event_origin$$,
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$)),$APP.$cljs$cst$2308$event_namespace$$,$APP.$cljs$core$namespace$$($context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$)),$APP.$cljs$cst$2309$event_symbol$$,$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$));var $data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$=
$app$main$data$event$simplify_props$$($APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$));$JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2310$app_DOT_main_DOT_data_DOT_event_SLASH_type$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$,
"action"),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$,$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$),$APP.$cljs$cst$2312$context$$,$context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$,$APP.$cljs$cst$575$props$$,$data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$],
null)}else $ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$ instanceof $APP.$potok$v2$core$DataEvent$$?($data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$=$APP.$cljs$core$_deref$$($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$),$JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$=$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$),
typeof $JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$==="string"?($ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$=$APP.$cljs$cst$2310$app_DOT_main_DOT_data_DOT_event_SLASH_type$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$,"action"),$context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$2306$app_DOT_main_DOT_data_DOT_event_SLASH_context$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$),
$APP.$cljs$cst$2307$event_origin$$,$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$))),$data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$=$app$main$data$event$simplify_props$$($APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$)),$JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$ev_name$jscomp$inline_9742_event$jscomp$65_type$jscomp$inline_9749$$,$APP.$cljs$cst$725$name$$,$JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$,$APP.$cljs$cst$2312$context$$,$context$jscomp$inline_9743_context$jscomp$inline_9750_type$jscomp$inline_9741$$,$APP.$cljs$cst$575$props$$,$data$jscomp$inline_9747_props$jscomp$inline_9744_props$jscomp$inline_9751$$],
null)):$JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$=null):$JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$=null;return $APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2061_JSCompiler_temp$jscomp$2062_data$jscomp$inline_9740_name$jscomp$inline_9748_temp__5825__auto__$jscomp$139$$,
$APP.$cljs$cst$2313$profile_id$$,$profile_id$jscomp$3$$):null};$app$main$data$event$make_event$$.$cljs$lang$maxFixedArity$=2;var $app$main$worker$on_error$$=null;$app$main$worker$on_error$$=$APP.$app$main$errors$on_error$$;
var $app$main$data$event$make_performance_event$$=function $app$main$data$event$make_performance_event$$($var_args$jscomp$1026$$){switch(arguments.length){case 1:return $app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$1$=function($result$jscomp$216$$){return $app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$216$$[1],$result$jscomp$216$$[0])};
$app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$=function($profile_id$jscomp$5$$,$props$jscomp$81$$){var $perf_info$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$2314$performance_info$$),$name$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$81$$,$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,"trigger",$APP.$cljs$cst$725$name$$,["performance-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$226$$)].join(""),$APP.$cljs$cst$2312$context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2315$file_stats$$,$APP.$cljs$cst$2316$counters$$.$cljs$core$IFn$_invoke$arity$1$($perf_info$$)],null),$APP.$cljs$cst$575$props$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$81$$,
$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$),$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($perf_info$$)),$APP.$cljs$cst$2313$profile_id$$,$profile_id$jscomp$5$$],null)};$app$main$data$event$make_performance_event$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$app$util$worker$Worker$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$34$$,$k__5324__auto__$jscomp$34$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$34$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$34$$,$k53805$$,$else__5326__auto__$jscomp$34$$){switch($k53805$$ instanceof $APP.$cljs$core$Keyword$$?$k53805$$.$fqn$:null){case "instance":return this.instance;case "stream":return this.stream;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k53805$$,$else__5326__auto__$jscomp$34$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$34$$,$f__5344__auto__$jscomp$34$$,$init__5345__auto__$jscomp$34$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$34$$,$p__53820_v__5348__auto__$jscomp$34$$){var $k__5347__auto__$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53820_v__5348__auto__$jscomp$34$$,0,null);$p__53820_v__5348__auto__$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53820_v__5348__auto__$jscomp$34$$,
1,null);return $f__5344__auto__$jscomp$34$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$34$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$34$$,$k__5347__auto__$jscomp$34$$,$p__53820_v__5348__auto__$jscomp$34$$):$f__5344__auto__$jscomp$34$$($ret__5346__auto__$jscomp$34$$,$k__5347__auto__$jscomp$34$$,$p__53820_v__5348__auto__$jscomp$34$$)},$init__5345__auto__$jscomp$34$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$34$$,$writer__5339__auto__$jscomp$34$$,$opts__5340__auto__$jscomp$34$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$34$$,function($keyval__5342__auto__$jscomp$34$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$34$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$34$$,$keyval__5342__auto__$jscomp$34$$)},"#app.util.worker.Worker{",
", ","}",$opts__5340__auto__$jscomp$34$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3118$instance$$,this.instance],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1416$stream$$,this.stream],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3118$instance$$,$APP.$cljs$cst$1416$stream$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$util$worker$Worker$$(this.instance,this.stream,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$=this.$__hash$;return $h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$!=null?$h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$:this.$__hash$=$h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$=-2074835673^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this53806$$,$other53807$$){return $other53807$$!=null&&this.constructor===$other53807$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.instance,$other53807$$.instance)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.stream,$other53807$$.stream)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other53807$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$34$$,$k__5334__auto__$jscomp$34$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3118$instance$$,null,$APP.$cljs$cst$1416$stream$$,null],null),null),$k__5334__auto__$jscomp$34$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$34$$):new $app$util$worker$Worker$$(this.instance,this.stream,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$34$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$34$$,$k53805$jscomp$1$$){switch($k53805$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k53805$jscomp$1$$.$fqn$:null){case "instance":case "stream":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k53805$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$34$$,$k__5332__auto__$jscomp$34$$,$G__53804$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3118$instance$$,$k__5332__auto__$jscomp$34$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$3118$instance$$,$k__5332__auto__$jscomp$34$$))?
new $app$util$worker$Worker$$($G__53804$jscomp$1$$,this.stream,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1416$stream$$,$k__5332__auto__$jscomp$34$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1416$stream$$,$k__5332__auto__$jscomp$34$$))?new $app$util$worker$Worker$$(this.instance,$G__53804$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $app$util$worker$Worker$$(this.instance,this.stream,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$34$$,$G__53804$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$3118$instance$$,this.instance,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1416$stream$$,this.stream,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$34$$,$G__53804$jscomp$2$$){return new $app$util$worker$Worker$$(this.instance,this.stream,$G__53804$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$34$$,$entry__5329__auto__$jscomp$34$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$34$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$34$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$34$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$34$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$core$PartialMatch$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$32$$,$k__5324__auto__$jscomp$32$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$32$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$32$$,$k51774$$,$else__5326__auto__$jscomp$32$$){switch($k51774$$ instanceof $APP.$cljs$core$Keyword$$?$k51774$$.$fqn$:null){case "template":return this.template;case "data":return this.data;case "result":return this.result;case "path-params":return this.$path_params$;case "required":return this.required;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k51774$$,
$else__5326__auto__$jscomp$32$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$32$$,$f__5344__auto__$jscomp$32$$,$init__5345__auto__$jscomp$32$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$32$$,$p__51807_v__5348__auto__$jscomp$32$$){var $k__5347__auto__$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51807_v__5348__auto__$jscomp$32$$,0,null);$p__51807_v__5348__auto__$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51807_v__5348__auto__$jscomp$32$$,
1,null);return $f__5344__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$32$$,$k__5347__auto__$jscomp$32$$,$p__51807_v__5348__auto__$jscomp$32$$):$f__5344__auto__$jscomp$32$$($ret__5346__auto__$jscomp$32$$,$k__5347__auto__$jscomp$32$$,$p__51807_v__5348__auto__$jscomp$32$$)},$init__5345__auto__$jscomp$32$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$32$$,$writer__5339__auto__$jscomp$32$$,$opts__5340__auto__$jscomp$32$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$32$$,function($keyval__5342__auto__$jscomp$32$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$32$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$32$$,$keyval__5342__auto__$jscomp$32$$)},"#reitit.core.PartialMatch{",
", ","}",$opts__5340__auto__$jscomp$32$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2403$template$$,this.template],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$828$result$$,this.result],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2395$path_params$$,this.$path_params$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1833$required$$,this.required],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2403$template$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$828$result$$,$APP.$cljs$cst$2395$path_params$$,$APP.$cljs$cst$1833$required$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$=this.$__hash$;return $h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$!=null?$h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$:this.$__hash$=$h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$=492095938^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this51775$$,$other51776$$){return $other51776$$!=null&&this.constructor===$other51776$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.template,$other51776$$.template)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other51776$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.result,$other51776$$.result)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$path_params$,
$other51776$$.$path_params$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.required,$other51776$$.required)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other51776$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$32$$,$k__5334__auto__$jscomp$32$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2403$template$$,null,$APP.$cljs$cst$828$result$$,null,$APP.$cljs$cst$2395$path_params$$,null,$APP.$cljs$cst$1833$required$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$32$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$32$$):new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$32$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$32$$,$k51774$jscomp$1$$){switch($k51774$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k51774$jscomp$1$$.$fqn$:null){case "template":case "data":case "result":case "path-params":case "required":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k51774$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$32$$,$k__5332__auto__$jscomp$32$$,$G__51773$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2403$template$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2403$template$$,$k__5332__auto__$jscomp$32$$))?
new $reitit$core$PartialMatch$$($G__51773$jscomp$1$$,this.data,this.result,this.$path_params$,this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,
$G__51773$jscomp$1$$,this.result,this.$path_params$,this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,this.data,$G__51773$jscomp$1$$,
this.$path_params$,this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2395$path_params$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2395$path_params$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,this.data,this.result,$G__51773$jscomp$1$$,
this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1833$required$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1833$required$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,$G__51773$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$32$$,$G__51773$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2403$template$$,this.template,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$828$result$$,this.result,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2395$path_params$$,
this.$path_params$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1833$required$$,this.required,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$32$$,$G__51773$jscomp$2$$){return new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,$G__51773$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$32$$,$entry__5329__auto__$jscomp$32$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$32$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$32$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$32$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$32$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$core$Match$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$31$$,$k__5324__auto__$jscomp$31$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$31$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$31$$,$k51697$$,$else__5326__auto__$jscomp$31$$){switch($k51697$$ instanceof $APP.$cljs$core$Keyword$$?$k51697$$.$fqn$:null){case "template":return this.template;case "data":return this.data;case "result":return this.result;case "path-params":return this.$path_params$;case "path":return this.path;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k51697$$,$else__5326__auto__$jscomp$31$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$31$$,$f__5344__auto__$jscomp$31$$,$init__5345__auto__$jscomp$31$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$31$$,$p__51710_v__5348__auto__$jscomp$31$$){var $k__5347__auto__$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51710_v__5348__auto__$jscomp$31$$,0,null);$p__51710_v__5348__auto__$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51710_v__5348__auto__$jscomp$31$$,
1,null);return $f__5344__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$31$$,$k__5347__auto__$jscomp$31$$,$p__51710_v__5348__auto__$jscomp$31$$):$f__5344__auto__$jscomp$31$$($ret__5346__auto__$jscomp$31$$,$k__5347__auto__$jscomp$31$$,$p__51710_v__5348__auto__$jscomp$31$$)},$init__5345__auto__$jscomp$31$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$31$$,$writer__5339__auto__$jscomp$31$$,$opts__5340__auto__$jscomp$31$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$31$$,function($keyval__5342__auto__$jscomp$31$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$31$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$31$$,$keyval__5342__auto__$jscomp$31$$)},"#reitit.core.Match{",
", ","}",$opts__5340__auto__$jscomp$31$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2403$template$$,this.template],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$828$result$$,this.result],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2395$path_params$$,this.$path_params$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,this.path],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2403$template$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$828$result$$,$APP.$cljs$cst$2395$path_params$$,$APP.$cljs$cst$296$path$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$=this.$__hash$;return $h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$!=null?$h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$:this.$__hash$=$h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$=687105853^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this51698$$,$other51699$$){return $other51699$$!=null&&this.constructor===$other51699$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.template,$other51699$$.template)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other51699$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.result,$other51699$$.result)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$path_params$,
$other51699$$.$path_params$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.path,$other51699$$.path)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other51699$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$31$$,$k__5334__auto__$jscomp$31$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2403$template$$,null,$APP.$cljs$cst$828$result$$,null,$APP.$cljs$cst$2395$path_params$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$31$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$31$$):new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$31$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$31$$,$k51697$jscomp$1$$){switch($k51697$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k51697$jscomp$1$$.$fqn$:null){case "template":case "data":case "result":case "path-params":case "path":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k51697$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$31$$,$k__5332__auto__$jscomp$31$$,$G__51696$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2403$template$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2403$template$$,$k__5332__auto__$jscomp$31$$))?
new $reitit$core$Match$$($G__51696$jscomp$1$$,this.data,this.result,this.$path_params$,this.path,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,
$G__51696$jscomp$1$$,this.result,this.$path_params$,this.path,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,this.data,$G__51696$jscomp$1$$,
this.$path_params$,this.path,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2395$path_params$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2395$path_params$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,this.data,this.result,$G__51696$jscomp$1$$,this.path,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$296$path$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,$G__51696$jscomp$1$$,this.$__meta$,this.$__extmap$,null):
new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$31$$,$G__51696$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2403$template$$,this.template,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$828$result$$,this.result,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2395$path_params$$,
this.$path_params$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$296$path$$,this.path,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$31$$,$G__51696$jscomp$2$$){return new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,$G__51696$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$31$$,$entry__5329__auto__$jscomp$31$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$31$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$31$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$31$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$31$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$Node$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$30$$,$k__5324__auto__$jscomp$30$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$30$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$30$$,$k50053$$,$else__5326__auto__$jscomp$30$$){switch($k50053$$ instanceof $APP.$cljs$core$Keyword$$?$k50053$$.$fqn$:null){case "children":return this.children;case "wilds":return this.$wilds$;case "catch-all":return this.$catch_all$;case "params":return this.params;case "data":return this.data;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k50053$$,$else__5326__auto__$jscomp$30$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$30$$,$f__5344__auto__$jscomp$30$$,$init__5345__auto__$jscomp$30$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$30$$,$p__50060_v__5348__auto__$jscomp$30$$){var $k__5347__auto__$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50060_v__5348__auto__$jscomp$30$$,0,null);$p__50060_v__5348__auto__$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50060_v__5348__auto__$jscomp$30$$,
1,null);return $f__5344__auto__$jscomp$30$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$30$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$30$$,$k__5347__auto__$jscomp$30$$,$p__50060_v__5348__auto__$jscomp$30$$):$f__5344__auto__$jscomp$30$$($ret__5346__auto__$jscomp$30$$,$k__5347__auto__$jscomp$30$$,$p__50060_v__5348__auto__$jscomp$30$$)},$init__5345__auto__$jscomp$30$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$30$$,$writer__5339__auto__$jscomp$30$$,$opts__5340__auto__$jscomp$30$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$30$$,function($keyval__5342__auto__$jscomp$30$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$30$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$30$$,$keyval__5342__auto__$jscomp$30$$)},"#reitit.trie.Node{",
", ","}",$opts__5340__auto__$jscomp$30$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,this.children],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2371$wilds$$,this.$wilds$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2372$catch_all$$,this.$catch_all$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,this.params],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$2371$wilds$$,$APP.$cljs$cst$2372$catch_all$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$=this.$__hash$;return $h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$!=null?$h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$:this.$__hash$=$h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$=33004208^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this50054$$,$other50055$$){return $other50055$$!=null&&this.constructor===$other50055$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.children,$other50055$$.children)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$wilds$,$other50055$$.$wilds$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$catch_all$,$other50055$$.$catch_all$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.params,
$other50055$$.params)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other50055$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other50055$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$30$$,$k__5334__auto__$jscomp$30$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$342$children$$,null,$APP.$cljs$cst$1430$params$$,null,$APP.$cljs$cst$2371$wilds$$,null,$APP.$cljs$cst$2372$catch_all$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$30$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$30$$):new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$30$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$30$$,$k50053$jscomp$1$$){switch($k50053$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k50053$jscomp$1$$.$fqn$:null){case "children":case "wilds":case "catch-all":case "params":case "data":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k50053$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$30$$,$k__5332__auto__$jscomp$30$$,$G__50052$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$342$children$$,$k__5332__auto__$jscomp$30$$))?
new $reitit$trie$Node$$($G__50052$jscomp$1$$,this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2371$wilds$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2371$wilds$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,
$G__50052$jscomp$1$$,this.$catch_all$,this.params,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2372$catch_all$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2372$catch_all$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,this.$wilds$,$G__50052$jscomp$1$$,
this.params,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1430$params$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1430$params$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,$G__50052$jscomp$1$$,this.data,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,$G__50052$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $reitit$trie$Node$$(this.children,
this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$30$$,$G__50052$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$342$children$$,this.children,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2371$wilds$$,this.$wilds$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2372$catch_all$$,this.$catch_all$,null),
new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1430$params$$,this.params,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$30$$,$G__50052$jscomp$2$$){return new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,this.data,$G__50052$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$30$$,$entry__5329__auto__$jscomp$30$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$30$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$30$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$30$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$30$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$Match$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$29$$,$k__5324__auto__$jscomp$29$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$29$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$29$$,$k50015$$,$else__5326__auto__$jscomp$29$$){switch($k50015$$ instanceof $APP.$cljs$core$Keyword$$?$k50015$$.$fqn$:null){case "params":return this.params;case "data":return this.data;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k50015$$,$else__5326__auto__$jscomp$29$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$29$$,$f__5344__auto__$jscomp$29$$,$init__5345__auto__$jscomp$29$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$29$$,$p__50024_v__5348__auto__$jscomp$29$$){var $k__5347__auto__$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50024_v__5348__auto__$jscomp$29$$,0,null);$p__50024_v__5348__auto__$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50024_v__5348__auto__$jscomp$29$$,
1,null);return $f__5344__auto__$jscomp$29$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$29$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$29$$,$k__5347__auto__$jscomp$29$$,$p__50024_v__5348__auto__$jscomp$29$$):$f__5344__auto__$jscomp$29$$($ret__5346__auto__$jscomp$29$$,$k__5347__auto__$jscomp$29$$,$p__50024_v__5348__auto__$jscomp$29$$)},$init__5345__auto__$jscomp$29$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$29$$,$writer__5339__auto__$jscomp$29$$,$opts__5340__auto__$jscomp$29$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$29$$,function($keyval__5342__auto__$jscomp$29$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$29$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$29$$,$keyval__5342__auto__$jscomp$29$$)},"#reitit.trie.Match{",
", ","}",$opts__5340__auto__$jscomp$29$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,this.params],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$Match$$(this.params,this.data,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$=this.$__hash$;return $h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$!=null?$h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$:this.$__hash$=$h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$=-1117628764^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this50016$$,$other50017$$){return $other50017$$!=null&&this.constructor===$other50017$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.params,$other50017$$.params)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other50017$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other50017$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$29$$,$k__5334__auto__$jscomp$29$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1430$params$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$29$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$29$$):new $reitit$trie$Match$$(this.params,this.data,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$29$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$29$$,$k50015$jscomp$1$$){switch($k50015$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k50015$jscomp$1$$.$fqn$:null){case "params":case "data":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k50015$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$29$$,$k__5332__auto__$jscomp$29$$,$G__50014$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1430$params$$,$k__5332__auto__$jscomp$29$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1430$params$$,$k__5332__auto__$jscomp$29$$))?
new $reitit$trie$Match$$($G__50014$jscomp$1$$,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$29$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$29$$))?new $reitit$trie$Match$$(this.params,$G__50014$jscomp$1$$,this.$__meta$,this.$__extmap$,
null):new $reitit$trie$Match$$(this.params,this.data,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$29$$,$G__50014$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1430$params$$,this.params,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$29$$,$G__50014$jscomp$2$$){return new $reitit$trie$Match$$(this.params,this.data,$G__50014$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$29$$,$entry__5329__auto__$jscomp$29$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$29$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$29$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$29$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$29$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50197$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50199$$,$meta50198__$1$$){return new $reitit$trie$t_reitit$0trie50197$$($meta50198__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50198$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$data_matcher$arity$3$=function($_$jscomp$1448$$,$params$jscomp$130$$,$data$jscomp$170$$){return new $reitit$trie$t_reitit$0trie50204$$(this.$meta50198$,this,$params$jscomp$130$$,$data$jscomp$170$$,new $reitit$trie$Match$$($params$jscomp$130$$,$data$jscomp$170$$,null,null,null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$static_matcher$arity$3$=function($_$jscomp$1449_size$jscomp$101$$,$path$jscomp$202$$,$matcher$jscomp$13$$){$_$jscomp$1449_size$jscomp$101$$=$APP.$cljs$core$count$$($path$jscomp$202$$);return new $reitit$trie$t_reitit$0trie50210$$(this.$meta50198$,this,$path$jscomp$202$$,$matcher$jscomp$13$$,$_$jscomp$1449_size$jscomp$101$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$wild_matcher$arity$4$=function($_$jscomp$1450$$,$key$jscomp$325$$,$end$jscomp$80$$,$matcher$jscomp$14$$){return new $reitit$trie$t_reitit$0trie50219$$(this.$meta50198$,this,$key$jscomp$325$$,$end$jscomp$80$$,$matcher$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$catch_all_matcher$arity$4$=function($_$jscomp$1451$$,$key$jscomp$326$$,$params$jscomp$131$$,$data$jscomp$171$$){return new $reitit$trie$t_reitit$0trie50245$$(this.$meta50198$,this,$key$jscomp$326$$,$params$jscomp$131$$,$data$jscomp$171$$,new $reitit$trie$Match$$($params$jscomp$131$$,$data$jscomp$171$$,null,null,null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$linear_matcher$arity$3$=function($_$jscomp$1452_matchers__$1$$,$matchers$jscomp$4_size$jscomp$102$$,$ordered_QMARK_$jscomp$5$$){$_$jscomp$1452_matchers__$1$$=$APP.$cljs$core$vec$$($APP.$cljs$core$truth_$$($ordered_QMARK_$jscomp$5$$)?$matchers$jscomp$4_size$jscomp$102$$:$APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($reitit$trie$depth$$,$reitit$trie$length$$),
$matchers$jscomp$4_size$jscomp$102$$)));$matchers$jscomp$4_size$jscomp$102$$=$APP.$cljs$core$count$$($_$jscomp$1452_matchers__$1$$);return new $reitit$trie$t_reitit$0trie50259$$(this.$meta50198$,this,$_$jscomp$1452_matchers__$1$$,$ordered_QMARK_$jscomp$5$$,$matchers$jscomp$4_size$jscomp$102$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$_path_matcher$arity$2$=function($_$jscomp$1454$$,$matcher$jscomp$16$$){return function($JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$){var $data$jscomp$inline_9774_temp__5823__auto__$jscomp$131$$=$reitit$trie$match$$($matcher$jscomp$16$$,0,$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$),$JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$);$APP.$cljs$core$truth_$$($data$jscomp$inline_9774_temp__5823__auto__$jscomp$131$$)?
($JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9774_temp__5823__auto__$jscomp$131$$),$data$jscomp$inline_9774_temp__5823__auto__$jscomp$131$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9774_temp__5823__auto__$jscomp$131$$),$JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$=new $reitit$trie$Match$$($JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$,
$data$jscomp$inline_9774_temp__5823__auto__$jscomp$131$$,null,null,null)):$JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$=null;return $JSCompiler_temp$jscomp$2069_params$jscomp$inline_9773_path$jscomp$203$$}};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$CatchAll$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$28$$,$k__5324__auto__$jscomp$28$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$28$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$28$$,$k49989$$,$else__5326__auto__$jscomp$28$$){switch($k49989$$ instanceof $APP.$cljs$core$Keyword$$?$k49989$$.$fqn$:null){case "value":return this.value;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49989$$,$else__5326__auto__$jscomp$28$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$28$$,$f__5344__auto__$jscomp$28$$,$init__5345__auto__$jscomp$28$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$28$$,$p__49996_v__5348__auto__$jscomp$28$$){var $k__5347__auto__$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49996_v__5348__auto__$jscomp$28$$,0,null);$p__49996_v__5348__auto__$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49996_v__5348__auto__$jscomp$28$$,
1,null);return $f__5344__auto__$jscomp$28$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$28$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$28$$,$k__5347__auto__$jscomp$28$$,$p__49996_v__5348__auto__$jscomp$28$$):$f__5344__auto__$jscomp$28$$($ret__5346__auto__$jscomp$28$$,$k__5347__auto__$jscomp$28$$,$p__49996_v__5348__auto__$jscomp$28$$)},$init__5345__auto__$jscomp$28$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$28$$,$writer__5339__auto__$jscomp$28$$,$opts__5340__auto__$jscomp$28$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$28$$,function($keyval__5342__auto__$jscomp$28$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$28$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$28$$,$keyval__5342__auto__$jscomp$28$$)},"#reitit.trie.CatchAll{",
", ","}",$opts__5340__auto__$jscomp$28$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$CatchAll$$(this.value,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$=this.$__hash$;return $h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$!=null?$h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$:this.$__hash$=$h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$=-987265038^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49990$$,$other49991$$){return $other49991$$!=null&&this.constructor===$other49991$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other49991$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49991$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$28$$,$k__5334__auto__$jscomp$28$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,null],null),null),$k__5334__auto__$jscomp$28$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$28$$):new $reitit$trie$CatchAll$$(this.value,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$28$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$28$$,$k49989$jscomp$1$$){switch($k49989$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49989$jscomp$1$$.$fqn$:null){case "value":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49989$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$28$$,$k__5332__auto__$jscomp$28$$,$G__49988$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$28$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$28$$))?
new $reitit$trie$CatchAll$$($G__49988$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $reitit$trie$CatchAll$$(this.value,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$28$$,$G__49988$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$28$$,$G__49988$jscomp$2$$){return new $reitit$trie$CatchAll$$(this.value,$G__49988$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$28$$,$entry__5329__auto__$jscomp$28$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$28$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$28$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$28$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$28$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$Wild$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$27$$,$k__5324__auto__$jscomp$27$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$27$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$27$$,$k49960$$,$else__5326__auto__$jscomp$27$$){switch($k49960$$ instanceof $APP.$cljs$core$Keyword$$?$k49960$$.$fqn$:null){case "value":return this.value;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49960$$,$else__5326__auto__$jscomp$27$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$27$$,$f__5344__auto__$jscomp$27$$,$init__5345__auto__$jscomp$27$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$27$$,$p__49970_v__5348__auto__$jscomp$27$$){var $k__5347__auto__$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49970_v__5348__auto__$jscomp$27$$,0,null);$p__49970_v__5348__auto__$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49970_v__5348__auto__$jscomp$27$$,
1,null);return $f__5344__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$27$$,$k__5347__auto__$jscomp$27$$,$p__49970_v__5348__auto__$jscomp$27$$):$f__5344__auto__$jscomp$27$$($ret__5346__auto__$jscomp$27$$,$k__5347__auto__$jscomp$27$$,$p__49970_v__5348__auto__$jscomp$27$$)},$init__5345__auto__$jscomp$27$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$27$$,$writer__5339__auto__$jscomp$27$$,$opts__5340__auto__$jscomp$27$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$27$$,function($keyval__5342__auto__$jscomp$27$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$27$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$27$$,$keyval__5342__auto__$jscomp$27$$)},"#reitit.trie.Wild{",
", ","}",$opts__5340__auto__$jscomp$27$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$Wild$$(this.value,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$=this.$__hash$;return $h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$!=null?$h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$:this.$__hash$=$h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$=-1970880185^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49961$$,$other49962$$){return $other49962$$!=null&&this.constructor===$other49962$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other49962$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49962$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$27$$,$k__5334__auto__$jscomp$27$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,null],null),null),$k__5334__auto__$jscomp$27$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$27$$):new $reitit$trie$Wild$$(this.value,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$27$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$27$$,$k49960$jscomp$1$$){switch($k49960$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49960$jscomp$1$$.$fqn$:null){case "value":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49960$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$27$$,$k__5332__auto__$jscomp$27$$,$G__49959$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$27$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$27$$))?
new $reitit$trie$Wild$$($G__49959$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $reitit$trie$Wild$$(this.value,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$27$$,$G__49959$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$27$$,$G__49959$jscomp$2$$){return new $reitit$trie$Wild$$(this.value,$G__49959$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$27$$,$entry__5329__auto__$jscomp$27$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$27$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$27$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$27$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$27$$)};
var $reitit$trie$_insert$$=function $reitit$trie$_insert$$($node$jscomp$254$$,$node_SINGLEQUOTE__p__50153_seq__50155$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$){$node_SINGLEQUOTE__p__50153_seq__50155$$=$APP.$cljs$core$seq$$($node_SINGLEQUOTE__p__50153_seq__50155$$);var $first__50156$$=$APP.$cljs$core$first$$($node_SINGLEQUOTE__p__50153_seq__50155$$),$seq__50155__$1$$=$APP.$cljs$core$next$$($node_SINGLEQUOTE__p__50153_seq__50155$$);$node_SINGLEQUOTE__p__50153_seq__50155$$=$first__50156$$==null?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($node$jscomp$254$$,$APP.$cljs$cst$142$data$$,$data$jscomp$165$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1430$params$$,$params$jscomp$125$$])):$first__50156$$ instanceof $reitit$trie$Wild$$?function(){var $next$jscomp$9$$=$APP.$cljs$core$first$$($seq__50155__$1$$);return $next$jscomp$9$$ instanceof $reitit$trie$Wild$$||$next$jscomp$9$$ instanceof $reitit$trie$CatchAll$$?$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2378$reitit_DOT_trie_SLASH_following_parameters$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$fp$$,$APP.$cljs$cst$2379$parameters$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$first__50156$$,$next$jscomp$9$$],null))],null)):$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$254$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2371$wilds$$,$first__50156$$],null),function($G__50157_n$jscomp$279$$){$G__50157_n$jscomp$279$$=$APP.$cljs$core$truth_$$($G__50157_n$jscomp$279$$)?$G__50157_n$jscomp$279$$:$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50157_n$jscomp$279$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($G__50157_n$jscomp$279$$,
$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)})}():$first__50156$$ instanceof $reitit$trie$CatchAll$$?$APP.$cljs$core$assoc_in$$($node$jscomp$254$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2372$catch_all$$,$first__50156$$],null),$reitit$trie$_node$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1430$params$$,$params$jscomp$125$$,$APP.$cljs$cst$142$data$$,$data$jscomp$165$$],null))):$APP.$cljs$core$empty_QMARK_$$($first__50156$$)?
$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$254$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($node$jscomp$254$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):function(){var $or__5025__auto__$jscomp$426$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$1437$$,$p__50162$$){var $p$jscomp$211$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50162$$,
0,null),$n$jscomp$280$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50162$$,1,null),$temp__5823__auto__$jscomp$129$$=$reitit$trie$common_prefix$$($p$jscomp$211$$,$first__50156$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$129$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$129$$,$p$jscomp$211$$)){var $n_SINGLEQUOTE_$$=function(){var $G__50171$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seq__50155__$1$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($first__50156$$,
$APP.$cljs$core$count$$($p$jscomp$211$$)));return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($n$jscomp$280$$,$G__50171$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($n$jscomp$280$$,$G__50171$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)}();return $APP.$cljs$core$reduced$$($APP.$cljs$core$assoc_in$$($node$jscomp$254$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$342$children$$,$p$jscomp$211$$],null),$n_SINGLEQUOTE_$$))}var $rp$jscomp$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$211$$,$temp__5823__auto__$jscomp$129$$.length),$rp_SINGLEQUOTE_$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($first__50156$$,$temp__5823__auto__$jscomp$129$$.length);$n_SINGLEQUOTE_$$=function(){var $G__50176$$=$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?
$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50176$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($G__50176$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)}();var $n_SINGLEQUOTE__SINGLEQUOTE_$$=function(){var $G__50181$$=$reitit$trie$_node$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$rp$jscomp$1$$,$n$jscomp$280$$,$rp_SINGLEQUOTE_$$,
$n_SINGLEQUOTE_$$])],null));return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50181$$,null,null,null,null):$reitit$trie$_insert$$($G__50181$$,null,null,null,null)}();return $APP.$cljs$core$reduced$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$254$$,$APP.$cljs$cst$342$children$$,function($children$jscomp$172$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$172$$,
$p$jscomp$211$$),$temp__5823__auto__$jscomp$129$$,$n_SINGLEQUOTE__SINGLEQUOTE_$$)}))}return null},null,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$254$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$426$$)?$or__5025__auto__$jscomp$426$$:$APP.$cljs$core$assoc_in$$($node$jscomp$254$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,$first__50156$$],null),function(){var $G__50187$$=
$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50187$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($G__50187$$,$seq__50155__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)}())}();var $temp__5823__auto__$jscomp$128$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($node_SINGLEQUOTE__p__50153_seq__50155$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,""],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$128$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($node_SINGLEQUOTE__p__50153_seq__50155$$,
$APP.$cljs$cst$142$data$$),$temp__5823__auto__$jscomp$128$$])),$APP.$cljs$cst$342$children$$,$APP.$cljs$core$dissoc$$,""):$node_SINGLEQUOTE__p__50153_seq__50155$$},$app$common$types$text$change_text$$=function $app$common$types$text$change_text$$($var_args$jscomp$925$$){for(var $args__5755__auto__$jscomp$148$$=[],$len__5749__auto___46236$$=arguments.length,$i__5750__auto___46237$$=0;;)if($i__5750__auto___46237$$<$len__5749__auto___46236$$)$args__5755__auto__$jscomp$148$$.push(arguments[$i__5750__auto___46237$$]),
$i__5750__auto___46237$$+=1;else break;return $app$common$types$text$change_text$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$148$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$148$$.slice(2),0,null):null)};
$app$common$types$text$change_text$$.$cljs$core$IFn$_invoke$arity$variadic$=function($content$jscomp$21_paragraph_texts_paragraphs$$,$text$jscomp$22$$,$p__46075_root_styles$$){var $styles$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($p__46075_root_styles$$);$p__46075_root_styles$$=$APP.$cljs$core$select_keys$$($content$jscomp$21_paragraph_texts_paragraphs$$,$APP.$app$common$types$text$text_valign_attrs$$);var $paragraph_style$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_text_attrs$$,
$styles$jscomp$1$$,$APP.$cljs$core$select_keys$$($APP.$cljs$core$first$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$content$jscomp$21_paragraph_texts_paragraphs$$)),$APP.$app$common$types$text$text_all_attrs$$)])),$text_style$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_text_attrs$$,$styles$jscomp$1$$,
$APP.$cljs$core$select_keys$$($APP.$cljs$core$first$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$content$jscomp$21_paragraph_texts_paragraphs$$)),$APP.$app$common$types$text$text_all_attrs$$)]));$content$jscomp$21_paragraph_texts_paragraphs$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$22$$,"\n");$content$jscomp$21_paragraph_texts_paragraphs$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($pt$jscomp$17$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$paragraph_style$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1588$text$$,$pt$jscomp$17$$],null),$text_style$$]))],null)],null)]))},$content$jscomp$21_paragraph_texts_paragraphs$$);
return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,$content$jscomp$21_paragraph_texts_paragraphs$$],null)],null)],null),$p__46075_root_styles$$)};
$app$common$types$text$change_text$$.$cljs$lang$maxFixedArity$=2;
$app$common$types$text$change_text$$.$cljs$lang$applyTo$=function($G__46074_seq46072$$){var $G__46073$$=$APP.$cljs$core$first$$($G__46074_seq46072$$),$seq46072__$1_seq46072__$2$$=$APP.$cljs$core$next$$($G__46074_seq46072$$);$G__46074_seq46072$$=$APP.$cljs$core$first$$($seq46072__$1_seq46072__$2$$);$seq46072__$1_seq46072__$2$$=$APP.$cljs$core$next$$($seq46072__$1_seq46072__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__46073$$,$G__46074_seq46072$$,$seq46072__$1_seq46072__$2$$)};
var $meta_merge$core$meta_merge$$=function $meta_merge$core$meta_merge$$($var_args$jscomp$1035$$){switch(arguments.length){case 0:return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$100$$=[],$len__5749__auto___49977$$=arguments.length,$i__5750__auto___49978$$=
0;;)if($i__5750__auto___49978$$<$len__5749__auto___49977$$)$args_arr__5774__auto__$jscomp$100$$.push(arguments[$i__5750__auto___49978$$]),$i__5750__auto___49978$$+=1;else break;return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$100$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$100$$.slice(2),0,null):null)}};$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$};
$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$1$=function($left$jscomp$21$$){return $left$jscomp$21$$};
$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$2$=function($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$,$right$jscomp$18$$){var $JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$=$APP.$cljs$core$some$$($cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$03$$(),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$,$right$jscomp$18$$],null));$JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$)?
$JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$:$APP.$cljs$cst$2369$top_displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$));$APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$)?
$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$=$meta_merge$core$pick_prioritized$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$,$right$jscomp$18$$):$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$)&&$APP.$cljs$core$map_QMARK_$$($right$jscomp$18$$)?
$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$=$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($meta_merge$core$meta_merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$,$right$jscomp$18$$])):$APP.$cljs$core$set_QMARK_$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$)&&
$APP.$cljs$core$set_QMARK_$$($right$jscomp$18$$)?$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($right$jscomp$18$$,$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$):$APP.$cljs$core$coll_QMARK_$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$)&&
$APP.$cljs$core$coll_QMARK_$$($right$jscomp$18$$)?($JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$=$APP.$cljs$cst$2370$prepend$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$)),$JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$)?$JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$:$APP.$cljs$cst$2370$prepend$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($right$jscomp$18$$)),$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2081_JSCompiler_inline_result$jscomp$inline_13883_or__5025__auto__$jscomp$inline_13884_or__5025__auto__$jscomp$inline_9789$$)?$APP.$cljs$core$with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($right$jscomp$18$$,$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$)),
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$),$APP.$cljs$core$select_keys$$($APP.$cljs$core$meta$$($right$jscomp$18$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2367$displace$$],null))]))):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$),
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$,$right$jscomp$18$$))):$JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$=$right$jscomp$18$$;return $JSCompiler_temp$jscomp$2077_JSCompiler_temp$jscomp$2078_JSCompiler_temp$jscomp$2079_JSCompiler_temp$jscomp$2080_left$jscomp$22$$};
$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$variadic$=function($left$jscomp$23$$,$right$jscomp$19$$,$more$jscomp$49$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($meta_merge$core$meta_merge$$,$left$jscomp$23$$,$APP.$cljs$core$cons$$($right$jscomp$19$$,$more$jscomp$49$$))};
$meta_merge$core$meta_merge$$.$cljs$lang$applyTo$=function($G__49966_seq49964$$){var $G__49965$$=$APP.$cljs$core$first$$($G__49966_seq49964$$),$seq49964__$1_seq49964__$2$$=$APP.$cljs$core$next$$($G__49966_seq49964$$);$G__49966_seq49964$$=$APP.$cljs$core$first$$($seq49964__$1_seq49964__$2$$);$seq49964__$1_seq49964__$2$$=$APP.$cljs$core$next$$($seq49964__$1_seq49964__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49965$$,$G__49966_seq49964$$,$seq49964__$1_seq49964__$2$$)};
$meta_merge$core$meta_merge$$.$cljs$lang$maxFixedArity$=2;var $reitit$core$trie_router$$=function $reitit$core$trie_router$$($var_args$jscomp$1046$$){switch(arguments.length){case 1:return $reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$10$$){return $reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$11$$,$opts$jscomp$281$$){var $compiler$jscomp$9$$=$APP.$cljs$cst$2418$reitit_DOT_trie_SLASH_trie_compiler$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$281$$,new $reitit$trie$t_reitit$0trie50197$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)),$names$jscomp$11$$=$reitit$impl$find_names$$($compiled_routes$jscomp$11$$),$vec__52031$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($nl$jscomp$15_p__52034$$,
$map__52045_p__52035$$){function $f$jscomp$797$$($JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$){var $temp__5823__auto__$jscomp$144$$=$reitit$impl$path_for$$($map__52045__$1$$,$JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$);$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$144$$)?$JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$=$reitit$core$__GT_Match$$($p$jscomp$232$$,$map__52042__$1$$,$result$jscomp$224$$,
$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$),$temp__5823__auto__$jscomp$144$$):($JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$=$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$),$JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$=new $reitit$core$PartialMatch$$($p$jscomp$232$$,
$map__52042__$1$$,$result$jscomp$224$$,$JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$,$path_params$jscomp$15$$,null,null,null));return $JSCompiler_temp$jscomp$2067_p1__52025_SHARP__path_params$jscomp$inline_9809$$}var $pl$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$15_p__52034$$,0,null);$nl$jscomp$15_p__52034$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$15_p__52034$$,1,null);var $p$jscomp$232$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52045_p__52035$$,
0,null),$map__52042_name$jscomp$243$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52045_p__52035$$,1,null),$map__52042__$1$$=$APP.$cljs$core$__destructure_map$$($map__52042_name$jscomp$243$$);$map__52042_name$jscomp$243$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52042__$1$$,$APP.$cljs$cst$725$name$$);var $result$jscomp$224$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52045_p__52035$$,2,null);$map__52045_p__52035$$=$reitit$impl$parse$$($p$jscomp$232$$,
$opts$jscomp$281$$);var $map__52045__$1$$=$APP.$cljs$core$__destructure_map$$($map__52045_p__52035$$),$path_params$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52045__$1$$,$APP.$cljs$cst$2395$path_params$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$reitit$trie$insert$cljs$0core$0IFn$0_invoke$0arity$04$$($pl$jscomp$11$$,$p$jscomp$232$$,$reitit$core$__GT_Match$$($p$jscomp$232$$,$map__52042__$1$$,$result$jscomp$224$$,
null,null),$opts$jscomp$281$$),$APP.$cljs$core$truth_$$($map__52042_name$jscomp$243$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nl$jscomp$15_p__52034$$,$map__52042_name$jscomp$243$$,$f$jscomp$797$$):$nl$jscomp$15_p__52034$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$compiled_routes$jscomp$11$$),$pl$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52031$jscomp$2$$,
0,null),$nl$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52031$jscomp$2$$,1,null),$matcher$jscomp$22$$=$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($pl$jscomp$10$$,$compiler$jscomp$9$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$match_by_path$jscomp$5$$=$APP.$cljs$core$truth_$$($matcher$jscomp$22$$)?$reitit$trie$_path_matcher$$($compiler$jscomp$9$$,$matcher$jscomp$22$$):null,$routes$jscomp$17$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$11$$);
return new $reitit$core$t_reitit$0core52046$$($matcher$jscomp$22$$,$names$jscomp$11$$,$compiled_routes$jscomp$11$$,$routes$jscomp$17$$,$vec__52031$jscomp$2$$,$nl$jscomp$14$$,$pl$jscomp$10$$,$nl$jscomp$14$$,$match_by_path$jscomp$5$$,$compiler$jscomp$9$$,$opts$jscomp$281$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$trie_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$single_static_path_router$$=function $reitit$core$single_static_path_router$$($var_args$jscomp$1047$$){switch(arguments.length){case 1:return $reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$14$$){return $reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$15$$,$opts$jscomp$284$$){var $JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$=($JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($compiled_routes$jscomp$15$$),1))?$JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$:
$APP.$cljs$core$some$$($reitit$impl$__GT_wild_route_QMARK_$$($opts$jscomp$284$$),$compiled_routes$jscomp$15$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$)&&$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$([":single-static-path-router requires exactly 1 static route: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($compiled_routes$jscomp$15$$)].join(""),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2397$routes$$,$compiled_routes$jscomp$15$$],null));$JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$=$reitit$impl$find_names$$($compiled_routes$jscomp$15$$);var $n$jscomp$283$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$,0,null),$vec__52078$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($compiled_routes$jscomp$15$$,
0,null),$p$jscomp$235$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52078$jscomp$2$$,0,null),$data$jscomp$188$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52078$jscomp$2$$,1,null),$result$jscomp$227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52078$jscomp$2$$,2,null),$match$jscomp$50$$=$reitit$core$__GT_Match$$($p$jscomp$235$$,$data$jscomp$188$$,$result$jscomp$227$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p$jscomp$235$$),$routes$jscomp$20$$=
$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$15$$);return new $reitit$core$t_reitit$0core52081$$($p$jscomp$235$$,$JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$,$match$jscomp$50$$,$data$jscomp$188$$,$compiled_routes$jscomp$15$$,$routes$jscomp$20$$,$compiled_routes$jscomp$15$$,$vec__52078$jscomp$2$$,$n$jscomp$283$$,$JSCompiler_inline_result$jscomp$2083_or__5025__auto__$jscomp$inline_9818_vec__52072$jscomp$2$$,$result$jscomp$227$$,$opts$jscomp$284$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$single_static_path_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$lookup_router$$=function $reitit$core$lookup_router$$($var_args$jscomp$1045$$){switch(arguments.length){case 1:return $reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$6$$){return $reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$7$$,$opts$jscomp$278$$){var $names$jscomp$8_temp__5825__auto___52259$$=$APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($reitit$impl$__GT_wild_route_QMARK_$$($opts$jscomp$278$$),$compiled_routes$jscomp$7$$));$names$jscomp$8_temp__5825__auto___52259$$&&$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(["can't create :lookup-router with wildcard routes: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($names$jscomp$8_temp__5825__auto___52259$$)].join(""),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2371$wilds$$,$names$jscomp$8_temp__5825__auto___52259$$,$APP.$cljs$cst$2397$routes$$,$compiled_routes$jscomp$7$$],null));$names$jscomp$8_temp__5825__auto___52259$$=$reitit$impl$find_names$$($compiled_routes$jscomp$7$$);var $vec__51985$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($nl$jscomp$11_p__51992$$,$p__51993$$){var $pl$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$11_p__51992$$,
0,null);$nl$jscomp$11_p__51992$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$11_p__51992$$,1,null);var $p$jscomp$231$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51993$$,0,null),$map__52000_name$jscomp$240$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51993$$,1,null),$map__52000__$1$$=$APP.$cljs$core$__destructure_map$$($map__52000_name$jscomp$240$$);$map__52000_name$jscomp$240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52000__$1$$,
$APP.$cljs$cst$725$name$$);var $result$jscomp$223$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51993$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($pl$jscomp$7$$,$p$jscomp$231$$,$reitit$core$__GT_Match$$($p$jscomp$231$$,$map__52000__$1$$,$result$jscomp$223$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p$jscomp$231$$)),$APP.$cljs$core$truth_$$($map__52000_name$jscomp$240$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nl$jscomp$11_p__51992$$,$map__52000_name$jscomp$240$$,function($p1__51971_SHARP_$$){return $reitit$core$__GT_Match$$($p$jscomp$231$$,$map__52000__$1$$,$result$jscomp$223$$,$p1__51971_SHARP_$$,$p$jscomp$231$$)}):$nl$jscomp$11_p__51992$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$compiled_routes$jscomp$7$$),
$pl$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51985$jscomp$2$$,0,null),$nl$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51985$jscomp$2$$,1,null),$routes$jscomp$14$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$7$$);return new $reitit$core$t_reitit$0core52001$$($names$jscomp$8_temp__5825__auto___52259$$,$pl$jscomp$6$$,$compiled_routes$jscomp$7$$,$routes$jscomp$14$$,$nl$jscomp$10$$,$pl$jscomp$6$$,$vec__51985$jscomp$2$$,$nl$jscomp$10$$,
$opts$jscomp$278$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$lookup_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$mixed_router$$=function $reitit$core$mixed_router$$($var_args$jscomp$1048$$){switch(arguments.length){case 1:return $reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$18$$){return $reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$19$$,$opts$jscomp$287$$){var $map__52095$jscomp$2_map__52095__$1$$=$APP.$cljs$core$group_by$$($reitit$impl$__GT_wild_route_QMARK_$$($opts$jscomp$287$$),$compiled_routes$jscomp$19$$);$map__52095$jscomp$2_map__52095__$1$$=$APP.$cljs$core$__destructure_map$$($map__52095$jscomp$2_map__52095__$1$$);var $wild$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52095$jscomp$2_map__52095__$1$$,
!0),$lookup$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52095$jscomp$2_map__52095__$1$$,!1),$__GT_static_router$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($lookup$jscomp$14$$))?$reitit$core$single_static_path_router$$:$reitit$core$lookup_router$$,$wildcard_router$jscomp$2$$=$reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$($wild$jscomp$2$$,$opts$jscomp$287$$),$static_router$jscomp$2$$=$__GT_static_router$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?
$__GT_static_router$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($lookup$jscomp$14$$,$opts$jscomp$287$$):$__GT_static_router$jscomp$2$$($lookup$jscomp$14$$,$opts$jscomp$287$$),$names$jscomp$17$$=$reitit$impl$find_names$$($compiled_routes$jscomp$19$$),$routes$jscomp$23$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$19$$);return new $reitit$core$t_reitit$0core52097$$($names$jscomp$17$$,$compiled_routes$jscomp$19$$,$routes$jscomp$23$$,$__GT_static_router$jscomp$2$$,$lookup$jscomp$14$$,$wild$jscomp$2$$,
$static_router$jscomp$2$$,$map__52095$jscomp$2_map__52095__$1$$,$opts$jscomp$287$$,$wildcard_router$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$mixed_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$quarantine_router$$=function $reitit$core$quarantine_router$$($var_args$jscomp$1049$$){switch(arguments.length){case 1:return $reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$22$$){return $reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$23$$,$opts$jscomp$290$$){function $conflicting_QMARK_$jscomp$2$$($p1__52107_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($conflicting_paths$jscomp$2$$,$APP.$cljs$core$first$$($p1__52107_SHARP_$$))}var $conflicting_paths$jscomp$2$$=$reitit$impl$conflicting_paths$$(function(){var $or__5025__auto__$jscomp$439$$=$APP.$cljs$cst$2449$reitit_DOT_core_SLASH_path_conflicting$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$290$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$439$$)?$or__5025__auto__$jscomp$439$$:$reitit$impl$path_conflicting_routes$$($compiled_routes$jscomp$23$$,$opts$jscomp$290$$)}()),$map__52110$jscomp$2_map__52110__$1$$=$APP.$cljs$core$group_by$$($conflicting_QMARK_$jscomp$2$$,$compiled_routes$jscomp$23$$);$map__52110$jscomp$2_map__52110__$1$$=$APP.$cljs$core$__destructure_map$$($map__52110$jscomp$2_map__52110__$1$$);var $conflicting$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52110$jscomp$2_map__52110__$1$$,
!0),$non_conflicting$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52110$jscomp$2_map__52110__$1$$,!1),$linear_router$jscomp$2$$=$reitit$core$linear_router$cljs$0core$0IFn$0_invoke$0arity$02$$($conflicting$jscomp$2$$,$opts$jscomp$290$$),$mixed_router$jscomp$2$$=$reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$($non_conflicting$jscomp$2$$,$opts$jscomp$290$$),$names$jscomp$20$$=$reitit$impl$find_names$$($compiled_routes$jscomp$23$$),$routes$jscomp$26$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$23$$);
return new $reitit$core$t_reitit$0core52118$$($non_conflicting$jscomp$2$$,$map__52110$jscomp$2_map__52110__$1$$,$names$jscomp$20$$,$conflicting_paths$jscomp$2$$,$compiled_routes$jscomp$23$$,$conflicting$jscomp$2$$,$routes$jscomp$26$$,$conflicting_QMARK_$jscomp$2$$,$mixed_router$jscomp$2$$,$linear_router$jscomp$2$$,$opts$jscomp$290$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$],null))};
$reitit$core$quarantine_router$$.$cljs$lang$maxFixedArity$=2;
var $cljs$cst$6347$exporting$$=new $APP.$cljs$core$Keyword$$(null,"exporting","exporting",-2019585981),$cljs$cst$6385$dashboard_legacy_team_settings$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-settings","dashboard-legacy-team-settings",1266059192),$cljs$cst$6528$getSharedPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginData-key","getSharedPluginData-key",1393856585),$cljs$cst$6545$applyTypography_typography$$=new $APP.$cljs$core$Keyword$$(null,"applyTypography-typography",
"applyTypography-typography",2055995230),$cljs$cst$6389$dashboard_legacy_font_providers$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-font-providers","dashboard-legacy-font-providers",192867763),$cljs$cst$6418$verticalMargin$$=new $APP.$cljs$core$Keyword$$(null,"verticalMargin","verticalMargin",2098722016),$cljs$cst$6594$font_height$$=new $APP.$cljs$core$Keyword$$(null,"font-height","font-height",49078273),$cljs$cst$6365$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.viewer",
"viewer-page*","app.main.ui.viewer/viewer-page*",2102384267,null),$cljs$cst$6390$dashboard_legacy_libraries$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-libraries","dashboard-legacy-libraries",-1600130587),$cljs$cst$6520$rotate_angle$$=new $APP.$cljs$core$Keyword$$(null,"rotate-angle","rotate-angle",-1896437128),$cljs$cst$6550$removeInteraction$$=new $APP.$cljs$core$Keyword$$(null,"removeInteraction","removeInteraction",1218317317),$cljs$cst$6495$border_radius_top_right$$=new $APP.$cljs$core$Keyword$$(null,
"border-radius-top-right","border-radius-top-right",-2056556020),$cljs$cst$6393$app_DOT_main_DOT_ui_DOT_routes_SLASH_teams$$=new $APP.$cljs$core$Keyword$$("app.main.ui.routes","teams","app.main.ui.routes/teams",-1977218830),$cljs$cst$6536$insertChild_child$$=new $APP.$cljs$core$Keyword$$(null,"insertChild-child","insertChild-child",1653590456),$cljs$cst$6425$minWidth$$=new $APP.$cljs$core$Keyword$$(null,"minWidth","minWidth",-204293526),$cljs$cst$6524$setPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,
"setPluginData-key","setPluginData-key",437211756),$cljs$cst$6362$finish$$=new $APP.$cljs$core$Keyword$$(null,"finish","finish",-586688046),$cljs$cst$6598$createColor$$=new $APP.$cljs$core$Keyword$$(null,"createColor","createColor",-414553580),$cljs$cst$6481$fontWeight$$=new $APP.$cljs$core$Keyword$$(null,"fontWeight","fontWeight",166450581),$cljs$cst$6448$setColumn$$=new $APP.$cljs$core$Keyword$$(null,"setColumn","setColumn",1194844473),$cljs$cst$6409$topPadding$$=new $APP.$cljs$core$Keyword$$(null,
"topPadding","topPadding",453548852),$cljs$cst$6480$fontSize$$=new $APP.$cljs$core$Keyword$$(null,"fontSize","fontSize",919623033),$cljs$cst$6399$plugin_name$$=new $APP.$cljs$core$Keyword$$(null,"plugin-name","plugin-name",1482210260),$cljs$cst$6463$columnSpan_value$$=new $APP.$cljs$core$Keyword$$(null,"columnSpan-value","columnSpan-value",2076747203),$cljs$cst$6534$getChildren$$=new $APP.$cljs$core$Keyword$$(null,"getChildren","getChildren",-446203521),$cljs$cst$6456$row_value$$=new $APP.$cljs$core$Keyword$$(null,
"row-value","row-value",-1067843622),$cljs$cst$6627$generateStyle_includeChildren$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-includeChildren","generateStyle-includeChildren",-441924583),$cljs$cst$6396$x_axis_rotation$$=new $APP.$cljs$core$Keyword$$(null,"x-axis-rotation","x-axis-rotation",-637606609),$cljs$cst$6626$generateStyle_withPrelude$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-withPrelude","generateStyle-withPrelude",-551214991),$cljs$cst$6560$reply$$=new $APP.$cljs$core$Keyword$$(null,
"reply","reply",1144328671),$cljs$cst$6614$replaceColor_newColor$$=new $APP.$cljs$core$Keyword$$(null,"replaceColor-newColor","replaceColor-newColor",-1427541529),$cljs$cst$6507$constraintsVertical$$=new $APP.$cljs$core$Keyword$$(null,"constraintsVertical","constraintsVertical",250879495),$cljs$cst$6436$lex$$=new $APP.$cljs$core$Keyword$$(null,"lex","lex",1572323917),$cljs$cst$6551$addRulerGuide$$=new $APP.$cljs$core$Keyword$$(null,"addRulerGuide","addRulerGuide",1837252654),$cljs$cst$6450$setRow_type$$=
new $APP.$cljs$core$Keyword$$(null,"setRow-type","setRow-type",1456587126),$cljs$cst$6564$page_plugin_data_namespace$$=new $APP.$cljs$core$Keyword$$(null,"page-plugin-data-namespace","page-plugin-data-namespace",-699256157),$cljs$cst$6618$createText$$=new $APP.$cljs$core$Keyword$$(null,"createText","createText",256547428),$cljs$cst$6610$selection$$=new $APP.$cljs$core$Keyword$$(null,"selection","selection",975998651),$cljs$cst$6413$appendChild$$=new $APP.$cljs$core$Keyword$$(null,"appendChild","appendChild",
1287125270),$cljs$cst$6613$replaceColor_oldColor$$=new $APP.$cljs$core$Keyword$$(null,"replaceColor-oldColor","replaceColor-oldColor",807960134),$cljs$cst$6568$removeFlow_flow$$=new $APP.$cljs$core$Keyword$$(null,"removeFlow-flow","removeFlow-flow",1839197888),$cljs$cst$6402$alignContent$$=new $APP.$cljs$core$Keyword$$(null,"alignContent","alignContent",403294922),$cljs$cst$6566$createFlow_name$$=new $APP.$cljs$core$Keyword$$(null,"createFlow-name","createFlow-name",88270356),$cljs$cst$6457$row_cell$$=
new $APP.$cljs$core$Keyword$$(null,"row-cell","row-cell",1612632022),$cljs$cst$6496$padding_top_left$$=new $APP.$cljs$core$Keyword$$(null,"padding-top-left","padding-top-left",-423019542),$cljs$cst$6386$dashboard_legacy_projects$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-projects","dashboard-legacy-projects",-834288049),$cljs$cst$6531$setSharedPluginData_value$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-value","setSharedPluginData-value",1942190613),$cljs$cst$6475$justifySelf$$=
new $APP.$cljs$core$Keyword$$(null,"justifySelf","justifySelf",-894439176),$cljs$cst$6588$findAllById$$=new $APP.$cljs$core$Keyword$$(null,"findAllById","findAllById",-633206720),$cljs$cst$6388$dashboard_legacy_fonts$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-fonts","dashboard-legacy-fonts",-1082225854),$cljs$cst$6547$applyTypography$$=new $APP.$cljs$core$Keyword$$(null,"applyTypography","applyTypography",-1953840408),$cljs$cst$6521$rotate_center$$=new $APP.$cljs$core$Keyword$$(null,"rotate-center",
"rotate-center",6610822),$cljs$cst$6563$page_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"page-plugin-data-key","page-plugin-data-key",936190759),$cljs$cst$6516$frameX$$=new $APP.$cljs$core$Keyword$$(null,"frameX","frameX",1123372234),$cljs$cst$6517$frameY$$=new $APP.$cljs$core$Keyword$$(null,"frameY","frameY",86132734),$cljs$cst$6379$debug_icons_preview$$=new $APP.$cljs$core$Keyword$$(null,"debug-icons-preview","debug-icons-preview",-444662807),$cljs$cst$6546$applyTypography_shape$$=new $APP.$cljs$core$Keyword$$(null,
"applyTypography-shape","applyTypography-shape",1275019073),$cljs$cst$6522$clone$$=new $APP.$cljs$core$Keyword$$(null,"clone","clone",711747572),$cljs$cst$6367$app_DOT_main_DOT_ui_DOT_settings_SLASH_settings_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.settings","settings-page*","app.main.ui.settings/settings-page*",-117972938,null),$cljs$cst$6405$rowGap$$=new $APP.$cljs$core$Keyword$$(null,"rowGap","rowGap",1869424743),$cljs$cst$6543$getRange_start$$=new $APP.$cljs$core$Keyword$$(null,
"getRange-start","getRange-start",243941450),$cljs$cst$6639$app_DOT_main_SLASH_initialize_rasterizer$$=new $APP.$cljs$core$Keyword$$("app.main","initialize-rasterizer","app.main/initialize-rasterizer",-823615130),$cljs$cst$6407$verticalPadding$$=new $APP.$cljs$core$Keyword$$(null,"verticalPadding","verticalPadding",-116062864),$cljs$cst$6629$alignHorizontal_shapes$$=new $APP.$cljs$core$Keyword$$(null,"alignHorizontal-shapes","alignHorizontal-shapes",1742786132),$cljs$cst$6428$addRow_type$$=new $APP.$cljs$core$Keyword$$(null,
"addRow-type","addRow-type",1581806272),$cljs$cst$6391$dashboard_legacy_files$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-files","dashboard-legacy-files",-547738017),$cljs$cst$6435$addColumn_type$$=new $APP.$cljs$core$Keyword$$(null,"addColumn-type","addColumn-type",369510652),$cljs$cst$6502$margin_top_left$$=new $APP.$cljs$core$Keyword$$(null,"margin-top-left","margin-top-left",-573305307),$cljs$cst$6468$areaName$$=new $APP.$cljs$core$Keyword$$(null,"areaName","areaName",-785186640),$cljs$cst$6345$export_success_QMARK_$$=
new $APP.$cljs$core$Keyword$$(null,"export-success?","export-success?",1913775048),$cljs$cst$6348$expected_use$$=new $APP.$cljs$core$Keyword$$(null,"expected-use","expected-use",133731615),$cljs$cst$6595$typography_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"typography-plugin-data-key","typography-plugin-data-key",1398110804),$cljs$cst$6398$name_like$$=new $APP.$cljs$core$Keyword$$(null,"name-like","name-like",244303068),$cljs$cst$6395$large_arc_flag$$=new $APP.$cljs$core$Keyword$$(null,
"large-arc-flag","large-arc-flag",396724034),$cljs$cst$6469$position_value$$=new $APP.$cljs$core$Keyword$$(null,"position-value","position-value",-1598412318),$cljs$cst$6424$maxWidth$$=new $APP.$cljs$core$Keyword$$(null,"maxWidth","maxWidth",-1375124795),$cljs$cst$6477$fontId$$=new $APP.$cljs$core$Keyword$$(null,"fontId","fontId",-474874285),$cljs$cst$6630$alignVertical_direction$$=new $APP.$cljs$core$Keyword$$(null,"alignVertical-direction","alignVertical-direction",-2037964308),$cljs$cst$6508$borderRadius$$=
new $APP.$cljs$core$Keyword$$(null,"borderRadius","borderRadius",-1505621083),$cljs$cst$6611$shapesColors_shapes$$=new $APP.$cljs$core$Keyword$$(null,"shapesColors-shapes","shapesColors-shapes",1999445904),$cljs$cst$6633$distributeVertical_shapes$$=new $APP.$cljs$core$Keyword$$(null,"distributeVertical-shapes","distributeVertical-shapes",404282144),$cljs$cst$6478$fontFamily$$=new $APP.$cljs$core$Keyword$$(null,"fontFamily","fontFamily",1493518353),$cljs$cst$6494$padding_bottom_right$$=new $APP.$cljs$core$Keyword$$(null,
"padding-bottom-right","padding-bottom-right",-495467114),$cljs$cst$6587$findByName$$=new $APP.$cljs$core$Keyword$$(null,"findByName","findByName",-1135437361),$cljs$cst$6414$horizontalSizing$$=new $APP.$cljs$core$Keyword$$(null,"horizontalSizing","horizontalSizing",1922240218),$cljs$cst$6592$setSharedPluginData_non_local_library$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-non-local-library","setSharedPluginData-non-local-library",331868634),$cljs$cst$6360$invites$$=new $APP.$cljs$core$Keyword$$(null,
"invites","invites",1962160761),$cljs$cst$6415$verticalSizing$$=new $APP.$cljs$core$Keyword$$(null,"verticalSizing","verticalSizing",911089716),$cljs$cst$6576$createPage$$=new $APP.$cljs$core$Keyword$$(null,"createPage","createPage",1663482836),$cljs$cst$6382$dashboard_legacy_team_members$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-members","dashboard-legacy-team-members",-659515913),$cljs$cst$6523$getPluginData$$=new $APP.$cljs$core$Keyword$$(null,"getPluginData","getPluginData",
190301887),$cljs$cst$6410$rightPadding$$=new $APP.$cljs$core$Keyword$$(null,"rightPadding","rightPadding",553025942),$cljs$cst$6498$border_radius_bottom_right$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-bottom-right","border-radius-bottom-right",-186894172),$cljs$cst$6506$constraintsHorizontal$$=new $APP.$cljs$core$Keyword$$(null,"constraintsHorizontal","constraintsHorizontal",1307569455),$cljs$cst$6397$sweep_flag$$=new $APP.$cljs$core$Keyword$$(null,"sweep-flag","sweep-flag",1319872435),
$cljs$cst$6363$app_DOT_main_DOT_ui_DOT_auth_SLASH_auth_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.auth","auth-page*","app.main.ui.auth/auth-page*",63279394,null),$cljs$cst$6346$prepare$$=new $APP.$cljs$core$Keyword$$(null,"prepare","prepare",-1449654665),$cljs$cst$6465$columnSpan$$=new $APP.$cljs$core$Keyword$$(null,"columnSpan","columnSpan",-1065100091),$cljs$cst$6381$render_sprite$$=new $APP.$cljs$core$Keyword$$(null,"render-sprite","render-sprite",463778943),$cljs$cst$6447$setColumn_value$$=
new $APP.$cljs$core$Keyword$$(null,"setColumn-value","setColumn-value",748250994),$cljs$cst$6505$proportionLock$$=new $APP.$cljs$core$Keyword$$(null,"proportionLock","proportionLock",90792392),$cljs$cst$6561$startingBoard$$=new $APP.$cljs$core$Keyword$$(null,"startingBoard","startingBoard",979547215),$cljs$cst$6444$removeColumn$$=new $APP.$cljs$core$Keyword$$(null,"removeColumn","removeColumn",-1624774294),$cljs$cst$6430$addRow$$=new $APP.$cljs$core$Keyword$$(null,"addRow","addRow",-1526940876),$cljs$cst$6635$centerShapes$$=
new $APP.$cljs$core$Keyword$$(null,"centerShapes","centerShapes",-1359078552),$cljs$cst$6460$rowSpan$$=new $APP.$cljs$core$Keyword$$(null,"rowSpan","rowSpan",826884002),$cljs$cst$6603$connectLibrary$$=new $APP.$cljs$core$Keyword$$(null,"connectLibrary","connectLibrary",606055059),$cljs$cst$6417$alignSelf$$=new $APP.$cljs$core$Keyword$$(null,"alignSelf","alignSelf",-1666557725),$cljs$cst$6573$pin$$=new $APP.$cljs$core$Keyword$$(null,"pin","pin",-2111774834),$cljs$cst$6622$generateMarkup_shapes$$=new $APP.$cljs$core$Keyword$$(null,
"generateMarkup-shapes","generateMarkup-shapes",-1635320333),$cljs$cst$6513$blendMode$$=new $APP.$cljs$core$Keyword$$(null,"blendMode","blendMode",2057676269),$cljs$cst$6355$start_with$$=new $APP.$cljs$core$Keyword$$(null,"start-with","start-with",1292915726),$cljs$cst$6504$addToken$$=new $APP.$cljs$core$Keyword$$(null,"addToken","addToken",-646732290),$cljs$cst$6380$debug_playground$$=new $APP.$cljs$core$Keyword$$(null,"debug-playground","debug-playground",371173136),$cljs$cst$6423$leftMargin$$=
new $APP.$cljs$core$Keyword$$(null,"leftMargin","leftMargin",-427217148),$cljs$cst$6470$position_cell$$=new $APP.$cljs$core$Keyword$$(null,"position-cell","position-cell",-608152505),$cljs$cst$6619$createShapeFromSvg$$=new $APP.$cljs$core$Keyword$$(null,"createShapeFromSvg","createShapeFromSvg",1744668068),$cljs$cst$6571$findCommentThreads$$=new $APP.$cljs$core$Keyword$$(null,"findCommentThreads","findCommentThreads",1948881022),$cljs$cst$6510$borderRadiusTopRight$$=new $APP.$cljs$core$Keyword$$(null,
"borderRadiusTopRight","borderRadiusTopRight",223982879),$cljs$cst$6422$bottomMargin$$=new $APP.$cljs$core$Keyword$$(null,"bottomMargin","bottomMargin",459661842),$cljs$cst$6591$setPluginData_non_local_library$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData-non-local-library","setPluginData-non-local-library",-839915494),$cljs$cst$6485$textTransform$$=new $APP.$cljs$core$Keyword$$(null,"textTransform","textTransform",-1959669529),$cljs$cst$6519$flipY$$=new $APP.$cljs$core$Keyword$$(null,"flipY",
"flipY",624880256),$cljs$cst$6518$flipX$$=new $APP.$cljs$core$Keyword$$(null,"flipX","flipX",-1853365),$cljs$cst$6486$textDecoration$$=new $APP.$cljs$core$Keyword$$(null,"textDecoration","textDecoration",418180221),$cljs$cst$6471$alignSelf_value$$=new $APP.$cljs$core$Keyword$$(null,"alignSelf-value","alignSelf-value",1581687155),$cljs$cst$6631$alignVertical_shapes$$=new $APP.$cljs$core$Keyword$$(null,"alignVertical-shapes","alignVertical-shapes",53178325),$cljs$cst$6437$addColumn_value$$=new $APP.$cljs$core$Keyword$$(null,
"addColumn-value","addColumn-value",-154426043),$cljs$cst$6615$uploadMedia_name$$=new $APP.$cljs$core$Keyword$$(null,"uploadMedia-name","uploadMedia-name",-1741554770),$cljs$cst$6578$export_file$$=new $APP.$cljs$core$Keyword$$(null,"export-file","export-file",-1808912864),$cljs$cst$6434$addRowAtIndex$$=new $APP.$cljs$core$Keyword$$(null,"addRowAtIndex","addRowAtIndex",-909836310),$cljs$cst$6552$removeRulerGuide$$=new $APP.$cljs$core$Keyword$$(null,"removeRulerGuide","removeRulerGuide",-1323808559),
$cljs$cst$6406$columnGap$$=new $APP.$cljs$core$Keyword$$(null,"columnGap","columnGap",-376837767),$cljs$cst$6549$addInteraction$$=new $APP.$cljs$core$Keyword$$(null,"addInteraction","addInteraction",1571848503),$cljs$cst$6357$onboarding_team_id$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-team-id","onboarding-team-id",1539385036),$cljs$cst$6620$createBoolean_boolType$$=new $APP.$cljs$core$Keyword$$(null,"createBoolean-boolType","createBoolean-boolType",1854310447),$cljs$cst$6419$horizontalMargin$$=
new $APP.$cljs$core$Keyword$$(null,"horizontalMargin","horizontalMargin",606533049),$cljs$cst$6628$alignHorizontal_direction$$=new $APP.$cljs$core$Keyword$$(null,"alignHorizontal-direction","alignHorizontal-direction",-378078007),$cljs$cst$6392$workspace_legacy$$=new $APP.$cljs$core$Keyword$$(null,"workspace-legacy","workspace-legacy",104522706),$cljs$cst$6585$applyToRange$$=new $APP.$cljs$core$Keyword$$(null,"applyToRange","applyToRange",1653614162),$cljs$cst$6431$addRowAtIndex_index$$=new $APP.$cljs$core$Keyword$$(null,
"addRowAtIndex-index","addRowAtIndex-index",-1679866381),$cljs$cst$6530$setSharedPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-key","setSharedPluginData-key",-1257676988),$cljs$cst$6499$border_radius_top_left$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-top-left","border-radius-top-left",-1945583265),$cljs$cst$6489$textDirection$$=new $APP.$cljs$core$Keyword$$(null,"textDirection","textDirection",-486409590),$cljs$cst$6623$generateMarkup_type$$=new $APP.$cljs$core$Keyword$$(null,
"generateMarkup-type","generateMarkup-type",-177562878),$cljs$cst$6488$growType$$=new $APP.$cljs$core$Keyword$$(null,"growType","growType",-2038406868),$cljs$cst$6525$setPluginData_value$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData-value","setPluginData-value",281004073),$cljs$cst$6443$removeRow$$=new $APP.$cljs$core$Keyword$$(null,"removeRow","removeRow",453086520),$cljs$cst$6354$team_size$$=new $APP.$cljs$core$Keyword$$(null,"team-size","team-size",2116636517),$cljs$cst$6625$generateStyle_type$$=
new $APP.$cljs$core$Keyword$$(null,"generateStyle-type","generateStyle-type",196722442),$cljs$cst$6580$findVersions$$=new $APP.$cljs$core$Keyword$$(null,"findVersions","findVersions",1578584464),$cljs$cst$6511$borderRadiusBottomRight$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusBottomRight","borderRadiusBottomRight",-1210449538),$cljs$cst$6461$column_value$$=new $APP.$cljs$core$Keyword$$(null,"column-value","column-value",1145304215),$cljs$cst$6599$createTypography$$=new $APP.$cljs$core$Keyword$$(null,
"createTypography","createTypography",1413714480),$cljs$cst$6479$fontVariantId$$=new $APP.$cljs$core$Keyword$$(null,"fontVariantId","fontVariantId",-598111105),$cljs$cst$6403$justifyItems$$=new $APP.$cljs$core$Keyword$$(null,"justifyItems","justifyItems",710685366),$cljs$cst$6493$margin_bottom_right$$=new $APP.$cljs$core$Keyword$$(null,"margin-bottom-right","margin-bottom-right",-258834144),$cljs$cst$6408$horizontalPadding$$=new $APP.$cljs$core$Keyword$$(null,"horizontalPadding","horizontalPadding",
513951974),$cljs$cst$6574$get_team_users$$=new $APP.$cljs$core$Keyword$$(null,"get-team-users","get-team-users",796041692),$cljs$cst$6464$columnSpan_cell$$=new $APP.$cljs$core$Keyword$$(null,"columnSpan-cell","columnSpan-cell",-149218441),$cljs$cst$6404$justifyContent$$=new $APP.$cljs$core$Keyword$$(null,"justifyContent","justifyContent",885406515),$cljs$cst$6575$getPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"getPluginData-key","getPluginData-key",-1372143031),$cljs$cst$6617$group_shapes$$=
new $APP.$cljs$core$Keyword$$(null,"group-shapes","group-shapes",1902987914),$cljs$cst$6512$borderRadiusBottomLeft$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusBottomLeft","borderRadiusBottomLeft",-81645913),$cljs$cst$6604$getItem$$=new $APP.$cljs$core$Keyword$$(null,"getItem","getItem",-1850161217),$cljs$cst$6370$get_library_file_references$$=new $APP.$cljs$core$Keyword$$(null,"get-library-file-references","get-library-file-references",383296011),$cljs$cst$6473$justifySelf_value$$=new $APP.$cljs$core$Keyword$$(null,
"justifySelf-value","justifySelf-value",131913092),$cljs$cst$6491$padding_top_right$$=new $APP.$cljs$core$Keyword$$(null,"padding-top-right","padding-top-right",-1775436890),$cljs$cst$6501$border_radius_bottom_left$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-bottom-left","border-radius-bottom-left",-1697288612),$cljs$cst$6353$img_height$$=new $APP.$cljs$core$Keyword$$(null,"img-height","img-height",1572702026),$cljs$cst$6372$nitrate_entry$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-entry",
"nitrate-entry",1711495687),$cljs$cst$6593$getSharedPluginDataKeys_namespace$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginDataKeys-namespace","getSharedPluginDataKeys-namespace",207404581),$cljs$cst$6394$app_DOT_main_DOT_ui_DOT_routes_SLASH_init_routes$$=new $APP.$cljs$core$Keyword$$("app.main.ui.routes","init-routes","app.main.ui.routes/init-routes",601316191),$cljs$cst$6455$appendChild_column$$=new $APP.$cljs$core$Keyword$$(null,"appendChild-column","appendChild-column",-2018830626),$cljs$cst$6412$leftPadding$$=
new $APP.$cljs$core$Keyword$$(null,"leftPadding","leftPadding",-550857795),$cljs$cst$6474$justifySelf_cell$$=new $APP.$cljs$core$Keyword$$(null,"justifySelf-cell","justifySelf-cell",1644610466),$cljs$cst$6581$findVersions_user$$=new $APP.$cljs$core$Keyword$$(null,"findVersions-user","findVersions-user",836091189),$cljs$cst$6600$createComponent$$=new $APP.$cljs$core$Keyword$$(null,"createComponent","createComponent",-2141156902),$cljs$cst$6586$findbyId$$=new $APP.$cljs$core$Keyword$$(null,"findbyId",
"findbyId",681438060),$cljs$cst$6538$addGridLayout$$=new $APP.$cljs$core$Keyword$$(null,"addGridLayout","addGridLayout",-2084589424),$cljs$cst$6562$getShapeById$$=new $APP.$cljs$core$Keyword$$(null,"getShapeById","getShapeById",1762718316),$cljs$cst$6589$findAllByName$$=new $APP.$cljs$core$Keyword$$(null,"findAllByName","findAllByName",1530295653),$cljs$cst$6609$zoomIntoView$$=new $APP.$cljs$core$Keyword$$(null,"zoomIntoView","zoomIntoView",-898042566),$cljs$cst$6579$export_files$$=new $APP.$cljs$core$Keyword$$(null,
"export-files","export-files",1120929044),$cljs$cst$6621$createBoolean_shapes$$=new $APP.$cljs$core$Keyword$$(null,"createBoolean-shapes","createBoolean-shapes",-1009255477),$cljs$cst$6584$applyToText$$=new $APP.$cljs$core$Keyword$$(null,"applyToText","applyToText",-2123120633),$cljs$cst$6492$padding_bottom_left$$=new $APP.$cljs$core$Keyword$$(null,"padding-bottom-left","padding-bottom-left",-876282989),$cljs$cst$6343$hash$$=new $APP.$cljs$core$Keyword$$(null,"hash","hash",-13781596),$cljs$cst$6590$undoBlockFinish$$=
new $APP.$cljs$core$Keyword$$(null,"undoBlockFinish","undoBlockFinish",223635385),$cljs$cst$6541$toD$$=new $APP.$cljs$core$Keyword$$(null,"toD","toD",-167929600),$cljs$cst$6634$flatten_shapes$$=new $APP.$cljs$core$Keyword$$(null,"flatten-shapes","flatten-shapes",489189922),$cljs$cst$6529$setSharedPluginData_namespace$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-namespace","setSharedPluginData-namespace",807971852),$cljs$cst$6420$topMargin$$=new $APP.$cljs$core$Keyword$$(null,"topMargin",
"topMargin",1454522636),$cljs$cst$6368$app_DOT_main_DOT_ui_DOT_workspace_SLASH_workspace_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.workspace","workspace-page*","app.main.ui.workspace/workspace-page*",1318295057,null),$cljs$cst$6577$export_file_v3$$=new $APP.$cljs$core$Keyword$$(null,"export-file-v3","export-file-v3",-1949378869),$cljs$cst$6449$setRow_index$$=new $APP.$cljs$core$Keyword$$(null,"setRow-index","setRow-index",1430875983),$cljs$cst$6441$addColumnAtIndex_value$$=new $APP.$cljs$core$Keyword$$(null,
"addColumnAtIndex-value","addColumnAtIndex-value",-1084618681),$cljs$cst$6597$component_plugin_data_namespace$$=new $APP.$cljs$core$Keyword$$(null,"component-plugin-data-namespace","component-plugin-data-namespace",-953872153),$cljs$cst$6605$setItem$$=new $APP.$cljs$core$Keyword$$(null,"setItem","setItem",1848393972),$cljs$cst$6467$areaName_cell$$=new $APP.$cljs$core$Keyword$$(null,"areaName-cell","areaName-cell",303279412),$cljs$cst$6432$addRowAtIndex_type$$=new $APP.$cljs$core$Keyword$$(null,"addRowAtIndex-type",
"addRowAtIndex-type",1831710979),$cljs$cst$6567$createFlow_frame$$=new $APP.$cljs$core$Keyword$$(null,"createFlow-frame","createFlow-frame",-1759152297),$cljs$cst$6535$insertChild$$=new $APP.$cljs$core$Keyword$$(null,"insertChild","insertChild",649742086),$cljs$cst$6565$openPage$$=new $APP.$cljs$core$Keyword$$(null,"openPage","openPage",136412439),$cljs$cst$6427$righPadding$$=new $APP.$cljs$core$Keyword$$(null,"righPadding","righPadding",422429811),$cljs$cst$6358$onboarding_without_invitations$$=
new $APP.$cljs$core$Keyword$$(null,"onboarding-without-invitations","onboarding-without-invitations",-677171434),$cljs$cst$6526$setPluginData$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData","setPluginData",2049380387),$cljs$cst$6359$onboarding_with_invitations$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-with-invitations","onboarding-with-invitations",1108924654),$cljs$cst$6384$dashboard_legacy_team_webhooks$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-webhooks","dashboard-legacy-team-webhooks",
-1694314662),$cljs$cst$6387$dashboard_legacy_search$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-search","dashboard-legacy-search",1431918022),$cljs$cst$6540$removeMask$$=new $APP.$cljs$core$Keyword$$(null,"removeMask","removeMask",1636150276),$cljs$cst$6458$rowSpan_value$$=new $APP.$cljs$core$Keyword$$(null,"rowSpan-value","rowSpan-value",-2081956858),$cljs$cst$6400$dir$$=new $APP.$cljs$core$Keyword$$(null,"dir","dir",1734754661),$cljs$cst$6532$setSharedPluginData$$=new $APP.$cljs$core$Keyword$$(null,
"setSharedPluginData","setSharedPluginData",-324251591),$cljs$cst$6383$dashboard_legacy_team_invitations$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-invitations","dashboard-legacy-team-invitations",464259896),$cljs$cst$6612$replaceColor_shapes$$=new $APP.$cljs$core$Keyword$$(null,"replaceColor-shapes","replaceColor-shapes",61687483),$cljs$cst$6527$getSharedPluginData_namespace$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginData-namespace","getSharedPluginData-namespace",823864288),
$cljs$cst$6452$setRow$$=new $APP.$cljs$core$Keyword$$(null,"setRow","setRow",959178877),$cljs$cst$6350$experience_design_tool$$=new $APP.$cljs$core$Keyword$$(null,"experience-design-tool","experience-design-tool",1120701429),$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$=new $APP.$cljs$core$Keyword$$("app.plugins.events","not-changed","app.plugins.events/not-changed",1296884509),$cljs$cst$6351$experience_design_tool_other$$=new $APP.$cljs$core$Keyword$$(null,"experience-design-tool-other",
"experience-design-tool-other",-1840227460),$cljs$cst$6557$content_type$$=new $APP.$cljs$core$Keyword$$(null,"content-type","content-type",-508222634),$cljs$cst$6356$start_with_other$$=new $APP.$cljs$core$Keyword$$(null,"start-with-other","start-with-other",-1627779046),$cljs$cst$6472$alignSelf_cell$$=new $APP.$cljs$core$Keyword$$(null,"alignSelf-cell","alignSelf-cell",702748092),$cljs$cst$6429$addRow_value$$=new $APP.$cljs$core$Keyword$$(null,"addRow-value","addRow-value",-1889184769),$cljs$cst$6411$bottomPadding$$=
new $APP.$cljs$core$Keyword$$(null,"bottomPadding","bottomPadding",-646451636),$cljs$cst$6602$file_plugin_data_namespace$$=new $APP.$cljs$core$Keyword$$(null,"file-plugin-data-namespace","file-plugin-data-namespace",1778425062),$cljs$cst$6636$app_DOT_plugins_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.plugins","initialize","app.plugins/initialize",-280898138),$cljs$cst$6596$component_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"component-plugin-data-key","component-plugin-data-key",
-1960216489),$cljs$cst$6606$removeItem$$=new $APP.$cljs$core$Keyword$$(null,"removeItem","removeItem",-1184844686),$cljs$cst$6570$removeCommentThread$$=new $APP.$cljs$core$Keyword$$(null,"removeCommentThread","removeCommentThread",-1296576721),$cljs$cst$6533$getSharedPluginDataKeys$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginDataKeys","getSharedPluginDataKeys",1605636461),$cljs$cst$6514$parentX$$=new $APP.$cljs$core$Keyword$$(null,"parentX","parentX",283353021),$cljs$cst$6515$parentY$$=new $APP.$cljs$core$Keyword$$(null,
"parentY","parentY",485277499),$cljs$cst$6490$verticalAlign$$=new $APP.$cljs$core$Keyword$$(null,"verticalAlign","verticalAlign",465597462),$cljs$cst$6451$setRow_value$$=new $APP.$cljs$core$Keyword$$(null,"setRow-value","setRow-value",-11319580),$cljs$cst$6439$addColumnAtIndex_index$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex-index","addColumnAtIndex-index",1508798879),$cljs$cst$6509$borderRadiusTopLeft$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusTopLeft","borderRadiusTopLeft",1495282142),
$cljs$cst$6559$findComments$$=new $APP.$cljs$core$Keyword$$(null,"findComments","findComments",1317965565),$cljs$cst$6632$distributeHorizontal_shapes$$=new $APP.$cljs$core$Keyword$$(null,"distributeHorizontal-shapes","distributeHorizontal-shapes",-995314595),$cljs$cst$6487$characters$$=new $APP.$cljs$core$Keyword$$(null,"characters","characters",-163867197),$cljs$cst$6361$klass$$=new $APP.$cljs$core$Keyword$$(null,"klass","klass",-1386752349),$cljs$cst$6421$rightMargin$$=new $APP.$cljs$core$Keyword$$(null,
"rightMargin","rightMargin",1199553501),$cljs$cst$6454$appendChild_row$$=new $APP.$cljs$core$Keyword$$(null,"appendChild-row","appendChild-row",420578043),$cljs$cst$6497$margin_bottom_left$$=new $APP.$cljs$core$Keyword$$(null,"margin-bottom-left","margin-bottom-left",2114774968),$cljs$cst$6556$app_DOT_common_DOT_types_DOT_grid_SLASH_grid$$=new $APP.$cljs$core$Keyword$$("app.common.types.grid","grid","app.common.types.grid/grid",-1484913641),$cljs$cst$6640$app_DOT_main_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main",
"initialize","app.main/initialize",1664955691),$cljs$cst$6544$getRange_end$$=new $APP.$cljs$core$Keyword$$(null,"getRange-end","getRange-end",-1693867629),$cljs$cst$6446$setColumn_type$$=new $APP.$cljs$core$Keyword$$(null,"setColumn-type","setColumn-type",373633885),$cljs$cst$6440$addColumnAtIndex_type$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex-type","addColumnAtIndex-type",-990488622),$cljs$cst$6377$frame_preview$$=new $APP.$cljs$core$Keyword$$(null,"frame-preview","frame-preview",1876875008),
$cljs$cst$6442$addColumnAtIndex$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex","addColumnAtIndex",316866004),$cljs$cst$6352$img_width$$=new $APP.$cljs$core$Keyword$$(null,"img-width","img-width",1169865415),$cljs$cst$6433$addRowAtIndex_value$$=new $APP.$cljs$core$Keyword$$(null,"addRowAtIndex-value","addRowAtIndex-value",-515836114),$cljs$cst$6378$viewer_legacy$$=new $APP.$cljs$core$Keyword$$(null,"viewer-legacy","viewer-legacy",-1892502654),$cljs$cst$6483$lineHeight$$=new $APP.$cljs$core$Keyword$$(null,
"lineHeight","lineHeight",-1729831016),$cljs$cst$6637$asserts$$=new $APP.$cljs$core$Keyword$$(null,"asserts","asserts",359548304),$cljs$cst$6462$column_cell$$=new $APP.$cljs$core$Keyword$$(null,"column-cell","column-cell",-497688888),$cljs$cst$6503$applyToSelected$$=new $APP.$cljs$core$Keyword$$(null,"applyToSelected","applyToSelected",577942880),$cljs$cst$6342$modified$$=new $APP.$cljs$core$Keyword$$(null,"modified","modified",-2134587826),$cljs$cst$6539$makeMask$$=new $APP.$cljs$core$Keyword$$(null,
"makeMask","makeMask",1937012005),$cljs$cst$6349$role_other$$=new $APP.$cljs$core$Keyword$$(null,"role-other","role-other",-933264397),$cljs$cst$6482$fontStyle$$=new $APP.$cljs$core$Keyword$$(null,"fontStyle","fontStyle",1246842165),$cljs$cst$6426$minHeight$$=new $APP.$cljs$core$Keyword$$(null,"minHeight","minHeight",-1635998980),$cljs$cst$6542$getRange_shape$$=new $APP.$cljs$core$Keyword$$(null,"getRange-shape","getRange-shape",1197987177),$cljs$cst$6459$rowSpan_cell$$=new $APP.$cljs$core$Keyword$$(null,
"rowSpan-cell","rowSpan-cell",-2040199739),$cljs$cst$6537$addFlexLayout$$=new $APP.$cljs$core$Keyword$$(null,"addFlexLayout","addFlexLayout",222594497),$cljs$cst$6438$addColumn$$=new $APP.$cljs$core$Keyword$$(null,"addColumn","addColumn",-1515461232),$cljs$cst$6555$showInViewMode$$=new $APP.$cljs$core$Keyword$$(null,"showInViewMode","showInViewMode",-445923934),$cljs$cst$6369$dashboard_font_providers$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-font-providers","dashboard-font-providers",-593422352),
$cljs$cst$6500$margin_top_right$$=new $APP.$cljs$core$Keyword$$(null,"margin-top-right","margin-top-right",257117857),$cljs$cst$6445$setColumn_index$$=new $APP.$cljs$core$Keyword$$(null,"setColumn-index","setColumn-index",-1846647314),$cljs$cst$6476$board$$=new $APP.$cljs$core$Keyword$$(null,"board","board",-1907017633),$cljs$cst$6341$cache$$=new $APP.$cljs$core$Keyword$$(null,"cache","cache",-1237023054),$cljs$cst$6569$addCommentThread$$=new $APP.$cljs$core$Keyword$$(null,"addCommentThread","addCommentThread",
11455178),$cljs$cst$6601$file_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"file-plugin-data-key","file-plugin-data-key",-1008870444),$cljs$cst$6416$zIndex$$=new $APP.$cljs$core$Keyword$$(null,"zIndex","zIndex",-1588341609),$cljs$cst$6484$letterSpacing$$=new $APP.$cljs$core$Keyword$$(null,"letterSpacing","letterSpacing",-1331934989),$cljs$cst$6401$alignItems$$=new $APP.$cljs$core$Keyword$$(null,"alignItems","alignItems",410331199),$cljs$cst$6548$setParentIndex$$=new $APP.$cljs$core$Keyword$$(null,
"setParentIndex","setParentIndex",1845372782),$cljs$cst$6608$center_y$$=new $APP.$cljs$core$Keyword$$(null,"center-y","center-y",-233780987),$cljs$cst$6607$center_x$$=new $APP.$cljs$core$Keyword$$(null,"center-x","center-x",2109659472),$cljs$cst$6583$app_DOT_plugins_DOT_events_SLASH_void$$=new $APP.$cljs$core$Keyword$$("app.plugins.events","void","app.plugins.events/void",1229710245),$cljs$cst$6453$appendChild_child$$=new $APP.$cljs$core$Keyword$$(null,"appendChild-child","appendChild-child",-568841985),
$cljs$cst$6616$uploadMedia_url$$=new $APP.$cljs$core$Keyword$$(null,"uploadMedia-url","uploadMedia-url",-675246750),$cljs$cst$6366$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.dashboard","dashboard-page*","app.main.ui.dashboard/dashboard-page*",-1237983004,null),$cljs$cst$6554$clipContent$$=new $APP.$cljs$core$Keyword$$(null,"clipContent","clipContent",249671651),$cljs$cst$6572$restore$$=new $APP.$cljs$core$Keyword$$(null,"restore","restore",
267172424),$cljs$cst$6466$areaName_value$$=new $APP.$cljs$core$Keyword$$(null,"areaName-value","areaName-value",982496147),$cljs$cst$6553$applyToken$$=new $APP.$cljs$core$Keyword$$(null,"applyToken","applyToken",-109067546),$cljs$cst$6638$build_date$$=new $APP.$cljs$core$Keyword$$(null,"build-date","build-date",-325850528),$cljs$cst$6364$app_DOT_main_DOT_ui_DOT_auth_DOT_verify_token_SLASH_verify_token_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.auth.verify-token","verify-token-page*","app.main.ui.auth.verify-token/verify-token-page*",
426832199,null),$cljs$cst$6371$auth_recovery$$=new $APP.$cljs$core$Keyword$$(null,"auth-recovery","auth-recovery",-1821305124),$cljs$cst$6624$generateStyle_shapes$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-shapes","generateStyle-shapes",-2048142893);$APP.$JSCompiler_prototypeAlias$$=$app$common$types$objects_map$ObjectsMapEntry$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$891$$,$writer$jscomp$177$$,$opts$jscomp$313$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$177$$,function($item$jscomp$149$$,$w$jscomp$47$$){return $APP.$cljs$core$_write$$($w$jscomp$47$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$item$jscomp$149$$])))},"[",", ","]",$opts$jscomp$313$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($node$jscomp$482$$,$k$jscomp$718$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$718$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($node$jscomp$483$$,$k$jscomp$719$$,$not_found$jscomp$88$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$719$$,$not_found$jscomp$88$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_key$arity$1$=function(){return this.key};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_val$arity$1$=function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.$omap$,this.key)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $app$common$types$objects_map$_hash_for_key$$(this.$omap$,this.key)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$892$$,$other$jscomp$204$$){return $APP.$cljs$core$map_entry_QMARK_$$($other$jscomp$204$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.key.$cljs$core$IFn$_invoke$arity$1$?this.key.$cljs$core$IFn$_invoke$arity$1$(this):this.key(this),this.key.$cljs$core$IFn$_invoke$arity$1$?this.key.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$204$$):this.key($other$jscomp$204$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_val$$(this),
$APP.$cljs$core$_val$$($other$jscomp$204$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($node$jscomp$484$$,$n$jscomp$325$$){if($n$jscomp$325$$===0)return this.key;if($n$jscomp$325$$===1)return this.$cljs$core$IMapEntry$_val$arity$1$(null);throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($node$jscomp$485$$,$n$jscomp$326$$,$not_found$jscomp$89$$){return $n$jscomp$326$$===0?this.key:$n$jscomp$326$$===1?this.$cljs$core$IMapEntry$_val$arity$1$(null):$not_found$jscomp$89$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $this$__$1$jscomp$450$$=this;return $APP.$cljs$core$cons$$(this.key,new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$($this$__$1$jscomp$450$$.$cljs$core$IMapEntry$_val$arity$1$(null),null)},null,null))};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$35$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7606$$,$args82977$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args82977$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$720$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$720$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$721$$,$not_found$jscomp$90$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$721$$,$not_found$jscomp$90$$)};$APP.$JSCompiler_prototypeAlias$$=$app$common$types$objects_map$ObjectsMap$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$894$$,$writer$jscomp$178$$,$opts$jscomp$314$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$178$$,function($item$jscomp$150$$,$w$jscomp$48$$){$APP.$cljs$core$_write$$($w$jscomp$48$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_key$$($item$jscomp$150$$)])));$APP.$cljs$core$_write$$($w$jscomp$48$$,
" ");return $APP.$cljs$core$_write$$($w$jscomp$48$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_val$$($item$jscomp$150$$)])))},"#penpot/objects-map {",", ","}",$opts$jscomp$314$$,$APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$SeqIter$$(this)};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$205$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$205$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$keys$$(this))};$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $APP.$cljs$core$es6_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$vals$$(this))};
$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$722$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$722$$)};$APP.$JSCompiler_prototypeAlias$$.get=function($k$jscomp$723$$,$not_found$jscomp$91$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$723$$,$not_found$jscomp$91$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$888$$){return $APP.$cljs$core$run_BANG_$$(function($p__82991_v$jscomp$695$$){var $k$jscomp$724$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82991_v$jscomp$695$$,0,null);$p__82991_v$jscomp$695$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82991_v$jscomp$695$$,1,null);return $f$jscomp$888$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$888$$.$cljs$core$IFn$_invoke$arity$2$($p__82991_v$jscomp$695$$,$k$jscomp$724$$):
$f$jscomp$888$$($p__82991_v$jscomp$695$$,$k$jscomp$724$$)},this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($this$$jscomp$904$$,$k$jscomp$725$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.data,$k$jscomp$725$$)?new $app$common$types$objects_map$ObjectsMapEntry$$($k$jscomp$725$$,this):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this$$jscomp$905$$,$new_meta$jscomp$36$$){return $new_meta$jscomp$36$$===$APP.$cljs$core$meta$$?this:new $app$common$types$objects_map$ObjectsMap$$($new_meta$jscomp$36$$,this.cache,this.data,this.$modified$,this.hash)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$,$k$jscomp$726$$){$or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$=$APP.$cljs$core$_lookup$$(this.cache,$k$jscomp$726$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$))return $or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$;if($APP.$cljs$core$_contains_key_QMARK_$$(this.data,
$k$jscomp$726$$))return $or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$=$APP.$cljs$core$_lookup$$(this.data,$k$jscomp$726$$),$or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$),this.cache=$APP.$cljs$core$_assoc$$(this.cache,$k$jscomp$726$$,$or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$),
$or__5025__auto__$jscomp$1416_this$$jscomp$906_v$jscomp$696_v__$1$jscomp$35$$;this.cache=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.cache,$k$jscomp$726$$,null);return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$907$$,$k$jscomp$727$$,$not_found$jscomp$92$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.data,$k$jscomp$727$$)?this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$727$$):$not_found$jscomp$92$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.metadata};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$$(this);return new $app$common$types$objects_map$ObjectsMap$$(this.metadata,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,this.data,!1,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this$$jscomp$909$$,$f$jscomp$889$$,$init$jscomp$61$$){var $this$__$1$jscomp$458$$=this;return $APP.$cljs$core$_kv_reduce$$(this.data,function($init__$1$jscomp$12$$,$k$jscomp$728$$){var $G__82999$$=$this$__$1$jscomp$458$$.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$728$$);return $f$jscomp$889$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$889$$.$cljs$core$IFn$_invoke$arity$3$($init__$1$jscomp$12$$,$k$jscomp$728$$,
$G__82999$$):$f$jscomp$889$$($init__$1$jscomp$12$$,$k$jscomp$728$$,$G__82999$$)},$init$jscomp$61$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){$APP.$cljs$core$truth_$$(this.hash)||(this.hash=$APP.$cljs$core$hash_unordered_coll$$(this));return this.hash};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$911$$,$other$jscomp$206$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$206$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$?$app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$():$app$common$types$objects_map$create$$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($_$jscomp$3180$$,$k$jscomp$729$$,$v$jscomp$697$$){return new $app$common$types$objects_map$ObjectsMap$$(this.metadata,$APP.$cljs$core$_assoc$$(this.cache,$k$jscomp$729$$,$v$jscomp$697$$),$APP.$cljs$core$_assoc$$(this.data,$k$jscomp$729$$,null),!0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($_$jscomp$3181$$,$k$jscomp$730$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.data,$k$jscomp$730$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$_count$$(this.data)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($_$jscomp$3183$$,$k$jscomp$731$$){return new $app$common$types$objects_map$ObjectsMap$$(this.metadata,$APP.$cljs$core$_dissoc$$(this.cache,$k$jscomp$731$$),$APP.$cljs$core$_dissoc$$(this.data,$k$jscomp$731$$),!0,null)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$objects_map$IObjectsMap$get_data$arity$1$=function(){$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$$(this);return this.data};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$objects_map$IObjectsMap$_hash_for_key$arity$2$=function($this$$jscomp$914$$,$key$jscomp$432$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.cache,$key$jscomp$432$$)?$APP.$cljs$core$_hash$$($APP.$cljs$core$_lookup$$(this.cache,$key$jscomp$432$$)):$APP.$cljs$core$_hash$$(this.$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$432$$))};
$APP.$JSCompiler_prototypeAlias$$.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$142$data$$,this.data,$cljs$cst$6341$cache$$,this.cache,$cljs$cst$6342$modified$$,this.$modified$,$cljs$cst$6343$hash$$,this.hash],null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $this$__$1$jscomp$464$$=this;return $APP.$cljs$core$seq$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$1079$$){return new $app$common$types$objects_map$ObjectsMapEntry$$($id$jscomp$1079$$,$this$__$1$jscomp$464$$)},$APP.$cljs$core$keys$$(this.data)))};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$36$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7642$$,$args82988$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args82988$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$732$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$732$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$733$$,$not_found$jscomp$93$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$733$$,$not_found$jscomp$93$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__83047_ret$jscomp$148_this$$jscomp$918$$,$G__83048_entry$jscomp$85_es$jscomp$12$$){if($APP.$cljs$core$map_entry_QMARK_$$($G__83048_entry$jscomp$85_es$jscomp$12$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$G__83048_entry$jscomp$85_es$jscomp$12$$.key,$G__83048_entry$jscomp$85_es$jscomp$12$$.$cljs$core$IMapEntry$_val$arity$1$(null));if($APP.$cljs$core$vector_QMARK_$$($G__83048_entry$jscomp$85_es$jscomp$12$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,
$APP.$cljs$core$_nth$$($G__83048_entry$jscomp$85_es$jscomp$12$$,0),$APP.$cljs$core$_nth$$($G__83048_entry$jscomp$85_es$jscomp$12$$,1));$G__83047_ret$jscomp$148_this$$jscomp$918$$=this;for($G__83048_entry$jscomp$85_es$jscomp$12$$=$APP.$cljs$core$seq$$($G__83048_entry$jscomp$85_es$jscomp$12$$);;){if($G__83048_entry$jscomp$85_es$jscomp$12$$==null)return $G__83047_ret$jscomp$148_this$$jscomp$918$$;var $e$jscomp$411$$=$APP.$cljs$core$first$$($G__83048_entry$jscomp$85_es$jscomp$12$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$411$$))$G__83047_ret$jscomp$148_this$$jscomp$918$$=
$APP.$cljs$core$_assoc$$($G__83047_ret$jscomp$148_this$$jscomp$918$$,$APP.$cljs$core$_nth$$($e$jscomp$411$$,0),$APP.$cljs$core$_nth$$($e$jscomp$411$$,1)),$G__83048_entry$jscomp$85_es$jscomp$12$$=$APP.$cljs$core$next$$($G__83048_entry$jscomp$85_es$jscomp$12$$);else throw Error("conj on a map takes map entries or seqables of map entries");}};$app$common$types$objects_map$ObjectsMap$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/objects-map/v2",$APP.$cljs$cst$1291$class$$,$app$common$types$objects_map$ObjectsMap$$,$APP.$cljs$cst$1314$wfn$$,$app$common$types$objects_map$get_data$$,$APP.$cljs$cst$1315$rfn$$,$app$common$types$objects_map$from_data$$],null)]));var $shadow$js$shim$module$0react_error_boundary$$=shadow$bridge("react-error-boundary");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$53$$,$APP.$cljs$cst$5015$app_DOT_main_DOT_data_DOT_exports_DOT_files_SLASH_export_files$$,$app$main$ui$exports$files$export_dialog$$)});var $app$main$ui$frame_preview$frame_preview$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $iframe_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_data_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$zoom_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$zoom_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(1),$zoom$jscomp$180$$=$APP.$cljs$core$_deref$$($zoom_STAR_$$),$handle_load$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$528$$,
$width$jscomp$257$$,$height$jscomp$223$$){$APP.$cljs$core$reset_BANG_$$($last_data_STAR_$$,$data$jscomp$528$$);var $iframe_dom$$=$APP.$rumext$v2$ref_val$$($iframe_ref$$);return $APP.$cljs$core$truth_$$($iframe_dom$$)?($iframe_dom$$.width=$width$jscomp$257$$+64,$iframe_dom$$.height=$height$jscomp$223$$+64,$iframe_dom$$.contentWindow.document.open(),$iframe_dom$$.contentWindow.document.write($data$jscomp$528$$),$iframe_dom$$.contentWindow.document.close()):null}),$load_ref$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($iframe_dom$jscomp$1$$){$APP.$rumext$v2$set_ref_val_BANG_$$($iframe_ref$$,
$iframe_dom$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($iframe_dom$jscomp$1$$)?$APP.$cljs$core$_deref$$($last_data_STAR_$$):$iframe_dom$jscomp$1$$)?($iframe_dom$jscomp$1$$.contentWindow.document.open(),$iframe_dom$jscomp$1$$.contentWindow.document.write($APP.$cljs$core$_deref$$($last_data_STAR_$$)),$iframe_dom$jscomp$1$$.contentWindow.document.close()):null}),$change_zoom$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($zoom_STAR_$$,
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$rumext$v2$ref_val$$($zoom_ref$jscomp$3$$).value)/100)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){window.load=$handle_load$$;return function(){return delete window.load}});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{display:"flex",width:"100%",height:"100%",flexDirection:"column",overflow:"auto",alignItems:"center"},children:[(0,$APP.$rumext$v2$jsx$$)("input",{id:"zoom-input",ref:$zoom_ref$jscomp$3$$,
type:"range",min:1,max:400,defaultValue:100,onChange:$change_zoom$$,style:{maxWidth:"500px"}}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{width:"100%",height:"100%",overflow:"auto"},children:(0,$APP.$rumext$v2$jsx$$)("iframe",{ref:$load_ref$$,frameBorder:"0",scrolling:"no",style:{transformOrigin:"top left",transform:["scale(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$180$$),")"].join("")}})})]})});var $app$main$ui$notifications$ref_COLON_notification$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2359$notification$$,$APP.$app$main$store$state$$);var $app$main$ui$onboarding$questions$schema_COLON_questions_form_1$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep1"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$6348$expected_use$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"work","education","personal"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2490$role$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"ux","developer","student-teacher","designer","marketing","manager",
"other"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6349$role_other$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,512],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3388$error_SLASH_field$$,$cljs$cst$6349$role_other$$],null),function($p__83192_role$jscomp$18$$){var $map__83193__$1_role_other$$=$APP.$cljs$core$__destructure_map$$($p__83192_role$jscomp$18$$);$p__83192_role$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83193__$1_role_other$$,$APP.$cljs$cst$2490$role$$);$map__83193__$1_role_other$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83193__$1_role_other$$,
$cljs$cst$6349$role_other$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83192_role$jscomp$18$$,"other")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83192_role$jscomp$18$$,"other")&&!$APP.$cuerdas$core$blank_QMARK_$$($map__83193__$1_role_other$$)}],null)],null),$app$main$ui$onboarding$questions$schema_COLON_questions_form_2$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep2"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6350$experience_design_tool$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"figma","sketch","adobe-xd","canva","invision","other"],null)],null),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6351$experience_design_tool_other$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,512],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3388$error_SLASH_field$$,$cljs$cst$6351$experience_design_tool_other$$],null),function($data$jscomp$529_experience_other$$){var $experience$$=$cljs$cst$6350$experience_design_tool$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$529_experience_other$$);$data$jscomp$529_experience_other$$=$cljs$cst$6351$experience_design_tool_other$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$529_experience_other$$);
return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($experience$$,"other")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($experience$$,"other")&&!$APP.$cuerdas$core$blank_QMARK_$$($data$jscomp$529_experience_other$$)}],null)],null),$app$main$ui$onboarding$questions$schema_COLON_questions_form_3$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep3"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6354$team_size$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"1","2-100","101-500","501-1000","1001-5000","5001+"],null)],null)],null)],null),$app$main$ui$onboarding$questions$schema_COLON_questions_form_4$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep4"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6355$start_with$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"ui","wireframing","prototyping","ds","code","other"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6356$start_with_other$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,512],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3388$error_SLASH_field$$,$cljs$cst$6356$start_with_other$$],null),function($p__83197_start_with$$){var $map__83198__$1_start_with_other$$=$APP.$cljs$core$__destructure_map$$($p__83197_start_with$$);$p__83197_start_with$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83198__$1_start_with_other$$,$cljs$cst$6355$start_with$$);$map__83198__$1_start_with_other$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83198__$1_start_with_other$$,$cljs$cst$6356$start_with_other$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83197_start_with$$,"other")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83197_start_with$$,"other")&&!$APP.$cuerdas$core$blank_QMARK_$$($map__83198__$1_start_with_other$$)}],
null)],null);var $app$main$ui$onboarding$team_choice$schema_COLON_team_form$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TeamForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$app$common$types$team$schema_COLON_team_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2490$role$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3290$emails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],
null)],null)],null);var $app$main$ui$releases$common$render_release_notes$$,$method_table__5622__auto__$jscomp$inline_13908$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$inline_13909$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$inline_13910$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$cached_hierarchy__5625__auto__$jscomp$inline_13911$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_13912$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$app$main$ui$releases$common$render_release_notes$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.main.ui.releases.common","render-release-notes"),$APP.$cljs$cst$2289$version$$,$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_13912$$,$method_table__5622__auto__$jscomp$inline_13908$$,$prefer_table__5623__auto__$jscomp$inline_13909$$,$method_cache__5624__auto__$jscomp$inline_13910$$,$cached_hierarchy__5625__auto__$jscomp$inline_13911$$);$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.10",function($klass$jscomp$5_p__83228$$){var $map__83229__$1_version$jscomp$25$$=$APP.$cljs$core$__destructure_map$$($klass$jscomp$5_p__83228$$);$klass$jscomp$5_p__83228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83229__$1_version$jscomp$25$$,$cljs$cst$6361$klass$$);var $finish$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83229__$1_version$jscomp$25$$,$cljs$cst$6362$finish$$);
$map__83229__$1_version$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83229__$1_version$jscomp$25$$,$APP.$cljs$cst$2289$version$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$5_p__83228$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/beta-on.jpg",border:"0",alt:"Penpot is now BETA"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Penpot is now BETA"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83229__$1_version$jscomp$25$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot’s officially beta!"}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We carefully analyzed everything important to us before taking this step. And now we’re ready to move forward onto the beta version.  Have a play around if you haven’t yet."}),(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://penpot.app/why-beta",target:"_blank",children:"Learn why we made this decision."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$$,children:"Explore Penpot Beta 1.10"})})]}),
(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",border:"0"})]})})})});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.11",function($p__83231_slide$jscomp$1$$){var $map__83232__$1_version$jscomp$26$$=$APP.$cljs$core$__destructure_map$$($p__83231_slide$jscomp$1$$);$p__83231_slide$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83232__$1_version$jscomp$26$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83232__$1_version$jscomp$26$$,
$cljs$cst$6361$klass$$),$next$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83232__$1_version$jscomp$26$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83232__$1_version$jscomp$26$$,$cljs$cst$6362$finish$$),$navigate$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83232__$1_version$jscomp$26$$,$APP.$cljs$cst$1941$navigate$$);$map__83232__$1_version$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83232__$1_version$jscomp$26$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83231_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.11"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83232__$1_version$jscomp$26$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.11 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$13$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83231_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.11-animations.gif",
border:"0",alt:"Animations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Prototype animations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Bring your prototypes to life with animations! With animations now you can define the transition between artboards when an interaction is triggered."}),(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Use dissolve, slide and push animations to fade screens and imitate gestures like swipe."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$13$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83231_slide$jscomp$1$$,navigate:$navigate$jscomp$6$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83231_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.11-bg-export.gif",border:"0",alt:"Ignore background on export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Ignore artboard background on export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Sometimes you don’t need the artboards to be part of your designs, but only their support to work on them."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can decide to include their backgrounds on your exports or leave them out."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$13$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83231_slide$jscomp$1$$,navigate:$navigate$jscomp$6$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83231_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.11-zoom-widget.gif",border:"0",alt:"New zoom widget"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"New zoom widget"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve redesigned zooming menus to improve their usability and the consistency between zooming in the design workspace and in the view mode."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve also added two new options to scale your designs at the view mode that might help you to make your presentations look better."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$1$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83231_slide$jscomp$1$$,navigate:$navigate$jscomp$6$$,total:3})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83231_slide$jscomp$1$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.12",function($p__83235_slide$jscomp$2$$){var $map__83237__$1_version$jscomp$27$$=$APP.$cljs$core$__destructure_map$$($p__83235_slide$jscomp$2$$);$p__83235_slide$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83237__$1_version$jscomp$27$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83237__$1_version$jscomp$27$$,
$cljs$cst$6361$klass$$),$next$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83237__$1_version$jscomp$27$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83237__$1_version$jscomp$27$$,$cljs$cst$6362$finish$$),$navigate$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83237__$1_version$jscomp$27$$,$APP.$cljs$cst$1941$navigate$$);$map__83237__$1_version$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83237__$1_version$jscomp$27$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83235_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.12"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83237__$1_version$jscomp$27$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.12 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83235_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-ui.gif",border:"0",
alt:"Adjustable UI"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Adjustable UI"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Adjust the workspace interface to your unique experience. Resize the sidebar, the layers panel  or hide the whole UI to have maximum space."}),(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Along with a better organization of panels (say hello to typography toolbar!) and new shortcuts that will speed your workflow."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83235_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83235_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-guides.gif",border:"0",alt:"Guides"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Guides"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"One of our most requested features! It’s hard to believe how far Penpot has come without guides, but they are here at last."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"And they don’t come alone, but with some nice improvements to the rulers."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83235_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83235_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-scrollbars.gif",border:"0",alt:"Scrollbars"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Scrollbars"})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-content",children:(0,$APP.$rumext$v2$jsx$$)("p",{children:"Scrollbars at the design workspace will make it more obvious how to navigate it and easier for some users, for instance those who love using graphic tablets, from now on, will feel just as comfortable as those who use a mouseAnd they don’t come alone, but with some nice improvements to the rulers."})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83235_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83235_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-nudge.gif",border:"0",alt:"Nudge amount"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Nudge amount"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Set your desired distance to move objects using the keyboard."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is a must if you’re working with grids (if you’re not, you should ;)), being able to adjust the movement to your baseline grid (8px? 5px?) is a huge timesaver that will improve your quality of life while designing."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$2$$,
children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83235_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83235_slide$jscomp$2$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.13",function($p__83234_slide$jscomp$3$$){var $map__83236__$1_version$jscomp$28$$=$APP.$cljs$core$__destructure_map$$($p__83234_slide$jscomp$3$$);$p__83234_slide$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83236__$1_version$jscomp$28$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83236__$1_version$jscomp$28$$,
$cljs$cst$6361$klass$$),$next$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83236__$1_version$jscomp$28$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83236__$1_version$jscomp$28$$,$cljs$cst$6362$finish$$),$navigate$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83236__$1_version$jscomp$28$$,$APP.$cljs$cst$1941$navigate$$);$map__83236__$1_version$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83236__$1_version$jscomp$28$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83234_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.13"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83236__$1_version$jscomp$28$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.13 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83234_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-multi-export.gif",
border:"0",alt:"Multiple exports"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Multiple exports"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Speed up your workflow exporting multiple elements simultaneously."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Use the export window to manage your multiple exports and be informed about the download progress. Big exports will happen in the background so you can keep designing in the meantime ;)"})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83234_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83234_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-multiple-fills.gif",border:"0",alt:"Multiple fills and strokes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",
children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Multiple fills and strokes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can add multiple color fills and strokes to a single element, including shapes and texts."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This opens endless graphic possibilities such as combining gradients and blending modes in the same element to create sophisticated visual effects."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83234_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83234_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-members.gif",border:"0",alt:"Members area redesign"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Members area redesign"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot is meant for teams, that’s why we decided to give some love to the members area."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"A refreshed interface and two new features! The Invitations section allows you to check the status of current team invites plus you now have the ability to invite multiple members at the same time."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83234_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83234_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-focus.gif",border:"0",alt:"Focus mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Focus mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Enjoy a distraction-less design mode by selecting the elements of a page that matter to you and temporarily hiding the rest."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"As a side effect, this can give you a performance boost in massive designs."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$3$$,children:"Start!"}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83234_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83234_slide$jscomp$3$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.14",function($p__83240_slide$jscomp$4$$){var $map__83241__$1_version$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($p__83240_slide$jscomp$4$$);$p__83240_slide$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83241__$1_version$jscomp$29$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83241__$1_version$jscomp$29$$,
$cljs$cst$6361$klass$$),$next$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83241__$1_version$jscomp$29$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83241__$1_version$jscomp$29$$,$cljs$cst$6362$finish$$),$navigate$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83241__$1_version$jscomp$29$$,$APP.$cljs$cst$1941$navigate$$);$map__83241__$1_version$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83241__$1_version$jscomp$29$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83240_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.14"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83241__$1_version$jscomp$29$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.14 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$16$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83240_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-shortcuts.gif",border:"0",
alt:"Shortcuts panel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Shortcuts panel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Shortcuts boost your productivity but are not easy to find and learn. A handy panel at your workspace will help you with that."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Categories and filters will help you to find the shortcut you need. One of the most requested features by the community!"})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$16$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83240_slide$jscomp$4$$,navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83240_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-color-group.gif",border:"0",alt:"Colors selection"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Colors selection"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"All of the colors that are contained within a selection of objects are showcased at the sidebar."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Play with the colors of a group without the hassles of individual selection!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$next$jscomp$16$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83240_slide$jscomp$4$$,navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83240_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-fix-on-scroll.gif",border:"0",alt:"Fix elements at scroll"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Fix elements at scroll"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"A new option that allows you to fix the position of an object when scrolling at the presentation view."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Ideal for prototyping fixed headers, navbars and floating buttons."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$16$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83240_slide$jscomp$4$$,
navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83240_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-group-assets.gif",
border:"0",alt:"Group library assets with drag \x26 drop"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Group library assets with drag \x26 drop"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We have improved the way to manage asset groups at libraries."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Until now you could only do it by renaming the groups, now with drag \x26 drop it is much more user friendly."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$4$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83240_slide$jscomp$4$$,navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83240_slide$jscomp$4$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.15",function($p__83242_slide$jscomp$5$$){var $map__83243__$1_version$jscomp$30$$=$APP.$cljs$core$__destructure_map$$($p__83242_slide$jscomp$5$$);$p__83242_slide$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83243__$1_version$jscomp$30$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83243__$1_version$jscomp$30$$,
$cljs$cst$6361$klass$$),$next$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83243__$1_version$jscomp$30$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83243__$1_version$jscomp$30$$,$cljs$cst$6362$finish$$),$navigate$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83243__$1_version$jscomp$30$$,$APP.$cljs$cst$1941$navigate$$);$map__83243__$1_version$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83243__$1_version$jscomp$30$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83242_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.15"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83243__$1_version$jscomp$30$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.15 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83242_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-nested-boards.gif",
border:"0",alt:"Nested boards"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Nested boards"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Unlike its predecessors (the artboards) boards can contain other boards and offer the options to clip content and show them or not at the View Mode, opening up a ton of possibilities when creating and organizing your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Say goodbye to Artboards and hello to Boards!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83242_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83242_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-share.gif",border:"0",alt:"Share prototype options"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Share prototype options"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Have you ever wanted to share a Penpot file and get feedback from people that are not in your Penpot team?"}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can thanks to new permissions that allow you to decide who can comment and/or inspect the code at a shared prototype link."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83242_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83242_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-comments.gif",border:"0",alt:"Comments positioning"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Comments positioning"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"They live! Now you can move existing comments wherever you want by dragging them."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Also, comments inside boards will be associated with it, so that if you move a board its comments will maintain its place inside it."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83242_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83242_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-view-mode.gif",border:"0",alt:"View Mode improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"View Mode improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"The View Mode, used for presenting designs, is now easier to use thanks to new navigation buttons and microinteractions."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve also made some adjustments to ensure the access to the options from  small screens."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$5$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83242_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83242_slide$jscomp$5$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.16",function($p__83246_slide$jscomp$6$$){var $map__83247__$1_version$jscomp$31$$=$APP.$cljs$core$__destructure_map$$($p__83246_slide$jscomp$6$$);$p__83246_slide$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83247__$1_version$jscomp$31$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83247__$1_version$jscomp$31$$,
$cljs$cst$6361$klass$$),$next$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83247__$1_version$jscomp$31$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83247__$1_version$jscomp$31$$,$cljs$cst$6362$finish$$),$navigate$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83247__$1_version$jscomp$31$$,$APP.$cljs$cst$1941$navigate$$);$map__83247__$1_version$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83247__$1_version$jscomp$31$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83246_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.16"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83247__$1_version$jscomp$31$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.16 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83246_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-dashboard.gif",
border:"0",alt:"Dashboard refreshed look \x26 feel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Dashboard refreshed look \x26 feel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"It’s been some time since we designed the project's dashboard and we felt that we could improve it in terms of accessibility, content hierarchy and aesthetics."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We heard the users before refreshing the interface, simplifying it to give prominence to the content. And yes, now that you ask, the dark theme is coming soon."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83246_slide$jscomp$6$$,
navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83246_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-slider.gif",
border:"0",alt:"Libraries \x26 templates module"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Libraries \x26 templates module"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"This new module will allow you to import a curated selection of the files that are available at the Libraries \x26 Templates page directly from your projects dashboard."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"You no longer need to to download most of them to the computer before importing."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83246_slide$jscomp$6$$,navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$p__83246_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-onboarding.gif",border:"0",alt:"Improved onboarding"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Improved onboarding"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve done a ton of improvements to the onboarding experience."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"More relevant info and better explanations, a refined new team and invitation flow, a beginners tutorial and a walkthrough file that will help newcomers learn how to use and start designing with Penpot faster."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83246_slide$jscomp$6$$,navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83246_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-click-zoom.gif",border:"0",alt:"Zoom to shape with double click"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",
children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Zoom to shape with double click"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"The devil is in the details. At the layers panel, double clicking to the icon of a layer will zoom to it, making the layers navigation and selection easier."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This was a contribution by our community member @andrewzhurov \x3c3"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$6$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83246_slide$jscomp$6$$,navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83246_slide$jscomp$6$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.17",function($p__83248_slide$jscomp$7$$){var $map__83249__$1_version$jscomp$32$$=$APP.$cljs$core$__destructure_map$$($p__83248_slide$jscomp$7$$);$p__83248_slide$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83249__$1_version$jscomp$32$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83249__$1_version$jscomp$32$$,
$cljs$cst$6361$klass$$),$next$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83249__$1_version$jscomp$32$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83249__$1_version$jscomp$32$$,$cljs$cst$6362$finish$$),$navigate$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83249__$1_version$jscomp$32$$,$APP.$cljs$cst$1941$navigate$$);$map__83249__$1_version$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83249__$1_version$jscomp$32$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83248_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/onboarding-version.jpg",
border:"0",alt:"What's new release 1.17"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Version ",$map__83249__$1_version$jscomp$32$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is the first release in which Penpot is no longer Beta (hooray!) and it comes with very special features, starring the long awaited Flex Layout."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"On this 1.17 release, you’ll also be able to inspect the code and properties of your designs right from the workspace and to manage webhooks. We’ve also implemented a lot of accessibility improvements."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",
border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83248_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",
children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.17-flex-layout.gif",border:"0",alt:"Flex-Layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Flex-Layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"The Flex Layout allows you to automatically adapt your designs. Resize, fit, and fill content and containers without the need to do it manually."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot brings a layout system like no other. As described by one of our beta testers: 'I love the fact that Penpot is following the CSS FlexBox, which is making UI Design a step closer to the logic and behavior behind how things will be actually built after design.'"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83248_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83248_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/1.17-inspect.gif",border:"0",alt:"Inspect at the workspace"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Inspect at the workspace"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can inspect designs to get measures, properties and production-ready code right at the workspace, so designers and developers can share the same space while working."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Also, inspect mode provides a safer view-only mode and other improvements."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83248_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$p__83248_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.17-webhook.gif",border:"0",alt:"Webhooks"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Webhooks"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Webhooks allow other websites and apps to be notified when certain events happen at Penpot, ensuring to create integrations with other services."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"While we are still working on a plugin system, this is a great and simple way to create integrations with other services."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83248_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83248_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.17-ally.gif",border:"0",alt:"Accessibility improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Accessibility improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We're working to ensure that people with visual or physical impairments can use Penpot in the same conditions."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This release comes with improvements on color contrasts, alt texts, semantic labels, focusable items and keyboard navigation at login and dashboard, but more will come."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$7$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83248_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83248_slide$jscomp$7$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.18",function($p__83252_slide$jscomp$8$$){var $map__83253__$1_version$jscomp$33$$=$APP.$cljs$core$__destructure_map$$($p__83252_slide$jscomp$8$$);$p__83252_slide$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83253__$1_version$jscomp$33$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83253__$1_version$jscomp$33$$,
$cljs$cst$6361$klass$$),$next$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83253__$1_version$jscomp$33$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83253__$1_version$jscomp$33$$,$cljs$cst$6362$finish$$),$navigate$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83253__$1_version$jscomp$33$$,$APP.$cljs$cst$1941$navigate$$);$map__83253__$1_version$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83253__$1_version$jscomp$33$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83252_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/onboarding-version.jpg",
border:"0",alt:"What's new release 1.18"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Version ",$map__83253__$1_version$jscomp$33$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"On this 1.18 release we make Flex Layout even more powerful with smart spacing, absolute position and z-index management."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We also continued implementing accessibility improvements to make Penpot more inclusive and published stability and performance enhancements."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",
src:"images/deco-right.png",border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83252_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-spacing.gif",
border:"0",alt:"Spacing management"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Spacing management for Flex layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Managing Flex Layout spacing is much more intuitive now. Visualize paddings, margins and gaps and drag to resize them."}),(0,$APP.$rumext$v2$jsx$$)("p",
{children:"And not only that, when creating Flex layouts, the spacing is predicted, helping you to maintain your design composition."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83252_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83252_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-absolute.gif",border:"0",alt:"Position absolute feature"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Absolute position elements in Flex layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Sometimes you need to freely position an element in a specific place regardless of the size of the layout where it belongs."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can exclude elements from the Flex layout flow using absolute position."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83252_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83252_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-z-index.gif",border:"0",alt:"Z-index feature"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"More on Flex layout: z-index"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"With the new z-index option you can decide the order of overlapping elements while maintaining the layers order."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is another capability that brings Penpot Flex layout even closer to the power of CSS standards."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83252_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83252_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-scale.gif",border:"0",alt:"Scale content proportionally"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Scale content proportionally affects strokes, shadows, blurs and corners"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can resize your layers and groups preserving their aspect ratio while scaling their properties proportionally, including strokes, shadows, blurs and corners."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Activate the scale tool by pressing K and scale your elements, maintaining their visual aspect."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$finish$jscomp$8$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83252_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83252_slide$jscomp$8$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.19",function($p__83254_slide$jscomp$9$$){var $map__83255__$1_version$jscomp$34$$=$APP.$cljs$core$__destructure_map$$($p__83254_slide$jscomp$9$$);$p__83254_slide$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83255__$1_version$jscomp$34$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83255__$1_version$jscomp$34$$,
$cljs$cst$6361$klass$$),$next$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83255__$1_version$jscomp$34$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83255__$1_version$jscomp$34$$,$cljs$cst$6362$finish$$),$navigate$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83255__$1_version$jscomp$34$$,$APP.$cljs$cst$1941$navigate$$);$map__83255__$1_version$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83255__$1_version$jscomp$34$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83254_slide$jscomp$9$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$14$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/onboarding-version.jpg",
border:"0",alt:"What's new release 1.19"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Version ",$map__83255__$1_version$jscomp$34$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["On this 1.19 release, we bring Access Tokens, which ",
"will enable Penpot to connect with other services, ","another gateway to community creativity!"]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["We’ve also published performance improvements and tons ","of enhancements, a lot of them from our beloved community ","contributors \x3c3"]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$21$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",
{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83254_slide$jscomp$9$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$14$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.19-contributions.png",border:"0",alt:"Community code contributions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Community code contributions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["By far, this is the Penpot release that has the most ",
"code contributions. We cannot emphasize enough how happy ","we are to see how Penpot is more and more  a product of ","the community."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Let’s give kudos to ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/astudentinearth",target:"_blank",rel:"noopener noreferrer",children:"@astudentinearth"}),", ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/dfelinto",target:"_blank",rel:"noopener noreferrer",children:"@dfelinto"}),", ",(0,$APP.$rumext$v2$jsx$$)("a",
{href:"https://github.com/akshay-gupta7",target:"_blank",rel:"noopener noreferrer",children:"@akshay-gupta7"}),", ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/ondrejkonec",target:"_blank",rel:"noopener noreferrer",children:"@ondrejkonec"})," and ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/ryanbreen",target:"_blank",rel:"noopener noreferrer",children:"@ryanbreen"})," in particular and the Penpot community as a whole!"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$21$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83254_slide$jscomp$9$$,navigate:$navigate$jscomp$14$$,total:2})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83254_slide$jscomp$9$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$14$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.19-tokens.gif",border:"0",alt:"Access Tokens"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Access Tokens"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Personal access tokens function like an alternative to ","our login/password authentication system and can be used ","to allow an application to access the internal Penpot API."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["This opens up a wide range of possibilities in terms of ","integrations and is an important step on the critical path ","to the Penpot’s plugins system."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$9$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83254_slide$jscomp$9$$,navigate:$navigate$jscomp$14$$,total:2})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83254_slide$jscomp$9$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.4",function($p__83258_slide$jscomp$10$$){var $map__83259__$1_version$jscomp$35$$=$APP.$cljs$core$__destructure_map$$($p__83258_slide$jscomp$10$$);$p__83258_slide$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83259__$1_version$jscomp$35$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83259__$1_version$jscomp$35$$,
$cljs$cst$6361$klass$$),$next$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83259__$1_version$jscomp$35$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83259__$1_version$jscomp$35$$,$cljs$cst$6362$finish$$),$navigate$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83259__$1_version$jscomp$35$$,$APP.$cljs$cst$1941$navigate$$);$map__83259__$1_version$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83259__$1_version$jscomp$35$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83258_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.4.0"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83259__$1_version$jscomp$35$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.4.0 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83258_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/select-files.gif",border:"0",
alt:"New file selection"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"New file selection and open files"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can select files with left click and make multi-selections holding down the shift + left click."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"To open a file you just have to double click it. You can also open a file in a new tab with right click."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83258_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83258_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/manage-files.gif",border:"0",alt:"Manage files"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"New files/projects management"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot now allows to duplicate and move files and projects."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Also, now you have an easy way to manage files and projects between teams."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,
children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83258_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83258_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/rtl.gif",border:"0",alt:"RTL support"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"RTL support is now available!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Diversity and inclusion is one major Penpot concern and that's why we love to give support to RTL languages, unlike in most of design tools."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"If you write in arabic, hebrew or other RTL language text direction will be automatically detected in text layers."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83258_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83258_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/blend-modes.gif",border:"0",alt:"Blend modes"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"New layer opacity and blend modes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Combining elements visually is an important part of the design process."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is why the standard blend modes and opacity level are now available for each element."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$10$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83258_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83258_slide$jscomp$10$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.5",function($p__83261_slide$jscomp$11$$){var $map__83262__$1_version$jscomp$36$$=$APP.$cljs$core$__destructure_map$$($p__83261_slide$jscomp$11$$);$p__83261_slide$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83262__$1_version$jscomp$36$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83262__$1_version$jscomp$36$$,
$cljs$cst$6361$klass$$),$next$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83262__$1_version$jscomp$36$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83262__$1_version$jscomp$36$$,$cljs$cst$6362$finish$$),$navigate$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83262__$1_version$jscomp$36$$,$APP.$cljs$cst$1941$navigate$$);$map__83262__$1_version$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83262__$1_version$jscomp$36$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83261_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.5.0"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83262__$1_version$jscomp$36$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.5.0 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$23$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83261_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/path-tool.gif",border:"0",
alt:"New path tool"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"New features for paths"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can select snap points on edition, add/remove nodes, merge/join/split nodes."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"The usability and performance of the paths tool has been improved too."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$23$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83261_slide$jscomp$11$$,navigate:$navigate$jscomp$16$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83261_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/assets-organiz.gif",border:"0",alt:"Manage libraries"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"New libraries organization"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot now allows to group, multiselect and bulk edition of assets (components and graphics)."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"It is time to have all the libraries well organized and work more efficiently."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$next$jscomp$23$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83261_slide$jscomp$11$$,navigate:$navigate$jscomp$16$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83261_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/smart-inputs.gif",border:"0",alt:"Smart inputs"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Smart inputs"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Now you can have more precision in your designs with basic math operations in inputs."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"It's easier to specify by how much you want to change a value and work with measures and distances."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$11$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83261_slide$jscomp$11$$,navigate:$navigate$jscomp$16$$,total:3})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83261_slide$jscomp$11$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.6",function($p__83264_slide$jscomp$12$$){var $map__83265__$1_version$jscomp$37$$=$APP.$cljs$core$__destructure_map$$($p__83264_slide$jscomp$12$$);$p__83264_slide$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83265__$1_version$jscomp$37$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83265__$1_version$jscomp$37$$,
$cljs$cst$6361$klass$$),$next$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83265__$1_version$jscomp$37$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83265__$1_version$jscomp$37$$,$cljs$cst$6362$finish$$),$navigate$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83265__$1_version$jscomp$37$$,$APP.$cljs$cst$1941$navigate$$);$map__83265__$1_version$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83265__$1_version$jscomp$37$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83264_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.6.0"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83265__$1_version$jscomp$37$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.6.0 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$24$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83264_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/custom-fonts.gif",border:"0",
alt:"Upload/use custom fonts"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Upload/use custom fonts"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"From now on you can upload fonts to a Penpot team and use them across its files. This is one of the most requested features since our first release (we listen!)"}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We hope you enjoy having more typography options and our brand new font selector."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$24$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83264_slide$jscomp$12$$,navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83264_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/scale-text.gif",border:"0",alt:"Interactively scale text"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Scale text layers at resizing"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"New main menu option “Scale text (K)” to enable scale text mode."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Disabled by default, this tool is disabled back after being used."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$24$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83264_slide$jscomp$12$$,navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83264_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/performance.gif",border:"0",alt:"Performance improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Performance improvements"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot brings important improvements handling large files. The performance in managing files in the dashboard has also been improved."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You should have the feeling that files and layers show up a bit faster :)"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$next$jscomp$24$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83264_slide$jscomp$12$$,navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83264_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/shapes-to-path.gif",border:"0",alt:"Shapes to path"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Shapes to path"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Now you can edit basic shapes like rectangles, circles and image containers by double clicking."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"An easy way to increase speed by working with vectors!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$12$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83264_slide$jscomp$12$$,
navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83264_slide$jscomp$12$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.7",function($p__83267_slide$jscomp$13$$){var $map__83268__$1_version$jscomp$38$$=$APP.$cljs$core$__destructure_map$$($p__83267_slide$jscomp$13$$);$p__83267_slide$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83268__$1_version$jscomp$38$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83268__$1_version$jscomp$38$$,
$cljs$cst$6361$klass$$),$next$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83268__$1_version$jscomp$38$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83268__$1_version$jscomp$38$$,$cljs$cst$6362$finish$$),$navigate$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83268__$1_version$jscomp$38$$,$APP.$cljs$cst$1941$navigate$$);$map__83268__$1_version$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83268__$1_version$jscomp$38$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83267_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.7"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83268__$1_version$jscomp$38$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.7 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83267_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/export.gif",border:"0",
alt:"Export \x26 Import"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Export and import Penpot files"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:[(0,$APP.$rumext$v2$jsx$$)("strong",{children:"Export files from the dashboard to your computer and import them from your computer to your projects."}),
" This means that Penpot users can freely save and share Penpot files."]}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Exported files linked to shared libraries provide\n          different ways to export their assets. Choose the one that\n          suits you better!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83267_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83267_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/constraints.gif",border:"0",alt:"Resizing constraints"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Resizing constraints"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Constraints allow you to ",(0,$APP.$rumext$v2$jsx$$)("strong",{children:"decide how layers will behave when resizing its container"}),
" being a group or an artboard."]}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You can manually set horizontal and vertical\n          constraints for every layer. This is especially useful to\n          control how your designs look when working with responsive\n          components."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83267_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83267_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/group-components.gif",border:"0",alt:"Library assets management improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Library assets management"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:[(0,$APP.$rumext$v2$jsx$$)("strong",{children:"Collapse/expand groups"})," at any nesting level, so you don’t have to manage their visibility individually."]}),
(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Penpot ",(0,$APP.$rumext$v2$jsx$$)("strong",{children:"remembers the last library state"}),", so you don’t have to collapse a group you want hidden every time."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Easily ",(0,$APP.$rumext$v2$jsx$$)("strong",{children:"rename and ungroup"})," asset groups."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,
children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83267_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83267_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/copy-paste.gif",border:"0",alt:"Paste components from file to file"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Paste components from file to file"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-content",children:(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Do you sometimes copy and paste component copies that belong to a library already shared by the original and destination files? From now on, those component copies are aware of this and will retain their linkage to the library."})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$13$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83267_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83267_slide$jscomp$13$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.8",function($p__83270_slide$jscomp$14$$){var $map__83271__$1_version$jscomp$39$$=$APP.$cljs$core$__destructure_map$$($p__83270_slide$jscomp$14$$);$p__83270_slide$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83271__$1_version$jscomp$39$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83271__$1_version$jscomp$39$$,
$cljs$cst$6361$klass$$),$next$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83271__$1_version$jscomp$39$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83271__$1_version$jscomp$39$$,$cljs$cst$6362$finish$$),$navigate$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83271__$1_version$jscomp$39$$,$APP.$cljs$cst$1941$navigate$$);$map__83271__$1_version$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83271__$1_version$jscomp$39$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83270_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.8"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83271__$1_version$jscomp$39$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.8 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83270_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/share-viewer.gif",border:"0",
alt:"Share options and pages at view mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Share options and pages at view mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can navigate through prototype pages of the same file at the view mode."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You can also create a shareable link deciding which pages will be available for the visitors. Sharing is caring!"})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83270_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83270_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/stroke-caps.gif",border:"0",alt:"Path stroke caps"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Path stroke caps"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Ever needed an arrow to point something? Style the ends of any open paths."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You can select different styles for each end of an open path: arrows, square, circle, diamond or just a round ending are the available options."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83270_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83270_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/navigate-history.gif",border:"0",alt:"Navigable history"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Navigable history"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Click on a change of the history of a file to get the file to this very point without ctrl+z all the way."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Quick and easy :)"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83270_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,
total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83270_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/export-artboards.gif",
border:"0",alt:"Export artboards PDF"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Export artboards PDF"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"If you have a presentation made at Penpot you might want to create a document that can be shared with anyone, regardless of having a Penpot account, or just to be able to use your presentation offline (essential for talks and classes)."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can easily export all the artboards of a page to a single pdf file."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$14$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83270_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,total:4})]})]})]})})});throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83270_slide$jscomp$14$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.9",function($p__83273_slide$jscomp$15$$){var $map__83274__$1_version$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($p__83273_slide$jscomp$15$$);$p__83273_slide$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83274__$1_version$jscomp$40$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83274__$1_version$jscomp$40$$,
$cljs$cst$6361$klass$$),$next$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83274__$1_version$jscomp$40$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83274__$1_version$jscomp$40$$,$cljs$cst$6362$finish$$),$navigate$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83274__$1_version$jscomp$40$$,$APP.$cljs$cst$1941$navigate$$);$map__83274__$1_version$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83274__$1_version$jscomp$40$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83273_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.9"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83274__$1_version$jscomp$40$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.9 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83273_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/advanced-proto.gif",
border:"0",alt:"Advanced interactions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Prototyping triggers and actions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Prototyping options at last! Different triggers (like mouse events or time delays) and actions allow you to add complexity to the interactions of your prototypes."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Create overlays, back buttons or links to URLs to mimic the behavior of the product you’re designing."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83273_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83273_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/flows-proto.gif",border:"0",alt:"Multiple flows"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Multiple flows"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Design projects usually need to define multiple casuistics for different devices and user journeys."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Flows allow you to define multiple starting points within the same page so you can better organize and present your prototypes."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83273_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83273_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/booleans.gif",border:"0",alt:"Boolean shapes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Boolean operations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now in Penpot you can combine shapes in different ways. There are five options: Union, difference, intersection, exclusion and flatten."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Using boolean operations will lead to countless graphic possibilities for your designs."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83273_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83273_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/libraries-feature.gif",border:"0",alt:"Libraries \x26 templates"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Libraries \x26 templates"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve created a new space on Penpot where you can share your libraries and templates and download the ones you like.   Material Design, Cocomaterial or Penpot’s Design System are among them (and a lot more to come!)."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:(0,$APP.$rumext$v2$jsx$$)("a",{alt:"Explore libraries \x26 templates",target:"_blank",href:"https://penpot.app/libraries-templates",children:"Explore libraries \x26 templates"})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$15$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83273_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83273_slide$jscomp$15$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.0",function($p__83276_slide$jscomp$16$$){var $map__83277__$1_version$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($p__83276_slide$jscomp$16$$);$p__83276_slide$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83277__$1_version$jscomp$41$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83277__$1_version$jscomp$41$$,
$cljs$cst$6361$klass$$),$next$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83277__$1_version$jscomp$41$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83277__$1_version$jscomp$41$$,$cljs$cst$6362$finish$$),$navigate$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83277__$1_version$jscomp$41$$,$APP.$cljs$cst$1941$navigate$$);$map__83277__$1_version$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83277__$1_version$jscomp$41$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83276_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-intro-image.png",
border:"0",alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"Welcome to Penpot 2.0! "}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__version-tag",children:"Version "+
($map__83277__$1_version$jscomp$41$$??"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__features-block",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:[(0,$APP.$rumext$v2$jsx$$)("spam",{className:"main_ui_releases_v2_0__feature-title",children:"CSS Grid Layout: "}),"Bring your designs to life, knowing that what you create is what developers code."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",
children:[(0,$APP.$rumext$v2$jsx$$)("spam",{className:"main_ui_releases_v2_0__feature-title",children:"Sleeker UI: "}),"We’ve polished Penpot to make your experience smoother and more enjoyable."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:[(0,$APP.$rumext$v2$jsx$$)("spam",{className:"main_ui_releases_v2_0__feature-title",children:"New Components System: "}),"Managing and using your design components got a whole lot better."]}),(0,$APP.$rumext$v2$jsxs$$)("p",
{className:"main_ui_releases_v2_0__feature-content",children:["And that’s not all - we’ve fined tuned performance and ","accessibility to give you a better and more fluid design experience."]}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:" Ready to dive in? Let 's get started!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",
children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83276_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-css-grid.gif",border:"0",alt:"Penpot's CSS Grid Layout",
className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"CSS Grid Layout - Design Meets Development"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",
children:["The much-awaited Grid Layout introduces 2-dimensional"," layout capabilities to Penpot, allowing for the creation"," of adaptive layouts by leveraging the power of CSS properties."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["It’s a host of new features, including columns and"," rows management, flexible units such as FR (fractions),"," the ability to create and name areas, and tons of new ","and unique possibilities within a design tool."]}),
(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["Designers will learn CSS basics while working, ","and as always with Penpot, developers can pick"," up the design as code to take it from there."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83276_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83276_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.0-new-ui.gif",border:"0",alt:"Penpot's UI Makeover",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"UI Makeover -  Smoother, Sharper, and Simply More Fun"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",
children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["We've completely overhauled Penpot's user interface. ","The improvements in consistency, the introduction of ","new microinteractions, and attention to countless details"," will significantly enhance the productivity and enjoyment of using Penpot."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["Furthermore, we’ve made several accessibility improvements, ",
"with better color contrast, keyboard navigation,"," and adherence to other best practices."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83276_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$p__83276_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-components.gif",border:"0",alt:"Penpot's new components system",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"New Components System"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:"The new Penpot components system improves; control over instances, including their ;inheritances and properties overrides. ;Main components are now accessible as design; elements, allowing a better updating ;workflow through instant changes synchronization.".split(";")}),
(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["And that’s not all, there are new capabilities ","such as component swapping and annotations ","that will help you to better manage your design systems."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83276_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83276_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-html.gif",border:"0",alt:" Penpot's  HTML code generator",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"And much more"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:"In addition to all of this, we’ve included several other requested improvements:"}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_releases_v2_0__feature-list",children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:"Access HTML markup code directly in inspect mode"}),(0,$APP.$rumext$v2$jsx$$)("li",{children:"Images are now treated as element fills, maintaining their aspect ratio on resize, ideal for flexible designs"}),
(0,$APP.$rumext$v2$jsx$$)("li",{children:"Enjoy new color themes with options for both dark and light modes"}),(0,$APP.$rumext$v2$jsx$$)("li",{children:"Feel the speed boost! Enjoy a smoother experience with a bunch of performance improvements"})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83276_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$16$$,className:"main_ui_releases_v2_0__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83276_slide$jscomp$16$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.1",function($klass$jscomp$22_p__83278$$){var $map__83279__$1_version$jscomp$42$$=$APP.$cljs$core$__destructure_map$$($klass$jscomp$22_p__83278$$),$G__83280__$1_slide$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83279__$1_version$jscomp$42$$,$APP.$cljs$cst$1958$slide$$);$klass$jscomp$22_p__83278$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83279__$1_version$jscomp$42$$,
$cljs$cst$6361$klass$$);var $finish$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83279__$1_version$jscomp$42$$,$cljs$cst$6362$finish$$);$map__83279__$1_version$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83279__$1_version$jscomp$42$$,$APP.$cljs$cst$2289$version$$);$G__83280__$1_slide$jscomp$17$$=$G__83280__$1_slide$jscomp$17$$ instanceof $APP.$cljs$core$Keyword$$?$G__83280__$1_slide$jscomp$17$$.$fqn$:null;switch($G__83280__$1_slide$jscomp$17$$){case "start":return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_1__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$22_p__83278$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-intro-image.png",border:"0",alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_1__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_1__modal-title",children:"What's new in Penpot? "}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_1__version-tag",children:"Version "+($map__83279__$1_version$jscomp$42$$??"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_1__feature-content",
children:"Penpot 2.1 brings improvements to the authentication system, path editing, real-time persistence, and comments system among other enhancements. We’ve improved the stability of the platform by fixing a bunch of bugs, a lot of them raised by our amazing community \x3c3."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_1__feature-content",children:"This minor release comes shortly after our amazing Penpot 2.0 and it shows the way to long-expected capabilities like the incoming new plugin system!"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_1__feature-content",children:" Ready to dive in? Let 's get started!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_1__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$17$$,className:"main_ui_releases_v2_1__next-btn",children:"Let's go"})})]})]})})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83280__$1_slide$jscomp$17$$)].join(""));
}});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.10",function($p__83282_slide$jscomp$18$$){var $map__83283__$1_version$jscomp$43$$=$APP.$cljs$core$__destructure_map$$($p__83282_slide$jscomp$18$$);$p__83282_slide$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83283__$1_version$jscomp$43$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83283__$1_version$jscomp$43$$,
$cljs$cst$6361$klass$$),$next$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83283__$1_version$jscomp$43$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83283__$1_version$jscomp$43$$,$cljs$cst$6362$finish$$),$navigate$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83283__$1_version$jscomp$43$$,$APP.$cljs$cst$1941$navigate$$);$map__83283__$1_version$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83283__$1_version$jscomp$43$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83282_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-slide-0.jpg",
border:"0",alt:"Penpot 2.10 is here!",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__version-tag",children:"Version "+($map__83283__$1_version$jscomp$43$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_10__feature-title",children:"Variants have arrived in Penpot!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"We’re excited to introduce what’s (probably) the top community request. Variants are a powerful way to bring order and flexibility to your design system in Penpot."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_10__feature-content",children:"This release also brings major progress on design tokens—including several new token types to help you manage typography at an entirely new level—plus a bunch of quality-of-life improvements that make the Penpot experience even more enjoyable."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__navigation",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83282_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-variants.gif",border:"0",alt:"Variants have arrived in Penpot!",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"Variants have arrived in Penpot!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"With Variants, you can group similar components—like buttons, icons, or toggles—into a single, customizable component. Instead of juggling multiple versions for every state, size, or style, you’ll manage them all in one unified place with clear, intuitive properties."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",
children:"Imagine a single button component that seamlessly switches between primary and secondary styles, active and disabled states, and small to large sizes—all without leaving your flow. That’s the power of Variants."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This release has been shaped by our amazing community. A huge thank-you to everyone who shared ideas, feedback, and insights to make Penpot Variants possible \x3c3"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83282_slide$jscomp$18$$,navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83282_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-penpotfest.jpg",border:"0",alt:"Road to Penpot 3.0… Join us at Penpot Fest next month!",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"Road to Penpot 3.0… Join us at Penpot Fest next month!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This year’s Penpot Fest theme is: Better, together: Refining the designer-developer workflow."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_10__feature-content",children:"Catch industry experts from GitHub, Blender, Wikimedia Foundation and more. Join workshops and our panel discussion for practical and visionary thoughts."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"And one more thing…Tune into our product showcase to see future plans and help us shape Penpot. Come for the insights, stay for the community…"}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_10__feature-content",
children:[(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://penpot.app/penpotfest",target:"_blank",children:"Get your tickets"})," now to join us 8-10 October, in Madrid!"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83282_slide$jscomp$18$$,navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",
children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83282_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-font-tokens.gif",border:"0",alt:"New typography token types",
className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"New typography token types"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",
children:"We're continually building on Penpot's native Design Tokens support, and this time, we introduce an expanded range of token types, giving you greater options for your design systems."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This latest update brings—no more no less than—six new token types, significantly boosting your ability to manage design decisions, particularly in typography: Font Family, Font Weight, Text Case, Text Decoration, Letter Spacing token, and Number token (for unitless values)."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83282_slide$jscomp$18$$,navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83282_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-preset.gif",border:"0",alt:"Select artboard defaults before their creation",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"Select artboard defaults before their creation"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"Starting a new design in Penpot just got easier. You can now choose from preset artboard sizes before creating an artboard. This will help you begin your designs with the right dimensions from the very first click."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This feature was born from community proposals. Several Penpot users helped us understand the different workflows around creating artboards, and their feedback shaped the simple, effective solution we’re announcing today."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83282_slide$jscomp$18$$,
navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$18$$,className:"main_ui_releases_v2_10__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83282_slide$jscomp$18$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.11",function($p__83285_slide$jscomp$19$$){var $map__83286__$1_version$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($p__83285_slide$jscomp$19$$);$p__83285_slide$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83286__$1_version$jscomp$44$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83286__$1_version$jscomp$44$$,
$cljs$cst$6361$klass$$),$next$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83286__$1_version$jscomp$44$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83286__$1_version$jscomp$44$$,$cljs$cst$6362$finish$$),$navigate$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83286__$1_version$jscomp$44$$,$APP.$cljs$cst$1941$navigate$$);$map__83286__$1_version$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83286__$1_version$jscomp$44$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83285_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-slide-0.jpg",
border:"0",alt:"Penpot 2.11 is here!",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__version-tag",children:"Version "+($map__83286__$1_version$jscomp$44$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_11__feature-title",children:"Typography tokens take the stage!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"This release brings one of our most anticipated design system upgrades yet: Typography tokens."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",
children:"But that’s not all. Variants get a nice boost with multi-switching, new creation shortcuts, and draggable property reordering. Invitations are now easier to manage and the user menu has been reorganized. Now showing your current Penpot version and direct access to release info."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"And as always, you’ll notice performance improvements throughout. Faster, smoother, and just a bit more magical every time."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83285_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-typography-token.gif",border:"0",alt:"Typography token: one token to rule your text",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"Typography token: one token to rule your text"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Imagine having just one token to manage all your typography. With the new Typography token, you can create presets that bundle all your text styles (font, weight, size, line height, spacing, and more) into a single reusable definition. Just one clean, flexible token to keep your type consistent across your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"The Typography token also marks a big step forward for Penpot: it’s our first composite token! Composite tokens are special because they can hold multiple properties within one token. Shadow token will be the next composite token coming your way."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83285_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83285_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-variants.gif",border:"0",alt:"Variants get a power-up",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"Variants get a power-up"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Variants just got published and they already got a serious quality-of-life boost!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"- Switch several variant copies at once: No more clicking through each one individually when you want to update a property. Just select multiple copies and change their values in one go — fast, smooth, and efficient."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"- New ways to create variants, right from the design viewport: No need to dig through menus. The new buttons make it super quick to spin up variant sets directly where you’re working."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"- Reorder your component properties by drag \x26 drop: Because organization matters, now you can arrange your properties however makes the most sense to you, so you can keep the ones you use most often right where you want them."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83285_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83285_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-invitations.gif",border:"0",alt:"A smoother way to manage invitations",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"A smoother way to manage invitations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"The Invitations section just got a big usability upgrade for admins. Here’s what’s new:"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Sorting - Organize invitations by role type or status to keep track of who’s in and who’s pending."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Quicker actions - Main actions (resend and delete) are now visible upfront for quicker access."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Bulk management - Select multiple invitations to resend or delete them all at once."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Invited users will also get clearer emails, including a reminder sent one day before the invite expires (after seven days). Simple, clean, and much more efficient."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83285_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,
total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83285_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-menu.gif",border:"0",alt:"User menu makeover",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"User menu makeover"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"The user menu got a well-deserved cleanup. Options are now grouped into clear sections like Help \x26 Learning and Community \x26 Contributions, making navigation faster and easier."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"You’ll also notice a handy new detail: the menu now shows your current Penpot version and gives you quick access to changelog information. This is especially useful for self-hosted setups that want to stay in sync with the latest updates. Simple, organized, and more informative."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83285_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$19$$,className:"main_ui_releases_v2_11__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83285_slide$jscomp$19$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.12",function($p__83289_slide$jscomp$20$$){var $map__83290__$1_version$jscomp$45$$=$APP.$cljs$core$__destructure_map$$($p__83289_slide$jscomp$20$$);$p__83289_slide$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83290__$1_version$jscomp$45$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83290__$1_version$jscomp$45$$,
$cljs$cst$6361$klass$$),$next$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83290__$1_version$jscomp$45$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83290__$1_version$jscomp$45$$,$cljs$cst$6362$finish$$),$navigate$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83290__$1_version$jscomp$45$$,$APP.$cljs$cst$1941$navigate$$);$map__83290__$1_version$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83290__$1_version$jscomp$45$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83289_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-slide-0.jpg",
border:"0",alt:"Penpot 2.12 is here!",className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__version-tag",children:"Version "+($map__83290__$1_version$jscomp$45$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"Better tokens visibility and more!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"This release focuses on making your everyday workflow feel clearer, faster and more intuitive. Tokens are now easier to see and apply, appearing directly where you work and giving the designs better context during code inspection. Variants gain a more natural flow thanks to simple boolean toggles that remove friction when switching states. And PDF export becomes more flexible, letting you choose exactly which boards to share so your files match the story you want to tell."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Together, these enhancements bring greater control and fluidity to your entire design process."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$31$$,className:"main_ui_releases_v2_12__next-btn",
children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83289_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-tokens-sidebar.gif",border:"0",alt:"Better tokens visibility",
className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"Better tokens visibility"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",
children:"Design systems should be both powerful and effortless to use. This release brings tokens closer to where you work, making them easier to apply and easier to understand."}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"Apply color tokens right from the sidebar"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Your color tokens now appear directly in the properties sidebar, making it faster to apply or unapply tokens from the design tab. No more digging: now you can use tokens within your design flow."}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"See token names in the Inspect panel"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Developers now get a clearer context during handoff. The Inspect panel shows the actual token used in your design, in a similar way to how styles are displayed. This small detail reduces ambiguity, aligns everyone on the same language, and strengthens collaboration across the team."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83289_slide$jscomp$20$$,navigate:$navigate$jscomp$24$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$31$$,className:"main_ui_releases_v2_12__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83289_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-variants.gif",border:"0",alt:"Simpler boolean variants",className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"Simpler boolean variants"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Variants are central to building flexible, scalable components. With this release, boolean properties become far easier to work with."}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_releases_v2_12__feature-title",children:"A simple toggle for boolean values"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Binary states now use a clean toggle, to be able to switch visually,  instead of a dropdown. This makes adjusting component states more intuitive and speeds up working with multiple instances."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"It’s a subtle improvement, but it removes friction you feel hundreds of times a week, and makes component work flow more naturally."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83289_slide$jscomp$20$$,navigate:$navigate$jscomp$24$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$31$$,className:"main_ui_releases_v2_12__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83289_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-export-pdf.gif",border:"0",alt:"Smarter PDF export",className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"Smarter PDF export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Exporting your work is now more precise and flexible."}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"Select specific boards when exporting"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"You’re now in control of which boards make it into your PDF. Share just the final screens, just a flow, just the workshop materials. This streamlined export flow adapts to the way real teams work: share the story you want to tell, with exactly the boards you need."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83289_slide$jscomp$20$$,navigate:$navigate$jscomp$24$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$20$$,className:"main_ui_releases_v2_12__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83289_slide$jscomp$20$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.13",function($p__83292_slide$jscomp$21$$){var $map__83293__$1_version$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($p__83292_slide$jscomp$21$$);$p__83292_slide$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83293__$1_version$jscomp$46$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83293__$1_version$jscomp$46$$,
$cljs$cst$6361$klass$$),$next$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83293__$1_version$jscomp$46$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83293__$1_version$jscomp$46$$,$cljs$cst$6362$finish$$),$navigate$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83293__$1_version$jscomp$46$$,$APP.$cljs$cst$1941$navigate$$);$map__83293__$1_version$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83293__$1_version$jscomp$46$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83292_slide$jscomp$21$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$26$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.13-slide-0.jpg",
border:"0",alt:"Penpot 2.13 is here!",className:"main_ui_releases_v2_13__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_13__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__version-tag",children:"Version "+($map__83293__$1_version$jscomp$46$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_13__feature-title",children:"The first release of the year, and we’re just getting started \ud83d\ude80"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"This is our first release of the year, and it sets the tone for what’s coming next. We’re kicking off an exciting year where we’ll take Penpot to a whole new level, with improved performance, stronger design system foundations, long-requested features, and new capabilities that unlock better workflows for teams."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"This release brings two highlights the community has been asking for, along with solid improvements under the hood to keep everything fast and smooth."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$32$$,
className:"main_ui_releases_v2_13__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83292_slide$jscomp$21$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$26$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.13-trash.gif",
border:"0",alt:"The Trash",className:"main_ui_releases_v2_13__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_13__modal-title",children:"The Trash"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",
children:"Deleting a file no longer means it’s gone forever. Introducing The Trash, a dedicated space in the dashboard where deleted files and projects live before being permanently removed."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"From here, you can recover content deleted by mistake or clean things up for good when you’re sure you don’t need them anymore. The Trash works for both files and projects, and items are automatically removed after a period of time depending on your Penpot plan."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Highly requested, long overdue, and now officially here."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83292_slide$jscomp$21$$,navigate:$navigate$jscomp$25$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$32$$,className:"main_ui_releases_v2_13__next-btn",
children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83292_slide$jscomp$21$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$26$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.13-shadow-tokens.gif",border:"0",alt:"Shadow tokens: Reusable shadows, at last!",
className:"main_ui_releases_v2_13__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_13__modal-title",children:"Shadow tokens: Reusable shadows, at last!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",
children:"With Shadow tokens, we’re introducing our second composite token, right after Typography tokens. This is a big step forward for design systems in Penpot."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Until now, shadows couldn’t be defined as reusable styles the way colors could before color tokens existed. Shadow tokens change that. You can now create reusable, consistent shadows, made of one or multiple layers, fully tokenized and ready to scale across your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Each shadow can reference existing tokens or use custom values, supports both Drop Shadow and Inner Shadow, and even allows shadow tokens to reference other shadow tokens. A brand-new capability, unlocked."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83292_slide$jscomp$21$$,
navigate:$navigate$jscomp$25$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$21$$,className:"main_ui_releases_v2_13__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83292_slide$jscomp$21$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.14",function($p__83295_slide$jscomp$22$$){var $map__83296__$1_version$jscomp$47$$=$APP.$cljs$core$__destructure_map$$($p__83295_slide$jscomp$22$$);$p__83295_slide$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83296__$1_version$jscomp$47$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83296__$1_version$jscomp$47$$,
$cljs$cst$6361$klass$$),$next$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83296__$1_version$jscomp$47$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83296__$1_version$jscomp$47$$,$cljs$cst$6362$finish$$),$navigate$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83296__$1_version$jscomp$47$$,$APP.$cljs$cst$1941$navigate$$);$map__83296__$1_version$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83296__$1_version$jscomp$47$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83295_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-slide-0.jpg",
border:"0",alt:"Penpot 2.14 is here!",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__version-tag",children:"Version "+($map__83296__$1_version$jscomp$47$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_14__feature-title",children:"Design tokens, but friendlier (and a bit faster, too)"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"This release keeps pushing Penpot’s design system foundations forward, with a big focus on design tokens. We’re making long token names easier to navigate, opening up tokens in the plugins API, and tackling one of the trickiest moments in token workflows: renaming (without breaking everything)."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"On top of that, you’ll find a handful of quality-of-life improvements and some performance work in the sidebar to keep things feeling smooth as your files grow. Let’s dive in."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$33$$,className:"main_ui_releases_v2_14__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83295_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.14-tokens-fold.gif",border:"0",alt:"Token groups: Navigating long names, finally",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Token groups: Navigating long names, finally"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_14__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Token names are rarely short and sweet. Most of the time they carry a lot of meaning (type, state, property, variant… and more), which is great for consistency, but not so great for browsing. In 2.14 we’re introducing token groups, a new way to navigate dotted token paths as nested, collapsible sections."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",
children:"Token segments before the final name are displayed as groups, and only the last segment stays as a pill (so you keep the familiar token “chip” where it matters). If you unfold a path, it stays open while you move around the app (it resets only when the page reloads). And when you create a new token, Penpot automatically unfolds the path needed to reveal it (even if it overrides a previously opened one)."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",
children:"One extra detail: if you edit the path and change group segments, the token is moved to its new group (creating it if needed), and empty groups are automatically cleaned up."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83295_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$33$$,
className:"main_ui_releases_v2_14__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83295_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-api.gif",
border:"0",alt:"Design tokens in the plugins API: Automation unlocked",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Design tokens in the plugins API: Automation unlocked"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Design tokens are now available in the Penpot plugins API. That means plugins (and external tools built around Penpot, like AI clients or Penpot MCP) can finally work with tokens programmatically and automate token workflows that used to be purely manual."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"If you’ve been waiting to generate tokens, sync them, or manipulate them from your own tools, this is the missing piece. And yes, this one has been requested a lot."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83295_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$33$$,className:"main_ui_releases_v2_14__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83295_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-remap.jpg",border:"0",alt:"Rename tokens without breaking everything",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Rename tokens without breaking everything"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Renaming tokens sounds simple until you remember the references. One change can ripple through aliases, applied tokens, tooltips, math operations… and suddenly you’re left with a broken chain. In 2.14, renaming a token can optionally remap its references, keeping connections intact and updating the design with the new token name."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Remapping is always optional, because sometimes you don’t want to keep the current connections. When enabled, it affects all tokens in the file and also takes libraries into account, so main components can propagate changes to child components, and applied tokens update on the elements using them."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83295_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$33$$,className:"main_ui_releases_v2_14__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83295_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-icons.gif",border:"0",alt:"Quality-of-life improvements",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Quality-of-life improvements"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Lock and hide controls in the layer panel are getting a usability boost. The lock and visibility icons stay fixed in a right-aligned column regardless of indentation, and scrolling won’t make them awkward to click (even in deeply nested files)."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",
children:"We’re also improving sidebar performance, with a focus on keeping interactions fluent. The goal is to lazy-load the shape list on-demand and avoid UI stalls when clicking or hovering around the sidebar."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"And one more: you can now use Shift/Alt arrow key stepping in color picker inputs (a community contribution by @eureka928. ❤️)"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83295_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$22$$,className:"main_ui_releases_v2_14__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83295_slide$jscomp$22$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.15",function($p__83298_slide$jscomp$23$$){var $map__83299__$1_version$jscomp$48$$=$APP.$cljs$core$__destructure_map$$($p__83298_slide$jscomp$23$$);$p__83298_slide$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83299__$1_version$jscomp$48$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83299__$1_version$jscomp$48$$,
$cljs$cst$6361$klass$$),$next$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83299__$1_version$jscomp$48$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83299__$1_version$jscomp$48$$,$cljs$cst$6362$finish$$),$navigate$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83299__$1_version$jscomp$48$$,$APP.$cljs$cst$1941$navigate$$);$map__83299__$1_version$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83299__$1_version$jscomp$48$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83298_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.15-slide-0.jpg",
border:"0",alt:"Penpot 2.15 is here!",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__version-tag",children:"Version "+($map__83299__$1_version$jscomp$48$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_15__feature-title",children:"One major feature: the Penpot MCP Server, with infinite workflow possibilities"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"This release marks a major MCP milestone: Penpot MCP moves from an early technical setup to an accessible in-app experience via hosted remote setup. Whether you already know MCP or are new to it, it's now zero-friction to connect your AI client and turn prompts into real actions on real design data."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"With 2.15, we are opening the door to truly multi-directional workflows between design and code, while staying faithful to Penpot values: openness, freedom of choice, and respect for your data."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$34$$,className:"main_ui_releases_v2_15__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83298_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.15-mcp-01.gif",border:"0",alt:"Penpot MCP Server: AI connected to real design context",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"Penpot MCP Server: AI connected to real design context"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_15__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"Penpot MCP Server is the bridge between your AI client and your Penpot file. You describe what you need in natural language, your agent picks the right operation, and MCP translates that into real actions through Penpot APIs."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"This is not a generic 'describe and generate' flow. It is context-aware work with components, tokens, pages, layers, and structure. In short: design expressed as code, now usable through your preferred AI assistant."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"You can run MCP in two ways. Remote MCP is hosted and simpler to set up. Local MCP runs on your machine and gives advanced teams extra control. Same vision, different operating model."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83298_slide$jscomp$23$$,navigate:$navigate$jscomp$27$$,
total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$34$$,className:"main_ui_releases_v2_15__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83298_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.15-mcp-02.gif",border:"0",alt:"Multi-directional workflows, from design to code and back",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"Multi-directional workflows, from design to code and back"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"The biggest unlock in 2.15 is multi-directionality. You can move from design to code, and from code back to design, without losing intent or structure in the process."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Generate semantic HTML/CSS from real layouts."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_15__feature-content",children:"• Translate tokens and styles into code variables."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Export only assets in use."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Validate design-code consistency."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Reorganize layers, apply naming rules, and automate repetitive design system maintenance."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"This is where MCP becomes workflow infrastructure. Less manual glue work, fewer handoff gaps, and faster iterations between designers and developers."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83298_slide$jscomp$23$$,navigate:$navigate$jscomp$27$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$34$$,className:"main_ui_releases_v2_15__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83298_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.15-mcp-03.gif",border:"0",alt:"Your stack, your model, your control",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"Your stack, your model, your control"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"With MCP, you connect Penpot to the AI client and model you already trust. Cursor, Claude, VS Code, Codex, or another MCP-compatible setup: the workflow adapts to your stack, not the other way around."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"You can run it hosted for a faster setup, or locally when you need tighter infrastructure control. The same applies to data boundaries: Penpot provides the bridge to your design context, while your team decides how and where AI runs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"In practice, this means teams can automate design and code workflows without giving up tool freedom, deployment control, or ownership of their process.\n"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83298_slide$jscomp$23$$,navigate:$navigate$jscomp$27$$,total:3}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$23$$,className:"main_ui_releases_v2_15__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83298_slide$jscomp$23$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.16",function($p__83304_slide$jscomp$24$$){var $map__83305__$1_version$jscomp$49$$=$APP.$cljs$core$__destructure_map$$($p__83304_slide$jscomp$24$$);$p__83304_slide$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83305__$1_version$jscomp$49$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83305__$1_version$jscomp$49$$,
$cljs$cst$6361$klass$$),$next$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83305__$1_version$jscomp$49$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83305__$1_version$jscomp$49$$,$cljs$cst$6362$finish$$),$navigate$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83305__$1_version$jscomp$49$$,$APP.$cljs$cst$1941$navigate$$);$map__83305__$1_version$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83305__$1_version$jscomp$49$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83304_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-slide-0.jpg",
border:"0",alt:"Penpot 2.16 is here!",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__version-tag",children:"Version "+($map__83305__$1_version$jscomp$49$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"2.16 brings design tokens into the Design sidebar next to the numbers you already tune for layout, so choosing and checking tokens stays in the same flow. It also introduces an optional WebGL path (beta) for a faster canvas when files grow heavy, plus a wide layer of fixes and polish so the app simply feels more dependable from session to session."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"This cycle ships on the order of fifty enhancements and sixty bug fixes, so the day-to-day gain is less about one headline and more about many small wins adding up. A large share of that work came from community contributors; we highlight a few names on a later slide, and we are grateful to everyone who helped move Penpot forward."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",
children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83304_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-tokens.gif",border:"0",alt:"Design tokens: visible and actionable from the Design tab",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",children:"Design tokens: visible and actionable from the Design tab"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"You can treat tokens as part of the Design sidebar: see what is bound, pick a token, or type a value with less jumping back to the tokens panel. The payoff is calmer work—fewer context switches when you are sizing, spacing, or tuning type and effects—and more confidence that what you see in the inspector matches what your system actually uses."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"This closes a long standing gap in the tokens roadmap: token picking and visibility belong in the Design panel itself. Token choices stay visible next to the controls you touch all day, so applying and checking design language feels like one continuous step instead of a detour."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83304_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83304_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-render.jpg",border:"0",alt:"WebGL rendering (beta): a faster canvas you can try now",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",
children:"WebGL rendering (beta): a faster canvas you can try now"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"WebGL is a genuine upgrade to how the canvas moves. On busy boards and heavy files, pan and zoom should feel quicker and more immediate—less friction between what you want to see and what appears on screen—so your attention stays on the design instead of on the viewport catching up."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"We are still hardening it with real work in the wild, so it ships as beta and stays off until you enable it in user settings. Turn it on for your toughest file, ride the speedup, and send feedback from the product if anything misbehaves so we can keep improving it together."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83304_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83304_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-find-replace.gif",border:"0",alt:"Community contributions: volume up, quality even higher",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",
children:"Community contributions: volume up, quality even higher"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"This release carried an unusually broad set of improvements with a community byline—not one or two patches at the edge, but a visible wave of quality-of-life work from people shipping Penpot alongside their own projects."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_16__feature-content",children:"That mix keeps the product grounded in how files actually behave in the wild, and we are glad to share the credit. In the long run, this is about ideas in motion: fresh workflows, clever affordances, and “why has nobody fixed this yet?” moments that expand what Penpot is."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83304_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83304_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-inputs-drag.gif",border:"0",alt:"Community contributions: volume up, quality even higher",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",
children:"Community contributions: volume up, quality even higher"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"A few highlights:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Drag to change on numeric inputs in the workspace sidebar — @RenzoMXD"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",
children:"• Loader feedback while importing and exporting files — @moorsecopers99"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Import tokens from a linked library — @dfelinto"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Find and replace for text content and layer names — @statxc"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Clickable links in comments — @eureka0928"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Read-only preview for saved versions — @wdeveloper16 "}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:" ... and many, many more."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83304_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,
total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(4,$p__83304_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-fixes.gif",border:"0",alt:"Stability, performance, and “everything else” (there is a lot)",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",children:"Stability, performance, and “everything else” (there is a lot)"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"Alongside the visible features, 2.16 clears a lot of rough edges: regressions, corner cases, and small frictions that only register once they stop getting in your way."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"On the enhancement side, think on the order of ~50 quality of life improvements. Together with the fixes, you’re looking at more than a hundred tracked improvements in this cycle, which is why the release feels “radical” in day to day feel even when no single line item explains it."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83304_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$24$$,className:"main_ui_releases_v2_16__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83304_slide$jscomp$24$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.2",function($klass$jscomp$30_p__83301$$){var $map__83302__$1_version$jscomp$50$$=$APP.$cljs$core$__destructure_map$$($klass$jscomp$30_p__83301$$),$G__83303__$1_slide$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83302__$1_version$jscomp$50$$,$APP.$cljs$cst$1958$slide$$);$klass$jscomp$30_p__83301$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83302__$1_version$jscomp$50$$,
$cljs$cst$6361$klass$$);var $finish$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83302__$1_version$jscomp$50$$,$cljs$cst$6362$finish$$);$map__83302__$1_version$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83302__$1_version$jscomp$50$$,$APP.$cljs$cst$2289$version$$);$G__83303__$1_slide$jscomp$25$$=$G__83303__$1_slide$jscomp$25$$ instanceof $APP.$cljs$core$Keyword$$?$G__83303__$1_slide$jscomp$25$$.$fqn$:null;switch($G__83303__$1_slide$jscomp$25$$){case "start":return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_2__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$30_p__83301$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-intro-image.png",border:"0",alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_2__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_2__modal-title",children:"What's new in Penpot? "}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_2__version-tag",children:"Version "+($map__83302__$1_version$jscomp$50$$??"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",
children:"This Penpot 2.2 release focuses on internal changes that are laying out the ground for the upcoming plugin system and substantial performance improvements."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",children:"This version also adds full JSON API interoperability and the brand-new Penpot’s Storybook!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",children:"Self-hosted Penpot installations will benefit from better file data storage and Penpot admins can now use the improved automatic snapshotting process when recovering old files."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",children:"Thanks again to our awesome community for their amazing contributions to this release!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_2__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$25$$,className:"main_ui_releases_v2_2__next-btn",children:"Let's go"})})]})]})})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83303__$1_slide$jscomp$25$$)].join(""));
}});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.3",function($p__83308_slide$jscomp$26$$){var $map__83309__$1_version$jscomp$51$$=$APP.$cljs$core$__destructure_map$$($p__83308_slide$jscomp$26$$);$p__83308_slide$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83309__$1_version$jscomp$51$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83309__$1_version$jscomp$51$$,
$cljs$cst$6361$klass$$),$next$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83309__$1_version$jscomp$51$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83309__$1_version$jscomp$51$$,$cljs$cst$6362$finish$$),$navigate$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83309__$1_version$jscomp$51$$,$APP.$cljs$cst$1941$navigate$$);$map__83309__$1_version$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83309__$1_version$jscomp$51$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83308_slide$jscomp$26$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$31$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.3-slide-0.png",border:"0",
alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_3__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_3__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__version-tag",children:"Version "+($map__83309__$1_version$jscomp$51$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_3__feature-title",children:"Penpot can now be extended by using Plugins!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"The introduction of our brand new Plugin system allows you to access even richer ecosystem of capabilities."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",
children:"We are beyond excited about how this will further involve the Penpot community in building the best design and prototyping platform."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$36$$,className:"main_ui_releases_v2_3__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$p__83308_slide$jscomp$26$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$31$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.3-img-slide-1.gif",border:"0",alt:"Build Plugins to enhance your workflow",className:"main_ui_releases_v2_3__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_3__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_3__modal-title",children:"Build Plugins and enhance your workflow"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Penpot Plugins encourage developers to easily customize and expand the platform using standard web technologies like JavaScript, CSS, and HTML."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Find everything you need in our full comprehensive documentation to start building your plugins now!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83308_slide$jscomp$26$$,navigate:$navigate$jscomp$29$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$36$$,
className:"main_ui_releases_v2_3__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83308_slide$jscomp$26$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$31$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.3-img-slide-2.gif",
border:"0",alt:"Plugins are safe and extremely easy to use",className:"main_ui_releases_v2_3__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_3__modal-title",children:"Plugins are safe and extremely easy to use"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Penpot plugins are quite easy to install."}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:["Be sure to keep an eye on our evolving ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://penpot.app/penpothub",target:"_blank",children:"Penpot Hub"})," to pick the ones that are best suited to enhance your workflow."]}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",
children:"This is just the beginning of a myriad of possibilities. Let’s build this community together ❤️."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83308_slide$jscomp$26$$,navigate:$navigate$jscomp$29$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$26$$,className:"main_ui_releases_v2_3__next-btn",children:"Let's go"})]})]})]})})});
throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83308_slide$jscomp$26$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.4",function($p__83311_slide$jscomp$27$$){var $map__83312__$1_version$jscomp$52$$=$APP.$cljs$core$__destructure_map$$($p__83311_slide$jscomp$27$$);$p__83311_slide$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83312__$1_version$jscomp$52$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83312__$1_version$jscomp$52$$,
$cljs$cst$6361$klass$$),$next$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83312__$1_version$jscomp$52$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83312__$1_version$jscomp$52$$,$cljs$cst$6362$finish$$),$navigate$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83312__$1_version$jscomp$52$$,$APP.$cljs$cst$1941$navigate$$);$map__83312__$1_version$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83312__$1_version$jscomp$52$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83311_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.4-slide-0.jpg",border:"0",
alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__version-tag",children:"Version "+($map__83312__$1_version$jscomp$52$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_4__feature-title",children:"At Penpot we are at full speed!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"With the release of the long-awaited Plugins System still fresh, this 2.4 brings improvements in a wide range of areas that will serve a variety of use cases."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_4__feature-content",children:"This release combines some of the most requested features—such as versioning and the viewer-only role—with performance improvements and a new .penpot format that will streamline the export of files and assets."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$37$$,className:"main_ui_releases_v2_4__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83311_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.4-viewer.gif",border:"0",alt:"Viewer role, designed to enhance collaboration",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"Viewer role, designed to enhance collaboration"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_4__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Collaboration takes many forms, and sometimes the risk of making unwanted or accidental adjustments can be a barrier to engaging with a design file."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Now, you can invite members to your teams who only need to view and comment on files. Team members, stakeholders, developers… pick your case. Anyone who doesn't need to edit can participate confidently."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83311_slide$jscomp$27$$,navigate:$navigate$jscomp$30$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$37$$,className:"main_ui_releases_v2_4__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83311_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.4-history.gif",border:"0",alt:"A timeline for your design process",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_4__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"A timeline for your design process"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Version History allows you to save different stages of your design process, so you can revisit them whenever needed."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_4__feature-content",children:"Some versions are saved automatically, serving as an invaluable emergency backup. Additionally, you can manually save versions, giving you full control over the timeline associated with a file. This way, you can always restore specific versions that you've intentionally saved."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83311_slide$jscomp$27$$,navigate:$navigate$jscomp$30$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$37$$,className:"main_ui_releases_v2_4__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83311_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.4-format.gif",border:"0",alt:"New export format: fast and open",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"New export format: fast and open"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"The new .penpot format will streamline the import and export of files and assets by being more efficient and interoperable."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"This format replaces the previous two—so no more choosing between them or accidentally picking the wrong one! It's better for both scenarios: if you just need to import or export files quickly, it’ll be a bit faster. And if you want to extract data (like a list of color assets), this new format is much easier to read."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83311_slide$jscomp$27$$,navigate:$navigate$jscomp$30$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$27$$,className:"main_ui_releases_v2_4__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83311_slide$jscomp$27$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.5",function($p__83314_slide$jscomp$28$$){var $map__83315__$1_version$jscomp$53$$=$APP.$cljs$core$__destructure_map$$($p__83314_slide$jscomp$28$$);$p__83314_slide$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83315__$1_version$jscomp$53$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83315__$1_version$jscomp$53$$,
$cljs$cst$6361$klass$$),$next$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83315__$1_version$jscomp$53$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83315__$1_version$jscomp$53$$,$cljs$cst$6362$finish$$),$navigate$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83315__$1_version$jscomp$53$$,$APP.$cljs$cst$1941$navigate$$);$map__83315__$1_version$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83315__$1_version$jscomp$53$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83314_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-slide-0.png",border:"0",
alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__version-tag",children:"Version "+($map__83315__$1_version$jscomp$53$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_5__feature-title",children:"We’re thrilled to introduce Penpot 2.5"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Packed with powerful new features and little big details. This release brings multi-step gradients, along with comment notifications, making it easier than ever to communicate with your team members. Now you also can easily copy/paste groups of styles between layers and share direct links to specific boards, among other new capabilities considered true gems for designers and team collaboration."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"But that’s not all—we’ve also tackled numerous bug fixes and optimizations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83314_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-gradients.gif",border:"0",alt:"Multi-step gradients and more",className:"main_ui_releases_v2_5__start-image"}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Multi-step gradients and more"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"We’re so happy to bring you one of our most requested features—multi-step gradients! Now, you can create smooth, complex color transitions with multiple stops, giving you more creative options to customize your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"And that’s not all. We’ve also added quick actions to flip and rotate gradients, plus now you can adjust the radius for radial gradients. More control, more flexibility, more fun."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83314_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,
total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83314_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-mention.gif",border:"0",alt:"Comment mentions and manage notifications",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Comment mentions and manage notifications"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"No more lost comments! You can now tag teammates in comments, and they’ll get a notification so they never miss direct feedback. Plus, now you can filter mentions—just select 'Only your mentions' to quickly find discussions that matter to you."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",
children:"We’ve also added a new section in your profile where you can customize your notifications, choosing what to receive on your dashboard and via email. On top of that, comments got a UI refresh, making everything clearer and better organized. And this is just the first batch of improvements—expect even more comment-related upgrades in the next Penpot release."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83314_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83314_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-copy.gif",border:"0",alt:"Copy/paste styles, CSS, and text",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Copy/paste styles, CSS, and text"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Easily copy and apply styles across your designs with just a few clicks. With the new Copy/Paste options, you can quickly transfer fills, strokes, shadows, and other properties from one layer to another—or multiple layers at once. Reusing styles is no longer a repetitive task."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",
children:"And we’ve also added more copy options:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"- 'Copy as CSS' to grab the code instantly."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"- 'Copy as text' if you just need the content."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Less manual work for a faster workflow. We hope you find it as useful as we do."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83314_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83314_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-link.gif",border:"0",alt:"Links to specific boards",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Links to specific boards"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"In a single Penpot file, it's common to have multiple individual screens or designs spread across different boards. Now, you can generate direct links to each board, making it easy to share them with team members or include direct links in documentation."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"No more navigating through the design workspace of a file to find a specific screen—just send a link and take your team straight to the intended board."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83314_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$finish$jscomp$28$$,className:"main_ui_releases_v2_5__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83314_slide$jscomp$28$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.6",function($p__83317_slide$jscomp$29$$){var $map__83318__$1_version$jscomp$54$$=$APP.$cljs$core$__destructure_map$$($p__83317_slide$jscomp$29$$);$p__83317_slide$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83318__$1_version$jscomp$54$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83318__$1_version$jscomp$54$$,
$cljs$cst$6361$klass$$),$next$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83318__$1_version$jscomp$54$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83318__$1_version$jscomp$54$$,$cljs$cst$6362$finish$$),$navigate$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83318__$1_version$jscomp$54$$,$APP.$cljs$cst$1941$navigate$$);$map__83318__$1_version$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83318__$1_version$jscomp$54$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83317_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-slide-0.png",border:"0",
alt:"Design Tokens make their debut in Penpot!",className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__version-tag",children:"Version "+($map__83318__$1_version$jscomp$54$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_6__feature-title",children:"Design Tokens make their debut in Penpot!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Penpot is the first design tool to integrate native design\n           tokens—a single source of truth to improve efficiency and\n           collaboration between product design and development."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"But that’s not all—we’ve also tackled improvements, bug fixes and optimizations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_6__next-btn",children:"Continue"})})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83317_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-tokens-1.gif",border:"0",alt:"Manage brands and themes across your design systems",
className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"Manage brands and themes across your design systems"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",
children:"Create and manage different token types—Color, Opacity,\n           Border Radius, Dimension, Sizing, Spacing, Rotation, and\n           Stroke. And this is just the beginning—more token types are\n           on the way!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Add values to your tokens, including references to other\n           tokens (aliases) and even math operations to keep things\n           dynamic and flexible."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_6__feature-content",children:"Use Themes and Sets for an efficient way to manage your\n           design system across multiple dimensions—whether it’s\n           brand, color schemes, devices, density, or anything else\n           your product needs."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83317_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,
total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_6__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83317_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-tokens-2.gif",border:"0",alt:"Open Source design tokens format",className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"Open Source design tokens format"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_6__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Penpot adopts the W3C Design Tokens Community Group (DTCG)\n           standard, ensuring maximum compatibility with a wide range\n           of tools and technologies."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"With Penpot’s standardized design tokens format, you can\n           easily reuse and sync tokens across different platforms,\n           workflows, and disciplines. Import your existing tokens\n           into Penpot—or export them for use anywhere else. Seamless\n           interoperability by design through Open Source."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83317_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_6__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83317_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-bubbles.gif",border:"0",alt:"Comments grouped by zoom level",className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_6__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"Comments grouped by zoom level"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"When collaborating on files, feedback can quickly become\n           dense and overwhelming, turning what should be information\n           into visual noise. Now, comments are grouped based on your\n           zoom level, giving the right level of visibility and making\n           navigating feedback easier."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"When you’re zoomed out, comments are grouped to reduce\n           clutter and keep your workspace clean. As you zoom in, the\n           groups expand, revealing individual comments in\n           context. This makes navigating feedback much smoother,\n           especially in complex designs with lots of discussion."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83317_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$29$$,className:"main_ui_releases_v2_6__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83317_slide$jscomp$29$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.7",function($p__83320_slide$jscomp$30$$){var $map__83321__$1_version$jscomp$55$$=$APP.$cljs$core$__destructure_map$$($p__83320_slide$jscomp$30$$);$p__83320_slide$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83321__$1_version$jscomp$55$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83321__$1_version$jscomp$55$$,
$cljs$cst$6361$klass$$),$next$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83321__$1_version$jscomp$55$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83321__$1_version$jscomp$55$$,$cljs$cst$6362$finish$$),$navigate$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83321__$1_version$jscomp$55$$,$APP.$cljs$cst$1941$navigate$$);$map__83321__$1_version$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83321__$1_version$jscomp$55$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83320_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-slide-0.jpg",border:"0",
alt:"Design Tokens make their debut in Penpot!",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__version-tag",children:"Version "+($map__83321__$1_version$jscomp$55$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_7__feature-title",children:"Penpot 2.7 is out!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"After the huge excitement around our last release. The first-ever native Design Tokens support in a design tool (yay!), we’re keeping the momentum going with a fresh batch of new features and improvements."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"This update brings the first set of upgrades to our new Design Tokens system, a few of the many to come. We’ve also expanded who can create sharing prototype links and improved the invitations area. Last but not least, we fixed a bunch of bugs and optimizations that will make the experience more enjoyable for all."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"Let’s dive in!"})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$40$$,className:"main_ui_releases_v2_7__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83320_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_7__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-duplicate-set.gif",border:"0",alt:"Design Tokens improvements",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"Design Tokens improvements"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"It hasn’t been long since we launched Design Tokens in Penpot (the first native Design Tokens support in a design tool!), and we’re already rolling out the first set of improvements."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"The highlight: you can now duplicate token sets directly from a menu item. A huge time-saver, especially when working from existing sets. We’ve also made it easier to create themes by letting you select their set right away, and we’ve polished some info indicators to make everything a bit clearer. Plus, we’ve fixed a bunch of early-stage bugs to keep things running smoothly."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83320_slide$jscomp$30$$,navigate:$navigate$jscomp$33$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$40$$,className:"main_ui_releases_v2_7__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83320_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-share.gif",border:"0",alt:"Editors and viewers can now create Share prototype links",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"Editors and viewers can now create Share prototype links"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"From now on, both editors and viewers can create Share Prototype links. Sharing prototypes is key for better team collaboration, no matter the role. It’s a common need, team members often have to share presentations without risking any accidental changes to the designs, which means they don’t necessarily need editing permissions. In the future, Penpot will introduce more fine-grained control over these permissions."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"This update gives editors and viewers the same ability to configure, create, copy, and delete sharing links. A capability that, until now, was limited to owners and admins."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83320_slide$jscomp$30$$,navigate:$navigate$jscomp$33$$,
total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$40$$,className:"main_ui_releases_v2_7__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83320_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-invitations.gif",border:"0",alt:"A clearer way to invite your first team members",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"A clearer way to invite your first team members"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"Penpot works perfectly for solo projects, but it’s always more fun with a team. That’s why we’ve updated the initial state of the invitations area. Instead of starting blank, it now offers clearer guidance to help you invite your first team members."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",
children:"This improvement in design and UX writing comes from community member Prithvi Tharun (credit where it’s due!) Not all open source contributions are about code, and this is a fantastic example of how design and writing make a real difference too."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83320_slide$jscomp$30$$,navigate:$navigate$jscomp$33$$,total:3}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$30$$,className:"main_ui_releases_v2_7__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83320_slide$jscomp$30$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.8",function($p__83323_slide$jscomp$31$$){var $map__83324__$1_version$jscomp$56$$=$APP.$cljs$core$__destructure_map$$($p__83323_slide$jscomp$31$$);$p__83323_slide$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83324__$1_version$jscomp$56$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83324__$1_version$jscomp$56$$,
$cljs$cst$6361$klass$$),$next$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83324__$1_version$jscomp$56$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83324__$1_version$jscomp$56$$,$cljs$cst$6362$finish$$),$navigate$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83324__$1_version$jscomp$56$$,$APP.$cljs$cst$1941$navigate$$);$map__83324__$1_version$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83324__$1_version$jscomp$56$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83323_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-slide-0.jpg",border:"0",
alt:"Penpot 2.8 is here!",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__version-tag",children:"Version "+($map__83324__$1_version$jscomp$56$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_8__feature-title",children:"Penpot 2.8 is out!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"Keeping the momentum from our last releases, we're moving forward with a fresh batch of features and improvements."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"This update brings significant user experience optimizations, new capabilities for Design Token management, and an important performance enhancement, in addition to the usual bug fixes and general optimizations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_8__next-btn",
children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83323_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-selection.gif",border:"0",alt:"Quality-of-life improvements",
className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Quality-of-life improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"The devil is in the details, and we've added many more improvements than we can list in this introduction, so we’ll list them here:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- You can now deselect layers with Ctrl+Shift+Drag."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- Synchronize your color theme (light, dark) with your operating system theme."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"- Copy objects directly as SVG from the design workspace using the contextual menu."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- Your choice of ruler visibility settings now persists across files and reloads."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- We have introduced a new look and feel for tooltips."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"- Our fonts catalog has been updated, highlighting fonts like Atkinson Hyperlegible, developed specifically to increase legibility for readers with low vision."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- And we’ve a new language! Hi Serbians!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83323_slide$jscomp$31$$,
navigate:$navigate$jscomp$34$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_8__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83323_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-json-multi.gif",border:"0",alt:"Multi-file tokens import and export",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Multi-file tokens import and export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_8__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"Continuing the development of our Design Tokens system, we keep launching new functionalities that will improve your workflow."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"It is now possible to perform multi-file token import. This is perfect for handling more complex setups like separate JSON files for themes or metadata. The same goes for exporting. Now you can export tokens choosing between single or multi-file (check your team preference!), being able to preview both options before you decide."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"This is just one more step in the evolution of Design Tokens in Penpot. And there's more to come: typography tokens are already in the works!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83323_slide$jscomp$31$$,navigate:$navigate$jscomp$34$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_8__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83323_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.8-ia-help.gif",border:"0",alt:"Better onboarding experience",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Better onboarding experience"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"We know Penpot works perfectly for solo projects, but it’s always more fun and productive to work as a team. That's why we have made significant optimizations to the onboarding process to make your team mates getting started easier and faster."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- We have reduced the number of onboarding steps so new users can start designing sooner. Only essential data will be collected to help you set up your profile more efficiently."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- We have integrated AI-powered help, which is trained on Penpot documentation, directly into the design workspace. Get assistance without switching context, so you can stay in the flow."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83323_slide$jscomp$31$$,navigate:$navigate$jscomp$34$$,
total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_8__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83323_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-svg-opt.gif",border:"0",alt:"Performance improvements related to SVG paths",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Performance improvements related to SVG paths"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"We are putting a special focus on performance. This time, we've made improvements around handling paths, which typically make up icons and illustrations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"We have carried out a refactoring of how Penpot deals with path data. This translates into perceptible performance improvements in SVG-heavily loaded files. This means that, in files with a significant presence of SVG icons and illustrations you can expect:"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- Faster import/export."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- A more fluid user experience."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"This is one of many performance improvements to come, including a new rendering engine that is already under development (this will be huge, please be patient!)."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83323_slide$jscomp$31$$,navigate:$navigate$jscomp$34$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$31$$,className:"main_ui_releases_v2_8__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83323_slide$jscomp$31$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.9",function($p__83326_slide$jscomp$32$$){var $map__83327__$1_version$jscomp$57$$=$APP.$cljs$core$__destructure_map$$($p__83326_slide$jscomp$32$$);$p__83326_slide$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83327__$1_version$jscomp$57$$,$APP.$cljs$cst$1958$slide$$);var $klass$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83327__$1_version$jscomp$57$$,
$cljs$cst$6361$klass$$),$next$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83327__$1_version$jscomp$57$$,$APP.$cljs$cst$1328$next$$),$finish$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83327__$1_version$jscomp$57$$,$cljs$cst$6362$finish$$),$navigate$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83327__$1_version$jscomp$57$$,$APP.$cljs$cst$1941$navigate$$);$map__83327__$1_version$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83327__$1_version$jscomp$57$$,
$APP.$cljs$cst$2289$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$p__83326_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.9-slide-0.jpg",border:"0",
alt:"Penpot 2.9 is here!",className:"main_ui_releases_v2_9__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_9__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__version-tag",children:"Version "+($map__83327__$1_version$jscomp$57$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_9__feature-title",children:"Penpot 2.9 is out!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"We're keeping the momentum going with another exciting round of improvements and features!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"This release brings major progress in Design Token management (including our very first typography token!), smarter text overrides for components, and a rich collection of quality-of-life enhancements."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$42$$,className:"main_ui_releases_v2_9__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83326_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.9-font-size.gif",border:"0",alt:"New typography token type",className:"main_ui_releases_v2_9__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-header",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_9__modal-title",children:"New typography token type"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"You can now define and manage font size tokens right from the Design Tokens panel. This is just the first of many typography token types to come. Font family token is next!"}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_9__feature-content",children:"And there’s more progress on Tokens, including support for importing multiple token files via .zip, and smarter token visibility, only showing the relevant tokens for each layer type."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83326_slide$jscomp$32$$,navigate:$navigate$jscomp$35$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$42$$,className:"main_ui_releases_v2_9__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83326_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.9-qol.gif",border:"0",alt:"Quality-of-life galore",className:"main_ui_releases_v2_9__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_9__modal-title",children:"Quality-of-life galore"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"This release packs dozens of small yet impactful usability improvements, including enhanced UX writing (thanks to community contributions!), a new visual indicator for comments directly in the design space, a reorganized dashboard sidebar, improved text resizing behavior, and much more."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"As always, we've squashed plenty of bugs and made underlying performance improvements to keep everything running smoothly."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83326_slide$jscomp$32$$,navigate:$navigate$jscomp$35$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$32$$,className:"main_ui_releases_v2_9__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83326_slide$jscomp$32$$)].join(""));
});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$54$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$54$$,$APP.$cljs$cst$5373$release_notes$$,$app$main$ui$releases$release_notes_modal$$)});
$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"0.0",function($params$jscomp$459$$){return $app$main$ui$releases$common$render_release_notes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$459$$,$APP.$cljs$cst$2289$version$$,"2.16"))});var $app$main$ui$auth_page$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6363$app_DOT_main_DOT_ui_DOT_auth_SLASH_auth_page_STAR_$$).then(function($f__49754__auto__$$){return{"default":$f__49754__auto__$$.$cljs$core$IFn$_invoke$arity$0$?$f__49754__auto__$$.$cljs$core$IFn$_invoke$arity$0$():$f__49754__auto__$$()}})}),$app$main$ui$verify_token_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6364$app_DOT_main_DOT_ui_DOT_auth_DOT_verify_token_SLASH_verify_token_page_STAR_$$).then(function($f__49754__auto__$jscomp$1$$){return{"default":$f__49754__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$f__49754__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$f__49754__auto__$jscomp$1$$()}})}),$app$main$ui$viewer_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6365$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer_page_STAR_$$).then(function($f__49754__auto__$jscomp$2$$){return{"default":$f__49754__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$f__49754__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$f__49754__auto__$jscomp$2$$()}})}),
$app$main$ui$dashboard_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6366$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard_page_STAR_$$).then(function($f__49754__auto__$jscomp$3$$){return{"default":$f__49754__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$f__49754__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$f__49754__auto__$jscomp$3$$()}})}),$app$main$ui$settings_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6367$app_DOT_main_DOT_ui_DOT_settings_SLASH_settings_page_STAR_$$).then(function($f__49754__auto__$jscomp$4$$){return{"default":$f__49754__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$f__49754__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$f__49754__auto__$jscomp$4$$()}})}),$app$main$ui$workspace_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6368$app_DOT_main_DOT_ui_DOT_workspace_SLASH_workspace_page_STAR_$$).then(function($f__49754__auto__$jscomp$5$$){return{"default":$f__49754__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$f__49754__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$f__49754__auto__$jscomp$5$$()}})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$55$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$55$$,$APP.$cljs$cst$3379$alert$$,$app$main$ui$alert$alert_dialog$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$56$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$56$$,$APP.$cljs$cst$2473$confirm$$,$app$main$ui$confirm$confirm_dialog$$)});var $app$main$ui$delete_shared$noop$$=$APP.$cljs$core$constantly$$(null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$57$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$57$$,$APP.$cljs$cst$5609$delete_shared_libraries$$,$app$main$ui$delete_shared$delete_shared_dialog$$)});var $app$main$ui$routes$init_routes_83454$$,$app$main$ui$routes$routes$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/auth",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/login",$APP.$cljs$cst$3356$auth_login$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/register",$APP.$cljs$cst$5383$auth_register$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/register/validate",$APP.$cljs$cst$6303$auth_register_validate$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/register/success",$APP.$cljs$cst$5393$auth_register_success$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/recovery/request",
$APP.$cljs$cst$5382$auth_recovery_request$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/recovery",$cljs$cst$6371$auth_recovery$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/verify-token",$APP.$cljs$cst$3304$auth_verify_token$$],null)],null),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/subscribe-nitrate",$cljs$cst$6372$nitrate_entry$$],null):null,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/settings",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/profile",$APP.$cljs$cst$5374$settings_profile$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/password",$APP.$cljs$cst$6373$settings_password$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/feedback",$APP.$cljs$cst$2509$settings_feedback$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/options",$APP.$cljs$cst$6374$settings_options$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/subscriptions",$APP.$cljs$cst$5069$settings_subscription$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/integrations",$APP.$cljs$cst$6375$settings_integrations$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/notifications",$APP.$cljs$cst$6376$settings_notifications$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/frame-preview",$cljs$cst$6377$frame_preview$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/view",$APP.$cljs$cst$1592$viewer$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/view/:file-id",$cljs$cst$6378$viewer_legacy$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/debug/icons-preview",$cljs$cst$6379$debug_icons_preview$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/debug/playground",$cljs$cst$6380$debug_playground$$],null):null,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/render-sprite/:file-id",$cljs$cst$6381$render_sprite$$],null),new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/dashboard",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/members",$APP.$cljs$cst$2524$dashboard_members$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/invitations",$APP.$cljs$cst$2526$dashboard_invitations$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/webhooks",$APP.$cljs$cst$2528$dashboard_webhooks$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/settings",$APP.$cljs$cst$2530$dashboard_settings$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/recent",$APP.$cljs$cst$2522$dashboard_recent$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/search",$APP.$cljs$cst$2515$dashboard_search$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts",$APP.$cljs$cst$2520$dashboard_fonts$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts/providers",$cljs$cst$6369$dashboard_font_providers$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/libraries",$APP.$cljs$cst$2518$dashboard_libraries$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/files",$APP.$cljs$cst$2512$dashboard_files$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/deleted",$APP.$cljs$cst$2536$dashboard_deleted$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/dashboard/team/:team-id",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/members",$cljs$cst$6382$dashboard_legacy_team_members$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/invitations",$cljs$cst$6383$dashboard_legacy_team_invitations$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/webhooks",$cljs$cst$6384$dashboard_legacy_team_webhooks$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/settings",$cljs$cst$6385$dashboard_legacy_team_settings$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/projects",$cljs$cst$6386$dashboard_legacy_projects$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/search",$cljs$cst$6387$dashboard_legacy_search$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts",$cljs$cst$6388$dashboard_legacy_fonts$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts/providers",$cljs$cst$6389$dashboard_legacy_font_providers$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/libraries",$cljs$cst$6390$dashboard_legacy_libraries$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/projects/:project-id",$cljs$cst$6391$dashboard_legacy_files$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/workspace",$APP.$cljs$cst$2532$workspace$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/workspace/:project-id/:file-id",$cljs$cst$6392$workspace_legacy$$],null)],null);var $shadow$js$shim$module$0$0penpot$0plugins_runtime$$=shadow$bridge("@penpot/plugins-runtime");var $app$plugins$format$shape_proxy$$=null;var $app$plugins$flex$shape_proxy_QMARK_$$=null;var $app$plugins$grid$shape_proxy_QMARK_$$=null;var $app$plugins$ruler_guides$shape_proxy$$=$APP.$cljs$core$identity$$,$app$plugins$ruler_guides$shape_proxy_QMARK_$$=$APP.$cljs$core$identity$$;var $app$plugins$text$font_size_re$$=/^\d*\.?\d*$/,$app$plugins$text$line_height_re$$=/^\d*\.?\d*$/,$app$plugins$text$letter_spacing_re$$=/^\d*\.?\d*$/,$app$plugins$text$text_transform_re$$=/uppercase|capitalize|lowercase|none/,$app$plugins$text$text_decoration_re$$=/underline|line-through|none/,$app$plugins$text$text_direction_re$$=/ltr|rtl/,$app$plugins$text$text_align_re$$=/left|center|right|justify/,$app$plugins$text$vertical_align_re$$=/top|center|bottom/;var $app$plugins$tokens$map_COLON_token_attr__GT_token_attr_plugin$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1688$p4$$,$APP.$cljs$cst$1702$m3$$,$APP.$cljs$cst$1687$p3$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1703$m4$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1701$m2$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1700$m1$$],[$cljs$cst$6491$padding_top_right$$,$cljs$cst$6492$padding_bottom_left$$,$cljs$cst$6493$margin_bottom_right$$,
$cljs$cst$6494$padding_bottom_right$$,$cljs$cst$6495$border_radius_top_right$$,$cljs$cst$6496$padding_top_left$$,$cljs$cst$6497$margin_bottom_left$$,$cljs$cst$6498$border_radius_bottom_right$$,$cljs$cst$6499$border_radius_top_left$$,$cljs$cst$6500$margin_top_right$$,$cljs$cst$6501$border_radius_bottom_left$$,$cljs$cst$6502$margin_top_left$$]),$app$plugins$tokens$map_COLON_token_attr_plugin__GT_token_attr$$=$APP.$clojure$set$map_invert$$($app$plugins$tokens$map_COLON_token_attr__GT_token_attr_plugin$$),
$app$plugins$tokens$token_proxy$$=function $app$plugins$tokens$token_proxy$$($plugin_id$jscomp$25$$,$file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$){var $obj_84997$$=new $APP.$app$util$object$Proxy$$,$schema_name_85203_86256$$=$APP.$app$common$files$tokens$make_token_name_schema$$(function(){var $G__85306$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$474$$);return $G__85306$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens$$($G__85306$$,$set_id$jscomp$47$$)}()),$coercer_fn_name_85201_86257$$=
$schema_name_85203_86256$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_name_85203_86256$$)?null:$APP.$app$common$schema$coercer$$($schema_name_85203_86256$$),$schema_value_85218_86262$$=function(){var $token$jscomp$212$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$);return $APP.$app$common$files$tokens$make_token_value_schema$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$212$$))}(),$coercer_fn_value_85216_86263$$=$schema_value_85218_86262$$==
null||$APP.$cljs$core$fn_QMARK_$$($schema_value_85218_86262$$)?null:$APP.$app$common$schema$coercer$$($schema_value_85218_86262$$),$coercer_fn_description_85238_86270$$=$APP.$app$common$files$tokens$schema_COLON_token_description$$==null||$APP.$cljs$core$fn_QMARK_$$($APP.$app$common$files$tokens$schema_COLON_token_description$$)?null:$APP.$app$common$schema$coercer$$($APP.$app$common$files$tokens$schema_COLON_token_description$$),$schema_applytoshapes_85262_86281$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$shape_proxy_QMARK_$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_attr_QMARK_$$],null)],null)],null)],null)],null),$coercer_fn_applytoshapes_85260_86282$$=
$schema_applytoshapes_85262_86281$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_applytoshapes_85262_86281$$)?null:$APP.$app$common$schema$coercer$$($schema_applytoshapes_85262_86281$$),$schema_applytoselected_85269_86285$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_attr_QMARK_$$],null)],null)],null)],null)],null),$coercer_fn_applytoselected_85267_86286$$=
$schema_applytoselected_85269_86285$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_applytoselected_85269_86285$$)?null:$APP.$app$common$schema$coercer$$($schema_applytoselected_85269_86285$$);Object.defineProperty($obj_84997$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TokenProxy"}});Object.defineProperty($obj_84997$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokenProxy"}});Object.defineProperty($obj_84997$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_85097$$=
$APP.$cljs$core$constantly$$($plugin_id$jscomp$25$$);try{return $internal_fn_plugin_85097$$.call(this)}catch($e85300$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85300$$)}}});Object.defineProperty($obj_84997$$,"$file-id",{enumerable:!1,get:function(){var $internal_fn_fileid_85172$$=$APP.$cljs$core$constantly$$($file_id$jscomp$474$$);try{return $internal_fn_fileid_85172$$.call(this)}catch($e85301$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85301$$)}}});
Object.defineProperty($obj_84997$$,"$set-id",{enumerable:!1,get:function(){var $internal_fn_setid_85179$$=$APP.$cljs$core$constantly$$($set_id$jscomp$47$$);try{return $internal_fn_setid_85179$$.call(this)}catch($e85302$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85302$$)}}});Object.defineProperty($obj_84997$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_85186$$=$APP.$cljs$core$constantly$$($id$jscomp$1111$$);try{return $internal_fn_id_85186$$.call(this)}catch($e85303$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85303$$)}}});
Object.defineProperty($obj_84997$$,"id",{enumerable:!0,get:function(){try{return""+($id$jscomp$1111$$??"")}catch($e85304$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85304$$)}}});Object.defineProperty($obj_84997$$,"name",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10268$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$);return $APP.$app$common$types$tokens_lib$get_name$$($token$jscomp$inline_10268$$)}catch($e85305$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85305$$)}},
set:function($val_name_85205$$){try{var $schema_name_85203__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_name_85203_86256$$)?$schema_name_85203_86256$$($val_name_85205$$):$schema_name_85203_86256$$,$coercer_fn_name_85201__$1$$=$coercer_fn_name_85201_86257$$==null?$APP.$app$common$schema$coercer$$($schema_name_85203__$1$$):$coercer_fn_name_85201_86257$$,$val_name_85205__$1$$=$APP.$app$common$json$__GT_clj$$($val_name_85205$$,null),$val_name_85205__$2$$=$coercer_fn_name_85201__$1$$($val_name_85205__$1$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$($set_id$jscomp$47$$,$id$jscomp$1111$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$val_name_85205__$2$$],null)),$plugin_id$jscomp$25$$))}catch($e85311$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85311$$)}}});Object.defineProperty($obj_84997$$,
"type",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10271$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$),$G__85314$jscomp$inline_10272$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$inline_10271$$);return $APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__85314$jscomp$inline_10272$$):
(0,$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$)($G__85314$jscomp$inline_10272$$)}catch($e85315$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85315$$)}}});Object.defineProperty($obj_84997$$,"value",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10275$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$);return $APP.$app$common$json$__GT_js$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$inline_10275$$))}catch($e85318$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85318$$)}},
set:function($val_value_85220$$){try{var $schema_value_85218__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_value_85218_86262$$)?$schema_value_85218_86262$$($val_value_85220$$):$schema_value_85218_86262$$,$coercer_fn_value_85216__$1$$=$coercer_fn_value_85216_86263$$==null?$APP.$app$common$schema$coercer$$($schema_value_85218__$1$$):$coercer_fn_value_85216_86263$$,$val_value_85220__$1$$=$APP.$app$common$json$__GT_clj$$($val_value_85220$$,null),$val_value_85220__$2$$=$coercer_fn_value_85216__$1$$($val_value_85220__$1$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$($set_id$jscomp$47$$,$id$jscomp$1111$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$val_value_85220__$2$$],null)))}catch($e85323$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85323$$)}}});Object.defineProperty($obj_84997$$,"resolvedValue",{enumerable:!1,get:function(){try{var $token$jscomp$inline_10278$$=
$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$),$tokens_lib$jscomp$inline_10279$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$474$$),$tokens_tree$jscomp$inline_10280$$=$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$inline_10279$$);return $app$plugins$tokens$get_resolved_value$$($token$jscomp$inline_10278$$,$tokens_tree$jscomp$inline_10280$$)}catch($e85328$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85328$$)}}});
Object.defineProperty($obj_84997$$,"resolvedValueString",{enumerable:!1,get:function(){try{var $token$jscomp$inline_10283$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$),$tokens_lib$jscomp$inline_10284$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$474$$),$tokens_tree$jscomp$inline_10285$$=$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$inline_10284$$);return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$tokens$get_resolved_value$$($token$jscomp$inline_10283$$,
$tokens_tree$jscomp$inline_10285$$))}catch($e85329$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85329$$)}}});Object.defineProperty($obj_84997$$,"description",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10288$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$);return $APP.$app$common$types$tokens_lib$get_description$$($token$jscomp$inline_10288$$)}catch($e85356$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85356$$)}},
set:function($val_description_85242$$){try{var $schema_description_85240__$1$$=$APP.$cljs$core$fn_QMARK_$$($APP.$app$common$files$tokens$schema_COLON_token_description$$)?(0,$APP.$app$common$files$tokens$schema_COLON_token_description$$)($val_description_85242$$):$APP.$app$common$files$tokens$schema_COLON_token_description$$,$coercer_fn_description_85238__$1$$=$coercer_fn_description_85238_86270$$==null?$APP.$app$common$schema$coercer$$($schema_description_85240__$1$$):$coercer_fn_description_85238_86270$$,
$val_description_85242__$1$$=$APP.$app$common$json$__GT_clj$$($val_description_85242$$,null),$val_description_85242__$2$$=$coercer_fn_description_85238__$1$$($val_description_85242__$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$($set_id$jscomp$47$$,$id$jscomp$1111$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$936$description$$,
$val_description_85242__$2$$],null)),$APP.$cljs$cst$1720$plugin_id$$))}catch($e85359$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85359$$)}}});Object.defineProperty($obj_84997$$,"duplicate",{enumerable:!1,get:function(){return function(){try{var $token$jscomp$216$$=$app$plugins$utils$locate_token$$($file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$),$token_SINGLEQUOTE_$jscomp$4$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$clojure$datafy$datafy$$($token$jscomp$216$$),
$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1737$modified_at$$]))]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$($set_id$jscomp$47$$,$token_SINGLEQUOTE_$jscomp$4$$),$plugin_id$jscomp$25$$));var $G__85408$$=$token_SINGLEQUOTE_$jscomp$4$$.id;return $app$plugins$tokens$token_proxy$$.$cljs$core$IFn$_invoke$arity$4$?
$app$plugins$tokens$token_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$25$$,$file_id$jscomp$474$$,$set_id$jscomp$47$$,$G__85408$$):$app$plugins$tokens$token_proxy$$($plugin_id$jscomp$25$$,$file_id$jscomp$474$$,$set_id$jscomp$47$$,$G__85408$$)}catch($e85366$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85366$$)}}.bind(this)}});Object.defineProperty($obj_84997$$,"remove",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$delete_token$$($set_id$jscomp$47$$,
$id$jscomp$1111$$),$plugin_id$jscomp$25$$))}catch($e85409$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85409$$)}}.bind(this)}});Object.defineProperty($obj_84997$$,"applyToShapes",{enumerable:!1,get:function(){var $internal_fn_applytoshapes_85259__$1$$=function($shapes$jscomp$240$$,$attrs$jscomp$188$$){try{return $app$plugins$tokens$apply_token_to_shapes$$($plugin_id$jscomp$25$$,$file_id$jscomp$474$$,$set_id$jscomp$47$$,$id$jscomp$1111$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__84969_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__84969_SHARP_$$,
"$id")},$shapes$jscomp$240$$),$attrs$jscomp$188$$)}catch($e85420$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85420$$)}}.bind(this);return function(){try{var $val_applytoshapes_85264$$=Array.from(arguments),$val_applytoshapes_85264__$1$$=$APP.$app$common$json$__GT_clj$$($val_applytoshapes_85264$$,null),$schema_applytoshapes_85262__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_applytoshapes_85262_86281$$)?$schema_applytoshapes_85262_86281$$($val_applytoshapes_85264__$1$$):$schema_applytoshapes_85262_86281$$,
$val_applytoshapes_85264__$2$$=($coercer_fn_applytoshapes_85260_86282$$==null?$APP.$app$common$schema$coercer$$($schema_applytoshapes_85262__$1$$):$coercer_fn_applytoshapes_85260_86282$$)($val_applytoshapes_85264__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_applytoshapes_85259__$1$$,$val_applytoshapes_85264__$2$$)}catch($e85421$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85421$$)}}}});Object.defineProperty($obj_84997$$,"applyToSelected",
{enumerable:!1,get:function(){var $internal_fn_applytoselected_85266__$1$$=function($attrs$jscomp$189$$){try{var $selected$jscomp$223$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null));return $app$plugins$tokens$apply_token_to_shapes$$($plugin_id$jscomp$25$$,$file_id$jscomp$474$$,
$set_id$jscomp$47$$,$id$jscomp$1111$$,$selected$jscomp$223$$,$attrs$jscomp$189$$)}catch($e85430$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85430$$)}}.bind(this);return function(){try{var $val_applytoselected_85271$$=Array.from(arguments),$val_applytoselected_85271__$1$$=$APP.$app$common$json$__GT_clj$$($val_applytoselected_85271$$,null),$schema_applytoselected_85269__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_applytoselected_85269_86285$$)?$schema_applytoselected_85269_86285$$($val_applytoselected_85271__$1$$):
$schema_applytoselected_85269_86285$$,$val_applytoselected_85271__$2$$=($coercer_fn_applytoselected_85267_86286$$==null?$APP.$app$common$schema$coercer$$($schema_applytoselected_85269__$1$$):$coercer_fn_applytoselected_85267_86286$$)($val_applytoselected_85271__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_applytoselected_85266__$1$$,$val_applytoselected_85271__$2$$)}catch($e85433$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$25$$)($e85433$$)}}}});
return $obj_84997$$},$app$plugins$tokens$token_theme_proxy$$=function $app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$28$$,$file_id$jscomp$477$$,$id$jscomp$1114$$){var $obj_85850$$=new $APP.$app$util$object$Proxy$$,$schema_group_85906_86529$$=function(){var $theme$jscomp$33$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$app$common$files$tokens$make_token_theme_group_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$33$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$33$$))}(),$coercer_fn_group_85904_86530$$=$schema_group_85906_86529$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_group_85906_86529$$)?null:$APP.$app$common$schema$coercer$$($schema_group_85906_86529$$),$schema_name_85914_86534$$=function(){var $theme$jscomp$36$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$app$common$files$tokens$make_token_theme_name_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$36$$),$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$36$$))}(),$coercer_fn_name_85912_86535$$=$schema_name_85914_86534$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_name_85914_86534$$)?null:$APP.$app$common$schema$coercer$$($schema_name_85914_86534$$),$coercer_fn_active_85920_86540$$=$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$==null||$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?
null:$APP.$app$common$schema$coercer$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$),$schema_addset_85948_86548$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_set_proxy_QMARK_$$],null)],null),$coercer_fn_addset_85942_86549$$=$schema_addset_85948_86548$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addset_85948_86548$$)?
null:$APP.$app$common$schema$coercer$$($schema_addset_85948_86548$$),$schema_removeset_85955_86552$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_set_proxy_QMARK_$$],null)],null),$coercer_fn_removeset_85953_86553$$=$schema_removeset_85955_86552$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_removeset_85955_86552$$)?
null:$APP.$app$common$schema$coercer$$($schema_removeset_85955_86552$$);Object.defineProperty($obj_85850$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TokenThemeProxy"}});Object.defineProperty($obj_85850$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokenThemeProxy"}});Object.defineProperty($obj_85850$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_85868$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$28$$);try{return $internal_fn_plugin_85868$$.call(this)}catch($e86051$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86051$$)}}});
Object.defineProperty($obj_85850$$,"$file-id",{enumerable:!1,get:function(){var $internal_fn_fileid_85875$$=$APP.$cljs$core$constantly$$($file_id$jscomp$477$$);try{return $internal_fn_fileid_85875$$.call(this)}catch($e86052$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86052$$)}}});Object.defineProperty($obj_85850$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_85882$$=$APP.$cljs$core$constantly$$($id$jscomp$1114$$);try{return $internal_fn_id_85882$$.call(this)}catch($e86053$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86053$$)}}});
Object.defineProperty($obj_85850$$,"id",{enumerable:!0,get:function(){try{return""+($id$jscomp$1114$$??"")}catch($e86054$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86054$$)}}});Object.defineProperty($obj_85850$$,"external-id",{enumerable:!0,get:function(){try{var $theme$jscomp$inline_10308$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$cljs$cst$2107$external_id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$inline_10308$$)}catch($e86055$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86055$$)}}});
Object.defineProperty($obj_85850$$,"group",{enumerable:!0,get:function(){try{var $theme$jscomp$inline_10311$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$inline_10311$$)}catch($e86056$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86056$$)}},set:function($val_group_85908$$){try{var $schema_group_85906__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_group_85906_86529$$)?
$schema_group_85906_86529$$($val_group_85908$$):$schema_group_85906_86529$$,$coercer_fn_group_85904__$1$$=$coercer_fn_group_85904_86530$$==null?$APP.$app$common$schema$coercer$$($schema_group_85906__$1$$):$coercer_fn_group_85904_86530$$,$val_group_85908__$1$$=$APP.$app$common$json$__GT_clj$$($val_group_85908$$,null),$group$jscomp$inline_10315$$=$coercer_fn_group_85904__$1$$($val_group_85908__$1$$),$theme$jscomp$inline_10316$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1114$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($theme$jscomp$inline_10316$$,$APP.$cljs$cst$1608$group$$,$group$jscomp$inline_10315$$)))}catch($e86057$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86057$$)}}});Object.defineProperty($obj_85850$$,"name",{enumerable:!0,get:function(){try{var $theme$jscomp$inline_10318$$=
$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$inline_10318$$)}catch($e86058$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86058$$)}},set:function($val_name_85916$$){try{var $schema_name_85914__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_name_85914_86534$$)?$schema_name_85914_86534$$($val_name_85916$$):$schema_name_85914_86534$$,$coercer_fn_name_85912__$1$$=$coercer_fn_name_85912_86535$$==
null?$APP.$app$common$schema$coercer$$($schema_name_85914__$1$$):$coercer_fn_name_85912_86535$$,$val_name_85916__$1$$=$APP.$app$common$json$__GT_clj$$($val_name_85916$$,null),$name$jscomp$inline_10322$$=$coercer_fn_name_85912__$1$$($val_name_85916__$1$$),$theme$jscomp$inline_10323$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$cljs$core$truth_$$($name$jscomp$inline_10322$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1114$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($theme$jscomp$inline_10323$$,$APP.$cljs$cst$725$name$$,$name$jscomp$inline_10322$$))):null}catch($e86059$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86059$$)}}});Object.defineProperty($obj_85850$$,"active",{enumerable:!1,get:function(){try{var $tokens_lib$jscomp$inline_10325$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$);return $app$common$types$tokens_lib$theme_active_QMARK_$$($tokens_lib$jscomp$inline_10325$$,
$id$jscomp$1114$$)}catch($e86060$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86060$$)}},set:function($val_active_85924$$){try{var $schema_active_85922__$1$$=$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?(0,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)($val_active_85924$$):$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$,$coercer_fn_active_85920__$1$$=$coercer_fn_active_85920_86540$$==null?$APP.$app$common$schema$coercer$$($schema_active_85922__$1$$):
$coercer_fn_active_85920_86540$$,$val_active_85924__$1$$=$APP.$app$common$json$__GT_clj$$($val_active_85924$$,null),$val_active_85924__$2$$=$coercer_fn_active_85920__$1$$($val_active_85924__$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$set_token_theme_active$$($id$jscomp$1114$$,$val_active_85924__$2$$))}catch($e86061$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86061$$)}}});Object.defineProperty($obj_85850$$,
"toggleActive",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1114$$))}catch($e86062$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86062$$)}}.bind(this)}});Object.defineProperty($obj_85850$$,"activeSets",{enumerable:!0,get:function(){function $internal_fn_activesets_85934$$(){var $tokens_lib$jscomp$63$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$),
$theme$jscomp$38$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$inline_10330_p1__85848_SHARP_$$){$id$jscomp$inline_10330_p1__85848_SHARP_$$=$APP.$app$common$types$tokens_lib$get_id$$($APP.$app$common$types$tokens_lib$get_set_by_name$$($tokens_lib$jscomp$63$$,$id$jscomp$inline_10330_p1__85848_SHARP_$$));
return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$($plugin_id$jscomp$28$$,$file_id$jscomp$477$$,$id$jscomp$inline_10330_p1__85848_SHARP_$$,null)},$APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$38$$)))}try{return $internal_fn_activesets_85934$$.call(this,this)}catch($e86063$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86063$$)}}});Object.defineProperty($obj_85850$$,"addSet",{enumerable:!1,get:function(){var $internal_fn_addset_85941__$1$$=
function($token_set$jscomp$23$$){try{var $set_name$jscomp$32$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($token_set$jscomp$23$$,$APP.$cljs$cst$725$name$$),$theme$jscomp$39$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $set_name$jscomp$32$$!=null&&$theme$jscomp$39$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1114$$,$app$common$types$tokens_lib$enable_set$$($theme$jscomp$39$$,
$set_name$jscomp$32$$))):null}catch($e86064$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86064$$)}}.bind(this);return function(){try{var $val_addset_85950$$=Array.from(arguments),$val_addset_85950__$1$$=$APP.$app$common$json$__GT_clj$$($val_addset_85950$$,null),$schema_addset_85948__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addset_85948_86548$$)?$schema_addset_85948_86548$$($val_addset_85950__$1$$):$schema_addset_85948_86548$$,$val_addset_85950__$2$$=($coercer_fn_addset_85942_86549$$==
null?$APP.$app$common$schema$coercer$$($schema_addset_85948__$1$$):$coercer_fn_addset_85942_86549$$)($val_addset_85950__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addset_85941__$1$$,$val_addset_85950__$2$$)}catch($e86065$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86065$$)}}}});Object.defineProperty($obj_85850$$,"removeSet",{enumerable:!1,get:function(){var $internal_fn_removeset_85952__$1$$=function($token_set$jscomp$24$$){try{var $set_name$jscomp$33$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($token_set$jscomp$24$$,$APP.$cljs$cst$725$name$$),$theme$jscomp$40$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,$id$jscomp$1114$$);return $set_name$jscomp$33$$!=null&&$theme$jscomp$40$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1114$$,$app$common$types$tokens_lib$disable_set$$($theme$jscomp$40$$,$set_name$jscomp$33$$))):
null}catch($e86066$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86066$$)}}.bind(this);return function(){try{var $val_removeset_85957$$=Array.from(arguments),$val_removeset_85957__$1$$=$APP.$app$common$json$__GT_clj$$($val_removeset_85957$$,null),$schema_removeset_85955__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_removeset_85955_86552$$)?$schema_removeset_85955_86552$$($val_removeset_85957__$1$$):$schema_removeset_85955_86552$$,$val_removeset_85957__$2$$=($coercer_fn_removeset_85953_86553$$==
null?$APP.$app$common$schema$coercer$$($schema_removeset_85955__$1$$):$coercer_fn_removeset_85953_86553$$)($val_removeset_85957__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_removeset_85952__$1$$,$val_removeset_85957__$2$$)}catch($e86067$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86067$$)}}}});Object.defineProperty($obj_85850$$,"duplicate",{enumerable:!1,get:function(){return function(){try{var $theme$jscomp$41$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$477$$,
$id$jscomp$1114$$),$theme_SINGLEQUOTE_$jscomp$4$$=$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$clojure$datafy$datafy$$($theme$jscomp$41$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1737$modified_at$$]))]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$($theme_SINGLEQUOTE_$jscomp$4$$));
var $G__86071$$=$theme_SINGLEQUOTE_$jscomp$4$$.id;return $app$plugins$tokens$token_theme_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$tokens$token_theme_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$28$$,$file_id$jscomp$477$$,$G__86071$$):$app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$28$$,$file_id$jscomp$477$$,$G__86071$$)}catch($e86068$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86068$$)}}.bind(this)}});Object.defineProperty($obj_85850$$,
"remove",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($id$jscomp$1114$$))}catch($e86072$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$28$$)($e86072$$)}}.bind(this)}});return $obj_85850$$};var $app$plugins$shape$variant_proxy$$=null,$app$plugins$shape$lib_typography_proxy_QMARK_$$=null,$app$plugins$shape$lib_component_proxy$$=null,$app$plugins$shape$shape_proxy$$=function $app$plugins$shape$shape_proxy$$($var_args$jscomp$1513$$){switch(arguments.length){case 2:return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],
arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$=function($plugin_id$jscomp$31$$,$id$jscomp$1115$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$31$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$id$jscomp$1115$$)};
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$3$=function($plugin_id$jscomp$32$$,$page_id$jscomp$488$$,$id$jscomp$1116$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$32$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$488$$,$id$jscomp$1116$$)};
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$=function($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$){var $data$jscomp$532$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$G__86566$$=function(){var $G__86567$$=function(){var $G__86568$$=function(){var $G__86569$$=function(){var $obj_86571$$=new $APP.$app$util$object$Proxy$$,$schema_applytoken_87231_88855$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$shape$token_proxy_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_attr_QMARK_$$],null)],null)],null)],null)],null),$coercer_fn_applytoken_87229_88857$$=$schema_applytoken_87231_88855$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_applytoken_87231_88855$$)?
null:$APP.$app$common$schema$coercer$$($schema_applytoken_87231_88855$$);Object.defineProperty($obj_86571$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ShapeProxy"}});Object.defineProperty($obj_86571$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ShapeProxy"}});Object.defineProperty($obj_86571$$,"$plugin",{enumerable:!1,get:function(){try{return $plugin_id$jscomp$33$$}catch($e87263$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87263$$)}}});
Object.defineProperty($obj_86571$$,"$id",{enumerable:!1,get:function(){try{return $id$jscomp$1117$$}catch($e87264$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87264$$)}}});Object.defineProperty($obj_86571$$,"$file",{enumerable:!1,get:function(){try{return $file_id$jscomp$480$$}catch($e87265$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87265$$)}}});Object.defineProperty($obj_86571$$,"$page",{enumerable:!1,get:function(){try{return $page_id$jscomp$489$$}catch($e87266$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87266$$)}}});
Object.defineProperty($obj_86571$$,"id",{enumerable:!0,get:function(){try{return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87267$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87267$$)}}});Object.defineProperty($obj_86571$$,"type",{enumerable:!0,get:function(){try{return $app$plugins$format$shape_type$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87268$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87268$$)}}});
Object.defineProperty($obj_86571$$,"name",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87269$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87269$$)}},set:function($val_name_86636_value__$1$jscomp$inline_10342$$){try{var $id__$1$jscomp$inline_10341$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");if(typeof $val_name_86636_value__$1$jscomp$inline_10342$$===
"string"){var $path$jscomp$inline_13984$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($val_name_86636_value__$1$jscomp$inline_10342$$);var $JSCompiler_temp$jscomp$10780$$=$APP.$app$common$path_names$join_path$$($APP.$app$common$path_names$split_path$$($path$jscomp$inline_13984$$))}else $JSCompiler_temp$jscomp$10780$$=null;$val_name_86636_value__$1$jscomp$inline_10342$$=$JSCompiler_temp$jscomp$10780$$;var $valid_QMARK_$jscomp$inline_10343$$=$val_name_86636_value__$1$jscomp$inline_10342$$!=
null&&!$APP.$cuerdas$core$ends_with_QMARK_$$($val_name_86636_value__$1$jscomp$inline_10342$$,"/")&&!$APP.$cuerdas$core$blank_QMARK_$$($val_name_86636_value__$1$jscomp$inline_10342$$);return $app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$valid_QMARK_$jscomp$inline_10343$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$rename_shape_or_variant$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,
$id__$1$jscomp$inline_10341$$,$val_name_86636_value__$1$jscomp$inline_10342$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$725$name$$,$val_name_86636_value__$1$jscomp$inline_10342$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'content:write' permission")}catch($e87310$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87310$$)}}});Object.defineProperty($obj_86571$$,"blocked",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87311$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87311$$)}},
set:function($val_blocked_86644$$){try{return function($self$jscomp$174$$,$value$jscomp$1121$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1121$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$174$$,
"$id")],null),function($p1__86455_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86455_SHARP_$$,$APP.$cljs$cst$1623$blocked$$,$value$jscomp$1121$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1623$blocked$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1623$blocked$$,$value$jscomp$1121$$)}.call(this,this,$val_blocked_86644$$)}catch($e87312$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87312$$)}}});
Object.defineProperty($obj_86571$$,"hidden",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87323$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87323$$)}},set:function($val_hidden_86652$$){try{return function($self$jscomp$175$$,$value$jscomp$1122$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1122$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$175$$,"$id")],null),function($p1__86457_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86457_SHARP_$$,$APP.$cljs$cst$1620$hidden$$,
$value$jscomp$1122$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1620$hidden$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1620$hidden$$,$value$jscomp$1122$$)}.call(this,this,$val_hidden_86652$$)}catch($e87336$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87336$$)}}});Object.defineProperty($obj_86571$$,"visible",{enumerable:!0,get:function(){try{return!$APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87337$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87337$$)}},
set:function($val_visible_86660$$){try{return function($self$jscomp$176$$,$value$jscomp$1123$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1123$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$176$$,
"$id")],null),function($p1__86459_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86459_SHARP_$$,$APP.$cljs$cst$1620$hidden$$,$APP.$cljs$core$not$$($value$jscomp$1123$$))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$2346$visible$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$2346$visible$$,$value$jscomp$1123$$)}.call(this,this,$val_visible_86660$$)}catch($e87338$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87338$$)}}});
Object.defineProperty($obj_86571$$,"proportionLock",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1808$proportion_lock$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87339$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87339$$)}},set:function($val_proportionlock_86668$$){try{return function($self$jscomp$177$$,$value$jscomp$1124$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1124$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$177$$,"$id")],null),function($p1__86461_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86461_SHARP_$$,$APP.$cljs$cst$1808$proportion_lock$$,
$value$jscomp$1124$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6505$proportionLock$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6505$proportionLock$$,$value$jscomp$1124$$)}.call(this,this,$val_proportionlock_86668$$)}catch($e87340$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87340$$)}}});Object.defineProperty($obj_86571$$,"constraintsHorizontal",{enumerable:!0,get:function(){try{return $APP.$app$common$data$name$$($APP.$cljs$cst$1872$constraints_h$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87341$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87341$$)}},
set:function($val_constraintshorizontal_86676$$){try{return function($id__$1$jscomp$29_self$jscomp$178$$,$value$jscomp$1125$$){$id__$1$jscomp$29_self$jscomp$178$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$29_self$jscomp$178$$,"$id");var $value__$1$jscomp$114$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1125$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$horizontal_constraint_types$$,$value__$1$jscomp$114$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$29_self$jscomp$178$$],null),function($p1__86463_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86463_SHARP_$$,$APP.$cljs$cst$1872$constraints_h$$,
$value__$1$jscomp$114$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6506$constraintsHorizontal$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6506$constraintsHorizontal$$,$value__$1$jscomp$114$$)}.call(this,this,$val_constraintshorizontal_86676$$)}catch($e87342$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87342$$)}}});Object.defineProperty($obj_86571$$,"constraintsVertical",{enumerable:!0,
get:function(){try{return $APP.$app$common$data$name$$($APP.$cljs$cst$1871$constraints_v$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87343$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87343$$)}},set:function($val_constraintsvertical_86684$$){try{return function($id__$1$jscomp$30_self$jscomp$179$$,$value$jscomp$1126$$){$id__$1$jscomp$30_self$jscomp$179$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$30_self$jscomp$179$$,
"$id");var $value__$1$jscomp$115$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1126$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$vertical_constraint_types$$,$value__$1$jscomp$115$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$30_self$jscomp$179$$],null),function($p1__86465_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86465_SHARP_$$,$APP.$cljs$cst$1871$constraints_v$$,$value__$1$jscomp$115$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6507$constraintsVertical$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6507$constraintsVertical$$,
$value__$1$jscomp$115$$)}.call(this,this,$val_constraintsvertical_86684$$)}catch($e87344$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87344$$)}}});Object.defineProperty($obj_86571$$,"borderRadius",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87345$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87345$$)}},set:function($val_borderradius_86692$$){try{return function($id__$1$jscomp$31_self$jscomp$180$$,
$value$jscomp$1127$$){$id__$1$jscomp$31_self$jscomp$180$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$31_self$jscomp$180$$,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($value$jscomp$1127$$))||$value$jscomp$1127$$<0?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6508$borderRadius$$,$value$jscomp$1127$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$31_self$jscomp$180$$],null),function($p1__86467_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_all_corners$$($p1__86467_SHARP_$$,$value$jscomp$1127$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6508$borderRadius$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradius_86692$$)}catch($e87346$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87346$$)}}});
Object.defineProperty($obj_86571$$,"borderRadiusTopLeft",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87347$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87347$$)}},set:function($val_borderradiustopleft_86700$$){try{return function($id__$1$jscomp$32_self$jscomp$181$$,$value$jscomp$1128$$){$id__$1$jscomp$32_self$jscomp$181$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$32_self$jscomp$181$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($value$jscomp$1128$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6509$borderRadiusTopLeft$$,$value$jscomp$1128$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$32_self$jscomp$181$$],null),function($p1__86469_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__86469_SHARP_$$,$APP.$cljs$cst$1646$r1$$,$value$jscomp$1128$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6509$borderRadiusTopLeft$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiustopleft_86700$$)}catch($e87348$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87348$$)}}});
Object.defineProperty($obj_86571$$,"borderRadiusTopRight",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1647$r2$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87349$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87349$$)}},set:function($val_borderradiustopright_86708$$){try{return function($id__$1$jscomp$33_self$jscomp$182$$,$value$jscomp$1129$$){$id__$1$jscomp$33_self$jscomp$182$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$33_self$jscomp$182$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($value$jscomp$1129$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6510$borderRadiusTopRight$$,$value$jscomp$1129$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$33_self$jscomp$182$$],null),function($p1__86471_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__86471_SHARP_$$,$APP.$cljs$cst$1647$r2$$,$value$jscomp$1129$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6510$borderRadiusTopRight$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiustopright_86708$$)}catch($e87350$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87350$$)}}});
Object.defineProperty($obj_86571$$,"borderRadiusBottomRight",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1648$r3$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87351$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87351$$)}},set:function($val_borderradiusbottomright_86716$$){try{return function($id__$1$jscomp$34_self$jscomp$183$$,$value$jscomp$1130$$){$id__$1$jscomp$34_self$jscomp$183$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$34_self$jscomp$183$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($value$jscomp$1130$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6511$borderRadiusBottomRight$$,$value$jscomp$1130$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$34_self$jscomp$183$$],null),function($p1__86473_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__86473_SHARP_$$,$APP.$cljs$cst$1648$r3$$,$value$jscomp$1130$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6511$borderRadiusBottomRight$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiusbottomright_86716$$)}catch($e87352$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87352$$)}}});
Object.defineProperty($obj_86571$$,"borderRadiusBottomLeft",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1649$r4$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87353$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87353$$)}},set:function($val_borderradiusbottomleft_86724$$){try{return function($id__$1$jscomp$35_self$jscomp$184$$,$value$jscomp$1131$$){$id__$1$jscomp$35_self$jscomp$184$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$35_self$jscomp$184$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($value$jscomp$1131$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6512$borderRadiusBottomLeft$$,$value$jscomp$1131$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$35_self$jscomp$184$$],null),function($p1__86475_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__86475_SHARP_$$,$APP.$cljs$cst$1649$r4$$,$value$jscomp$1131$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6512$borderRadiusBottomLeft$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiusbottomleft_86724$$)}catch($e87354$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87354$$)}}});
Object.defineProperty($obj_86571$$,"opacity",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87355$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87355$$)}},set:function($val_opacity_86732$$){try{return function($id__$1$jscomp$36_self$jscomp$185$$,$value$jscomp$1132$$){$id__$1$jscomp$36_self$jscomp$185$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$36_self$jscomp$185$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1132$$))||$value$jscomp$1132$$<0||$value$jscomp$1132$$>1?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1734$opacity$$,$value$jscomp$1132$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$36_self$jscomp$185$$],null),function($p1__86477_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86477_SHARP_$$,$APP.$cljs$cst$1734$opacity$$,$value$jscomp$1132$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1734$opacity$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_opacity_86732$$)}catch($e87356$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87356$$)}}});
Object.defineProperty($obj_86571$$,"blendMode",{enumerable:!0,get:function(){try{return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1867$blend_mode$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$2023$normal$$))}catch($e87357$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87357$$)}},set:function($val_blendmode_86740$$){try{return function($id__$1$jscomp$37_self$jscomp$186$$,
$value$jscomp$1133$$){$id__$1$jscomp$37_self$jscomp$186$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$37_self$jscomp$186$$,"$id");var $value__$1$jscomp$116$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1133$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$blend_modes$$,$value__$1$jscomp$116$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$37_self$jscomp$186$$],null),function($p1__86479_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86479_SHARP_$$,$APP.$cljs$cst$1867$blend_mode$$,$value__$1$jscomp$116$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6513$blendMode$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6513$blendMode$$,$value__$1$jscomp$116$$)}.call(this,
this,$val_blendmode_86740$$)}catch($e87358$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87358$$)}}});Object.defineProperty($obj_86571$$,"shadows",{enumerable:!0,get:function(){try{var $shadows$jscomp$inline_13986$$=$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));return $shadows$jscomp$inline_13986$$!=null?$app$plugins$format$format_array$$($app$plugins$format$format_shadow$$,$shadows$jscomp$inline_13986$$):[]}catch($e87359$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87359$$)}},
set:function($val_shadows_86748$$){try{return function($id__$1$jscomp$38_self$jscomp$187$$,$value$jscomp$1134$$){$id__$1$jscomp$38_self$jscomp$187$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$38_self$jscomp$187$$,"$id");var $value__$1$jscomp$117$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$){$JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$=$JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$!=
null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"id")),$APP.$cljs$cst$1904$style$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"style")),$APP.$cljs$cst$1650$offset_x$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"offsetX"),$APP.$cljs$cst$1651$offset_y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"offsetY"),$APP.$cljs$cst$1653$blur$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"blur"),$APP.$cljs$cst$1652$spread$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,
"spread"),$APP.$cljs$cst$1620$hidden$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"hidden"),$APP.$cljs$cst$1298$color$$,$app$plugins$parser$parse_color$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$,"color"))],null)):null;return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,
$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1905$drop_shadow$$,$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,.2],null),$APP.$cljs$cst$1650$offset_x$$,4,$APP.$cljs$cst$1651$offset_y$$,4,$APP.$cljs$cst$1653$blur$$,4,$APP.$cljs$cst$1652$spread$$,0,$APP.$cljs$cst$1620$hidden$$,!1],null),$JSCompiler_inline_result$jscomp$2097_p1__86481_SHARP_$$)},$value$jscomp$1134$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$shape$shadow$schema_COLON_shadow$$],null),$value__$1$jscomp$117$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$4075$shadows$$,$value__$1$jscomp$117$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$38_self$jscomp$187$$],null),function($p1__86482_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86482_SHARP_$$,$APP.$cljs$cst$1654$shadow$$,$value__$1$jscomp$117$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$4075$shadows$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_shadows_86748$$)}catch($e87360$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87360$$)}}});
Object.defineProperty($obj_86571$$,"blur",{enumerable:!0,get:function(){try{var $p__83766$jscomp$inline_13988$$=$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$map__83767__$1$jscomp$inline_13989$$=$APP.$cljs$core$__destructure_map$$($p__83766$jscomp$inline_13988$$),$id$jscomp$inline_13990$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83767__$1$jscomp$inline_13989$$,$APP.$cljs$cst$266$id$$),$type$jscomp$inline_13991$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83767__$1$jscomp$inline_13989$$,
$APP.$cljs$cst$139$type$$),$value$jscomp$inline_13992$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83767__$1$jscomp$inline_13989$$,$APP.$cljs$cst$260$value$$),$hidden$jscomp$inline_13993$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83767__$1$jscomp$inline_13989$$,$APP.$cljs$cst$1620$hidden$$);return $map__83767__$1$jscomp$inline_13989$$!=null?$app$util$object$without_empty$$({id:$app$plugins$format$format_id$$($id$jscomp$inline_13990$$),type:$app$plugins$format$format_key$$($type$jscomp$inline_13991$$),
value:$value$jscomp$inline_13992$$,hidden:$hidden$jscomp$inline_13993$$}):null}catch($e87361$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87361$$)}},set:function($val_blur_86756$$){try{return function($id__$1$jscomp$39_self$jscomp$188$$,$value$jscomp$1135$$){if($value$jscomp$1135$$==null)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),function($p1__86484_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__86484_SHARP_$$,$APP.$cljs$cst$1653$blur$$)}));$id__$1$jscomp$39_self$jscomp$188$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$39_self$jscomp$188$$,"$id");var $value__$1$jscomp$118$$=$app$plugins$shape$blur_defaults$$($app$plugins$parser$parse_blur$$($value$jscomp$1135$$));return $APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$blur$schema_COLON_blur$$,
$value__$1$jscomp$118$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1653$blur$$,$value__$1$jscomp$118$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$39_self$jscomp$188$$],null),
function($p1__86485_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86485_SHARP_$$,$APP.$cljs$cst$1653$blur$$,$value__$1$jscomp$118$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1653$blur$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_blur_86756$$)}catch($e87362$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87362$$)}}});Object.defineProperty($obj_86571$$,"exports",{enumerable:!0,get:function(){try{var $exports$jscomp$inline_13995$$=
$APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));return $exports$jscomp$inline_13995$$!=null?$app$plugins$format$format_array$$($app$plugins$format$format_export$$,$exports$jscomp$inline_13995$$):null}catch($e87363$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87363$$)}},set:function($val_exports_86764$$){try{return function($id__$1$jscomp$40_self$jscomp$189$$,$value$jscomp$1136$$){$id__$1$jscomp$40_self$jscomp$189$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$40_self$jscomp$189$$,"$id");var $value__$1$jscomp$119$$=$app$plugins$parser$parse_exports$$($value$jscomp$1136$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$shape$export$0$schema_COLON_export$$],null),$value__$1$jscomp$119$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$1870$exports$$,$value__$1$jscomp$119$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$40_self$jscomp$189$$],null),function($p1__86487_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86487_SHARP_$$,
$APP.$cljs$cst$1870$exports$$,$value__$1$jscomp$119$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1870$exports$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_exports_86764$$)}catch($e87364$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87364$$)}}});Object.defineProperty($obj_86571$$,"x",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))))}catch($e87366$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87366$$)}},
set:function($val_x_86772$$){try{var $id__$1$jscomp$inline_10351$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_x_86772$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1510$x$$,$val_x_86772$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10351$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1510$x$$,$val_x_86772$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!0],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1510$x$$,"Plugin doesn't have 'content:write' permission")}catch($e87369$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87369$$)}}});Object.defineProperty($obj_86571$$,"y",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))))}catch($e87402$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87402$$)}},
set:function($val_y_86780$$){try{var $id__$1$jscomp$inline_10355$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_y_86780$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1511$y$$,$val_y_86780$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10355$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1511$y$$,$val_y_86780$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!0],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1511$y$$,"Plugin doesn't have 'content:write' permission")}catch($e87404$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87404$$)}}});Object.defineProperty($obj_86571$$,"parent",{enumerable:!1,get:function(){try{var $shape$jscomp$inline_10358$$=
$app$plugins$utils$proxy__GT_shape$$(this);if($APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$inline_10358$$))var $JSCompiler_inline_result$jscomp$2218$$=null;else{var $parent_id$jscomp$inline_10359$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10358$$);$JSCompiler_inline_result$jscomp$2218$$=$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$33$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10359$$)}return $JSCompiler_inline_result$jscomp$2218$$}catch($e87426$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87426$$)}}});Object.defineProperty($obj_86571$$,"parentIndex",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10362$$=$app$plugins$utils$proxy__GT_shape$$(this);if($APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$inline_10362$$))var $JSCompiler_inline_result$jscomp$2219$$=
0;else{var $parent$jscomp$inline_10363$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10362$$));$JSCompiler_inline_result$jscomp$2219$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10363$$),$id$jscomp$1117$$)}return $JSCompiler_inline_result$jscomp$2219$$}catch($e87427$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87427$$)}}});
Object.defineProperty($obj_86571$$,"parentX",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10366$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_x$jscomp$inline_10367$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10366$$))),$parent_id$jscomp$inline_10368$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10366$$),
$parent$jscomp$inline_10369$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10368$$);return $shape_x$jscomp$inline_10367$$-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10369$$)}catch($e87428$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87428$$)}},set:function($val_parentx_86802$$){try{if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_parentx_86802$$)))var $JSCompiler_inline_result$jscomp$2221$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6514$parentX$$,$val_parentx_86802$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $id__$1$jscomp$inline_10373$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$parent_id$jscomp$inline_10374$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$parent$jscomp$inline_10375$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10374$$),$parent_x$jscomp$inline_10376$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10375$$);$JSCompiler_inline_result$jscomp$2221$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10373$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1510$x$$,$parent_x$jscomp$inline_10376$$+$val_parentx_86802$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!0],null)))}else $JSCompiler_inline_result$jscomp$2221$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6514$parentX$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2221$$}catch($e87431$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87431$$)}}});
Object.defineProperty($obj_86571$$,"parentY",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10379$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_y$jscomp$inline_10380$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10379$$))),$parent_id$jscomp$inline_10381$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10379$$),
$parent$jscomp$inline_10382$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10381$$),$parent_y$jscomp$inline_10383$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10382$$);return $shape_y$jscomp$inline_10380$$-$parent_y$jscomp$inline_10383$$}catch($e87464$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87464$$)}},
set:function($val_parenty_86810$$){try{if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_parenty_86810$$)))var $JSCompiler_inline_result$jscomp$2223$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6515$parentY$$,$val_parenty_86810$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $id__$1$jscomp$inline_10387$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$parent_id$jscomp$inline_10388$$=
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$parent$jscomp$inline_10389$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10388$$),$parent_y$jscomp$inline_10390$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10389$$);$JSCompiler_inline_result$jscomp$2223$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10387$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1511$y$$,$parent_y$jscomp$inline_10390$$+$val_parenty_86810$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!0],null)))}else $JSCompiler_inline_result$jscomp$2223$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6515$parentY$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2223$$}catch($e87465$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87465$$)}}});Object.defineProperty($obj_86571$$,"boardX",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10393$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_x$jscomp$inline_10394$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10393$$))),
$frame_id$jscomp$inline_10395$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10393$$),$frame$jscomp$inline_10396$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$frame_id$jscomp$inline_10395$$),$frame_x$jscomp$inline_10397$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_10396$$);return $shape_x$jscomp$inline_10394$$-
$frame_x$jscomp$inline_10397$$}catch($e87466$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87466$$)}},set:function($val_boardx_86818$$){try{if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_boardx_86818$$)))var $JSCompiler_inline_result$jscomp$2225$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6516$frameX$$,$val_boardx_86818$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $id__$1$jscomp$inline_10401$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$frame_id$jscomp$inline_10402$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$frame$jscomp$inline_10403$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$frame_id$jscomp$inline_10402$$),$frame_x$jscomp$inline_10404$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_10403$$);
$JSCompiler_inline_result$jscomp$2225$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10401$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1510$x$$,$frame_x$jscomp$inline_10404$$+$val_boardx_86818$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!0],null)))}else $JSCompiler_inline_result$jscomp$2225$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6516$frameX$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2225$$}catch($e87467$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87467$$)}}});Object.defineProperty($obj_86571$$,"boardY",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10407$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_y$jscomp$inline_10408$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10407$$))),
$frame_id$jscomp$inline_10409$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10407$$),$frame$jscomp$inline_10410$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$frame_id$jscomp$inline_10409$$),$frame_y$jscomp$inline_10411$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_10410$$);return $shape_y$jscomp$inline_10408$$-
$frame_y$jscomp$inline_10411$$}catch($e87468$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87468$$)}},set:function($val_boardy_86826$$){try{if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_boardy_86826$$)))var $JSCompiler_inline_result$jscomp$2227$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6517$frameY$$,$val_boardy_86826$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $id__$1$jscomp$inline_10415$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$frame_id$jscomp$inline_10416$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$frame$jscomp$inline_10417$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$frame_id$jscomp$inline_10416$$),$frame_y$jscomp$inline_10418$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_10417$$);
$JSCompiler_inline_result$jscomp$2227$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10415$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1511$y$$,$frame_y$jscomp$inline_10418$$+$val_boardy_86826$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!0],null)))}else $JSCompiler_inline_result$jscomp$2227$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6517$frameY$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2227$$}catch($e87469$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87469$$)}}});Object.defineProperty($obj_86571$$,"width",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87470$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87470$$)}}});
Object.defineProperty($obj_86571$$,"height",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87471$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87471$$)}}});Object.defineProperty($obj_86571$$,"bounds",{enumerable:!0,get:function(){try{return $app$plugins$format$format_bounds$$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))))}catch($e87472$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87472$$)}}});
Object.defineProperty($obj_86571$$,"center",{enumerable:!0,get:function(){try{var $param49201$jscomp$inline_13997$$=$app$plugins$utils$proxy__GT_shape$$(this);var $JSCompiler_inline_result$jscomp$10778$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($param49201$jscomp$inline_13997$$);return $app$plugins$format$format_point$$($JSCompiler_inline_result$jscomp$10778$$)}catch($e87473$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87473$$)}}});Object.defineProperty($obj_86571$$,
"rotation",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e87474$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87474$$)}},set:function($val_rotation_86862$$){try{if(typeof $val_rotation_86862$$!=="number")var $JSCompiler_inline_result$jscomp$2228$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1788$rotation$$,$val_rotation_86862$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,
"content:write")){var $shape$jscomp$inline_10422$$=$app$plugins$utils$proxy__GT_shape$$(this);$JSCompiler_inline_result$jscomp$2228$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10422$$)]),$val_rotation_86862$$))}else $JSCompiler_inline_result$jscomp$2228$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$1788$rotation$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2228$$}catch($e87475$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87475$$)}}});Object.defineProperty($obj_86571$$,"flipX",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87476$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87476$$)}},
set:function($val_flipx_86870$$){try{return $APP.$cljs$core$boolean_QMARK_$$($val_flipx_86870$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id")]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6518$flipX$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6518$flipX$$,$val_flipx_86870$$)}catch($e87477$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87477$$)}}});Object.defineProperty($obj_86571$$,"flipY",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e87478$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87478$$)}},
set:function($val_flipy_86878$$){try{return $APP.$cljs$core$boolean_QMARK_$$($val_flipy_86878$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id")]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6519$flipY$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6519$flipY$$,$val_flipy_86878$$)}catch($e87479$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87479$$)}}});Object.defineProperty($obj_86571$$,"fills",{enumerable:!0,get:function(){try{if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)){var $JSCompiler_temp_const$jscomp$11094$$=$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$,
$shape$jscomp$inline_13999$$=$app$plugins$utils$proxy__GT_shape$$(this);var $JSCompiler_inline_result$jscomp$11096$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$inline_13999$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$inline_13999$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$inline_13999$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]));var $JSCompiler_temp$jscomp$11093$$=$app$plugins$format$format_fills$$($JSCompiler_temp_const$jscomp$11094$$.call($APP.$cljs$cst$1634$fills$$,
$JSCompiler_inline_result$jscomp$11096$$))}else $JSCompiler_temp$jscomp$11093$$=$app$plugins$format$format_fills$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)));return $JSCompiler_temp$jscomp$11093$$}catch($e87480$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87480$$)}},set:function($val_fills_86886$$){try{return function($self$jscomp$205_shape$jscomp$1138$$,$value$jscomp$1146$$){$self$jscomp$205_shape$jscomp$1138$$=
$app$plugins$utils$proxy__GT_shape$$($self$jscomp$205_shape$jscomp$1138$$);var $id__$1$jscomp$49$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self$jscomp$205_shape$jscomp$1138$$),$value__$1$jscomp$120$$=$app$plugins$parser$parse_fills$$($value$jscomp$1146$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$fills$schema_COLON_fill$$],
null),$value__$1$jscomp$120$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1634$fills$$,$value__$1$jscomp$120$$):$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($self$jscomp$205_shape$jscomp$1138$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id__$1$jscomp$49$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1634$fills$$,$value__$1$jscomp$120$$],null))):
$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$49$$],null),function($p1__86498_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86498_SHARP_$$,$APP.$cljs$cst$1634$fills$$,$value__$1$jscomp$120$$)})):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1634$fills$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_fills_86886$$)}catch($e87481$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87481$$)}}});Object.defineProperty($obj_86571$$,"strokes",{enumerable:!0,get:function(){try{var $strokes$jscomp$inline_14001$$=$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));return $strokes$jscomp$inline_14001$$!=
null?$app$plugins$format$format_array$$($app$plugins$format$format_stroke$$,$strokes$jscomp$inline_14001$$):null}catch($e87482$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87482$$)}},set:function($val_strokes_86894$$){try{return function($id__$1$jscomp$50_self$jscomp$206$$,$value$jscomp$1147$$){$id__$1$jscomp$50_self$jscomp$206$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$50_self$jscomp$206$$,"$id");var $value__$1$jscomp$121$$=$app$plugins$parser$parse_strokes$$($value$jscomp$1147$$);
return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$shape$schema_COLON_stroke$$],null),$value__$1$jscomp$121$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1636$strokes$$,$value__$1$jscomp$121$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$50_self$jscomp$206$$],null),function($p1__86500_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86500_SHARP_$$,$APP.$cljs$cst$1636$strokes$$,$value__$1$jscomp$121$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1636$strokes$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_strokes_86894$$)}catch($e87483$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87483$$)}}});
Object.defineProperty($obj_86571$$,"layoutChild",{enumerable:!0,get:function(){try{var $file_id__$1$jscomp$inline_10431$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10432$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$id__$1$jscomp$inline_10433$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$objects$jscomp$inline_10434$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id__$1$jscomp$inline_10431$$,
$page_id__$1$jscomp$inline_10432$$);return $APP.$app$common$types$shape$layout$any_layout_immediate_child_id_QMARK_$$($objects$jscomp$inline_10434$$,$id__$1$jscomp$inline_10433$$)?$app$plugins$flex$layout_child_proxy$$($plugin_id$jscomp$33$$,$file_id__$1$jscomp$inline_10431$$,$page_id__$1$jscomp$inline_10432$$,$id__$1$jscomp$inline_10433$$):null}catch($e87484$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87484$$)}}});Object.defineProperty($obj_86571$$,"layoutCell",{enumerable:!0,
get:function(){try{var $file_id__$1$jscomp$inline_10437$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10438$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$id__$1$jscomp$inline_10439$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$objects$jscomp$inline_14003$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id__$1$jscomp$inline_10437$$,$page_id__$1$jscomp$inline_10438$$),
$parent_id$jscomp$inline_14005$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_14003$$,$id__$1$jscomp$inline_10439$$),$APP.$cljs$cst$1619$parent_id$$),$parent$jscomp$inline_14006$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_14003$$,$parent_id$jscomp$inline_14005$$);return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_14006$$)?
$app$plugins$grid$layout_cell_proxy$$($plugin_id$jscomp$33$$,$file_id__$1$jscomp$inline_10437$$,$page_id__$1$jscomp$inline_10438$$,$id__$1$jscomp$inline_10439$$):null}catch($e87485$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87485$$)}}});Object.defineProperty($obj_86571$$,"interactions",{enumerable:!0,get:function(){function $internal_fn_interactions_86911$$($interactions$jscomp$25_self$jscomp$209$$){$interactions$jscomp$25_self$jscomp$209$$=$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($interactions$jscomp$25_self$jscomp$209$$));
return $app$plugins$format$format_array$$(function($p1__86501_SHARP_$$){return $app$plugins$shape$interaction_proxy$$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$,$p1__86501_SHARP_$$)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(0,$APP.$cljs$core$count$$($interactions$jscomp$25_self$jscomp$209$$)))}try{return $internal_fn_interactions_86911$$.call(this,this)}catch($e87486$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87486$$)}}});
Object.defineProperty($obj_86571$$,"resize",{enumerable:!1,get:function(){return function($width$jscomp$262$$,$height$jscomp$227$$){try{return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($width$jscomp$262$$))||$width$jscomp$262$$<=0?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1799$resize$$,$width$jscomp$262$$):$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($height$jscomp$227$$))||$height$jscomp$227$$<=0?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$1799$resize$$,$height$jscomp$227$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),$APP.$cljs$cst$290$width$$,$width$jscomp$262$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),$APP.$cljs$cst$1522$height$$,$height$jscomp$227$$)])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1799$resize$$,"Plugin doesn't have 'content:write' permission")}catch($e87487$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87487$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"rotate",{enumerable:!1,get:function(){return function($angle$jscomp$44$$,$center$jscomp$57$$){try{var $center__$1$jscomp$6$$=
$APP.$cljs$core$truth_$$($center$jscomp$57$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($center$jscomp$57$$,"x"),$APP.$cljs$cst$1511$y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($center$jscomp$57$$,"y")],null):null;return typeof $angle$jscomp$44$$!=="number"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6520$rotate_angle$$,$angle$jscomp$44$$):$center__$1$jscomp$6$$==
null||typeof $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($center__$1$jscomp$6$$)==="number"&&typeof $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center__$1$jscomp$6$$)==="number"?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$increase_rotation$$)(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],
null),$angle$jscomp$44$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1667$center$$,$center__$1$jscomp$6$$,$APP.$cljs$cst$3844$delta_QMARK_$$,!0],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$2863$rotate$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6521$rotate_center$$,$center__$1$jscomp$6$$)}catch($e87488$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87488$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"clone",{enumerable:!1,get:function(){return function(){try{var $ret_v$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);return $app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$duplicate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1117$$]),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3617$change_selection_QMARK_$$,!1,$APP.$cljs$cst$3618$return_ref$$,$ret_v$jscomp$1$$]))),$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$33$$,$APP.$cljs$core$_deref$$($ret_v$jscomp$1$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6522$clone$$,"Plugin doesn't have 'content:write' permission")}catch($e87489$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87489$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"remove",{enumerable:!1,get:function(){return function(){try{return $app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1117$$]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'content:write' permission")}catch($e87490$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87490$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$436$$){try{if(typeof $key$jscomp$436$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6523$getPluginData$$,$key$jscomp$436$$);var $shape$jscomp$1139$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1139$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$33$$))),$key$jscomp$436$$)}catch($e87491$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87491$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$437$$,$value$jscomp$1148$$){try{return typeof $key$jscomp$437$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6524$setPluginData_key$$,$key$jscomp$437$$):$value$jscomp$1148$$!=null&&typeof $value$jscomp$1148$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6525$setPluginData_value$$,$value$jscomp$1148$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$480$$,$APP.$cljs$cst$1811$shape$$,
$id$jscomp$1117$$,$page_id$jscomp$489$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$33$$)),$key$jscomp$437$$,$value$jscomp$1148$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6526$setPluginData$$,"Plugin doesn't have 'content:write' permission")}catch($e87492$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87492$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,
"getPluginDataKeys",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1140$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1140$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$33$$)))))}catch($e87493$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87493$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$18$$,$key$jscomp$438$$){try{if(typeof $namespace$jscomp$18$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6527$getSharedPluginData_namespace$$,$namespace$jscomp$18$$);
if(typeof $key$jscomp$438$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6528$getSharedPluginData_key$$,$key$jscomp$438$$);var $shape$jscomp$1141$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1141$$,$APP.$cljs$cst$1738$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$18$$)),$key$jscomp$438$$)}catch($e87494$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87494$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$19$$,$key$jscomp$439$$,$value$jscomp$1149$$){try{return typeof $namespace$jscomp$19$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6529$setSharedPluginData_namespace$$,
$namespace$jscomp$19$$):typeof $key$jscomp$439$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6530$setSharedPluginData_key$$,$key$jscomp$439$$):$value$jscomp$1149$$!=null&&typeof $value$jscomp$1149$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1149$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$480$$,
$APP.$cljs$cst$1811$shape$$,$id$jscomp$1117$$,$page_id$jscomp$489$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$19$$),$key$jscomp$439$$,$value$jscomp$1149$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6532$setSharedPluginData$$,"Plugin doesn't have 'content:write' permission")}catch($e87495$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87495$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"getSharedPluginDataKeys",
{enumerable:!1,get:function(){return function($namespace$jscomp$20$$){try{if(typeof $namespace$jscomp$20$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6533$getSharedPluginDataKeys$$,$namespace$jscomp$20$$);var $shape$jscomp$1142$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1142$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$20$$))))}catch($e87496$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87496$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"getChildren",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1143$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1143$$)||
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1143$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1143$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1143$$)){var $is_reversed_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1143$$),$reverse_fn$$=$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$33$$)&&
$is_reversed_QMARK_$$?$APP.$cljs$core$reverse$$:$APP.$cljs$core$identity$$;return $app$plugins$format$format_array$$(function($p1__86502_SHARP_$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$page_id$jscomp$489$$,$p1__86502_SHARP_$$)},function(){var $G__87498$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$));return $reverse_fn$$.$cljs$core$IFn$_invoke$arity$1$?
$reverse_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__87498$$):$reverse_fn$$($G__87498$$)}())}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6534$getChildren$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1143$$))}catch($e87497$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87497$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"appendChild",{enumerable:!1,get:function(){return function($child$jscomp$127$$){try{var $shape$jscomp$1144$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1144$$)){if($app$plugins$shape$shape_proxy_QMARK_$$($child$jscomp$127$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,
"content:write")){var $child_id$jscomp$14$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$127$$,"$id"),$child_shape$jscomp$2$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$child_id$jscomp$14$$),$is_reversed_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$),$index$jscomp$609$$=!$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$33$$)||$is_reversed_QMARK_$jscomp$1$$?
0:$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child_id$jscomp$14$$]),$id$jscomp$1117$$,$index$jscomp$609$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$)?"add-layout-element":"add-element",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($child_shape$jscomp$2$$),$APP.$cljs$cst$3622$parent_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$)]))]))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6413$appendChild$$,
"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6453$appendChild_child$$,$child$jscomp$127$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6413$appendChild$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1144$$))}catch($e87499$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87499$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"insertChild",{enumerable:!1,
get:function(){return function($index$jscomp$610$$,$child$jscomp$128$$){try{var $shape$jscomp$1145$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$)||
$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1145$$)){if($app$plugins$shape$shape_proxy_QMARK_$$($child$jscomp$128$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $child_id$jscomp$15$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$128$$,"$id"),$child_shape$jscomp$3$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$child_id$jscomp$15$$),$is_reversed_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$),
$index__$1$jscomp$26$$=!$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$33$$)||$is_reversed_QMARK_$jscomp$2$$?$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$))-$index$jscomp$610$$:$index$jscomp$610$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child_id$jscomp$15$$]),$id$jscomp$1117$$,
$index__$1$jscomp$26$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$)?"add-layout-element":"add-element",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($child_shape$jscomp$3$$),
$APP.$cljs$cst$3622$parent_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$)]))]))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6535$insertChild$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6536$insertChild_child$$,$child$jscomp$128$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6535$insertChild$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1145$$))}catch($e87500$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87500$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"addFlexLayout",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1146$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1146$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$1117$$,
$APP.$cljs$cst$1660$flex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4395$from_frame_QMARK_$$,!0,$APP.$cljs$cst$4396$calculate_params_QMARK_$$,!1])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,"create-shape-layout",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,"flex"]))])),$app$plugins$flex$flex_layout_proxy$$($plugin_id$jscomp$33$$,
$file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6537$addFlexLayout$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6537$addFlexLayout$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1146$$))}catch($e87501$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87501$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,
"addGridLayout",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1147$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1147$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$1117$$,
$APP.$cljs$cst$1659$grid$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4395$from_frame_QMARK_$$,!0,$APP.$cljs$cst$4396$calculate_params_QMARK_$$,!1]))),$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,"create-shape-layout",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,"grid"])),$app$plugins$grid$grid_layout_proxy$$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$page_id$jscomp$489$$,
$id$jscomp$1117$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6538$addGridLayout$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6538$addGridLayout$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1147$$))}catch($e87502$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87502$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"makeMask",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1148$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1148$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1117$$])),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,"mask"]))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6539$makeMask$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6539$makeMask$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1148$$))}catch($e87503$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87503$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"removeMask",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1149$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1149$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1117$$]))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6540$removeMask$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6540$removeMask$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1149$$))}catch($e87504$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87504$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"toD",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1150$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1150$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1150$$)?$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1150$$).toString():$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6541$toD$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1150$$))}catch($e87505$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87505$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"getRange",{enumerable:!1,get:function(){return function($start$jscomp$258$$,$end$jscomp$114$$){try{var $shape$jscomp$1151$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1151$$)?$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($start$jscomp$258$$))||$start$jscomp$258$$<0||$start$jscomp$258$$>
$end$jscomp$114$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6543$getRange_start$$,$start$jscomp$258$$):$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($end$jscomp$114$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6544$getRange_end$$,$end$jscomp$114$$):$app$plugins$text$text_range_proxy$$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$,$start$jscomp$258$$,$end$jscomp$114$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6542$getRange_shape$$,"shape is not text")}catch($e87506$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87506$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"applyTypography",{enumerable:!1,get:function(){return function($typography$jscomp$42$$){try{var $shape$jscomp$1152$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$cljs$core$not$$($app$plugins$shape$lib_typography_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$app$plugins$shape$lib_typography_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$42$$):$app$plugins$shape$lib_typography_proxy_QMARK_$$($typography$jscomp$42$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6545$applyTypography_typography$$,$typography$jscomp$42$$);if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1152$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $typography__$1$jscomp$6$$=
$app$plugins$utils$proxy__GT_library_typography$$($typography$jscomp$42$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1117$$]),$typography__$1$jscomp$6$$,$file_id$jscomp$480$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6547$applyTypography$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6546$applyTypography_shape$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1152$$))}catch($e87507$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87507$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"setParentIndex",{enumerable:!1,get:function(){return function($index$jscomp$611$$){try{return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$611$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6548$setParentIndex$$,$index$jscomp$611$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_shape_index$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$,$index$jscomp$611$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6548$setParentIndex$$,"Plugin doesn't have 'content:write' permission")}catch($e87508$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87508$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"bringForward",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1954$up$$))}catch($e87509$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87509$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"sendBackward",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1953$down$$))}catch($e87510$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87510$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"bringToFront",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1562$top$$))}catch($e87511$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87511$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"sendToBack",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1563$bottom$$))}catch($e87512$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87512$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"isComponentInstance",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1153$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$objects$jscomp$856$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$);return $APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$856$$,$shape$jscomp$1153$$)}catch($e87513$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87513$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"isComponentMainInstance",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1154$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$objects$jscomp$857$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$);return $APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$857$$,$shape$jscomp$1154$$,
!0)!=null}catch($e87514$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87514$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"isComponentCopyInstance",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1155$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$1155$$)}catch($e87515$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87515$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"isComponentRoot",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1156$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$types$component$instance_root_QMARK_$$($shape$jscomp$1156$$)}catch($e87516$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87516$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"isComponentHead",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1157$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$1157$$)}catch($e87517$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87517$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"componentRefShape",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$858$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,
$page_id$jscomp$489$$),$shape$jscomp$1158$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$858$$,$shape$jscomp$1158$$))){var $vec__87519$$=$app$plugins$utils$locate_component$$($objects$jscomp$858$$,$shape$jscomp$1158$$),$root$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__87519$$,0,null),$component$jscomp$139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__87519$$,
1,null),$component_page_id$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$139$$),$component_file$jscomp$8$$=$app$plugins$utils$locate_file$$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$69$$)),$ref_shape$jscomp$9$$=$APP.$app$common$types$file$get_ref_shape$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$8$$),$component$jscomp$139$$,$shape$jscomp$1158$$);return $APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$139$$))&&
$ref_shape$jscomp$9$$!=null&&$component_file$jscomp$8$$!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$33$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$8$$),$component_page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$9$$)):null}return null}catch($e87518$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87518$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"componentRoot",
{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$859$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$),$shape$jscomp$1159$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$859$$,$shape$jscomp$1159$$))){var $vec__87523$$=$app$plugins$utils$locate_component$$($objects$jscomp$859$$,
$shape$jscomp$1159$$),$root$jscomp$70$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__87523$$,0,null),$component$jscomp$140$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__87523$$,1,null);return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$70$$),$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$140$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$70$$))}return null}catch($e87522$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87522$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"componentHead",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$860$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$),$shape$jscomp$1160$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,
$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$860$$,$shape$jscomp$1160$$))){var $head$jscomp$30$$=$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$),$shape$jscomp$1160$$);return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$33$$,
$file_id$jscomp$480$$,$page_id$jscomp$489$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$30$$))}return null}catch($e87526$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87526$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"component",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$861$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$),$shape$jscomp$1161$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$861$$,$shape$jscomp$1161$$))){var $state$jscomp$inline_10444$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file$jscomp$inline_10445$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$inline_10444$$),$libraries$jscomp$inline_10446$$=$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$inline_10444$$),
$head$jscomp$inline_10447$$=$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$861$$,$shape$jscomp$1161$$);var $temp__5825__auto__$jscomp$465$$=$APP.$cljs$core$truth_$$($head$jscomp$inline_10447$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$head$jscomp$inline_10447$$,$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($head$jscomp$inline_10447$$,$file$jscomp$inline_10445$$,
$libraries$jscomp$inline_10446$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]))],null):null;if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$465$$)){var $head$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$465$$,0,null),$component$jscomp$141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$465$$,
1,null),$G__87532$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$31$$),$G__87533$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$141$$);return $app$plugins$shape$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$shape$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$33$$,$G__87532$$,$G__87533$$):$app$plugins$shape$lib_component_proxy$$($plugin_id$jscomp$33$$,$G__87532$$,$G__87533$$)}}return null}catch($e87527$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87527$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"detach",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$detach_component$$($id$jscomp$1117$$))}catch($e87534$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87534$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"export",{enumerable:!1,get:function(){return function($value$jscomp$1150$$){try{var $value__$1$jscomp$122$$=
$app$plugins$parser$parse_export$$($value$jscomp$1150$$);if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$export$0$schema_COLON_export$$,$value__$1$jscomp$122$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$2177$export$$,$value__$1$jscomp$122$$);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4124$wasm_export$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1534$png$$,null,$APP.$cljs$cst$1536$webp$$,null,$APP.$cljs$cst$1535$jpeg$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$122$$,$APP.$cljs$cst$1534$png$$))){var $uri$jscomp$115$$=$APP.$app$main$data$exports$wasm$export_image_uri$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$480$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$489$$,$APP.$cljs$cst$2272$object_id$$,
$id$jscomp$1117$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$122$$,$APP.$cljs$cst$1534$png$$),$APP.$cljs$cst$1902$scale$$,$APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$122$$,1)],null));return new Promise(function($resolve$jscomp$42$$,$reject$jscomp$29$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$42$$,$reject$jscomp$29$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,
"export-shapes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1578$method$$,"wasm"])))},$APP.$beicon$v2$core$map$$(function($p1__86504_SHARP_$$){return new Uint8Array($p1__86504_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__86503_SHARP_$$){return $p1__86503_SHARP_$$.arrayBuffer()},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,
$APP.$cljs$cst$1579$uri$$,$uri$jscomp$115$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$,$APP.$cljs$cst$1582$omit_default_headers$$,!0],null)))))))})}var $shape$jscomp$1162$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$payload$jscomp$18$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$4125$export_shapes$$,$APP.$cljs$cst$2313$profile_id$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$APP.$cljs$cst$2281$wait$$,!0,$APP.$cljs$cst$4771$is_wasm$$,!1,$APP.$cljs$cst$1870$exports$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$480$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$489$$,$APP.$cljs$cst$2272$object_id$$,$id$jscomp$1117$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1162$$),$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$122$$,$APP.$cljs$cst$1534$png$$),$APP.$cljs$cst$1371$suffix$$,$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$122$$,""),$APP.$cljs$cst$1902$scale$$,$APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$122$$,1)],null)],null)],null);return new Promise(function($resolve$jscomp$43$$,$reject$jscomp$30$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$43$$,
$reject$jscomp$30$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$33$$,"export-shapes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1578$method$$,"exporter"])))},$APP.$beicon$v2$core$map$$(function($p1__86506_SHARP_$$){return new Uint8Array($p1__86506_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__86505_SHARP_$$){return $p1__86505_SHARP_$$.arrayBuffer()},
$APP.$beicon$v2$core$mapcat$$(function($map__87537__$1_p__87536_uri$jscomp$116$$){$map__87537__$1_p__87536_uri$jscomp$116$$=$APP.$cljs$core$__destructure_map$$($map__87537__$1_p__87536_uri$jscomp$116$$);$map__87537__$1_p__87536_uri$jscomp$116$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__87537__$1_p__87536_uri$jscomp$116$$,$APP.$cljs$cst$1579$uri$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$map__87537__$1_p__87536_uri$jscomp$116$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$,$APP.$cljs$cst$1582$omit_default_headers$$,!0],null)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2177$export$$,$payload$jscomp$18$$))))))})}catch($e87535$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87535$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,
"addInteraction",{enumerable:!1,get:function(){return function($trigger$jscomp$7$$,$action$jscomp$11$$,$delay$jscomp$10$$){try{var $JSCompiler_temp_const$jscomp$2099$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$;if(typeof $trigger$jscomp$7$$==="string"&&$action$jscomp$11$$!=null){var $trigger__$1$jscomp$inline_10452$$=$app$plugins$parser$parse_keyword$$($trigger$jscomp$7$$),$action__$1$jscomp$inline_10453$$=$app$plugins$parser$parse_action$$($action$jscomp$11$$);var $JSCompiler_inline_result$jscomp$2101$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1557$event_type$$,$trigger__$1$jscomp$inline_10452$$,$APP.$cljs$cst$1325$delay$$,$delay$jscomp$10$$],null),$action__$1$jscomp$inline_10453$$))}else $JSCompiler_inline_result$jscomp$2101$$=null;var $interaction$jscomp$58$$=$JSCompiler_temp_const$jscomp$2099$$.call($APP.$app$common$data$patch_object$$,
$APP.$app$common$types$shape$interactions$default_interaction$$,$JSCompiler_inline_result$jscomp$2101$$);if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$interactions$schema_COLON_interaction$$,$interaction$jscomp$58$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6549$addInteraction$$,$interaction$jscomp$58$$);var $index$jscomp$612$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,
$page_id$jscomp$489$$,$id$jscomp$1117$$),$APP.$cljs$core$PersistentVector$EMPTY$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$interactions$add_interaction$$($page_id$jscomp$489$$,$id$jscomp$1117$$,$interaction$jscomp$58$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$33$$,"add-interaction")]));return $app$plugins$shape$interaction_proxy$$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,
$page_id$jscomp$489$$,$id$jscomp$1117$$,$index$jscomp$612$$)}catch($e87538$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87538$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"removeInteraction",{enumerable:!1,get:function(){return function($interaction$jscomp$59$$){try{if($app$util$object$type_of_QMARK_$$($interaction$jscomp$59$$,"InteractionProxy")){var $JSCompiler_temp_const$jscomp$1270$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$1272$$=
$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1117$$],null),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($interaction$jscomp$59$$,"$index"));var $JSCompiler_temp$jscomp$1269$$=$JSCompiler_temp_const$jscomp$1270$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1272$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$33$$,
"remove-interaction")]))}else $JSCompiler_temp$jscomp$1269$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6550$removeInteraction$$,$interaction$jscomp$59$$);return $JSCompiler_temp$jscomp$1269$$}catch($e87539$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87539$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"addRulerGuide",{enumerable:!1,get:function(){return function($orientation$jscomp$9$$,$value$jscomp$1151$$){try{var $shape$jscomp$1163$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,
$page_id$jscomp$489$$,$id$jscomp$1117$$);if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1151$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6551$addRulerGuide$$,"Value not a safe number");if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["vertical",null,"horizontal",null],null),null),$orientation$jscomp$9$$)){if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1163$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,
"content:write")){var $ruler_id$jscomp$2$$=$APP.$app$common$uuid$next$$(),$axis$jscomp$61$$=$app$plugins$parser$orientation__GT_axis$$($orientation$jscomp$9$$),$objects$jscomp$862$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$480$$,$page_id$jscomp$489$$),$frame$jscomp$119$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$862$$,$id$jscomp$1117$$),$position$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$119$$,
$axis$jscomp$61$$)+$value$jscomp$1151$$;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$ruler_id$jscomp$2$$,$APP.$cljs$cst$2054$axis$$,$axis$jscomp$61$$,$APP.$cljs$cst$1676$position$$,$position$jscomp$248$$,$APP.$cljs$cst$1607$frame_id$$,$id$jscomp$1117$$],null)),$plugin_id$jscomp$33$$));return $app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$33$$,
$file_id$jscomp$480$$,$page_id$jscomp$489$$,$ruler_id$jscomp$2$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6551$addRulerGuide$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6551$addRulerGuide$$,"The shape is not a board")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6551$addRulerGuide$$,"Orientation should be either 'vertical' or 'horizontal'")}catch($e87540$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87540$$)}}.bind(this)}});
Object.defineProperty($obj_86571$$,"removeRulerGuide",{enumerable:!1,get:function(){return function($_$jscomp$3271$$,$value$jscomp$1152$$){try{if($app$util$object$type_of_QMARK_$$($value$jscomp$1152$$,"RulerGuideProxy")){if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){var $guide$jscomp$31$$=$app$plugins$utils$proxy__GT_ruler_guide$$($value$jscomp$1152$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$31$$),
$plugin_id$jscomp$33$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6552$removeRulerGuide$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6552$removeRulerGuide$$,"Guide not provided")}catch($e87541$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87541$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"tokens",{enumerable:!0,get:function(){function $internal_fn_tokens_87221$$(){var $applied_tokens$jscomp$36$$=
$app$plugins$tokens$applied_tokens_plugin__GT_applied_tokens$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$APP.$cljs$cst$1873$applied_tokens$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$171$$,$name$jscomp$515_p__87542$$){var $prop$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$515_p__87542$$,0,null);$name$jscomp$515_p__87542$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$515_p__87542$$,1,null);return $APP.$app$util$object$set_BANG_$$($acc$jscomp$171$$,$APP.$app$common$json$write_camel_key$$($prop$jscomp$46$$),$name$jscomp$515_p__87542$$)},{},$applied_tokens$jscomp$36$$)}try{return $internal_fn_tokens_87221$$.call(this,this)}catch($e87546$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87546$$)}}});Object.defineProperty($obj_86571$$,"applyToken",{enumerable:!1,get:function(){var $internal_fn_applytoken_87228__$1$$=
function($token$jscomp$219$$,$attrs$jscomp$194$$){try{var $token__$1$jscomp$7$$=$app$plugins$utils$locate_token$$($file_id$jscomp$480$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$219$$,"$set-id"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$219$$,"$id")),$kw_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$tokens$token_attr_plugin__GT_token_attr$$,
$attrs$jscomp$194$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__86507_SHARP_$$){return!$app$plugins$tokens$token_attr_QMARK_$$($p1__86507_SHARP_$$)},$kw_attrs$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6553$applyToken$$,$attrs$jscomp$194$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1136$token$$,$token__$1$jscomp$7$$,$APP.$cljs$cst$2645$attrs$$,$kw_attrs$$,$APP.$cljs$cst$4641$shape_ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),$APP.$cljs$cst$4653$expand_with_children$$,!1],null)),$plugin_id$jscomp$33$$))}catch($e87547$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87547$$)}}.bind(this);return function(){try{var $val_applytoken_87233$$=Array.from(arguments),
$val_applytoken_87233__$1$$=$APP.$app$common$json$__GT_clj$$($val_applytoken_87233$$,null),$schema_applytoken_87231__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_applytoken_87231_88855$$)?$schema_applytoken_87231_88855$$($val_applytoken_87233__$1$$):$schema_applytoken_87231_88855$$,$val_applytoken_87233__$2$$=($coercer_fn_applytoken_87229_88857$$==null?$APP.$app$common$schema$coercer$$($schema_applytoken_87231__$1$$):$coercer_fn_applytoken_87229_88857$$)($val_applytoken_87233__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_applytoken_87228__$1$$,
$val_applytoken_87233__$2$$)}catch($e87548$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87548$$)}}}});Object.defineProperty($obj_86571$$,"isVariantHead",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1164$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$component$jscomp$142$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$480$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1164$$));
return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$1164$$)&&$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$142$$)}catch($e87549$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87549$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"isVariantContainer",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1165$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$);
return $APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1165$$)}catch($e87550$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87550$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"switchVariant",{enumerable:!1,get:function(){return function($pos$jscomp$164$$,$value$jscomp$1153$$){try{if($APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$164$$)){if(typeof $value$jscomp$1153$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$260$value$$,$value$jscomp$1153$$);var $shape$jscomp$1166$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,$page_id$jscomp$489$$,$id$jscomp$1117$$),$component$jscomp$143$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$480$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1166$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$143$$)?$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$143$$):
$component$jscomp$143$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$variants$variants_switch$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1166$$],null),$APP.$cljs$cst$1406$pos$$,$pos$jscomp$164$$,$APP.$cljs$cst$108$val$$,$value$jscomp$1153$$],null)),$plugin_id$jscomp$33$$)):
null}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1406$pos$$,$pos$jscomp$164$$)}catch($e87551$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87551$$)}}.bind(this)}});Object.defineProperty($obj_86571$$,"combineAsVariants",{enumerable:!1,get:function(){return function($ids$jscomp$322$$){try{if($APP.$cljs$core$not$$($APP.$cljs$core$seq$$($ids$jscomp$322$$))||!$APP.$cljs$core$every_QMARK_$$($APP.$app$common$uuid$parse_STAR_$$,$ids$jscomp$322$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$1723$ids$$,$ids$jscomp$322$$);var $ids__$1$jscomp$33$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1117$$]),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$uuid$parse_STAR_$$),$id$jscomp$1117$$);if($APP.$cljs$core$every_QMARK_$$(function($component$jscomp$144_id__$1$jscomp$53_shape$jscomp$1167$$){$component$jscomp$144_id__$1$jscomp$53_shape$jscomp$1167$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$480$$,
$page_id$jscomp$489$$,$component$jscomp$144_id__$1$jscomp$53_shape$jscomp$1167$$);$component$jscomp$144_id__$1$jscomp$53_shape$jscomp$1167$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$480$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$144_id__$1$jscomp$53_shape$jscomp$1167$$));return!$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$144_id__$1$jscomp$53_shape$jscomp$1167$$)},$ids__$1$jscomp$33$$)){var $variant_id$jscomp$55$$=
$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids__$1$jscomp$33$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4424$trigger$$,"plugin:combine-as-variants",$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$55$$],null)),$plugin_id$jscomp$33$$));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$33$$,
$variant_id$jscomp$55$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1723$ids$$,"One of the components is not on the same page or is already a variant")}catch($e87552$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$33$$)($e87552$$)}}.bind(this)}});return $obj_86571$$}();if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||
$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($data$jscomp$532$$)){var $set_fn87736_91581$$=function($page_id__$1$jscomp$35_self$jscomp$211$$,$children$jscomp$323_ids$jscomp$323$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){if($APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$children$jscomp$323_ids$jscomp$323$$)){var $shape$jscomp$1168$$=
$app$plugins$utils$proxy__GT_shape$$($page_id__$1$jscomp$35_self$jscomp$211$$),$file_id__$1$jscomp$17$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page_id__$1$jscomp$35_self$jscomp$211$$,"$file");$page_id__$1$jscomp$35_self$jscomp$211$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page_id__$1$jscomp$35_self$jscomp$211$$,"$page");var $reverse_fn$jscomp$1$$=$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$33$$)?$APP.$cljs$core$reverse$$:$APP.$cljs$core$identity$$;
$children$jscomp$323_ids$jscomp$323$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86508_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__86508_SHARP_$$,"$id")},$reverse_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$reverse_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$323_ids$jscomp$323$$):$reverse_fn$jscomp$1$$($children$jscomp$323_ids$jscomp$323$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($children$jscomp$323_ids$jscomp$323$$),
$APP.$cljs$core$set$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1168$$)))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$342$children$$,"Not all children are present in the input"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$reorder_children$$($file_id__$1$jscomp$17$$,$page_id__$1$jscomp$35_self$jscomp$211$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1168$$),$children$jscomp$323_ids$jscomp$323$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$342$children$$,"Every children needs to be shape proxies")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$342$children$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__86569$$,"children",function(){return{enumerable:!1,get:function(){return this.getChildren()},set:function($value__42799__auto__$jscomp$15$$){return $set_fn87736_91581$$(this,$value__42799__auto__$jscomp$15$$)}}}())}return $G__86569$$}();if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)){var $set_fn87742_91583$$=
function($_$jscomp$3273$$,$value$jscomp$1154$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1154$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),function($p1__86509_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86509_SHARP_$$,
$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$core$not$$($value$jscomp$1154$$))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6554$clipContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6554$clipContent$$,$value$jscomp$1154$$)};Object.defineProperty($G__86568$$,"clipContent",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($value__42799__auto__$jscomp$16$$){return $set_fn87742_91583$$(this,$value__42799__auto__$jscomp$16$$)}}}());var $set_fn87742_91585$$=function($_$jscomp$3274$$,$value$jscomp$1155$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1155$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),function($p1__86510_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86510_SHARP_$$,$APP.$cljs$cst$1875$hide_in_viewer$$,$APP.$cljs$core$not$$($value$jscomp$1155$$))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6555$showInViewMode$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6555$showInViewMode$$,$value$jscomp$1155$$)};
Object.defineProperty($G__86568$$,"showInViewMode",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$not$$($APP.$cljs$cst$1875$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42799__auto__$jscomp$17$$){return $set_fn87742_91585$$(this,$value__42799__auto__$jscomp$17$$)}}}());Object.defineProperty($G__86568$$,"grid",function(){return{enumerable:!0,get:function(){var $layout$jscomp$inline_10459$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$file_id__$1$jscomp$inline_10460$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10461$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$id__$1$jscomp$inline_10462$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1659$grid$$,$layout$jscomp$inline_10459$$)?$app$plugins$grid$grid_layout_proxy$$($plugin_id$jscomp$33$$,
$file_id__$1$jscomp$inline_10460$$,$page_id__$1$jscomp$inline_10461$$,$id__$1$jscomp$inline_10462$$):null}}}());Object.defineProperty($G__86568$$,"flex",function(){return{enumerable:!0,get:function(){var $layout$jscomp$inline_10465$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$file_id__$1$jscomp$inline_10466$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10467$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$page"),$id__$1$jscomp$inline_10468$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$layout$jscomp$inline_10465$$)?$app$plugins$flex$flex_layout_proxy$$($plugin_id$jscomp$33$$,$file_id__$1$jscomp$inline_10466$$,$page_id__$1$jscomp$inline_10467$$,$id__$1$jscomp$inline_10468$$):null}}}());var $set_fn87742_91591$$=function($id__$1$jscomp$56_self$jscomp$216$$,$value$jscomp$1156$$){$id__$1$jscomp$56_self$jscomp$216$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$56_self$jscomp$216$$,"$id");var $value__$1$jscomp$123$$=$app$plugins$parser$parse_frame_guides$$($value$jscomp$1156$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$cljs$cst$6556$app_DOT_common_DOT_types_DOT_grid_SLASH_grid$$],null),$value__$1$jscomp$123$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$2057$guides$$,$value__$1$jscomp$123$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$56_self$jscomp$216$$],null),function($p1__86512_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__86512_SHARP_$$,
$APP.$cljs$cst$2050$grids$$,$value__$1$jscomp$123$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$2057$guides$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__86568$$,"guides",function(){return{enumerable:!0,get:function(){var $guides$jscomp$inline_14008$$=$APP.$cljs$cst$2050$grids$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));return $guides$jscomp$inline_14008$$!=null?$app$plugins$format$format_array$$($app$plugins$format$format_frame_guide$$,
$guides$jscomp$inline_14008$$):null},set:function($value__42799__auto__$jscomp$18$$){return $set_fn87742_91591$$(this,$value__42799__auto__$jscomp$18$$)}}}());var $get_fn87741_91592$$=function(){var $guides$jscomp$14$$=$APP.$cljs$cst$2057$guides$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_page$$($file_id$jscomp$480$$,$page_id$jscomp$489$$));return $app$plugins$format$format_array$$(function($p1__86514_SHARP_$$){return $app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$33$$,
$file_id$jscomp$480$$,$page_id$jscomp$489$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__86514_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86513_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1117$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__86513_SHARP_$$))},$APP.$cljs$core$vals$$($guides$jscomp$14$$)))};Object.defineProperty($G__86568$$,"rulerGuides",function(){return{enumerable:!0,
get:function(){return $get_fn87741_91592$$(this)}}}());Object.defineProperty($G__86568$$,"horizontalSizing",function(){return{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1697$fix$$))},set:function($value__$1$jscomp$inline_10473_value__42799__auto__$jscomp$19$$){var $id__$1$jscomp$inline_10472$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10473_value__42799__auto__$jscomp$19$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$inline_10473_value__42799__auto__$jscomp$19$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$value__$1$jscomp$inline_10473_value__42799__auto__$jscomp$19$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id__$1$jscomp$inline_10472$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,$value__$1$jscomp$inline_10473_value__42799__auto__$jscomp$19$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6414$horizontalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6414$horizontalSizing$$,$value__$1$jscomp$inline_10473_value__42799__auto__$jscomp$19$$)}}}());Object.defineProperty($G__86568$$,"verticalSizing",function(){return{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1697$fix$$))},set:function($value__$1$jscomp$inline_10478_value__42799__auto__$jscomp$20$$){var $id__$1$jscomp$inline_10477$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10478_value__42799__auto__$jscomp$20$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$inline_10478_value__42799__auto__$jscomp$20$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$value__$1$jscomp$inline_10478_value__42799__auto__$jscomp$20$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id__$1$jscomp$inline_10477$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,$value__$1$jscomp$inline_10478_value__42799__auto__$jscomp$20$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6415$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$cljs$cst$6415$verticalSizing$$,$value__$1$jscomp$inline_10478_value__42799__auto__$jscomp$20$$)}}}());Object.defineProperty($G__86568$$,"variants",function(){return{enumerable:!1,get:function(){var $G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$=
$app$plugins$utils$proxy__GT_shape$$(this);$APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$))?($G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$),$G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$=
$app$plugins$shape$variant_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$shape$variant_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$):$app$plugins$shape$variant_proxy$$($plugin_id$jscomp$33$$,$file_id$jscomp$480$$,$G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$)):$G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$=
null;return $G__87763$jscomp$inline_10482_JSCompiler_inline_result$jscomp$2237_shape$jscomp$inline_10481$$}}}())}return $G__86568$$}();return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)?$app$plugins$text$add_text_props$$($G__86567$$,$plugin_id$jscomp$33$$):$G__86567$$}();if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($data$jscomp$532$$)){var $set_fn87767_91616$$=
function($_$jscomp$3276_segments$jscomp$17$$,$value$jscomp$1159$$){$_$jscomp$3276_segments$jscomp$17$$=(0,$APP.$app$common$types$path$impl$decode_segments$$)($APP.$app$common$json$__GT_clj$$($value$jscomp$1159$$));if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$path$impl$schema_COLON_segments$$,$_$jscomp$3276_segments$jscomp$17$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$1637$content$$,$_$jscomp$3276_segments$jscomp$17$$);var $selrect$jscomp$98$$=$APP.$app$common$types$path$calc_selrect$$($_$jscomp$3276_segments$jscomp$17$$),$content$jscomp$279$$=$APP.$app$common$types$path$impl$from_plain$$($_$jscomp$3276_segments$jscomp$17$$),$points$jscomp$111$$=$APP.$app$common$geom$rect$rect__GT_points$$($selrect$jscomp$98$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),function($shape$jscomp$1170$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1170$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$279$$),$APP.$cljs$cst$1605$selrect$$,$selrect$jscomp$98$$),$APP.$cljs$cst$1604$points$$,$points$jscomp$111$$)}))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$APP.$cljs$cst$1637$content$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__86566$$,"commands",function(){return{enumerable:!0,get:function(){var $content$jscomp$inline_14010$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));return $content$jscomp$inline_14010$$!=null?$app$plugins$format$format_array$$($app$plugins$format$format_command$$,$content$jscomp$inline_14010$$):null},set:function($value__42799__auto__$jscomp$21$$){return $set_fn87767_91616$$(this,
$value__42799__auto__$jscomp$21$$)}}}());var $set_fn87767_91618$$=function($_$jscomp$3277_segments$jscomp$18$$,$value$jscomp$1160$$){$_$jscomp$3277_segments$jscomp$18$$=typeof $value$jscomp$1160$$==="string"?$APP.$app$common$svg$path$parse$$($value$jscomp$1160$$):$value$jscomp$1160$$;if($app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")){if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)){if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$path$impl$schema_COLON_segments$$,
$_$jscomp$3277_segments$jscomp$18$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1637$content$$,$_$jscomp$3277_segments$jscomp$18$$);var $selrect$jscomp$99$$=$APP.$app$common$types$path$calc_selrect$$($_$jscomp$3277_segments$jscomp$18$$),$content$jscomp$280$$=$APP.$app$common$types$path$impl$from_plain$$($_$jscomp$3277_segments$jscomp$18$$),$points$jscomp$112$$=$APP.$app$common$geom$rect$rect__GT_points$$($selrect$jscomp$99$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1117$$],null),function($shape$jscomp$1171$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1171$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$280$$),$APP.$cljs$cst$1605$selrect$$,$selrect$jscomp$99$$),$APP.$cljs$cst$1604$points$$,$points$jscomp$112$$)}))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,
$cljs$cst$6557$content_type$$,$APP.$cljs$core$type$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1637$content$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__86566$$,"d",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42799__auto__$jscomp$22$$){return $set_fn87767_91618$$(this,
$value__42799__auto__$jscomp$22$$)}}}());Object.defineProperty($G__86566$$,"content",function(){return{enumerable:!0,get:function(){return this.d},set:function($value__42799__auto__$jscomp$23$$){return this.d=$value__42799__auto__$jscomp$23$$}}}())}return $G__86566$$};$app$plugins$shape$shape_proxy$$.$cljs$lang$maxFixedArity$=4;var $app$plugins$file$file_version_proxy$$=function $app$plugins$file$file_version_proxy$$($plugin_id$jscomp$41$$,$file_id$jscomp$485$$,$users$jscomp$11$$,$data$jscomp$538_obj_90160$$){var $data__$1$jscomp$19$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$538_obj_90160$$);$data$jscomp$538_obj_90160$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($data$jscomp$538_obj_90160$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FileVersionProxy"}});Object.defineProperty($data$jscomp$538_obj_90160$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FileVersionProxy"}});Object.defineProperty($data$jscomp$538_obj_90160$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$41$$}});Object.defineProperty($data$jscomp$538_obj_90160$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$485$$}});Object.defineProperty($data$jscomp$538_obj_90160$$,"label",{enumerable:!0,get:function(){return $APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$))},
set:function($val_label_90197$$){return function($value$jscomp$1170$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$41$$,"content:write")){if(typeof $value$jscomp$1170$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($value$jscomp$1170$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$41$$,$APP.$cljs$cst$2287$label$$,$value$jscomp$1170$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($data__$1$jscomp$19$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2287$label$$,
$value$jscomp$1170$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5756$created_by$$,"user"]));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$("rename-version",$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_id$jscomp$485$$])))},
$APP.$beicon$v2$core$take$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5030$update_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)),$APP.$cljs$cst$2287$label$$,$value$jscomp$1170$$],null))))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$41$$,$APP.$cljs$cst$2287$label$$,"Plugin doesn't have 'content:write' permission")}.call(this,
$val_label_90197$$)}});Object.defineProperty($data$jscomp$538_obj_90160$$,"createdBy",{enumerable:!0,get:function(){var $temp__5825__auto__$jscomp$inline_10511$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($users$jscomp$11$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_10511$$)?$app$plugins$user$user_proxy$$($plugin_id$jscomp$41$$,$temp__5825__auto__$jscomp$inline_10511$$):
null}});Object.defineProperty($data$jscomp$538_obj_90160$$,"createdAt",{enumerable:!0,get:function(){return $APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)).toJSDate()}});Object.defineProperty($data$jscomp$538_obj_90160$$,"isAutosave",{enumerable:!0,get:function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5756$created_by$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)))}});
Object.defineProperty($data$jscomp$538_obj_90160$$,"restore",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$51$$,$reject$jscomp$35$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$41$$,"content:write")){var $version_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$),$APP.$cljs$cst$266$id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$restore_version_from_plugin$$($file_id$jscomp$485$$,
$version_id$$,$resolve$jscomp$51$$,$reject$jscomp$35$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$41$$,"restore-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$485$$]))]))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$35$$,$cljs$cst$6572$restore$$,"Plugin doesn't have 'content:write' permission")})}.bind(this)}});
Object.defineProperty($data$jscomp$538_obj_90160$$,"remove",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$52$$,$reject$jscomp$36$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$41$$,"content:write")){var $version_id$jscomp$1$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$52$$,$reject$jscomp$36$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$(null),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5035$delete_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$version_id$jscomp$1$$],null))))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$36$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'content:write' permission")})}.bind(this)}});Object.defineProperty($data$jscomp$538_obj_90160$$,"pin",{enumerable:!1,
get:function(){return function(){return new Promise(function($resolve$jscomp$53$$,$reject$jscomp$37$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$41$$,"content:write")){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5756$created_by$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$))))return $app$plugins$utils$reject_not_valid$$($reject$jscomp$37$$,$cljs$cst$6573$pin$$,"Only auto-saved versions can be pinned");
var $params$jscomp$472$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)),$APP.$cljs$cst$2287$label$$,$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)),$APP.$cljs$cst$5027$localized_date$$)],null);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$){var $G__90246_users__$1_users__$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$,0,null);$G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$,1,null);$G__90246_users__$1_users__$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$G__90246_users__$1_users__$2$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$41$$,
"pin-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$485$$])));$G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$=$APP.$cljs$core$_deref$$($G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$);$G__90246_users__$1_users__$2$$=$app$plugins$file$file_version_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$file$file_version_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$41$$,$file_id$jscomp$485$$,$G__90246_users__$1_users__$2$$,
$G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$):$app$plugins$file$file_version_proxy$$($plugin_id$jscomp$41$$,$file_id$jscomp$485$$,$G__90246_users__$1_users__$2$$,$G__90250$jscomp$inline_10513_data__$2$jscomp$2_p__90242$$);return $resolve$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$($G__90246_users__$1_users__$2$$):$resolve$jscomp$53$$($G__90246_users__$1_users__$2$$)},$reject$jscomp$37$$,$APP.$beicon$v2$core$zip$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6574$get_team_users$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$485$$],null)),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5030$update_file_snapshot$$,$params$jscomp$472$$)))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$37$$,$cljs$cst$6573$pin$$,"Plugin doesn't have 'content:write' permission")})}.bind(this)}});return $data$jscomp$538_obj_90160$$};var $app$plugins$events$handle_state_change$$=function(){var $method_table__5622__auto__$jscomp$26$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$26$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$26$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$26$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.plugins.events",
"handle-state-change"),function($type$jscomp$747$$){return $type$jscomp$747$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$26$$,$method_table__5622__auto__$jscomp$26$$,$prefer_table__5623__auto__$jscomp$26$$,$method_cache__5624__auto__$jscomp$26$$,$cached_hierarchy__5625__auto__$jscomp$26$$)}();
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"finish",function($_$jscomp$3292_old_file_id$$,$___$1$jscomp$2109$$,$old_val$jscomp$9$$,$new_file_id_new_val$jscomp$10$$){$_$jscomp$3292_old_file_id$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($old_val$jscomp$9$$);$new_file_id_new_val$jscomp$10$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_file_id_new_val$jscomp$10$$);return $_$jscomp$3292_old_file_id$$!=
null&&$new_file_id_new_val$jscomp$10$$==null?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3292_old_file_id$$):$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"filechange",function($_$jscomp$3293_old_file_id$jscomp$1$$,$plugin_id$jscomp$43$$,$old_val$jscomp$10$$,$new_file_id$jscomp$1_new_val$jscomp$11$$){$_$jscomp$3293_old_file_id$jscomp$1$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($old_val$jscomp$10$$);$new_file_id$jscomp$1_new_val$jscomp$11$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_file_id$jscomp$1_new_val$jscomp$11$$);
return $_$jscomp$3293_old_file_id$jscomp$1$$===$new_file_id$jscomp$1_new_val$jscomp$11$$?$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$app$plugins$file$file_proxy$$($plugin_id$jscomp$43$$,$new_file_id$jscomp$1_new_val$jscomp$11$$)});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"pagechange",function($_$jscomp$3294_old_page_id$$,$plugin_id$jscomp$44$$,$new_page_id$jscomp$1_old_val$jscomp$11$$,$new_val$jscomp$12$$){$_$jscomp$3294_old_page_id$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($new_page_id$jscomp$1_old_val$jscomp$11$$);$new_page_id$jscomp$1_old_val$jscomp$11$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$12$$);
return $_$jscomp$3294_old_page_id$$===$new_page_id$jscomp$1_old_val$jscomp$11$$?$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$app$plugins$page$page_proxy$$($plugin_id$jscomp$44$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$12$$),$new_page_id$jscomp$1_old_val$jscomp$11$$)});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"selectionchange",function($_$jscomp$3295_old_selection$$,$___$1$jscomp$2112$$,$old_val$jscomp$12$$,$new_selection_new_val$jscomp$13$$){$_$jscomp$3295_old_selection$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null));
$new_selection_new_val$jscomp$13$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_selection_new_val$jscomp$13$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null));return $_$jscomp$3295_old_selection$$===$new_selection_new_val$jscomp$13$$?$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$new_selection_new_val$jscomp$13$$))});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"themechange",function($_$jscomp$3296_old_theme$$,$___$1$jscomp$2113$$,$old_val$jscomp$13$$,$new_theme_new_val$jscomp$14$$){$_$jscomp$3296_old_theme$$=$app$plugins$events$get_theme$$($old_val$jscomp$13$$);$new_theme_new_val$jscomp$14$$=$app$plugins$events$get_theme$$($new_theme_new_val$jscomp$14$$);return $_$jscomp$3296_old_theme$$===$new_theme_new_val$jscomp$14$$?$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$:
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_theme_new_val$jscomp$14$$,"default")?"dark":$new_theme_new_val$jscomp$14$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"shapechange",function($_$jscomp$3297_temp__5823__auto__$jscomp$268$$,$plugin_id$jscomp$45$$,$old_shape$jscomp$4_old_val$jscomp$14$$,$new_val$jscomp$15_page_id$jscomp$494$$,$new_shape$jscomp$25_props$jscomp$463$$){$_$jscomp$3297_temp__5823__auto__$jscomp$268$$=$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($new_shape$jscomp$25_props$jscomp$463$$,"shapeId"));if($APP.$cljs$core$truth_$$($_$jscomp$3297_temp__5823__auto__$jscomp$268$$)){$old_shape$jscomp$4_old_val$jscomp$14$$=
$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($old_shape$jscomp$4_old_val$jscomp$14$$,$_$jscomp$3297_temp__5823__auto__$jscomp$268$$);$new_shape$jscomp$25_props$jscomp$463$$=$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($new_val$jscomp$15_page_id$jscomp$494$$,$_$jscomp$3297_temp__5823__auto__$jscomp$268$$);var $file_id$jscomp$486$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$15_page_id$jscomp$494$$);
$new_val$jscomp$15_page_id$jscomp$494$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$15_page_id$jscomp$494$$);return $old_shape$jscomp$4_old_val$jscomp$14$$===$new_shape$jscomp$25_props$jscomp$463$$&&$plugin_id$jscomp$45$$!=null&&$file_id$jscomp$486$$!=null&&$new_val$jscomp$15_page_id$jscomp$494$$!=null&&$_$jscomp$3297_temp__5823__auto__$jscomp$268$$!=null?$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$45$$,
$file_id$jscomp$486$$,$new_val$jscomp$15_page_id$jscomp$494$$,$_$jscomp$3297_temp__5823__auto__$jscomp$268$$)}return $cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"contentsave",function($_$jscomp$3298_old_status$$,$___$1$jscomp$2114$$,$old_val$jscomp$15$$,$new_status_new_val$jscomp$16$$){$_$jscomp$3298_old_status$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$15$$,$APP.$cljs$cst$2178$persistence$$),$APP.$cljs$cst$109$status$$);$new_status_new_val$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_status_new_val$jscomp$16$$,
$APP.$cljs$cst$2178$persistence$$),$APP.$cljs$cst$109$status$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3151$saved$$,$new_status_new_val$jscomp$16$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_status_new_val$jscomp$16$$,$_$jscomp$3298_old_status$$)?$cljs$cst$6583$app_DOT_plugins_DOT_events_SLASH_void$$:$cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function(){return $cljs$cst$6582$app_DOT_plugins_DOT_events_SLASH_not_changed$$});var $app$plugins$library$lib_color_proxy$$=function $app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$50$$,$file_id$jscomp$487$$,$id$jscomp$1126$$){var $obj_88141$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_88141$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryColorProxy"}});Object.defineProperty($obj_88141$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryColorProxy"}});Object.defineProperty($obj_88141$$,"$plugin",{enumerable:!1,
get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$50$$).call(this)}});Object.defineProperty($obj_88141$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1126$$).call(this)}});Object.defineProperty($obj_88141$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$487$$).call(this)}});Object.defineProperty($obj_88141$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1126$$??"")}});Object.defineProperty($obj_88141$$,
"fileId",{enumerable:!0,get:function(){return""+($file_id$jscomp$487$$??"")}});Object.defineProperty($obj_88141$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},set:function($JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$){if(typeof $JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$!=="string")$JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")){var $color$jscomp$inline_10518$$=$app$plugins$utils$proxy__GT_library_color$$(this);$JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$=""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_10518$$),
"")??"")+" / "+($JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$??"");$JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$rename_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$,$JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$))}else $JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2245_val_name_88199_value__$1$jscomp$inline_10519$$}});Object.defineProperty($obj_88141$$,"path",{enumerable:!0,get:function(){return $APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},set:function($val_path_88207$$){return function($color$jscomp$249_self$jscomp$226$$,$value$jscomp$1175$$){return typeof $value$jscomp$1175$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$296$path$$,$value$jscomp$1175$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")?($color$jscomp$249_self$jscomp$226$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$($color$jscomp$249_self$jscomp$226$$),$APP.$cljs$cst$725$name$$,function($p1__88027_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1175$$),
" / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__88027_SHARP_$$)].join("")}),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_color$$($color$jscomp$249_self$jscomp$226$$,$file_id$jscomp$487$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$296$path$$,"Plugin doesn't have 'library:write' permission")}.call(this,this,$val_path_88207$$)}});Object.defineProperty($obj_88141$$,"color",{enumerable:!0,
get:function(){return $APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},set:function($JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$){typeof $JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$==="string"&&$APP.$app$common$types$color$valid_hex_color_QMARK_$$($JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,
"library:write")?($JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),$APP.$cljs$cst$1298$color$$,$JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$),$JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$,
$file_id$jscomp$487$$))):$JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1298$color$$,"Plugin doesn't have 'library:write' permission"):$JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1298$color$$,$JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$);return $JSCompiler_inline_result$jscomp$2246_color$jscomp$inline_10523_val_color_88215$$}});
Object.defineProperty($obj_88141$$,"opacity",{enumerable:!0,get:function(){return $APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},set:function($JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$){typeof $JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$!=="number"||$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$<0||$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$>
1?$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1734$opacity$$,$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")?($JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),
$APP.$cljs$cst$1734$opacity$$,$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$),$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$,$file_id$jscomp$487$$))):$JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1734$opacity$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2247_color$jscomp$inline_10527_val_opacity_88223$$}});Object.defineProperty($obj_88141$$,"gradient",{enumerable:!0,get:function(){return $app$plugins$format$format_gradient$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this)))},set:function($JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$){$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$=
$app$plugins$parser$parse_gradient$$($JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$);$APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_gradient$$,$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$))?$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1724$gradient$$,$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")?($JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),
$APP.$cljs$cst$1724$gradient$$,$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$),$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$,$file_id$jscomp$487$$))):
$JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1724$gradient$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2248_color$jscomp$inline_10532_val_gradient_88231_value__$1$jscomp$inline_10531$$}});Object.defineProperty($obj_88141$$,"image",{enumerable:!0,get:function(){return $app$plugins$format$format_image$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this)))},
set:function($JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$){$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$=$app$plugins$parser$parse_image_data$$($JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$);$APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_image$$,
$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$))?$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1612$image$$,$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")?
($JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),$APP.$cljs$cst$1612$image$$,$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$),$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$,
$file_id$jscomp$487$$))):$JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$1612$image$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2249_color$jscomp$inline_10537_val_image_88239_value__$1$jscomp$inline_10536$$}});Object.defineProperty($obj_88141$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$delete_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1126$$],null)),$plugin_id$jscomp$50$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_88141$$,"clone",{enumerable:!1,
get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")){var $color_id$jscomp$12$$=$APP.$app$common$uuid$next$$(),$color$jscomp$254$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$),$APP.$cljs$cst$266$id$$,$color_id$jscomp$12$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$254$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3902$rename_QMARK_$$,!1],null)),$plugin_id$jscomp$50$$));return $app$plugins$library$lib_color_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$library$lib_color_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$50$$,$id$jscomp$1126$$,$color_id$jscomp$12$$):$app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$50$$,$id$jscomp$1126$$,$color_id$jscomp$12$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6522$clone$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_88141$$,"asFill",{enumerable:!1,get:function(){return function(){var $color$jscomp$255$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$);return $app$plugins$format$format_fill$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$255$$),$APP.$cljs$cst$1747$fill_opacity$$,
$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$255$$),$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$255$$),$APP.$cljs$cst$1640$fill_color_ref_file$$,$file_id$jscomp$487$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$id$jscomp$1126$$,$APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$255$$)],null))}.bind(this)}});Object.defineProperty($obj_88141$$,
"asStroke",{enumerable:!1,get:function(){return function(){var $color$jscomp$256$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$);return $app$plugins$format$format_stroke$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1739$stroke_color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$256$$),$APP.$cljs$cst$1740$stroke_opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$256$$),$APP.$cljs$cst$1741$stroke_color_gradient$$,
$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$256$$),$APP.$cljs$cst$1641$stroke_color_ref_file$$,$file_id$jscomp$487$$,$APP.$cljs$cst$1742$stroke_color_ref_id$$,$id$jscomp$1126$$,$APP.$cljs$cst$1635$stroke_image$$,$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$256$$),$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$2041$inner$$],null))}.bind(this)}});Object.defineProperty($obj_88141$$,
"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$450$$){if(typeof $key$jscomp$450$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6575$getPluginData_key$$,$key$jscomp$450$$);var $color$jscomp$257$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$257$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$50$$))),$key$jscomp$450$$)}.bind(this)}});Object.defineProperty($obj_88141$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$451$$,$value$jscomp$1180$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$487$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6591$setPluginData_non_local_library$$,$file_id$jscomp$487$$):typeof $key$jscomp$451$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6524$setPluginData_key$$,$key$jscomp$451$$):$value$jscomp$1180$$!=null&&typeof $value$jscomp$1180$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6525$setPluginData_value$$,$value$jscomp$1180$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$487$$,$APP.$cljs$cst$1298$color$$,$id$jscomp$1126$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$50$$)),$key$jscomp$451$$,$value$jscomp$1180$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6526$setPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});
Object.defineProperty($obj_88141$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $color$jscomp$258$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$258$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$50$$)))))}.bind(this)}});Object.defineProperty($obj_88141$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$27$$,$key$jscomp$452$$){if(typeof $namespace$jscomp$27$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6527$getSharedPluginData_namespace$$,$namespace$jscomp$27$$);if(typeof $key$jscomp$452$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,
$cljs$cst$6528$getSharedPluginData_key$$,$key$jscomp$452$$);var $color$jscomp$259$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$259$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$27$$)),$key$jscomp$452$$)}.bind(this)}});
Object.defineProperty($obj_88141$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$28$$,$key$jscomp$453$$,$value$jscomp$1181$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$487$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6592$setSharedPluginData_non_local_library$$,$file_id$jscomp$487$$):
typeof $namespace$jscomp$28$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6529$setSharedPluginData_namespace$$,$namespace$jscomp$28$$):typeof $key$jscomp$453$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6530$setSharedPluginData_key$$,$key$jscomp$453$$):$value$jscomp$1181$$!=null&&typeof $value$jscomp$1181$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1181$$):
$app$plugins$register$check_permission$$($plugin_id$jscomp$50$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$487$$,$APP.$cljs$cst$1298$color$$,$id$jscomp$1126$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$28$$),$key$jscomp$453$$,$value$jscomp$1181$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6532$setSharedPluginData$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_88141$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$29$$){if(typeof $namespace$jscomp$29$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$50$$,$cljs$cst$6593$getSharedPluginDataKeys_namespace$$,$namespace$jscomp$29$$);var $color$jscomp$260$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$487$$,$id$jscomp$1126$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$260$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$29$$))))}.bind(this)}});return $obj_88141$$},$app$plugins$library$lib_typography_proxy$$=function $app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$51$$,$file_id$jscomp$488$$,$id$jscomp$1127$$){var $obj_89183$$=new $APP.$app$util$object$Proxy$$;
Object.defineProperty($obj_89183$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryTypographyProxy"}});Object.defineProperty($obj_89183$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryTypographyProxy"}});Object.defineProperty($obj_89183$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$51$$).call(this)}});Object.defineProperty($obj_89183$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1127$$).call(this)}});
Object.defineProperty($obj_89183$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$488$$).call(this)}});Object.defineProperty($obj_89183$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1127$$??"")}});Object.defineProperty($obj_89183$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$){if(typeof $JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$!==
"string")$JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")){var $typo$jscomp$inline_10541$$=$app$plugins$utils$proxy__GT_library_typography$$(this);$JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$=
""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($typo$jscomp$inline_10541$$),"")??"")+" / "+($JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$??"");$JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$rename_typography$$($file_id$jscomp$488$$,
$id$jscomp$1127$$,$JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$),$plugin_id$jscomp$51$$))}else $JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2250_val_name_89234_value__$1$jscomp$inline_10542$$}});Object.defineProperty($obj_89183$$,"path",{enumerable:!0,
get:function(){return $APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($val_path_89242$$){return function($self$jscomp$232_typo$jscomp$1$$,$value$jscomp$1183$$){return typeof $value$jscomp$1183$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$APP.$cljs$cst$296$path$$,$value$jscomp$1183$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($self$jscomp$232_typo$jscomp$1$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$($self$jscomp$232_typo$jscomp$1$$),$APP.$cljs$cst$725$name$$,function($p1__89172_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1183$$)," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__89172_SHARP_$$)].join("")}),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($self$jscomp$232_typo$jscomp$1$$,
$file_id$jscomp$488$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$APP.$cljs$cst$296$path$$,"Plugin doesn't have 'library:write' permission")}.call(this,this,$val_path_89242$$)}});Object.defineProperty($obj_89183$$,"fontId",{enumerable:!0,get:function(){return $APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$){typeof $JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$!==
"string"?$JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6477$fontId$$,$JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1757$font_id$$,$JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$),$JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6477$fontId$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2251_typo$jscomp$inline_10546_val_fontid_89250$$}});Object.defineProperty($obj_89183$$,"fontFamily",{enumerable:!0,get:function(){return $APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$){typeof $JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$!==
"string"?$JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6478$fontFamily$$,$JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1758$font_family$$,$JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$),$JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6478$fontFamily$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2252_typo$jscomp$inline_10550_val_fontfamily_89258$$}});Object.defineProperty($obj_89183$$,"fontVariantId",{enumerable:!0,get:function(){return $APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$){typeof $JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$!==
"string"?$JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6479$fontVariantId$$,$JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1759$font_variant_id$$,$JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$),$JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6479$fontVariantId$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2253_typo$jscomp$inline_10554_val_fontvariantid_89266$$}});Object.defineProperty($obj_89183$$,"fontSize",{enumerable:!0,get:function(){return $APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$){typeof $JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$!==
"string"?$JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6480$fontSize$$,$JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1760$font_size$$,$JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$),$JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6480$fontSize$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2254_typo$jscomp$inline_10558_val_fontsize_89274$$}});Object.defineProperty($obj_89183$$,"fontWeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$){typeof $JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$!==
"string"?$JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6481$fontWeight$$,$JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1761$font_weight$$,$JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$),$JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6481$fontWeight$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2255_typo$jscomp$inline_10562_val_fontweight_89282$$}});Object.defineProperty($obj_89183$$,"fontStyle",{enumerable:!0,get:function(){return $APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$){typeof $JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$!==
"string"?$JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6482$fontStyle$$,$JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1762$font_style$$,$JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$),$JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6482$fontStyle$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2256_typo$jscomp$inline_10566_val_fontstyle_89290$$}});Object.defineProperty($obj_89183$$,"lineHeight",{enumerable:!0,get:function(){return $cljs$cst$6594$font_height$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$){typeof $JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$!==
"string"?$JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6483$lineHeight$$,$JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$cljs$cst$6594$font_height$$,$JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$),$JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6483$lineHeight$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2257_typo$jscomp$inline_10570_val_lineheight_89298$$}});Object.defineProperty($obj_89183$$,"letterSpacing",{enumerable:!0,get:function(){return $APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$){typeof $JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$!==
"string"?$JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6484$letterSpacing$$,$JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1766$letter_spacing$$,$JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$),$JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6484$letterSpacing$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2258_typo$jscomp$inline_10574_val_letterspacing_89306$$}});Object.defineProperty($obj_89183$$,"textTransform",{enumerable:!0,get:function(){return $APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$){typeof $JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$!==
"string"?$JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6485$textTransform$$,$JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?($JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),
$APP.$cljs$cst$1769$text_transform$$,$JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$),$JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$,$file_id$jscomp$488$$))):$JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6485$textTransform$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2259_typo$jscomp$inline_10578_val_texttransform_89314$$}});Object.defineProperty($obj_89183$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$delete_typography$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1127$$],null)),$plugin_id$jscomp$51$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$APP.$cljs$cst$2590$remove$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89183$$,"clone",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")){var $typo_id$$=$APP.$app$common$uuid$next$$(),$typo$jscomp$11$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,
$id$jscomp$1127$$),$APP.$cljs$cst$266$id$$,$typo_id$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($typo$jscomp$11$$,!1),$plugin_id$jscomp$51$$));return $app$plugins$library$lib_typography_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$library$lib_typography_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$51$$,$id$jscomp$1127$$,$typo_id$$):
$app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$51$$,$id$jscomp$1127$$,$typo_id$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6522$clone$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89183$$,"applyToText",{enumerable:!1,get:function(){return function($shape$jscomp$1176_shape_id$jscomp$185$$){if($app$plugins$shape$shape_proxy_QMARK_$$($shape$jscomp$1176_shape_id$jscomp$185$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,
"content:write")){$shape$jscomp$1176_shape_id$jscomp$185$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1176_shape_id$jscomp$185$$,"$id");var $typography$jscomp$43$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,$id$jscomp$1127$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape$jscomp$1176_shape_id$jscomp$185$$]),
$typography$jscomp$43$$,$file_id$jscomp$488$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6584$applyToText$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6584$applyToText$$,$shape$jscomp$1176_shape_id$jscomp$185$$)}.bind(this)}});Object.defineProperty($obj_89183$$,"applyToTextRange",{enumerable:!1,get:function(){return function($end$jscomp$116_range$jscomp$20$$){if($app$util$object$type_of_QMARK_$$($end$jscomp$116_range$jscomp$20$$,
"TextRange")){if($app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"content:write")){var $shape_id$jscomp$186$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,"$id"),$start$jscomp$260$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,"start");$end$jscomp$116_range$jscomp$20$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,"end");var $attrs$jscomp$195_typography$jscomp$44$$=
$app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,$id$jscomp$1127$$);$attrs$jscomp$195_typography$jscomp$44$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$195_typography$jscomp$44$$,$APP.$cljs$cst$1642$typography_ref_file$$,$file_id$jscomp$488$$),$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$195_typography$jscomp$44$$)),
$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($shape_id$jscomp$186$$,$start$jscomp$260$$,$end$jscomp$116_range$jscomp$20$$,$attrs$jscomp$195_typography$jscomp$44$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6584$applyToText$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,
$cljs$cst$6584$applyToText$$,$end$jscomp$116_range$jscomp$20$$)}.bind(this)}});Object.defineProperty($obj_89183$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$454$$){if(typeof $key$jscomp$454$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6595$typography_plugin_data_key$$,$key$jscomp$454$$);var $typography$jscomp$45$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,$id$jscomp$1127$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$45$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$51$$))),$key$jscomp$454$$)}.bind(this)}});Object.defineProperty($obj_89183$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$455$$,$value$jscomp$1193$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$488$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6591$setPluginData_non_local_library$$,$file_id$jscomp$488$$):typeof $key$jscomp$455$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6524$setPluginData_key$$,$key$jscomp$455$$):$value$jscomp$1193$$!=null&&typeof $value$jscomp$1193$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6525$setPluginData_value$$,$value$jscomp$1193$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$488$$,$APP.$cljs$cst$1981$typography$$,$id$jscomp$1127$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$51$$)),$key$jscomp$455$$,$value$jscomp$1193$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6526$setPluginData$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89183$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $typography$jscomp$46$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,$id$jscomp$1127$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$46$$,
$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$51$$)))))}.bind(this)}});Object.defineProperty($obj_89183$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$30$$,$key$jscomp$456$$){if(typeof $namespace$jscomp$30$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6527$getSharedPluginData_namespace$$,$namespace$jscomp$30$$);
if(typeof $key$jscomp$456$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6528$getSharedPluginData_key$$,$key$jscomp$456$$);var $typography$jscomp$47$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,$id$jscomp$1127$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$47$$,$APP.$cljs$cst$1738$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$30$$)),$key$jscomp$456$$)}.bind(this)}});Object.defineProperty($obj_89183$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$31$$,$key$jscomp$457$$,$value$jscomp$1194$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$488$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6592$setSharedPluginData_non_local_library$$,$file_id$jscomp$488$$):typeof $namespace$jscomp$31$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6529$setSharedPluginData_namespace$$,$namespace$jscomp$31$$):typeof $key$jscomp$457$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6530$setSharedPluginData_key$$,$key$jscomp$457$$):$value$jscomp$1194$$!=null&&typeof $value$jscomp$1194$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6531$setSharedPluginData_value$$,$value$jscomp$1194$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$51$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$488$$,$APP.$cljs$cst$1981$typography$$,$id$jscomp$1127$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$31$$),
$key$jscomp$457$$,$value$jscomp$1194$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6532$setSharedPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89183$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$32$$){if(typeof $namespace$jscomp$32$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$51$$,$cljs$cst$6593$getSharedPluginDataKeys_namespace$$,$namespace$jscomp$32$$);
var $typography$jscomp$48$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$488$$,$id$jscomp$1127$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$48$$,$APP.$cljs$cst$1738$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$32$$))))}.bind(this)}});
return $obj_89183$$};$app$plugins$shape$variant_proxy$$=$app$plugins$library$variant_proxy$$;var $app$plugins$local_storage$local_storage$$;try{$app$plugins$local_storage$local_storage$$=$APP.$app$util$globals$global$$.localStorage}catch($e87365$jscomp$inline_10600$$){$app$plugins$local_storage$local_storage$$=null};$APP.$goog$exportSymbol$$("app.plugins.public_utils.centerShapes",function($plugin_id$jscomp$61_shapes__$1$jscomp$45$$,$shapes$jscomp$258$$){return $APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$258$$)?($plugin_id$jscomp$61_shapes__$1$jscomp$45$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$proxy__GT_shape$$,$shapes$jscomp$258$$),$app$plugins$format$format_point$$($APP.$app$common$geom$rect$rect__GT_center$$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($plugin_id$jscomp$61_shapes__$1$jscomp$45$$)))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$61_shapes__$1$jscomp$45$$,$cljs$cst$6635$centerShapes$$,$shapes$jscomp$258$$)});$app$plugins$grid$shape_proxy_QMARK_$$=$app$plugins$flex$shape_proxy_QMARK_$$=$app$plugins$shape$shape_proxy_QMARK_$$;$app$plugins$ruler_guides$shape_proxy$$=$app$plugins$format$shape_proxy$$=$app$plugins$shape$shape_proxy$$;$app$plugins$ruler_guides$shape_proxy_QMARK_$$=$app$plugins$shape$shape_proxy_QMARK_$$;$app$plugins$shape$lib_typography_proxy_QMARK_$$=function($p$jscomp$290$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$290$$,"LibraryTypographyProxy")};
$app$plugins$shape$lib_component_proxy$$=$app$plugins$library$lib_component_proxy$$;$APP.$goog$exportSymbol$$("features.grid",function(){$APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$features$toggle_feature$$())});return null});$APP.$goog$exportSymbol$$("features.get_enabled",function(){return $APP.$cljs$core$clj__GT_js$$($APP.$app$main$features$global_enabled_features$$)});
$APP.$goog$exportSymbol$$("features.get_team_enabled",function(){return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$227$features$$))});$APP.$goog$exportSymbol$$("features.plugins",function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$features$enable_feature$$());$app$plugins$init_plugins_runtime_BANG_$$();return null});$APP.$app$common$logging$setup_BANG_$$();$APP.$app$common$logging$loggers$$.set("app.main",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1357$browser$$,$APP.$app$config$target$$)&&($APP.$app$common$logging$enabled_QMARK_$$("app.main",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2289$version$$,$APP.$cljs$cst$1273$full$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6637$asserts$$,$APP.$cljs$core$_STAR_assert_STAR_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6638$build_date$$,$APP.$app$config$build_date$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3128$public_uri$$,""+($APP.$app$config$public_uri$$??"")],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2332$session_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$session_id$$)],null)],null)}),null,"app.main",$APP.$cljs$cst$1161$info$$,!1),$APP.$app$common$logging$enabled_QMARK_$$("app.main",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"enabled flags"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1467$flags$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$APP.$app$config$flags$$))],null)],null)}),null,"app.main",$APP.$cljs$cst$1161$info$$,!1));
var $app$main$app_root$$,$el$jscomp$inline_10614$$=$APP.$goog$dom$getElement$$("app");$app$main$app_root$$=(0,$APP.$rumext$v2$create_root$$)($el$jscomp$inline_10614$$);$APP.$goog$exportSymbol$$("app.main.init",$app$main$init$$);
$APP.$app$main$reinit$$=function $app$main$reinit$$($var_args$jscomp$1515$$){switch(arguments.length){case 0:return $app$main$reinit$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$main$reinit$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("app.main.reinit",$APP.$app$main$reinit$$);$APP.$app$main$reinit$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$main$reinit$$.$cljs$core$IFn$_invoke$arity$1$(!1)};
$APP.$app$main$reinit$$.$cljs$core$IFn$_invoke$arity$1$=function($hard_QMARK_$$){$APP.$cljs$core$truth_$$($hard_QMARK_$$)&&($app$main$app_root$$.unmount(),$app$main$app_root$$=(0,$APP.$rumext$v2$create_root$$)($APP.$goog$dom$getElement$$("app")));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$event$initialize$$());return $rumext$v2$render_BANG_$$()};$APP.$app$main$reinit$$.$cljs$lang$maxFixedArity$=1;Error.stackTraceLimit=50;export const init=$app$main$init$$;
//# sourceMappingURL=main.js.map
