import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$util$webapi$observe_resize$$,$app$util$sse$progress_QMARK_$$,$app$main$data$dashboard$builtin_templates_fetched$$,$app$main$data$plugins$delay_open_plugin$$,$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$dashboard$stop_edit_file_name$$,$app$main$data$dashboard$start_edit_file_name$$,$app$main$data$dashboard$show_file_menu_with_position$$,$app$main$data$fonts$add_font$$,$app$main$data$dashboard$file_deleted$$,$app$main$data$dashboard$projects_fetched$$,$app$main$data$common$clear_progress$$,
$app$main$data$dashboard$deleted_files_fetched$$,$app$main$data$dashboard$recent_files_fetched$$,$app$main$data$project$files_fetched$$,$app$main$data$team$stats_fetched$$,$app$common$types$organization$apply_organization$$,$app$main$data$common$toggle_progress_visibility$$,$app$main$data$common$update_progress$$,$app$main$data$dashboard$toggle_file_select$$,$app$main$data$dashboard$clear_selected_files$$,$app$main$data$dashboard$hide_file_menu$$,$app$main$data$nitrate$add_team_to_org$$,$app$main$data$nitrate$remove_team_from_org$$,
$app$main$data$dashboard$set_file_shared$$,$app$main$data$dashboard$delete_file$$,$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$dashboard$fetch_builtin_templates$$,$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$dashboard$fetch_projects$$,$app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$team$fetch_stats$$,$app$main$data$dashboard$rename_file$$,$app$main$data$fonts$calculate_family_to_id_mapping$$,
$app$main$data$fonts$rename_and_regroup$$,$app$main$data$fonts$merge_and_group_fonts$$,$app$main$data$fonts$update_font$$,$app$common$media$parse_font_style$$,$app$common$media$parse_font_weight$$,$app$main$data$fonts$delete_font_variant$$,$app$main$data$fonts$delete_font$$,$app$main$data$fonts$upload_font_variant$$,$app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$team$delete_invitation$$,$app$main$data$dashboard$set_file_thumbnail$$,$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$,
$cljs$core$partition_all$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$,$app$main$data$common$go_to_dashboard_deleted$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$dashboard$open_selected_file$$,$app$main$ui$dashboard$team$webhooks_list_STAR_$$,$app$main$ui$dashboard$team$webhooks_hero_STAR_$$,$app$main$ui$dashboard$team$empty_invitation_table_STAR_$$,$app$main$ui$dashboard$team$team_members_STAR_$$,$app$main$ui$dashboard$team$webhooks_page_STAR_$$,
$app$main$ui$dashboard$subscription$members_cta_STAR_$$,$app$main$ui$dashboard$team$team_members_page_STAR_$$,$app$main$ui$dashboard$subscription$team_STAR_$$,$app$main$data$dashboard$restore_files$$,$app$main$data$dashboard$restore_project_immediately$$,$app$main$data$dashboard$restore_files_immediately$$,$app$main$data$dashboard$delete_files$$,$app$main$data$dashboard$delete_project_immediately$$,$app$main$data$dashboard$delete_files_immediately$$,$app$main$data$dashboard$handle_organization_deleted$$,
$app$main$data$dashboard$handle_user_org_change$$,$app$main$data$dashboard$handle_change_team_org$$,$app$main$data$dashboard$duplicate_file$$,$app$main$data$dashboard$create_file$$,$app$main$data$dashboard$create_project$$,$app$main$data$fonts$process_upload$$,$app$main$data$team$update_team_photo$$,$app$main$ui$dashboard$team$team_settings_page_STAR_$$,$app$main$data$dashboard$handle_change_team_role$$,$app$main$data$dashboard$process_message$$,$app$main$data$dashboard$initialize$$,$app$main$fonts$render_font_styles$$,
$app$main$data$dashboard$search$$,$app$main$ui$dashboard$team$invitation_section_STAR_$$,$app$main$ui$dashboard$team$team_invitations_page_STAR_$$,$app$main$ui$components$progress$progress_notification_widget_STAR_$$,$app$main$ui$components$portal$portal_on_document_STAR_$$,$app$main$ui$dashboard$file_menu$get_project_name$$,$app$main$ui$dashboard$file_menu$get_project_id$$,$app$main$ui$dashboard$file_menu$get_team_name$$,$app$main$ui$dashboard$file_menu$group_by_team$$,$app$main$ui$dashboard$file_menu$file_menu_STAR_$$,
$app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,$app$main$ui$dashboard$placeholder$empty_project_placeholder_STAR_$$,$app$main$ui$dashboard$placeholder$make_has_other_files_or_projects_ref$$,$app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$,$app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$,$app$main$ui$dashboard$grid$persist_thumbnail$$,$app$main$ui$dashboard$grid$render_thumbnail$$,$app$main$ui$dashboard$grid$grid_item_thumbnail_STAR_$$,$app$main$ui$dashboard$grid$grid_item_library_STAR_$$,
$app$main$ui$dashboard$grid$grid_item_metadata_STAR_$$,$app$main$ui$dashboard$grid$create_counter_element$$,$app$main$ui$dashboard$grid$grid_item_STAR_$$,$app$main$ui$dashboard$grid$grid_STAR_$$,$app$main$ui$dashboard$grid$line_grid_row$$,$app$main$ui$dashboard$grid$line_grid$$,$app$main$ui$dashboard$deleted$on_restore_project$$,$app$main$ui$dashboard$deleted$on_delete_project$$,$app$main$ui$dashboard$deleted$header_STAR_$$,$app$main$ui$dashboard$deleted$project_context_menu_STAR_$$,$app$main$ui$dashboard$deleted$deleted_project_item_STAR_$$,
$app$main$ui$dashboard$deleted$menu_STAR_$$,$app$main$ui$dashboard$deleted$deleted_section_STAR_$$,$app$main$ui$dashboard$pin_button$pin_button_STAR_$$,$app$main$ui$dashboard$files$header_STAR_$$,$app$main$ui$dashboard$files$files_section_STAR_$$,$app$main$ui$dashboard$fonts$use_page_title$$,$app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$,$app$main$ui$dashboard$fonts$handle_font_upload$$,$app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$,$app$main$ui$dashboard$fonts$uploaded_fonts_STAR_$$,
$app$main$ui$dashboard$fonts$installed_font_context_menu$$,$app$main$ui$dashboard$fonts$installed_fonts_STAR_$$,$app$main$ui$dashboard$fonts$fonts_page_STAR_$$,$app$main$ui$dashboard$fonts$font_providers_page_STAR_$$,$app$main$ui$dashboard$libraries$libraries_page_STAR_$$,$app$main$ui$dashboard$projects$project_item_STAR_$$,$app$main$ui$dashboard$projects$projects_section_STAR_$$,$app$main$ui$dashboard$search$search_page_STAR_$$,$app$main$ui$dashboard$templates$import_template_BANG_$$,$app$main$ui$dashboard$templates$title_STAR_$$,
$app$main$ui$dashboard$templates$card_item$$,$app$main$ui$dashboard$templates$card_item_link$$,$app$main$ui$dashboard$templates$templates_section_STAR_$$,$app$main$ui$dashboard$dashboard_content_STAR_$$,$app$main$ui$dashboard$use_plugin_register$$,$app$main$ui$dashboard$use_templates_import$$,$app$main$ui$dashboard$use_nitrate_entry_popup$$,$app$main$ui$dashboard$dashboard_STAR_$$,$app$main$data$common$initialize_progress_52568$$,$app$main$data$common$update_progress_52578$$,$app$main$data$common$toggle_progress_visibility_52584$$,
$app$main$data$common$clear_progress_52598$$,$app$main$data$common$go_to_dashboard_deleted_52806$$,$app$main$data$team$stats_fetched_55460$$,$app$main$data$team$fetch_stats_55467$$,$app$main$data$team$update_team_photo_55507$$,$app$main$data$team$delete_invitation_55620$$,$app$main$data$plugins$delay_open_plugin_66271$$,$app$main$data$fonts$add_font_55874$$,$app$main$data$fonts$update_font_55892$$,$app$main$data$fonts$delete_font_55908$$,$app$main$data$fonts$delete_font_variants_55931$$,$app$main$data$project$files_fetched_55804$$,
$app$main$data$project$fetch_files_55817$$,$app$main$data$dashboard$initialize_72808$$,$app$main$data$dashboard$projects_fetched_72818$$,$app$main$data$dashboard$fetch_projects_72823$$,$app$main$data$dashboard$search_72831$$,$app$main$data$dashboard$recent_files_fetched_72835$$,$app$main$data$dashboard$fetch_recent_files_72840$$,$app$main$data$dashboard$libraries_fetched_72846$$,$app$main$data$dashboard$fetch_builtin_templates_72852$$,$app$main$data$dashboard$deleted_files_fetched_72859$$,$app$main$data$dashboard$fetch_deleted_files_72877$$,
$app$main$data$dashboard$clear_file_select_72883$$,$app$main$data$dashboard$toggle_file_select_72892$$,$app$main$data$dashboard$show_file_menu_with_position_72901$$,$app$main$data$dashboard$hide_file_menu_72914$$,$app$main$data$dashboard$start_edit_file_menu_72918$$,$app$main$data$dashboard$stop_edit_file_name_72924$$,$app$main$data$dashboard$create_project_72938$$,$app$main$data$dashboard$file_deleted_73006$$,$app$main$data$dashboard$delete_file_73011$$,$app$main$data$dashboard$rename_file_73021$$,
$app$main$data$dashboard$set_file_shared_73036$$,$app$main$data$dashboard$set_file_thumbnail_73043$$,$app$main$data$dashboard$create_file_73061$$,$app$main$data$dashboard$duplicate_file_73074$$,$app$main$data$dashboard$open_selected_file_73106$$,$app$main$data$dashboard$handle_change_team_role_73116$$,$app$main$data$dashboard$handle_change_team_org_73126$$,$app$main$data$dashboard$handle_user_org_change_73136$$,$app$main$data$dashboard$handle_organization_deleted_73146$$,$app$main$data$dashboard$delete_files_73162$$,
$app$main$data$dashboard$delete_files_immediately_73176$$,$app$main$data$dashboard$delete_project_immediately_73190$$,$app$main$data$dashboard$restore_files_73205$$,$app$main$data$dashboard$restore_files_immediately_73215$$,$app$main$data$dashboard$restore_project_immediately_73233$$,$app$main$data$nitrate$remove_team_from_org_73386$$,$app$main$data$nitrate$add_team_to_org_73396$$,$cljs$cst$6298$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_dashboard$$,$cljs$cst$6280$search$$,$cljs$cst$6281$get_all_projects$$,
$cljs$cst$6288$can_restore$$,$cljs$cst$6279$is_default_team$$,$cljs$cst$6299$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$,$cljs$cst$6302$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard$$,$cljs$cst$6283$thumbnails_SLASH_generate_for_file_wasm$$,$cljs$cst$6290$has_files$$,$cljs$cst$6287$limit$$,$cljs$cst$6289$create_fn$$,$cljs$cst$6285$file_if$$,$cljs$cst$6292$font_family_tmp$$,$cljs$cst$6284$thumbnails_SLASH_generate_for_file$$,$cljs$cst$6296$app_DOT_main_DOT_ui_DOT_dashboard_DOT_libraries_SLASH_dashboard$$,
$cljs$cst$6286$sample$$,$cljs$cst$6293$download_font_family$$,$cljs$cst$6297$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$,$cljs$cst$6291$app_DOT_main_DOT_ui_DOT_dashboard_DOT_files_SLASH_dashboard$$,$cljs$cst$6294$download_font$$,$cljs$cst$6295$providers$$;
$app$util$webapi$observe_resize$$=function($node$jscomp$164$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$9$$){var $obs$jscomp$2$$=new ResizeObserver(function($entries$jscomp$10$$){return $subs$jscomp$9$$.next($entries$jscomp$10$$)});$obs$jscomp$2$$.observe($node$jscomp$164$$);return function(){return $obs$jscomp$2$$.disconnect()}})};$app$util$sse$progress_QMARK_$$=function($event$jscomp$61$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("progress",$event$jscomp$61$$.type)};
$app$main$data$dashboard$builtin_templates_fetched$$=function($libraries$jscomp$99$$){typeof $app$main$data$dashboard$libraries_fetched_72846$$==="undefined"&&($app$main$data$dashboard$libraries_fetched_72846$$=function($libraries$jscomp$100$$,$meta72847$$){this.libraries=$libraries$jscomp$100$$;this.$meta72847$=$meta72847$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$libraries_fetched_72846$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$libraries_fetched_72846$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4917$app_DOT_main_DOT_data_DOT_dashboard_SLASH_libraries_fetched$$},$app$main$data$dashboard$libraries_fetched_72846$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72848$$,$meta72847__$1$$){return new $app$main$data$dashboard$libraries_fetched_72846$$(this.libraries,$meta72847__$1$$)},$app$main$data$dashboard$libraries_fetched_72846$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72847$},$app$main$data$dashboard$libraries_fetched_72846$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$libraries_fetched_72846$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2714$$,$state$jscomp$1026$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1026$$,$APP.$cljs$cst$4918$builtin_templates$$,this.libraries)});return new $app$main$data$dashboard$libraries_fetched_72846$$($libraries$jscomp$99$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$plugins$delay_open_plugin$$=function($plugin$jscomp$2$$){typeof $app$main$data$plugins$delay_open_plugin_66271$$==="undefined"&&($app$main$data$plugins$delay_open_plugin_66271$$=function($plugin$jscomp$3$$,$meta66272$$){this.$plugin$=$plugin$jscomp$3$$;this.$meta66272$=$meta66272$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$delay_open_plugin_66271$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$plugins$delay_open_plugin_66271$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3405$app_DOT_main_DOT_data_DOT_plugins_SLASH_delay_open_plugin$$},$app$main$data$plugins$delay_open_plugin_66271$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66273$$,$meta66272__$1$$){return new $app$main$data$plugins$delay_open_plugin_66271$$(this.$plugin$,$meta66272__$1$$)},$app$main$data$plugins$delay_open_plugin_66271$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66272$},$app$main$data$plugins$delay_open_plugin_66271$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$delay_open_plugin_66271$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1792$$,$state$jscomp$248$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$248$$,$APP.$cljs$cst$3406$app_DOT_main_DOT_data_DOT_plugins_SLASH_open_plugin$$,$APP.$cljs$cst$1720$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$(this.$plugin$))});
return new $app$main$data$plugins$delay_open_plugin_66271$$($plugin$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$03$$=function(){return function(){function $G__29334__3$$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$):(0,$APP.$cljs$cst$1758$font_family$$)($x$jscomp$605$$,$y$jscomp$255$$,
$z$jscomp$96$$),$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$):(0,$APP.$cljs$cst$1761$font_weight$$)($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$),$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$):(0,$APP.$cljs$cst$1762$font_style$$)($x$jscomp$605$$,
$y$jscomp$255$$,$z$jscomp$96$$)],null)}function $G__29334__2$$($x$jscomp$604$$,$y$jscomp$254$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$604$$,$y$jscomp$254$$):(0,$APP.$cljs$cst$1758$font_family$$)($x$jscomp$604$$,$y$jscomp$254$$),$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$604$$,
$y$jscomp$254$$):(0,$APP.$cljs$cst$1761$font_weight$$)($x$jscomp$604$$,$y$jscomp$254$$),$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$604$$,$y$jscomp$254$$):(0,$APP.$cljs$cst$1762$font_style$$)($x$jscomp$604$$,$y$jscomp$254$$)],null)}function $G__29334__1$$($x$jscomp$603$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$603$$):(0,$APP.$cljs$cst$1758$font_family$$)($x$jscomp$603$$),$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$603$$):(0,$APP.$cljs$cst$1761$font_weight$$)($x$jscomp$603$$),$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$603$$):(0,$APP.$cljs$cst$1762$font_style$$)($x$jscomp$603$$)],
null)}function $G__29334__0$$(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$0$():(0,$APP.$cljs$cst$1758$font_family$$)(),$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$0$():(0,$APP.$cljs$cst$1761$font_weight$$)(),$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$0$?
$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$0$():(0,$APP.$cljs$cst$1762$font_style$$)()],null)}var $G__29334$$=null,$G__29334__4$$=function(){function $G__29342$$($x$jscomp$607$$,$y$jscomp$257$$,$z$jscomp$98$$,$var_args$jscomp$270$$){var $G__29343__i_args$jscomp$100$$=null;if(arguments.length>3){$G__29343__i_args$jscomp$100$$=0;for(var $G__29343__a$$=Array(arguments.length-3);$G__29343__i_args$jscomp$100$$<$G__29343__a$$.length;)$G__29343__a$$[$G__29343__i_args$jscomp$100$$]=arguments[$G__29343__i_args$jscomp$100$$+
3],++$G__29343__i_args$jscomp$100$$;$G__29343__i_args$jscomp$100$$=new $APP.$cljs$core$IndexedSeq$$($G__29343__a$$,0,null)}return $G__29342__delegate$$.call(this,$x$jscomp$607$$,$y$jscomp$257$$,$z$jscomp$98$$,$G__29343__i_args$jscomp$100$$)}function $G__29342__delegate$$($x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$1758$font_family$$,
$x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$1761$font_weight$$,$x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$1762$font_style$$,$x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$)],null)}$G__29342$$.$cljs$lang$maxFixedArity$=3;$G__29342$$.$cljs$lang$applyTo$=function($arglist__29344_args$jscomp$101$$){var $x$jscomp$608$$=
$APP.$cljs$core$first$$($arglist__29344_args$jscomp$101$$);$arglist__29344_args$jscomp$101$$=$APP.$cljs$core$next$$($arglist__29344_args$jscomp$101$$);var $y$jscomp$258$$=$APP.$cljs$core$first$$($arglist__29344_args$jscomp$101$$);$arglist__29344_args$jscomp$101$$=$APP.$cljs$core$next$$($arglist__29344_args$jscomp$101$$);var $z$jscomp$99$$=$APP.$cljs$core$first$$($arglist__29344_args$jscomp$101$$);$arglist__29344_args$jscomp$101$$=$APP.$cljs$core$rest$$($arglist__29344_args$jscomp$101$$);return $G__29342__delegate$$($x$jscomp$608$$,
$y$jscomp$258$$,$z$jscomp$99$$,$arglist__29344_args$jscomp$101$$)};$G__29342$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29342__delegate$$;return $G__29342$$}();$G__29334$$=function($x$jscomp$609$$,$y$jscomp$259$$,$z$jscomp$100$$,$var_args$jscomp$271$$){switch(arguments.length){case 0:return $G__29334__0$$.call(this);case 1:return $G__29334__1$$.call(this,$x$jscomp$609$$);case 2:return $G__29334__2$$.call(this,$x$jscomp$609$$,$y$jscomp$259$$);case 3:return $G__29334__3$$.call(this,$x$jscomp$609$$,
$y$jscomp$259$$,$z$jscomp$100$$);default:var $G__29346_G__29347__i$$=null;if(arguments.length>3){$G__29346_G__29347__i$$=0;for(var $G__29347__a$$=Array(arguments.length-3);$G__29346_G__29347__i$$<$G__29347__a$$.length;)$G__29347__a$$[$G__29346_G__29347__i$$]=arguments[$G__29346_G__29347__i$$+3],++$G__29346_G__29347__i$$;$G__29346_G__29347__i$$=new $APP.$cljs$core$IndexedSeq$$($G__29347__a$$,0,null)}return $G__29334__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$609$$,$y$jscomp$259$$,$z$jscomp$100$$,
$G__29346_G__29347__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__29334$$.$cljs$lang$maxFixedArity$=3;$G__29334$$.$cljs$lang$applyTo$=$G__29334__4$$.$cljs$lang$applyTo$;$G__29334$$.$cljs$core$IFn$_invoke$arity$0$=$G__29334__0$$;$G__29334$$.$cljs$core$IFn$_invoke$arity$1$=$G__29334__1$$;$G__29334$$.$cljs$core$IFn$_invoke$arity$2$=$G__29334__2$$;$G__29334$$.$cljs$core$IFn$_invoke$arity$3$=$G__29334__3$$;$G__29334$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29334__4$$.$cljs$core$IFn$_invoke$arity$variadic$;
return $G__29334$$}()};
$app$main$data$dashboard$stop_edit_file_name$$=function(){typeof $app$main$data$dashboard$stop_edit_file_name_72924$$==="undefined"&&($app$main$data$dashboard$stop_edit_file_name_72924$$=function($meta72925$$){this.$meta72925$=$meta72925$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$stop_edit_file_name_72924$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$stop_edit_file_name_72924$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4934$app_DOT_main_DOT_data_DOT_dashboard_SLASH_stop_edit_file_name$$},
$app$main$data$dashboard$stop_edit_file_name_72924$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72926$$,$meta72925__$1$$){return new $app$main$data$dashboard$stop_edit_file_name_72924$$($meta72925__$1$$)},$app$main$data$dashboard$stop_edit_file_name_72924$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72925$},$app$main$data$dashboard$stop_edit_file_name_72924$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$stop_edit_file_name_72924$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2724$$,$state$jscomp$1035$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1035$$,$APP.$cljs$cst$2185$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,!1)});return new $app$main$data$dashboard$stop_edit_file_name_72924$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$start_edit_file_name$$=function($file_id$jscomp$318$$){typeof $app$main$data$dashboard$start_edit_file_menu_72918$$==="undefined"&&($app$main$data$dashboard$start_edit_file_menu_72918$$=function($file_id$jscomp$319$$,$meta72919$$){this.$file_id$=$file_id$jscomp$319$$;this.$meta72919$=$meta72919$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$start_edit_file_menu_72918$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$start_edit_file_menu_72918$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4933$app_DOT_main_DOT_data_DOT_dashboard_SLASH_start_edit_file_menu$$},$app$main$data$dashboard$start_edit_file_menu_72918$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72920$$,$meta72919__$1$$){return new $app$main$data$dashboard$start_edit_file_menu_72918$$(this.$file_id$,$meta72919__$1$$)},$app$main$data$dashboard$start_edit_file_menu_72918$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72919$},$app$main$data$dashboard$start_edit_file_menu_72918$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$start_edit_file_menu_72918$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2723$$,$state$jscomp$1034$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1034$$,$APP.$cljs$cst$2185$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,
!0,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$file_id$]))});return new $app$main$data$dashboard$start_edit_file_menu_72918$$($file_id$jscomp$318$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$show_file_menu_with_position$$=function($file_id$jscomp$316$$,$pos$jscomp$125$$){typeof $app$main$data$dashboard$show_file_menu_with_position_72901$$==="undefined"&&($app$main$data$dashboard$show_file_menu_with_position_72901$$=function($file_id$jscomp$317$$,$pos$jscomp$126$$,$meta72902$$){this.$file_id$=$file_id$jscomp$317$$;this.pos=$pos$jscomp$126$$;this.$meta72902$=$meta72902$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$dashboard$show_file_menu_with_position_72901$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$show_file_menu_with_position_72901$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4930$app_DOT_main_DOT_data_DOT_dashboard_SLASH_show_file_menu_with_position$$},$app$main$data$dashboard$show_file_menu_with_position_72901$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72903$$,$meta72902__$1$$){return new $app$main$data$dashboard$show_file_menu_with_position_72901$$(this.$file_id$,
this.pos,$meta72902__$1$$)},$app$main$data$dashboard$show_file_menu_with_position_72901$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72902$},$app$main$data$dashboard$show_file_menu_with_position_72901$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$show_file_menu_with_position_72901$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2720$$,$state$jscomp$1031$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1031$$,
$APP.$cljs$cst$2185$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!0,$APP.$cljs$cst$4928$menu_pos$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.pos,$APP.$cljs$cst$1644$file_id$$,this.$file_id$]))});return new $app$main$data$dashboard$show_file_menu_with_position_72901$$($file_id$jscomp$316$$,$pos$jscomp$125$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$add_font$$=function($font$jscomp$33$$){typeof $app$main$data$fonts$add_font_55874$$==="undefined"&&($app$main$data$fonts$add_font_55874$$=function($font$jscomp$34$$,$meta55875$$){this.font=$font$jscomp$34$$;this.$meta55875$=$meta55875$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$add_font_55874$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_font_55874$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3501$app_DOT_main_DOT_data_DOT_fonts_SLASH_add_font$$},$app$main$data$fonts$add_font_55874$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55876$$,$meta55875__$1$$){return new $app$main$data$fonts$add_font_55874$$(this.font,$meta55875__$1$$)},$app$main$data$fonts$add_font_55874$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55875$},$app$main$data$fonts$add_font_55874$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$fonts$add_font_55874$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1844$$,$state$jscomp$287$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$287$$,$APP.$cljs$cst$2969$fonts$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.font),this.font)},$app$main$data$fonts$add_font_55874$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_font_55874$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1845_team_id$jscomp$75$$,$state$jscomp$288$$){$_$jscomp$1845_team_id$jscomp$75$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$288$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-font",$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1845_team_id$jscomp$75$$,$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.font),
$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$(this.font),$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$(this.font),$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$(this.font)],null)))});return new $app$main$data$fonts$add_font_55874$$($font$jscomp$33$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$file_deleted$$=function($project_id$jscomp$18$$){typeof $app$main$data$dashboard$file_deleted_73006$$==="undefined"&&($app$main$data$dashboard$file_deleted_73006$$=function($project_id$jscomp$19$$,$meta73007$$){this.$project_id$=$project_id$jscomp$19$$;this.$meta73007$=$meta73007$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$file_deleted_73006$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$file_deleted_73006$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4950$app_DOT_main_DOT_data_DOT_dashboard_SLASH_file_deleted$$},$app$main$data$dashboard$file_deleted_73006$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73008$$,$meta73007__$1$$){return new $app$main$data$dashboard$file_deleted_73006$$(this.$project_id$,$meta73007__$1$$)},$app$main$data$dashboard$file_deleted_73006$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73007$},$app$main$data$dashboard$file_deleted_73006$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$file_deleted_73006$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2739$$,$state$jscomp$1044$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$1044$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.$project_id$,
$APP.$cljs$cst$1080$count$$],null),$APP.$cljs$core$dec$$)});return new $app$main$data$dashboard$file_deleted_73006$$($project_id$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$projects_fetched$$=function($projects$jscomp$1$$){typeof $app$main$data$dashboard$projects_fetched_72818$$==="undefined"&&($app$main$data$dashboard$projects_fetched_72818$$=function($projects$jscomp$2$$,$meta72819$$){this.projects=$projects$jscomp$2$$;this.$meta72819$=$meta72819$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$projects_fetched_72818$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$projects_fetched_72818$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4907$app_DOT_main_DOT_data_DOT_dashboard_SLASH_projects_fetched$$},$app$main$data$dashboard$projects_fetched_72818$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72820$$,$meta72819__$1$$){return new $app$main$data$dashboard$projects_fetched_72818$$(this.projects,$meta72819__$1$$)},$app$main$data$dashboard$projects_fetched_72818$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72819$},$app$main$data$dashboard$projects_fetched_72818$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$projects_fetched_72818$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2708$$,$state$jscomp$1021$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$51$$,$map__72822__$1_p__72821$$){$map__72822__$1_p__72821$$=$APP.$cljs$core$__destructure_map$$($map__72822__$1_p__72821$$);
var $id$jscomp$809$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72822__$1_p__72821$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$assoc_in$$($state__$1$jscomp$51$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,$id$jscomp$809$$],null),$map__72822__$1_p__72821$$)},$state$jscomp$1021$$,this.projects)});return new $app$main$data$dashboard$projects_fetched_72818$$($projects$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$clear_progress$$=function(){typeof $app$main$data$common$clear_progress_52598$$==="undefined"&&($app$main$data$common$clear_progress_52598$$=function($meta52599$$){this.$meta52599$=$meta52599$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$clear_progress_52598$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$clear_progress_52598$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2507$app_DOT_main_DOT_data_DOT_common_SLASH_clear_progress$$},$app$main$data$common$clear_progress_52598$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52600$$,$meta52599__$1$$){return new $app$main$data$common$clear_progress_52598$$($meta52599__$1$$)},$app$main$data$common$clear_progress_52598$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52599$},$app$main$data$common$clear_progress_52598$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$clear_progress_52598$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1547$$,$state$jscomp$129$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$129$$,$APP.$cljs$cst$2244$progress$$)});return new $app$main$data$common$clear_progress_52598$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$deleted_files_fetched$$=function($files$jscomp$16$$){typeof $app$main$data$dashboard$deleted_files_fetched_72859$$==="undefined"&&($app$main$data$dashboard$deleted_files_fetched_72859$$=function($files$jscomp$17$$,$meta72860$$){this.files=$files$jscomp$17$$;this.$meta72860$=$meta72860$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$deleted_files_fetched_72859$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$deleted_files_fetched_72859$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4921$app_DOT_main_DOT_data_DOT_dashboard_SLASH_deleted_files_fetched$$},$app$main$data$dashboard$deleted_files_fetched_72859$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72861$$,$meta72860__$1$$){return new $app$main$data$dashboard$deleted_files_fetched_72859$$(this.files,$meta72860__$1$$)},$app$main$data$dashboard$deleted_files_fetched_72859$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72860$},$app$main$data$dashboard$deleted_files_fetched_72859$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$deleted_files_fetched_72859$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2716_files__$1$jscomp$3_filtered_files$$,$state$jscomp$1027$$){var $now$jscomp$7$$=$APP.$app$common$time$now$$();$_$jscomp$2716_files__$1$jscomp$3_filtered_files$$=$APP.$cljs$core$filterv$$(function($file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$){$file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$=
$APP.$cljs$cst$4922$will_be_deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$);var $JSCompiler_temp$jscomp$1977$$;($JSCompiler_temp$jscomp$1977$$=$file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$==null)||($file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$=$APP.$cljs$core$compare$$($file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$,$now$jscomp$7$$),$JSCompiler_temp$jscomp$1977$$=$file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$<
0?!1:$file$jscomp$80_result$jscomp$inline_9480_will_be_deleted_at$$===0?!1:!0);return $JSCompiler_temp$jscomp$1977$$},this.files);$_$jscomp$2716_files__$1$jscomp$3_filtered_files$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$_$jscomp$2716_files__$1$jscomp$3_filtered_files$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1027$$,$APP.$cljs$cst$4923$deleted_files$$,
$_$jscomp$2716_files__$1$jscomp$3_filtered_files$$),$APP.$cljs$cst$1916$files$$,$APP.$app$common$data$merge$$,$_$jscomp$2716_files__$1$jscomp$3_filtered_files$$)});return new $app$main$data$dashboard$deleted_files_fetched_72859$$($files$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$recent_files_fetched$$=function($files$jscomp$14$$){typeof $app$main$data$dashboard$recent_files_fetched_72835$$==="undefined"&&($app$main$data$dashboard$recent_files_fetched_72835$$=function($files$jscomp$15$$,$meta72836$$){this.files=$files$jscomp$15$$;this.$meta72836$=$meta72836$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$recent_files_fetched_72835$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$recent_files_fetched_72835$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4913$app_DOT_main_DOT_data_DOT_dashboard_SLASH_recent_files_fetched$$},$app$main$data$dashboard$recent_files_fetched_72835$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72837$$,$meta72836__$1$$){return new $app$main$data$dashboard$recent_files_fetched_72835$$(this.files,$meta72836__$1$$)},$app$main$data$dashboard$recent_files_fetched_72835$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72836$},$app$main$data$dashboard$recent_files_fetched_72835$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$recent_files_fetched_72835$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2712_files__$1$jscomp$2$$,$state$jscomp$1024$$){$_$jscomp$2712_files__$1$jscomp$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.files);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1024$$,
$APP.$cljs$cst$4914$recent_files$$,$_$jscomp$2712_files__$1$jscomp$2$$),$APP.$cljs$cst$1916$files$$,$APP.$app$common$data$merge$$,$_$jscomp$2712_files__$1$jscomp$2$$)});return new $app$main$data$dashboard$recent_files_fetched_72835$$($files$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$files_fetched$$=function($project_id$jscomp$11$$,$files$jscomp$11$$){typeof $app$main$data$project$files_fetched_55804$$==="undefined"&&($app$main$data$project$files_fetched_55804$$=function($project_id$jscomp$12$$,$files$jscomp$12$$,$meta55805$$){this.$project_id$=$project_id$jscomp$12$$;this.files=$files$jscomp$12$$;this.$meta55805$=$meta55805$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$files_fetched_55804$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$files_fetched_55804$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3514$app_DOT_main_DOT_data_DOT_project_SLASH_files_fetched$$},$app$main$data$project$files_fetched_55804$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55806$$,$meta55805__$1$$){return new $app$main$data$project$files_fetched_55804$$(this.$project_id$,this.files,$meta55805__$1$$)},$app$main$data$project$files_fetched_55804$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55805$},$app$main$data$project$files_fetched_55804$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$files_fetched_55804$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1860$$,$state$jscomp$302$$){var $self__$jscomp$4089$$=this;return $APP.$app$common$data$update_in_when$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$302$$,$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$merge$$,
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$self__$jscomp$4089$$.files)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,$self__$jscomp$4089$$.$project_id$],null),function($project$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$2$$,$APP.$cljs$cst$1080$count$$,$APP.$cljs$core$count$$($self__$jscomp$4089$$.files))})});return new $app$main$data$project$files_fetched_55804$$($project_id$jscomp$11$$,
$files$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$stats_fetched$$=function($team_id$jscomp$43$$,$stats$$){typeof $app$main$data$team$stats_fetched_55460$$==="undefined"&&($app$main$data$team$stats_fetched_55460$$=function($team_id$jscomp$44$$,$stats$jscomp$1$$,$meta55461$$){this.$team_id$=$team_id$jscomp$44$$;this.$stats$=$stats$jscomp$1$$;this.$meta55461$=$meta55461$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$stats_fetched_55460$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$stats_fetched_55460$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3279$app_DOT_main_DOT_data_DOT_team_SLASH_stats_fetched$$},$app$main$data$team$stats_fetched_55460$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55462$$,$meta55461__$1$$){return new $app$main$data$team$stats_fetched_55460$$(this.$team_id$,this.$stats$,$meta55461__$1$$)},$app$main$data$team$stats_fetched_55460$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55461$},$app$main$data$team$stats_fetched_55460$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$stats_fetched_55460$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1712$$,$state$jscomp$218$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$218$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2173$teams$$,
this.$team_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3280$stats$$,this.$stats$)});return new $app$main$data$team$stats_fetched_55460$$($team_id$jscomp$43$$,$stats$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$organization$apply_organization$$=function($team$jscomp$8$$,$organization$$){var $id$jscomp$808$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($organization$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$142$$,$p__72772_team_k$$){var $org_k_v$jscomp$624$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72772_team_k$$,0,null);$p__72772_team_k$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72772_team_k$$,
1,null);$org_k_v$jscomp$624$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($organization$$,$org_k_v$jscomp$624$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($id$jscomp$808$$)?$org_k_v$jscomp$624$$!=null:$id$jscomp$808$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$142$$,$p__72772_team_k$$,$org_k_v$jscomp$624$$):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$142$$,$p__72772_team_k$$)},$team$jscomp$8$$,$APP.$app$common$types$organization$organization__GT_team_keys$$)};
$app$main$data$common$toggle_progress_visibility$$=function(){typeof $app$main$data$common$toggle_progress_visibility_52584$$==="undefined"&&($app$main$data$common$toggle_progress_visibility_52584$$=function($meta52585$$){this.$meta52585$=$meta52585$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$toggle_progress_visibility_52584$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$toggle_progress_visibility_52584$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2506$app_DOT_main_DOT_data_DOT_common_SLASH_toggle_progress_visibility$$},$app$main$data$common$toggle_progress_visibility_52584$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52586$$,$meta52585__$1$$){return new $app$main$data$common$toggle_progress_visibility_52584$$($meta52585__$1$$)},$app$main$data$common$toggle_progress_visibility_52584$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52585$},$app$main$data$common$toggle_progress_visibility_52584$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$toggle_progress_visibility_52584$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1546$$,$state$jscomp$128$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$128$$,$APP.$cljs$cst$2244$progress$$,function($state__$1$jscomp$10$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$10$$,$APP.$cljs$cst$2346$visible$$,$APP.$cljs$core$not$$)})});return new $app$main$data$common$toggle_progress_visibility_52584$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$update_progress$$=function($p__52576$$){var $map__52577__$1$$=$APP.$cljs$core$__destructure_map$$($p__52576$$),$index$jscomp$212$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52577__$1$$,$APP.$cljs$cst$1795$index$$),$total$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52577__$1$$,$APP.$cljs$cst$2328$total$$);typeof $app$main$data$common$update_progress_52578$$==="undefined"&&($app$main$data$common$update_progress_52578$$=function($p__52576$jscomp$1$$,
$map__52577$jscomp$1$$,$params$jscomp$154$$,$index$jscomp$213$$,$total$jscomp$8$$,$meta52579$$){this.$p__52576$=$p__52576$jscomp$1$$;this.$map__52577$=$map__52577$jscomp$1$$;this.params=$params$jscomp$154$$;this.index=$index$jscomp$213$$;this.total=$total$jscomp$8$$;this.$meta52579$=$meta52579$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$update_progress_52578$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$update_progress_52578$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2504$app_DOT_main_DOT_data_DOT_common_SLASH_update_progress$$},$app$main$data$common$update_progress_52578$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52580$$,$meta52579__$1$$){return new $app$main$data$common$update_progress_52578$$(this.$p__52576$,this.$map__52577$,this.params,this.index,this.total,$meta52579__$1$$)},$app$main$data$common$update_progress_52578$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta52579$},$app$main$data$common$update_progress_52578$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$update_progress_52578$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1545$$,$state$jscomp$127$$){var $self__$jscomp$3320$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$127$$,$APP.$cljs$cst$2244$progress$$,function($state__$1$jscomp$9$$){var $healthy_QMARK__last_update$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$9$$,$APP.$cljs$cst$2503$last_update$$),$hints$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$9$$,$APP.$cljs$cst$2498$hints$$),$hint$jscomp$7_threshold$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$9$$,$APP.$cljs$cst$2499$slow_progress_threshold$$);$hint$jscomp$7_threshold$jscomp$1$$=($healthy_QMARK__last_update$$=$APP.$app$common$time$diff_ms$$($healthy_QMARK__last_update$$)<
$hint$jscomp$7_threshold$jscomp$1$$)?function(){var $fexpr__52581$$=$APP.$cljs$cst$2023$normal$$.$cljs$core$IFn$_invoke$arity$2$($hints$jscomp$3$$,$APP.$app$main$data$common$noop_fn$$);return $fexpr__52581$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__52581$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3320$$.params):$fexpr__52581$$($self__$jscomp$3320$$.params)}():function(){var $fexpr__52582$$=$APP.$cljs$cst$2505$slow$$.$cljs$core$IFn$_invoke$arity$2$($hints$jscomp$3$$,$APP.$app$main$data$common$noop_fn$$);
return $fexpr__52582$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__52582$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3320$$.params):$fexpr__52582$$($self__$jscomp$3320$$.params)}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$9$$,$APP.$cljs$cst$2244$progress$$,
$self__$jscomp$3320$$.index),$APP.$cljs$cst$2328$total$$,$self__$jscomp$3320$$.total),$APP.$cljs$cst$2503$last_update$$,$APP.$app$common$time$now$$()),$APP.$cljs$cst$2502$healthy$$,$healthy_QMARK__last_update$$),$APP.$cljs$cst$275$hint$$,$hint$jscomp$7_threshold$jscomp$1$$)})});return new $app$main$data$common$update_progress_52578$$($p__52576$$,$map__52577__$1$$,$map__52577__$1$$,$index$jscomp$212$$,$total$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$toggle_file_select$$=function($p__72890$$){var $map__72891__$1$$=$APP.$cljs$core$__destructure_map$$($p__72890$$),$id$jscomp$810$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72891__$1$$,$APP.$cljs$cst$266$id$$),$project_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72891__$1$$,$APP.$cljs$cst$2181$project_id$$);typeof $app$main$data$dashboard$toggle_file_select_72892$$==="undefined"&&($app$main$data$dashboard$toggle_file_select_72892$$=
function($p__72890$jscomp$1$$,$map__72891$jscomp$1$$,$file$jscomp$82$$,$id$jscomp$811$$,$project_id$jscomp$17$$,$meta72893$$){this.$p__72890$=$p__72890$jscomp$1$$;this.$map__72891$=$map__72891$jscomp$1$$;this.file=$file$jscomp$82$$;this.id=$id$jscomp$811$$;this.$project_id$=$project_id$jscomp$17$$;this.$meta72893$=$meta72893$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$toggle_file_select_72892$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_file_select_72892$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4929$app_DOT_main_DOT_data_DOT_dashboard_SLASH_toggle_file_select$$},$app$main$data$dashboard$toggle_file_select_72892$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72894$$,$meta72893__$1$$){return new $app$main$data$dashboard$toggle_file_select_72892$$(this.$p__72890$,this.$map__72891$,this.file,this.id,this.$project_id$,
$meta72893__$1$$)},$app$main$data$dashboard$toggle_file_select_72892$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72893$},$app$main$data$dashboard$toggle_file_select_72892$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_file_select_72892$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2719_selected_project_id$$,$state$jscomp$1030$$){var $self__$jscomp$6813$$=this;$_$jscomp$2719_selected_project_id$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1030$$,$APP.$cljs$cst$2184$selected_project$$);return $_$jscomp$2719_selected_project_id$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2719_selected_project_id$$,$self__$jscomp$6813$$.$project_id$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1030$$,$APP.$cljs$cst$2183$selected_files$$,function($p1__72889_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__72889_SHARP_$$,
$self__$jscomp$6813$$.id)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($p1__72889_SHARP_$$,$self__$jscomp$6813$$.id):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__72889_SHARP_$$,$self__$jscomp$6813$$.id)}),$APP.$cljs$cst$2184$selected_project$$,$self__$jscomp$6813$$.$project_id$):$state$jscomp$1030$$});return new $app$main$data$dashboard$toggle_file_select_72892$$($p__72890$$,$map__72891__$1$$,$map__72891__$1$$,$id$jscomp$810$$,$project_id$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$clear_selected_files$$=function(){typeof $app$main$data$dashboard$clear_file_select_72883$$==="undefined"&&($app$main$data$dashboard$clear_file_select_72883$$=function($meta72884$$){this.$meta72884$=$meta72884$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$clear_file_select_72883$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clear_file_select_72883$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4926$app_DOT_main_DOT_data_DOT_dashboard_SLASH_clear_file_select$$},$app$main$data$dashboard$clear_file_select_72883$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72885$$,$meta72884__$1$$){return new $app$main$data$dashboard$clear_file_select_72883$$($meta72884__$1$$)},$app$main$data$dashboard$clear_file_select_72883$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72884$},$app$main$data$dashboard$clear_file_select_72883$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clear_file_select_72883$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2718$$,$state$jscomp$1029$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1029$$,$APP.$cljs$cst$2183$selected_files$$),$APP.$cljs$cst$2184$selected_project$$),$APP.$cljs$cst$2185$dashboard_local$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4927$menu_open$$,$APP.$cljs$cst$4928$menu_pos$$)});return new $app$main$data$dashboard$clear_file_select_72883$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$hide_file_menu$$=function(){typeof $app$main$data$dashboard$hide_file_menu_72914$$==="undefined"&&($app$main$data$dashboard$hide_file_menu_72914$$=function($meta72915$$){this.$meta72915$=$meta72915$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$hide_file_menu_72914$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$hide_file_menu_72914$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4932$app_DOT_main_DOT_data_DOT_dashboard_SLASH_hide_file_menu$$},$app$main$data$dashboard$hide_file_menu_72914$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72916$$,$meta72915__$1$$){return new $app$main$data$dashboard$hide_file_menu_72914$$($meta72915__$1$$)},$app$main$data$dashboard$hide_file_menu_72914$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72915$},$app$main$data$dashboard$hide_file_menu_72914$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$hide_file_menu_72914$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2722$$,$state$jscomp$1033$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1033$$,$APP.$cljs$cst$2185$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!1)});return new $app$main$data$dashboard$hide_file_menu_72914$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$add_team_to_org$$=function($p__73394$$){var $map__73395__$1$$=$APP.$cljs$core$__destructure_map$$($p__73394$$),$team_id$jscomp$121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73395__$1$$,$APP.$cljs$cst$1927$team_id$$),$organization_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73395__$1$$,$APP.$cljs$cst$3256$organization_id$$);typeof $app$main$data$nitrate$add_team_to_org_73396$$==="undefined"&&($app$main$data$nitrate$add_team_to_org_73396$$=
function($p__73394$jscomp$1$$,$map__73395$jscomp$1$$,$params$jscomp$364$$,$team_id$jscomp$122$$,$organization_id$jscomp$9$$,$meta73397$$){this.$p__73394$=$p__73394$jscomp$1$$;this.$map__73395$=$map__73395$jscomp$1$$;this.params=$params$jscomp$364$$;this.$team_id$=$team_id$jscomp$122$$;this.$organization_id$=$organization_id$jscomp$9$$;this.$meta73397$=$meta73397$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$add_team_to_org_73396$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$add_team_to_org_73396$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5063$app_DOT_main_DOT_data_DOT_nitrate_SLASH_add_team_to_org$$},$app$main$data$nitrate$add_team_to_org_73396$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73398$$,$meta73397__$1$$){return new $app$main$data$nitrate$add_team_to_org_73396$$(this.$p__73394$,this.$map__73395$,this.params,this.$team_id$,this.$organization_id$,
$meta73397__$1$$)},$app$main$data$nitrate$add_team_to_org_73396$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73397$},$app$main$data$nitrate$add_team_to_org_73396$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$add_team_to_org_73396$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$())},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5064$app_DOT_main_DOT_data_DOT_nitrate_SLASH_add_team_to_organization$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,this.$team_id$,$APP.$cljs$cst$3256$organization_id$$,this.$organization_id$],null)))});return new $app$main$data$nitrate$add_team_to_org_73396$$($p__73394$$,$map__73395__$1$$,$map__73395__$1$$,$team_id$jscomp$121$$,$organization_id$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$remove_team_from_org$$=function($p__73384$$){var $map__73385__$1$$=$APP.$cljs$core$__destructure_map$$($p__73384$$),$team_id$jscomp$119$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73385__$1$$,$APP.$cljs$cst$1927$team_id$$),$organization_id$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73385__$1$$,$APP.$cljs$cst$3256$organization_id$$),$organization_name$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73385__$1$$,
$APP.$cljs$cst$3257$organization_name$$);typeof $app$main$data$nitrate$remove_team_from_org_73386$$==="undefined"&&($app$main$data$nitrate$remove_team_from_org_73386$$=function($p__73384$jscomp$1$$,$map__73385$jscomp$1$$,$params$jscomp$362$$,$team_id$jscomp$120$$,$organization_id$jscomp$7$$,$organization_name$jscomp$5$$,$meta73387$$){this.$p__73384$=$p__73384$jscomp$1$$;this.$map__73385$=$map__73385$jscomp$1$$;this.params=$params$jscomp$362$$;this.$team_id$=$team_id$jscomp$120$$;this.$organization_id$=
$organization_id$jscomp$7$$;this.$organization_name$=$organization_name$jscomp$5$$;this.$meta73387$=$meta73387$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$remove_team_from_org_73386$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$remove_team_from_org_73386$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5062$app_DOT_main_DOT_data_DOT_nitrate_SLASH_remove_team_from_org$$},
$app$main$data$nitrate$remove_team_from_org_73386$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73388$$,$meta73387__$1$$){return new $app$main$data$nitrate$remove_team_from_org_73386$$(this.$p__73384$,this.$map__73385$,this.params,this.$team_id$,this.$organization_id$,this.$organization_name$,$meta73387__$1$$)},$app$main$data$nitrate$remove_team_from_org_73386$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73387$},$app$main$data$nitrate$remove_team_from_org_73386$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$remove_team_from_org_73386$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$())},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5062$app_DOT_main_DOT_data_DOT_nitrate_SLASH_remove_team_from_org$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1927$team_id$$,this.$team_id$,
$APP.$cljs$cst$3256$organization_id$$,this.$organization_id$,$APP.$cljs$cst$3257$organization_name$$,this.$organization_name$],null)))});return new $app$main$data$nitrate$remove_team_from_org_73386$$($p__73384$$,$map__73385__$1$$,$map__73385__$1$$,$team_id$jscomp$119$$,$organization_id$jscomp$6$$,$organization_name$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$set_file_shared$$=function($p__73031$$){var $map__73035__$1$$=$APP.$cljs$core$__destructure_map$$($p__73031$$),$id$jscomp$830$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73035__$1$$,$APP.$cljs$cst$266$id$$),$is_shared$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73035__$1$$,$APP.$cljs$cst$2182$is_shared$$);typeof $app$main$data$dashboard$set_file_shared_73036$$==="undefined"&&($app$main$data$dashboard$set_file_shared_73036$$=function($p__73031$jscomp$1$$,
$map__73035$jscomp$1$$,$params$jscomp$341$$,$id$jscomp$831$$,$is_shared$jscomp$4$$,$meta73037$$){this.$p__73031$=$p__73031$jscomp$1$$;this.$map__73035$=$map__73035$jscomp$1$$;this.params=$params$jscomp$341$$;this.id=$id$jscomp$831$$;this.$is_shared$=$is_shared$jscomp$4$$;this.$meta73037$=$meta73037$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$set_file_shared_73036$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$set_file_shared_73036$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4954$app_DOT_main_DOT_data_DOT_dashboard_SLASH_set_file_shared$$},$app$main$data$dashboard$set_file_shared_73036$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73038$$,$meta73037__$1$$){return new $app$main$data$dashboard$set_file_shared_73036$$(this.$p__73031$,this.$map__73035$,this.params,this.id,this.$is_shared$,$meta73037__$1$$)},$app$main$data$dashboard$set_file_shared_73036$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73037$},$app$main$data$dashboard$set_file_shared_73036$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_shared_73036$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3977$shared$$,this.$is_shared$],null)},$app$main$data$dashboard$set_file_shared_73036$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_shared_73036$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__73039__$jscomp$2746$$,$state$jscomp$1047$$){$G__73039__$jscomp$2746$$=$APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$$($state$jscomp$1047$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.id,$APP.$cljs$cst$2182$is_shared$$],null),$APP.$cljs$core$constantly$$(this.$is_shared$)),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4914$recent_files$$,this.id,$APP.$cljs$cst$2182$is_shared$$],null),$APP.$cljs$core$constantly$$(this.$is_shared$));return $APP.$cljs$core$not$$(this.$is_shared$)?$APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__73039__$jscomp$2746$$,$APP.$cljs$cst$2179$shared_files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])):
$G__73039__$jscomp$2746$$},$app$main$data$dashboard$set_file_shared_73036$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_shared_73036$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3978$set_file_shared$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
this.id,$APP.$cljs$cst$2182$is_shared$$,this.$is_shared$],null))),$APP.$cljs$core$truth_$$(this.$is_shared$)?$APP.$beicon$v2$core$map$$(function($summary$jscomp$1$$){return $APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$1$$))>0?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"set-file-variants-shared",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"dashboard"],null)):null},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2480$get_file_summary$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null))):null)});return new $app$main$data$dashboard$set_file_shared_73036$$($p__73031$$,$map__73035__$1$$,$map__73035__$1$$,$id$jscomp$830$$,$is_shared$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_file$$=function($p__73009$$){var $map__73010__$1$$=$APP.$cljs$core$__destructure_map$$($p__73009$$),$id$jscomp$826$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73010__$1$$,$APP.$cljs$cst$266$id$$),$project_id$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73010__$1$$,$APP.$cljs$cst$2181$project_id$$);typeof $app$main$data$dashboard$delete_file_73011$$==="undefined"&&($app$main$data$dashboard$delete_file_73011$$=function($p__73009$jscomp$1$$,
$map__73010$jscomp$1$$,$params$jscomp$337$$,$id$jscomp$827$$,$project_id$jscomp$21$$,$meta73012$$){this.$p__73009$=$p__73009$jscomp$1$$;this.$map__73010$=$map__73010$jscomp$1$$;this.params=$params$jscomp$337$$;this.id=$id$jscomp$827$$;this.$project_id$=$project_id$jscomp$21$$;this.$meta73012$=$meta73012$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_file_73011$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$delete_file_73011$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4951$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_file$$},$app$main$data$dashboard$delete_file_73011$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73013$$,$meta73012__$1$$){return new $app$main$data$dashboard$delete_file_73011$$(this.$p__73009$,this.$map__73010$,this.params,this.id,this.$project_id$,$meta73012__$1$$)},$app$main$data$dashboard$delete_file_73011$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73012$},$app$main$data$dashboard$delete_file_73011$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_file_73011$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2740$$,$state$jscomp$1045$$){return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1045$$,
$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])),$APP.$cljs$cst$2179$shared_files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])),$APP.$cljs$cst$4914$recent_files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id]))},$app$main$data$dashboard$delete_file_73011$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$delete_file_73011$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$dashboard$file_deleted$$,this.$project_id$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4952$delete_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$dashboard$delete_file_73011$$($p__73009$$,
$map__73010__$1$$,$map__73010__$1$$,$id$jscomp$826$$,$project_id$jscomp$20$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($team_id$jscomp$95$$){typeof $app$main$data$dashboard$fetch_deleted_files_72877$$==="undefined"&&($app$main$data$dashboard$fetch_deleted_files_72877$$=function($team_id$jscomp$96$$,$meta72878$$){this.$team_id$=$team_id$jscomp$96$$;this.$meta72878$=$meta72878$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_deleted_files_72877$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_deleted_files_72877$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4924$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_deleted_files$$},$app$main$data$dashboard$fetch_deleted_files_72877$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72879$$,$meta72878__$1$$){return new $app$main$data$dashboard$fetch_deleted_files_72877$$(this.$team_id$,$meta72878__$1$$)},$app$main$data$dashboard$fetch_deleted_files_72877$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72878$},$app$main$data$dashboard$fetch_deleted_files_72877$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_deleted_files_72877$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2717_or__5025__auto__$jscomp$inline_9482$$,$state$jscomp$1028_temp__5825__auto__$jscomp$259$$){$_$jscomp$2717_or__5025__auto__$jscomp$inline_9482$$=this.$team_id$;$state$jscomp$1028_temp__5825__auto__$jscomp$259$$=$APP.$cljs$core$truth_$$($_$jscomp$2717_or__5025__auto__$jscomp$inline_9482$$)?
$_$jscomp$2717_or__5025__auto__$jscomp$inline_9482$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1028_temp__5825__auto__$jscomp$259$$);return $APP.$cljs$core$truth_$$($state$jscomp$1028_temp__5825__auto__$jscomp$259$$)?$APP.$beicon$v2$core$map$$($app$main$data$dashboard$deleted_files_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4925$get_team_deleted_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,
$state$jscomp$1028_temp__5825__auto__$jscomp$259$$],null))):null});return new $app$main$data$dashboard$fetch_deleted_files_72877$$($team_id$jscomp$95$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_builtin_templates$$=function(){typeof $app$main$data$dashboard$fetch_builtin_templates_72852$$==="undefined"&&($app$main$data$dashboard$fetch_builtin_templates_72852$$=function($meta72853$$){this.$meta72853$=$meta72853$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_builtin_templates_72852$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_builtin_templates_72852$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4919$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_builtin_templates$$},$app$main$data$dashboard$fetch_builtin_templates_72852$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72854$$,$meta72853__$1$$){return new $app$main$data$dashboard$fetch_builtin_templates_72852$$($meta72853__$1$$)},$app$main$data$dashboard$fetch_builtin_templates_72852$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72853$},$app$main$data$dashboard$fetch_builtin_templates_72852$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_builtin_templates_72852$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$dashboard$builtin_templates_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4920$get_builtin_templates$$))});return new $app$main$data$dashboard$fetch_builtin_templates_72852$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($team_id$jscomp$93$$){typeof $app$main$data$dashboard$fetch_recent_files_72840$$==="undefined"&&($app$main$data$dashboard$fetch_recent_files_72840$$=function($team_id$jscomp$94$$,$meta72841$$){this.$team_id$=$team_id$jscomp$94$$;this.$meta72841$=$meta72841$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_recent_files_72840$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_recent_files_72840$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4915$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_recent_files$$},$app$main$data$dashboard$fetch_recent_files_72840$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72842$$,$meta72841__$1$$){return new $app$main$data$dashboard$fetch_recent_files_72840$$(this.$team_id$,$meta72841__$1$$)},$app$main$data$dashboard$fetch_recent_files_72840$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72841$},$app$main$data$dashboard$fetch_recent_files_72840$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_recent_files_72840$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2713_or__5025__auto__$jscomp$inline_9484$$,$state$jscomp$1025_temp__5825__auto__$jscomp$258$$){$_$jscomp$2713_or__5025__auto__$jscomp$inline_9484$$=this.$team_id$;$state$jscomp$1025_temp__5825__auto__$jscomp$258$$=$APP.$cljs$core$truth_$$($_$jscomp$2713_or__5025__auto__$jscomp$inline_9484$$)?
$_$jscomp$2713_or__5025__auto__$jscomp$inline_9484$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1025_temp__5825__auto__$jscomp$258$$);return $APP.$cljs$core$truth_$$($state$jscomp$1025_temp__5825__auto__$jscomp$258$$)?$APP.$beicon$v2$core$map$$($app$main$data$dashboard$recent_files_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4916$get_team_recent_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,
$state$jscomp$1025_temp__5825__auto__$jscomp$258$$],null))):null});return new $app$main$data$dashboard$fetch_recent_files_72840$$($team_id$jscomp$93$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_projects$$=function($team_id$jscomp$90$$){typeof $app$main$data$dashboard$fetch_projects_72823$$==="undefined"&&($app$main$data$dashboard$fetch_projects_72823$$=function($team_id$jscomp$91$$,$meta72824$$){this.$team_id$=$team_id$jscomp$91$$;this.$meta72824$=$meta72824$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_projects_72823$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$fetch_projects_72823$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4908$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_projects$$},$app$main$data$dashboard$fetch_projects_72823$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72825$$,$meta72824__$1$$){return new $app$main$data$dashboard$fetch_projects_72823$$(this.$team_id$,$meta72824__$1$$)},$app$main$data$dashboard$fetch_projects_72823$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72824$},$app$main$data$dashboard$fetch_projects_72823$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_projects_72823$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$dashboard$projects_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4909$get_projects$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,
this.$team_id$],null)))});return new $app$main$data$dashboard$fetch_projects_72823$$($team_id$jscomp$90$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($project_id$jscomp$13$$){typeof $app$main$data$project$fetch_files_55817$$==="undefined"&&($app$main$data$project$fetch_files_55817$$=function($project_id$jscomp$14$$,$meta55818$$){this.$project_id$=$project_id$jscomp$14$$;this.$meta55818$=$meta55818$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$fetch_files_55817$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$fetch_files_55817$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3515$app_DOT_main_DOT_data_DOT_project_SLASH_fetch_files$$},$app$main$data$project$fetch_files_55817$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55819$$,$meta55818__$1$$){return new $app$main$data$project$fetch_files_55817$$(this.$project_id$,$meta55818__$1$$)},$app$main$data$project$fetch_files_55817$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55818$},$app$main$data$project$fetch_files_55817$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$fetch_files_55817$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1861_or__5025__auto__$jscomp$inline_9486$$,$state$jscomp$303_temp__5825__auto__$jscomp$196$$){$_$jscomp$1861_or__5025__auto__$jscomp$inline_9486$$=this.$project_id$;$state$jscomp$303_temp__5825__auto__$jscomp$196$$=$APP.$cljs$core$truth_$$($_$jscomp$1861_or__5025__auto__$jscomp$inline_9486$$)?
$_$jscomp$1861_or__5025__auto__$jscomp$inline_9486$$:$APP.$cljs$cst$2174$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$303_temp__5825__auto__$jscomp$196$$);return $APP.$cljs$core$truth_$$($state$jscomp$303_temp__5825__auto__$jscomp$196$$)?$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$project$files_fetched$$,$state$jscomp$303_temp__5825__auto__$jscomp$196$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3516$get_project_files$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2181$project_id$$,$state$jscomp$303_temp__5825__auto__$jscomp$196$$],null))):null});return new $app$main$data$project$fetch_files_55817$$($project_id$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$fetch_stats$$=function(){typeof $app$main$data$team$fetch_stats_55467$$==="undefined"&&($app$main$data$team$fetch_stats_55467$$=function($meta55468$$){this.$meta55468$=$meta55468$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_stats_55467$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_stats_55467$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3281$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_stats$$},
$app$main$data$team$fetch_stats_55467$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55469$$,$meta55468__$1$$){return new $app$main$data$team$fetch_stats_55467$$($meta55468__$1$$)},$app$main$data$team$fetch_stats_55467$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55468$},$app$main$data$team$fetch_stats_55467$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_stats_55467$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1713_team_id$jscomp$45$$,$state$jscomp$219$$){$_$jscomp$1713_team_id$jscomp$45$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$219$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$stats_fetched$$,$_$jscomp$1713_team_id$jscomp$45$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3282$get_team_stats$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1713_team_id$jscomp$45$$],null)))});return new $app$main$data$team$fetch_stats_55467$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$rename_file$$=function($p__73019$$){var $map__73020__$1$$=$APP.$cljs$core$__destructure_map$$($p__73019$$),$id$jscomp$828$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73020__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$391$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73020__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$rename_file_73021$$==="undefined"&&($app$main$data$dashboard$rename_file_73021$$=function($p__73019$jscomp$1$$,
$map__73020$jscomp$1$$,$params$jscomp$339$$,$id$jscomp$829$$,$name$jscomp$392$$,$meta73022$$){this.$p__73019$=$p__73019$jscomp$1$$;this.$map__73020$=$map__73020$jscomp$1$$;this.params=$params$jscomp$339$$;this.id=$id$jscomp$829$$;this.name=$name$jscomp$392$$;this.$meta73022$=$meta73022$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$rename_file_73021$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73021$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4953$app_DOT_main_DOT_data_DOT_dashboard_SLASH_rename_file$$},$app$main$data$dashboard$rename_file_73021$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73023$$,$meta73022__$1$$){return new $app$main$data$dashboard$rename_file_73021$$(this.$p__73019$,this.$map__73020$,this.params,this.id,this.name,$meta73022__$1$$)},$app$main$data$dashboard$rename_file_73021$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73022$},$app$main$data$dashboard$rename_file_73021$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73021$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name],null)},$app$main$data$dashboard$rename_file_73021$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73021$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2743$$,$state$jscomp$1046$$){return $APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$$($state$jscomp$1046$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.id,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$constantly$$(this.name)),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2179$shared_files$$,
this.id,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$constantly$$(this.name)),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4914$recent_files$$,this.id,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$constantly$$(this.name))},$app$main$data$dashboard$rename_file_73021$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73021$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $params__$1$jscomp$45$$=$APP.$cljs$core$select_keys$$(this.params,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$],null));return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4471$rename_file$$,$params__$1$jscomp$45$$))});return new $app$main$data$dashboard$rename_file_73021$$($p__73019$$,$map__73020__$1$$,$map__73020__$1$$,
$id$jscomp$828$$,$name$jscomp$391$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$calculate_family_to_id_mapping$$=function($existing$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__55856_SHARP_$$,$p2__55857_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55856_SHARP_$$,$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($p2__55857_SHARP_$$),$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($p2__55857_SHARP_$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$vals$$($existing$jscomp$2$$))};
$app$main$data$fonts$rename_and_regroup$$=function($current_fonts$jscomp$1$$,$id$jscomp$442$$,$name$jscomp$281$$,$installed_fonts$jscomp$1$$){var $famdb$jscomp$1$$=$app$main$data$fonts$calculate_family_to_id_mapping$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$current_fonts$jscomp$1$$,$installed_fonts$jscomp$1$$]))),$font_id$jscomp$28$$=function(){var $or__5025__auto__$jscomp$640$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($famdb$jscomp$1$$,
$name$jscomp$281$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$640$$)?$or__5025__auto__$jscomp$640$$:$APP.$app$common$uuid$next$$()}();return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($current_fonts$jscomp$1$$,$id$jscomp$442$$,function($font$jscomp$32$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$32$$,$APP.$cljs$cst$1758$font_family$$,$name$jscomp$281$$),$APP.$cljs$cst$1757$font_id$$,
$font_id$jscomp$28$$)})};
$app$main$data$fonts$merge_and_group_fonts$$=function($G__56069_current_fonts_result$jscomp$266$$,$G__56067_famdb_installed_fonts$$,$G__56068_incoming_fonts_items$jscomp$33$$){$G__56067_famdb_installed_fonts$$=$app$main$data$fonts$calculate_family_to_id_mapping$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__56069_current_fonts_result$jscomp$266$$,$G__56067_famdb_installed_fonts$$])));for($G__56068_incoming_fonts_items$jscomp$33$$=$APP.$cljs$core$vals$$($G__56068_incoming_fonts_items$jscomp$33$$);;){var $id$jscomp$441_temp__5823__auto__$jscomp$162$$=
$APP.$cljs$core$first$$($G__56068_incoming_fonts_items$jscomp$33$$);if($APP.$cljs$core$truth_$$($id$jscomp$441_temp__5823__auto__$jscomp$162$$)){var $font_family$jscomp$6_map__55866__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$441_temp__5823__auto__$jscomp$162$$),$font$jscomp$31_item$jscomp$68$$=$font_family$jscomp$6_map__55866__$1$$;$id$jscomp$441_temp__5823__auto__$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_family$jscomp$6_map__55866__$1$$,$APP.$cljs$cst$266$id$$);
$font_family$jscomp$6_map__55866__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_family$jscomp$6_map__55866__$1$$,$APP.$cljs$cst$1758$font_family$$);var $font_id$jscomp$27_or__5025__auto__$jscomp$inline_9488$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__56067_famdb_installed_fonts$$,$font_family$jscomp$6_map__55866__$1$$);$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9488$$=$APP.$cljs$core$truth_$$($font_id$jscomp$27_or__5025__auto__$jscomp$inline_9488$$)?$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9488$$:
$APP.$app$common$uuid$next$$();$font$jscomp$31_item$jscomp$68$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$31_item$jscomp$68$$,$APP.$cljs$cst$1757$font_id$$,$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9488$$);$G__56067_famdb_installed_fonts$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56067_famdb_installed_fonts$$,$font_family$jscomp$6_map__55866__$1$$,$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9488$$);$G__56068_incoming_fonts_items$jscomp$33$$=
$APP.$cljs$core$rest$$($G__56068_incoming_fonts_items$jscomp$33$$);$G__56069_current_fonts_result$jscomp$266$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56069_current_fonts_result$jscomp$266$$,$id$jscomp$441_temp__5823__auto__$jscomp$162$$,$font$jscomp$31_item$jscomp$68$$)}else return $G__56069_current_fonts_result$jscomp$266$$}};
$app$main$data$fonts$update_font$$=function($p__55889$$){var $map__55890__$1$$=$APP.$cljs$core$__destructure_map$$($p__55889$$),$id$jscomp$443$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55890__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55890__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$fonts$update_font_55892$$==="undefined"&&($app$main$data$fonts$update_font_55892$$=function($p__55889$jscomp$1$$,$map__55890$jscomp$1$$,
$params$jscomp$247$$,$id$jscomp$444$$,$name$jscomp$283$$,$meta55893$$){this.$p__55889$=$p__55889$jscomp$1$$;this.$map__55890$=$map__55890$jscomp$1$$;this.params=$params$jscomp$247$$;this.id=$id$jscomp$444$$;this.name=$name$jscomp$283$$;this.$meta55893$=$meta55893$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$update_font_55892$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$update_font_55892$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3502$app_DOT_main_DOT_data_DOT_fonts_SLASH_update_font$$},$app$main$data$fonts$update_font_55892$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55894$$,$meta55893__$1$$){return new $app$main$data$fonts$update_font_55892$$(this.$p__55889$,this.$map__55890$,this.params,this.id,this.name,$meta55893__$1$$)},$app$main$data$fonts$update_font_55892$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55893$},$app$main$data$fonts$update_font_55892$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$update_font_55892$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1846$$,$state$jscomp$289$$){var $self__$jscomp$4051$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$289$$,$APP.$cljs$cst$2969$fonts$$,$APP.$cljs$core$update_vals$$,function($font$jscomp$35$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4051$$.id,$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$35$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$35$$,$APP.$cljs$cst$1758$font_family$$,$self__$jscomp$4051$$.name):$font$jscomp$35$$})},$app$main$data$fonts$update_font_55892$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$update_font_55892$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1847_team_id$jscomp$76$$,$state$jscomp$290$$){$_$jscomp$1847_team_id$jscomp$76$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$290$$);
return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3503$update_font$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1847_team_id$jscomp$76$$],null)))});return new $app$main$data$fonts$update_font_55892$$($p__55889$$,$map__55890__$1$$,$map__55890__$1$$,$id$jscomp$443$$,$name$jscomp$282$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$media$parse_font_style$$=function($JSCompiler_inline_result$jscomp$1978_variant$jscomp$1$$){var $or__5025__auto__$jscomp$inline_9490$$=$APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(italic)(?:[-_\s]|$)/i,$JSCompiler_inline_result$jscomp$1978_variant$jscomp$1$$);$JSCompiler_inline_result$jscomp$1978_variant$jscomp$1$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9490$$)?$or__5025__auto__$jscomp$inline_9490$$:$APP.$cljs$core$re_seq$$(/italic$/i,$JSCompiler_inline_result$jscomp$1978_variant$jscomp$1$$);
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1978_variant$jscomp$1$$)?"italic":"normal"};
$app$common$media$parse_font_weight$$=function($variant$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(hairline|thin)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?100:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(extra\s*light|ultra\s*light)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?200:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(light)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?300:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(normal|regular)(?=(?:[-_\s]|$|italic\b))/i,
$variant$$))?400:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(medium)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?500:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(semi\s*bold|demi\s*bold)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?600:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(extra\s*bold|ultra\s*bold)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?800:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(bold)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?
700:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(extra\s*black|ultra\s*black)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?950:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(black|heavy|solid)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?900:400};
$app$main$data$fonts$delete_font_variant$$=function($id$jscomp$445$$){typeof $app$main$data$fonts$delete_font_variants_55931$$==="undefined"&&($app$main$data$fonts$delete_font_variants_55931$$=function($id$jscomp$446$$,$meta55932$$){this.id=$id$jscomp$446$$;this.$meta55932$=$meta55932$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$delete_font_variants_55931$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$fonts$delete_font_variants_55931$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3506$app_DOT_main_DOT_data_DOT_fonts_SLASH_delete_font_variants$$},$app$main$data$fonts$delete_font_variants_55931$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55933$$,$meta55932__$1$$){return new $app$main$data$fonts$delete_font_variants_55931$$(this.id,$meta55932__$1$$)},$app$main$data$fonts$delete_font_variants_55931$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55932$},$app$main$data$fonts$delete_font_variants_55931$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_variants_55931$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1851$$,$state$jscomp$293$$){var $self__$jscomp$4062$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$293$$,$APP.$cljs$cst$2969$fonts$$,function($variants$jscomp$7$$){return $APP.$app$common$data$removem$$(function($p__55935_variant$jscomp$15$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55935_variant$jscomp$15$$,
0,null);$p__55935_variant$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55935_variant$jscomp$15$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p__55935_variant$jscomp$15$$),$self__$jscomp$4062$$.id)},$variants$jscomp$7$$)})},$app$main$data$fonts$delete_font_variants_55931$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_variants_55931$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1852_team_id$jscomp$78$$,$state$jscomp$294$$){$_$jscomp$1852_team_id$jscomp$78$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$294$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3507$delete_font_variant$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1852_team_id$jscomp$78$$],
null))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-font-variant",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1852_team_id$jscomp$78$$],null))))});return new $app$main$data$fonts$delete_font_variants_55931$$($id$jscomp$445$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$delete_font$$=function($font_id$jscomp$29$$){typeof $app$main$data$fonts$delete_font_55908$$==="undefined"&&($app$main$data$fonts$delete_font_55908$$=function($font_id$jscomp$30$$,$meta55909$$){this.$font_id$=$font_id$jscomp$30$$;this.$meta55909$=$meta55909$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$delete_font_55908$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_55908$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3504$app_DOT_main_DOT_data_DOT_fonts_SLASH_delete_font$$},$app$main$data$fonts$delete_font_55908$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55910$$,$meta55909__$1$$){return new $app$main$data$fonts$delete_font_55908$$(this.$font_id$,$meta55909__$1$$)},$app$main$data$fonts$delete_font_55908$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55909$},$app$main$data$fonts$delete_font_55908$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_55908$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.$font_id$],null)},$app$main$data$fonts$delete_font_55908$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_55908$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1849$$,$state$jscomp$291$$){var $self__$jscomp$4057$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$291$$,$APP.$cljs$cst$2969$fonts$$,function($variants$jscomp$6$$){return $APP.$app$common$data$removem$$(function($p__55923_variant$jscomp$14$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55923_variant$jscomp$14$$,0,null);$p__55923_variant$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55923_variant$jscomp$14$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($p__55923_variant$jscomp$14$$),
$self__$jscomp$4057$$.$font_id$)},$variants$jscomp$6$$)})},$app$main$data$fonts$delete_font_55908$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_55908$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1850_team_id$jscomp$77$$,$state$jscomp$292$$){$_$jscomp$1850_team_id$jscomp$77$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$292$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3505$delete_font$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.$font_id$,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1850_team_id$jscomp$77$$],null))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-font",$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1850_team_id$jscomp$77$$,$APP.$cljs$cst$1757$font_id$$,this.$font_id$],null))))});return new $app$main$data$fonts$delete_font_55908$$($font_id$jscomp$29$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$upload_font_variant$$=function($map__55756__$1_p__55755$$){$map__55756__$1_p__55755$$=$APP.$cljs$core$__destructure_map$$($map__55756__$1_p__55755$$);var $data$jscomp$304$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55756__$1_p__55755$$,$APP.$cljs$cst$142$data$$),$team_id$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55756__$1_p__55755$$,$APP.$cljs$cst$1927$team_id$$),$font_id$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55756__$1_p__55755$$,
$APP.$cljs$cst$1757$font_id$$),$font_family$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55756__$1_p__55755$$,$APP.$cljs$cst$1758$font_family$$),$font_weight$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55756__$1_p__55755$$,$APP.$cljs$cst$1761$font_weight$$),$font_style$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55756__$1_p__55755$$,$APP.$cljs$cst$1762$font_style$$);return $APP.$beicon$v2$core$mapcat$$(function($uploads$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3497$create_font_variant$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$73$$,$APP.$cljs$cst$1757$font_id$$,$font_id$jscomp$26$$,$APP.$cljs$cst$1758$font_family$$,$font_family$jscomp$5$$,$APP.$cljs$cst$1761$font_weight$$,$font_weight$jscomp$10$$,$APP.$cljs$cst$1762$font_style$$,$font_style$jscomp$11$$,$APP.$cljs$cst$3498$uploads$$,$uploads$$],null))},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$121$$,$p__55758_session_id$jscomp$4$$){var $mtype$jscomp$12$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55758_session_id$jscomp$4$$,0,null);$p__55758_session_id$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55758_session_id$jscomp$4$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$121$$,$mtype$jscomp$12$$,$p__55758_session_id$jscomp$4$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($buffer$jscomp$80_p__55763$$){var $mtype$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$80_p__55763$$,
0,null);$buffer$jscomp$80_p__55763$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$80_p__55763$$,1,null);return $APP.$beicon$v2$core$map$$(function($map__55770__$1_p__55769_session_id$jscomp$5$$){$map__55770__$1_p__55769_session_id$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($map__55770__$1_p__55769_session_id$jscomp$5$$);$map__55770__$1_p__55769_session_id$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55770__$1_p__55769_session_id$jscomp$5$$,
$APP.$cljs$cst$2332$session_id$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$mtype$jscomp$13$$,$map__55770__$1_p__55769_session_id$jscomp$5$$],null)},$APP.$app$main$data$uploads$upload_blob_chunked$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(new Blob([$buffer$jscomp$80_p__55763$$],{type:$mtype$jscomp$13$$}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3485$chunk_size$$,10485760])))},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($data$jscomp$304$$)))))};
$app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52566$$){var $map__52567__$1$$=$APP.$cljs$core$__destructure_map$$($p__52566$$),$key$jscomp$328$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52567__$1$$,$APP.$cljs$cst$302$key$$),$index$jscomp$210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52567__$1$$,$APP.$cljs$cst$1795$index$$),$total$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52567__$1$$,
$APP.$cljs$cst$2328$total$$),$hints$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52567__$1$$,$APP.$cljs$cst$2498$hints$$),$slow_progress_threshold$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52567__$1$$,$APP.$cljs$cst$2499$slow_progress_threshold$$);typeof $app$main$data$common$initialize_progress_52568$$==="undefined"&&($app$main$data$common$initialize_progress_52568$$=function($p__52566$jscomp$1$$,$map__52567$jscomp$1$$,$params$jscomp$152$$,$key$jscomp$329$$,
$index$jscomp$211$$,$total$jscomp$6$$,$hints$jscomp$2$$,$slow_progress_threshold$jscomp$1$$,$meta52569$$){this.$p__52566$=$p__52566$jscomp$1$$;this.$map__52567$=$map__52567$jscomp$1$$;this.params=$params$jscomp$152$$;this.key=$key$jscomp$329$$;this.index=$index$jscomp$211$$;this.total=$total$jscomp$6$$;this.$hints$=$hints$jscomp$2$$;this.$slow_progress_threshold$=$slow_progress_threshold$jscomp$1$$;this.$meta52569$=$meta52569$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$common$initialize_progress_52568$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$initialize_progress_52568$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2500$app_DOT_main_DOT_data_DOT_common_SLASH_initialize_progress$$},$app$main$data$common$initialize_progress_52568$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52570$$,$meta52569__$1$$){return new $app$main$data$common$initialize_progress_52568$$(this.$p__52566$,
this.$map__52567$,this.params,this.key,this.index,this.total,this.$hints$,this.$slow_progress_threshold$,$meta52569__$1$$)},$app$main$data$common$initialize_progress_52568$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52569$},$app$main$data$common$initialize_progress_52568$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$initialize_progress_52568$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1544$$,
$state$jscomp$126$$){var $self__$jscomp$3316$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$126$$,$APP.$cljs$cst$2244$progress$$,function(){var $hint$jscomp$6$$=function(){var $fexpr__52575$$=$APP.$cljs$cst$2023$normal$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3316$$.$hints$,$APP.$app$main$data$common$noop_fn$$);return $fexpr__52575$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__52575$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3316$$.params):$fexpr__52575$$($self__$jscomp$3316$$.params)}();
return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2498$hints$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$275$hint$$,$APP.$cljs$cst$2501$threshold$$,$APP.$cljs$cst$2502$healthy$$,$APP.$cljs$cst$2328$total$$,$APP.$cljs$cst$2503$last_update$$,$APP.$cljs$cst$2244$progress$$,$APP.$cljs$cst$2346$visible$$],[$self__$jscomp$3316$$.$hints$,$self__$jscomp$3316$$.key,$hint$jscomp$6$$,function(){var $or__5025__auto__$jscomp$441$$=$self__$jscomp$3316$$.$slow_progress_threshold$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$441$$)?
$or__5025__auto__$jscomp$441$$:5E3}(),!0,$self__$jscomp$3316$$.total,$APP.$app$common$time$now$$(),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3316$$.index,0),!0])})});return new $app$main$data$common$initialize_progress_52568$$($p__52566$$,$map__52567__$1$$,$map__52567__$1$$,$key$jscomp$328$$,$index$jscomp$210$$,$total$jscomp$5$$,$hints$jscomp$1$$,$slow_progress_threshold$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$delete_invitation$$=function($p__55618$$){var $map__55619__$1$$=$APP.$cljs$core$__destructure_map$$($p__55618$$),$email$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55619__$1$$,$APP.$cljs$cst$3183$email$$),$team_id$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55619__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$team$delete_invitation_55620$$==="undefined"&&($app$main$data$team$delete_invitation_55620$$=function($p__55618$jscomp$1$$,
$map__55619$jscomp$1$$,$params$jscomp$214$$,$email$jscomp$7$$,$team_id$jscomp$58$$,$meta55621$$){this.$p__55618$=$p__55618$jscomp$1$$;this.$map__55619$=$map__55619$jscomp$1$$;this.params=$params$jscomp$214$$;this.email=$email$jscomp$7$$;this.$team_id$=$team_id$jscomp$58$$;this.$meta55621$=$meta55621$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$delete_invitation_55620$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$delete_invitation_55620$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3308$app_DOT_main_DOT_data_DOT_team_SLASH_delete_invitation$$},$app$main$data$team$delete_invitation_55620$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55622$$,$meta55621__$1$$){return new $app$main$data$team$delete_invitation_55620$$(this.$p__55618$,this.$map__55619$,this.params,this.email,this.$team_id$,$meta55621__$1$$)},$app$main$data$team$delete_invitation_55620$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55621$},$app$main$data$team$delete_invitation_55620$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_invitation_55620$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55623_on_success$jscomp$17$$=$APP.$cljs$core$meta$$(this.params),$map__55623__$1_on_error$jscomp$21$$=$APP.$cljs$core$__destructure_map$$($map__55623_on_success$jscomp$17$$);$map__55623_on_success$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55623__$1_on_error$jscomp$21$$,
$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__55623__$1_on_error$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55623__$1_on_error$jscomp$21$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55623__$1_on_error$jscomp$21$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55623_on_success$jscomp$17$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3309$delete_team_invitation$$,
this.params)))});return new $app$main$data$team$delete_invitation_55620$$($p__55618$$,$map__55619__$1$$,$map__55619__$1$$,$email$jscomp$6$$,$team_id$jscomp$57$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$set_file_thumbnail$$=function($file_id$jscomp$320$$,$thumbnail_id$$){typeof $app$main$data$dashboard$set_file_thumbnail_73043$$==="undefined"&&($app$main$data$dashboard$set_file_thumbnail_73043$$=function($file_id$jscomp$321$$,$thumbnail_id$jscomp$1$$,$meta73044$$){this.$file_id$=$file_id$jscomp$321$$;this.$thumbnail_id$=$thumbnail_id$jscomp$1$$;this.$meta73044$=$meta73044$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$set_file_thumbnail_73043$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_thumbnail_73043$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4955$app_DOT_main_DOT_data_DOT_dashboard_SLASH_set_file_thumbnail$$},$app$main$data$dashboard$set_file_thumbnail_73043$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73045$$,$meta73044__$1$$){return new $app$main$data$dashboard$set_file_thumbnail_73043$$(this.$file_id$,this.$thumbnail_id$,$meta73044__$1$$)},$app$main$data$dashboard$set_file_thumbnail_73043$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73044$},$app$main$data$dashboard$set_file_thumbnail_73043$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_thumbnail_73043$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2748$$,$state$jscomp$1048$$){var $self__$jscomp$6896$$=this;return $APP.$app$common$data$update_when$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1048$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$self__$jscomp$6896$$.$file_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2573$thumbnail_id$$,$self__$jscomp$6896$$.$thumbnail_id$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4914$recent_files$$,$self__$jscomp$6896$$.$file_id$],null),$APP.$cljs$core$assoc$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2573$thumbnail_id$$,$self__$jscomp$6896$$.$thumbnail_id$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4923$deleted_files$$,$self__$jscomp$6896$$.$file_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2573$thumbnail_id$$,$self__$jscomp$6896$$.$thumbnail_id$])),$APP.$cljs$cst$4956$dashboard_search_result$$,
function($files$jscomp$18$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73042_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6896$$.$file_id$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73042_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__73042_SHARP_$$,$APP.$cljs$cst$2573$thumbnail_id$$,$self__$jscomp$6896$$.$thumbnail_id$):$p1__73042_SHARP_$$},$files$jscomp$18$$)})});return new $app$main$data$dashboard$set_file_thumbnail_73043$$($file_id$jscomp$320$$,
$thumbnail_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$=function($itemsize_limit__$1$jscomp$1$$){var $width_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$th_size_width$jscomp$84$$=$APP.$cljs$core$_deref$$($width_STAR_$$),$rowref$$=(0,$APP.$rumext$v2$use_ref$$)();$itemsize_limit__$1$jscomp$1$$=Math.max(1,Math.min(10,$APP.$app$common$math$floor$$($th_size_width$jscomp$84$$!=null?$th_size_width$jscomp$84$$/($itemsize_limit__$1$jscomp$1$$!=null?
$itemsize_limit__$1$jscomp$1$$:$th_size_width$jscomp$84$$>=1030?280:230):0)));$th_size_width$jscomp$84$$=$APP.$cljs$core$truth_$$($th_size_width$jscomp$84$$)?$APP.$app$common$math$floor$$(($th_size_width$jscomp$84$$-32-($itemsize_limit__$1$jscomp$1$$-1)*24)/$itemsize_limit__$1$jscomp$1$$-12):null;var $th_size__$1$$=$APP.$cljs$core$even_QMARK_$$($th_size_width$jscomp$84$$|0)?$th_size_width$jscomp$84$$:$th_size_width$jscomp$84$$-1;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($th_size__$1$$)],
function(){if($APP.$cljs$core$truth_$$($th_size__$1$$)){var $node$jscomp$283$$=$APP.$rumext$v2$ref_val$$($rowref$$);$node$jscomp$283$$.style.setProperty("--th-width",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($th_size__$1$$),"px"].join(""));return $node$jscomp$283$$.style.setProperty("--th-height",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$math$ceil$$(2/3*$th_size__$1$$)),"px"].join(""))}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $mnt_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!0),$sub$jscomp$14$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($entries$jscomp$12_row_width$$){$entries$jscomp$12_row_width$$=$APP.$cljs$core$first$$($entries$jscomp$12_row_width$$).contentRect.width;return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($mnt_QMARK_$$))?$APP.$cljs$core$reset_BANG_$$($width_STAR_$$,$entries$jscomp$12_row_width$$):null},$app$util$webapi$observe_resize$$($APP.$rumext$v2$ref_val$$($rowref$$)));
return function(){$APP.$cljs$core$_vreset_BANG_$$($mnt_QMARK_$$,!1);return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$14$$)}});return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rowref$$,$itemsize_limit__$1$jscomp$1$$],null)};
$cljs$core$partition_all$cljs$0core$0IFn$0_invoke$0arity$03$$=function($n$jscomp$143$$,$step$jscomp$7$$,$coll$jscomp$739$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$18$$=$APP.$cljs$core$seq$$($coll$jscomp$739$$);return $temp__5825__auto__$jscomp$18$$?$APP.$cljs$core$cons$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$143$$,$temp__5825__auto__$jscomp$18$$),$cljs$core$partition_all$cljs$0core$0IFn$0_invoke$0arity$03$$($n$jscomp$143$$,$step$jscomp$7$$,
$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($step$jscomp$7$$,$temp__5825__auto__$jscomp$18$$))):null},null,null)};
$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$=function($and__5023__auto__$jscomp$606_team$jscomp$14$$,$editors$jscomp$3_profile$jscomp$33$$){var $seats$jscomp$2_subscription$jscomp$8$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$606_team$jscomp$14$$),$subscription_type$jscomp$7$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($seats$jscomp$2_subscription$jscomp$8$$);$seats$jscomp$2_subscription$jscomp$8$$=
$APP.$cljs$cst$5071$seats$$.$cljs$core$IFn$_invoke$arity$1$($seats$jscomp$2_subscription$jscomp$8$$);$editors$jscomp$3_profile$jscomp$33$$=$APP.$cljs$core$count$$($APP.$cljs$cst$3200$editors$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($editors$jscomp$3_profile$jscomp$33$$))));$and__5023__auto__$jscomp$606_team$jscomp$14$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$606_team$jscomp$14$$));
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$606_team$jscomp$14$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$7$$,"unlimited")&&$seats$jscomp$2_subscription$jscomp$8$$<25&&$editors$jscomp$3_profile$jscomp$33$$-$seats$jscomp$2_subscription$jscomp$8$$>=4:$and__5023__auto__$jscomp$606_team$jscomp$14$$};
$app$main$data$common$go_to_dashboard_deleted$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52800$$){var $map__52801__$1$$=$APP.$cljs$core$__destructure_map$$($p__52800$$),$team_id$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52801__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$common$go_to_dashboard_deleted_52806$$==="undefined"&&($app$main$data$common$go_to_dashboard_deleted_52806$$=function($p__52800$jscomp$1$$,$map__52801$jscomp$1$$,$options$jscomp$478$$,
$team_id$jscomp$24$$,$meta52807$$){this.$p__52800$=$p__52800$jscomp$1$$;this.$map__52801$=$map__52801$jscomp$1$$;this.options=$options$jscomp$478$$;this.$team_id$=$team_id$jscomp$24$$;this.$meta52807$=$meta52807$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_deleted_52806$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_deleted_52806$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2535$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_deleted$$},$app$main$data$common$go_to_dashboard_deleted_52806$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52808$$,$meta52807__$1$$){return new $app$main$data$common$go_to_dashboard_deleted_52806$$(this.$p__52800$,this.$map__52801$,this.options,this.$team_id$,$meta52807__$1$$)},$app$main$data$common$go_to_dashboard_deleted_52806$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52807$},
$app$main$data$common$go_to_dashboard_deleted_52806$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_deleted_52806$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1560_profile$jscomp$4$$,$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$){$_$jscomp$1560_profile$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$,$APP.$cljs$cst$1914$profile$$);
$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,this.$team_id$)?$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1560_profile$jscomp$4$$):$APP.$cljs$core$uuid_QMARK_$$(this.$team_id$)?this.$team_id$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$);$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$(),$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2536$dashboard_deleted$$,$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.options])))});return new $app$main$data$common$go_to_dashboard_deleted_52806$$($p__52800$$,
$map__52801__$1$$,$map__52801__$1$$,$team_id$jscomp$23$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$open_selected_file$$=function(){typeof $app$main$data$dashboard$open_selected_file_73106$$==="undefined"&&($app$main$data$dashboard$open_selected_file_73106$$=function($meta73107$$){this.$meta73107$=$meta73107$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$open_selected_file_73106$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$open_selected_file_73106$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4969$app_DOT_main_DOT_data_DOT_dashboard_SLASH_open_selected_file$$},$app$main$data$dashboard$open_selected_file_73106$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73108$$,$meta73107__$1$$){return new $app$main$data$dashboard$open_selected_file_73106$$($meta73107__$1$$)},$app$main$data$dashboard$open_selected_file_73106$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73107$},$app$main$data$dashboard$open_selected_file_73106$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$open_selected_file_73106$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2760_vec__73112$$,$file_id$jscomp$322_state$jscomp$1055$$){$_$jscomp$2760_vec__73112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$322_state$jscomp$1055$$,$APP.$cljs$cst$2183$selected_files$$);$file_id$jscomp$322_state$jscomp$1055$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2760_vec__73112$$,
0,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($_$jscomp$2760_vec__73112$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$322_state$jscomp$1055$$]))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$dashboard$open_selected_file_73106$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$team$webhooks_list_STAR_$$=function($props_73788$$){var $permissions$jscomp$25$$=$props_73788$$.permissions;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-rows main_ui_dashboard_team__webhook-table",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$54$$,$webhook$jscomp$2$$){$out_arr__44124__auto__$jscomp$54$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$webhook_item_STAR_$$,
{webhook:$webhook$jscomp$2$$,permissions:$permissions$jscomp$25$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$2$$)??"")));return $out_arr__44124__auto__$jscomp$54$$},[],$props_73788$$.webhooks)})};
$app$main$ui$dashboard$team$webhooks_hero_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__webhooks-hero-container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team__hero-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.webhooks")}),$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{className:"main_ui_dashboard_team__hero-desc",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.description")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5154$webhook$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))},className:"main_ui_dashboard_team__hero-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.create")})]})};
$app$main$ui$dashboard$team$empty_invitation_table_STAR_$$=function($on_invite_member$jscomp$1_props_73746_route$jscomp$9$$){var $can_invite$jscomp$2$$=$on_invite_member$jscomp$1_props_73746_route$jscomp$9$$.canInvite,$team$jscomp$34$$=$on_invite_member$jscomp$1_props_73746_route$jscomp$9$$.team;$on_invite_member$jscomp$1_props_73746_route$jscomp$9$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);var $invite_email$jscomp$2$$=$APP.$cljs$cst$5122$invite_email$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($on_invite_member$jscomp$1_props_73746_route$jscomp$9$$));
$on_invite_member$jscomp$1_props_73746_route$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$34$$),$APP.$rumext$v2$adapt$$($invite_email$jscomp$2$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5127$invite_members$$,$APP.$cljs$cst$2492$team$$,
$team$jscomp$34$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$2492$team$$,$APP.$cljs$cst$5122$invite_email$$,$invite_email$jscomp$2$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__empty-invitations",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.no-invitations")}),$can_invite$jscomp$2$$?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[(0,$APP.$rumext$v2$jsx$$)("span",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.no-invitations-gather-people")}),(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_invite_member$jscomp$1_props_73746_route$jscomp$9$$,"data-testid":"invite-member",className:"main_ui_dashboard_team__btn-empty-invitations",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invite-profile")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__blank-space"})],null):null]})};
$app$main$ui$dashboard$team$team_members_STAR_$$=function($owner$jscomp$5_props_73737$$){var $profile$jscomp$43$$=$owner$jscomp$5_props_73737$$.profile,$team$jscomp$32$$=$owner$jscomp$5_props_73737$$.team,$members$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$32$$,$APP.$cljs$cst$3264$members$$),$total_members$jscomp$1$$=$APP.$cljs$core$count$$($members$jscomp$10$$);$owner$jscomp$5_props_73737$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($members$jscomp$10$$)],
function(){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1598$is_owner$$,$members$jscomp$10$$)});var $members__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$32$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1598$is_owner$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$,$APP.$cljs$cst$3264$members$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$32$$))))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__dashboard-table main_ui_dashboard_team__team-members",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__title-field-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.member")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__title-field-role",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.role")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-rows",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$team_member_STAR_$$,{member:$owner$jscomp$5_props_73737$$,team:$team$jscomp$32$$,profile:$profile$jscomp$43$$,totalMembers:$total_members$jscomp$1$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$51$$,$item$jscomp$106$$){$out_arr__44124__auto__$jscomp$51$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$team_member_STAR_$$,
{member:$item$jscomp$106$$,team:$team$jscomp$32$$,profile:$profile$jscomp$43$$,totalMembers:$total_members$jscomp$1$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$106$$)??"")));return $out_arr__44124__auto__$jscomp$51$$},[],$members__$1$$)]})]})};
$app$main$ui$dashboard$team$webhooks_page_STAR_$$=function($props_73789_webhooks$jscomp$3$$){var $team$jscomp$39$$=$props_73789_webhooks$jscomp$3$$.team;$props_73789_webhooks$jscomp$3$$=$APP.$cljs$cst$1215$webhooks$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$39$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$39$$)],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-webhooks",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$39$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$39$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_webhooks$$())});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{team:$team$jscomp$39$$,section:$APP.$cljs$cst$5126$dashboard_team_webhooks$$}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_dashboard_team__dashboard-container main_ui_dashboard_team__dashboard-team-webhooks",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhooks_hero_STAR_$$,
{}),$APP.$cljs$core$empty_QMARK_$$($props_73789_webhooks$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__webhooks-empty",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.empty.no-webhooks")}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.empty.add-one")})]}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhooks_list_STAR_$$,
{webhooks:$props_73789_webhooks$jscomp$3$$,permissions:$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$39$$)})]})})]})};
$app$main$ui$dashboard$subscription$members_cta_STAR_$$=function(){return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$cta$cta_STAR_$$,{className:"main_ui_dashboard_subscription__members-cta",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.unlimited-members-extra-editors-cta-title"),children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"span",className:"main_ui_dashboard_subscription__cta-message",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.unlimited-members-extra-editors-cta-text")})})};
$app$main$ui$dashboard$team$team_members_page_STAR_$$=function($props_73741$$){var $profile$jscomp$44$$=$props_73741$$.profile,$team$jscomp$33$$=$props_73741$$.team;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$33$$))],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-members",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$33$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$33$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$33$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{section:$APP.$cljs$cst$5123$dashboard_team_members$$,team:$team$jscomp$33$$}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_dashboard_team__dashboard-container main_ui_dashboard_team__dashboard-team-members",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_members_STAR_$$,{profile:$profile$jscomp$44$$,team:$team$jscomp$33$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$639$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$);return $and__5023__auto__$jscomp$639$$?$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$($team$jscomp$33$$,$profile$jscomp$44$$):$and__5023__auto__$jscomp$639$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$members_cta_STAR_$$,{team:$team$jscomp$33$$}):null]})]})};
$app$main$ui$dashboard$subscription$team_STAR_$$=function($go_to_manage_subscription_props_73519_subscription$jscomp$5$$){var $is_owner$$=$go_to_manage_subscription_props_73519_subscription$jscomp$5$$.isOwner;$go_to_manage_subscription_props_73519_subscription$jscomp$5$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($go_to_manage_subscription_props_73519_subscription$jscomp$5$$.team);var $subscription_type$jscomp$3$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($go_to_manage_subscription_props_73519_subscription$jscomp$5$$),
$subscription_is_trial$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("trialing",$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($go_to_manage_subscription_props_73519_subscription$jscomp$5$$));$go_to_manage_subscription_props_73519_subscription$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-subscription-management",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1366$section$$,"team-settings"],null)));var $href$jscomp$15_href__$1$jscomp$1$$=encodeURIComponent($APP.$app$util$globals$location$$.href);$href$jscomp$15_href__$1$jscomp$1$$=["payments/subscriptions/show?returnUrl\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($href$jscomp$15_href__$1$jscomp$1$$)].join("");
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,$href$jscomp$15_href__$1$jscomp$1$$])))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__team",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_subscription__team-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.team-plan")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__team-text",children:function(){switch($subscription_type$jscomp$3$$){case "professional":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional");case "unlimited":return $subscription_is_trial$jscomp$2$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited");
case "enterprise":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$3$$)].join(""));}}()}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_owner$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$3$$,"professional"):$is_owner$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_to_manage_subscription_props_73519_subscription$jscomp$5$$,
"data-testid":"manage-subscription-link",className:"main_ui_dashboard_subscription__manage-subscription-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription")}):null]})};
$app$main$data$dashboard$restore_files$$=function($p__73203$$){var $map__73204__$1$$=$APP.$cljs$core$__destructure_map$$($p__73203$$),$team_id$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73204__$1$$,$APP.$cljs$cst$1927$team_id$$),$ids$jscomp$265$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73204__$1$$,$APP.$cljs$cst$1723$ids$$),$on_success$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73204__$1$$,$APP.$cljs$cst$2488$on_success$$),
$on_error$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73204__$1$$,$APP.$cljs$cst$1295$on_error$$);typeof $app$main$data$dashboard$restore_files_73205$$==="undefined"&&($app$main$data$dashboard$restore_files_73205$$=function($p__73203$jscomp$1$$,$map__73204$jscomp$1$$,$team_id$jscomp$111$$,$ids$jscomp$266$$,$on_success$jscomp$43$$,$on_error$jscomp$49$$,$meta73206$$){this.$p__73203$=$p__73203$jscomp$1$$;this.$map__73204$=$map__73204$jscomp$1$$;this.$team_id$=$team_id$jscomp$111$$;
this.ids=$ids$jscomp$266$$;this.$on_success$=$on_success$jscomp$43$$;this.$on_error$=$on_error$jscomp$49$$;this.$meta73206$=$meta73206$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$restore_files_73205$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_files_73205$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4978$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_files$$},
$app$main$data$dashboard$restore_files_73205$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73207$$,$meta73206__$1$$){return new $app$main$data$dashboard$restore_files_73205$$(this.$p__73203$,this.$map__73204$,this.$team_id$,this.ids,this.$on_success$,this.$on_error$,$meta73206__$1$$)},$app$main$data$dashboard$restore_files_73205$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73206$},$app$main$data$dashboard$restore_files_73205$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_files_73205$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6962$$=this;return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2499$slow_progress_threshold$$,1E3,$APP.$cljs$cst$2328$total$$,
$APP.$cljs$core$count$$($self__$jscomp$6962$$.ids),$APP.$cljs$cst$2498$hints$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2244$progress$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.restoring-files")},$APP.$cljs$cst$2505$slow$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.slow-restore")}],null)],null)]))),function(){var $stream$jscomp$99$$=$APP.$beicon$v2$core$share$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2261$app_DOT_util_DOT_sse_SLASH_restore_deleted_team_files$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6962$$.$team_id$,$APP.$cljs$cst$1723$ids$$,$self__$jscomp$6962$$.ids],null)));return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$beicon$v2$core$mapcat$$(function($event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$){$event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$=$APP.$app$util$sse$get_payload$$($event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$);
if($APP.$cljs$core$truth_$$($event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$)){var $map__73208__$1_total$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$);$event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73208__$1_total$jscomp$15$$,$APP.$cljs$cst$1795$index$$);$map__73208__$1_total$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73208__$1_total$jscomp$15$$,
$APP.$cljs$cst$2328$total$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$)?$map__73208__$1_total$jscomp$15$$:$event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$common$update_progress$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,$event$jscomp$135_index$jscomp$380_temp__5823__auto__$jscomp$200$$,$APP.$cljs$cst$2328$total$$,$map__73208__$1_total$jscomp$15$$],
null))):$APP.$beicon$v2$core$empty$$()}return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$filter$$($app$util$sse$progress_QMARK_$$,$stream$jscomp$99$$))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$79$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$()),$self__$jscomp$6962$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$6962$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$79$$):
$self__$jscomp$6962$$.$on_error$($error$jscomp$79$$))},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$(),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$6962$$.$team_id$),$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($self__$jscomp$6962$$.$team_id$),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$6962$$.$team_id$)),$self__$jscomp$6962$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$?
$self__$jscomp$6962$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$6962$$.$on_success$())},$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$stream$jscomp$99$$)))))}())});return new $app$main$data$dashboard$restore_files_73205$$($p__73203$$,$map__73204__$1$$,$team_id$jscomp$110$$,$ids$jscomp$265$$,$on_success$jscomp$42$$,$on_error$jscomp$48$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$restore_project_immediately$$=function($p__73231$$){var $map__73232__$1$$=$APP.$cljs$core$__destructure_map$$($p__73231$$),$team_id$jscomp$114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73232__$1$$,$APP.$cljs$cst$1927$team_id$$),$id$jscomp$838$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73232__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$400$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73232__$1$$,$APP.$cljs$cst$725$name$$);
typeof $app$main$data$dashboard$restore_project_immediately_73233$$==="undefined"&&($app$main$data$dashboard$restore_project_immediately_73233$$=function($p__73231$jscomp$1$$,$map__73232$jscomp$1$$,$project$jscomp$14$$,$team_id$jscomp$115$$,$id$jscomp$839$$,$name$jscomp$401$$,$meta73234$$){this.$p__73231$=$p__73231$jscomp$1$$;this.$map__73232$=$map__73232$jscomp$1$$;this.project=$project$jscomp$14$$;this.$team_id$=$team_id$jscomp$115$$;this.id=$id$jscomp$839$$;this.name=$name$jscomp$401$$;this.$meta73234$=
$meta73234$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$restore_project_immediately_73233$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_project_immediately_73233$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4980$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_project_immediately$$},$app$main$data$dashboard$restore_project_immediately_73233$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73235$$,$meta73234__$1$$){return new $app$main$data$dashboard$restore_project_immediately_73233$$(this.$p__73231$,this.$map__73232$,this.project,this.$team_id$,this.id,this.name,$meta73234__$1$$)},$app$main$data$dashboard$restore_project_immediately_73233$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73234$},$app$main$data$dashboard$restore_project_immediately_73233$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_project_immediately_73233$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2771_ids$jscomp$269$$,$state$jscomp$1063$$){var $self__$jscomp$6970$$=this;$_$jscomp$2771_ids$jscomp$269$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$144$$,$file_id$jscomp$324$$,$file$jscomp$86$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$86$$),$self__$jscomp$6970$$.id)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$144$$,$file_id$jscomp$324$$):$acc$jscomp$144$$},
$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1063$$,$APP.$cljs$cst$4923$deleted_files$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-files",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6970$$.$team_id$,
$APP.$cljs$cst$2181$project_id$$,$self__$jscomp$6970$$.id,$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$($_$jscomp$2771_ids$jscomp$269$$)],null)),$app$main$data$dashboard$restore_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6970$$.$team_id$,$APP.$cljs$cst$1723$ids$$,$_$jscomp$2771_ids$jscomp$269$$,$APP.$cljs$cst$2488$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6970$$.name]))))},$APP.$cljs$cst$1295$on_error$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-restoring-project",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6970$$.name]))))}],null)))});return new $app$main$data$dashboard$restore_project_immediately_73233$$($p__73231$$,
$map__73232__$1$$,$map__73232__$1$$,$team_id$jscomp$114$$,$id$jscomp$838$$,$name$jscomp$400$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$restore_files_immediately$$=function($p__73213$$){var $map__73214__$1$$=$APP.$cljs$core$__destructure_map$$($p__73213$$),$team_id$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73214__$1$$,$APP.$cljs$cst$1927$team_id$$),$ids$jscomp$267$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73214__$1$$,$APP.$cljs$cst$1723$ids$$);typeof $app$main$data$dashboard$restore_files_immediately_73215$$==="undefined"&&($app$main$data$dashboard$restore_files_immediately_73215$$=
function($p__73213$jscomp$1$$,$map__73214$jscomp$1$$,$team_id$jscomp$113$$,$ids$jscomp$268$$,$meta73216$$){this.$p__73213$=$p__73213$jscomp$1$$;this.$map__73214$=$map__73214$jscomp$1$$;this.$team_id$=$team_id$jscomp$113$$;this.ids=$ids$jscomp$268$$;this.$meta73216$=$meta73216$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$restore_files_immediately_73215$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$restore_files_immediately_73215$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4979$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_files_immediately$$},$app$main$data$dashboard$restore_files_immediately_73215$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73217$$,$meta73216__$1$$){return new $app$main$data$dashboard$restore_files_immediately_73215$$(this.$p__73213$,this.$map__73214$,this.$team_id$,this.ids,$meta73216__$1$$)},
$app$main$data$dashboard$restore_files_immediately_73215$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73216$},$app$main$data$dashboard$restore_files_immediately_73215$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_files_immediately_73215$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2770$$,$state$jscomp$1062$$){var $self__$jscomp$6966$$=this,$deleted_files$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1062$$,
$APP.$cljs$cst$4923$deleted_files$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-files",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6966$$.$team_id$,$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$($self__$jscomp$6966$$.ids)],null)),$app$main$data$dashboard$restore_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6966$$.$team_id$,$APP.$cljs$cst$1723$ids$$,$self__$jscomp$6966$$.ids,$APP.$cljs$cst$2488$on_success$$,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($self__$jscomp$6966$$.ids))){var $fname$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($deleted_files$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($self__$jscomp$6966$$.ids),
$APP.$cljs$cst$725$name$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-success-notification",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fname$jscomp$1$$]))))}return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-files-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($self__$jscomp$6966$$.ids)]))))},$APP.$cljs$cst$1295$on_error$$,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($self__$jscomp$6966$$.ids))){var $fname$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($deleted_files$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($self__$jscomp$6966$$.ids),
$APP.$cljs$cst$725$name$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-restore-file",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fname$jscomp$2$$]))))}return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.errors.error-on-restore-files")))}],null)))});return new $app$main$data$dashboard$restore_files_immediately_73215$$($p__73213$$,
$map__73214__$1$$,$team_id$jscomp$112$$,$ids$jscomp$267$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_files$$=function($p__73159$$){var $map__73161__$1$$=$APP.$cljs$core$__destructure_map$$($p__73159$$),$team_id$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73161__$1$$,$APP.$cljs$cst$1927$team_id$$),$ids$jscomp$260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73161__$1$$,$APP.$cljs$cst$1723$ids$$),$on_success$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73161__$1$$,$APP.$cljs$cst$2488$on_success$$),
$on_error$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73161__$1$$,$APP.$cljs$cst$1295$on_error$$);typeof $app$main$data$dashboard$delete_files_73162$$==="undefined"&&($app$main$data$dashboard$delete_files_73162$$=function($p__73159$jscomp$1$$,$map__73161$jscomp$1$$,$team_id$jscomp$105$$,$ids$jscomp$261$$,$on_success$jscomp$39$$,$on_error$jscomp$45$$,$meta73163$$){this.$p__73159$=$p__73159$jscomp$1$$;this.$map__73161$=$map__73161$jscomp$1$$;this.$team_id$=$team_id$jscomp$105$$;
this.ids=$ids$jscomp$261$$;this.$on_success$=$on_success$jscomp$39$$;this.$on_error$=$on_error$jscomp$45$$;this.$meta73163$=$meta73163$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_files_73162$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_73162$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4975$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_files$$},
$app$main$data$dashboard$delete_files_73162$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73164$$,$meta73163__$1$$){return new $app$main$data$dashboard$delete_files_73162$$(this.$p__73159$,this.$map__73161$,this.$team_id$,this.ids,this.$on_success$,this.$on_error$,$meta73163__$1$$)},$app$main$data$dashboard$delete_files_73162$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73163$},$app$main$data$dashboard$delete_files_73162$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_73162$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6950$$=this,$stream$jscomp$98$$=$APP.$beicon$v2$core$share$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2266$app_DOT_util_DOT_sse_SLASH_permanently_delete_team_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6950$$.$team_id$,$APP.$cljs$cst$1723$ids$$,
$self__$jscomp$6950$$.ids],null)));return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2499$slow_progress_threshold$$,1E3,$APP.$cljs$cst$2328$total$$,$APP.$cljs$core$count$$($self__$jscomp$6950$$.ids),$APP.$cljs$cst$2498$hints$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2244$progress$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.deleting-files")},$APP.$cljs$cst$2505$slow$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.slow-delete")}],null)],null)]))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$beicon$v2$core$mapcat$$(function($event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$){$event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$=
$APP.$app$util$sse$get_payload$$($event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$);if($APP.$cljs$core$truth_$$($event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$)){var $map__73172__$1_total$jscomp$14$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$);$event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73172__$1_total$jscomp$14$$,$APP.$cljs$cst$1795$index$$);
$map__73172__$1_total$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73172__$1_total$jscomp$14$$,$APP.$cljs$cst$2328$total$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$)?$map__73172__$1_total$jscomp$14$$:$event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$common$update_progress$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,
$event$jscomp$134_index$jscomp$379_temp__5823__auto__$jscomp$199$$,$APP.$cljs$cst$2328$total$$,$map__73172__$1_total$jscomp$14$$],null))):$APP.$beicon$v2$core$empty$$()}return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$filter$$($app$util$sse$progress_QMARK_$$,$stream$jscomp$98$$))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$78$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$()),$self__$jscomp$6950$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$6950$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$78$$):$self__$jscomp$6950$$.$on_error$($error$jscomp$78$$))},$APP.$beicon$v2$core$merge_map$$(function(){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$(),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$6950$$.$team_id$),$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($self__$jscomp$6950$$.$team_id$),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$6950$$.$team_id$)),
$self__$jscomp$6950$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$?$self__$jscomp$6950$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$6950$$.$on_success$())},$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$stream$jscomp$98$$)))))});return new $app$main$data$dashboard$delete_files_73162$$($p__73159$$,$map__73161__$1$$,$team_id$jscomp$104$$,$ids$jscomp$260$$,$on_success$jscomp$38$$,$on_error$jscomp$44$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_project_immediately$$=function($p__73188$$){var $map__73189__$1$$=$APP.$cljs$core$__destructure_map$$($p__73188$$),$team_id$jscomp$108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73189__$1$$,$APP.$cljs$cst$1927$team_id$$),$id$jscomp$836$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73189__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73189__$1$$,$APP.$cljs$cst$725$name$$);
typeof $app$main$data$dashboard$delete_project_immediately_73190$$==="undefined"&&($app$main$data$dashboard$delete_project_immediately_73190$$=function($p__73188$jscomp$1$$,$map__73189$jscomp$1$$,$project$jscomp$12$$,$team_id$jscomp$109$$,$id$jscomp$837$$,$name$jscomp$399$$,$meta73191$$){this.$p__73188$=$p__73188$jscomp$1$$;this.$map__73189$=$map__73189$jscomp$1$$;this.project=$project$jscomp$12$$;this.$team_id$=$team_id$jscomp$109$$;this.id=$id$jscomp$837$$;this.name=$name$jscomp$399$$;this.$meta73191$=
$meta73191$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_project_immediately_73190$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_project_immediately_73190$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4977$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_project_immediately$$},$app$main$data$dashboard$delete_project_immediately_73190$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73192$$,$meta73191__$1$$){return new $app$main$data$dashboard$delete_project_immediately_73190$$(this.$p__73188$,this.$map__73189$,this.project,this.$team_id$,this.id,this.name,$meta73191__$1$$)},$app$main$data$dashboard$delete_project_immediately_73190$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73191$},$app$main$data$dashboard$delete_project_immediately_73190$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_project_immediately_73190$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2768_ids$jscomp$264$$,$state$jscomp$1061$$){var $self__$jscomp$6958$$=this;$_$jscomp$2768_ids$jscomp$264$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$143$$,$file_id$jscomp$323$$,$file$jscomp$85$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$85$$),$self__$jscomp$6958$$.id)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$143$$,$file_id$jscomp$323$$):$acc$jscomp$143$$},
$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1061$$,$APP.$cljs$cst$4923$deleted_files$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-files",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6958$$.$team_id$,
$APP.$cljs$cst$2181$project_id$$,$self__$jscomp$6958$$.id,$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$($_$jscomp$2768_ids$jscomp$264$$)],null)),$app$main$data$dashboard$delete_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6958$$.$team_id$,$APP.$cljs$cst$1723$ids$$,$_$jscomp$2768_ids$jscomp$264$$,$APP.$cljs$cst$2488$on_success$$,function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6958$$.name]))))},$APP.$cljs$cst$1295$on_error$$,function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-delete-project",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6958$$.name]))))}],null)))});return new $app$main$data$dashboard$delete_project_immediately_73190$$($p__73188$$,
$map__73189__$1$$,$map__73189__$1$$,$team_id$jscomp$108$$,$id$jscomp$836$$,$name$jscomp$398$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_files_immediately$$=function($p__73173$$){var $map__73174__$1$$=$APP.$cljs$core$__destructure_map$$($p__73173$$),$team_id$jscomp$106$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73174__$1$$,$APP.$cljs$cst$1927$team_id$$),$ids$jscomp$262$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73174__$1$$,$APP.$cljs$cst$1723$ids$$);typeof $app$main$data$dashboard$delete_files_immediately_73176$$==="undefined"&&($app$main$data$dashboard$delete_files_immediately_73176$$=
function($p__73173$jscomp$1$$,$map__73174$jscomp$1$$,$params$jscomp$354$$,$team_id$jscomp$107$$,$ids$jscomp$263$$,$meta73177$$){this.$p__73173$=$p__73173$jscomp$1$$;this.$map__73174$=$map__73174$jscomp$1$$;this.params=$params$jscomp$354$$;this.$team_id$=$team_id$jscomp$107$$;this.ids=$ids$jscomp$263$$;this.$meta73177$=$meta73177$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_files_immediately_73176$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_immediately_73176$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4976$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_files_immediately$$},$app$main$data$dashboard$delete_files_immediately_73176$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73178$$,$meta73177__$1$$){return new $app$main$data$dashboard$delete_files_immediately_73176$$(this.$p__73173$,this.$map__73174$,this.params,
this.$team_id$,this.ids,$meta73177__$1$$)},$app$main$data$dashboard$delete_files_immediately_73176$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73177$},$app$main$data$dashboard$delete_files_immediately_73176$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_immediately_73176$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2767$$,$state$jscomp$1060$$){var $self__$jscomp$6954$$=this,$deleted_files$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1060$$,$APP.$cljs$cst$4923$deleted_files$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-files",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6954$$.$team_id$,$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$($self__$jscomp$6954$$.ids)],
null)),$app$main$data$dashboard$delete_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6954$$.$team_id$,$APP.$cljs$cst$1723$ids$$,$self__$jscomp$6954$$.ids,$APP.$cljs$cst$2488$on_success$$,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($self__$jscomp$6954$$.ids))){var $fname$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($deleted_files$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($self__$jscomp$6954$$.ids),$APP.$cljs$cst$725$name$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-success-notification",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fname$$]))))}return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-files-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($self__$jscomp$6954$$.ids)]))))},$APP.$cljs$cst$1295$on_error$$,function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.errors.error-on-delete-files")))}],null)))});return new $app$main$data$dashboard$delete_files_immediately_73176$$($p__73173$$,$map__73174__$1$$,$map__73174__$1$$,$team_id$jscomp$106$$,$ids$jscomp$262$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$handle_organization_deleted$$=function($p__73144$$){var $map__73145__$1$$=$APP.$cljs$core$__destructure_map$$($p__73144$$),$organization_name$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73145__$1$$,$APP.$cljs$cst$3257$organization_name$$),$teams$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73145__$1$$,$APP.$cljs$cst$2173$teams$$),$deleted_teams$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73145__$1$$,$APP.$cljs$cst$4973$deleted_teams$$);
typeof $app$main$data$dashboard$handle_organization_deleted_73146$$==="undefined"&&($app$main$data$dashboard$handle_organization_deleted_73146$$=function($p__73144$jscomp$1$$,$map__73145$jscomp$1$$,$organization_name$jscomp$3$$,$teams$jscomp$7$$,$deleted_teams$jscomp$1$$,$meta73147$$){this.$p__73144$=$p__73144$jscomp$1$$;this.$map__73145$=$map__73145$jscomp$1$$;this.$organization_name$=$organization_name$jscomp$3$$;this.teams=$teams$jscomp$7$$;this.$deleted_teams$=$deleted_teams$jscomp$1$$;this.$meta73147$=
$meta73147$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_organization_deleted_73146$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_organization_deleted_73146$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4974$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_organization_deleted$$},$app$main$data$dashboard$handle_organization_deleted_73146$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73148$$,$meta73147__$1$$){return new $app$main$data$dashboard$handle_organization_deleted_73146$$(this.$p__73144$,this.$map__73145$,this.$organization_name$,this.teams,this.$deleted_teams$,$meta73147__$1$$)},$app$main$data$dashboard$handle_organization_deleted_73146$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73147$},$app$main$data$dashboard$handle_organization_deleted_73146$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_organization_deleted_73146$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2765_go_to_default_QMARK__team_id$jscomp$103$$,$fetch_QMARK__state$jscomp$1059$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$)){$_$jscomp$2765_go_to_default_QMARK__team_id$jscomp$103$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($fetch_QMARK__state$jscomp$1059$$);var $notify_QMARK__teams_set$$=$APP.$cljs$core$set$$(this.teams);$notify_QMARK__teams_set$$=$APP.$cljs$core$contains_QMARK_$$($notify_QMARK__teams_set$$,
$_$jscomp$2765_go_to_default_QMARK__team_id$jscomp$103$$);$fetch_QMARK__state$jscomp$1059$$=$APP.$cljs$core$some$$($APP.$cljs$cst$2173$teams$$.$cljs$core$IFn$_invoke$arity$1$($fetch_QMARK__state$jscomp$1059$$),this.teams);$_$jscomp$2765_go_to_default_QMARK__team_id$jscomp$103$$=$APP.$cljs$core$some$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$_$jscomp$2765_go_to_default_QMARK__team_id$jscomp$103$$]),this.$deleted_teams$);return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$($_$jscomp$2765_go_to_default_QMARK__team_id$jscomp$103$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$205$default$$],null)]))):null,$notify_QMARK__teams_set$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.org-deleted",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$organization_name$])),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2353$timeout$$,null],null))):null,$APP.$cljs$core$truth_$$($fetch_QMARK__state$jscomp$1059$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$()):null)}return null});return new $app$main$data$dashboard$handle_organization_deleted_73146$$($p__73144$$,$map__73145__$1$$,
$organization_name$jscomp$2$$,$teams$jscomp$6$$,$deleted_teams$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$handle_user_org_change$$=function($p__73134$$){var $map__73135__$1$$=$APP.$cljs$core$__destructure_map$$($p__73134$$),$organization_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73135__$1$$,$APP.$cljs$cst$3256$organization_id$$),$organization_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73135__$1$$,$APP.$cljs$cst$3257$organization_name$$),$notification$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73135__$1$$,
$APP.$cljs$cst$2359$notification$$);typeof $app$main$data$dashboard$handle_user_org_change_73136$$==="undefined"&&($app$main$data$dashboard$handle_user_org_change_73136$$=function($p__73134$jscomp$1$$,$map__73135$jscomp$1$$,$organization_id$jscomp$4$$,$organization_name$jscomp$1$$,$notification$jscomp$5$$,$meta73137$$){this.$p__73134$=$p__73134$jscomp$1$$;this.$map__73135$=$map__73135$jscomp$1$$;this.$organization_id$=$organization_id$jscomp$4$$;this.$organization_name$=$organization_name$jscomp$1$$;
this.notification=$notification$jscomp$5$$;this.$meta73137$=$meta73137$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_user_org_change_73136$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_user_org_change_73136$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4972$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_user_org_change$$},
$app$main$data$dashboard$handle_user_org_change_73136$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73138$$,$meta73137__$1$$){return new $app$main$data$dashboard$handle_user_org_change_73136$$(this.$p__73134$,this.$map__73135$,this.$organization_id$,this.$organization_name$,this.notification,$meta73137__$1$$)},$app$main$data$dashboard$handle_user_org_change_73136$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73137$},$app$main$data$dashboard$handle_user_org_change_73136$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_user_org_change_73136$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$,$state$jscomp$1058_team$jscomp$11$$){$JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$=this.notification;$JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$):$JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$)?($JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$=
$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1058_team$jscomp$11$$),$state$jscomp$1058_team$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1058_team$jscomp$11$$,$APP.$cljs$cst$2173$teams$$),$JSCompiler_inline_result$jscomp$1979__$jscomp$2764_and__5023__auto__$jscomp$inline_9492_team_id$jscomp$102$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$(this.notification,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$organization_name$])),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2353$timeout$$,null],null)),$APP.$app$main$data$team$fetch_teams$$(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$organization_id$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1058_team$jscomp$11$$))?
$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$205$default$$],null)])):null)):null});return new $app$main$data$dashboard$handle_user_org_change_73136$$($p__73134$$,$map__73135__$1$$,$organization_id$jscomp$3$$,$organization_name$$,$notification$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$handle_change_team_org$$=function($p__73123$$){var $map__73125__$1$$=$APP.$cljs$core$__destructure_map$$($p__73123$$),$team$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73125__$1$$,$APP.$cljs$cst$2492$team$$),$notification$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73125__$1$$,$APP.$cljs$cst$2359$notification$$);typeof $app$main$data$dashboard$handle_change_team_org_73126$$==="undefined"&&($app$main$data$dashboard$handle_change_team_org_73126$$=
function($p__73123$jscomp$1$$,$map__73125$jscomp$1$$,$team$jscomp$10$$,$notification$jscomp$3$$,$meta73127$$){this.$p__73123$=$p__73123$jscomp$1$$;this.$map__73125$=$map__73125$jscomp$1$$;this.team=$team$jscomp$10$$;this.notification=$notification$jscomp$3$$;this.$meta73127$=$meta73127$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4971$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_change_team_org$$},$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73128$$,$meta73127__$1$$){return new $app$main$data$dashboard$handle_change_team_org_73126$$(this.$p__73123$,this.$map__73125$,this.team,this.notification,$meta73127__$1$$)},$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73127$},$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2762_organization$jscomp$1$$,$JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$){$JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$);
$_$jscomp$2762_organization$jscomp$1$$=$APP.$cljs$cst$4901$organization$$.$cljs$core$IFn$_invoke$arity$1$(this.team);var $and__5023__auto__$jscomp$inline_9494_and__5023__auto____$1$jscomp$inline_9495$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$);$and__5023__auto__$jscomp$inline_9494_and__5023__auto____$1$jscomp$inline_9495$$?($and__5023__auto__$jscomp$inline_9494_and__5023__auto____$1$jscomp$inline_9495$$=this.notification,$JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9494_and__5023__auto____$1$jscomp$inline_9495$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.team),$JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$):$and__5023__auto__$jscomp$inline_9494_and__5023__auto____$1$jscomp$inline_9495$$):$JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$=$and__5023__auto__$jscomp$inline_9494_and__5023__auto____$1$jscomp$inline_9495$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1980_current_team_id$jscomp$1_state$jscomp$1056$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$(this.notification,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2762_organization$jscomp$1$$)])),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2353$timeout$$,null],null))):null},$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_org_73126$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2763_team_id$jscomp$101$$,$state$jscomp$1057$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1233$nitrate$$)){$_$jscomp$2763_team_id$jscomp$101$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.team);var $team_name$jscomp$2$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.team),$organization$jscomp$2$$=$APP.$cljs$cst$4901$organization$$.$cljs$core$IFn$_invoke$arity$1$(this.team);return $APP.$app$common$data$update_in_when$$($state$jscomp$1057$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2173$teams$$,
$_$jscomp$2763_team_id$jscomp$101$$],null),function($G__73132_team__$1$$){$G__73132_team__$1$$=$app$common$types$organization$apply_organization$$($G__73132_team__$1$$,$organization$jscomp$2$$);return $APP.$cljs$core$truth_$$($team_name$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73132_team__$1$$,$APP.$cljs$cst$725$name$$,$team_name$jscomp$2$$):$G__73132_team__$1$$})}return $state$jscomp$1057$$});return new $app$main$data$dashboard$handle_change_team_org_73126$$($p__73123$$,
$map__73125__$1$$,$team$jscomp$9$$,$notification$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$duplicate_file$$=function($p__73072$$){var $map__73073__$1$$=$APP.$cljs$core$__destructure_map$$($p__73072$$),$id$jscomp$834$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73073__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$395$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73073__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$duplicate_file_73074$$==="undefined"&&($app$main$data$dashboard$duplicate_file_73074$$=function($p__73072$jscomp$1$$,
$map__73073$jscomp$1$$,$params$jscomp$345$$,$id$jscomp$835$$,$name$jscomp$396$$,$meta73075$$){this.$p__73072$=$p__73072$jscomp$1$$;this.$map__73073$=$map__73073$jscomp$1$$;this.params=$params$jscomp$345$$;this.id=$id$jscomp$835$$;this.name=$name$jscomp$396$$;this.$meta73075$=$meta73075$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$duplicate_file_73074$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$duplicate_file_73074$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4960$app_DOT_main_DOT_data_DOT_dashboard_SLASH_duplicate_file$$},$app$main$data$dashboard$duplicate_file_73074$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73076$$,$meta73075__$1$$){return new $app$main$data$dashboard$duplicate_file_73074$$(this.$p__73072$,this.$map__73073$,this.params,this.id,this.name,$meta73075__$1$$)},$app$main$data$dashboard$duplicate_file_73074$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73075$},$app$main$data$dashboard$duplicate_file_73074$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$duplicate_file_73074$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2753_map__73077_on_success$jscomp$35$$,$new_name$jscomp$34_state$jscomp$1051_unames$jscomp$17$$){$_$jscomp$2753_map__73077_on_success$jscomp$35$$=$APP.$cljs$core$meta$$(this.params);var $map__73077__$1_on_error$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2753_map__73077_on_success$jscomp$35$$);
$_$jscomp$2753_map__73077_on_success$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73077__$1_on_error$jscomp$41$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__73077__$1_on_error$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73077__$1_on_error$jscomp$41$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);$new_name$jscomp$34_state$jscomp$1051_unames$jscomp$17$$=$APP.$app$common$files$helpers$get_used_names$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_name$jscomp$34_state$jscomp$1051_unames$jscomp$17$$,
$APP.$cljs$cst$1916$files$$));$new_name$jscomp$34_state$jscomp$1051_unames$jscomp$17$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(this.name,$new_name$jscomp$34_state$jscomp$1051_unames$jscomp$17$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1628$suffix_fn$$,function($copy_count$jscomp$4$$){return" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.copy-suffix")??"")+(($copy_count$jscomp$4$$>
1?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($copy_count$jscomp$4$$)].join(""):null)??"")}]));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73077__$1_on_error$jscomp$41$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$dashboard$file_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2753_map__73077_on_success$jscomp$35$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4961$duplicate_file$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,this.id,$APP.$cljs$cst$725$name$$,$new_name$jscomp$34_state$jscomp$1051_unames$jscomp$17$$],null)))))});return new $app$main$data$dashboard$duplicate_file_73074$$($p__73072$$,$map__73073__$1$$,$map__73073__$1$$,$id$jscomp$834$$,$name$jscomp$395$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$create_file$$=function($p__73059$$){var $map__73060__$1$$=$APP.$cljs$core$__destructure_map$$($p__73059$$),$project_id$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73060__$1$$,$APP.$cljs$cst$2181$project_id$$),$name$jscomp$393$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73060__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$create_file_73061$$==="undefined"&&($app$main$data$dashboard$create_file_73061$$=function($p__73059$jscomp$1$$,
$map__73060$jscomp$1$$,$params$jscomp$343$$,$project_id$jscomp$25$$,$name$jscomp$394$$,$meta73062$$){this.$p__73059$=$p__73059$jscomp$1$$;this.$map__73060$=$map__73060$jscomp$1$$;this.params=$params$jscomp$343$$;this.$project_id$=$project_id$jscomp$25$$;this.name=$name$jscomp$394$$;this.$meta73062$=$meta73062$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$create_file_73061$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$create_file_73061$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4958$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_file$$},$app$main$data$dashboard$create_file_73061$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73063$$,$meta73062__$1$$){return new $app$main$data$dashboard$create_file_73061$$(this.$p__73059$,this.$map__73060$,this.params,this.$project_id$,this.name,$meta73062__$1$$)},$app$main$data$dashboard$create_file_73061$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73062$},$app$main$data$dashboard$create_file_73061$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_file_73061$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2181$project_id$$,this.$project_id$],null)},$app$main$data$dashboard$create_file_73061$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_file_73061$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$273_map__73067_on_success$jscomp$34$$,$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$){var $self__$jscomp$6906$$=this,$it__$1$jscomp$149$$=this;$it$jscomp$273_map__73067_on_success$jscomp$34$$=$APP.$cljs$core$meta$$($self__$jscomp$6906$$.params);var $map__73067__$1_on_error$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($it$jscomp$273_map__73067_on_success$jscomp$34$$);$it$jscomp$273_map__73067_on_success$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73067__$1_on_error$jscomp$40$$,
$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__73067__$1_on_error$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73067__$1_on_error$jscomp$40$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $files$jscomp$19_name__$1$jscomp$14$$=$APP.$app$main$data$helpers$lookup_team_files$cljs$0core$0IFn$0_invoke$0arity$02$$($features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$,$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$)),
$unames$jscomp$16$$=$APP.$app$common$files$helpers$get_used_names$$($files$jscomp$19_name__$1$jscomp$14$$),$base_name$jscomp$6$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file-prefix");$files$jscomp$19_name__$1$jscomp$14$$=function(){var $or__5025__auto__$jscomp$917$$=$self__$jscomp$6906$$.name;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$917$$)?$or__5025__auto__$jscomp$917$$:$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_name$jscomp$6$$,
$unames$jscomp$16$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,!0]))}();$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$,$APP.$cljs$cst$227$features$$),$APP.$app$common$features$frontend_only_features$$);$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$6906$$.params,$APP.$cljs$cst$725$name$$,$files$jscomp$19_name__$1$jscomp$14$$),$APP.$cljs$cst$227$features$$,$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73067__$1_on_error$jscomp$40$$,$APP.$beicon$v2$core$map$$(function($p1__73058_SHARP_$$){return $APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$file_created$$($p1__73058_SHARP_$$),
$APP.$cljs$core$meta$$($it__$1$jscomp$149$$))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($it$jscomp$273_map__73067_on_success$jscomp$34$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4959$create_file$$,$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1050$$))))});return new $app$main$data$dashboard$create_file_73061$$($p__73059$$,$map__73060__$1$$,$map__73060__$1$$,$project_id$jscomp$24$$,$name$jscomp$393$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$create_project$$=function(){typeof $app$main$data$dashboard$create_project_72938$$==="undefined"&&($app$main$data$dashboard$create_project_72938$$=function($meta72939$$){this.$meta72939$=$meta72939$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$create_project_72938$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_project_72938$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4937$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_project$$},$app$main$data$dashboard$create_project_72938$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72940$$,$meta72939__$1$$){return new $app$main$data$dashboard$create_project_72938$$($meta72939__$1$$)},$app$main$data$dashboard$create_project_72938$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72939$},$app$main$data$dashboard$create_project_72938$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_project_72938$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$,$params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$){$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$);
$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$=$APP.$app$main$data$helpers$lookup_team_projects$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$,$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$);$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$=
$APP.$app$common$files$helpers$get_used_names$$($_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$);var $base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-project-prefix");$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$,
$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,!0]));$params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$);$params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$725$name$$,$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$,$APP.$cljs$cst$1927$team_id$$,$params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$],null);$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$=$APP.$cljs$core$meta$$($params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$);$base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$=
$APP.$cljs$core$__destructure_map$$($_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$);$_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$,
$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($base_name$jscomp$5_map__72944__$1_on_error$jscomp$37$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$dashboard$project_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2727_map__72944_name$jscomp$386_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$97_unames$jscomp$14$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4938$create_project$$,
$params$jscomp$326_state$jscomp$1037_team_id__$1$jscomp$12$$))))});return new $app$main$data$dashboard$create_project_72938$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$process_upload$$=function($blobs_fonts$jscomp$13$$,$team_id$jscomp$74$$){function $parse_mtype$$($G__55833_ba_u8$$){$G__55833_ba_u8$$=new Uint8Array($G__55833_ba_u8$$,0,4);a:{for(var $l__5614__auto__$jscomp$inline_9497$$=$G__55833_ba_u8$$.length,$i$jscomp$inline_9498$$=0,$G__56033$jscomp$inline_9501_ret$jscomp$inline_9499$$="";;)if($i$jscomp$inline_9498$$<$l__5614__auto__$jscomp$inline_9497$$){var $G__56032$jscomp$inline_9500$$=$i$jscomp$inline_9498$$+1;$G__56033$jscomp$inline_9501_ret$jscomp$inline_9499$$=
[$G__56033$jscomp$inline_9501_ret$jscomp$inline_9499$$,$i$jscomp$inline_9498$$===0?"":" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__55833_ba_u8$$[$i$jscomp$inline_9498$$].toString(8))].join("");$i$jscomp$inline_9498$$=$G__56032$jscomp$inline_9500$$}else{$G__55833_ba_u8$$=$G__56033$jscomp$inline_9501_ret$jscomp$inline_9499$$;break a}$G__55833_ba_u8$$=void 0}switch($G__55833_ba_u8$$){case "117 124 124 117":return"font/otf";case "0 1 0 0":return"font/ttf";case "167 117 106 106":return"font/woff";
case "167 117 106 62":return"font/woff2";default:throw Error(["No matching clause: ",$G__55833_ba_u8$$].join(""));}}$blobs_fonts$jscomp$13$$=$APP.$beicon$v2$core$mapcat$$(function($blob$jscomp$23$$){return $APP.$beicon$v2$core$mapcat$$(function($map__55847__$1_p__55846$$){$map__55847__$1_p__55846$$=$APP.$cljs$core$__destructure_map$$($map__55847__$1_p__55846$$);var $type$jscomp$448$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55847__$1_p__55846$$,$APP.$cljs$cst$139$type$$),$error$jscomp$69$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55847__$1_p__55846$$,$APP.$cljs$cst$849$error$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($type$jscomp$448$$)?$type$jscomp$448$$:$error$jscomp$69$$)?(0,$APP.$beicon$v2$core$of$$)($map__55847__$1_p__55846$$):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,
$blob$jscomp$23$$.name],null))},$APP.$beicon$v2$core$map$$(function($data$jscomp$307$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$142$data$$,$data$jscomp$307$$,$APP.$cljs$cst$725$name$$,$blob$jscomp$23$$.name,$APP.$cljs$cst$139$type$$,$parse_mtype$$($data$jscomp$307$$)],null)},$APP.$app$util$webapi$read_file_as_array_buffer$$($blob$jscomp$23$$))))},$APP.$beicon$v2$core$from$$($blobs_fonts$jscomp$13$$));var $errors$jscomp$16$$=$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$122$$,
$font$jscomp$30$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$122$$,["'",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$30$$)),"'"].join(""))},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$filter$$(function($p1__55783_SHARP_$$){return $APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($p1__55783_SHARP_$$)!=null},$blobs_fonts$jscomp$13$$));$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($errors$jscomp$16$$,
function($p1__55784_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$not_empty$$($p1__55784_SHARP_$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$cljs$core$count$$($p1__55784_SHARP_$$)>1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font-plural",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$p1__55784_SHARP_$$)])):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$first$$($p1__55784_SHARP_$$)])))):null});return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($res$jscomp$38$$,$existing$jscomp$1_p__55825_tmp_id$$){var $map__55826__$1$$=$APP.$cljs$core$__destructure_map$$($existing$jscomp$1_p__55825_tmp_id$$),$content$jscomp$158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55826__$1$$,
$APP.$cljs$cst$1637$content$$),$key_fn$jscomp$11$$=$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$03$$();$existing$jscomp$1_p__55825_tmp_id$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55777_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key_fn$jscomp$11$$($map__55826__$1$$),$key_fn$jscomp$11$$($p1__55777_SHARP_$$))},$APP.$cljs$core$vals$$($res$jscomp$38$$));if($APP.$cljs$core$truth_$$($existing$jscomp$1_p__55825_tmp_id$$))return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$38$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($existing$jscomp$1_p__55825_tmp_id$$),function($existing__$1$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($existing__$1$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$158$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$158$$)),$APP.$cljs$cst$3500$names$$,$APP.$cljs$core$conj$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$158$$))});$existing$jscomp$1_p__55825_tmp_id$$=$APP.$app$common$uuid$next$$();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$38$$,$existing$jscomp$1_p__55825_tmp_id$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55826__$1$$,
$APP.$cljs$cst$266$id$$,$existing$jscomp$1_p__55825_tmp_id$$),$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$74$$),$APP.$cljs$cst$3500$names$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$158$$)])),$APP.$cljs$cst$142$data$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$158$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$158$$)])),
$APP.$cljs$cst$1637$content$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$map$$(function($p__55807_type$jscomp$446$$){var $data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$=$APP.$cljs$core$__destructure_map$$($p__55807_type$jscomp$446$$),$font$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$,$APP.$cljs$cst$2716$font$$);$p__55807_type$jscomp$446$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$,
$APP.$cljs$cst$139$type$$);var $name$jscomp$279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$,$APP.$cljs$cst$725$name$$);$data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$,$APP.$cljs$cst$142$data$$);if($APP.$cljs$core$truth_$$($font$jscomp$27$$)){var $base_name$jscomp$2_family$jscomp$6$$=function(){var $or__5025__auto__$jscomp$635$$=
$font$jscomp$27$$.getEnglishName("preferredFamily");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$635$$)?$or__5025__auto__$jscomp$635$$:$font$jscomp$27$$.getEnglishName("fontFamily")}(),$family_name_raw_family_name_variant$jscomp$13$$=function(){var $or__5025__auto__$jscomp$636$$=$font$jscomp$27$$.getEnglishName("preferredSubfamily");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$636$$)?$or__5025__auto__$jscomp$636$$:$font$jscomp$27$$.getEnglishName("fontSubfamily")}(),$height_warning_QMARK__hhea_ascender$$=
$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.hhea.ascender),$hhea_descender$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.hhea.descender),$win_descent$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.usWinDescent),$os2_ascent$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.sTypoAscender),$os2_descent$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.sTypoDescender),$f_selection$$=($font$jscomp$27$$.tables.os2.fsSelection&128)!=0;$height_warning_QMARK__hhea_ascender$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($height_warning_QMARK__hhea_ascender$$,
$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.usWinAscent))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hhea_descender$$,$win_descent$$)||$f_selection$$&&($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($height_warning_QMARK__hhea_ascender$$,$os2_ascent$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hhea_descender$$,$os2_descent$$));$data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$=new Uint8Array($data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$142$data$$,$data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$,$APP.$cljs$cst$725$name$$,$name$jscomp$279$$,$APP.$cljs$cst$139$type$$,$p__55807_type$jscomp$446$$],null),$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$core$truth_$$($base_name$jscomp$2_family$jscomp$6$$)?$base_name$jscomp$2_family$jscomp$6$$:"",$APP.$cljs$cst$1761$font_weight$$,$app$common$media$parse_font_weight$$($family_name_raw_family_name_variant$jscomp$13$$),
$APP.$cljs$cst$1762$font_style$$,$app$common$media$parse_font_style$$($family_name_raw_family_name_variant$jscomp$13$$),$APP.$cljs$cst$2002$variant_name$$,$family_name_raw_family_name_variant$jscomp$13$$,$APP.$cljs$cst$3499$height_warning_QMARK_$$,$height_warning_QMARK__hhea_ascender$$],null)}$base_name$jscomp$2_family$jscomp$6$$=$APP.$cuerdas$core$replace$$($name$jscomp$279$$,/\.[^.]+$/,"");$family_name_raw_family_name_variant$jscomp$13$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($base_name$jscomp$2_family$jscomp$6$$,
/(^|[-_\s])(extra\s*black|ultra\s*black|extra\s*bold|ultra\s*bold|semi\s*bold|demi\s*bold|extra\s*light|ultra\s*light|hairline|thin|light|normal|regular|medium|bold|black|heavy|solid|italic)([-_\s]|$)/i,"$1$3"),/[-_\s]+/," "));$family_name_raw_family_name_variant$jscomp$13$$=$APP.$cuerdas$core$blank_QMARK_$$($family_name_raw_family_name_variant$jscomp$13$$)?$base_name$jscomp$2_family$jscomp$6$$:$family_name_raw_family_name_variant$jscomp$13$$;$data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$=new Uint8Array($data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$142$data$$,$data$jscomp$305_data__$1$jscomp$13_map__55812__$1$$,$APP.$cljs$cst$725$name$$,$name$jscomp$279$$,$APP.$cljs$cst$139$type$$,$p__55807_type$jscomp$446$$],null),$APP.$cljs$cst$1758$font_family$$,$family_name_raw_family_name_variant$jscomp$13$$,$APP.$cljs$cst$1761$font_weight$$,$app$common$media$parse_font_weight$$($base_name$jscomp$2_family$jscomp$6$$),
$APP.$cljs$cst$1762$font_style$$,$app$common$media$parse_font_style$$($base_name$jscomp$2_family$jscomp$6$$),$APP.$cljs$cst$3499$height_warning_QMARK_$$,!1],null)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$map$$(function($map__55836__$1_p__55834$$){$map__55836__$1_p__55834$$=$APP.$cljs$core$__destructure_map$$($map__55836__$1_p__55834$$);var $data$jscomp$306$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55836__$1_p__55834$$,$APP.$cljs$cst$142$data$$),
$type$jscomp$447$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55836__$1_p__55834$$,$APP.$cljs$cst$139$type$$),$name$jscomp$280$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55836__$1_p__55834$$,$APP.$cljs$cst$725$name$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$447$$,"font/woff2"))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55836__$1_p__55834$$,$APP.$cljs$cst$2716$font$$,null);try{return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55836__$1_p__55834$$,
$APP.$cljs$cst$2716$font$$,$APP.$shadow$js$shim$module$0opentype$$.parse($data$jscomp$306$$))}catch($e55844$$){return $APP.$app$common$logging$enabled_QMARK_$$("app.main.data.fonts",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,
$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("skipping file %s, unsupported format",$name$jscomp$280$$):$APP.$cuerdas$core$format$$("skipping file %s, unsupported format",$name$jscomp$280$$)],null)],null)}),null,"app.main.data.fonts",$APP.$cljs$cst$1162$warn$$,!1),null}},$APP.$beicon$v2$core$filter$$(function($p1__55785_SHARP_$$){return $APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($p1__55785_SHARP_$$)==null},
$blobs_fonts$jscomp$13$$)))))};
$app$main$data$team$update_team_photo$$=function($file$jscomp$41$$){typeof $app$main$data$team$update_team_photo_55507$$==="undefined"&&($app$main$data$team$update_team_photo_55507$$=function($file$jscomp$42$$,$meta55508$$){this.file=$file$jscomp$42$$;this.$meta55508$=$meta55508$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$update_team_photo_55507$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_team_photo_55507$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3286$app_DOT_main_DOT_data_DOT_team_SLASH_update_team_photo$$},$app$main$data$team$update_team_photo_55507$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55509$$,$meta55508__$1$$){return new $app$main$data$team$update_team_photo_55507$$(this.file,$meta55508__$1$$)},$app$main$data$team$update_team_photo_55507$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55508$},$app$main$data$team$update_team_photo_55507$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_team_photo_55507$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1716$$,$state$jscomp$222$$){var $team_id$jscomp$49$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$222$$);$APP.$app$main$data$media$notify_start_loading$$();return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55489_SHARP_$$){$APP.$app$main$data$media$notify_finished_loading$$();
return $APP.$app$main$data$media$process_error$$($p1__55489_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"update-team-photo",$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$49$$],null)))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$media$notify_finished_loading$$,
$APP.$beicon$v2$core$mapcat$$(function($p1__55491_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2286$update_team_photo$$,$p1__55491_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__55490_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$1927$team_id$$],[$p1__55490_SHARP_$$,$team_id$jscomp$49$$])},$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,(0,$APP.$beicon$v2$core$of$$)(this.file)))))))});
return new $app$main$data$team$update_team_photo_55507$$($file$jscomp$41$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$team$team_settings_page_STAR_$$=function($nitrate_QMARK_$jscomp$2_props_73791$$){function $on_file_selected$$($file$jscomp$90$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$update_team_photo$$($file$jscomp$90$$))}var $team$jscomp$40$$=$nitrate_QMARK_$jscomp$2_props_73791$$.team;$nitrate_QMARK_$jscomp$2_props_73791$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$);var $finput$$=(0,$APP.$rumext$v2$use_ref$$)(),
$members$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$40$$,$APP.$cljs$cst$3264$members$$),$stats$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$40$$,$APP.$cljs$cst$3280$stats$$),$owner$jscomp$6$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1598$is_owner$$,$members$jscomp$11$$),$permissions$jscomp$26$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),$can_edit$jscomp$2$$=
function(){var $or__5025__auto__$jscomp$967$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$26$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$967$$)?$or__5025__auto__$jscomp$967$$:$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$26$$)}(),$organizations$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$teams$$),$organizations__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organizations$jscomp$1$$)],
function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$team$team__GT_organization$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3256$organization_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,$APP.$cljs$core$vals$$($organizations$jscomp$1$$))))}),$can_change_organization_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organizations__$1$$)],
function(){return $APP.$cljs$core$count$$($organizations__$1$$)>1}),$can_add_to_organization_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organizations__$1$$)],function(){return $APP.$cljs$core$count$$($organizations__$1$$)>0&&$APP.$cljs$core$not$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$))}),$show_org_options_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_org_options_menu_QMARK_$$=
$APP.$cljs$core$_deref$$($show_org_options_menu_STAR_$$),$on_show_options_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$201$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$201$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_org_options_menu_STAR_$$,$APP.$cljs$core$not$$)}),$close_org_options_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_org_options_menu_STAR_$$,
!1)}),$on_image_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($finput$$))}),$remove_team_from_org_fn$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$40$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$remove_team_from_org$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1927$team_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),$APP.$cljs$cst$3256$organization_id$$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),$APP.$cljs$cst$3257$organization_name$$,$APP.$cljs$cst$3257$organization_name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$)],null)))}),$on_remove_team_from_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$40$$)],function(){var $params$jscomp$378$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.remove-team-org.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.remove-team-org.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),$APP.$cljs$cst$3257$organization_name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$)])),
$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.remove-team-org.info"),$APP.$cljs$cst$5157$hint_level$$,$APP.$cljs$cst$205$default$$,$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.remove-team-org.accept"),$APP.$cljs$cst$2479$on_accept$$,$remove_team_from_org_fn$$,$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$5158$danger$$],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($params$jscomp$378$$))}),
$on_add_team_to_org_confirm$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$40$$)],function($organization_id$jscomp$11$$){var $organization$jscomp$4$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73790_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($organization_id$jscomp$11$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73790_SHARP_$$))},$organizations__$1$$);return $APP.$cljs$core$truth_$$($organization$jscomp$4$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$add_team_to_org$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),$APP.$cljs$cst$3256$organization_id$$,$organization_id$jscomp$11$$],null))):null}),$on_add_team_to_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organizations__$1$$),$APP.$rumext$v2$adapt$$($on_add_team_to_org_confirm$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5151$select_organization_modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$5148$organizations$$,$organizations__$1$$,$APP.$cljs$cst$5149$current_organization_id$$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),$APP.$cljs$cst$5140$on_confirm$$,$on_add_team_to_org_confirm$$,
$APP.$cljs$cst$5147$title_key$$,"dashboard.select-org-modal.title",$APP.$cljs$cst$5145$choose_key$$,"dashboard.select-org-modal.choose",$APP.$cljs$cst$5146$placeholder_key$$,"dashboard.select-org-modal.select",$APP.$cljs$cst$5144$accept_key$$,"dashboard.select-org-modal.accept",$APP.$cljs$cst$5150$cancel_key$$,"labels.cancel"],null)))}),$on_change_team_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organizations__$1$$),$APP.$rumext$v2$adapt$$($on_add_team_to_org_confirm$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5151$select_organization_modal$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$5145$choose_key$$,$APP.$cljs$cst$5146$placeholder_key$$,$APP.$cljs$cst$5147$title_key$$,$APP.$cljs$cst$5148$organizations$$,$APP.$cljs$cst$5149$current_organization_id$$,$APP.$cljs$cst$5150$cancel_key$$,$APP.$cljs$cst$5143$text_key$$,$APP.$cljs$cst$5140$on_confirm$$,
$APP.$cljs$cst$5144$accept_key$$],["dashboard.change-org-modal.choose","dashboard.change-org-modal.select","dashboard.change-org-modal.title",$organizations__$1$$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$),"labels.cancel","dashboard.change-org-modal.text",$on_add_team_to_org_confirm$$,"dashboard.change-org-modal.accept"])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$40$$)],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-settings",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$team$fetch_stats$$()]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{section:$APP.$cljs$cst$5124$dashboard_team_settings$$,team:$team$jscomp$40$$}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_dashboard_team__dashboard-team-settings",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__settings-container",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block main_ui_dashboard_team__info-block",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__team-icon",children:[$APP.$cljs$core$truth_$$($can_edit$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_image_click$$,className:"main_ui_dashboard_team__update-overlay",children:$APP.$app$main$ui$dashboard$team$image_icon$$}):null,(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_team_photo_url$$($team$jscomp$40$$),
className:"main_ui_dashboard_team__team-image"}),$APP.$cljs$core$truth_$$($can_edit$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{accept:"image/jpeg,image/png",multi:!1,ref:$finput$$,"on-selected":$on_file_selected$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-info")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-text",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$)})]}),$nitrate_QMARK_$jscomp$2_props_73791$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization")}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-content",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__org-block-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$,{org:$APP.$app$main$data$team$team__GT_organization$$($team$jscomp$40$$),size:"xxxl"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$cljs$cst$3257$organization_name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$)}),
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$642$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$26$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$642$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$40$$)):$and__5023__auto__$jscomp$642$$}())?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"ghost",type:"button",className:($APP.$cljs$core$not$$($show_org_options_menu_QMARK_$$)?"main_ui_dashboard_team__org-options-btn":"")+" "+($APP.$cljs$core$truth_$$($show_org_options_menu_QMARK_$$)?"main_ui_dashboard_team__org-options-btn-open":""),onClick:$on_show_options_click$$,children:[$APP.$app$main$ui$dashboard$team$org_menu_icon$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_org_options_menu_QMARK_$$,"on-close":$close_org_options_menu$$,"dropdown-id":"org-options",
children:(0,$APP.$rumext$v2$jsxs$$)("ul",{role:"listbox",className:"main_ui_dashboard_team__org-dropdown",children:[$APP.$cljs$core$truth_$$($can_change_organization_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_change_team_org$$,className:"main_ui_dashboard_team__org-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.change")}):null,(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_remove_team_from_org$$,className:"main_ui_dashboard_team__org-dropdown-item",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.remove")})]})})]})}):null]})}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-content",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.none")})}),$APP.$cljs$core$truth_$$($can_add_to_organization_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-content",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_add_team_to_org$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.add")})})}):null]})]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-members")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_profile_photo_url$$($owner$jscomp$6$$),className:"main_ui_dashboard_team__owner-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($owner$jscomp$6$$)),
" (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.owner")),")"].join("")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[$APP.$app$main$ui$dashboard$team$user_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.num-of-members",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($members$jscomp$11$$)]))})]})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-projects")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[$APP.$app$main$ui$dashboard$team$group_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-projects",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$cst$1928$projects$$.$cljs$core$IFn$_invoke$arity$1$($stats$jscomp$2$$)-1)]))})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[$APP.$app$main$ui$dashboard$team$document_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($stats$jscomp$2$$))]))})]})]}),
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$team_STAR_$$,{isOwner:$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$26$$),team:$team$jscomp$40$$}):null]})})]})};
$app$main$data$dashboard$handle_change_team_role$$=function($params$jscomp$351$$){typeof $app$main$data$dashboard$handle_change_team_role_73116$$==="undefined"&&($app$main$data$dashboard$handle_change_team_role_73116$$=function($params$jscomp$352$$,$meta73117$$){this.params=$params$jscomp$352$$;this.$meta73117$=$meta73117$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_change_team_role_73116$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_role_73116$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4970$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_change_team_role$$},$app$main$data$dashboard$handle_change_team_role_73116$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73118$$,$meta73117__$1$$){return new $app$main$data$dashboard$handle_change_team_role_73116$$(this.params,$meta73117__$1$$)},$app$main$data$dashboard$handle_change_team_role_73116$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73117$},$app$main$data$dashboard$handle_change_team_role_73116$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_role_73116$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$change_team_role$$(this.params),$APP.$app$main$data$modal$hide$$())});return new $app$main$data$dashboard$handle_change_team_role_73116$$($params$jscomp$351$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$process_message$$=function($map__73154__$1_p__73151$$){$map__73154__$1_p__73151$$=$APP.$cljs$core$__destructure_map$$($map__73154__$1_p__73151$$);var $G__73158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73154__$1_p__73151$$,$APP.$cljs$cst$139$type$$);switch($G__73158$$ instanceof $APP.$cljs$core$Keyword$$?$G__73158$$.$fqn$:null){case "notification":return $APP.$app$main$data$common$handle_notification$$($map__73154__$1_p__73151$$);case "team-role-change":return $app$main$data$dashboard$handle_change_team_role$$($map__73154__$1_p__73151$$);
case "team-membership-change":return $APP.$app$main$data$common$team_membership_change$$($map__73154__$1_p__73151$$);case "team-org-change":return $app$main$data$dashboard$handle_change_team_org$$($map__73154__$1_p__73151$$);case "user-org-change":return $app$main$data$dashboard$handle_user_org_change$$($map__73154__$1_p__73151$$);case "organization-deleted":return $app$main$data$dashboard$handle_organization_deleted$$($map__73154__$1_p__73151$$);default:return null}};
$app$main$data$dashboard$initialize$$=function($team_id$jscomp$87$$){typeof $app$main$data$dashboard$initialize_72808$$==="undefined"&&($app$main$data$dashboard$initialize_72808$$=function($team_id$jscomp$88$$,$meta72809$$){this.$team_id$=$team_id$jscomp$88$$;this.$meta72809$=$meta72809$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$initialize_72808$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$initialize_72808$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4905$app_DOT_main_DOT_data_DOT_dashboard_SLASH_initialize$$},$app$main$data$dashboard$initialize_72808$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72810$$,$meta72809__$1$$){return new $app$main$data$dashboard$initialize_72808$$(this.$team_id$,$meta72809__$1$$)},$app$main$data$dashboard$initialize_72808$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72809$},$app$main$data$dashboard$initialize_72808$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$initialize_72808$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2707_stopper$jscomp$39$$,$state$jscomp$1020$$,$stream$jscomp$97$$){$_$jscomp$2707_stopper$jscomp$39$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4906$app_DOT_main_DOT_data_DOT_dashboard_SLASH_finalize$$),$stream$jscomp$97$$);var $profile_id$jscomp$16$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1020$$);
return $APP.$beicon$v2$core$take_until$$($_$jscomp$2707_stopper$jscomp$39$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$dashboard$fetch_projects$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$dashboard$fetch_projects$$.$cljs$core$IFn$_invoke$arity$1$(this.$team_id$):$app$main$data$dashboard$fetch_projects$$(this.$team_id$),$APP.$app$main$data$fonts$fetch_fonts$$(this.$team_id$)),$APP.$beicon$v2$core$map$$($app$main$data$dashboard$process_message$$,$APP.$beicon$v2$core$filter$$(function($map__72816__$1_p__72815_topic$jscomp$1$$){$map__72816__$1_p__72815_topic$jscomp$1$$=
$APP.$cljs$core$__destructure_map$$($map__72816__$1_p__72815_topic$jscomp$1$$);$map__72816__$1_p__72815_topic$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72816__$1_p__72815_topic$jscomp$1$$,$APP.$cljs$cst$4352$topic$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__72816__$1_p__72815_topic$jscomp$1$$,$APP.$app$common$uuid$zero$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__72816__$1_p__72815_topic$jscomp$1$$,$profile_id$jscomp$16$$)},
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3338$app_DOT_main_DOT_data_DOT_websocket_SLASH_message$$),$stream$jscomp$97$$))))))});return new $app$main$data$dashboard$initialize_72808$$($team_id$jscomp$87$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$fonts$render_font_styles$$=function($font_refs$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$108$$,$css$jscomp$4$$){return""+($acc$jscomp$108$$??"")+"\n"+($css$jscomp$4$$??"")},"",$APP.$beicon$v2$core$mapcat$$($APP.$app$main$fonts$fetch_font_css$$,$APP.$beicon$v2$core$from$$($font_refs$$)))};
$app$main$data$dashboard$search$$=function($params$jscomp$324_params__$1$jscomp$42$$){$params$jscomp$324_params__$1$jscomp$42$$=(0,$APP.$app$main$data$dashboard$check_search_params$$)($params$jscomp$324_params__$1$jscomp$42$$);typeof $app$main$data$dashboard$search_72831$$==="undefined"&&($app$main$data$dashboard$search_72831$$=function($params$jscomp$325$$,$meta72832$$){this.params=$params$jscomp$325$$;this.$meta72832$=$meta72832$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$dashboard$search_72831$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$search_72831$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4910$app_DOT_main_DOT_data_DOT_dashboard_SLASH_search$$},$app$main$data$dashboard$search_72831$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72833$$,$meta72832__$1$$){return new $app$main$data$dashboard$search_72831$$(this.params,$meta72832__$1$$)},$app$main$data$dashboard$search_72831$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72832$},$app$main$data$dashboard$search_72831$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$search_72831$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2710$$,$state$jscomp$1022$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1022$$,$APP.$cljs$cst$4911$search_result$$)},$app$main$data$dashboard$search_72831$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$search_72831$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2711_params__$1$jscomp$43_team_id$jscomp$92$$,$state$jscomp$1023$$){$_$jscomp$2711_params__$1$jscomp$43_team_id$jscomp$92$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1023$$);$_$jscomp$2711_params__$1$jscomp$43_team_id$jscomp$92$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.params,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$2711_params__$1$jscomp$43_team_id$jscomp$92$$);
return $APP.$beicon$v2$core$map$$(function($result$jscomp$322$$){return function($p1__72830_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__72830_SHARP_$$,$APP.$cljs$cst$4911$search_result$$,$result$jscomp$322$$)}},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4912$search_files$$,$_$jscomp$2711_params__$1$jscomp$43_team_id$jscomp$92$$))});return new $app$main$data$dashboard$search_72831$$($params$jscomp$324_params__$1$jscomp$42$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$team$invitation_section_STAR_$$=function($on_delete$jscomp$4_props_73769$$){function $on_error$jscomp$58$$($form$jscomp$177$$){var $map__73774__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($form$jscomp$177$$)),$type$jscomp$594$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73774__$1$$,$APP.$cljs$cst$139$type$$),$code$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73774__$1$$,$APP.$cljs$cst$273$code$$);$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$form$jscomp$177$$]));
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$type$jscomp$594$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5128$profile_is_muted$$,$code$jscomp$48$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()])):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$type$jscomp$594$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5129$max_invitations_by_request$$,$code$jscomp$48$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.maximum-invitations-by-request-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2501$threshold$$.$cljs$core$IFn$_invoke$arity$1$($map__73774__$1$$)])))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$type$jscomp$594$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3382$max_quote_reached$$,$code$jscomp$48$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.max-quote-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2872$target$$.$cljs$core$IFn$_invoke$arity$1$($map__73774__$1$$)])))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5130$member_is_muted$$,$code$jscomp$48$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5131$email_has_permanent_bounces$$,$code$jscomp$48$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5132$email_has_complaints$$,$code$jscomp$48$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-spam-or-permanent-bounces",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($map__73774__$1$$)])))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}var $team$jscomp$35$$=$on_delete$jscomp$4_props_73769$$.team,$permissions$jscomp$21$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$35$$,$APP.$cljs$cst$1722$permissions$$),$invitations$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$35$$,$APP.$cljs$cst$3268$invitations$$)),$team_id$jscomp$127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$35$$,$APP.$cljs$cst$266$id$$),$owner_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($permissions$jscomp$21$$,
$APP.$cljs$cst$1598$is_owner$$),$admin_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($permissions$jscomp$21$$,$APP.$cljs$cst$1597$is_admin$$),$can_invite_QMARK_$$=$APP.$cljs$core$truth_$$($owner_QMARK_$jscomp$2$$)?$owner_QMARK_$jscomp$2$$:$admin_QMARK_$jscomp$1$$,$selected$jscomp$130$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$sort_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$5152$field$$,null,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$5153$asc$$],null)),$selected_invitations$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$130$$),$APP.$rumext$v2$adapt$$($invitations$jscomp$5$$)],function(){return $APP.$cljs$core$filterv$$(function($p1__73766_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($selected$jscomp$130$$),$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($p1__73766_SHARP_$$))},
$APP.$cljs$core$_deref$$($invitations$jscomp$5$$))}),$on_select_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$130$$)],function($email$jscomp$15$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($selected$jscomp$130$$),$email$jscomp$15$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$130$$,$APP.$cljs$core$disj$$,$email$jscomp$15$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$130$$,
$APP.$cljs$core$conj$$,$email$jscomp$15$$)}),$on_confirm_delete$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$130$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$127$$)],function(){for(var $c__5548__auto___73841_seq__73770_73828$$=$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($selected$jscomp$130$$)),$G__73843_chunk__73771_73829$$=null,$G__73844_count__73772_73830$$=0,$G__73842_i__73773_73831$$=0;;)if($G__73842_i__73773_73831$$<$G__73844_count__73772_73830$$){var $email_73832_seq__73770_73840__$1$$=
$G__73843_chunk__73771_73829$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__73842_i__73773_73831$$),$params_73833_temp__5825__auto___73839$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3183$email$$,$email_73832_seq__73770_73840__$1$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$127$$],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_invitation$$($APP.$cljs$core$with_meta$$($params_73833_temp__5825__auto___73839$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2488$on_success$$,function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-deleted")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_invitations$$(),$APP.$app$main$data$modal$hide$$()]))}}($c__5548__auto___73841_seq__73770_73828$$,
$G__73843_chunk__73771_73829$$,$G__73844_count__73772_73830$$,$G__73842_i__73773_73831$$,$params_73833_temp__5825__auto___73839$$,$email_73832_seq__73770_73840__$1$$,$permissions$jscomp$21$$,$invitations$jscomp$5$$,$team_id$jscomp$127$$,$owner_QMARK_$jscomp$2$$,$admin_QMARK_$jscomp$1$$,$can_invite_QMARK_$$,$selected$jscomp$130$$,$sort_state$$,$selected_invitations$$,$on_select_change$jscomp$1$$,$team$jscomp$35$$)],null))));$G__73842_i__73773_73831$$+=1}else if($params_73833_temp__5825__auto___73839$$=
$APP.$cljs$core$seq$$($c__5548__auto___73841_seq__73770_73828$$)){$email_73832_seq__73770_73840__$1$$=$params_73833_temp__5825__auto___73839$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($email_73832_seq__73770_73840__$1$$))$c__5548__auto___73841_seq__73770_73828$$=$APP.$cljs$core$_chunked_first$$($email_73832_seq__73770_73840__$1$$),$G__73842_i__73773_73831$$=$APP.$cljs$core$_chunked_rest$$($email_73832_seq__73770_73840__$1$$),$G__73843_chunk__73771_73829$$=$c__5548__auto___73841_seq__73770_73828$$,
$G__73844_count__73772_73830$$=$APP.$cljs$core$count$$($c__5548__auto___73841_seq__73770_73828$$),$c__5548__auto___73841_seq__73770_73828$$=$G__73842_i__73773_73831$$;else{var $email_73846$$=$APP.$cljs$core$first$$($email_73832_seq__73770_73840__$1$$),$params_73848$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3183$email$$,$email_73846$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$127$$],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_invitation$$($APP.$cljs$core$with_meta$$($params_73848$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-deleted")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_invitations$$(),$APP.$app$main$data$modal$hide$$()]))}}($c__5548__auto___73841_seq__73770_73828$$,
$G__73843_chunk__73771_73829$$,$G__73844_count__73772_73830$$,$G__73842_i__73773_73831$$,$params_73848$$,$email_73846$$,$email_73832_seq__73770_73840__$1$$,$params_73833_temp__5825__auto___73839$$,$permissions$jscomp$21$$,$invitations$jscomp$5$$,$team_id$jscomp$127$$,$owner_QMARK_$jscomp$2$$,$admin_QMARK_$jscomp$1$$,$can_invite_QMARK_$$,$selected$jscomp$130$$,$sort_state$$,$selected_invitations$$,$on_select_change$jscomp$1$$,$team$jscomp$35$$)],null))));$c__5548__auto___73841_seq__73770_73828$$=$APP.$cljs$core$next$$($email_73832_seq__73770_73840__$1$$);
$G__73843_chunk__73771_73829$$=null;$G__73844_count__73772_73830$$=0}$G__73842_i__73773_73831$$=0}else break;return $APP.$cljs$core$reset_BANG_$$($selected$jscomp$130$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)});$on_delete$jscomp$4_props_73769$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_invitations$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$127$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5141$invitation_modal$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1921$selected$$,$selected_invitations$$,$APP.$cljs$cst$4834$delete$$,!0,$APP.$cljs$cst$5140$on_confirm$$,$on_confirm_delete$$],null)))});var $on_resend_success$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-email-sent")),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$team$fetch_invitations$$()]));return $APP.$cljs$core$reset_BANG_$$($selected$jscomp$130$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)}),$on_confirm_resend$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_invitations$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$127$$),$APP.$rumext$v2$adapt$$($on_resend_success$$)],function(){$APP.$app$main$data$modal$hide_BANG_$$();
var $params$jscomp$373$$=$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3268$invitations$$,$selected_invitations$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$127$$,$APP.$cljs$cst$3299$resend_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_resend_success$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$58$$],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$team$create_invitations$$($params$jscomp$373$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$cst$2492$team$$],null)))}),$on_resend$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$127$$),$APP.$rumext$v2$adapt$$($selected_invitations$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5141$invitation_modal$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1921$selected$$,$selected_invitations$$,$APP.$cljs$cst$5140$on_confirm$$,$on_confirm_resend$$],null)))}),$on_order_by_status$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($sort_state$$)],function(){var $current_field$$=$APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$current_direction$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$new_direction$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_field$$,$APP.$cljs$cst$109$status$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_direction$$,$APP.$cljs$cst$5153$asc$$)?$APP.$cljs$cst$2698$desc$$:$APP.$cljs$cst$5153$asc$$:$APP.$cljs$cst$5153$asc$$;$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_deref$$($invitations$jscomp$5$$)]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($sort_state$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5152$field$$,$APP.$cljs$cst$109$status$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1963$direction$$,$new_direction$$]));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($invitations$jscomp$5$$,function($p1__73767_SHARP__sorted$jscomp$1$$){$p1__73767_SHARP__sorted$jscomp$1$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5139$expired$$,
$APP.$cljs$cst$3183$email$$),$p1__73767_SHARP__sorted$jscomp$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_direction$$,$APP.$cljs$cst$2698$desc$$)?$APP.$cljs$core$reverse$$($p1__73767_SHARP__sorted$jscomp$1$$):$p1__73767_SHARP__sorted$jscomp$1$$})}),$on_order_by_role$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($sort_state$$)],function(){var $current_field$jscomp$1$$=$APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$current_direction$jscomp$1$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$new_direction$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_field$jscomp$1$$,$APP.$cljs$cst$2490$role$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_direction$jscomp$1$$,$APP.$cljs$cst$5153$asc$$)?$APP.$cljs$cst$2698$desc$$:$APP.$cljs$cst$5153$asc$$:$APP.$cljs$cst$5153$asc$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($sort_state$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5152$field$$,$APP.$cljs$cst$2490$role$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1963$direction$$,$new_direction$jscomp$1$$]));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($invitations$jscomp$5$$,function($p1__73768_SHARP__sorted$jscomp$2$$){$p1__73768_SHARP__sorted$jscomp$2$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2490$role$$,
$APP.$cljs$cst$3183$email$$),$p1__73768_SHARP__sorted$jscomp$2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_direction$jscomp$1$$,$APP.$cljs$cst$2698$desc$$)?$APP.$cljs$core$reverse$$($p1__73768_SHARP__sorted$jscomp$2$$):$p1__73768_SHARP__sorted$jscomp$2$$})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$35$$)],function(){$APP.$cljs$core$reset_BANG_$$($invitations$jscomp$5$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$35$$,
$APP.$cljs$cst$3268$invitations$$));return $APP.$cljs$core$reset_BANG_$$($sort_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5152$field$$,null,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$5153$asc$$],null))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__invitations",children:[$APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($selected$jscomp$130$$))>0?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_team__invitations-actions",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("team.invitations-selected",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($selected$jscomp$130$$)))]))}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",
type:"button",onClick:$on_resend$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.resend-invitation")})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$on_delete$jscomp$4_props_73769$$,variant:"destructive","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete-invitation"),icon:"delete"})]})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_team__title-field-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invitations")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__title-field-role",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.role"),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$APP.$cljs$cst$2490$role$$)?"main_ui_dashboard_team__sort-active":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$2490$role$$)?"main_ui_dashboard_team__sort-inactive":""),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.order-invitations-by-role"),icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$APP.$cljs$cst$2490$role$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$5153$asc$$)?"arrow-down":"arrow-up":"arrow-down",onClick:$on_order_by_role$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__title-field-status",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.status"),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"action",className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$109$status$$)?"main_ui_dashboard_team__sort-active":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$109$status$$)?"main_ui_dashboard_team__sort-inactive":""),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.order-invitations-by-status"),
icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5152$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$109$status$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$5153$asc$$)?"arrow-down":"arrow-up":"arrow-down",onClick:$on_order_by_status$$})]})]}),$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($invitations$jscomp$5$$))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$empty_invitation_table_STAR_$$,{canInvite:$can_invite_QMARK_$$,team:$team$jscomp$35$$}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-rows",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$53$$,$invitation$jscomp$2$$){$out_arr__44124__auto__$jscomp$53$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$invitation_row_STAR_$$,{invitation:$invitation$jscomp$2$$,
canInvite:$can_invite_QMARK_$$,teamId:$team_id$jscomp$127$$,selected:$selected$jscomp$130$$,onSelectChange:$on_select_change$jscomp$1$$},$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($invitation$jscomp$2$$)));return $out_arr__44124__auto__$jscomp$53$$},[],$APP.$cljs$core$_deref$$($invitations$jscomp$5$$))})]})};
$app$main$ui$dashboard$team$team_invitations_page_STAR_$$=function($props_73780$$){var $profile$jscomp$45$$=$props_73780$$.profile,$team$jscomp$38$$=$props_73780$$.team;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$38$$)],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-invitations",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$38$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$38$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$38$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_invitations$$())});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{section:$APP.$cljs$cst$5125$dashboard_team_invitations$$,team:$team$jscomp$38$$}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_dashboard_team__dashboard-team-invitations",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$invitation_section_STAR_$$,{team:$team$jscomp$38$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$641$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1223$subscriptions$$);return $and__5023__auto__$jscomp$641$$?$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$($team$jscomp$38$$,$profile$jscomp$45$$):$and__5023__auto__$jscomp$641$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$members_cta_STAR_$$,{team:$team$jscomp$38$$}):null]})]})};
$app$main$ui$components$progress$progress_notification_widget_STAR_$$=function(){var $state$jscomp$1228_total$jscomp$24$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$progress$$),$error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$,$APP.$cljs$cst$3184$theme$$,"dark");var $background_clr$jscomp$1_default_theme_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("dark",$error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$);$error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$=$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228_total$jscomp$24$$);var $color$jscomp$237_healthy_QMARK_$jscomp$3$$=$APP.$cljs$cst$2502$healthy$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228_total$jscomp$24$$),$visible_QMARK_$jscomp$5$$=$APP.$cljs$cst$2346$visible$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228_total$jscomp$24$$),
$progress$jscomp$2$$=$APP.$cljs$cst$2244$progress$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228_total$jscomp$24$$),$hint$jscomp$29$$=$APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228_total$jscomp$24$$);$state$jscomp$1228_total$jscomp$24$$=$APP.$cljs$cst$2328$total$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228_total$jscomp$24$$);var $pwidth$jscomp$1$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$)?280:$progress$jscomp$2$$*
280/$state$jscomp$1228_total$jscomp$24$$;$color$jscomp$237_healthy_QMARK_$jscomp$3$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$)?"#ff3277":$APP.$cljs$core$truth_$$($color$jscomp$237_healthy_QMARK_$jscomp$3$$)?$background_clr$jscomp$1_default_theme_QMARK_$$?"#7efff5":"#6911d4":$APP.$cljs$core$not$$($color$jscomp$237_healthy_QMARK_$jscomp$3$$)?"#fe4811":null;$background_clr$jscomp$1_default_theme_QMARK_$$=$background_clr$jscomp$1_default_theme_QMARK_$$?"#2e3434":
"#eef0f2";var $toggle_detail_visibility$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$toggle_progress_visibility$$())});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_progress__progress-modal "+($APP.$cljs$core$truth_$$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$)?
"main_ui_components_progress__has-error":""),children:[$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$)?$app$main$ui$components$progress$error_icon$$:$app$main$ui$components$progress$neutral_icon$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_progress__title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_progress__title-text",children:$hint$jscomp$29$$}),$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$)?
(0,$APP.$rumext$v2$jsx$$)("button",{className:"main_ui_components_progress__retry-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_progress__progress",children:""+($progress$jscomp$2$$??"")+" / "+($state$jscomp$1228_total$jscomp$24$$??"")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_detail_visibility$jscomp$1$$,className:"main_ui_components_progress__progress-close-button",children:$app$main$ui$components$progress$close_icon$$}),
$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$3_profile$jscomp$79_theme$jscomp$30$$)?null:(0,$APP.$rumext$v2$jsx$$)("svg",{height:4,width:280,className:"main_ui_components_progress__progress-bar",children:(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("path",{d:"M0 0 L280 0",stroke:$background_clr$jscomp$1_default_theme_QMARK_$$,strokeWidth:30}),(0,$APP.$rumext$v2$jsx$$)("path",{d:"M0 0 L280 0",stroke:$color$jscomp$237_healthy_QMARK_$jscomp$3$$,strokeWidth:30,fill:"transparent",
strokeDasharray:280,strokeDashoffset:280-$pwidth$jscomp$1$$,style:{transition:"stroke-dashoffset 1s ease-in-out"}})]})})]}):null})};
$app$main$ui$components$portal$portal_on_document_STAR_$$=function($children$jscomp$314_props_81983$$){$children$jscomp$314_props_81983$$=$children$jscomp$314_props_81983$$.children;var $container$jscomp$97$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$205$default$$);return(0,$APP.$rumext$v2$portal$$)((0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$children$jscomp$314_props_81983$$}),$container$jscomp$97$$)};
$app$main$ui$dashboard$file_menu$get_project_name$$=function($project$jscomp$23$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$23$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$23$$)};$app$main$ui$dashboard$file_menu$get_project_id$$=function($project$jscomp$24$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$24$$))};
$app$main$ui$dashboard$file_menu$get_team_name$$=function($team$jscomp$63$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$63$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$63$$)};
$app$main$ui$dashboard$file_menu$group_by_team$$=function($projects$jscomp$7$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($teams$jscomp$17$$,$project$jscomp$25$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($teams$jscomp$17$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),function($p1__81993_SHARP_$$){return $p1__81993_SHARP_$$==null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),
$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2493$team_name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),$APP.$cljs$cst$4902$is_default$$,$cljs$cst$6279$is_default_team$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),$APP.$cljs$cst$1928$projects$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$project$jscomp$25$$],null)],null):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__81993_SHARP_$$,$APP.$cljs$cst$1928$projects$$,
$APP.$cljs$core$conj$$,$project$jscomp$25$$)})},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$projects$jscomp$7$$)};
$app$main$ui$dashboard$file_menu$file_menu_STAR_$$=function($options$jscomp$645_props_82006_sub_options$jscomp$2$$){function $on_delete_immediately$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-file-forever-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$)])),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$delete_files_immediately$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1927$team_id$$,$current_team_id$jscomp$3$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,$files$jscomp$34$$)],null)))}],null)))}function $on_restore_immediately$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard-restore-file-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard-restore-file-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$)])),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),
$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$2478$primary$$,$APP.$cljs$cst$2479$on_accept$$,$restore_fn$$],null)))}function $restore_fn$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$restore_files_immediately$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$current_team_id$jscomp$3$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$app$common$data$xf_COLON_map_id$$,$files$jscomp$34$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-success-notification",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$)]))),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_projects$$($current_team_id$jscomp$3$$),$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($current_team_id$jscomp$3$$)]))},$APP.$cljs$cst$1295$on_error$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-restore-file",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$)]))))}],null))))}function $on_export_binary_files$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$exports$files$open_export_dialog$$($files$jscomp$34$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)))}
function $on_del_shared$$($event$jscomp$725$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$725$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$725$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5609$delete_shared_libraries$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$5610$unpublish$$,$APP.$cljs$cst$1723$ids$$,
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2479$on_accept$$,$del_shared$$,$APP.$cljs$cst$5611$count_libraries$$,$file_count$$],null)))}function $on_add_shared$jscomp$1$$($event$jscomp$724$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$724$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$show_shared_dialog$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$),
$add_shared$jscomp$2$$))}function $del_shared$$(){return $APP.$cljs$core$run_BANG_$$(function($p1__82002_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$set_file_shared$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__82002_SHARP_$$,$APP.$cljs$cst$2182$is_shared$$,!1)))},$files$jscomp$34$$)}function $add_shared$jscomp$2$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$set_file_shared$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$191$$,
$APP.$cljs$cst$2182$is_shared$$,!0)))}function $on_move$jscomp$1$$($team_id$jscomp$150$$,$project_id$jscomp$40$$){var $params$jscomp$441$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$40$$],null);return function(){var $num_shared$jscomp$1$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82001_SHARP_$$){return $APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($p1__82001_SHARP_$$)},$files$jscomp$34$$);return 0<$APP.$cljs$core$count$$($num_shared$jscomp$1$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$150$$,$current_team_id$jscomp$3$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5609$delete_shared_libraries$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$1798$move$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2479$on_accept$$,function(){return $on_move_accept$$($params$jscomp$441$$,$team_id$jscomp$150$$,$project_id$jscomp$40$$)},$APP.$cljs$cst$5611$count_libraries$$,
$APP.$cljs$core$count$$($num_shared$jscomp$1$$)],null))):$on_move_accept$$($params$jscomp$441$$,$team_id$jscomp$150$$,$project_id$jscomp$40$$)}}function $on_move_accept$$($params$jscomp$440$$,$team_id$jscomp$149$$,$project_id$jscomp$39$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$move_files$$($APP.$cljs$core$with_meta$$($params$jscomp$440$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,function(){return $on_move_success$jscomp$1$$($team_id$jscomp$149$$,
$project_id$jscomp$39$$)}],null))))}function $on_move_success$jscomp$1$$($team_id$jscomp$148$$,$project_id$jscomp$38$$){$multi_QMARK_$jscomp$2$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-files"))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-file")));
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($navigate$jscomp$1$$)?$navigate$jscomp$1$$:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$148$$,$current_team_id$jscomp$3$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,
$project_id$jscomp$38$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$148$$],null)]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$148$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))}function $on_delete$jscomp$15$$($event$jscomp$723_num_shared$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$723_num_shared$$);
$event$jscomp$723_num_shared$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82000_SHARP_$$){return $APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($p1__82000_SHARP_$$)},$files$jscomp$34$$);return 0<$APP.$cljs$core$count$$($event$jscomp$723_num_shared$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$5609$delete_shared_libraries$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$4834$delete$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2479$on_accept$$,$on_delete_accept$jscomp$1$$,$APP.$cljs$cst$5611$count_libraries$$,$APP.$cljs$core$count$$($event$jscomp$723_num_shared$$)],null))):$multi_QMARK_$jscomp$2$$?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-file-multi-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-file-multi-confirm.message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-file-multi-confirm.accept",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$2479$on_accept$$,$on_delete_accept$jscomp$1$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-file-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-file-confirm.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-file-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$on_delete_accept$jscomp$1$$],null)))}
function $on_delete_accept$jscomp$1$$(){$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$dashboard$delete_file$$,$files$jscomp$34$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.success-delete-file",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)]))),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))}function $on_duplicate$jscomp$4$$(){$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$dashboard$duplicate_file$$,$files$jscomp$34$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.success-duplicate-file",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)]))))}function $on_new_tab$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$),
$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,!0],null)])))}var $left$jscomp$39$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.left,$navigate$jscomp$1$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.navigate,$on_close$jscomp$42$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.onClose,$top$jscomp$21$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.top,$can_edit$jscomp$5$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.canEdit,$on_edit$jscomp$10$$=
$options$jscomp$645_props_82006_sub_options$jscomp$2$$.onEdit,$parent_id$jscomp$111$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.parentId,$files$jscomp$34$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.files,$can_restore$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.canRestore,$origin$jscomp$66$$=$options$jscomp$645_props_82006_sub_options$jscomp$2$$.origin,$is_lib_page_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5244$libraries$$,
$origin$jscomp$66$$),$is_search_page_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6280$search$$,$origin$jscomp$66$$),$top__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($top$jscomp$21$$)?$top$jscomp$21$$:0,$left__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($left$jscomp$39$$)?$left$jscomp$39$$:0,$file$jscomp$191$$=$APP.$cljs$core$first$$($files$jscomp$34$$),$file_count$$=$APP.$cljs$core$count$$($files$jscomp$34$$),$multi_QMARK_$jscomp$2$$=$file_count$$>1,$current_team_id$jscomp$3$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$),$teams_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$teams$jscomp$18$$=$APP.$cljs$core$_deref$$($teams_STAR_$$),$current_team$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($teams$jscomp$18$$,$current_team_id$jscomp$3$$),$other_teams$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81998_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__81998_SHARP_$$),
$current_team_id$jscomp$3$$)},$APP.$cljs$core$vals$$($teams$jscomp$18$$)),$file_project_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2181$project_id$$),$files$jscomp$34$$),$current_projects$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81999_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($file_project_ids$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__81999_SHARP_$$))},
$APP.$cljs$cst$1928$projects$$.$cljs$core$IFn$_invoke$arity$1$($current_team$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__82003_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($teams_STAR_$$,$p1__82003_SHARP_$$)},$APP.$beicon$v2$core$map$$($app$main$ui$dashboard$file_menu$group_by_team$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$6281$get_all_projects$$)))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$42$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5054$dropdown_SLASH_open$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,"file-menu"],null)));var $stream$jscomp$107$$=$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__82004_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("file-menu",
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82004_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5054$dropdown_SLASH_open$$),$APP.$app$main$store$stream$$)))),$subs$jscomp$33$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($stream$jscomp$107$$,null,null,$on_close$jscomp$42$$);return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$33$$)}});
$options$jscomp$645_props_82006_sub_options$jscomp$2$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82038$$($s__82039$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__82039__$2_temp__5825__auto__$jscomp$451$$=$APP.$cljs$core$seq$$($s__82039$$);if($s__82039__$2_temp__5825__auto__$jscomp$451$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82039__$2_temp__5825__auto__$jscomp$451$$)){var $JSCompiler_inline_result$jscomp$1981_c__5501__auto__$jscomp$62$$=
$APP.$cljs$core$_chunked_first$$($s__82039__$2_temp__5825__auto__$jscomp$451$$),$size__5502__auto__$jscomp$62$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1981_c__5501__auto__$jscomp$62$$),$b__82041_project$jscomp$26$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$62$$);a:{for(var $i__82040$jscomp$inline_9503$$=0;;)if($i__82040$jscomp$inline_9503$$<$size__5502__auto__$jscomp$62$$){var $project$jscomp$inline_9504_x$jscomp$inline_13847$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1981_c__5501__auto__$jscomp$62$$,
$i__82040$jscomp$inline_9503$$),$b$jscomp$inline_13846$$=$b__82041_project$jscomp$26$$;$project$jscomp$inline_9504_x$jscomp$inline_13847$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($project$jscomp$inline_9504_x$jscomp$inline_13847$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($project$jscomp$inline_9504_x$jscomp$inline_13847$$),$APP.$cljs$cst$2402$handler$$,$on_move$jscomp$1$$($current_team_id$jscomp$3$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$inline_9504_x$jscomp$inline_13847$$))],null);$b$jscomp$inline_13846$$.add($project$jscomp$inline_9504_x$jscomp$inline_13847$$);$i__82040$jscomp$inline_9503$$+=1}else{$JSCompiler_inline_result$jscomp$1981_c__5501__auto__$jscomp$62$$=!0;break a}$JSCompiler_inline_result$jscomp$1981_c__5501__auto__$jscomp$62$$=void 0}return $JSCompiler_inline_result$jscomp$1981_c__5501__auto__$jscomp$62$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82041_project$jscomp$26$$),
$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82038$$($APP.$cljs$core$_chunked_rest$$($s__82039__$2_temp__5825__auto__$jscomp$451$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82041_project$jscomp$26$$),null)}$b__82041_project$jscomp$26$$=$APP.$cljs$core$first$$($s__82039__$2_temp__5825__auto__$jscomp$451$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($b__82041_project$jscomp$26$$),
$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($b__82041_project$jscomp$26$$),$APP.$cljs$cst$2402$handler$$,$on_move$jscomp$1$$($current_team_id$jscomp$3$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__82041_project$jscomp$26$$))],null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82038$$($APP.$cljs$core$rest$$($s__82039__$2_temp__5825__auto__$jscomp$451$$)))}return null}},null,null)}($current_projects$$)}(),$APP.$cljs$core$seq$$($other_teams$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.move-to-other-team"),$APP.$cljs$cst$266$id$$,"move-to-other-team",$APP.$cljs$cst$873$options$$,function(){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052$$($s__82053$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$452$$=
$APP.$cljs$core$seq$$($s__82053$$);if($temp__5825__auto__$jscomp$452$$){var $s__82053__$2$$=$temp__5825__auto__$jscomp$452$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82053__$2$$)){var $c__5501__auto__$jscomp$63$$=$APP.$cljs$core$_chunked_first$$($s__82053__$2$$),$size__5502__auto__$jscomp$63$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$63$$),$b__82055$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$63$$);return function(){for(var $i__82054$$=0;;)if($i__82054$$<$size__5502__auto__$jscomp$63$$){var $team$jscomp$65$$=
$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$63$$,$i__82054$$);$APP.$cljs$core$chunk_append$$($b__82055$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_team_name$$($team$jscomp$65$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($team$jscomp$65$$),$APP.$cljs$cst$873$options$$,function(){return function($i__82054$jscomp$1$$,$team$jscomp$66$$,$c__5501__auto__$jscomp$64$$,$size__5502__auto__$jscomp$64$$,$b__82055$jscomp$1$$,
$s__82053__$2$jscomp$1$$,$temp__5825__auto__$jscomp$453$$,$is_lib_page_QMARK_$jscomp$1$$,$is_search_page_QMARK_$jscomp$1$$,$top__$1$jscomp$4$$,$left__$1$jscomp$5$$,$file$jscomp$192$$,$file_count$jscomp$1$$,$multi_QMARK_$jscomp$3$$,$current_team_id$jscomp$4$$,$teams_STAR_$jscomp$1$$,$teams$jscomp$19$$,$current_team$jscomp$1$$,$other_teams$jscomp$1$$,$file_project_ids$jscomp$1$$,$current_projects$jscomp$1$$,$on_new_tab$jscomp$1$$,$on_duplicate$jscomp$5$$,$on_delete_accept$jscomp$2$$,$on_delete$jscomp$16$$,
$on_move_success$jscomp$2$$,$on_move_accept$jscomp$1$$,$on_move$jscomp$2$$,$add_shared$jscomp$3$$,$del_shared$jscomp$1$$,$on_add_shared$jscomp$2$$,$on_del_shared$jscomp$1$$,$on_export_binary_files$jscomp$1$$,$restore_fn$jscomp$1$$,$on_restore_immediately$jscomp$1$$,$on_delete_immediately$jscomp$1$$,$left$jscomp$40$$,$navigate$jscomp$2$$,$on_close$jscomp$43$$,$top$jscomp$22$$,$can_edit$jscomp$6$$,$on_edit$jscomp$11$$,$parent_id$jscomp$112$$,$files$jscomp$35$$,$can_restore$jscomp$1$$,$origin$jscomp$67$$){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052_$_iter__82057$$($s__82058$$){return new $APP.$cljs$core$LazySeq$$(null,
function($i__82054$jscomp$2$$,$team$jscomp$67$$,$c__5501__auto__$jscomp$65$$,$size__5502__auto__$jscomp$65$$,$b__82055$jscomp$2$$,$s__82053__$2$jscomp$2$$,$temp__5825__auto__$jscomp$454$$,$is_lib_page_QMARK_$jscomp$2$$,$is_search_page_QMARK_$jscomp$2$$,$top__$1$jscomp$5$$,$left__$1$jscomp$6$$,$file$jscomp$193$$,$file_count$jscomp$2$$,$multi_QMARK_$jscomp$4$$,$current_team_id$jscomp$5$$,$teams_STAR_$jscomp$2$$,$teams$jscomp$20$$,$current_team$jscomp$2$$,$other_teams$jscomp$2$$,$file_project_ids$jscomp$2$$,
$current_projects$jscomp$2$$,$on_new_tab$jscomp$2$$,$on_duplicate$jscomp$6$$,$on_delete_accept$jscomp$3$$,$on_delete$jscomp$17$$,$on_move_success$jscomp$3$$,$on_move_accept$jscomp$2$$,$on_move$jscomp$3$$){return function(){for(;;){var $s__82058__$2_temp__5825__auto____$1$jscomp$29$$=$APP.$cljs$core$seq$$($s__82058$$);if($s__82058__$2_temp__5825__auto____$1$jscomp$29$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82058__$2_temp__5825__auto____$1$jscomp$29$$)){var $JSCompiler_inline_result$jscomp$1982_c__5501__auto____$1$jscomp$1$$=
$APP.$cljs$core$_chunked_first$$($s__82058__$2_temp__5825__auto____$1$jscomp$29$$),$size__5502__auto____$1$jscomp$1$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1982_c__5501__auto____$1$jscomp$1$$),$b__82060_sub_project$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto____$1$jscomp$1$$);a:{for(var $i__82059$jscomp$inline_9506$$=0;;)if($i__82059$jscomp$inline_9506$$<$size__5502__auto____$1$jscomp$1$$){var $sub_project$jscomp$inline_9507_x$jscomp$inline_13850$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1982_c__5501__auto____$1$jscomp$1$$,
$i__82059$jscomp$inline_9506$$),$b$jscomp$inline_13849$$=$b__82060_sub_project$$;$sub_project$jscomp$inline_9507_x$jscomp$inline_13850$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($sub_project$jscomp$inline_9507_x$jscomp$inline_13850$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($sub_project$jscomp$inline_9507_x$jscomp$inline_13850$$),$APP.$cljs$cst$2402$handler$$,$on_move$jscomp$3$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$67$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_project$jscomp$inline_9507_x$jscomp$inline_13850$$))],null);$b$jscomp$inline_13849$$.add($sub_project$jscomp$inline_9507_x$jscomp$inline_13850$$);$i__82059$jscomp$inline_9506$$+=1}else{$JSCompiler_inline_result$jscomp$1982_c__5501__auto____$1$jscomp$1$$=!0;break a}$JSCompiler_inline_result$jscomp$1982_c__5501__auto____$1$jscomp$1$$=void 0}return $JSCompiler_inline_result$jscomp$1982_c__5501__auto____$1$jscomp$1$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82060_sub_project$$),
$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052_$_iter__82057$$($APP.$cljs$core$_chunked_rest$$($s__82058__$2_temp__5825__auto____$1$jscomp$29$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82060_sub_project$$),null)}$b__82060_sub_project$$=$APP.$cljs$core$first$$($s__82058__$2_temp__5825__auto____$1$jscomp$29$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($b__82060_sub_project$$),
$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($b__82060_sub_project$$),$APP.$cljs$cst$2402$handler$$,$on_move$jscomp$3$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$67$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__82060_sub_project$$))],null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052_$_iter__82057$$($APP.$cljs$core$rest$$($s__82058__$2_temp__5825__auto____$1$jscomp$29$$)))}return null}}}($i__82054$jscomp$1$$,
$team$jscomp$66$$,$c__5501__auto__$jscomp$64$$,$size__5502__auto__$jscomp$64$$,$b__82055$jscomp$1$$,$s__82053__$2$jscomp$1$$,$temp__5825__auto__$jscomp$453$$,$is_lib_page_QMARK_$jscomp$1$$,$is_search_page_QMARK_$jscomp$1$$,$top__$1$jscomp$4$$,$left__$1$jscomp$5$$,$file$jscomp$192$$,$file_count$jscomp$1$$,$multi_QMARK_$jscomp$3$$,$current_team_id$jscomp$4$$,$teams_STAR_$jscomp$1$$,$teams$jscomp$19$$,$current_team$jscomp$1$$,$other_teams$jscomp$1$$,$file_project_ids$jscomp$1$$,$current_projects$jscomp$1$$,
$on_new_tab$jscomp$1$$,$on_duplicate$jscomp$5$$,$on_delete_accept$jscomp$2$$,$on_delete$jscomp$16$$,$on_move_success$jscomp$2$$,$on_move_accept$jscomp$1$$,$on_move$jscomp$2$$,$add_shared$jscomp$3$$,$del_shared$jscomp$1$$,$on_add_shared$jscomp$2$$,$on_del_shared$jscomp$1$$,$on_export_binary_files$jscomp$1$$,$restore_fn$jscomp$1$$,$on_restore_immediately$jscomp$1$$,$on_delete_immediately$jscomp$1$$,$left$jscomp$40$$,$navigate$jscomp$2$$,$on_close$jscomp$43$$,$top$jscomp$22$$,$can_edit$jscomp$6$$,$on_edit$jscomp$11$$,
$parent_id$jscomp$112$$,$files$jscomp$35$$,$can_restore$jscomp$1$$,$origin$jscomp$67$$),null,null)}}($i__82054$$,$team$jscomp$65$$,$c__5501__auto__$jscomp$63$$,$size__5502__auto__$jscomp$63$$,$b__82055$$,$s__82053__$2$$,$temp__5825__auto__$jscomp$452$$,$is_lib_page_QMARK_$$,$is_search_page_QMARK_$$,$top__$1$jscomp$3$$,$left__$1$jscomp$4$$,$file$jscomp$191$$,$file_count$$,$multi_QMARK_$jscomp$2$$,$current_team_id$jscomp$3$$,$teams_STAR_$$,$teams$jscomp$18$$,$current_team$$,$other_teams$$,$file_project_ids$$,
$current_projects$$,$on_new_tab$$,$on_duplicate$jscomp$4$$,$on_delete_accept$jscomp$1$$,$on_delete$jscomp$15$$,$on_move_success$jscomp$1$$,$on_move_accept$$,$on_move$jscomp$1$$,$add_shared$jscomp$2$$,$del_shared$$,$on_add_shared$jscomp$1$$,$on_del_shared$$,$on_export_binary_files$$,$restore_fn$$,$on_restore_immediately$$,$on_delete_immediately$$,$left$jscomp$39$$,$navigate$jscomp$1$$,$on_close$jscomp$42$$,$top$jscomp$21$$,$can_edit$jscomp$5$$,$on_edit$jscomp$10$$,$parent_id$jscomp$111$$,$files$jscomp$34$$,
$can_restore$$,$origin$jscomp$66$$)($APP.$cljs$cst$1928$projects$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$65$$))}()],null));$i__82054$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82055$$),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052$$($APP.$cljs$core$_chunked_rest$$($s__82053__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82055$$),null)}var $team$jscomp$64$$=$APP.$cljs$core$first$$($s__82053__$2$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_team_name$$($team$jscomp$64$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($team$jscomp$64$$),$APP.$cljs$cst$873$options$$,function(){return function($team$jscomp$68$$,$s__82053__$2$jscomp$3$$,$temp__5825__auto__$jscomp$455$$,$is_lib_page_QMARK_$jscomp$3$$,$is_search_page_QMARK_$jscomp$3$$,$top__$1$jscomp$6$$,$left__$1$jscomp$7$$,$file$jscomp$194$$,$file_count$jscomp$3$$,$multi_QMARK_$jscomp$5$$,$current_team_id$jscomp$6$$,
$teams_STAR_$jscomp$3$$,$teams$jscomp$21$$,$current_team$jscomp$3$$,$other_teams$jscomp$3$$,$file_project_ids$jscomp$3$$,$current_projects$jscomp$3$$,$on_new_tab$jscomp$3$$,$on_duplicate$jscomp$7$$,$on_delete_accept$jscomp$4$$,$on_delete$jscomp$18$$,$on_move_success$jscomp$4$$,$on_move_accept$jscomp$3$$,$on_move$jscomp$4$$){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052_$_iter__82068$$($s__82069$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__82069__$2_temp__5825__auto____$1$jscomp$30$$=
$APP.$cljs$core$seq$$($s__82069$$);if($s__82069__$2_temp__5825__auto____$1$jscomp$30$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82069__$2_temp__5825__auto____$1$jscomp$30$$)){var $JSCompiler_inline_result$jscomp$1983_c__5501__auto__$jscomp$66$$=$APP.$cljs$core$_chunked_first$$($s__82069__$2_temp__5825__auto____$1$jscomp$30$$),$size__5502__auto__$jscomp$66$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1983_c__5501__auto__$jscomp$66$$),$b__82071_sub_project$jscomp$2$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$66$$);
a:{for(var $i__82070$jscomp$inline_9509$$=0;;)if($i__82070$jscomp$inline_9509$$<$size__5502__auto__$jscomp$66$$){var $sub_project$jscomp$inline_9510_x$jscomp$inline_13853$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1983_c__5501__auto__$jscomp$66$$,$i__82070$jscomp$inline_9509$$),$b$jscomp$inline_13852$$=$b__82071_sub_project$jscomp$2$$;$sub_project$jscomp$inline_9510_x$jscomp$inline_13853$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($sub_project$jscomp$inline_9510_x$jscomp$inline_13853$$),
$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($sub_project$jscomp$inline_9510_x$jscomp$inline_13853$$),$APP.$cljs$cst$2402$handler$$,$on_move$jscomp$4$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$68$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_project$jscomp$inline_9510_x$jscomp$inline_13853$$))],null);$b$jscomp$inline_13852$$.add($sub_project$jscomp$inline_9510_x$jscomp$inline_13853$$);$i__82070$jscomp$inline_9509$$+=1}else{$JSCompiler_inline_result$jscomp$1983_c__5501__auto__$jscomp$66$$=
!0;break a}$JSCompiler_inline_result$jscomp$1983_c__5501__auto__$jscomp$66$$=void 0}return $JSCompiler_inline_result$jscomp$1983_c__5501__auto__$jscomp$66$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82071_sub_project$jscomp$2$$),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052_$_iter__82068$$($APP.$cljs$core$_chunked_rest$$($s__82069__$2_temp__5825__auto____$1$jscomp$30$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82071_sub_project$jscomp$2$$),null)}$b__82071_sub_project$jscomp$2$$=
$APP.$cljs$core$first$$($s__82069__$2_temp__5825__auto____$1$jscomp$30$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($b__82071_sub_project$jscomp$2$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($b__82071_sub_project$jscomp$2$$),$APP.$cljs$cst$2402$handler$$,$on_move$jscomp$4$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$68$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__82071_sub_project$jscomp$2$$))],
null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052_$_iter__82068$$($APP.$cljs$core$rest$$($s__82069__$2_temp__5825__auto____$1$jscomp$30$$)))}return null}},null,null)}}($team$jscomp$64$$,$s__82053__$2$$,$temp__5825__auto__$jscomp$452$$,$is_lib_page_QMARK_$$,$is_search_page_QMARK_$$,$top__$1$jscomp$3$$,$left__$1$jscomp$4$$,$file$jscomp$191$$,$file_count$$,$multi_QMARK_$jscomp$2$$,$current_team_id$jscomp$3$$,$teams_STAR_$$,$teams$jscomp$18$$,$current_team$$,$other_teams$$,$file_project_ids$$,
$current_projects$$,$on_new_tab$$,$on_duplicate$jscomp$4$$,$on_delete_accept$jscomp$1$$,$on_delete$jscomp$15$$,$on_move_success$jscomp$1$$,$on_move_accept$$,$on_move$jscomp$1$$,$add_shared$jscomp$2$$,$del_shared$$,$on_add_shared$jscomp$1$$,$on_del_shared$$,$on_export_binary_files$$,$restore_fn$$,$on_restore_immediately$$,$on_delete_immediately$$,$left$jscomp$39$$,$navigate$jscomp$1$$,$on_close$jscomp$42$$,$top$jscomp$21$$,$can_edit$jscomp$5$$,$on_edit$jscomp$10$$,$parent_id$jscomp$111$$,$files$jscomp$34$$,
$can_restore$$,$origin$jscomp$66$$)($APP.$cljs$cst$1928$projects$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$64$$))}()],null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82052$$($APP.$cljs$core$rest$$($s__82053__$2$$)))}return null}},null,null)}($other_teams$$)}()],null)],null):null);$options$jscomp$645_props_82006_sub_options$jscomp$2$$=$APP.$cljs$core$truth_$$($can_restore$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.file-menu.restore-files-option",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)])),$APP.$cljs$cst$266$id$$,"restore-file",$APP.$cljs$cst$2402$handler$$,$on_restore_immediately$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.file-menu.delete-files-permanently-option",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)])),$APP.$cljs$cst$266$id$$,"delete-file",$APP.$cljs$cst$2402$handler$$,$on_delete_immediately$$],null)],null):$multi_QMARK_$jscomp$2$$?new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($can_edit$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.duplicate-multi",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"duplicate-multi",$APP.$cljs$cst$2402$handler$$,$on_duplicate$jscomp$4$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1005$$=$APP.$cljs$core$seq$$($current_projects$$)||$APP.$cljs$core$seq$$($other_teams$$);return $and__5023__auto__$jscomp$1005$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1005$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.move-to-multi",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"file-move-multi",$APP.$cljs$cst$873$options$$,$options$jscomp$645_props_82006_sub_options$jscomp$2$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.export-binary-multi",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),
$APP.$cljs$cst$266$id$$,"file-binary-export-multi",$APP.$cljs$cst$2402$handler$$,$on_export_binary_files$$],null),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1006$$=$APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1006$$)?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1006$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.unpublish-multi-files",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"file-unpublish-multi",$APP.$cljs$cst$2402$handler$$,$on_del_shared$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1007$$=!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1007$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1007$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.delete-multi-files",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"file-delete-multi",$APP.$cljs$cst$2402$handler$$,$on_delete$jscomp$15$$],null):null],null):new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.open-in-new-tab"),$APP.$cljs$cst$266$id$$,"file-open-new-tab",$APP.$cljs$cst$2402$handler$$,
$on_new_tab$$],null),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1008$$=!$is_search_page_QMARK_$$;return $and__5023__auto__$jscomp$1008$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1008$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),$APP.$cljs$cst$266$id$$,"file-rename",$APP.$cljs$cst$2402$handler$$,$on_edit$jscomp$10$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1009$$=
!$is_search_page_QMARK_$$;return $and__5023__auto__$jscomp$1009$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1009$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.duplicate"),$APP.$cljs$cst$266$id$$,"file-duplicate",$APP.$cljs$cst$2402$handler$$,$on_duplicate$jscomp$4$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$=
!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$?($and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$=!$is_search_page_QMARK_$$)?($and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$=$APP.$cljs$core$seq$$($current_projects$$)||$APP.$cljs$core$seq$$($other_teams$$))?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$:
$and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$:$and__5023__auto__$jscomp$1010_and__5023__auto____$1$jscomp$165_and__5023__auto____$2$jscomp$48$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.move-to"),$APP.$cljs$cst$266$id$$,"file-move-to",$APP.$cljs$cst$873$options$$,$options$jscomp$645_props_82006_sub_options$jscomp$2$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1011$$=
!$is_search_page_QMARK_$$;return $and__5023__auto__$jscomp$1011$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1011$$}())?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$191$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.unpublish-shared"),$APP.$cljs$cst$266$id$$,"file-del-shared",$APP.$cljs$cst$2402$handler$$,$on_del_shared$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.add-shared"),$APP.$cljs$cst$266$id$$,"file-add-shared",$APP.$cljs$cst$2402$handler$$,$on_add_shared$jscomp$1$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1472$separator$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.download-binary-file"),$APP.$cljs$cst$266$id$$,
"download-binary-file",$APP.$cljs$cst$2402$handler$$,$on_export_binary_files$$],null),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1012_and__5023__auto____$1$jscomp$166$$=!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1012_and__5023__auto____$1$jscomp$166$$?($and__5023__auto__$jscomp$1012_and__5023__auto____$1$jscomp$166$$=!$is_search_page_QMARK_$$)?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1012_and__5023__auto____$1$jscomp$166$$:$and__5023__auto__$jscomp$1012_and__5023__auto____$1$jscomp$166$$}())?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1472$separator$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1013_and__5023__auto____$1$jscomp$167$$=!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1013_and__5023__auto____$1$jscomp$167$$?($and__5023__auto__$jscomp$1013_and__5023__auto____$1$jscomp$167$$=!$is_search_page_QMARK_$$)?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1013_and__5023__auto____$1$jscomp$167$$:
$and__5023__auto__$jscomp$1013_and__5023__auto____$1$jscomp$167$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$266$id$$,"file-delete",$APP.$cljs$cst$2402$handler$$,$on_delete$jscomp$15$$],null):null],null);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,{onClose:$on_close$jscomp$42$$,fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($top__$1$jscomp$3$$,
0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($left__$1$jscomp$4$$,0),show:!0,minWidth:!0,top:$top__$1$jscomp$3$$,left:$left__$1$jscomp$4$$,options:$options$jscomp$645_props_82006_sub_options$jscomp$2$$,origin:$parent_id$jscomp$111$$})};
$app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$=function($children$jscomp$315_props_81988$$){var $title$jscomp$50$$,$subtitle$jscomp$1$$,$props$jscomp$430$$;({className:$class$$jscomp$82_props__$1$jscomp$106$$,title:$title$jscomp$50$$,subtitle:$subtitle$jscomp$1$$,type:$decoration_type_or__5025__auto__$jscomp$inline_9512_type$jscomp$722$$,children:$children$jscomp$315_props_81988$$,...$props$jscomp$430$$}=$children$jscomp$315_props_81988$$);var $class$$jscomp$82_props__$1$jscomp$106$$=
{...$props$jscomp$430$$,className:""+($class$$jscomp$82_props__$1$jscomp$106$$??"")+" main_ui_ds_product_empty_placeholder__empty-placeholder","data-testid":"empty-placeholder"};var $decoration_type_or__5025__auto__$jscomp$inline_9512_type$jscomp$722$$="empty-placeholder-"+($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($decoration_type_or__5025__auto__$jscomp$inline_9512_type$jscomp$722$$)?$decoration_type_or__5025__auto__$jscomp$inline_9512_type$jscomp$722$$:1)??
"");return(0,$APP.$rumext$v2$create_element$$)("div",$class$$jscomp$82_props__$1$jscomp$106$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:""+($decoration_type_or__5025__auto__$jscomp$inline_9512_type$jscomp$722$$??"")+"-left",className:"main_ui_ds_product_empty_placeholder__svg-decor"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_empty_placeholder__text-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"title-medium",className:"main_ui_ds_product_empty_placeholder__placeholder-title",children:$title$jscomp$50$$}),$APP.$cljs$core$truth_$$($subtitle$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-large",children:$subtitle$jscomp$1$$}):null,$children$jscomp$315_props_81988$$]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:""+($decoration_type_or__5025__auto__$jscomp$inline_9512_type$jscomp$722$$??
"")+"-right",className:"main_ui_ds_product_empty_placeholder__svg-decor"}))};
$app$main$ui$dashboard$placeholder$empty_project_placeholder_STAR_$$=function($on_create$jscomp$1_props_82005$$){var $on_finish_import$jscomp$4$$=$on_create$jscomp$1_props_82005$$.onFinishImport,$project_id$jscomp$41$$=$on_create$jscomp$1_props_82005$$.projectId;$on_create$jscomp$1_props_82005$$=$on_create$jscomp$1_props_82005$$.onCreate;var $file_input$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_add_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-libraries-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1366$section$$,"empty-placeholder-projects"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/penpothub/libraries-templates")}),$on_import$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($file_input$jscomp$1$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_create$jscomp$1_props_82005$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.add-file"),className:"main_ui_dashboard_placeholder__empty-project-card",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.create")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.start")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_import$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.import"),className:"main_ui_dashboard_placeholder__empty-project-card",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.import")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.import-penpot")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_add_library$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.go-to-libraries"),className:"main_ui_dashboard_placeholder__empty-project-card",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.add-library")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.explore")})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$import$0$import_form$$,
{ref:$file_input$jscomp$1$$,"project-id":$project_id$jscomp$41$$,"on-finish-import":$on_finish_import$jscomp$4$$})]})};
$app$main$ui$dashboard$placeholder$make_has_other_files_or_projects_ref$$=function($team_id$jscomp$151$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1229$$){var $files$jscomp$38_or__5025__auto__$jscomp$1389$$=function(){var $projects$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1229$$,$APP.$cljs$cst$1928$projects$$);return $APP.$cljs$core$some$$(function($p__82007_project$jscomp$28$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82007_project$jscomp$28$$,
0,null);$p__82007_project$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82007_project$jscomp$28$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($p__82007_project$jscomp$28$$),$team_id$jscomp$151$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($p__82007_project$jscomp$28$$))},$projects$jscomp$8$$)}();if($APP.$cljs$core$truth_$$($files$jscomp$38_or__5025__auto__$jscomp$1389$$))return $files$jscomp$38_or__5025__auto__$jscomp$1389$$;
$files$jscomp$38_or__5025__auto__$jscomp$1389$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1229$$,$APP.$cljs$cst$1916$files$$);return $APP.$cljs$core$some$$(function($file$jscomp$195_p__82015$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file$jscomp$195_p__82015$$,0,null);$file$jscomp$195_p__82015$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file$jscomp$195_p__82015$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$195_p__82015$$),
$team_id$jscomp$151$$)},$files$jscomp$38_or__5025__auto__$jscomp$1389$$)},$APP.$app$main$store$state$$)};
$app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$=function($origin$jscomp$70_props_82019$$){var $on_finish_import$jscomp$5$$=$origin$jscomp$70_props_82019$$.onFinishImport,$project_id$jscomp$42$$=$origin$jscomp$70_props_82019$$.projectId,$team_id$jscomp$152$$=$origin$jscomp$70_props_82019$$.teamId,$limit$jscomp$8$$=$origin$jscomp$70_props_82019$$.limit,$can_edit$jscomp$9$$=$origin$jscomp$70_props_82019$$.canEdit,$is_dragging$$=$origin$jscomp$70_props_82019$$.isDragging,$create_fn$$=
$origin$jscomp$70_props_82019$$.createFn;$origin$jscomp$70_props_82019$$=$origin$jscomp$70_props_82019$$.origin;var $on_click$jscomp$63$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($create_fn$$)],function(){return $create_fn$$.$cljs$core$IFn$_invoke$arity$1$?$create_fn$$.$cljs$core$IFn$_invoke$arity$1$("dashboard:empty-folder-placeholder"):$create_fn$$("dashboard:empty-folder-placeholder")}),$show_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$show_text_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_text_STAR_$$),$on_mouse_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_text_STAR_$$,!0)}),$on_mouse_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_text_STAR_$$,null)}),$has_other_QMARK__has_other_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$152$$)],
function(){return $app$main$ui$dashboard$placeholder$make_has_other_files_or_projects_ref$$($team_id$jscomp$152$$)});$has_other_QMARK__has_other_STAR_$$=$APP.$rumext$v2$deref$$($has_other_QMARK__has_other_STAR_$$);return $is_dragging$$===!0?(0,$APP.$rumext$v2$jsx$$)("ul",{style:{gridTemplateColumns:["repeat(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($limit$jscomp$8$$),", 1fr)"].join("")},className:"main_ui_dashboard_placeholder__grid-row main_ui_dashboard_placeholder__no-wrap",children:(0,$APP.$rumext$v2$jsx$$)("li",
{className:"main_ui_dashboard_placeholder__grid-item main_ui_dashboard_placeholder__grid-empty-placeholder main_ui_dashboard_placeholder__dragged"})}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5244$libraries$$,$origin$jscomp$70_props_82019$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-libraries-title"),type:2,subtitle:$APP.$cljs$core$truth_$$($can_edit$jscomp$9$$)?
null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-libraries-subtitle-viewer-role"),className:"main_ui_dashboard_placeholder__empty-placeholder-libraries",children:$APP.$cljs$core$truth_$$($can_edit$jscomp$9$$)?$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-libraries"),className:"main_ui_dashboard_placeholder__placeholder-markdown",tagName:"span"}):null}):
$APP.$cljs$core$not$$($has_other_QMARK__has_other_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$empty_project_placeholder_STAR_$$,{onCreate:$on_click$jscomp$63$$,onFinishImport:$on_finish_import$jscomp$5$$,projectId:$project_id$jscomp$42$$}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__grid-empty-placeholder",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_click$jscomp$63$$,onMouseEnter:$on_mouse_enter$$,onMouseLeave:$on_mouse_leave$$,
className:"main_ui_dashboard_placeholder__create-new",children:$APP.$cljs$core$truth_$$($show_text_QMARK_$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.create"):$APP.$app$main$ui$icons$add$$})})};
$app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$=function(){return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{width:32,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),className:"main_ui_dashboard_placeholder__placeholder-loader",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_placeholder__placeholder-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.loading-files")})})};
$app$main$ui$dashboard$grid$persist_thumbnail$$=function($file_id$jscomp$450$$,$revn$jscomp$10$$,$blob$jscomp$40$$){return $APP.$beicon$v2$core$map$$($APP.$cljs$cst$266$id$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2259$create_file_thumbnail$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$450$$,$APP.$cljs$cst$2270$revn$$,$revn$jscomp$10$$,$APP.$cljs$cst$1639$media$$,$blob$jscomp$40$$],null)))};
$app$main$ui$dashboard$grid$render_thumbnail$$=function($file_id$jscomp$451$$,$revn$jscomp$11$$){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$6283$thumbnails_SLASH_generate_for_file_wasm$$,$APP.$cljs$cst$2270$revn$$,$revn$jscomp$11$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$451$$,
$APP.$cljs$cst$290$width$$,252],null)):$APP.$beicon$v2$core$mapcat$$(function($fonts$jscomp$41_p__82100$$){var $map__82101__$1$$=$APP.$cljs$core$__destructure_map$$($fonts$jscomp$41_p__82100$$);$fonts$jscomp$41_p__82100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82101__$1$$,$APP.$cljs$cst$2969$fonts$$);return $APP.$beicon$v2$core$map$$(function($styles$jscomp$35$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__82101__$1$$,$APP.$cljs$cst$2940$styles$$,
$styles$jscomp$35$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,252]))},$app$main$fonts$render_font_styles$$($fonts$jscomp$41_p__82100$$))},$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$6284$thumbnails_SLASH_generate_for_file$$,$APP.$cljs$cst$2270$revn$$,$revn$jscomp$11$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$451$$,$APP.$cljs$cst$290$width$$,
252],null)))};
$app$main$ui$dashboard$grid$grid_item_thumbnail_STAR_$$=function($can_restore$jscomp$4_props_82102$$){var $bg_color$jscomp$1_file$jscomp$196$$=$can_restore$jscomp$4_props_82102$$.file,$can_edit$jscomp$10$$=$can_restore$jscomp$4_props_82102$$.canEdit;$can_restore$jscomp$4_props_82102$$=$can_restore$jscomp$4_props_82102$$.canRestore;var $file_id$jscomp$453$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$196$$,$APP.$cljs$cst$266$id$$),$revn$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$196$$,
$APP.$cljs$cst$2270$revn$$),$thumbnail_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$196$$,$APP.$cljs$cst$2573$thumbnail_id$$);$bg_color$jscomp$1_file$jscomp$196$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$196$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2058$background$$);var $container$jscomp$98$$=(0,$APP.$rumext$v2$use_ref$$)(),$visible_QMARK_$jscomp$6$$=
$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($container$jscomp$98$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$453$$),$APP.$rumext$v2$adapt$$($revn$jscomp$13$$),$APP.$rumext$v2$adapt$$($visible_QMARK_$jscomp$6$$),$APP.$rumext$v2$adapt$$($thumbnail_id$jscomp$2$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$6$$)?$APP.$cljs$core$not$$($thumbnail_id$jscomp$2$$):
$visible_QMARK_$jscomp$6$$)){var $subscription$jscomp$11$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($thumbnail_id__$1$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$set_file_thumbnail$$($file_id$jscomp$453$$,$thumbnail_id__$1$$))},function($cause$jscomp$110$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.dashboard.grid",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unable to render thumbnail"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6285$file_if$$,$file_id$jscomp$453$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2270$revn$$,$revn$jscomp$13$$],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$141$message$$,$APP.$cljs$core$ex_message$$($cause$jscomp$110$$)],null)],null)}),null,"app.main.ui.dashboard.grid",$APP.$cljs$cst$849$error$$,!1);return null},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$dashboard$grid$persist_thumbnail$$,$file_id$jscomp$453$$,$revn$jscomp$13$$),$APP.$beicon$v2$core$mapcat$$($APP.$app$main$rasterizer$render$$,
$app$main$ui$dashboard$grid$render_thumbnail$$($file_id$jscomp$453$$,$revn$jscomp$13$$))));return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$dispose_BANG_$$,$subscription$jscomp$11$$)}return null});return(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundColor:$bg_color$jscomp$1_file$jscomp$196$$},ref:$container$jscomp$98$$,className:"main_ui_dashboard_grid__grid-item-th "+($APP.$cljs$core$truth_$$($can_restore$jscomp$4_props_82102$$)?"main_ui_dashboard_grid__deleted-item":
""),children:$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$6$$)?$APP.$cljs$core$truth_$$($thumbnail_id$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("img",{draggable:""+($can_edit$jscomp$10$$??""),src:$APP.$app$config$resolve_media$$($thumbnail_id$jscomp$2$$),loading:"lazy",decoding:"async",className:"main_ui_dashboard_grid__grid-item-thumbnail-image"}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{className:"main_ui_dashboard_grid__grid-loader",draggable:""+($can_edit$jscomp$10$$??
""),overlay:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):null})};
$app$main$ui$dashboard$grid$grid_item_library_STAR_$$=function($can_restore$jscomp$5_props_82105$$){var $file$jscomp$197$$=$can_restore$jscomp$5_props_82105$$.file;$can_restore$jscomp$5_props_82105$$=$can_restore$jscomp$5_props_82105$$.canRestore;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$197$$)],function(){if($APP.$cljs$core$truth_$$($file$jscomp$197$$)){var $font_ids$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$197$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3982$library_summary$$,$APP.$cljs$cst$2215$typographies$$,$cljs$cst$6286$sample$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$));return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,$font_ids$$)}return null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__grid-item-th main_ui_dashboard_grid__library "+
($APP.$cljs$core$truth_$$($can_restore$jscomp$5_props_82105$$)?"main_ui_dashboard_grid__deleted-item":""),children:$file$jscomp$197$$==null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{className:"main_ui_dashboard_grid__grid-loader",overlay:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):function(){var $summary$jscomp$6_typographies$jscomp$12$$=$APP.$cljs$cst$3982$library_summary$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$197$$),
$components$jscomp$25$$=$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$),$colors$jscomp$27$$=$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$);$summary$jscomp$6_typographies$jscomp$12$$=$APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)===
0&&$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)===0&&$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$)===0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components")}),
(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",0,")"]})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",
children:[" (",0,")"]})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",0,")"]})]})})]}):null,$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)>
0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$),
")"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$239$$,$JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$){var $JSCompiler_temp_const$jscomp$1985$$=$out_arr__44124__auto__$jscomp$239$$.push,$root_id$jscomp$inline_9514$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$);
$JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg$$,{"root-shape":$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$root_id$jscomp$inline_9514$$],
null)),objects:$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$),className:"main_ui_dashboard_grid__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$)})})]},
["assets-component-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$))].join(""));$JSCompiler_temp_const$jscomp$1985$$.call($out_arr__44124__auto__$jscomp$239$$,$JSCompiler_inline_result$jscomp$1987_component$jscomp$137$$);return $out_arr__44124__auto__$jscomp$239$$},[],$cljs$cst$6286$sample$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)),$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)>
$APP.$cljs$core$count$$($cljs$cst$6286$sample$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__item-name",children:"(...)"})})}):null]})]}):null,$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)>0?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__asset-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$),")"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__asset-list",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$240$$,$JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$){var $JSCompiler_temp_const$jscomp$1988$$=$out_arr__44124__auto__$jscomp$240$$.push,$default_name$jscomp$inline_9516$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$))?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$139$type$$],null))):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$))?$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$):$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$);
$JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list-item main_ui_dashboard_grid__color-item",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{color:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$),
$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$)],null),mini:!0}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__name-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__color-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$)}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$),
$default_name$jscomp$inline_9516$$)?null:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__color-value",children:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$)})]})]},["assets-color-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$))].join(""));$JSCompiler_temp_const$jscomp$1988$$.call($out_arr__44124__auto__$jscomp$240$$,
$JSCompiler_inline_result$jscomp$1990_color$jscomp$238$$);return $out_arr__44124__auto__$jscomp$240$$},[],$cljs$cst$6286$sample$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)),$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)>$APP.$cljs$core$count$$($cljs$cst$6286$sample$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__item-name",children:"(...)"})})}):null]})]}):null,$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$)>0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography")}),
(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$),")"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$241$$,$typography$jscomp$40$$){$out_arr__44124__auto__$jscomp$241$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__asset-list-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$)},className:"main_ui_dashboard_grid__typography-sample",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$),className:"main_ui_dashboard_grid__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$)})})]},["assets-typography-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$))].join("")));
return $out_arr__44124__auto__$jscomp$241$$},[],$cljs$cst$6286$sample$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$)),$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$)>$APP.$cljs$core$count$$($cljs$cst$6286$sample$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$6_typographies$jscomp$12$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__item-name",children:"(...)"})})}):null]})]}):null]})}()})};
$app$main$ui$dashboard$grid$grid_item_metadata_STAR_$$=function($JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$){$JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$=$JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$.file;var $or__5025__auto__$jscomp$inline_9518$$=$APP.$cljs$cst$4922$will_be_deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$);
$JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9518$$)?$or__5025__auto__$jscomp$inline_9518$$:$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$);$JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$=$APP.$app$common$time$timeago$$($JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$);
return(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.deleted.will-be-deleted-at",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$])),className:"main_ui_dashboard_grid__date",children:$JSCompiler_inline_result$jscomp$1991_file$jscomp$198_props_82117_time$jscomp$8$$})};
$app$main$ui$dashboard$grid$create_counter_element$$=function($file_count$jscomp$4$$){var $counter_el$jscomp$2$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("div");$APP.$app$util$dom$set_property_BANG_$$($counter_el$jscomp$2$$,"class","main_ui_dashboard_grid__drag-counter");$APP.$app$util$dom$set_text_BANG_$$($counter_el$jscomp$2$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($file_count$jscomp$4$$));return $counter_el$jscomp$2$$};
$app$main$ui$dashboard$grid$grid_item_STAR_$$=function($origin$jscomp$71_props_82120$$){var $file$jscomp$199$$=$origin$jscomp$71_props_82120$$.file,$can_edit$jscomp$11$$=$origin$jscomp$71_props_82120$$.canEdit,$selected_files$jscomp$1$$=$origin$jscomp$71_props_82120$$.selectedFiles,$can_restore$jscomp$6$$=$origin$jscomp$71_props_82120$$.canRestore;$origin$jscomp$71_props_82120$$=$origin$jscomp$71_props_82120$$.origin;var $file_id$jscomp$454$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$199$$,
$APP.$cljs$cst$266$id$$),$state$jscomp$1230$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$),$menu_pos$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1230$$,$APP.$cljs$cst$4928$menu_pos$$),$menu_open_QMARK_$jscomp$2$$=function(){var $and__5023__auto__$jscomp$1015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1230$$,$APP.$cljs$cst$4927$menu_open$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1015$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$454$$,
$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1230$$)):$and__5023__auto__$jscomp$1015$$}(),$selected_QMARK_$jscomp$28$$=$APP.$cljs$core$contains_QMARK_$$($selected_files$jscomp$1$$,$file_id$jscomp$454$$),$selected_num$$=$APP.$cljs$core$count$$($selected_files$jscomp$1$$),$node_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(),$menu_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$is_library_view_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$71_props_82120$$,
$APP.$cljs$cst$5244$libraries$$),$on_menu_close$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$hide_file_menu$$())}),$on_select$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$28$$),$APP.$rumext$v2$adapt$$($selected_num$$)],function($event$jscomp$726$$){return!$selected_QMARK_$jscomp$28$$||$selected_num$$>
1?($APP.$app$util$dom$stop_propagation$$($event$jscomp$726$$),$event$jscomp$726$$.shiftKey||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$toggle_file_select$$($file$jscomp$199$$))):null}),$on_navigate$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$454$$),$APP.$rumext$v2$adapt$$($can_restore$jscomp$6$$)],
function($event$jscomp$727$$){return $APP.$cljs$core$truth_$$($can_restore$jscomp$6$$)?null:$APP.$cljs$core$truth_$$($APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$727$$),$APP.$rumext$v2$ref_val$$($menu_ref$$)))?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$454$$])))}),
$on_drag_start$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$28$$),$APP.$rumext$v2$adapt$$($selected_num$$)],function($event$jscomp$728$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$hide_file_menu$$());if($APP.$cljs$core$truth_$$($can_edit$jscomp$11$$)){var $offset$jscomp$219$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$728$$.nativeEvent),$item_el$jscomp$1$$=$APP.$rumext$v2$ref_val$$($node_ref$jscomp$6$$),
$counter_el$jscomp$3$$=$app$main$ui$dashboard$grid$create_counter_element$$($selected_QMARK_$jscomp$28$$?$selected_num$$:1);$selected_QMARK_$jscomp$28$$||($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$toggle_file_select$$($file$jscomp$199$$)));$APP.$app$util$dom$dnd$set_data_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$728$$,
"penpot/files","dummy");$APP.$app$util$dom$dnd$set_allowed_effect_BANG_$$($event$jscomp$728$$);$APP.$app$util$dom$append_child_BANG_$$($item_el$jscomp$1$$,$counter_el$jscomp$3$$);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($event$jscomp$728$$,$item_el$jscomp$1$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$219$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$219$$));return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$child_QMARK_$$($counter_el$jscomp$3$$,
$item_el$jscomp$1$$))){$item_el$jscomp$1$$!=null&&$item_el$jscomp$1$$.removeChild($counter_el$jscomp$3$$);var $JSCompiler_temp$jscomp$661$$=$item_el$jscomp$1$$}else $JSCompiler_temp$jscomp$661$$=null;return $JSCompiler_temp$jscomp$661$$})}return null}),$on_menu_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$199$$),$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$28$$)],function($JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$){$APP.$app$util$dom$stop_propagation$$($JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$);
$selected_QMARK_$jscomp$28$$||($JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$.shiftKey||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$toggle_file_select$$($file$jscomp$199$$)));var $client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$);
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$)==null&&$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$)==null?($client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$)),$JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$=
$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$),$client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$),$JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$,
$JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$)):$JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$=$client_position_points$jscomp$inline_9523_x$jscomp$inline_9525$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$show_file_menu_with_position$$($file_id$jscomp$454$$,$JSCompiler_temp$jscomp$1992_event$jscomp$729_y$jscomp$inline_9524$$))}),$on_context_menu$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$5$$)],
function($event$jscomp$730$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$730$$);return $on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$730$$):$on_menu_click$jscomp$5$$($event$jscomp$730$$)}),$edit$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$199$$)],function($name$jscomp$500_name_82171__$1$$){$name$jscomp$500_name_82171__$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$500_name_82171__$1$$);
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$500_name_82171__$1$$,"")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$rename_file$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$199$$,$APP.$cljs$cst$725$name$$,$name$jscomp$500_name_82171__$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$stop_edit_file_name$$())}),$on_edit$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$199$$)],
function($event$jscomp$731$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$731$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$start_edit_file_name$$($file_id$jscomp$454$$))}),$on_key_down$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_navigate$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_select$jscomp$8$$)],function($event$jscomp$732$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$732$$);
$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$732$$))&&($on_navigate$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_navigate$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$732$$):$on_navigate$jscomp$1$$($event$jscomp$732$$));return $event$jscomp$732$$.shiftKey?$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$732$$);
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$))return $or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$;$or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$=(0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($event$jscomp$732$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$))return $or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$;
$or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$732$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$)?$or__5025__auto__$jscomp$1391_or__5025__auto____$1$jscomp$157_or__5025__auto____$2$jscomp$41$$:(0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($event$jscomp$732$$)}())?$on_select$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?
$on_select$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$732$$):$on_select$jscomp$8$$($event$jscomp$732$$):null:null}),$on_menu_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$5$$)],function($event$jscomp$733$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$733$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$733$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$733$$),
$on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$733$$):$on_menu_click$jscomp$5$$($event$jscomp$733$$)):null});return(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_grid__grid-item main_ui_dashboard_grid__project-th "+($is_library_view_QMARK_$$?"main_ui_dashboard_grid__library":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{onDoubleClick:$on_navigate$jscomp$1$$,role:"button","aria-label":$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$199$$),
className:($selected_QMARK_$jscomp$28$$?"main_ui_dashboard_grid__selected":"")+" "+($is_library_view_QMARK_$$?"main_ui_dashboard_grid__library":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__overlay"}),$is_library_view_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_library_STAR_$$,{file:$file$jscomp$199$$,canRestore:$can_restore$jscomp$6$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_thumbnail_STAR_$$,{file:$file$jscomp$199$$,
canEdit:$can_edit$jscomp$11$$,canRestore:$can_restore$jscomp$6$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1016$$=$APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$199$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1016$$)?!$is_library_view_QMARK_$$:$and__5023__auto__$jscomp$1016$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__item-badge",children:$APP.$app$main$ui$icons$library$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__info-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__item-info",children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1017$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$454$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1230$$));return $and__5023__auto__$jscomp$1017$$?$APP.$cljs$cst$2199$edition$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1230$$):
$and__5023__auto__$jscomp$1017$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$199$$),"on-end":$edit$jscomp$17$$,"max-length":250}):(0,$APP.$rumext$v2$jsx$$)("h3",{children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$199$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_metadata_STAR_$$,{file:$file$jscomp$199$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_grid__project-th-actions "+($APP.$cljs$core$truth_$$($menu_open_QMARK_$jscomp$2$$)?"main_ui_dashboard_grid__force-display":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{role:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),tabIndex:"0",className:"main_ui_dashboard_grid__project-th-icon main_ui_dashboard_grid__menu",children:[$app$main$ui$dashboard$grid$menu_icon$$,$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$28$$?
$menu_open_QMARK_$jscomp$2$$:$selected_QMARK_$jscomp$28$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$portal$portal_on_document_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$file_menu$file_menu_STAR_$$,{parentId:""+($file_id$jscomp$454$$??"")+"-action-menu",origin:$origin$jscomp$71_props_82120$$,top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($menu_pos$$),onClose:$on_menu_close$jscomp$3$$,canRestore:$can_restore$jscomp$6$$,files:$APP.$cljs$core$vals$$($selected_files$jscomp$1$$),
onEdit:$on_edit$jscomp$14$$,canEdit:$can_edit$jscomp$11$$,left:24+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($menu_pos$$),navigate:!0})}):null],id:""+($file_id$jscomp$454$$??"")+"-action-menu",onClick:$on_menu_click$jscomp$5$$,ref:$menu_ref$$,onKeyDown:$on_menu_key_down$$})})]})],onContextMenu:$on_context_menu$jscomp$31$$,draggable:""+($can_edit$jscomp$11$$??""),onClick:$on_select$jscomp$8$$,title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$199$$),ref:$node_ref$jscomp$6$$,
onDragStart:$on_drag_start$jscomp$6$$,onKeyDown:$on_key_down$jscomp$29$$})})};
$app$main$ui$dashboard$grid$grid_STAR_$$=function($node_ref$jscomp$7_props_82133$$){var $limit$jscomp$9$$=$node_ref$jscomp$7_props_82133$$.limit,$can_edit$jscomp$12$$=$node_ref$jscomp$7_props_82133$$.canEdit,$on_finish_import$jscomp$6_project$jscomp$29$$=$node_ref$jscomp$7_props_82133$$.project,$selected_files$jscomp$2$$=$node_ref$jscomp$7_props_82133$$.selectedFiles,$create_fn$jscomp$1$$=$node_ref$jscomp$7_props_82133$$.createFn,$files$jscomp$39$$=$node_ref$jscomp$7_props_82133$$.files,$can_restore$jscomp$7$$=
$node_ref$jscomp$7_props_82133$$.canRestore,$origin$jscomp$72$$=$node_ref$jscomp$7_props_82133$$.origin,$dragging_QMARK_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$project_id$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_finish_import$jscomp$6_project$jscomp$29$$,$APP.$cljs$cst$266$id$$),$team_id$jscomp$153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_finish_import$jscomp$6_project$jscomp$29$$,$APP.$cljs$cst$1927$team_id$$);
$node_ref$jscomp$7_props_82133$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$on_finish_import$jscomp$6_project$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$43$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$153$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$43$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$153$$),
$app$main$data$dashboard$clear_selected_files$$()]))});var $import_files$$=$APP.$app$main$ui$dashboard$import$0$use_import_file$$($project_id$jscomp$43$$,$on_finish_import$jscomp$6_project$jscomp$29$$),$on_scroll$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$hide_file_menu$$())}),$on_drag_enter$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$402$$){var $JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$;
if($JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$=$APP.$cljs$core$truth_$$($can_edit$jscomp$12$$)){if($JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$=$APP.$cljs$core$not$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$402$$,"penpot/files")))$JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$402$$,"Files"),$JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$)?$JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$:
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$402$$,"application/x-moz-file");$JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$)}return $JSCompiler_inline_result$jscomp$1994_JSCompiler_temp$jscomp$1993_and__5023__auto__$jscomp$inline_9527_or__5025__auto__$jscomp$inline_9528$$?
($APP.$app$util$dom$prevent_default$$($e$jscomp$402$$),$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$10$$,!0)):null}),$on_drag_over$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$403$$){var $JSCompiler_inline_result$jscomp$1995_or__5025__auto__$jscomp$inline_9530$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$403$$,"Files");$JSCompiler_inline_result$jscomp$1995_or__5025__auto__$jscomp$inline_9530$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1995_or__5025__auto__$jscomp$inline_9530$$)?
$JSCompiler_inline_result$jscomp$1995_or__5025__auto__$jscomp$inline_9530$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$403$$,"application/x-moz-file");return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1995_or__5025__auto__$jscomp$inline_9530$$)?$APP.$app$util$dom$prevent_default$$($e$jscomp$403$$):null}),$on_drag_leave$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$404$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$404$$))?
null:$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$10$$,!1)}),$on_drop$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__82134_e$jscomp$405$$){if($APP.$cljs$core$truth_$$($can_edit$jscomp$12$$)){var $JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$;if($JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$=$APP.$cljs$core$not$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82134_e$jscomp$405$$,
"penpot/files")))$JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82134_e$jscomp$405$$,"Files"),$JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$)?$JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$:
$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82134_e$jscomp$405$$,"application/x-moz-file");return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1996_and__5023__auto__$jscomp$inline_9532_or__5025__auto__$jscomp$inline_9533$$)?($APP.$app$util$dom$prevent_default$$($G__82134_e$jscomp$405$$),$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$10$$,!1),$G__82134_e$jscomp$405$$=$G__82134_e$jscomp$405$$.dataTransfer.files,$import_files$$.$cljs$core$IFn$_invoke$arity$1$?$import_files$$.$cljs$core$IFn$_invoke$arity$1$($G__82134_e$jscomp$405$$):
$import_files$$($G__82134_e$jscomp$405$$)):null}return $APP.$app$util$dom$prevent_default$$($G__82134_e$jscomp$405$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{onDragEnter:$on_drag_enter$jscomp$10$$,onDragLeave:$on_drag_leave$jscomp$8$$,className:"main_ui_dashboard_grid__dashboard-grid",children:$files$jscomp$39$$==null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$,{}):$APP.$cljs$core$seq$$($files$jscomp$39$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$242$$,
$p__82136_slice$jscomp$1$$){var $index$jscomp$581$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82136_slice$jscomp$1$$,0,null);$p__82136_slice$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82136_slice$jscomp$1$$,1,null);$out_arr__44124__auto__$jscomp$242$$.push((0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_grid__grid-row",children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$10$$))?(0,$APP.$rumext$v2$jsx$$)("li",
{className:"main_ui_dashboard_grid__grid-item"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$25$$,$item$jscomp$139$$){$out_arr__44124__auto____$1$jscomp$25$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_STAR_$$,{file:$item$jscomp$139$$,origin:$origin$jscomp$72$$,selectedFiles:$selected_files$jscomp$2$$,canEdit:$can_edit$jscomp$12$$,canRestore:$can_restore$jscomp$7$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$139$$)??
"")));return $out_arr__44124__auto____$1$jscomp$25$$},[],$p__82136_slice$jscomp$1$$)]},""+($index$jscomp$581$$??"")));return $out_arr__44124__auto__$jscomp$242$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$partition_all$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$9$$,$limit$jscomp$9$$,$files$jscomp$39$$))):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$,{limit:$limit$jscomp$9$$,canEdit:$can_edit$jscomp$12$$,
createFn:$create_fn$jscomp$1$$,origin:$origin$jscomp$72$$,projectId:$project_id$jscomp$43$$,teamId:$team_id$jscomp$153$$,onFinishImport:$on_finish_import$jscomp$6_project$jscomp$29$$}),onDrop:$on_drop$jscomp$21$$,onDragOver:$on_drag_over$jscomp$4$$,dragabble:""+($can_edit$jscomp$12$$??""),ref:$node_ref$jscomp$7_props_82133$$,onScroll:$on_scroll$jscomp$1$$})};
$app$main$ui$dashboard$grid$line_grid_row$$=function($files$jscomp$40_map__82142_props_82141$$){$files$jscomp$40_map__82142_props_82141$$=$APP.$rumext$v2$util$wrap_props$$($files$jscomp$40_map__82142_props_82141$$);var $limit__$1$jscomp$2_map__82142__$1$$=$APP.$cljs$core$__destructure_map$$($files$jscomp$40_map__82142_props_82141$$);$files$jscomp$40_map__82142_props_82141$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,$APP.$cljs$cst$1916$files$$);var $selected_files$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,$APP.$cljs$cst$2183$selected_files$$),$dragging_QMARK_$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,$APP.$cljs$cst$5368$dragging_QMARK_$$),$limit$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,$cljs$cst$6287$limit$$),$can_edit$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,
$APP.$cljs$cst$1596$can_edit$$),$can_restore$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,$cljs$cst$6288$can_restore$$);$limit__$1$jscomp$2_map__82142__$1$$=$APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$11$$)?$limit$jscomp$10$$-1:$limit$jscomp$10$$;return(0,$APP.$rumext$v2$jsxs$$)("ul",{style:{gridTemplateColumns:"repeat("+($limit$jscomp$10$$??"")+", 1fr)"},className:"main_ui_dashboard_grid__grid-row main_ui_dashboard_grid__no-wrap",children:[$APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$11$$)?
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_grid__grid-item main_ui_dashboard_grid__dragged"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$243$$,$item$jscomp$140$$){$out_arr__44124__auto__$jscomp$243$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_STAR_$$,{id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$140$$),file:$item$jscomp$140$$,selectedFiles:$selected_files$jscomp$3$$,
canEdit:$can_edit$jscomp$13$$,canRestore:$can_restore$jscomp$8$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$140$$)??"")));return $out_arr__44124__auto__$jscomp$243$$},[],$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82142__$1$$,$files$jscomp$40_map__82142_props_82141$$))]})};
$app$main$ui$dashboard$grid$line_grid$$=function($files$jscomp$41_map__82146_props_82145$$){$files$jscomp$41_map__82146_props_82145$$=$APP.$rumext$v2$util$wrap_props$$($files$jscomp$41_map__82146_props_82145$$);var $can_restore$jscomp$9_map__82146__$1$$=$APP.$cljs$core$__destructure_map$$($files$jscomp$41_map__82146_props_82145$$),$on_finish_import$jscomp$7_project$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,$APP.$cljs$cst$2230$project$$),
$on_drag_enter$jscomp$11_team$jscomp$69$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,$APP.$cljs$cst$2492$team$$);$files$jscomp$41_map__82146_props_82145$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,$APP.$cljs$cst$1916$files$$);var $limit$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,$cljs$cst$6287$limit$$),$create_fn$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,
$cljs$cst$6289$create_fn$$),$can_edit$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,$APP.$cljs$cst$1596$can_edit$$);$can_restore$jscomp$9_map__82146__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82146__$1$$,$cljs$cst$6288$can_restore$$);var $dragging_QMARK_$jscomp$12$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$project_id$jscomp$44$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_finish_import$jscomp$7_project$jscomp$30$$),
$team_id$jscomp$154$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_drag_enter$jscomp$11_team$jscomp$69$$),$selected_files$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_files$$),$selected_project$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_project$$);$on_finish_import$jscomp$7_project$jscomp$30$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$154$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$154$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});var $import_files$jscomp$1$$=$APP.$app$main$ui$dashboard$import$0$use_import_file$$($project_id$jscomp$44$$,$on_finish_import$jscomp$7_project$jscomp$30$$);$on_drag_enter$jscomp$11_team$jscomp$69$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_project$jscomp$1$$),$APP.$rumext$v2$adapt$$($can_edit$jscomp$14$$)],function($e$jscomp$406$$){if($APP.$cljs$core$truth_$$($can_edit$jscomp$14$$)){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$406$$,
"penpot/files")))return $APP.$app$util$dom$prevent_default$$($e$jscomp$406$$),$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1395$$=$APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$406$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1395$$)?$or__5025__auto__$jscomp$1395$$:$e$jscomp$406$$.relatedTarget==null}())?null:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_project$jscomp$1$$,$project_id$jscomp$44$$)?$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,
!0):null;if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1396$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$406$$,"Files");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1396$$)?$or__5025__auto__$jscomp$1396$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$406$$,"application/x-moz-file")}()))return $APP.$app$util$dom$prevent_default$$($e$jscomp$406$$),$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!0)}return null});var $on_drag_over$jscomp$5$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$407$$){var $JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$407$$,"penpot/files");$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$)||($JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$407$$,"Files"),$JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$)?$JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$407$$,"application/x-moz-file"));
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1997_or__5025__auto__$jscomp$inline_9535_or__5025__auto____$1$jscomp$inline_9536$$)?$APP.$app$util$dom$prevent_default$$($e$jscomp$407$$):null}),$on_drag_leave$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$408$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$408$$))?null:$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!1)}),$on_drop_success$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$154$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-file")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$154$$),
$app$main$data$dashboard$clear_selected_files$$()]))}),$on_drop$jscomp$22$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$41_map__82146_props_82145$$),$APP.$rumext$v2$adapt$$($selected_files$jscomp$4$$),$APP.$rumext$v2$adapt$$($can_edit$jscomp$14$$)],function($G__82154_data$jscomp$508_e$jscomp$409$$){if($APP.$cljs$core$truth_$$($can_edit$jscomp$14$$)){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82154_data$jscomp$508_e$jscomp$409$$,
"penpot/files"))){if($APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!1),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_project$jscomp$1$$,$project_id$jscomp$44$$))return $G__82154_data$jscomp$508_e$jscomp$409$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($selected_files$jscomp$4$$)),$APP.$cljs$cst$2181$project_id$$,
$project_id$jscomp$44$$],null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$move_files$$($APP.$cljs$core$with_meta$$($G__82154_data$jscomp$508_e$jscomp$409$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,$on_drop_success$jscomp$1$$],null))))}else{var $JSCompiler_inline_result$jscomp$1998_or__5025__auto__$jscomp$inline_9538$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82154_data$jscomp$508_e$jscomp$409$$,"Files");
$JSCompiler_inline_result$jscomp$1998_or__5025__auto__$jscomp$inline_9538$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1998_or__5025__auto__$jscomp$inline_9538$$)?$JSCompiler_inline_result$jscomp$1998_or__5025__auto__$jscomp$inline_9538$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82154_data$jscomp$508_e$jscomp$409$$,"application/x-moz-file");if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1998_or__5025__auto__$jscomp$inline_9538$$))return $APP.$app$util$dom$prevent_default$$($G__82154_data$jscomp$508_e$jscomp$409$$),
$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!1),$G__82154_data$jscomp$508_e$jscomp$409$$=$G__82154_data$jscomp$508_e$jscomp$409$$.dataTransfer.files,$import_files$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$import_files$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__82154_data$jscomp$508_e$jscomp$409$$):$import_files$jscomp$1$$($G__82154_data$jscomp$508_e$jscomp$409$$)}return null}return $APP.$app$util$dom$prevent_default$$($G__82154_data$jscomp$508_e$jscomp$409$$)});return(0,$APP.$rumext$v2$jsx$$)("div",
{dragabble:""+($can_edit$jscomp$14$$??""),onDragEnter:$on_drag_enter$jscomp$11_team$jscomp$69$$,onDragOver:$on_drag_over$jscomp$5$$,onDragLeave:$on_drag_leave$jscomp$9$$,onDrop:$on_drop$jscomp$22$$,className:"main_ui_dashboard_grid__dashboard-grid",children:$files$jscomp$41_map__82146_props_82145$$==null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$,{}):$APP.$cljs$core$seq$$($files$jscomp$41_map__82146_props_82145$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$line_grid_row$$,
{files:$files$jscomp$41_map__82146_props_82145$$,"team-id":$team_id$jscomp$154$$,"selected-files":$selected_files$jscomp$4$$,"dragging?":$APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$12$$),"can-edit":$can_edit$jscomp$14$$,limit:$limit$jscomp$11$$,"can-restore":$can_restore$jscomp$9_map__82146__$1$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$,{isDragging:$APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$12$$),limit:$limit$jscomp$11$$,canEdit:$can_edit$jscomp$14$$,
createFn:$create_fn$jscomp$2$$,projectId:$project_id$jscomp$44$$,teamId:$team_id$jscomp$154$$,onFinishImport:$on_finish_import$jscomp$7_project$jscomp$30$$})})};
$app$main$ui$dashboard$deleted$on_restore_project$$=function($project$jscomp$31$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-project-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-project-confirmation.description",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$31$$)])),$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$2478$primary$$,$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$restore_project_immediately$$($project$jscomp$31$$))}],
null)))};
$app$main$ui$dashboard$deleted$on_delete_project$$=function($project$jscomp$32$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-project-forever-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$32$$)])),
$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$delete_project_immediately$$($project$jscomp$32$$))}],null)))};
$app$main$ui$dashboard$deleted$header_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_deleted__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-deleted-title",className:"main_ui_dashboard_deleted__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.projects-title")})})})};
$app$main$ui$dashboard$deleted$project_context_menu_STAR_$$=function($props_82608_top__$1$jscomp$7$$){var $show$jscomp$8$$=$props_82608_top__$1$jscomp$7$$.show,$left$jscomp$43_left__$1$jscomp$8$$=$props_82608_top__$1$jscomp$7$$.left,$on_close$jscomp$46$$=$props_82608_top__$1$jscomp$7$$.onClose,$options$jscomp$646_project$jscomp$33$$=$props_82608_top__$1$jscomp$7$$.project;$props_82608_top__$1$jscomp$7$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_82608_top__$1$jscomp$7$$.top,
0);$left$jscomp$43_left__$1$jscomp$8$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$43_left__$1$jscomp$8$$,0);var $on_restore_project$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$646_project$jscomp$33$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$deleted$on_restore_project$$,$options$jscomp$646_project$jscomp$33$$)),$on_delete_project$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$646_project$jscomp$33$$)],
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$deleted$on_delete_project$$,$options$jscomp$646_project$jscomp$33$$));$options$jscomp$646_project$jscomp$33$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_restore_project$$),$APP.$rumext$v2$adapt$$($on_delete_project$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-project-button"),$APP.$cljs$cst$266$id$$,"project-restore",$APP.$cljs$cst$2402$handler$$,$on_restore_project$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-project-button"),$APP.$cljs$cst$266$id$$,"project-delete",$APP.$cljs$cst$2402$handler$$,$on_delete_project$$],null)],null)});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,
{onClose:$on_close$jscomp$46$$,show:$show$jscomp$8$$,fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_82608_top__$1$jscomp$7$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$43_left__$1$jscomp$8$$,0),minWidth:!0,top:$props_82608_top__$1$jscomp$7$$,left:$left$jscomp$43_left__$1$jscomp$8$$,options:$options$jscomp$646_project$jscomp$33$$})};
$app$main$ui$dashboard$deleted$deleted_project_item_STAR_$$=function($project_files_props_82616$$){var $project$jscomp$34$$=$project_files_props_82616$$.project;$project_files_props_82616$$=$APP.$cljs$core$filterv$$(function($p1__82613_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82613_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$))},$project_files_props_82616$$.files);
var $empty_QMARK_$jscomp$3$$=$APP.$cljs$core$empty_QMARK_$$($project_files_props_82616$$),$selected_files$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_files$$),$dstate$jscomp$1_rowref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$),$edit_id$jscomp$3$$=$APP.$cljs$cst$4936$project_for_edit$$.$cljs$core$IFn$_invoke$arity$1$($dstate$jscomp$1_rowref$jscomp$1$$),$local$jscomp$32$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4927$menu_open$$,!1,$APP.$cljs$cst$4928$menu_pos$$,null,$APP.$cljs$cst$2199$edition$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$),$edit_id$jscomp$3$$)],null)}),$limit$jscomp$12_vec__82621$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$dstate$jscomp$1_rowref$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$12_vec__82621$$,
0,null);$limit$jscomp$12_vec__82621$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$12_vec__82621$$,1,null);var $on_menu_click$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$){$APP.$app$util$dom$prevent_default$$($JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$);var $client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$);
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$)==null&&$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$)==null?($client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$)),$JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$=
$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$),$client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$),$JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$,
$JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$)):$JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$=$client_position$jscomp$1_points$jscomp$inline_9540_x$jscomp$inline_9542$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$32$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4928$menu_pos$$,$JSCompiler_temp$jscomp$1999_event$jscomp$734_y$jscomp$inline_9541$$]))}),
$on_menu_close$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$32$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!1)}),$handle_menu_click$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$6$$)],function($event$jscomp$735$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$735$$))?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$735$$),$on_menu_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$735$$):$on_menu_click$jscomp$6$$($event$jscomp$735$$)):null});return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_dashboard_deleted__dashboard-project-row",children:[(0,$APP.$rumext$v2$jsx$$)("header",{className:"main_ui_dashboard_deleted__project",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__project-name-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)("h2",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$),className:"main_ui_dashboard_deleted__project-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$)}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2571$deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__info-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_deleted__project-actions",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_menu_click$jscomp$6$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),"data-testid":"project-options",onKeyDown:$handle_menu_click$$,className:"main_ui_dashboard_deleted__options-btn",children:$app$main$ui$dashboard$deleted$menu_icon$$})}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$4927$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$32$$)))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$project_context_menu_STAR_$$,{project:$project$jscomp$34$$,show:$APP.$cljs$cst$4927$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$32$$)),left:24+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$32$$))),top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$32$$))),
onClose:$on_menu_close$jscomp$4$$}):null]}):null]})}),(0,$APP.$rumext$v2$jsx$$)("div",{ref:$dstate$jscomp$1_rowref$jscomp$1$$,className:"main_ui_dashboard_deleted__grid-container",children:$empty_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-title"),className:"main_ui_dashboard_deleted__placeholder-placement",type:1,subtitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-subtitle")}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{project:$project$jscomp$34$$,files:$project_files_props_82616$$,origin:$APP.$cljs$cst$2541$deleted$$,canEdit:!1,canRestore:!0,limit:$limit$jscomp$12_vec__82621$$,selectedFiles:$selected_files$jscomp$5$$})})]})};
$app$main$ui$dashboard$deleted$menu_STAR_$$=function($props_82640_section$jscomp$37$$){var $team_id$jscomp$155$$=$props_82640_section$jscomp$37$$.teamId;$props_82640_section$jscomp$37$$=$props_82640_section$jscomp$37$$.section;var $on_recent_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$155$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$155$$])))}),$on_deleted_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$155$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_deleted$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$155$$])))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_deleted__nav",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__nav-inside",children:[(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"recent-tab",onClick:$on_recent_click$$,className:"main_ui_dashboard_deleted__nav-option "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_82640_section$jscomp$37$$,$APP.$cljs$cst$2522$dashboard_recent$$)?"main_ui_dashboard_deleted__selected":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.recent")}),(0,$APP.$rumext$v2$jsx$$)("div",
{variant:"ghost",type:"button","data-testid":"deleted-tab",onClick:$on_deleted_click$$,className:"main_ui_dashboard_deleted__nav-option "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_82640_section$jscomp$37$$,$APP.$cljs$cst$2536$dashboard_deleted$$)?"main_ui_dashboard_deleted__selected":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.deleted")})]})})};
$app$main$ui$dashboard$deleted$deleted_section_STAR_$$=function($projects__$1_props_82666$$){var $projects$jscomp$9$$=$projects__$1_props_82666$$.projects,$team$jscomp$70$$=$projects__$1_props_82666$$.team,$deleted_map$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$deleted$ref_COLON_deleted_files$$);$projects__$1_props_82666$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$9$$),$APP.$rumext$v2$adapt$$($deleted_map$$)],function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($project$jscomp$35$$){return $APP.$cljs$core$truth_$$($deleted_map$$)?$APP.$cljs$core$some$$(function($p1__82655_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$35$$),$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82655_SHARP_$$))},$APP.$cljs$core$vals$$($deleted_map$$)):null},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($project$jscomp$36$$){var $or__5025__auto__$jscomp$1399$$=
$APP.$cljs$cst$2571$deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1399$$)?$or__5025__auto__$jscomp$1399$$:$APP.$cljs$core$truth_$$($deleted_map$$)?$APP.$cljs$core$some$$(function($p1__82654_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$36$$),$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82654_SHARP_$$))},
$APP.$cljs$core$vals$$($deleted_map$$)):null},$projects$jscomp$9$$)))))});var $team_id$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$70$$,$APP.$cljs$cst$266$id$$),$deletion_days$$=function(){var $canceled_QMARK__sub_status_subscription$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$70$$,$APP.$cljs$cst$3201$subscription$$),$sub_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($canceled_QMARK__sub_status_subscription$jscomp$12$$,
$APP.$cljs$cst$139$type$$);$canceled_QMARK__sub_status_subscription$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($canceled_QMARK__sub_status_subscription$jscomp$12$$,$APP.$cljs$cst$109$status$$);$canceled_QMARK__sub_status_subscription$jscomp$12$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],null),null),$canceled_QMARK__sub_status_subscription$jscomp$12$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("unlimited",
$sub_type$$)&&!$canceled_QMARK__sub_status_subscription$jscomp$12$$?30:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$sub_type$$)&&!$canceled_QMARK__sub_status_subscription$jscomp$12$$?90:7}(),$on_delete_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$156$$),$APP.$rumext$v2$adapt$$($deleted_map$$)],function(){var $temp__5825__auto__$jscomp$456$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$),$deleted_map$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$456$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-all-forever-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($temp__5825__auto__$jscomp$456$$)])),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$delete_files_immediately$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$156$$,$APP.$cljs$cst$1723$ids$$,$temp__5825__auto__$jscomp$456$$],null)))}],null))):null}),$on_restore_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$156$$),$APP.$rumext$v2$adapt$$($deleted_map$$)],function(){var $temp__5825__auto__$jscomp$457$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$),
$deleted_map$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$457$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-all-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-all-confirmation.description",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($temp__5825__auto__$jscomp$457$$)])),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$2478$primary$$,$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$restore_files_immediately$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$156$$,$APP.$cljs$cst$1723$ids$$,$temp__5825__auto__$jscomp$457$$],null)))}],null))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$156$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_projects$$($team_id$jscomp$156$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$156$$),
$app$main$data$dashboard$clear_selected_files$$()]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$header_STAR_$$,{team:$team$jscomp$70$$}),(0,$APP.$rumext$v2$jsx$$)("section",{"data-testid":"deleted-page-section",className:"main_ui_dashboard_deleted__dashboard-container main_ui_dashboard_deleted__no-bg",children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__no-bg",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$menu_STAR_$$,{teamId:$team_id$jscomp$156$$,section:$APP.$cljs$cst$2536$dashboard_deleted$$}),$APP.$cljs$core$seq$$($projects__$1_props_82666$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__deleted-info-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_dashboard_deleted__deleted-info",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.trash-info-text-part1"),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_deleted__info-text-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.trash-info-text-part2",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$deletion_days$$]))}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.trash-info-text-part3"),(0,$APP.$rumext$v2$jsx$$)("br",{}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.trash-info-text-part4")]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__deleted-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"ghost",type:"button",onClick:$on_restore_all$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-all-deleted-button")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"destructive",type:"button",icon:"delete",onClick:$on_delete_all$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.clear-trash-button")})]})]}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$244$$,$p__82696$$){var $map__82697__$1$$=$APP.$cljs$core$__destructure_map$$($p__82696$$),$id$jscomp$1061$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82697__$1$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$244$$.push(function(){var $files$jscomp$43$$=$APP.$cljs$core$truth_$$($deleted_map$$)?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1737$modified_at$$,
function($p1__82664_SHARP_$$,$p2__82663_SHARP_$$){return $APP.$cljs$core$compare$$($p2__82663_SHARP_$$,$p1__82664_SHARP_$$)},$APP.$cljs$core$filterv$$(function($p1__82661_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1061$$,$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82661_SHARP_$$))},$APP.$cljs$core$vals$$($deleted_map$$))):null;return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$deleted_project_item_STAR_$$,{project:$map__82697__$1$$,
files:$files$jscomp$43$$},$id$jscomp$1061$$)}());return $out_arr__44124__auto__$jscomp$244$$},[],$projects__$1_props_82666$$)]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_deleted__deleted-info-content",children:(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_deleted__deleted-info",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.deleted.empty-state-description")})})]})})})]})};
$app$main$ui$dashboard$pin_button$pin_button_STAR_$$=function($props_82155_props__$1$jscomp$107$$){var $aria_label$jscomp$11_aria_label__$1$jscomp$1$$=$props_82155_props__$1$jscomp$107$$["aria-label"],$class$__$1$jscomp$13_is_pinned$jscomp$2$$=$props_82155_props__$1$jscomp$107$$.isPinned,$class$$jscomp$83$$=$props_82155_props__$1$jscomp$107$$.className;$aria_label$jscomp$11_aria_label__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($aria_label$jscomp$11_aria_label__$1$jscomp$1$$)?$aria_label$jscomp$11_aria_label__$1$jscomp$1$$:
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.pin-unpin");$class$__$1$jscomp$13_is_pinned$jscomp$2$$=""+(($APP.$cljs$core$truth_$$($class$$jscomp$83$$)?$class$$jscomp$83$$:"")??"")+" main_ui_dashboard_pin_button__button "+($APP.$cljs$core$truth_$$($class$__$1$jscomp$13_is_pinned$jscomp$2$$)?"main_ui_dashboard_pin_button__button-active":"");$props_82155_props__$1$jscomp$107$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props_82155_props__$1$jscomp$107$$),
"isPinned"),"className",$class$__$1$jscomp$13_is_pinned$jscomp$2$$),"aria-label",$aria_label$jscomp$11_aria_label__$1$jscomp$1$$);return(0,$APP.$rumext$v2$create_element$$)("button",$props_82155_props__$1$jscomp$107$$,$app$main$ui$dashboard$pin_button$pin_icon$$)};
$app$main$ui$dashboard$files$header_STAR_$$=function($on_menu_close$jscomp$5_props_82599$$){var $can_edit$jscomp$15$$=$on_menu_close$jscomp$5_props_82599$$.canEdit,$project$jscomp$38$$=$on_menu_close$jscomp$5_props_82599$$.project,$create_fn$jscomp$3$$=$on_menu_close$jscomp$5_props_82599$$.createFn,$project_id$jscomp$45$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),$local$jscomp$33$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$4927$menu_open$$,!1,$APP.$cljs$cst$2199$edition$$,!1],null)),$on_create_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($create_fn$jscomp$3$$)],function($event$jscomp$736$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$736$$);return $create_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$create_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$("dashboard:header"):$create_fn$jscomp$3$$("dashboard:header")}),$on_menu_click$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$737$$){var $position$jscomp$244$$=
$APP.$app$util$dom$get_client_position$$($event$jscomp$737$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$737$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$33$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4928$menu_pos$$,$position$jscomp$244$$]))});$on_menu_close$jscomp$5_props_82599$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$33$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!1)});var $on_edit$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$33$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4927$menu_open$$,!1]))}),$toggle_pin$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$38$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$toggle_project_pin$$($project$jscomp$38$$))}),$on_import$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$45$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$45$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});
return(0,$APP.$rumext$v2$jsxs$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_files__dashboard-header",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$))?(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-drafts-title",className:"main_ui_dashboard_files__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts")})}):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1021$$=
$APP.$cljs$cst$2199$edition$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1021$$)?$can_edit$jscomp$15$$:$and__5023__auto__$jscomp$1021$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),"on-end":function($name$jscomp$501_name__$1$jscomp$25$$){$name$jscomp$501_name__$1$jscomp$25$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$501_name__$1$jscomp$25$$);
$APP.$cuerdas$core$empty_QMARK_$$($name$jscomp$501_name__$1$jscomp$25$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$rename_project$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$38$$,$APP.$cljs$cst$725$name$$,$name$jscomp$501_name__$1$jscomp$25$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"project"],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$33$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,!1)},"max-length":250}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_files__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{onDoubleClick:$on_edit$jscomp$15$$,"data-testid":"project-title",id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$)})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_files__dashboard-header-actions",
children:[$can_edit$jscomp$15$$?(0,$APP.$rumext$v2$jsx$$)("a",{tabIndex:"0",onClick:$on_create_click$$,"data-testid":"new-file",onKeyDown:function($event$jscomp$738$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$738$$))?$on_create_click$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$738$$):$on_create_click$$($event$jscomp$738$$):null},className:"main_ui_dashboard_files__btn-secondary main_ui_dashboard_files__btn-small main_ui_dashboard_files__new-file",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file")}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$))?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$pin_button$pin_button_STAR_$$,{tabIndex:0,isPinned:$APP.$cljs$cst$4903$is_pinned$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),onClick:$toggle_pin$jscomp$1$$,onKeyDown:function($event$jscomp$739$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$739$$))?
$toggle_pin$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_pin$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$739$$):$toggle_pin$jscomp$1$$($event$jscomp$739$$):null}}),$can_edit$jscomp$15$$?(0,$APP.$rumext$v2$jsx$$)("div",{tabIndex:"0",onClick:$on_menu_click$jscomp$7$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),onKeyDown:function($event$jscomp$740$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$740$$))?
$on_menu_click$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$740$$):$on_menu_click$jscomp$7$$($event$jscomp$740$$):null},className:"main_ui_dashboard_files__icon",children:$app$main$ui$dashboard$files$menu_icon$$}):null,$can_edit$jscomp$15$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$project_menu$project_menu_STAR_$$,{project:$project$jscomp$38$$,show:$APP.$cljs$cst$4927$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$)),
left:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$)))-180,top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$))),onEdit:$on_edit$jscomp$15$$,onClose:$on_menu_close$jscomp$5_props_82599$$,onImport:$on_import$jscomp$2$$}):null]})]})};
$app$main$ui$dashboard$files$files_section_STAR_$$=function($props_82619_team$jscomp$71$$){var $project$jscomp$39$$=$props_82619_team$jscomp$71$$.project;$props_82619_team$jscomp$71$$=$props_82619_team$jscomp$71$$.team;var $files$jscomp$44$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$project_id$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$39$$,$APP.$cljs$cst$266$id$$),$files__$1$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$46$$),
$APP.$rumext$v2$adapt$$($files$jscomp$44$$)],function(){return $APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82615_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($project_id$jscomp$46$$,$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82615_SHARP_$$))},$APP.$cljs$core$vals$$($files$jscomp$44$$))))}),$can_edit_QMARK_$jscomp$15$$=
$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($props_82619_team$jscomp$71$$)),$project_id__$1$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$),$is_draft_proyect$$=$APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$),$limit$jscomp$13_vec__82629$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$rowref$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$13_vec__82629$$,0,null);$limit$jscomp$13_vec__82629$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$13_vec__82629$$,1,null);var $file_count$jscomp$5$$=function(){var $or__5025__auto__$jscomp$1402$$=$APP.$cljs$core$count$$($files__$1$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1402$$)?$or__5025__auto__$jscomp$1402$$:0}(),$empty_state_viewer$$=$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$15$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$file_count$jscomp$5$$),$selected_files$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_files$$),$on_file_created$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file_data$jscomp$125_page_id$jscomp$466$$){var $file_id$jscomp$455$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$125_page_id$jscomp$466$$);$file_data$jscomp$125_page_id$jscomp$466$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file_data$jscomp$125_page_id$jscomp$466$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2228$pages$$,0],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$455$$,$APP.$cljs$cst$2043$page_id$$,$file_data$jscomp$125_page_id$jscomp$466$$])))}),$create_file$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$39$$)],function($origin$jscomp$73$$){var $mdata$jscomp$26$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,$on_file_created$$],null),$params$jscomp$443$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($app$main$data$dashboard$create_file$$($APP.$cljs$core$with_meta$$($params$jscomp$443$$,
$mdata$jscomp$26$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$73$$,$cljs$cst$6290$has_files$$,$file_count$jscomp$5$$>0],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$39$$)],function(){if($APP.$cljs$core$truth_$$($project$jscomp$39$$)){var $pname$jscomp$26$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$pname$jscomp$26$$])))}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id__$1$jscomp$4$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id__$1$jscomp$4$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6291$app_DOT_main_DOT_ui_DOT_dashboard_DOT_files_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_drafts_libraries$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$files$header_STAR_$$,{team:$props_82619_team$jscomp$71$$,canEdit:$can_edit_QMARK_$jscomp$15$$,project:$project$jscomp$39$$,createFn:$create_file$$}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$rowref$jscomp$2$$,className:"main_ui_dashboard_files__dashboard-container main_ui_dashboard_files__no-bg",children:$empty_state_viewer$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$cljs$core$truth_$$($is_draft_proyect$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-title"),className:"main_ui_dashboard_files__placeholder-placement",type:1,subtitle:$APP.$cljs$core$truth_$$($is_draft_proyect$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-subtitle"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-subtitle")}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{project:$project$jscomp$39$$,files:$files__$1$jscomp$6$$,selectedFiles:$selected_files$jscomp$6$$,canEdit:$can_edit_QMARK_$jscomp$15$$,origin:$APP.$cljs$cst$1916$files$$,createFn:$create_file$$,limit:$limit$jscomp$13_vec__82629$$})})]})};
$app$main$ui$dashboard$fonts$use_page_title$$=function($team$jscomp$72$$,$section$jscomp$38$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$72$$)],function(){if($APP.$cljs$core$truth_$$($team$jscomp$72$$)){var $tname$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$72$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$72$$),
$G__82609__$1$$=$section$jscomp$38$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$38$$.$fqn$:null;switch($G__82609__$1$$){case "fonts":return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.fonts",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$1$$])));case "providers":return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.font-providers",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$1$$])));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__82609__$1$$)].join(""));}}else return null})};$app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$=function($font$jscomp$55$$){return $APP.$cljs$core$contains_QMARK_$$($font$jscomp$55$$,$cljs$cst$6292$font_family_tmp$$)&&$APP.$cuerdas$core$blank_QMARK_$$($cljs$cst$6292$font_family_tmp$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$55$$))};
$app$main$ui$dashboard$fonts$handle_font_upload$$=function($map__82612__$1_p__82611$$){$map__82612__$1_p__82611$$=$APP.$cljs$core$__destructure_map$$($map__82612__$1_p__82611$$);var $id$jscomp$1062$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82612__$1_p__82611$$,$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$map$$(function($font$jscomp$56$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1062$$,$font$jscomp$56$$],
null)},$APP.$beicon$v2$core$delay_at_least$$(2E3,$app$main$data$fonts$upload_font_variant$$($map__82612__$1_p__82611$$)))};
$app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$=function($props_82620_variant$jscomp$29$$){$props_82620_variant$jscomp$29$$=$props_82620_variant$jscomp$29$$.variant;return(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$common$media$font_display_variant$$($APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($props_82620_variant$jscomp$29$$),$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($props_82620_variant$jscomp$29$$),$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($props_82620_variant$jscomp$29$$))})};
$app$main$ui$dashboard$fonts$uploaded_fonts_STAR_$$=function($disable_upload_all_QMARK__props_82638$$){var $installed_fonts$jscomp$2$$=$disable_upload_all_QMARK__props_82638$$.installedFonts,$on_upload_all_team$jscomp$74$$=$disable_upload_all_QMARK__props_82638$$.team,$fonts_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$fonts$jscomp$42$$=$APP.$cljs$core$_deref$$($fonts_STAR_$$),$font_vals$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$42$$)],
function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$fonts$jscomp$42$$))}),$team_id$jscomp$157$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_upload_all_team$jscomp$74$$),$input_ref$jscomp$14$$=(0,$APP.$rumext$v2$use_ref$$)(),$uploading_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),
$uploading$$=$APP.$cljs$core$_deref$$($uploading_STAR_$$);$disable_upload_all_QMARK__props_82638$$=$APP.$cljs$core$some$$($app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$,$fonts$jscomp$42$$);var $problematic_fonts_QMARK_$$=$APP.$cljs$core$some$$($APP.$cljs$cst$3499$height_warning_QMARK_$$,$APP.$cljs$core$vals$$($fonts$jscomp$42$$)),$on_click$jscomp$64$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$14$$))}),
$on_selected$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$157$$),$APP.$rumext$v2$adapt$$($installed_fonts$jscomp$2$$)],function($blobs$jscomp$4$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$385$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($fonts_STAR_$$,$app$main$data$fonts$merge_and_group_fonts$$,$installed_fonts$jscomp$2$$,$result$jscomp$385$$)},function($error$jscomp$153$$){return console.error("error",
$error$jscomp$153$$)},$app$main$data$fonts$process_upload$$($blobs$jscomp$4$$,$team_id$jscomp$157$$))}),$on_upload$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$42$$)],function($event$jscomp$741_id$jscomp$1063$$){$event$jscomp$741_id$jscomp$1063$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$741_id$jscomp$1063$$),"id"));var $item$jscomp$142$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$42$$,
$event$jscomp$741_id$jscomp$1063$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,$APP.$cljs$core$conj$$,$event$jscomp$741_id$jscomp$1063$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($font$jscomp$57_p__82641$$){var $previous_id$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$57_p__82641$$,0,null);$font$jscomp$57_p__82641$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$57_p__82641$$,
1,null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$previous_id$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,$APP.$cljs$core$disj$$,$previous_id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$add_font$$($font$jscomp$57_p__82641$$))},function($cause$jscomp$111$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$first$$($APP.$cljs$cst$3500$names$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$142$$))]))));return console.error("Unexpected error on uploading font",$cause$jscomp$111$$)},$app$main$ui$dashboard$fonts$handle_font_upload$$($item$jscomp$142$$))}),$on_blur_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($installed_fonts$jscomp$2$$)],function($event$jscomp$742_id$jscomp$1064$$){var $name$jscomp$502_target$jscomp$171$$=
$APP.$app$util$dom$get_current_target$$($event$jscomp$742_id$jscomp$1064$$);$event$jscomp$742_id$jscomp$1064$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($name$jscomp$502_target$jscomp$171$$,"id"));$name$jscomp$502_target$jscomp$171$$=$APP.$app$util$dom$get_value$$($name$jscomp$502_target$jscomp$171$$);var $JSCompiler_inline_result$jscomp$2000_and__5023__auto__$jscomp$inline_9544$$=($JSCompiler_inline_result$jscomp$2000_and__5023__auto__$jscomp$inline_9544$$=!$APP.$cuerdas$core$blank_QMARK_$$($name$jscomp$502_target$jscomp$171$$))?
$APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$font$schema_COLON_font_family$$,$name$jscomp$502_target$jscomp$171$$):$JSCompiler_inline_result$jscomp$2000_and__5023__auto__$jscomp$inline_9544$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2000_and__5023__auto__$jscomp$inline_9544$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($fonts_STAR_$$,$app$main$data$fonts$rename_and_regroup$$,$event$jscomp$742_id$jscomp$1064$$,$name$jscomp$502_target$jscomp$171$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$installed_fonts$jscomp$2$$])):null}),$on_change_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$743_target$jscomp$172$$){$event$jscomp$743_target$jscomp$172$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$743_target$jscomp$172$$);var $id$jscomp$1065$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($event$jscomp$743_target$jscomp$172$$,"id"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($fonts_STAR_$$,
$APP.$cljs$core$update$$,$id$jscomp$1065$$,$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$6292$font_family_tmp$$,$APP.$app$util$dom$get_value$$($event$jscomp$743_target$jscomp$172$$)]))}),$on_delete$jscomp$19$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_upload_all_team$jscomp$74$$)],function($event$jscomp$744_id$jscomp$1066$$){$event$jscomp$744_id$jscomp$1066$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$744_id$jscomp$1066$$),
"id"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$event$jscomp$744_id$jscomp$1066$$)});$on_upload_all_team$jscomp$74$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_vals$$)],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($font$jscomp$58_p__82656$$){var $previous_id$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$58_p__82656$$,
0,null);$font$jscomp$58_p__82656$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$58_p__82656$$,1,null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$previous_id$jscomp$1$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,$APP.$cljs$core$disj$$,$previous_id$jscomp$1$$);return $APP.$cljs$core$truth_$$($font$jscomp$58_p__82656$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$add_font$$($font$jscomp$58_p__82656$$)):
null},$APP.$beicon$v2$core$mapcat$$(function($p__82662$$){var $map__82665__$1$$=$APP.$cljs$core$__destructure_map$$($p__82662$$),$id$jscomp$1067$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82665__$1$$,$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$112$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$first$$($APP.$cljs$cst$3500$names$$.$cljs$core$IFn$_invoke$arity$1$($map__82665__$1$$))]))));console.error("Unexpected error on uploading font",$cause$jscomp$112$$);return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1067$$,null],null))},$app$main$ui$dashboard$fonts$handle_font_upload$$($map__82665__$1$$))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__82633_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,
$APP.$cljs$core$conj$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82633_SHARP_$$))},$APP.$beicon$v2$core$from$$($font_vals$$))))});var $on_dismis_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$42$$)],function(){return $APP.$cljs$core$run_BANG_$$(function($p1__82637_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82637_SHARP_$$))},
$APP.$cljs$core$vals$$($fonts$jscomp$42$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__dashboard-fonts-upload",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__dashboard-fonts-hero",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__desc",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.upload-custom-fonts")}),$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,
{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.hero-text1")}),(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_click$jscomp$64$$,tabIndex:"0",className:"main_ui_dashboard_fonts__btn-primary",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.add-custom-font")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{"input-id":"font-upload",accept:$app$main$ui$dashboard$fonts$accept_font_types$$,
multi:!0,ref:$input_ref$jscomp$14$$,"on-selected":$on_selected$jscomp$2$$})]}),$APP.$cljs$core$truth_$$($APP.$app$config$terms_of_service_uri$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.fonts.hero-text2",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$terms_of_service_uri$$])),level:$APP.$cljs$cst$205$default$$,"is-html":!0}):
null,$APP.$cljs$core$truth_$$($problematic_fonts_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.warning-text"),level:$APP.$cljs$cst$2343$warning$$,"is-html":!0}):null]})}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$seq$$($fonts$jscomp$42$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__font-item main_ui_dashboard_fonts__table-row",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.fonts.fonts-added",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($fonts$jscomp$42$$))]))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_upload_all_team$jscomp$74$$,"data-testid":"upload-all",
disabled:$disable_upload_all_QMARK__props_82638$$,className:"main_ui_dashboard_fonts__btn-primary "+($APP.$cljs$core$truth_$$($disable_upload_all_QMARK__props_82638$$)?"main_ui_dashboard_fonts__disabled":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.upload-all")})}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_dismis_all$$,"data-testid":"dismiss-all",className:"main_ui_dashboard_fonts__btn-secondary",children:(0,$APP.$rumext$v2$jsx$$)("span",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.dismiss-all")})})]})]}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$245$$,$p__82675$$){var $map__82676__$1$$=$APP.$cljs$core$__destructure_map$$($p__82675$$),$id$jscomp$1068$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82676__$1$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$245$$.push(function(){var $uploading_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($uploading$$,
$id$jscomp$1068$$),$disable_upload_QMARK_$$=$uploading_QMARK_$$||$app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$($map__82676__$1$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__font-item main_ui_dashboard_fonts__table-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__family",children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"text","data-id":""+($id$jscomp$1068$$??""),onBlur:$on_blur_name$$,
onChange:$on_change_name$$,defaultValue:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($map__82676__$1$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__variants",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_fonts__label",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$,{variant:$map__82676__$1$$})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__filenames",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$26$$,$item__$1$jscomp$3$$){$out_arr__44124__auto____$1$jscomp$26$$.push((0,$APP.$rumext$v2$jsx$$)("span",{children:$item__$1$jscomp$3$$},"name-"+($item__$1$jscomp$3$$??"")));return $out_arr__44124__auto____$1$jscomp$26$$},[],$APP.$cljs$cst$3500$names$$.$cljs$core$IFn$_invoke$arity$1$($map__82676__$1$$))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",
children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$3499$height_warning_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__82676__$1$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__failure",children:$APP.$app$main$ui$icons$msg_neutral$$}):null,(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_upload$$,"data-id":""+($id$jscomp$1068$$??""),disabled:$disable_upload_QMARK_$$,className:"main_ui_dashboard_fonts__btn-primary main_ui_dashboard_fonts__upload-button "+
($disable_upload_QMARK_$$?"main_ui_dashboard_fonts__disabled":""),children:$uploading_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.uploading"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.upload")}),(0,$APP.$rumext$v2$jsx$$)("span",{"data-id":""+($id$jscomp$1068$$??""),onClick:$on_delete$jscomp$19$$,className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__close",children:$APP.$app$main$ui$icons$close$$})]})]},""+($id$jscomp$1068$$??""))}());
return $out_arr__44124__auto__$jscomp$245$$},[],$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1758$font_family$$,$font_vals$$))]})]})};
$app$main$ui$dashboard$fonts$installed_font_context_menu$$=function($options$jscomp$647_props_82686$$){var $is_open$jscomp$14$$=$options$jscomp$647_props_82686$$["is-open"],$on_download$jscomp$3$$=$options$jscomp$647_props_82686$$["on-download"],$on_close$jscomp$47$$=$options$jscomp$647_props_82686$$["on-close"],$on_delete$jscomp$20$$=$options$jscomp$647_props_82686$$["on-delete"],$on_edit$jscomp$16$$=$options$jscomp$647_props_82686$$["on-edit"];$options$jscomp$647_props_82686$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_edit$jscomp$16$$),
$APP.$rumext$v2$adapt$$($on_download$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$20$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit"),$APP.$cljs$cst$266$id$$,"font-edit",$APP.$cljs$cst$2402$handler$$,$on_edit$jscomp$16$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.download-simple"),$APP.$cljs$cst$266$id$$,"font-download",$APP.$cljs$cst$2402$handler$$,$on_download$jscomp$3$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$266$id$$,"font-delete",$APP.$cljs$cst$2402$handler$$,$on_delete$jscomp$20$$],null)],null)});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,
{onClose:$on_close$jscomp$47$$,show:$is_open$jscomp$14$$,fixed:!1,minWidth:!0,top:-15,left:-115,options:$options$jscomp$647_props_82686$$})};
$app$main$ui$dashboard$fonts$installed_fonts_STAR_$$=function($on_change$jscomp$103_props_82707$$){function $matches_QMARK_$jscomp$4$$($p1__82706_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($p1__82706_SHARP_$$)),$APP.$cljs$core$_deref$$($sterm$$))}var $fonts$jscomp$43$$=$on_change$jscomp$103_props_82707$$.fonts,$can_edit$jscomp$17$$=$on_change$jscomp$103_props_82707$$.canEdit,$sterm$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("");
$on_change$jscomp$103_props_82707$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$748_val$jscomp$231$$){$event$jscomp$748_val$jscomp$231$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$748_val$jscomp$231$$);return $APP.$cljs$core$reset_BANG_$$($sterm$$,$APP.$cuerdas$core$lower$$($event$jscomp$748_val$jscomp$231$$))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__dashboard-installed-fonts",children:$APP.$cljs$core$seq$$($fonts$jscomp$43$$)?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("h3",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.installed-fonts")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__installed-fonts-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__family",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.font-family")}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__variants",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.font-variants")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__search-input",children:(0,$APP.$rumext$v2$jsx$$)("input",{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.search-font"),defaultValue:"",onChange:$on_change$jscomp$103_props_82707$$})})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$247$$,
$p__82708_variants$jscomp$12$$){var $font_id$jscomp$42$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82708_variants$jscomp$12$$,0,null);$p__82708_variants$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82708_variants$jscomp$12$$,1,null);$out_arr__44124__auto__$jscomp$247$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$installed_font$$,{"font-id":$font_id$jscomp$42$$,"can-edit":$can_edit$jscomp$17$$,variants:$p__82708_variants$jscomp$12$$},""+
($font_id$jscomp$42$$??"")+"-installed"));return $out_arr__44124__auto__$jscomp$247$$},[],$APP.$cljs$core$group_by$$($APP.$cljs$cst$1757$font_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($matches_QMARK_$jscomp$4$$,$APP.$cljs$core$vals$$($fonts$jscomp$43$$))))]}):$fonts$jscomp$43$$==null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__fonts-placeholder",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__icon",children:$APP.$app$main$ui$icons$loader$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.loading-fonts")})]}):$can_edit$jscomp$17$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__fonts-placeholder",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__icon",children:$APP.$app$main$ui$icons$text$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.empty-placeholder")})]}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.empty-placeholder-viewer"),subtitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.empty-placeholder-viewer-sub"),type:2})})};
$app$main$ui$dashboard$fonts$fonts_page_STAR_$$=function($props_82713_team$jscomp$75$$){$props_82713_team$jscomp$75$$=$props_82713_team$jscomp$75$$.team;var $fonts$jscomp$44$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$fonts$ref_COLON_fonts$$),$can_edit$jscomp$18_permissions$jscomp$42$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($props_82713_team$jscomp$75$$);$can_edit$jscomp$18_permissions$jscomp$42$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($can_edit$jscomp$18_permissions$jscomp$42$$);
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$header_STAR_$$,{team:$props_82713_team$jscomp$75$$,section:$APP.$cljs$cst$2969$fonts$$}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_dashboard_fonts__dashboard-container main_ui_dashboard_fonts__dashboard-fonts",children:[$can_edit$jscomp$18_permissions$jscomp$42$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$uploaded_fonts_STAR_$$,{team:$props_82713_team$jscomp$75$$,
installedFonts:$fonts$jscomp$44$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$installed_fonts_STAR_$$,{team:$props_82713_team$jscomp$75$$,fonts:$fonts$jscomp$44$$,canEdit:$can_edit$jscomp$18_permissions$jscomp$42$$})]})]})};
$app$main$ui$dashboard$fonts$font_providers_page_STAR_$$=function($props_82714$$){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$header_STAR_$$,{team:$props_82714$$.team,section:$cljs$cst$6295$providers$$}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_dashboard_fonts__dashboard-container",children:(0,$APP.$rumext$v2$jsx$$)("span",{children:"font providers"})})]})};
$app$main$ui$dashboard$libraries$libraries_page_STAR_$$=function($can_edit$jscomp$19_props_82600$$){var $default_project$jscomp$1$$=$can_edit$jscomp$19_props_82600$$.defaultProject,$team$jscomp$77$$=$can_edit$jscomp$19_props_82600$$.team,$files$jscomp$46$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$shared_files$$),$team_id$jscomp$158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$77$$,$APP.$cljs$cst$266$id$$);$can_edit$jscomp$19_props_82600$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$77$$));
var $files__$1$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$46$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$158$$)],function(){return $APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82597_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$158$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82597_SHARP_$$))},
$APP.$cljs$core$vals$$($files$jscomp$46$$))))}),$selected_files$jscomp$7$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$libraries$ref_COLON_selected_files$$),$limit$jscomp$14_vec__82604$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(350),$rowref$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$14_vec__82604$$,0,null);$limit$jscomp$14_vec__82604$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$14_vec__82604$$,
1,null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$77$$)],function(){var $tname$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$77$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$77$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.shared-libraries",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$2$$])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$158$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$158$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});
$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6296$app_DOT_main_DOT_ui_DOT_dashboard_DOT_libraries_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_drafts_libraries$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_libraries__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-libraries-title",className:"main_ui_dashboard_libraries__dashboard-title",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-title")})})}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$rowref$jscomp$3$$,className:"main_ui_dashboard_libraries__dashboard-container main_ui_dashboard_libraries__no-bg main_ui_dashboard_libraries__dashboard-shared",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{files:$files__$1$jscomp$7$$,selectedFiles:$selected_files$jscomp$7$$,project:$default_project$jscomp$1$$,
origin:$APP.$cljs$cst$5244$libraries$$,limit:$limit$jscomp$14_vec__82604$$,canEdit:$can_edit$jscomp$19_props_82600$$})})]})};
$app$main$ui$dashboard$projects$project_item_STAR_$$=function($files$jscomp$47_props_82725$$){var $is_first$$=$files$jscomp$47_props_82725$$.isFirst,$can_edit$jscomp$21$$=$files$jscomp$47_props_82725$$.canEdit,$project$jscomp$40$$=$files$jscomp$47_props_82725$$.project,$team$jscomp$79$$=$files$jscomp$47_props_82725$$.team;$files$jscomp$47_props_82725$$=$files$jscomp$47_props_82725$$.files;var $project_id$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$40$$,$APP.$cljs$cst$266$id$$),
$team_id$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$79$$,$APP.$cljs$cst$266$id$$),$file_count$jscomp$6$$=function(){var $or__5025__auto__$jscomp$1403$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1403$$)?$or__5025__auto__$jscomp$1403$$:0}(),$is_draft_QMARK_$$=$APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),$empty_QMARK_$jscomp$4$$=
$APP.$cljs$core$not$$($can_edit$jscomp$21$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$file_count$jscomp$6$$),$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$);$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$=$APP.$cljs$cst$4936$project_for_edit$$.$cljs$core$IFn$_invoke$arity$1$($dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$);var $local$jscomp$34$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4927$menu_open$$,!1,$APP.$cljs$cst$4928$menu_pos$$,null,$APP.$cljs$cst$2199$edition$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$)],null)),$limit$jscomp$15_vec__82726$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$15_vec__82726$$,
0,null);$limit$jscomp$15_vec__82726$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$15_vec__82726$$,1,null);var $on_nav$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$47$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2181$project_id$$,
$project_id$jscomp$47$$])))}),$toggle_pin$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$40$$)],function($event$jscomp$750$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$750$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$toggle_project_pin$$($project$jscomp$40$$))}),$on_menu_click$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$){$APP.$app$util$dom$prevent_default$$($JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$);
var $client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$);$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$)==null&&$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$)==null?($client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$=
$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$)),$JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$),$client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$),
$JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$,$JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$)):$JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$=$client_position$jscomp$2_points$jscomp$inline_9546_x$jscomp$inline_9548$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$34$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4928$menu_pos$$,$JSCompiler_temp$jscomp$2001_event$jscomp$751_y$jscomp$inline_9547$$]))}),$on_menu_close$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$34$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!1)}),$on_edit_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$34$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,!0)}),$on_edit$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$40$$)],function($name$jscomp$505_name__$1$jscomp$26$$){$name$jscomp$505_name__$1$jscomp$26$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$505_name__$1$jscomp$26$$);$APP.$cuerdas$core$empty_QMARK_$$($name$jscomp$505_name__$1$jscomp$26$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$rename_project$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$40$$,
$APP.$cljs$cst$725$name$$,$name$jscomp$505_name__$1$jscomp$26$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$34$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,!1)}),$on_file_created$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1071_p__82734$$){var $data$jscomp$509_map__82735__$1_page_id$jscomp$467$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$1071_p__82734$$);$id$jscomp$1071_p__82734$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$509_map__82735__$1_page_id$jscomp$467$$,$APP.$cljs$cst$266$id$$);$data$jscomp$509_map__82735__$1_page_id$jscomp$467$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$509_map__82735__$1_page_id$jscomp$467$$,$APP.$cljs$cst$142$data$$);$data$jscomp$509_map__82735__$1_page_id$jscomp$467$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$509_map__82735__$1_page_id$jscomp$467$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2228$pages$$,0],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1071_p__82734$$,$APP.$cljs$cst$2043$page_id$$,$data$jscomp$509_map__82735__$1_page_id$jscomp$467$$])))}),
$create_file$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$47$$),$APP.$rumext$v2$adapt$$($on_file_created$jscomp$1$$)],function($origin$jscomp$74$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($app$main$data$dashboard$create_file$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$47$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2488$on_success$$,$on_file_created$jscomp$1$$],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$74$$,$cljs$cst$6290$has_files$$,$file_count$jscomp$6$$>0],null)))}),$on_create_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($create_file$jscomp$1$$)],function(){return $create_file$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$create_file$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$("dashboard:grid-header-plus-button"):
$create_file$jscomp$1$$("dashboard:grid-header-plus-button")}),$on_import$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$47$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$159$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$47$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$159$$),
$app$main$data$dashboard$fetch_projects$$($team_id$jscomp$159$$),$app$main$data$dashboard$clear_selected_files$$()]))}),$handle_create_click$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_create_click$jscomp$1$$)],function($event$jscomp$752$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$752$$))?$on_create_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$752$$):
$on_create_click$jscomp$1$$($event$jscomp$752$$):null}),$handle_menu_click$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$8$$)],function($event$jscomp$753$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$753$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$753$$),$on_menu_click$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$753$$):
$on_menu_click$jscomp$8$$($event$jscomp$753$$)):null}),$title_width$$=100/$limit$jscomp$15_vec__82726$$;return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_dashboard_projects__dashboard-project-row "+($APP.$cljs$core$truth_$$($is_first$$)?"main_ui_dashboard_projects__first":""),children:[(0,$APP.$rumext$v2$jsx$$)("header",{className:"main_ui_dashboard_projects__project",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__project-name-wrapper",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$2199$edition$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$)))?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),"on-end":$on_edit$jscomp$18$$,"max-length":250}):(0,$APP.$rumext$v2$jsx$$)("h2",{onClick:$on_nav$$,style:{maxWidth:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($title_width$$),"%"].join("")},title:$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),onContextMenu:$APP.$cljs$core$truth_$$($can_edit$jscomp$21$$)?$on_menu_click$jscomp$8$$:null,className:"main_ui_dashboard_projects__project-name",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$)}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__info-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_projects__info",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$jscomp$6$$)])))}),function(){var $time$jscomp$9$$=
$APP.$app$common$time$timeago$$($APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$));return(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_projects__recent-files-row-title-info",children:[", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($time$jscomp$9$$)].join("")})}()]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__project-actions "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$4903$is_pinned$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?
"main_ui_dashboard_projects__pinned-project":""),children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$pin_button$pin_button_STAR_$$,{className:"main_ui_dashboard_projects__pin-button",isPinned:$APP.$cljs$cst$4903$is_pinned$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),onClick:$toggle_pin$jscomp$2$$,tabIndex:0}),$can_edit$jscomp$21$$?(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$on_create_click$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file"),"data-testid":"project-new-file",onKeyDown:$handle_create_click$$,className:"main_ui_dashboard_projects__add-file-btn",children:$app$main$ui$dashboard$projects$add_icon$$}):null,$can_edit$jscomp$21$$?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_menu_click$jscomp$8$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),"data-testid":"project-options",onKeyDown:$handle_menu_click$jscomp$1$$,className:"main_ui_dashboard_projects__options-btn",children:$app$main$ui$dashboard$projects$menu_icon$$}):null]}),$can_edit$jscomp$21$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$project_menu$project_menu_STAR_$$,{project:$project$jscomp$40$$,show:$APP.$cljs$cst$4927$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$)),
left:24+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$))),top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$))),onEdit:$on_edit_open$jscomp$1$$,onClose:$on_menu_close$jscomp$7$$,onImport:$on_import$jscomp$3$$}):null]})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{ref:$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$,
className:"main_ui_dashboard_projects__grid-container",children:$empty_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$is_draft_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-title"),className:"main_ui_dashboard_projects__placeholder-placement",type:1,subtitle:$is_draft_QMARK_$$?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-subtitle"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-subtitle")}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$line_grid$$,{project:$project$jscomp$40$$,team:$team$jscomp$79$$,files:$files$jscomp$47_props_82725$$,"create-fn":$create_file$jscomp$1$$,"can-edit":$can_edit$jscomp$21$$,limit:$limit$jscomp$15_vec__82726$$})}),$limit$jscomp$15_vec__82726$$>
0&&$file_count$jscomp$6$$>$limit$jscomp$15_vec__82726$$?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_nav$$,tabIndex:"0",onKeyDown:function($event$jscomp$754$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$754$$))?$on_nav$$.$cljs$core$IFn$_invoke$arity$0$?$on_nav$$.$cljs$core$IFn$_invoke$arity$0$():$on_nav$$():null},className:"main_ui_dashboard_projects__show-more",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_projects__placeholder-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.show-all-files")}),$app$main$ui$dashboard$projects$show_more_icon$$]}):null]})};
$app$main$ui$dashboard$projects$projects_section_STAR_$$=function($props_82750_show_deleted_QMARK_$$){var $on_close$jscomp$49_profile$jscomp$80$$=$props_82750_show_deleted_QMARK_$$.profile,$projects$jscomp$10$$=$props_82750_show_deleted_QMARK_$$.projects,$team$jscomp$80$$=$props_82750_show_deleted_QMARK_$$.team,$team_id$jscomp$160$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$80$$,$APP.$cljs$cst$266$id$$),$recent_map$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$projects$ref_COLON_recent_files$$),
$permisions$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$80$$),$can_edit$jscomp$22$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permisions$$),$can_invite$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1404$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permisions$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1404$$)?$or__5025__auto__$jscomp$1404$$:$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permisions$$)}(),
$show_team_hero_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$global$$,$cljs$cst$6297$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$,!0)}),$show_team_hero_QMARK_$$=$APP.$cljs$core$_deref$$($show_team_hero_STAR_$$),$my_penpot_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($on_close$jscomp$49_profile$jscomp$80$$),
$team_id$jscomp$160$$),$default_team_QMARK_$$=$APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$80$$);$props_82750_show_deleted_QMARK_$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permisions$$);var $projects__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$10$$)],function(){return $APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2571$deleted_at$$,$projects$jscomp$10$$)))});$on_close$jscomp$49_profile$jscomp$80$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($show_team_hero_STAR_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"dont-show-team-up-hero",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_team_hero_QMARK_$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,$APP.$cljs$core$assoc$$,$cljs$cst$6297$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$,$show_team_hero_QMARK_$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$80$$)],
function(){var $tname$jscomp$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$80$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$80$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.projects",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$3$$])))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$160$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$160$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6298$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_dashboard$$,
$APP.$app$main$data$dashboard$shortcuts$shortcuts_projects$$);return $APP.$cljs$core$seq$$($projects__$1$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$header_STAR_$$,{canEdit:$can_edit$jscomp$22$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_projects__projects-container",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_team_hero_QMARK_$$)?
$APP.$cljs$core$truth_$$($can_invite$jscomp$3$$)?$APP.$cljs$core$not$$($default_team_QMARK_$$):$can_invite$jscomp$3$$:$show_team_hero_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$team_hero_STAR_$$,{team:$team$jscomp$80$$,onClose:$on_close$jscomp$49_profile$jscomp$80$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__dashboard-container main_ui_dashboard_projects__no-bg main_ui_dashboard_projects__dashboard-projects "+($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1024_and__5023__auto____$1$jscomp$169$$=
!$my_penpot_QMARK_$$;return $and__5023__auto__$jscomp$1024_and__5023__auto____$1$jscomp$169$$?($and__5023__auto__$jscomp$1024_and__5023__auto____$1$jscomp$169$$=$APP.$cljs$core$not$$($default_team_QMARK_$$))?$APP.$cljs$core$truth_$$($show_team_hero_QMARK_$$)?$can_invite$jscomp$3$$:$show_team_hero_QMARK_$$:$and__5023__auto__$jscomp$1024_and__5023__auto____$1$jscomp$169$$:$and__5023__auto__$jscomp$1024_and__5023__auto____$1$jscomp$169$$}())?"main_ui_dashboard_projects__with-team-hero":""),children:[$APP.$cljs$core$truth_$$($props_82750_show_deleted_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$menu_STAR_$$,{teamId:$team_id$jscomp$160$$,section:$APP.$cljs$cst$2522$dashboard_recent$$}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$248$$,$p__82769$$){var $map__82770__$1$$=$APP.$cljs$core$__destructure_map$$($p__82769$$),$id$jscomp$1072$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82770__$1$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$248$$.push(function(){var $files$jscomp$48$$=
$APP.$cljs$core$truth_$$($recent_map$$)?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1737$modified_at$$,function($p1__82749_SHARP_$$,$p2__82748_SHARP_$$){return $APP.$cljs$core$compare$$($p2__82748_SHARP_$$,$p1__82749_SHARP_$$)},$APP.$cljs$core$filterv$$(function($p1__82747_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1072$$,$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82747_SHARP_$$))},$APP.$cljs$core$vals$$($recent_map$$))):
null;return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$project_item_STAR_$$,{project:$map__82770__$1$$,team:$team$jscomp$80$$,files:$files$jscomp$48$$,canEdit:$can_edit$jscomp$22$$,isFirst:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__82770__$1$$,$APP.$cljs$core$first$$($projects__$1$jscomp$1$$))},$id$jscomp$1072$$)}());return $out_arr__44124__auto__$jscomp$248$$},[],$projects__$1$jscomp$1$$)]})]})})]}):null};
$app$main$ui$dashboard$search$search_page_STAR_$$=function($props_82598_result$jscomp$386$$){var $team$jscomp$81$$=$props_82598_result$jscomp$386$$.team,$search_term__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_82598_result$jscomp$386$$.searchTerm,"");$props_82598_result$jscomp$386$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$search$ref_COLON_search_result$$);var $selected$jscomp$217$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$search$ref_COLON_selected$$),
$limit$jscomp$16_vec__82601$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$rowref$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$16_vec__82601$$,0,null);$limit$jscomp$16_vec__82601$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$16_vec__82601$$,1,null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$81$$)],function(){if($APP.$cljs$core$truth_$$($team$jscomp$81$$)){var $tname$jscomp$4$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$81$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$81$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.search",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$4$$])))}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($search_term__$1$jscomp$1$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$search$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2516$search_term$$,$search_term__$1$jscomp$1$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",
className:"main_ui_dashboard_search__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-search-title",className:"main_ui_dashboard_search__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.title-search")})})}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$rowref$jscomp$5$$,className:"main_ui_dashboard_search__dashboard-container main_ui_dashboard_search__search main_ui_dashboard_search__no-bg",
children:$APP.$cljs$core$empty_QMARK_$$($search_term__$1$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_search__grid-empty-placeholder main_ui_dashboard_search__search",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.type-something")})]}):
$props_82598_result$jscomp$386$$==null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_search__grid-empty-placeholder main_ui_dashboard_search__search",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.searching-for",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$search_term__$1$jscomp$1$$]))})]}):
$APP.$cljs$core$empty_QMARK_$$($props_82598_result$jscomp$386$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_search__grid-empty-placeholder main_ui_dashboard_search__search",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.no-matches-for",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$search_term__$1$jscomp$1$$]))})]}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{files:$props_82598_result$jscomp$386$$,selectedFiles:$selected$jscomp$217$$,origin:$cljs$cst$6280$search$$,limit:$limit$jscomp$16_vec__82601$$})})]})};
$app$main$ui$dashboard$templates$import_template_BANG_$$=function($template$jscomp$9$$,$team_id$jscomp$161$$,$project_id$jscomp$48$$,$default_project_id$jscomp$1$$,$section$jscomp$40$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-template-launch",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"dashboard",$APP.$cljs$cst$2403$template$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($template$jscomp$9$$),$APP.$cljs$cst$1366$section$$,$section$jscomp$40$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5346$import$$,$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$core$truth_$$($project_id$jscomp$48$$)?$project_id$jscomp$48$$:
$default_project_id$jscomp$1$$,$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$2403$template$$,$template$jscomp$9$$,$APP.$cljs$cst$5347$on_finish_import$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$161$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-template-finish",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$2403$template$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($template$jscomp$9$$),$APP.$cljs$cst$1366$section$$,$section$jscomp$40$$],null)),$project_id$jscomp$48$$!=null?null:$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$161$$,$APP.$cljs$cst$2181$project_id$$,$default_project_id$jscomp$1$$]))]))}],null))]))};
$app$main$ui$dashboard$templates$title_STAR_$$=function($on_key_down$jscomp$31_props_82610$$){var $is_collapsed$jscomp$1$$=$on_key_down$jscomp$31_props_82610$$.isCollapsed,$on_click$jscomp$66$$=$on_key_down$jscomp$31_props_82610$$.onClick;$on_key_down$jscomp$31_props_82610$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$66$$)],function($event$jscomp$755$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$755$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$755$$),
$APP.$app$util$dom$prevent_default$$($event$jscomp$755$$),$on_click$jscomp$66$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$66$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$755$$):$on_click$jscomp$66$$($event$jscomp$755$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__title",children:(0,$APP.$rumext$v2$jsxs$$)("button",{tabIndex:"0",onClick:$on_click$jscomp$66$$,onKeyDown:$on_key_down$jscomp$31_props_82610$$,className:"main_ui_dashboard_templates__title-btn",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates")}),$is_collapsed$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_templates__title-icon-container",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-icon-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-icon main_ui_dashboard_templates__title-icon-collapsed",children:$app$main$ui$dashboard$templates$arrow_icon$$})]}):(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_templates__title-icon-container",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-icon-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.hide")}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_dashboard_templates__title-icon",children:$app$main$ui$dashboard$templates$arrow_icon$$})]})]})})};
$app$main$ui$dashboard$templates$card_item$$=function($id$jscomp$1073_props_82625$$){var $on_import$jscomp$4$$=$id$jscomp$1073_props_82625$$["on-import"],$collapsed$jscomp$4$$=$id$jscomp$1073_props_82625$$.collapsed,$index$jscomp$582$$=$id$jscomp$1073_props_82625$$.index,$item$jscomp$147$$=$id$jscomp$1073_props_82625$$.item,$is_visible$jscomp$2$$=$id$jscomp$1073_props_82625$$["is-visible"];$id$jscomp$1073_props_82625$$="card-container-"+($index$jscomp$582$$??"");var $href$jscomp$21$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"images/thumbnails/template-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$147$$)??"")+".jpg"])),$hover_QMARK_$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_click$jscomp$67$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_import$jscomp$4$$)],function($event$jscomp$756$$){return $on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$147$$,
$event$jscomp$756$$):$on_import$jscomp$4$$($item$jscomp$147$$,$event$jscomp$756$$)}),$on_key_down$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_import$jscomp$4$$)],function($event$jscomp$757$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$757$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$757$$),$on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$147$$,
$event$jscomp$757$$):$on_import$jscomp$4$$($item$jscomp$147$$,$event$jscomp$757$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{tabIndex:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1406$$=$APP.$cljs$core$not$$($is_visible$jscomp$2$$);return $or__5025__auto__$jscomp$1406$$?$or__5025__auto__$jscomp$1406$$:$collapsed$jscomp$4$$}())?"-1":"0",id:$id$jscomp$1073_props_82625$$,"data-index":$index$jscomp$582$$,className:"main_ui_dashboard_templates__card-container",children:(0,$APP.$rumext$v2$jsxs$$)("a",
{onClick:$on_click$jscomp$67$$,onMouseDown:$APP.$app$util$dom$prevent_default$$,onMouseEnter:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$14$$,!0)},onMouseLeave:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$14$$,!1)},onKeyDown:$on_key_down$jscomp$32$$,className:"main_ui_dashboard_templates__template-card",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__img-container",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:""+
($href$jscomp$21$$??""),alt:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$147$$),loading:"lazy",decoding:"async"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_templates__card-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__card-text",children:$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover_QMARK_$jscomp$14$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.template.add-to-project"):
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$147$$)}),$app$main$ui$dashboard$templates$download_icon$$]})]})})};
$app$main$ui$dashboard$templates$card_item_link$$=function($id$jscomp$1074_props_82639$$){var $collapsed$jscomp$5$$=$id$jscomp$1074_props_82639$$.collapsed,$section$jscomp$41$$=$id$jscomp$1074_props_82639$$.section,$is_visible$jscomp$3$$=$id$jscomp$1074_props_82639$$["is-visible"];$id$jscomp$1074_props_82639$$="card-container-"+($id$jscomp$1074_props_82639$$.total??"");var $on_click$jscomp$68$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($section$jscomp$41$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-libraries-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1366$section$$,$section$jscomp$41$$],null)))}),$on_key_down$jscomp$33$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$68$$)],
function($event$jscomp$758$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$758$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$758$$),$on_click$jscomp$68$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$68$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$758$$):$on_click$jscomp$68$$($event$jscomp$758$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__card-container",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_templates__template-card",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__img-container",children:(0,$APP.$rumext$v2$jsx$$)("a",{id:$id$jscomp$1074_props_82639$$,tabIndex:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1407$$=$APP.$cljs$core$not$$($is_visible$jscomp$3$$);return $or__5025__auto__$jscomp$1407$$?$or__5025__auto__$jscomp$1407$$:$collapsed$jscomp$5$$}())?"-1":"0",href:"https://penpot.app/libraries-templates",
target:"_blank",onClick:$on_click$jscomp$68$$,onKeyDown:$on_key_down$jscomp$33$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_templates__template-link",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__template-link-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__template-link-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.explore")})]})})})})})};
$app$main$ui$dashboard$templates$templates_section_STAR_$$=function($props_82660_route$jscomp$20_route_name_total$jscomp$26$$){var $project_id$jscomp$49$$=$props_82660_route$jscomp$20_route_name_total$jscomp$26$$.projectId,$profile$jscomp$81$$=$props_82660_route$jscomp$20_route_name_total$jscomp$26$$.profile,$team_id$jscomp$162$$=$props_82660_route$jscomp$20_route_name_total$jscomp$26$$.teamId,$default_project_id$jscomp$2$$=$props_82660_route$jscomp$20_route_name_total$jscomp$26$$.defaultProjectId,
$templates$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$templates$builtin_templates$$),$templates__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($templates$$)],function(){return $APP.$cljs$core$filterv$$(function($p1__82651_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82651_SHARP_$$),"welcome")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82651_SHARP_$$),
"tutorial-for-beginners")},$templates$$)});$props_82660_route$jscomp$20_route_name_total$jscomp$26$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);$props_82660_route$jscomp$20_route_name_total$jscomp$26$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($props_82660_route$jscomp$20_route_name_total$jscomp$26$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null));var $section$jscomp$42$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_82660_route$jscomp$20_route_name_total$jscomp$26$$,$APP.$cljs$cst$2512$dashboard_files$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($project_id$jscomp$49$$,$default_project_id$jscomp$2$$)?"dashboard-drafts":"dashboard-project":$APP.$cljs$core$name$$($props_82660_route$jscomp$20_route_name_total$jscomp$26$$),$collapsed_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$global$$,
$cljs$cst$6299$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$)}),$collapsed$jscomp$6$$=$APP.$cljs$core$_deref$$($collapsed_STAR_$jscomp$1$$),$can_move$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$257$left$$,!1,$APP.$cljs$cst$258$right$$,!0],null));$props_82660_route$jscomp$20_route_name_total$jscomp$26$$=$APP.$cljs$core$count$$($templates__$1$$);var $content_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(),
$on_toggle_collapse$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_STAR_$jscomp$1$$,$APP.$cljs$core$not$$)}),$on_wheel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$759_event_STAR_$$){$event$jscomp$759_event_STAR_$$=$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$($event$jscomp$759_event_STAR_$$);var $deltaY$$=$event$jscomp$759_event_STAR_$$.spinY,
$node$jscomp$481$$=$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$);return $APP.$cljs$core$abs$$($deltaY$$)>$APP.$cljs$core$abs$$($event$jscomp$759_event_STAR_$$.spinX)?$node$jscomp$481$$.scrollBy({left:300*$deltaY$$,mode:"smooth"}):null}),$on_scroll$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($client_width_e$jscomp$410$$){var $scroll$jscomp$5_scroll_available$$=(0,$APP.$app$util$dom$get_target_scroll$$)($client_width_e$jscomp$410$$),$scroll_left$$=$APP.$cljs$cst$1559$scroll_left$$.$cljs$core$IFn$_invoke$arity$1$($scroll$jscomp$5_scroll_available$$);
$scroll$jscomp$5_scroll_available$$=$APP.$cljs$cst$1561$scroll_width$$.$cljs$core$IFn$_invoke$arity$1$($scroll$jscomp$5_scroll_available$$)-$scroll_left$$;$client_width_e$jscomp$410$$=$APP.$app$util$dom$get_client_size$$($APP.$app$util$dom$get_target$$($client_width_e$jscomp$410$$)).width;return $APP.$cljs$core$reset_BANG_$$($can_move$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$257$left$$,$scroll_left$$>0,$APP.$cljs$cst$258$right$$,$scroll$jscomp$5_scroll_available$$>$client_width_e$jscomp$410$$],
null))}),$on_move_left$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$760$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($event$jscomp$760$$))?$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(300,0):$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(-300,0)}),$on_move_right$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$761$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($event$jscomp$761$$))?
$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(-300,0):$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(300,0)}),$on_import_template$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_project_id$jscomp$2$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$49$$),$APP.$rumext$v2$adapt$$($section$jscomp$42$$),$APP.$rumext$v2$adapt$$($templates__$1$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$162$$)],function($template$jscomp$10$$){return $app$main$ui$dashboard$templates$import_template_BANG_$$($template$jscomp$10$$,
$team_id$jscomp$162$$,$project_id$jscomp$49$$,$default_project_id$jscomp$2$$,$section$jscomp$42$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($templates__$1$$)],function(){var $content$jscomp$274$$=$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$);if($content$jscomp$274$$!=null&&$templates__$1$$!=null){$content$jscomp$274$$.scrollTo({behavior:"instant",left:0,top:0});var $event$jscomp$inline_9554$$=new Event("scroll");return $content$jscomp$274$$!=
null?$content$jscomp$274$$.dispatchEvent($event$jscomp$inline_9554$$):null}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$81$$),$APP.$rumext$v2$adapt$$($collapsed$jscomp$6$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,$APP.$cljs$core$assoc$$,$cljs$cst$6299$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$,$collapsed$jscomp$6$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($profile$jscomp$81$$)?
$APP.$cljs$core$not$$($collapsed$jscomp$6$$):$profile$jscomp$81$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$fetch_builtin_templates$$()):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_templates__dashboard-templates-section "+($APP.$cljs$core$truth_$$($collapsed$jscomp$6$$)?"main_ui_dashboard_templates__collapsed":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$title_STAR_$$,{onClick:$on_toggle_collapse$jscomp$3$$,
isCollapsed:$collapsed$jscomp$6$$}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_templates__content-description",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.description")}),(0,$APP.$rumext$v2$jsxs$$)("div",{onScroll:$on_scroll$jscomp$2$$,onWheel:$on_wheel$jscomp$1$$,ref:$content_ref$jscomp$1$$,className:"main_ui_dashboard_templates__content",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$249$$,
$index$jscomp$583$$){$out_arr__44124__auto__$jscomp$249$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$card_item$$,{"on-import":$on_import_template$$,item:$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($templates__$1$$,$index$jscomp$583$$),index:$index$jscomp$583$$,"is-visible":!0,collapsed:$collapsed$jscomp$6$$},$index$jscomp$583$$));return $out_arr__44124__auto__$jscomp$249$$},[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($templates__$1$$))),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$card_item_link$$,{"is-visible":!0,collapsed:$collapsed$jscomp$6$$,section:$section$jscomp$42$$,total:$props_82660_route$jscomp$20_route_name_total$jscomp$26$$})]}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($can_move$$)))?(0,$APP.$rumext$v2$jsx$$)("button",{tabIndex:$collapsed$jscomp$6$$?"-1":"0",onClick:$on_move_left$$,onKeyDown:$on_move_left$$,className:"main_ui_dashboard_templates__move-button main_ui_dashboard_templates__move-left",
children:$app$main$ui$dashboard$templates$arrow_icon$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($can_move$$)))?(0,$APP.$rumext$v2$jsx$$)("button",{tabIndex:$APP.$cljs$core$truth_$$($collapsed$jscomp$6$$)?"-1":"0",onClick:$on_move_right$$,onKeyDown:$on_move_right$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"),className:"main_ui_dashboard_templates__move-button main_ui_dashboard_templates__move-right",
children:$app$main$ui$dashboard$templates$arrow_icon$$}):null]})};
$app$main$ui$dashboard$dashboard_content_STAR_$$=function($clear_selected_fn_props_82785$$){var $default_project$jscomp$2$$=$clear_selected_fn_props_82785$$.defaultProject,$profile$jscomp$82$$=$clear_selected_fn_props_82785$$.profile,$projects$jscomp$11$$=$clear_selected_fn_props_82785$$.projects,$search_term$jscomp$7$$=$clear_selected_fn_props_82785$$.searchTerm,$section$jscomp$43$$=$clear_selected_fn_props_82785$$.section,$project$jscomp$42$$=$clear_selected_fn_props_82785$$.project,$team$jscomp$82$$=
$clear_selected_fn_props_82785$$.team,$container$jscomp$99$$=(0,$APP.$rumext$v2$use_ref$$)(),$content_width$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$project_id$jscomp$50$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$42$$),$team_id$jscomp$163$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$82$$),$permissions$jscomp$43$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$82$$),$default_project_id$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_project$jscomp$2$$,$APP.$cljs$cst$266$id$$),$on_resize$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($content_width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$99$$),"clientWidth"))});$clear_selected_fn_props_82785$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$())});
var $show_templates_QMARK_$$=function(){var $and__5023__auto__$jscomp$1026$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1189$dashboard_templates_section$$);return $and__5023__auto__$jscomp$1026$$?$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$43$$):$and__5023__auto__$jscomp$1026$$}(),$show_deleted_QMARK_$jscomp$1$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$43$$),$section__$1$jscomp$2$$=$APP.$cljs$core$not$$($show_deleted_QMARK_$jscomp$1$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$43$$,$APP.$cljs$cst$2536$dashboard_deleted$$)?$APP.$cljs$cst$2522$dashboard_recent$$:$section$jscomp$43$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$9$$=$APP.$goog$events$listen$$(window,"resize",$on_resize$jscomp$7$$);return function(){return $APP.$goog$events$unlistenByKey$$($key1$jscomp$9$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$($on_resize$jscomp$7$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$clear_selected_fn_props_82785$$,ref:$container$jscomp$99$$,className:"main_ui_dashboard__dashboard-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$progress$progress_notification_widget_STAR_$$,{}),function(){switch($section__$1$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$section__$1$jscomp$2$$.$fqn$:null){case "dashboard-recent":return $APP.$cljs$core$seq$$($projects$jscomp$11$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$projects_section_STAR_$$,{team:$team$jscomp$82$$,projects:$projects$jscomp$11$$,profile:$profile$jscomp$82$$}),$show_templates_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$templates_section_STAR_$$,{profile:$profile$jscomp$82$$,projectId:$project_id$jscomp$50$$,teamId:$team_id$jscomp$163$$,defaultProjectId:$default_project_id$jscomp$3$$,contentWidth:$APP.$cljs$core$_deref$$($content_width$$)}):null]}):null;
case "dashboard-fonts":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$fonts_page_STAR_$$,{team:$team$jscomp$82$$});case "dashboard-font-providers":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$font_providers_page_STAR_$$,{team:$team$jscomp$82$$});case "dashboard-files":return $APP.$cljs$core$truth_$$($project$jscomp$42$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$files$files_section_STAR_$$,{team:$team$jscomp$82$$,
project:$project$jscomp$42$$}),$show_templates_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$templates_section_STAR_$$,{profile:$profile$jscomp$82$$,teamId:$team_id$jscomp$163$$,projectId:$project_id$jscomp$50$$,defaultProjectId:$default_project_id$jscomp$3$$,contentWidth:$APP.$cljs$core$_deref$$($content_width$$)}):null]}):null;case "dashboard-search":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$search$search_page_STAR_$$,{team:$team$jscomp$82$$,searchTerm:$search_term$jscomp$7$$});
case "dashboard-libraries":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$libraries$libraries_page_STAR_$$,{team:$team$jscomp$82$$,defaultProject:$default_project$jscomp$2$$});case "dashboard-members":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_members_page_STAR_$$,{team:$team$jscomp$82$$,profile:$profile$jscomp$82$$});case "dashboard-invitations":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_invitations_page_STAR_$$,{team:$team$jscomp$82$$,profile:$profile$jscomp$82$$});
case "dashboard-webhooks":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhooks_page_STAR_$$,{team:$team$jscomp$82$$});case "dashboard-settings":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_settings_page_STAR_$$,{team:$team$jscomp$82$$,profile:$profile$jscomp$82$$});case "dashboard-deleted":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$deleted_section_STAR_$$,{team:$team$jscomp$82$$,projects:$projects$jscomp$11$$,profile:$profile$jscomp$82$$});default:return null}}()]})};
$app$main$ui$dashboard$use_plugin_register$$=function($plugin_url$jscomp$4$$,$team_id$jscomp$164$$,$project_id$jscomp$51$$){function $open_permissions_dialog$$($plugin$jscomp$13$$){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4993$plugin_permissions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3402$plugin$$,$plugin$jscomp$13$$,$APP.$cljs$cst$2479$on_accept$$,function(){$APP.$app$plugins$register$install_plugin_BANG_$$($plugin$jscomp$13$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2522$dashboard_recent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$164$$],null)),$open_try_out_dialog$$($plugin$jscomp$13$$)]))},$APP.$cljs$cst$4994$on_close$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2522$dashboard_recent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$164$$],null))]))}],null))}function $open_try_out_dialog$$($plugin$jscomp$12$$){return $APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4995$plugin_try_out$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3402$plugin$$,
$plugin$jscomp$12$$,$APP.$cljs$cst$2479$on_accept$$,function(){var $JSCompiler_temp_const$jscomp$inline_13856$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$inline_13857$$=$APP.$app$main$data$modal$hide$$();var $JSCompiler_inline_result$jscomp$inline_13858_data$jscomp$inline_13859$$=$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$51$$,$APP.$cljs$cst$725$name$$,
""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plugins.try-plugin")??"")+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$12$$)??"")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($navegate_file_BANG_$$,$plugin$jscomp$12$$)],null));$JSCompiler_inline_result$jscomp$inline_13858_data$jscomp$inline_13859$$=$APP.$cljs$core$with_meta$$($app$main$data$dashboard$create_file$$($JSCompiler_inline_result$jscomp$inline_13858_data$jscomp$inline_13859$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugin-try-out"],null));return $JSCompiler_temp_const$jscomp$inline_13856$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_temp_const$jscomp$inline_13857$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$inline_13858_data$jscomp$inline_13859$$]))},$APP.$cljs$cst$4994$on_close$$,$APP.$app$main$data$modal$hide_BANG_$$],null))}function $navegate_file_BANG_$$($plugin$jscomp$10$$,
$p__82793_project_id__$1$jscomp$5$$){var $data$jscomp$510_map__82794__$1$$=$APP.$cljs$core$__destructure_map$$($p__82793_project_id__$1$jscomp$5$$);$p__82793_project_id__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__82794__$1$$,$APP.$cljs$cst$2181$project_id$$);var $id$jscomp$1075$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__82794__$1$$,$APP.$cljs$cst$266$id$$);$data$jscomp$510_map__82794__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__82794__$1$$,
$APP.$cljs$cst$142$data$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$plugins$delay_open_plugin$$($plugin$jscomp$10$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2532$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__82794__$1$$,
$APP.$cljs$cst$2228$pages$$),0),$APP.$cljs$cst$2181$project_id$$,$p__82793_project_id__$1$jscomp$5$$,$APP.$cljs$cst$1644$file_id$$,$id$jscomp$1075$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$164$$],null))]))}$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($plugin_url$jscomp$4$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$164$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$51$$)],function(){if($APP.$cljs$core$truth_$$($plugin_url$jscomp$4$$)){$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($plugin$jscomp$14$$){return $APP.$cljs$core$truth_$$($plugin$jscomp$14$$)?
($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-plugin",$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$14$$),$APP.$cljs$cst$1975$url$$,$plugin_url$jscomp$4$$],null))),$open_permissions_dialog$$($plugin$jscomp$14$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plugins.parse-error")))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plugins.bad-url")))},$APP.$app$main$data$plugins$fetch_manifest$$($plugin_url$jscomp$4$$));var $_STAR_sync_STAR__orig_val__82795$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$session$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$6301$plugin_url$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__82795$$}}else return null})};
$app$main$ui$dashboard$use_templates_import$$=function($can_edit_QMARK_$jscomp$16$$,$template$jscomp$11$$,$project$jscomp$43$$){var $project_id$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$43$$,$APP.$cljs$cst$266$id$$),$team_id$jscomp$165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$43$$,$APP.$cljs$cst$1927$team_id$$);$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$16$$),
$APP.$rumext$v2$adapt$$($template$jscomp$11$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$52$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$165$$)],function(){if($template$jscomp$11$$!=null&&$project_id$jscomp$52$$!=null&&$team_id$jscomp$165$$!=null){if($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$16$$)){var $_STAR_sync_STAR__orig_val__82797_valid_url_QMARK__82823$$=$APP.$cuerdas$core$ends_with_QMARK_$$($template$jscomp$11$$,".penpot"),$template_name_82824$$=$APP.$cuerdas$core$starts_with_QMARK_$$($template$jscomp$11$$,
"http")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($template$jscomp$11$$,$APP.$cljs$core$count$$($APP.$app$config$templates_uri$$)):$template$jscomp$11$$,$template_url_82825$$=["/github/penpot-files/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($template_name_82824$$)].join(""),$on_import_82826$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$52$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$165$$),$app$main$data$dashboard$fetch_projects$$($team_id$jscomp$165$$),$app$main$data$dashboard$clear_selected_files$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-template-from-link-finished",$APP.$cljs$cst$725$name$$,$template_name_82824$$,
$APP.$cljs$cst$1975$url$$,$template_url_82825$$],null))]))};$_STAR_sync_STAR__orig_val__82797_valid_url_QMARK__82823$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-template-from-link",$APP.$cljs$cst$725$name$$,$template_name_82824$$,$APP.$cljs$cst$1975$url$$,$template_url_82825$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5346$import$$,$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$52$$,$APP.$cljs$cst$4379$entries$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$template_name_82824$$,$APP.$cljs$cst$1579$uri$$,$template_url_82825$$],null)],null),$APP.$cljs$cst$5347$on_finish_import$$,$on_import_82826$$],null))])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.bad-url")))}else $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.no-perms")));
$_STAR_sync_STAR__orig_val__82797_valid_url_QMARK__82823$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$session$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2403$template$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__82797_valid_url_QMARK__82823$$}}else return null})};
$app$main$ui$dashboard$use_nitrate_entry_popup$$=function(){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){if($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$storage$$,$APP.$cljs$cst$5056$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$)===!0){var $_STAR_sync_STAR__orig_val__73332$jscomp$inline_9558$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$storage$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5055$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$,$APP.$cljs$cst$5056$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__73332$jscomp$inline_9558$$}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3227$onboarding_viewed$$,
!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5068$nitrate_form$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}return null})};
$app$main$ui$dashboard$dashboard_STAR_$$=function($props_82804_team$jscomp$83$$){var $project_id$jscomp$53$$=$props_82804_team$jscomp$83$$.projectId,$profile$jscomp$83$$=$props_82804_team$jscomp$83$$.profile,$team_id$jscomp$166$$=$props_82804_team$jscomp$83$$.teamId,$search_term$jscomp$8$$=$props_82804_team$jscomp$83$$.searchTerm,$plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$=$props_82804_team$jscomp$83$$.pluginUrl,$section$jscomp$44$$=$props_82804_team$jscomp$83$$.section,$template$jscomp$12_template__$1$jscomp$2$$=
$props_82804_team$jscomp$83$$.template;$props_82804_team$jscomp$83$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$);var $projects$jscomp$12$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$projects$$),$project$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($projects$jscomp$12$$,$project_id$jscomp$53$$),$projects__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$12$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$166$$)],
function(){return $APP.$cljs$core$filterv$$(function($p1__82801_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$166$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82801_SHARP_$$))},$APP.$cljs$core$vals$$($projects$jscomp$12$$))}),$can_edit_QMARK_$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_82804_team$jscomp$83$$,$APP.$cljs$cst$1722$permissions$$),$APP.$cljs$cst$1596$can_edit$$);
$template$jscomp$12_template__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($template$jscomp$12_template__$1$jscomp$2$$)?$template$jscomp$12_template__$1$jscomp$2$$:$APP.$cljs$cst$2403$template$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$session$$);$plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$)?$plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$:$APP.$cljs$cst$6301$plugin_url$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$session$$);
var $default_project$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects__$1$jscomp$2$$)],function(){return $APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,$projects__$1$jscomp$2$$))});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6302$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_dashboard$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$166$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$initialize$$($team_id$jscomp$166$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4906$app_DOT_main_DOT_data_DOT_dashboard_SLASH_finalize$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$166$$],null)))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $key$jscomp$427$$=$APP.$goog$events$listen$$($APP.$goog$global$$,"keydown",function($event$jscomp$762$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$762$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$762$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$open_selected_file$$())):null});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$427$$)}});$app$main$ui$dashboard$use_plugin_register$$($plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$,
$team_id$jscomp$166$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_project$jscomp$3$$));$app$main$ui$dashboard$use_templates_import$$($can_edit_QMARK_$jscomp$17$$,$template$jscomp$12_template__$1$jscomp$2$$,$default_project$jscomp$3$$);$app$main$ui$dashboard$use_nitrate_entry_popup$$();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_project_id$$),{value:$project_id$jscomp$53$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,
{}),(0,$APP.$rumext$v2$jsxs$$)("main",{className:"main_ui_dashboard__dashboard",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$sidebar$sidebar_STAR_$$,{team:$props_82804_team$jscomp$83$$,projects:$projects__$1$jscomp$2$$,project:$project$jscomp$44$$,defaultProject:$default_project$jscomp$3$$,profile:$profile$jscomp$83$$,section:$section$jscomp$44$$,searchTerm:$search_term$jscomp$8$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$dashboard_content_STAR_$$,{projects:$projects__$1$jscomp$2$$,
profile:$profile$jscomp$83$$,project:$project$jscomp$44$$,defaultProject:$default_project$jscomp$3$$,section:$section$jscomp$44$$,searchTerm:$search_term$jscomp$8$$,team:$props_82804_team$jscomp$83$$})]},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_82804_team$jscomp$83$$)??""))]})};$APP.$app$main$ui$dashboard$dashboard_page_STAR_$$=function($props_82817$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$dashboard$dashboard_STAR_$$,$props_82817$$)};
$cljs$cst$6298$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.projects","dashboard","app.main.ui.dashboard.projects/dashboard",-556856058);$cljs$cst$6280$search$$=new $APP.$cljs$core$Keyword$$(null,"search","search",1564939822);$cljs$cst$6281$get_all_projects$$=new $APP.$cljs$core$Keyword$$(null,"get-all-projects","get-all-projects",1718710818);
$cljs$cst$6288$can_restore$$=new $APP.$cljs$core$Keyword$$(null,"can-restore","can-restore",388064375);$cljs$cst$6279$is_default_team$$=new $APP.$cljs$core$Keyword$$(null,"is-default-team","is-default-team",1150636297);$cljs$cst$6299$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.templates","collapsed","app.main.ui.dashboard.templates/collapsed",1868771256);
$cljs$cst$6302$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard","dashboard","app.main.ui.dashboard/dashboard",25877386);$cljs$cst$6283$thumbnails_SLASH_generate_for_file_wasm$$=new $APP.$cljs$core$Keyword$$("thumbnails","generate-for-file-wasm","thumbnails/generate-for-file-wasm",-1780261229);$cljs$cst$6290$has_files$$=new $APP.$cljs$core$Keyword$$(null,"has-files","has-files",-150994558);
$cljs$cst$6287$limit$$=new $APP.$cljs$core$Keyword$$(null,"limit","limit",-1355822363);$cljs$cst$6289$create_fn$$=new $APP.$cljs$core$Keyword$$(null,"create-fn","create-fn",-1596040813);$cljs$cst$6285$file_if$$=new $APP.$cljs$core$Keyword$$(null,"file-if","file-if",-1983487897);$cljs$cst$6292$font_family_tmp$$=new $APP.$cljs$core$Keyword$$(null,"font-family-tmp","font-family-tmp",1518875480);
$cljs$cst$6284$thumbnails_SLASH_generate_for_file$$=new $APP.$cljs$core$Keyword$$("thumbnails","generate-for-file","thumbnails/generate-for-file",-1533672464);$cljs$cst$6296$app_DOT_main_DOT_ui_DOT_dashboard_DOT_libraries_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.libraries","dashboard","app.main.ui.dashboard.libraries/dashboard",-1567324353);$cljs$cst$6286$sample$$=new $APP.$cljs$core$Keyword$$(null,"sample","sample",79023601);
$cljs$cst$6293$download_font_family$$=new $APP.$cljs$core$Keyword$$(null,"download-font-family","download-font-family",249288215);$cljs$cst$6297$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.projects","show-team-hero","app.main.ui.dashboard.projects/show-team-hero",-741317864);
$cljs$cst$6291$app_DOT_main_DOT_ui_DOT_dashboard_DOT_files_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.files","dashboard","app.main.ui.dashboard.files/dashboard",1600474145);$cljs$cst$6294$download_font$$=new $APP.$cljs$core$Keyword$$(null,"download-font","download-font",-652313214);$cljs$cst$6295$providers$$=new $APP.$cljs$core$Keyword$$(null,"providers","providers",543153826);var $app$main$ui$components$progress$neutral_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_components_progress__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-neutral"})}),$app$main$ui$components$progress$error_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_components_progress__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete-text"})}),$app$main$ui$components$progress$close_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",
{width:500,className:"main_ui_components_progress__close-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})});$APP.$app$common$logging$loggers$$.set("app.main.ui.dashboard.grid",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));var $app$main$ui$dashboard$grid$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_grid__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});var $app$main$ui$dashboard$deleted$ref_COLON_deleted_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4923$deleted_files$$,$APP.$app$main$store$state$$),$app$main$ui$dashboard$deleted$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_deleted__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});var $app$main$ui$dashboard$pin_button$pin_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_pin_button__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pin"})});var $app$main$ui$dashboard$files$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_files__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});var $app$common$types$font$font_family_re$$=RegExp("[\\p{L}\\d _.-]+","u"),$app$common$types$font$schema_COLON_font_family$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,"errors.font-family-invalid-chars"],null),function($s$jscomp$610$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$re_matches$$($app$common$types$font$font_family_re$$,$s$jscomp$610$$))}],null)],null);var $app$main$ui$dashboard$fonts$accept_font_types$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$app$common$media$font_types$$)),",.ttf,application/font-woff,.woff,.woff2,.otf"].join(""),$app$main$ui$dashboard$fonts$header_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_82614$$){$app$main$ui$dashboard$fonts$use_page_title$$($props_82614$$.team,$props_82614$$.section);return(0,$APP.$rumext$v2$jsx$$)("header",
{"data-testid":"dashboard-header",className:"main_ui_dashboard_fonts__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-fonts-title",className:"main_ui_dashboard_fonts__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.fonts")})})})}),$app$main$ui$dashboard$fonts$installed_font$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($menu_open_QMARK_$jscomp$3_props_82695$$){var $variants$jscomp$11$$=
$menu_open_QMARK_$jscomp$3_props_82695$$.variants,$font_id$jscomp$41$$=$menu_open_QMARK_$jscomp$3_props_82695$$["font-id"],$can_edit$jscomp$16$$=$menu_open_QMARK_$jscomp$3_props_82695$$["can-edit"],$font$jscomp$59$$=$APP.$cljs$core$first$$($variants$jscomp$11$$),$menu_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$menu_open_QMARK_$jscomp$3_props_82695$$=$APP.$cljs$core$_deref$$($menu_open_STAR_$jscomp$1$$);var $edition_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$edition_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($edition_STAR_$jscomp$3$$),$state_STAR_$jscomp$26$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$59$$)),$font_family$jscomp$11$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$26$$),$variants__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants$jscomp$11$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$145$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$145$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("normal",$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$145$$))?1:2],null)},$variants$jscomp$11$$)}),$on_change$jscomp$102$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$745$$){return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$26$$,(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$745$$))}),
$on_edit$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$3$$,!0)}),$on_menu_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$1$$,!0)}),$on_menu_close$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$1$$,!1)}),$on_save$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_family$jscomp$11$$)],function(){$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$3$$,!1);return $APP.$cuerdas$core$blank_QMARK_$$($font_family$jscomp$11$$)?null:$APP.$cljs$core$truth_$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$font$schema_COLON_font_family$$,$font_family$jscomp$11$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$update_font$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$font_id$jscomp$41$$,$APP.$cljs$cst$725$name$$,$font_family$jscomp$11$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.font-family-invalid-chars")))}),$on_key_down$jscomp$30$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_save$jscomp$4$$)],function($event$jscomp$746$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$746$$))?
$on_save$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_save$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$746$$):$on_save$jscomp$4$$($event$jscomp$746$$):null}),$on_cancel$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$3$$,!1);return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$26$$,$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$59$$))}),$on_delete_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_id$jscomp$41$$)],
function(){var $options$jscomp$648$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$2479$on_accept$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$delete_font$$($font_id$jscomp$41$$))}],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($options$jscomp$648$$))}),$on_download$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants__$1$$)],function(){var $variant$jscomp$30_variant_id$jscomp$54$$=
$APP.$cljs$core$first$$($variants__$1$$);$variant$jscomp$30_variant_id$jscomp$54$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$30_variant_id$jscomp$54$$);var $multiple_QMARK_$jscomp$11$$=$APP.$cljs$core$count$$($variants__$1$$)>1;return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($blob$jscomp$41_p__82698$$){var $filename$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blob$jscomp$41_p__82698$$,0,null);$blob$jscomp$41_p__82698$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blob$jscomp$41_p__82698$$,1,null);return $APP.$app$util$dom$trigger_download$$($filename$jscomp$14$$,$blob$jscomp$41_p__82698$$)},function($error$jscomp$154$$){console.error("error downloading font",$error$jscomp$154$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")))},$APP.$beicon$v2$core$mapcat$$(function($map__82703__$1_p__82702_uri$jscomp$113$$){$map__82703__$1_p__82702_uri$jscomp$113$$=
$APP.$cljs$core$__destructure_map$$($map__82703__$1_p__82702_uri$jscomp$113$$);var $name$jscomp$504$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82703__$1_p__82702_uri$jscomp$113$$,$APP.$cljs$cst$725$name$$);$map__82703__$1_p__82702_uri$jscomp$113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82703__$1_p__82702_uri$jscomp$113$$,$APP.$cljs$cst$1579$uri$$);return $APP.$beicon$v2$core$map$$(function($blob$jscomp$42$$){return new $APP.$cljs$core$MapEntry$$($name$jscomp$504$$,
$blob$jscomp$42$$,null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1579$uri$$,$map__82703__$1_p__82702_uri$jscomp$113$$,$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$],null))))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($multiple_QMARK_$jscomp$11$$?$cljs$cst$6293$download_font_family$$:$cljs$cst$6294$download_font$$,
$multiple_QMARK_$jscomp$11$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1757$font_id$$,$font_id$jscomp$41$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$variant$jscomp$30_variant_id$jscomp$54$$],null))))}),$on_delete_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$747_options$jscomp$649$$){var $id$jscomp$1069$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$747_options$jscomp$649$$),
"id"));$event$jscomp$747_options$jscomp$649$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font-variant.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font-variant.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$delete_font_variant$$($id$jscomp$1069$$))}],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($event$jscomp$747_options$jscomp$649$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__font-item main_ui_dashboard_fonts__table-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__family "+($APP.$cljs$core$truth_$$($edition_QMARK_$jscomp$4$$)?"main_ui_dashboard_fonts__is-edition":""),children:$edition_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",autoFocus:!0,defaultValue:$font_family$jscomp$11$$,onKeyDown:$on_key_down$jscomp$30$$,onChange:$on_change$jscomp$102$$}):(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$59$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__variants",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$246$$,$map__82705__$1_p__82704$$){$map__82705__$1_p__82704$$=$APP.$cljs$core$__destructure_map$$($map__82705__$1_p__82704$$);var $id$jscomp$1070$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82705__$1_p__82704$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$246$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_fonts__variant "+($APP.$cljs$core$not$$($can_edit$jscomp$16$$)?"main_ui_dashboard_fonts__inhert-variant":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_fonts__label",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$,{variant:$map__82705__$1_p__82704$$})}),$APP.$cljs$core$truth_$$($can_edit$jscomp$16$$)?(0,$APP.$rumext$v2$jsx$$)("span",{"data-id":""+($id$jscomp$1070$$??""),onClick:$on_delete_variant$$,
className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__close",children:$APP.$app$main$ui$icons$add$$}):null]},""+($id$jscomp$1070$$??"")));return $out_arr__44124__auto__$jscomp$246$$},[],$variants__$1$$)}),$edition_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cuerdas$core$blank_QMARK_$$($font_family$jscomp$11$$),onClick:$on_save$jscomp$4$$,
className:"main_ui_dashboard_fonts__btn-primary "+($APP.$cuerdas$core$blank_QMARK_$$($font_family$jscomp$11$$)?"main_ui_dashboard_fonts__btn-disabled":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_cancel$jscomp$10$$,className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__close",children:$APP.$app$main$ui$icons$close$$})]}):$APP.$cljs$core$truth_$$($can_edit$jscomp$16$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",children:[(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$on_menu_open$$,className:"main_ui_dashboard_fonts__icon",children:$APP.$app$main$ui$icons$menu$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$installed_font_context_menu$$,{"on-close":$on_menu_close$jscomp$6$$,"is-open":$menu_open_QMARK_$jscomp$3_props_82695$$,"on-delete":$on_delete_font$$,"on-download":$on_download$jscomp$4$$,"on-edit":$on_edit$jscomp$17$$})]}):
null]})}),$app$main$ui$dashboard$fonts$ref_COLON_fonts$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2969$fonts$$,$APP.$app$main$store$state$$);var $app$main$ui$dashboard$libraries$ref_COLON_selected_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($files$jscomp$45_state$jscomp$1231$$){var $selected$jscomp$216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$45_state$jscomp$1231$$,$APP.$cljs$cst$2183$selected_files$$);$files$jscomp$45_state$jscomp$1231$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$45_state$jscomp$1231$$,$APP.$cljs$cst$2179$shared_files$$);return $APP.$app$main$refs$extract_selected_files$$($files$jscomp$45_state$jscomp$1231$$,
$selected$jscomp$216$$)},$APP.$app$main$store$state$$);var $app$main$ui$dashboard$projects$show_more_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_projects__show-more-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})}),$app$main$ui$dashboard$projects$close_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_projects__close-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})}),$app$main$ui$dashboard$projects$add_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",
{width:500,className:"main_ui_dashboard_projects__add-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})}),$app$main$ui$dashboard$projects$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_projects__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})}),$app$main$ui$dashboard$projects$header_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($can_edit$jscomp$20_props_82712$$){$can_edit$jscomp$20_props_82712$$=
$can_edit$jscomp$20_props_82712$$.canEdit;var $on_click$jscomp$65$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$create_project$$())});return(0,$APP.$rumext$v2$jsxs$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_projects__dashboard-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-projects-title",className:"main_ui_dashboard_projects__dashboard-title",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.projects-title")})}),$APP.$cljs$core$truth_$$($can_edit$jscomp$20_props_82712$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_click$jscomp$65$$,"data-testid":"new-project-button",className:"main_ui_dashboard_projects__btn-secondary main_ui_dashboard_projects__btn-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-project")}):null]})}),$app$main$ui$dashboard$projects$team_hero_STAR_$$=
$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_nav_members_click_props_82716$$){var $on_close$jscomp$48$$=$on_nav_members_click_props_82716$$.onClose,$team$jscomp$78$$=$on_nav_members_click_props_82716$$.team;$on_nav_members_click_props_82716$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_members$$())});var $on_invite$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$78$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5127$invite_members$$,$APP.$cljs$cst$2492$team$$,$team$jscomp$78$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$5134$hero$$],null)))}),$on_close_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$48$$)],
function($event$jscomp$749$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$749$$);return $on_close$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$on_close$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$749$$):$on_close$jscomp$48$$($event$jscomp$749$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__team-hero",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_projects__img-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/deco-team-banner.png",
border:"0",role:"presentation"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__text",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_projects__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dasboard.team-hero.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__info",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dasboard.team-hero.text")}),
(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_nav_members_click_props_82716$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dasboard.team-hero.management")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_invite$$,className:"main_ui_dashboard_projects__btn-primary main_ui_dashboard_projects__invite",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.invite-members")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close_SINGLEQUOTE_$$,
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),className:"main_ui_dashboard_projects__close",children:$app$main$ui$dashboard$projects$close_icon$$})]})}),$app$main$ui$dashboard$projects$ref_COLON_recent_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4914$recent_files$$,$APP.$app$main$store$state$$);var $app$main$ui$dashboard$search$ref_COLON_search_result$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4911$search_result$$,$APP.$app$main$store$state$$),$app$main$ui$dashboard$search$ref_COLON_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1232$$){var $files$jscomp$49$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$4911$search_result$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1232$$));
return $APP.$app$main$refs$extract_selected_files$$($files$jscomp$49$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1232$$,$APP.$cljs$cst$2183$selected_files$$))},$APP.$app$main$store$state$$);var $app$main$ui$dashboard$templates$arrow_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_templates__arrow-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})}),$app$main$ui$dashboard$templates$download_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_templates__download-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})}),$app$main$ui$dashboard$templates$builtin_templates$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4918$builtin_templates$$,
$APP.$app$main$store$state$$);
//# sourceMappingURL=main-dashboard.js.map
