import { $APP, shadow$provide } from "./shared.js";
import "./main-auth.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$viewer$comments$update_thread_position$$,$app$main$data$common$share_link_created$$,$app$main$data$viewer$set_viewport_size$$,$app$main$data$viewer$exit_fullscreen$$,$app$main$data$viewer$toggle_selection$$,$app$main$data$viewer$complete_animation$$,$app$main$data$viewer$finalize$$,$app$main$data$viewer$reset_nav_scroll$$,$app$main$data$viewer$hover_shape$$,
$app$main$data$viewer$toggle_collapse$$,$app$main$data$common$create_share_link$$,$app$main$data$common$delete_share_link$$,$app$main$data$comments$created_thread_on_viewer$$,$app$render_wasm$api$process_pending_no_sideffects$$,$app$main$data$viewer$fetch_comment_threads$$,$app$main$ui$inspect$selection_feedback$selection_rect$$,$app$main$data$comments$create_thread_on_viewer$$,$app$main$data$viewer$generate_update_position_data_changes$$,$app$main$ui$viewer$interactions$animate_close_overlay$$,$app$main$ui$viewer$interactions$animate_open_overlay$$,
$app$main$ui$viewer$interactions$animate_go_to_frame$$,$app$util$dom$fullscreen_QMARK_$$,$app$util$webapi$exit_fullscreen$$,$app$util$webapi$request_fullscreen$$,$app$main$ui$inspect$selection_feedback$selection_feedback$$,$app$main$data$viewer$select_shape$$,$app$main$data$viewer$shift_select_to$$,$app$main$data$viewer$go_to_frame_auto$$,$app$main$data$viewer$go_to_frame$$,$app$main$ui$viewer$comments$comments_layer$$,$app$render_wasm$api$set_objects_callback$$,$app$main$data$viewer$apply_changes_viewer$$,
$app$main$data$viewer$update_page_position_data$$,$app$main$data$viewer$bundle_fetched$$,$app$main$data$viewer$fetch_bundle$$,$app$main$data$viewer$initialize$$,$app$main$ui$viewer$comments$comments_sidebar_STAR_$$,$app$main$ui$inspect$left_sidebar$make_collapsed_iref$$,$app$main$ui$inspect$left_sidebar$left_sidebar$$,$app$main$ui$inspect$render$handle_hover_shape$$,$app$main$ui$inspect$render$select_shape$$,$app$main$ui$inspect$render$shape_wrapper_factory$$,$app$main$ui$inspect$render$frame_container_factory$$,
$app$main$ui$inspect$render$group_container_factory$$,$app$main$ui$inspect$render$bool_container_factory$$,$app$main$ui$inspect$render$svg_raw_container_factory$$,$app$main$ui$inspect$render$shape_container_factory$$,$app$main$ui$inspect$render$render_frame_svg$$,$app$main$ui$viewer$inspect$handle_select_frame$$,$app$main$ui$viewer$inspect$viewport$$,$app$main$ui$viewer$login$login_register_modal$$,$app$main$ui$viewer$share_link$prepare_params$$,$app$main$ui$viewer$share_link$share_link_dialog$$,
$app$main$ui$viewer$thumbnails$thumbnails_content$$,$app$main$ui$viewer$thumbnails$thumbnails_summary$$,$app$main$ui$viewer$thumbnails$thumbnails_panel$$,$app$main$ui$viewer$calculate_size$$,$app$main$ui$viewer$calculate_delta$$,$app$main$ui$viewer$calculate_wrapper$$,$app$main$ui$viewer$viewer_pagination$$,$app$main$ui$viewer$viewer_overlay$$,$app$main$ui$viewer$viewer_wrapper$$,$app$main$ui$viewer$viewer_content_STAR_$$,$app$main$ui$viewer$viewer_STAR_$$,$app$main$data$common$share_link_created_52458$$,
$app$main$data$common$create_share_link_52470$$,$app$main$data$common$delete_share_link_52485$$,$app$main$data$comments$created_thread_on_viewer_55774$$,$app$main$data$comments$create_thread_on_viewer_55838$$,$app$main$data$viewer$initialize_73923$$,$app$main$data$viewer$finalize_73931$$,$app$main$data$viewer$fetch_bundle_73939$$,$app$main$data$viewer$apply_changes_viewer_73971$$,$app$main$data$viewer$update_page_position_data_73977$$,$app$main$data$viewer$bundle_fetched_73991$$,$app$main$data$viewer$fetch_comment_threads_74026$$,
$app$main$data$viewer$exit_fullscreen_74173$$,$app$main$data$viewer$set_viewport_size_74182$$,$app$main$data$viewer$reset_nav_scroll_74268$$,$app$main$data$viewer$complete_animation_74274$$,$app$main$data$viewer$go_to_frame_auto_74312$$,$app$main$data$viewer$select_shape_74558$$,$app$main$data$viewer$toggle_selection_74593$$,$app$main$data$viewer$shift_select_to_74615$$,$app$main$data$viewer$toggle_collapse_74669$$,$app$main$data$viewer$hover_shape_74673$$,$cljs$cst$6334$left_bar$$,$cljs$cst$6330$thumbnail_data$$,
$cljs$cst$6324$email_sent$$,$cljs$cst$6335$right_bar$$,$cljs$cst$6326$all_pages$$,$cljs$cst$6329$expanded_QMARK_$$,$cljs$cst$6325$pages_mode$$,$cljs$cst$6333$num_frames$$,$cljs$cst$6323$register$$,$cljs$cst$6328$can_inspect_code$$,$cljs$cst$6338$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer$$,$cljs$cst$6331$base_width$$,$cljs$cst$6337$wrapper_size$$,$cljs$cst$6336$comment_sidebar$$,$cljs$cst$6321$hide_toggle_QMARK_$$,$cljs$cst$6332$base_height$$,$cljs$cst$6320$component_child_QMARK_$$,$cljs$cst$6327$can_comment$$,
$cljs$cst$6319$item$$,$cljs$cst$6322$viewer_pagination$$;$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($animation_item$jscomp$38$$,$keyframes$jscomp$2$$,$duration$jscomp$3$$,$onfinish$$){$animation_item$jscomp$38$$=$animation_item$jscomp$38$$.animate($keyframes$jscomp$2$$,$duration$jscomp$3$$);return $APP.$cljs$core$truth_$$($onfinish$$)?$animation_item$jscomp$38$$.onfinish=$onfinish$$:null};
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($item$jscomp$37$$,$keyframes$jscomp$1$$,$duration$jscomp$2$$){return $app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($item$jscomp$37$$,$keyframes$jscomp$1$$,$duration$jscomp$2$$,null)};
$app$main$ui$viewer$comments$update_thread_position$$=function($positions$jscomp$3_temp__5823__auto__$jscomp$213$$,$map__75274__$1_p__75273$$){$map__75274__$1_p__75273$$=$APP.$cljs$core$__destructure_map$$($map__75274__$1_p__75273$$);var $id$jscomp$917$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75274__$1_p__75273$$,$APP.$cljs$cst$266$id$$);$positions$jscomp$3_temp__5823__auto__$jscomp$213$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($positions$jscomp$3_temp__5823__auto__$jscomp$213$$,
$id$jscomp$917$$);return $APP.$cljs$core$truth_$$($positions$jscomp$3_temp__5823__auto__$jscomp$213$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__75274__$1_p__75273$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($positions$jscomp$3_temp__5823__auto__$jscomp$213$$)),$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($positions$jscomp$3_temp__5823__auto__$jscomp$213$$)):
$map__75274__$1_p__75273$$};
$app$main$data$common$share_link_created$$=function($link$jscomp$5$$){typeof $app$main$data$common$share_link_created_52458$$==="undefined"&&($app$main$data$common$share_link_created_52458$$=function($link$jscomp$6$$,$meta52459$$){this.link=$link$jscomp$6$$;this.$meta52459$=$meta52459$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$share_link_created_52458$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$share_link_created_52458$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2465$app_DOT_main_DOT_data_DOT_common_SLASH_share_link_created$$},$app$main$data$common$share_link_created_52458$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52460$$,$meta52459__$1$$){return new $app$main$data$common$share_link_created_52458$$(this.link,$meta52459__$1$$)},$app$main$data$common$share_link_created_52458$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52459$},$app$main$data$common$share_link_created_52458$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$share_link_created_52458$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1532$$,$state$jscomp$119$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$119$$,$APP.$cljs$cst$2176$share_links$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),this.link)});return new $app$main$data$common$share_link_created_52458$$($link$jscomp$5$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$set_viewport_size$$=function($p__74179$$){var $map__74181__$1$$=$APP.$cljs$core$__destructure_map$$($p__74179$$),$size$jscomp$136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74181__$1$$,$APP.$cljs$cst$874$size$$);typeof $app$main$data$viewer$set_viewport_size_74182$$==="undefined"&&($app$main$data$viewer$set_viewport_size_74182$$=function($p__74179$jscomp$1$$,$map__74181$jscomp$1$$,$size$jscomp$137$$,$meta74183$$){this.$p__74179$=$p__74179$jscomp$1$$;this.$map__74181$=
$map__74181$jscomp$1$$;this.size=$size$jscomp$137$$;this.$meta74183$=$meta74183$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$set_viewport_size_74182$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_viewport_size_74182$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5261$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_viewport_size$$},$app$main$data$viewer$set_viewport_size_74182$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_74184$$,$meta74183__$1$$){return new $app$main$data$viewer$set_viewport_size_74182$$(this.$p__74179$,this.$map__74181$,this.size,$meta74183__$1$$)},$app$main$data$viewer$set_viewport_size_74182$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74183$},$app$main$data$viewer$set_viewport_size_74182$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_viewport_size_74182$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2897$$,$state$jscomp$1109$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1109$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$5255$viewport_size$$],null),this.size)});return new $app$main$data$viewer$set_viewport_size_74182$$($p__74179$$,$map__74181__$1$$,$size$jscomp$136$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$exit_fullscreen$$=function(){typeof $app$main$data$viewer$exit_fullscreen_74173$$==="undefined"&&($app$main$data$viewer$exit_fullscreen_74173$$=function($meta74174$$){this.$meta74174$=$meta74174$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$exit_fullscreen_74173$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$exit_fullscreen_74173$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5260$app_DOT_main_DOT_data_DOT_viewer_SLASH_exit_fullscreen$$},$app$main$data$viewer$exit_fullscreen_74173$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74175$$,$meta74174__$1$$){return new $app$main$data$viewer$exit_fullscreen_74173$$($meta74174__$1$$)},$app$main$data$viewer$exit_fullscreen_74173$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74174$},$app$main$data$viewer$exit_fullscreen_74173$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$exit_fullscreen_74173$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2896$$,$state$jscomp$1108$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1108$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2234$fullscreen_QMARK_$$],null),!1)});return new $app$main$data$viewer$exit_fullscreen_74173$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$toggle_selection$$=function($id$jscomp$900$$){typeof $app$main$data$viewer$toggle_selection_74593$$==="undefined"&&($app$main$data$viewer$toggle_selection_74593$$=function($id$jscomp$901$$,$meta74594$$){this.id=$id$jscomp$901$$;this.$meta74594$=$meta74594$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$toggle_selection_74593$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_selection_74593$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5290$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_selection$$},$app$main$data$viewer$toggle_selection_74593$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74595$$,$meta74594__$1$$){return new $app$main$data$viewer$toggle_selection_74593$$(this.id,$meta74594__$1$$)},$app$main$data$viewer$toggle_selection_74593$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74594$},$app$main$data$viewer$toggle_selection_74593$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_selection_74593$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2926_selected$jscomp$133$$,$G__74614__$1_state$jscomp$1138$$){$_$jscomp$2926_selected$jscomp$133$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__74614__$1_state$jscomp$1138$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$1921$selected$$],
null));$G__74614__$1_state$jscomp$1138$$=$APP.$cljs$core$not$$($_$jscomp$2926_selected$jscomp$133$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$2926_selected$jscomp$133$$.$cljs$core$IFn$_invoke$arity$1$(this.id):$_$jscomp$2926_selected$jscomp$133$$(this.id))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__74614__$1_state$jscomp$1138$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$1921$selected$$],
null),$APP.$cljs$core$conj$$,this.id):$G__74614__$1_state$jscomp$1138$$;return $APP.$cljs$core$truth_$$($_$jscomp$2926_selected$jscomp$133$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$2926_selected$jscomp$133$$.$cljs$core$IFn$_invoke$arity$1$(this.id):$_$jscomp$2926_selected$jscomp$133$$(this.id))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__74614__$1_state$jscomp$1138$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,
$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$disj$$,this.id):$G__74614__$1_state$jscomp$1138$$});return new $app$main$data$viewer$toggle_selection_74593$$($id$jscomp$900$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$complete_animation$$=function(){typeof $app$main$data$viewer$complete_animation_74274$$==="undefined"&&($app$main$data$viewer$complete_animation_74274$$=function($meta74275$$){this.$meta74275$=$meta74275$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$complete_animation_74274$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$complete_animation_74274$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5275$app_DOT_main_DOT_data_DOT_viewer_SLASH_complete_animation$$},$app$main$data$viewer$complete_animation_74274$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74276$$,$meta74275__$1$$){return new $app$main$data$viewer$complete_animation_74274$$($meta74275__$1$$)},$app$main$data$viewer$complete_animation_74274$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74275$},$app$main$data$viewer$complete_animation_74274$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$complete_animation_74274$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2912$$,$state$jscomp$1123$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1123$$,$APP.$cljs$cst$5266$viewer_animations$$)});return new $app$main$data$viewer$complete_animation_74274$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$finalize$$=function($_$jscomp$2876$$){typeof $app$main$data$viewer$finalize_73931$$==="undefined"&&($app$main$data$viewer$finalize_73931$$=function($_$jscomp$2877$$,$meta73932$$){this.$_$=$_$jscomp$2877$$;this.$meta73932$=$meta73932$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$finalize_73931$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$finalize_73931$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5237$app_DOT_main_DOT_data_DOT_viewer_SLASH_finalize$$},$app$main$data$viewer$finalize_73931$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73933$$,$meta73932__$1$$){return new $app$main$data$viewer$finalize_73931$$(this.$_$,$meta73932__$1$$)},$app$main$data$viewer$finalize_73931$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73932$},$app$main$data$viewer$finalize_73931$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$finalize_73931$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($___$1$jscomp$2009$$,$state$jscomp$1092$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1092$$,$APP.$cljs$cst$1592$viewer$$)});return new $app$main$data$viewer$finalize_73931$$($_$jscomp$2876$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$reset_nav_scroll$$=function(){typeof $app$main$data$viewer$reset_nav_scroll_74268$$==="undefined"&&($app$main$data$viewer$reset_nav_scroll_74268$$=function($meta74269$$){this.$meta74269$=$meta74269$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$reset_nav_scroll_74268$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$reset_nav_scroll_74268$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5274$app_DOT_main_DOT_data_DOT_viewer_SLASH_reset_nav_scroll$$},$app$main$data$viewer$reset_nav_scroll_74268$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74270$$,$meta74269__$1$$){return new $app$main$data$viewer$reset_nav_scroll_74268$$($meta74269__$1$$)},$app$main$data$viewer$reset_nav_scroll_74268$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74269$},$app$main$data$viewer$reset_nav_scroll_74268$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$reset_nav_scroll_74268$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2911$$,$state$jscomp$1122$$){return $APP.$app$common$data$dissoc_in$$($state$jscomp$1122$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$5273$nav_scroll$$],null))});return new $app$main$data$viewer$reset_nav_scroll_74268$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$hover_shape$$=function($id$jscomp$906$$,$hover_QMARK_$jscomp$4$$){typeof $app$main$data$viewer$hover_shape_74673$$==="undefined"&&($app$main$data$viewer$hover_shape_74673$$=function($id$jscomp$907$$,$hover_QMARK_$jscomp$5$$,$meta74674$$){this.id=$id$jscomp$907$$;this.$hover_QMARK_$=$hover_QMARK_$jscomp$5$$;this.$meta74674$=$meta74674$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$hover_shape_74673$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$hover_shape_74673$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5294$app_DOT_main_DOT_data_DOT_viewer_SLASH_hover_shape$$},$app$main$data$viewer$hover_shape_74673$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74675$$,$meta74674__$1$$){return new $app$main$data$viewer$hover_shape_74673$$(this.id,this.$hover_QMARK_$,$meta74674__$1$$)},$app$main$data$viewer$hover_shape_74673$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74674$},$app$main$data$viewer$hover_shape_74673$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$hover_shape_74673$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2930$$,$state$jscomp$1142$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1142$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2204$hover$$],
null),$APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?this.id:null)});return new $app$main$data$viewer$hover_shape_74673$$($id$jscomp$906$$,$hover_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$toggle_collapse$$=function($id$jscomp$904$$){typeof $app$main$data$viewer$toggle_collapse_74669$$==="undefined"&&($app$main$data$viewer$toggle_collapse_74669$$=function($id$jscomp$905$$,$meta74670$$){this.id=$id$jscomp$905$$;this.$meta74670$=$meta74670$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$toggle_collapse_74669$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_collapse_74669$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5293$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_collapse$$},$app$main$data$viewer$toggle_collapse_74669$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74671$$,$meta74670__$1$$){return new $app$main$data$viewer$toggle_collapse_74669$$(this.id,$meta74670__$1$$)},$app$main$data$viewer$toggle_collapse_74669$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74670$},$app$main$data$viewer$toggle_collapse_74669$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_collapse_74669$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2929_toggled_QMARK_$$,$state$jscomp$1141$$){$_$jscomp$2929_toggled_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1141$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2048$collapsed$$],
null)),this.id);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1141$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2048$collapsed$$],null),$_$jscomp$2929_toggled_QMARK_$$?$APP.$cljs$core$disj$$:$APP.$cljs$core$conj$$,this.id)});return new $app$main$data$viewer$toggle_collapse_74669$$($id$jscomp$904$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$create_share_link$$=function($params$jscomp$145$$){typeof $app$main$data$common$create_share_link_52470$$==="undefined"&&($app$main$data$common$create_share_link_52470$$=function($params$jscomp$146$$,$meta52471$$){this.params=$params$jscomp$146$$;this.$meta52471$=$meta52471$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$create_share_link_52470$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$create_share_link_52470$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2466$app_DOT_main_DOT_data_DOT_common_SLASH_create_share_link$$},$app$main$data$common$create_share_link_52470$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52472$$,$meta52471__$1$$){return new $app$main$data$common$create_share_link_52470$$(this.params,$meta52471__$1$$)},$app$main$data$common$create_share_link_52470$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta52471$},$app$main$data$common$create_share_link_52470$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$create_share_link_52470$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$common$share_link_created$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2467$create_share_link$$,this.params))});return new $app$main$data$common$create_share_link_52470$$($params$jscomp$145$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$delete_share_link$$=function($p__52479$$){var $map__52482__$1$$=$APP.$cljs$core$__destructure_map$$($p__52479$$),$id$jscomp$241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52482__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$common$delete_share_link_52485$$==="undefined"&&($app$main$data$common$delete_share_link_52485$$=function($p__52479$jscomp$1$$,$map__52482$jscomp$1$$,$link$jscomp$8$$,$id$jscomp$242$$,$meta52486$$){this.$p__52479$=$p__52479$jscomp$1$$;
this.$map__52482$=$map__52482$jscomp$1$$;this.link=$link$jscomp$8$$;this.id=$id$jscomp$242$$;this.$meta52486$=$meta52486$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$delete_share_link_52485$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$delete_share_link_52485$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2468$app_DOT_main_DOT_data_DOT_common_SLASH_delete_share_link$$},
$app$main$data$common$delete_share_link_52485$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52487$$,$meta52486__$1$$){return new $app$main$data$common$delete_share_link_52485$$(this.$p__52479$,this.$map__52482$,this.link,this.id,$meta52486__$1$$)},$app$main$data$common$delete_share_link_52485$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52486$},$app$main$data$common$delete_share_link_52485$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$delete_share_link_52485$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1534$$,$state$jscomp$120$$){var $self__$jscomp$3285$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$120$$,$APP.$cljs$cst$2176$share_links$$,function($links$jscomp$2$$){return $APP.$cljs$core$filterv$$(function($p1__52476_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3285$$.id,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__52476_SHARP_$$))},
$links$jscomp$2$$)})},$app$main$data$common$delete_share_link_52485$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$delete_share_link_52485$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2469$delete_share_link$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$common$delete_share_link_52485$$($p__52479$$,
$map__52482__$1$$,$map__52482__$1$$,$id$jscomp$241$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$created_thread_on_viewer$$=function($p__55767$$){var $map__55768__$1$$=$APP.$cljs$core$__destructure_map$$($p__55767$$),$id$jscomp$422$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55768__$1$$,$APP.$cljs$cst$266$id$$),$comment$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55768__$1$$,$APP.$cljs$cst$3432$comment$$),$page_id$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55768__$1$$,$APP.$cljs$cst$2043$page_id$$);
typeof $app$main$data$comments$created_thread_on_viewer_55774$$==="undefined"&&($app$main$data$comments$created_thread_on_viewer_55774$$=function($p__55767$jscomp$1$$,$map__55768$jscomp$1$$,$thread$jscomp$4$$,$id$jscomp$423$$,$comment$jscomp$3$$,$page_id$jscomp$93$$,$meta55775$$){this.$p__55767$=$p__55767$jscomp$1$$;this.$map__55768$=$map__55768$jscomp$1$$;this.thread=$thread$jscomp$4$$;this.id=$id$jscomp$423$$;this.comment=$comment$jscomp$3$$;this.$page_id$=$page_id$jscomp$93$$;this.$meta55775$=
$meta55775$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3441$app_DOT_main_DOT_data_DOT_comments_SLASH_created_thread_on_viewer$$},$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55776$$,$meta55775__$1$$){return new $app$main$data$comments$created_thread_on_viewer_55774$$(this.$p__55767$,this.$map__55768$,this.thread,this.id,this.comment,this.$page_id$,$meta55775__$1$$)},$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55775$},$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1800_position$jscomp$62$$,$state$jscomp$254$$){$_$jscomp$1800_position$jscomp$62$$=$APP.$cljs$core$select_keys$$(this.thread,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1607$frame_id$$],null));return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$254$$,
$APP.$cljs$cst$2175$comment_threads$$,$APP.$cljs$core$assoc$$,this.id,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.thread,$APP.$cljs$cst$3432$comment$$)),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,this.$page_id$,$APP.$cljs$cst$2061$comment_thread_positions$$],null),$APP.$cljs$core$assoc$$,this.id,$_$jscomp$1800_position$jscomp$62$$),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$3434$open$$,this.id),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$873$options$$,null),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3435$draft$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3436$comments$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.comment),this.comment)},$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_viewer_55774$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-comment-thread",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3437$content_size$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$(this.comment))],null)))});return new $app$main$data$comments$created_thread_on_viewer_55774$$($p__55767$$,$map__55768__$1$$,$map__55768__$1$$,$id$jscomp$422$$,$comment$jscomp$2$$,$page_id$jscomp$92$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$render_wasm$api$process_pending_no_sideffects$$=function($pending_thumbnails$jscomp$3_thumbnails$jscomp$4$$,$full$jscomp$4_pending_full$jscomp$3$$,$on_complete$jscomp$2$$){$pending_thumbnails$jscomp$3_thumbnails$jscomp$4$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2354$callback$$,$pending_thumbnails$jscomp$3_thumbnails$jscomp$4$$);$full$jscomp$4_pending_full$jscomp$3$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,
$APP.$cljs$cst$2354$callback$$,$full$jscomp$4_pending_full$jscomp$3$$);$APP.$cljs$core$seq$$($pending_thumbnails$jscomp$3_thumbnails$jscomp$4$$)||$APP.$cljs$core$seq$$($full$jscomp$4_pending_full$jscomp$3$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$render_wasm$api$noop_fn$$,$APP.$app$render_wasm$api$noop_fn$$,function(){return $APP.$cljs$core$fn_QMARK_$$($on_complete$jscomp$2$$)?$on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():
$on_complete$jscomp$2$$():null},$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($callback$jscomp$87$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$87$$)?$callback$jscomp$87$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$87$$.$cljs$core$IFn$_invoke$arity$0$():
$callback$jscomp$87$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($pending_thumbnails$jscomp$3_thumbnails$jscomp$4$$))))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($callback$jscomp$88$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$88$$)?
$callback$jscomp$88$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$88$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$88$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($full$jscomp$4_pending_full$jscomp$3$$))))))):$APP.$cljs$core$truth_$$($on_complete$jscomp$2$$)&&($on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_complete$jscomp$2$$())};
$app$main$data$viewer$fetch_comment_threads$$=function($p__74015$$){var $map__74016__$1$$=$APP.$cljs$core$__destructure_map$$($p__74015$$),$file_id$jscomp$346$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74016__$1$$,$APP.$cljs$cst$1644$file_id$$),$page_id$jscomp$390$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74016__$1$$,$APP.$cljs$cst$2043$page_id$$),$share_id$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74016__$1$$,$APP.$cljs$cst$3237$share_id$$);
typeof $app$main$data$viewer$fetch_comment_threads_74026$$==="undefined"&&($app$main$data$viewer$fetch_comment_threads_74026$$=function($p__74015$jscomp$1$$,$map__74016$jscomp$1$$,$params$jscomp$384$$,$file_id$jscomp$347$$,$page_id$jscomp$391$$,$share_id$jscomp$21$$,$fetched$jscomp$7$$,$on_error$jscomp$62$$,$meta74027$$){this.$p__74015$=$p__74015$jscomp$1$$;this.$map__74016$=$map__74016$jscomp$1$$;this.params=$params$jscomp$384$$;this.$file_id$=$file_id$jscomp$347$$;this.$page_id$=$page_id$jscomp$391$$;
this.$share_id$=$share_id$jscomp$21$$;this.$fetched$=$fetched$jscomp$7$$;this.$on_error$=$on_error$jscomp$62$$;this.$meta74027$=$meta74027$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$fetch_comment_threads_74026$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$fetch_comment_threads_74026$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5247$app_DOT_main_DOT_data_DOT_viewer_SLASH_fetch_comment_threads$$},
$app$main$data$viewer$fetch_comment_threads_74026$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74028$$,$meta74027__$1$$){return new $app$main$data$viewer$fetch_comment_threads_74026$$(this.$p__74015$,this.$map__74016$,this.params,this.$file_id$,this.$page_id$,this.$share_id$,this.$fetched$,this.$on_error$,$meta74027__$1$$)},$app$main$data$viewer$fetch_comment_threads_74026$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74027$},$app$main$data$viewer$fetch_comment_threads_74026$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$fetch_comment_threads_74026$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7109$$=this;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7109$$.$on_error$,$APP.$beicon$v2$core$map$$(function($p1__74012_SHARP_$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7109$$.$fetched$,$p1__74012_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3460$get_comment_threads$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$7109$$.$file_id$,$APP.$cljs$cst$3237$share_id$$,$self__$jscomp$7109$$.$share_id$],null))))});return new $app$main$data$viewer$fetch_comment_threads_74026$$($p__74015$$,$map__74016__$1$$,$map__74016__$1$$,$file_id$jscomp$346$$,$page_id$jscomp$390$$,$share_id$jscomp$20$$,function($data$jscomp$447$$,$state$jscomp$1097$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1097$$,$APP.$cljs$cst$2175$comment_threads$$,
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74011_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$390$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74011_SHARP_$$))},$data$jscomp$447$$)))},function($map__74024__$1_p__74022$$){$map__74024__$1_p__74022$$=$APP.$cljs$core$__destructure_map$$($map__74024__$1_p__74022$$);var $type$jscomp$597$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74024__$1_p__74022$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3157$authentication$$,$type$jscomp$597$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2665$not_found$$,$type$jscomp$597$$)?$APP.$beicon$v2$core$empty$$():$APP.$beicon$v2$core$throw$0$$($map__74024__$1_p__74022$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$inspect$selection_feedback$selection_rect$$=function($map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$){$map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$=$APP.$rumext$v2$util$wrap_props$$($map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$);$map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$=$APP.$cljs$core$__destructure_map$$($map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$);var $selrect$jscomp$78_x$jscomp$1241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$,
$APP.$cljs$cst$1605$selrect$$);$map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$,$APP.$cljs$cst$2196$zoom$$);var $height$jscomp$157_map__75009__$1$$=$APP.$cljs$core$__destructure_map$$($selrect$jscomp$78_x$jscomp$1241$$);$selrect$jscomp$78_x$jscomp$1241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75009__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$461$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75009__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75009__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$157_map__75009__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75009__$1$$,$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"selection-rect",children:(0,$APP.$rumext$v2$jsx$$)("rect",
{x:$selrect$jscomp$78_x$jscomp$1241$$,y:$y$jscomp$461$$,width:$width$jscomp$180$$,height:$height$jscomp$157_map__75009__$1$$,style:{fill:"none",stroke:"var(--color-accent-tertiary)",strokeWidth:1/$map__75008_map__75008__$1_props_75007_zoom$jscomp$59$$}})})};
$app$main$data$comments$create_thread_on_viewer$$=function($params$jscomp$233$$){typeof $app$main$data$comments$create_thread_on_viewer_55838$$==="undefined"&&($app$main$data$comments$create_thread_on_viewer_55838$$=function($params$jscomp$234$$,$meta55839$$){this.params=$params$jscomp$234$$;this.$meta55839$=$meta55839$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$create_thread_on_viewer_55838$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_thread_on_viewer_55838$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3442$app_DOT_main_DOT_data_DOT_comments_SLASH_create_thread_on_viewer$$},$app$main$data$comments$create_thread_on_viewer_55838$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55840$$,$meta55839__$1$$){return new $app$main$data$comments$create_thread_on_viewer_55838$$(this.params,$meta55839__$1$$)},$app$main$data$comments$create_thread_on_viewer_55838$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55839$},$app$main$data$comments$create_thread_on_viewer_55838$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_thread_on_viewer_55838$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1802_frame_id$jscomp$36_params__$1$jscomp$32$$,$state$jscomp$255$$){var $share_id$jscomp$1$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$255$$));
$_$jscomp$1802_frame_id$jscomp$36_params__$1$jscomp$32$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$(this.params);$_$jscomp$1802_frame_id$jscomp$36_params__$1$jscomp$32$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$comments$update_mentions$$(this.params),$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1607$frame_id$$,$_$jscomp$1802_frame_id$jscomp$36_params__$1$jscomp$32$$]));
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__55881__$1_p__55880$$){$map__55881__$1_p__55880$$=$APP.$cljs$core$__destructure_map$$($map__55881__$1_p__55880$$);var $type$jscomp$443$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55881__$1_p__55880$$,$APP.$cljs$cst$139$type$$),$code$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55881__$1_p__55880$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$443$$,
$APP.$cljs$cst$2561$restriction$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$39$$,$APP.$cljs$cst$3382$max_quote_reached$$)?$APP.$beicon$v2$core$throw$0$$($map__55881__$1_p__55880$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$map$$($app$main$data$comments$created_thread_on_viewer$$,$APP.$beicon$v2$core$mapcat$$(function($p1__55832_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3439$get_comment_thread$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55832_SHARP_$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55832_SHARP_$$),$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$1$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3440$create_comment_thread$$,$_$jscomp$1802_frame_id$jscomp$36_params__$1$jscomp$32$$))))});return new $app$main$data$comments$create_thread_on_viewer_55838$$($params$jscomp$233$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$generate_update_position_data_changes$$=function($shapes$jscomp$148$$,$page_id$jscomp$385$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$329$$,$shape$jscomp$894$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$329$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$894$$),$APP.$cljs$cst$2043$page_id$$,
$page_id$jscomp$385$$,$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$108$val$$,$APP.$app$render_wasm$api$calculate_position_data$$($shape$jscomp$894$$),$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2557$ignore_geometry$$,!0],null)],null)],
null))},$APP.$cljs$core$PersistentVector$EMPTY$$,$shapes$jscomp$148$$)};
$app$main$ui$viewer$interactions$animate_close_overlay$$=function($animation$jscomp$14$$,$overlay_viewport$jscomp$1$$,$wrapper_size$jscomp$2$$,$overlay_size$jscomp$3$$,$overlay_position$jscomp$4$$,$overlay_id$$){if($overlay_viewport$jscomp$1$$!=null){var $G__75638_G__75638__$1_G__75639_G__75639__$1$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$);$G__75638_G__75638__$1_G__75639_G__75639__$1$$=$G__75638_G__75638__$1_G__75639_G__75639__$1$$ instanceof $APP.$cljs$core$Keyword$$?
$G__75638_G__75638__$1_G__75639_G__75639__$1$$.$fqn$:null;switch($G__75638_G__75638__$1_G__75639_G__75639__$1$$){case "dissolve":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"100"},{opacity:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});break;case "slide":switch($G__75638_G__75638__$1_G__75639_G__75639__$1$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),$G__75638_G__75638__$1_G__75639_G__75639__$1$$=
$G__75638_G__75638__$1_G__75639_G__75639__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75638_G__75638__$1_G__75639_G__75639__$1$$.$fqn$:null,$G__75638_G__75638__$1_G__75639_G__75639__$1$$){case "right":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$2$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;case "left":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;case "up":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;case "down":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$2$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75638_G__75638__$1_G__75639_G__75639__$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75638_G__75638__$1_G__75639_G__75639__$1$$)].join(""));}}};
$app$main$ui$viewer$interactions$animate_open_overlay$$=function($animation$jscomp$13$$,$overlay_viewport$$,$wrapper_size$jscomp$1$$,$overlay_size$jscomp$2$$,$overlay_position$jscomp$3$$){if($overlay_viewport$$!=null){var $G__75635_G__75635__$1_G__75636_G__75636__$1$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$);$G__75635_G__75635__$1_G__75636_G__75636__$1$$=$G__75635_G__75635__$1_G__75636_G__75636__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75635_G__75635__$1_G__75636_G__75636__$1$$.$fqn$:
null;switch($G__75635_G__75635__$1_G__75636_G__75636__$1$$){case "dissolve":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"0"},{opacity:"100"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});break;case "slide":switch($G__75635_G__75635__$1_G__75636_G__75636__$1$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),$G__75635_G__75635__$1_G__75636_G__75636__$1$$=$G__75635_G__75635__$1_G__75636_G__75636__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75635_G__75635__$1_G__75636_G__75636__$1$$.$fqn$:null,$G__75635_G__75635__$1_G__75636_G__75636__$1$$){case "right":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$2$$)),"px"].join("")},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});return;case "left":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$1$$)),
"px"].join("")},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});
return;case "up":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$1$$)),"px"].join("")},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});return;case "down":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$2$$)),"px"].join("")},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});return;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75635_G__75635__$1_G__75636_G__75636__$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75635_G__75635__$1_G__75636_G__75636__$1$$)].join(""));}}};
$app$main$ui$viewer$interactions$animate_go_to_frame$$=function($animation$jscomp$12$$,$current_viewport$$,$orig_viewport$$,$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$,$G__75630_G__75630__$1_orig_size$$,$offset$jscomp$197_wrapper_size$$){var $G__75628_G__75628__$1_G__75629_G__75629__$1$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$);$G__75628_G__75628__$1_G__75629_G__75629__$1$$=$G__75628_G__75628__$1_G__75629_G__75629__$1$$ instanceof
$APP.$cljs$core$Keyword$$?$G__75628_G__75628__$1_G__75629_G__75629__$1$$.$fqn$:null;switch($G__75628_G__75628__$1_G__75629_G__75629__$1$$){case "dissolve":return $app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"100%"},{opacity:"0%"},{opacity:"0%"}],null),{delay:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$)/3,duration:2*$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$)/
3,easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"0%"},{opacity:"100%"},{opacity:"100%"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});case "slide":$G__75628_G__75628__$1_G__75629_G__75629__$1$$=$APP.$cljs$cst$1962$way$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$);$G__75628_G__75628__$1_G__75629_G__75629__$1$$=$G__75628_G__75628__$1_G__75629_G__75629__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75628_G__75628__$1_G__75629_G__75629__$1$$.$fqn$:null;switch($G__75628_G__75628__$1_G__75629_G__75629__$1$$){case "in":switch($G__75630_G__75630__$1_orig_size$$=
$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),$G__75630_G__75630__$1_orig_size$$=$G__75630_G__75630__$1_orig_size$$ instanceof $APP.$cljs$core$Keyword$$?$G__75630_G__75630__$1_orig_size$$.$fqn$:null,$G__75630_G__75630__$1_orig_size$$){case "right":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{left:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{left:"0",opacity:"100%"},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "left":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),
"px"].join("")},{right:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:"0",opacity:"100%"},{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "up":return $offset$jscomp$197_wrapper_size$$=
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{bottom:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{bottom:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:"0",opacity:"100%"},{bottom:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):
null;case "down":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{top:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:"0",opacity:"100%"},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$)].join(""));}case "out":switch($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$=
$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$.$fqn$:null,$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$){case "right":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$))/
2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:"0"},{right:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*
.2),"px"].join(""),opacity:"0"},{right:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "left":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$))/2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:"0"},{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"},{left:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "up":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$)+
($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$))/2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:"0"},{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"},{top:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "down":return $offset$jscomp$197_wrapper_size$$=
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__75630_G__75630__$1_orig_size$$))/2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{bottom:"0"},{bottom:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$*.2),"px"].join(""),opacity:"0"},{bottom:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):
null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75628_G__75628__$1_G__75629_G__75629__$1$$)].join(""));}break;case "push":switch($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$=$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$.$fqn$:null,$G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$){case "right":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{left:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:"0"},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});
case "left":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{right:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:"0"},{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});case "up":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{bottom:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:"0"},{bottom:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});
case "down":return $offset$jscomp$197_wrapper_size$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),"px"].join("")},{top:"0"}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:"0"},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$197_wrapper_size$$),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75631_G__75631__$1_G__75634_G__75634__$1_current_size$jscomp$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75628_G__75628__$1_G__75629_G__75629__$1$$)].join(""));
}};
$app$util$dom$fullscreen_QMARK_$$=function(){if("webkitFullscreenElement"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.webkitFullscreenElement);if("mozFullScreen"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.mozFullScreen);if("msFullscreenElement"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.msFullscreenElement);if("fullscreenElement"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.fullscreenElement);
$APP.$app$common$logging$enabled_QMARK_$$("app.util.dom",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Seems like the current browser does not support fullscreen api."],null)],null)}),null,"app.util.dom",$APP.$cljs$cst$849$error$$,
!1);return!1};
$app$util$webapi$exit_fullscreen$$=function(){if("exitFullscreen"in document)return document.exitFullscreen();if("webkitExitFullscreen"in document)return document.webkitExitFullscreen();$APP.$app$common$logging$enabled_QMARK_$$("app.util.webapi",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1546$msg$$,"Seems like the current browser does not support fullscreen api."],null)],null)}),null,"app.util.webapi",$APP.$cljs$cst$849$error$$,!1);return!1};
$app$util$webapi$request_fullscreen$$=function($el$jscomp$5$$){if("requestFullscreen"in $el$jscomp$5$$)return $el$jscomp$5$$.requestFullscreen();if("webkitRequestFullscreen"in $el$jscomp$5$$)return $el$jscomp$5$$.webkitRequestFullscreen();$APP.$app$common$logging$enabled_QMARK_$$("app.util.webapi",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Seems like the current browser does not support fullscreen api."],null)],null)}),null,"app.util.webapi",$APP.$cljs$cst$849$error$$,!1);return!1};
$app$main$ui$inspect$selection_feedback$selection_feedback$$=function($map__75011_map__75011__$1_props_75010_size$jscomp$138$$){$map__75011_map__75011__$1_props_75010_size$jscomp$138$$=$APP.$rumext$v2$util$wrap_props$$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$);$map__75011_map__75011__$1_props_75010_size$jscomp$138$$=$APP.$cljs$core$__destructure_map$$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$);var $frame$jscomp$54_hover_shape$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$,
$APP.$cljs$cst$1606$frame$$),$local$jscomp$25_map__75012__$1_zoom$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$,$APP.$cljs$cst$2883$local$$),$objects$jscomp$731_selected_shapes$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$,$APP.$cljs$cst$1631$objects$$);$map__75011_map__75011__$1_props_75010_size$jscomp$138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$,
$APP.$cljs$cst$874$size$$);$local$jscomp$25_map__75012__$1_zoom$jscomp$60$$=$APP.$cljs$core$__destructure_map$$($local$jscomp$25_map__75012__$1_zoom$jscomp$60$$);var $hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$25_map__75012__$1_zoom$jscomp$60$$,$APP.$cljs$cst$2204$hover$$),$selected$jscomp$135_selrect$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$25_map__75012__$1_zoom$jscomp$60$$,
$APP.$cljs$cst$1921$selected$$);$local$jscomp$25_map__75012__$1_zoom$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$25_map__75012__$1_zoom$jscomp$60$$,$APP.$cljs$cst$2196$zoom$$);$hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$=$APP.$app$main$ui$inspect$selection_feedback$resolve_shapes$$($objects$jscomp$731_selected_shapes$jscomp$10$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$],
null));$hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$=$APP.$cljs$core$first$$($hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$);$frame$jscomp$54_hover_shape$jscomp$1$$=$APP.$cljs$core$truth_$$($hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$)?$hover$jscomp$1_or__5025__auto__$jscomp$inline_9562_shapes$jscomp$166$$:$frame$jscomp$54_hover_shape$jscomp$1$$;$objects$jscomp$731_selected_shapes$jscomp$10$$=$APP.$app$main$ui$inspect$selection_feedback$resolve_shapes$$($objects$jscomp$731_selected_shapes$jscomp$10$$,
$selected$jscomp$135_selrect$jscomp$79$$);$selected$jscomp$135_selrect$jscomp$79$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($objects$jscomp$731_selected_shapes$jscomp$10$$);return $APP.$app$common$data$not_empty_QMARK_$$($objects$jscomp$731_selected_shapes$jscomp$10$$)?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-feedback",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selected-shapes",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$selection_feedback$selection_rect$$,
{selrect:$selected$jscomp$135_selrect$jscomp$79$$,zoom:$local$jscomp$25_map__75012__$1_zoom$jscomp$60$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$size_display$$,{selrect:$selected$jscomp$135_selrect$jscomp$79$$,zoom:$local$jscomp$25_map__75012__$1_zoom$jscomp$60$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement$$,{bounds:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__75011_map__75011__$1_props_75010_size$jscomp$138$$,$APP.$cljs$cst$1510$x$$,
0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,0])),"selected-shapes":$objects$jscomp$731_selected_shapes$jscomp$10$$,"hover-shape":$frame$jscomp$54_hover_shape$jscomp$1$$,zoom:$local$jscomp$25_map__75012__$1_zoom$jscomp$60$$})]}):null};
$app$main$data$viewer$select_shape$$=function($id$jscomp$898$$){typeof $app$main$data$viewer$select_shape_74558$$==="undefined"&&($app$main$data$viewer$select_shape_74558$$=function($id$jscomp$899$$,$meta74559$$){this.id=$id$jscomp$899$$;this.$meta74559$=$meta74559$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$select_shape_74558$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$select_shape_74558$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5289$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_shape$$},$app$main$data$viewer$select_shape_74558$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74560$$,$meta74559__$1$$){return new $app$main$data$viewer$select_shape_74558$$(this.id,$meta74559__$1$$)},$app$main$data$viewer$select_shape_74558$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74559$},$app$main$data$viewer$select_shape_74558$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$select_shape_74558$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2925$$,$state$jscomp$1137$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1137$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.id]))});return new $app$main$data$viewer$select_shape_74558$$($id$jscomp$898$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$shift_select_to$$=function($id$jscomp$902$$){typeof $app$main$data$viewer$shift_select_to_74615$$==="undefined"&&($app$main$data$viewer$shift_select_to_74615$$=function($id$jscomp$903$$,$meta74616$$){this.id=$id$jscomp$903$$;this.$meta74616$=$meta74616$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$shift_select_to_74615$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$shift_select_to_74615$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5291$app_DOT_main_DOT_data_DOT_viewer_SLASH_shift_select_to$$},$app$main$data$viewer$shift_select_to_74615$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74617$$,$meta74616__$1$$){return new $app$main$data$viewer$shift_select_to_74615$$(this.id,$meta74616__$1$$)},$app$main$data$viewer$shift_select_to_74615$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74616$},$app$main$data$viewer$shift_select_to_74615$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$shift_select_to_74615$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$,$state$jscomp$1139$$){$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1139$$);$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$=
$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$);$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$);$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$=
$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$==null?null:$APP.$app$common$uuid$parse$$($G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$);$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1139$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$,$APP.$cljs$cst$1631$objects$$],null));var $selection$jscomp$12$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1139$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id);return $APP.$cljs$core$assoc_in$$($state$jscomp$1139$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$1921$selected$$],null),$APP.$app$common$files$helpers$expand_region_selection$$($G__74626$jscomp$inline_9564__$jscomp$2927_objects$jscomp$702_page_id$jscomp$400_qparams$jscomp$6_route$jscomp$16$$,
$selection$jscomp$12$$))});return new $app$main$data$viewer$shift_select_to_74615$$($id$jscomp$902$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_frame_auto$$=function(){typeof $app$main$data$viewer$go_to_frame_auto_74312$$==="undefined"&&($app$main$data$viewer$go_to_frame_auto_74312$$=function($meta74313$$){this.$meta74313$=$meta74313$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_frame_auto_74312$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_auto_74312$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5280$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame_auto$$},$app$main$data$viewer$go_to_frame_auto_74312$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74314$$,$meta74313__$1$$){return new $app$main$data$viewer$go_to_frame_auto_74312$$($meta74313__$1$$)},$app$main$data$viewer$go_to_frame_auto_74312$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74313$},$app$main$data$viewer$go_to_frame_auto_74312$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_auto_74312$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$,$flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$){$G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$);
$G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$);$G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$);
$G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$=$G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$==null?null:$APP.$app$common$uuid$parse$$($G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$);$flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$G__74316$jscomp$inline_9566__$jscomp$2917_page_id$jscomp$397_qparams$jscomp$3_route$jscomp$13$$,$APP.$cljs$cst$873$options$$,$APP.$cljs$cst$2056$flows$$],null));return $APP.$cljs$core$seq$$($flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$)?($flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$=$APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$)),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$($flows$jscomp$6_frame_id$jscomp$121_state$jscomp$1128$$))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$go_to_frame_by_index$$(0))});return new $app$main$data$viewer$go_to_frame_auto_74312$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_frame$$=function($var_args$jscomp$1402$$){switch(arguments.length){case 1:return $APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);case 2:return $APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$ui$viewer$comments$comments_layer$$=function($cursor$jscomp$1_props_75278$$){var $zoom$jscomp$61$$=$cursor$jscomp$1_props_75278$$.zoom,$frame$jscomp$56$$=$cursor$jscomp$1_props_75278$$.frame,$file$jscomp$154$$=$cursor$jscomp$1_props_75278$$.file,$page$jscomp$154$$=$cursor$jscomp$1_props_75278$$.page,$profile$jscomp$61$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$local$jscomp$28$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$);$cursor$jscomp$1_props_75278$$=$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$3436$comments$$);
var $open_thread_id$$=$APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$28$$),$page_id$jscomp$415$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$154$$),$file_id$jscomp$366_on_click$jscomp$29$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$154$$),$frame_id$jscomp$132$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$56$$),$vsize$$=$APP.$cljs$cst$5255$viewport_size$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_local$$)),
$threads$jscomp$10_tpos_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$415$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2228$pages$$,$page_id$jscomp$415$$,$APP.$cljs$cst$2061$comment_thread_positions$$],null)),$APP.$app$main$refs$viewer_data$$)}),$positions$jscomp$4$$=
$APP.$rumext$v2$deref$$($threads$jscomp$10_tpos_ref$$),$threads_map$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$),$frame_corner$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame$jscomp$56$$)],function(){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$56$$)))}),$modifier1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_corner$$)],
function(){return $APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$app$common$geom$point$negate$$($frame_corner$$))}),$modifier2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_corner$$)],function(){return $APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($frame_corner$$))});$threads$jscomp$10_tpos_ref$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($threads_map$jscomp$4$$),$APP.$rumext$v2$adapt$$($positions$jscomp$4$$),$APP.$rumext$v2$adapt$$($frame$jscomp$56$$),$APP.$rumext$v2$adapt$$($local$jscomp$28$$),$APP.$rumext$v2$adapt$$($profile$jscomp$61$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__75281__$1_p__75280_position$jscomp$187$$){$map__75281__$1_p__75280_position$jscomp$187$$=$APP.$cljs$core$__destructure_map$$($map__75281__$1_p__75280_position$jscomp$187$$);
$map__75281__$1_p__75280_position$jscomp$187$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75281__$1_p__75280_position$jscomp$187$$,$APP.$cljs$cst$1676$position$$);return $APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$($frame$jscomp$56$$,$map__75281__$1_p__75280_position$jscomp$187$$)},$APP.$app$main$data$comments$apply_filters$$($local$jscomp$28$$,$profile$jscomp$61$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75275_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75275_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$56$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$viewer$comments$update_thread_position$$,$positions$jscomp$4$$),$APP.$cljs$core$vals$$($threads_map$jscomp$4$$)))))});var $on_bubble_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_thread_id$$)],function($map__75284__$1_p__75283$$){$map__75284__$1_p__75283$$=
$APP.$cljs$core$__destructure_map$$($map__75284__$1_p__75283$$);var $id$jscomp$918$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75284__$1_p__75283$$,$APP.$cljs$cst$266$id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($open_thread_id$$,$id$jscomp$918$$)?$APP.$app$main$data$comments$close_thread$$():$APP.$cljs$core$with_meta$$($APP.$app$main$data$comments$open_thread$$($map__75284__$1_p__75283$$),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer"],null)))});$file_id$jscomp$366_on_click$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_thread_id$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$61$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$415$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$366_on_click$jscomp$29$$),$APP.$rumext$v2$adapt$$($modifier2$$)],function($event$jscomp$270_params$jscomp$413_position$jscomp$188$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$270_params$jscomp$413_position$jscomp$188$$);
if($open_thread_id$$!=null)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$());$event$jscomp$270_params$jscomp$413_position$jscomp$188$$=$APP.$app$common$geom$point$transform$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$dom$get_offset_position$$($event$jscomp$270_params$jscomp$413_position$jscomp$188$$.nativeEvent),$APP.$cljs$cst$1510$x$$,function($p1__75276_SHARP_$$){return $p1__75276_SHARP_$$/
$zoom$jscomp$61$$}),$APP.$cljs$cst$1511$y$$,function($p1__75277_SHARP_$$){return $p1__75277_SHARP_$$/$zoom$jscomp$61$$}),$modifier2$$);$event$jscomp$270_params$jscomp$413_position$jscomp$188$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1676$position$$,$event$jscomp$270_params$jscomp$413_position$jscomp$188$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$154$$),$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$154$$)],
null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$create_draft$$($event$jscomp$270_params$jscomp$413_position$jscomp$188$$))});var $on_draft_cancel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$())}),$on_draft_submit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$132$$),
$APP.$rumext$v2$adapt$$($modifier2$$)],function($draft$jscomp$1_params$jscomp$414$$){$draft$jscomp$1_params$jscomp$414$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($draft$jscomp$1_params$jscomp$414$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$132$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$comments$create_thread_on_viewer$$($draft$jscomp$1_params$jscomp$414$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$comments$close_thread$$()]))});
return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$file_id$jscomp$366_on_click$jscomp$29$$,className:"main_ui_viewer_comments__comments-section",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:""+($cursor$jscomp$1_props_75278$$??"")+" main_ui_viewer_comments__viewer-comments-container",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_comments__threads",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$107$$,$item$jscomp$117$$){$out_arr__44124__auto__$jscomp$107$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_bubble_STAR_$$,
{thread:$item$jscomp$117$$,positionModifier:$modifier1$$,zoom:$zoom$jscomp$61$$,onClick:$on_bubble_click$$,isOpen:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$117$$),$APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$28$$)),origin:$APP.$cljs$cst$1592$viewer$$},$APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$117$$)));return $out_arr__44124__auto__$jscomp$107$$},[],$threads$jscomp$10_tpos_ref$$),
function(){var $temp__5825__auto__$jscomp$319$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($threads_map$jscomp$4$$,$open_thread_id$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$319$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_thread_STAR_$$,{thread:$temp__5825__auto__$jscomp$319$$,positionModifier:$modifier1$$,viewport:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1650$offset_x$$,0,$APP.$cljs$cst$1651$offset_y$$,0,$APP.$cljs$cst$290$width$$,
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vsize$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vsize$$)],null),zoom:$zoom$jscomp$61$$}):null}(),function(){var $temp__5825__auto__$jscomp$320$$=$APP.$cljs$cst$3435$draft$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$28$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$320$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$comments$comment_floating_thread_draft_STAR_$$,{draft:$temp__5825__auto__$jscomp$320$$,
positionModifier:$modifier1$$,onCancel:$on_draft_cancel$$,onSubmit:$on_draft_submit$$,viewport:null,zoom:$zoom$jscomp$61$$}):null}()]})})})};
$app$render_wasm$api$set_objects_callback$$=function($map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$,$set_objects_cb$$){var $full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$=$APP.$cljs$core$count$$($map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$);a:{for(var $G__54879$jscomp$inline_9576_index$jscomp$inline_9568$$=0,$G__54880$jscomp$inline_9577_thumbnails_acc$jscomp$inline_9569$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$G__54881$jscomp$inline_9578_full_acc$jscomp$inline_9570$$=
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__54879$jscomp$inline_9576_index$jscomp$inline_9568$$<$full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$){var $map__54203$jscomp$inline_9572_shape$jscomp$inline_9571_thumbnails$jscomp$inline_9574$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$,$G__54879$jscomp$inline_9576_index$jscomp$inline_9568$$);$map__54203$jscomp$inline_9572_shape$jscomp$inline_9571_thumbnails$jscomp$inline_9574$$=
$APP.$app$render_wasm$api$set_object$$($map__54203$jscomp$inline_9572_shape$jscomp$inline_9571_thumbnails$jscomp$inline_9574$$);var $full$jscomp$inline_9575_map__54203__$1$jscomp$inline_9573$$=$APP.$cljs$core$__destructure_map$$($map__54203$jscomp$inline_9572_shape$jscomp$inline_9571_thumbnails$jscomp$inline_9574$$);$map__54203$jscomp$inline_9572_shape$jscomp$inline_9571_thumbnails$jscomp$inline_9574$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$inline_9575_map__54203__$1$jscomp$inline_9573$$,
$APP.$cljs$cst$2229$thumbnails$$);$full$jscomp$inline_9575_map__54203__$1$jscomp$inline_9573$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$inline_9575_map__54203__$1$jscomp$inline_9573$$,$APP.$cljs$cst$1273$full$$);$G__54879$jscomp$inline_9576_index$jscomp$inline_9568$$+=1;$G__54880$jscomp$inline_9577_thumbnails_acc$jscomp$inline_9569$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__54880$jscomp$inline_9577_thumbnails_acc$jscomp$inline_9569$$,
$map__54203$jscomp$inline_9572_shape$jscomp$inline_9571_thumbnails$jscomp$inline_9574$$);$G__54881$jscomp$inline_9578_full_acc$jscomp$inline_9570$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__54881$jscomp$inline_9578_full_acc$jscomp$inline_9570$$,$full$jscomp$inline_9575_map__54203__$1$jscomp$inline_9573$$)}else{$map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2229$thumbnails$$,$APP.$cljs$core$_persistent_BANG_$$($G__54880$jscomp$inline_9577_thumbnails_acc$jscomp$inline_9569$$),
$APP.$cljs$cst$1273$full$$,$APP.$cljs$core$_persistent_BANG_$$($G__54881$jscomp$inline_9578_full_acc$jscomp$inline_9570$$)],null);break a}$map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$=void 0}$full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$);$map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$,$APP.$cljs$cst$2229$thumbnails$$);
$full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$,$APP.$cljs$cst$1273$full$$);$app$render_wasm$api$process_pending_no_sideffects$$($map__54201_shapes$jscomp$28_thumbnails$jscomp$5$$,$full$jscomp$5_map__54201__$1_total_shapes$jscomp$1$$,$set_objects_cb$$)};
$app$main$data$viewer$apply_changes_viewer$$=function($changes$jscomp$323$$){typeof $app$main$data$viewer$apply_changes_viewer_73971$$==="undefined"&&($app$main$data$viewer$apply_changes_viewer_73971$$=function($changes$jscomp$324$$,$meta73972$$){this.$changes$=$changes$jscomp$324$$;this.$meta73972$=$meta73972$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$apply_changes_viewer_73971$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$apply_changes_viewer_73971$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5240$app_DOT_main_DOT_data_DOT_viewer_SLASH_apply_changes_viewer$$},$app$main$data$viewer$apply_changes_viewer_73971$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73973$$,$meta73972__$1$$){return new $app$main$data$viewer$apply_changes_viewer_73971$$(this.$changes$,$meta73972__$1$$)},$app$main$data$viewer$apply_changes_viewer_73971$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73972$},$app$main$data$viewer$apply_changes_viewer_73971$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$apply_changes_viewer_73971$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2879_pages$jscomp$8$$,$state$jscomp$1093$$){var $file$jscomp$144$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1093$$,
$APP.$cljs$cst$1592$viewer$$),$APP.$cljs$cst$208$file$$),$APP.$cljs$cst$142$data$$,$APP.$app$common$files$changes$process_changes$$,this.$changes$,!1);$_$jscomp$2879_pages$jscomp$8$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($page_id$jscomp$384$$){var $data$jscomp$445$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$144$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$384$$],null)),$JSCompiler_temp_const$jscomp$2008$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$2006$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$2009_objects$jscomp$inline_9580$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$445$$);$JSCompiler_inline_result$jscomp$2009_objects$jscomp$inline_9580$$=
$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2009_objects$jscomp$inline_9580$$,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$2008$$,[$page_id$jscomp$384$$,$JSCompiler_temp_const$jscomp$2006$$.call($APP.$cljs$core$assoc$$,$data$jscomp$445$$,$APP.$cljs$cst$5241$frames$$,$JSCompiler_inline_result$jscomp$2009_objects$jscomp$inline_9580$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5242$all_frames$$,
$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$445$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2088$all_frames_QMARK_$$,!0],null))]))],null)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$144$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2228$pages$$)));return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1093$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$208$file$$],null),$file$jscomp$144$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$],null),$_$jscomp$2879_pages$jscomp$8$$)});return new $app$main$data$viewer$apply_changes_viewer_73971$$($changes$jscomp$323$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$update_page_position_data$$=function($file_id$jscomp$343$$,$page_id$jscomp$386$$){typeof $app$main$data$viewer$update_page_position_data_73977$$==="undefined"&&($app$main$data$viewer$update_page_position_data_73977$$=function($file_id$jscomp$344$$,$page_id$jscomp$387$$,$meta73978$$){this.$file_id$=$file_id$jscomp$344$$;this.$page_id$=$page_id$jscomp$387$$;this.$meta73978$=$meta73978$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$viewer$update_page_position_data_73977$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$update_page_position_data_73977$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5243$app_DOT_main_DOT_data_DOT_viewer_SLASH_update_page_position_data$$},$app$main$data$viewer$update_page_position_data_73977$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73979$$,$meta73978__$1$$){return new $app$main$data$viewer$update_page_position_data_73977$$(this.$file_id$,
this.$page_id$,$meta73978__$1$$)},$app$main$data$viewer$update_page_position_data_73977$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73978$},$app$main$data$viewer$update_page_position_data_73977$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$update_page_position_data_73977$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2880_objects$jscomp$701_set_objects_stream$$,$state$jscomp$1094$$){var $self__$jscomp$7100$$=
this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$1094$$,"render-wasm/v1")){$_$jscomp$2880_objects$jscomp$701_set_objects_stream$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1094$$,$self__$jscomp$7100$$.$file_id$,$self__$jscomp$7100$$.$page_id$);var $shapes$jscomp$149$$=$APP.$cljs$core$reduce_kv$$(function($result$jscomp$330$$,$___$3$jscomp$235$$,$shape$jscomp$895$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$895$$)&&
$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$895$$)==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$330$$,$shape$jscomp$895$$):$result$jscomp$330$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$_$jscomp$2880_objects$jscomp$701_set_objects_stream$$);$_$jscomp$2880_objects$jscomp$701_set_objects_stream$$=$APP.$beicon$v2$core$create$$(function($subs$jscomp$20$$){$APP.$app$render_wasm$api$init_canvas_context$$(new OffscreenCanvas(0,0));$app$render_wasm$api$set_objects_callback$$($shapes$jscomp$149$$,
function(){return $subs$jscomp$20$$.next($APP.$cljs$cst$4765$done$$)});return null});return $APP.$app$common$data$not_empty_QMARK_$$($shapes$jscomp$149$$)?$APP.$beicon$v2$core$mapcat$$(function(){var $changes$jscomp$325$$=$app$main$data$viewer$generate_update_position_data_changes$$($shapes$jscomp$149$$,$self__$jscomp$7100$$.$page_id$);$APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $APP.$app$common$data$not_empty_QMARK_$$($changes$jscomp$325$$)?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$apply_changes_viewer$$($changes$jscomp$325$$)):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$constantly$$($_$jscomp$2880_objects$jscomp$701_set_objects_stream$$),$APP.$beicon$v2$core$from$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$module$$)))):$APP.$beicon$v2$core$empty$$()}return $APP.$beicon$v2$core$empty$$()});return new $app$main$data$viewer$update_page_position_data_73977$$($file_id$jscomp$343$$,$page_id$jscomp$386$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$bundle_fetched$$=function($p__73983$$){var $map__73984__$1$$=$APP.$cljs$core$__destructure_map$$($p__73983$$),$project$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$2230$project$$),$file$jscomp$145$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$208$file$$),$team$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$2492$team$$),$share_links$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$2176$share_links$$),$libraries$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$5244$libraries$$),$users$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$5245$users$$),$permissions$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$1722$permissions$$),$thumbnails$jscomp$16$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73984__$1$$,$APP.$cljs$cst$2229$thumbnails$$),$pages$jscomp$9$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($page_id$jscomp$388$$){var $data$jscomp$446$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$145$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$388$$],null)),$JSCompiler_temp_const$jscomp$2012$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$2010$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$2013_objects$jscomp$inline_9582$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$446$$);$JSCompiler_inline_result$jscomp$2013_objects$jscomp$inline_9582$$=$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2013_objects$jscomp$inline_9582$$,
null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$2012$$,[$page_id$jscomp$388$$,$JSCompiler_temp_const$jscomp$2010$$.call($APP.$cljs$core$assoc$$,$data$jscomp$446$$,$APP.$cljs$cst$5241$frames$$,$JSCompiler_inline_result$jscomp$2013_objects$jscomp$inline_9582$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5242$all_frames$$,$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$446$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2088$all_frames_QMARK_$$,!0],null))]))],null)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$145$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2228$pages$$)));typeof $app$main$data$viewer$bundle_fetched_73991$$==="undefined"&&($app$main$data$viewer$bundle_fetched_73991$$=function($users$jscomp$2$$,$permissions$jscomp$28$$,$libraries$jscomp$126$$,$p__73983$jscomp$1$$,
$file$jscomp$146$$,$bundle$jscomp$6$$,$thumbnails$jscomp$17$$,$pages$jscomp$10$$,$project$jscomp$16$$,$team$jscomp$43$$,$map__73984$jscomp$1$$,$share_links$jscomp$1$$,$meta73992$$){this.users=$users$jscomp$2$$;this.permissions=$permissions$jscomp$28$$;this.libraries=$libraries$jscomp$126$$;this.$p__73983$=$p__73983$jscomp$1$$;this.file=$file$jscomp$146$$;this.$bundle$=$bundle$jscomp$6$$;this.$thumbnails$=$thumbnails$jscomp$17$$;this.$pages$=$pages$jscomp$10$$;this.project=$project$jscomp$16$$;this.team=
$team$jscomp$43$$;this.$map__73984$=$map__73984$jscomp$1$$;this.$share_links$=$share_links$jscomp$1$$;this.$meta73992$=$meta73992$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$bundle_fetched_73991$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$bundle_fetched_73991$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5246$app_DOT_main_DOT_data_DOT_viewer_SLASH_bundle_fetched$$},
$app$main$data$viewer$bundle_fetched_73991$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73993$$,$meta73992__$1$$){return new $app$main$data$viewer$bundle_fetched_73991$$(this.users,this.permissions,this.libraries,this.$p__73983$,this.file,this.$bundle$,this.$thumbnails$,this.$pages$,this.project,this.team,this.$map__73984$,this.$share_links$,$meta73992__$1$$)},$app$main$data$viewer$bundle_fetched_73991$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73992$},
$app$main$data$viewer$bundle_fetched_73991$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$bundle_fetched_73991$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2881_team_id$jscomp$130$$,$state$jscomp$1095$$){$_$jscomp$2881_team_id$jscomp$130$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.team);var $team__$1$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.team,$APP.$cljs$cst$3264$members$$,
this.users);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1095$$,$APP.$cljs$cst$2176$share_links$$,this.$share_links$),$APP.$cljs$cst$1926$current_team_id$$,$_$jscomp$2881_team_id$jscomp$130$$),$APP.$cljs$cst$2173$teams$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$_$jscomp$2881_team_id$jscomp$130$$,
$team__$1$jscomp$1$$])),$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.libraries),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.file),this.file)),$APP.$cljs$cst$1592$viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$5244$libraries$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.libraries),
$APP.$cljs$cst$5245$users$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.users),$APP.$cljs$cst$1722$permissions$$,this.permissions,$APP.$cljs$cst$2230$project$$,this.project,$APP.$cljs$cst$2228$pages$$,this.$pages$,$APP.$cljs$cst$2229$thumbnails$$,this.$thumbnails$,$APP.$cljs$cst$208$file$$,this.file],null))},$app$main$data$viewer$bundle_fetched_73991$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$bundle_fetched_73991$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2882_index$jscomp$389_route$jscomp$10$$,$frame_id$jscomp$117_state$jscomp$1096$$){$_$jscomp$2882_index$jscomp$389_route$jscomp$10$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$117_state$jscomp$1096$$);var $qparams$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2882_index$jscomp$389_route$jscomp$10$$);$_$jscomp$2882_index$jscomp$389_route$jscomp$10$$=function(){var $G__74000$$=$APP.$app$main$router$get_query_param$$($qparams$$,
$APP.$cljs$cst$1795$index$$);return $G__74000$$==null?null:$APP.$cljs$core$parse_long$$($G__74000$$)}();$frame_id$jscomp$117_state$jscomp$1096$$=function(){var $G__74002$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$$);return $G__74002$$==null?null:$APP.$app$common$uuid$parse$$($G__74002$$)}();var $page_id$jscomp$389$$=function(){var $G__74004$$=$APP.$app$main$router$get_query_param$$($qparams$$,$APP.$cljs$cst$2043$page_id$$);return $G__74004$$==null?null:$APP.$app$common$uuid$parse$$($G__74004$$)}(),
$file_id$jscomp$345$$=function(){var $G__74005$$=$APP.$app$main$router$get_query_param$$($qparams$$,$APP.$cljs$cst$1644$file_id$$);return $G__74005$$==null?null:$APP.$app$common$uuid$parse$$($G__74005$$)}();return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)(function(){switch($APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($qparams$$)){case "fit":return $APP.$app$main$data$viewer$zoom_to_fit$$;case "fill":return $APP.$app$main$data$viewer$zoom_to_fill$$;default:return null}}()),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$update_page_position_data$$($file_id$jscomp$345$$,$page_id$jscomp$389$$),$frame_id$jscomp$117_state$jscomp$1096$$!=null?$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$?$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$($frame_id$jscomp$117_state$jscomp$1096$$):$app$main$data$viewer$go_to_frame$$($frame_id$jscomp$117_state$jscomp$1096$$):$_$jscomp$2882_index$jscomp$389_route$jscomp$10$$!=null?$APP.$app$main$data$viewer$go_to_frame_by_index$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$main$data$viewer$go_to_frame_by_index$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2882_index$jscomp$389_route$jscomp$10$$):$APP.$app$main$data$viewer$go_to_frame_by_index$$($_$jscomp$2882_index$jscomp$389_route$jscomp$10$$):$app$main$data$viewer$go_to_frame_auto$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$viewer$go_to_frame_auto$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$viewer$go_to_frame_auto$$()))});return new $app$main$data$viewer$bundle_fetched_73991$$($users$jscomp$1$$,
$permissions$jscomp$27$$,$libraries$jscomp$125$$,$p__73983$$,$file$jscomp$145$$,$map__73984__$1$$,$thumbnails$jscomp$16$$,$pages$jscomp$9$$,$project$jscomp$15$$,$team$jscomp$42$$,$map__73984__$1$$,$share_links$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$fetch_bundle$$=function($p__73937$$){var $map__73938__$1$$=$APP.$cljs$core$__destructure_map$$($p__73937$$),$file_id$jscomp$341$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73938__$1$$,$APP.$cljs$cst$1644$file_id$$),$share_id$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73938__$1$$,$APP.$cljs$cst$3237$share_id$$);typeof $app$main$data$viewer$fetch_bundle_73939$$==="undefined"&&($app$main$data$viewer$fetch_bundle_73939$$=function($p__73937$jscomp$1$$,
$map__73938$jscomp$1$$,$params$jscomp$382$$,$file_id$jscomp$342$$,$share_id$jscomp$19$$,$meta73940$$){this.$p__73937$=$p__73937$jscomp$1$$;this.$map__73938$=$map__73938$jscomp$1$$;this.params=$params$jscomp$382$$;this.$file_id$=$file_id$jscomp$342$$;this.$share_id$=$share_id$jscomp$19$$;this.$meta73940$=$meta73940$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$fetch_bundle_73939$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$fetch_bundle_73939$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5238$app_DOT_main_DOT_data_DOT_viewer_SLASH_fetch_bundle$$},$app$main$data$viewer$fetch_bundle_73939$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73941$$,$meta73940__$1$$){return new $app$main$data$viewer$fetch_bundle_73939$$(this.$p__73937$,this.$map__73938$,this.params,this.$file_id$,this.$share_id$,$meta73940__$1$$)},$app$main$data$viewer$fetch_bundle_73939$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73940$},$app$main$data$viewer$fetch_bundle_73939$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$fetch_bundle_73939$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){function $resolve$jscomp$40$$($p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$){var $key$jscomp$394$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$,0,null);$p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$,1,null);$p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$7092$$.$file_id$,$APP.$cljs$cst$3899$fragment_id$$,$APP.$cljs$core$_deref$$($p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$)],null);$p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$=$APP.$cljs$core$uuid_QMARK_$$($self__$jscomp$7092$$.$share_id$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$,$APP.$cljs$cst$3237$share_id$$,$self__$jscomp$7092$$.$share_id$):$p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$;return $APP.$beicon$v2$core$map$$(function($p1__73936_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$394$$,$p1__73936_SHARP_$$],null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$142$data$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3898$get_file_fragment$$,$p__73945_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$)))}var $self__$jscomp$7092$$=this,$params_SINGLEQUOTE_$$=function(){var $G__73944$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$7092$$.$file_id$,$APP.$cljs$cst$227$features$$,$APP.$app$common$features$supported_features$$],null);return $APP.$cljs$core$uuid_QMARK_$$($self__$jscomp$7092$$.$share_id$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73944$$,$APP.$cljs$cst$3237$share_id$$,$self__$jscomp$7092$$.$share_id$):$G__73944$$}();return $APP.$beicon$v2$core$mapcat$$(function($JSCompiler_temp_const$jscomp$2015_fonts$jscomp$27_p__73950$$){var $G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$2015_fonts$jscomp$27_p__73950$$);$JSCompiler_temp_const$jscomp$2015_fonts$jscomp$27_p__73950$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$,$APP.$cljs$cst$2969$fonts$$);var $JSCompiler_temp_const$jscomp$2014_team$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$,$APP.$cljs$cst$2492$team$$);$JSCompiler_temp_const$jscomp$2015_fonts$jscomp$27_p__73950$$=$APP.$app$main$data$fonts$fonts_fetched$$($JSCompiler_temp_const$jscomp$2015_fonts$jscomp$27_p__73950$$);
$JSCompiler_temp_const$jscomp$2014_team$jscomp$41$$=$APP.$app$main$features$initialize$$($APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$2014_team$jscomp$41$$));$G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$,$self__$jscomp$7092$$.params]));
$G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$=$app$main$data$viewer$bundle_fetched$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$viewer$bundle_fetched$$.$cljs$core$IFn$_invoke$arity$1$($G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$):$app$main$data$viewer$bundle_fetched$$($G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$2015_fonts$jscomp$27_p__73950$$,
$JSCompiler_temp_const$jscomp$2014_team$jscomp$41$$,$G__73954$jscomp$inline_9584_JSCompiler_inline_result$jscomp$2016_map__73951__$1$$)},$APP.$beicon$v2$core$mapcat$$(function($bundle$jscomp$3$$){return $APP.$beicon$v2$core$map$$(function($data$jscomp$444$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($bundle$jscomp$3$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$142$data$$,$data$jscomp$444$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__73959$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73959$$,0,null);var $object$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73959$$,1,null);return $APP.$app$common$transit$pointer_QMARK_$$($object$jscomp$38$$)?$resolve$jscomp$40$$($p__73959$$):(0,$APP.$beicon$v2$core$of$$)($p__73959$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($bundle$jscomp$3$$)))))))},
$APP.$beicon$v2$core$mapcat$$(function($bundle$jscomp$4$$){return $APP.$beicon$v2$core$map$$(function($pages_index$jscomp$2$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($bundle$jscomp$4$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1630$pages_index$$,$pages_index$jscomp$2$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__73965$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73965$$,0,null);var $page$jscomp$150$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73965$$,1,null);return $APP.$app$common$transit$pointer_QMARK_$$($page$jscomp$150$$)?$resolve$jscomp$40$$($p__73965$$):(0,$APP.$beicon$v2$core$of$$)($p__73965$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($bundle$jscomp$4$$))))))))},
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5239$get_view_only_bundle$$,$params_SINGLEQUOTE_$$))))});return new $app$main$data$viewer$fetch_bundle_73939$$($p__73937$$,$map__73938__$1$$,$map__73938__$1$$,$file_id$jscomp$341$$,$share_id$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$initialize$$=function($p__73916$$){var $map__73918__$1$$=$APP.$cljs$core$__destructure_map$$($p__73916$$),$file_id$jscomp$339$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73918__$1$$,$APP.$cljs$cst$1644$file_id$$),$share_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73918__$1$$,$APP.$cljs$cst$3237$share_id$$);typeof $app$main$data$viewer$initialize_73923$$==="undefined"&&($app$main$data$viewer$initialize_73923$$=function($p__73916$jscomp$1$$,
$map__73918$jscomp$1$$,$params$jscomp$380$$,$file_id$jscomp$340$$,$share_id$jscomp$17$$,$meta73924$$){this.$p__73916$=$p__73916$jscomp$1$$;this.$map__73918$=$map__73918$jscomp$1$$;this.params=$params$jscomp$380$$;this.$file_id$=$file_id$jscomp$340$$;this.$share_id$=$share_id$jscomp$17$$;this.$meta73924$=$meta73924$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5236$app_DOT_main_DOT_data_DOT_viewer_SLASH_initialize$$},$app$main$data$viewer$initialize_73923$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73925$$,$meta73924__$1$$){return new $app$main$data$viewer$initialize_73923$$(this.$p__73916$,this.$map__73918$,this.params,this.$file_id$,this.$share_id$,$meta73924__$1$$)},$app$main$data$viewer$initialize_73923$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73924$},$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2873$$,$state$jscomp$1090$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1090$$,
$APP.$cljs$cst$1917$current_file_id$$,this.$file_id$),$APP.$cljs$cst$3484$current_share_id$$,this.$share_id$),$APP.$cljs$cst$2231$viewer_local$$,function($lstate$jscomp$1$$){return $lstate$jscomp$1$$==null?$APP.$app$main$data$viewer$default_local_state$$:$lstate$jscomp$1$$}),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$3237$share_id$$],null),this.$share_id$)},$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__73930$jscomp$inline_9586_JSCompiler_inline_result$jscomp$2017__$jscomp$2874$$,$state$jscomp$1091$$){$G__73930$jscomp$inline_9586_JSCompiler_inline_result$jscomp$2017__$jscomp$2874$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(this.params);$G__73930$jscomp$inline_9586_JSCompiler_inline_result$jscomp$2017__$jscomp$2874$$=$app$main$data$viewer$fetch_bundle$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$viewer$fetch_bundle$$.$cljs$core$IFn$_invoke$arity$1$($G__73930$jscomp$inline_9586_JSCompiler_inline_result$jscomp$2017__$jscomp$2874$$):$app$main$data$viewer$fetch_bundle$$($G__73930$jscomp$inline_9586_JSCompiler_inline_result$jscomp$2017__$jscomp$2874$$);return(0,$APP.$beicon$v2$core$of$$)($G__73930$jscomp$inline_9586_JSCompiler_inline_result$jscomp$2017__$jscomp$2874$$,$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1091$$)!=null?$app$main$data$viewer$fetch_comment_threads$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$viewer$fetch_comment_threads$$.$cljs$core$IFn$_invoke$arity$1$(this.params):$app$main$data$viewer$fetch_comment_threads$$(this.params):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$(this.params))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"shared-prototipe-visited"],null))):null)},$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$initialize_73923$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $name$jscomp$421$$=["viewer-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$file_id$)].join("");return $APP.$app$util$globals$global$$.name=$name$jscomp$421$$});return new $app$main$data$viewer$initialize_73923$$($p__73916$$,$map__73918__$1$$,$map__73918__$1$$,$file_id$jscomp$339$$,$share_id$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$viewer$comments$comments_sidebar_STAR_$$=function($page$jscomp$155_props_75293$$){var $profiles$jscomp$2$$=$page$jscomp$155_props_75293$$.profiles,$frame$jscomp$57$$=$page$jscomp$155_props_75293$$.frame;$page$jscomp$155_props_75293$$=$page$jscomp$155_props_75293$$.page;var $profile$jscomp$62_threads$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$local$jscomp$29$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$threads_map$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$);
$profile$jscomp$62_threads$jscomp$11$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__75304__$1_p__75303_position$jscomp$189$$){$map__75304__$1_p__75303_position$jscomp$189$$=$APP.$cljs$core$__destructure_map$$($map__75304__$1_p__75303_position$jscomp$189$$);$map__75304__$1_p__75303_position$jscomp$189$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75304__$1_p__75303_position$jscomp$189$$,$APP.$cljs$cst$1676$position$$);return $APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$($frame$jscomp$57$$,
$map__75304__$1_p__75303_position$jscomp$189$$)},$APP.$app$main$data$comments$apply_filters$$($local$jscomp$29$$,$profile$jscomp$62_threads$jscomp$11$$,$APP.$cljs$core$vals$$($threads_map$jscomp$5$$)));return(0,$APP.$rumext$v2$jsx$$)("aside",{className:"main_ui_viewer_comments__comments-sidebar",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_comments__settings-bar-inside",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$comments$comments_sidebar_STAR_$$,{fromViewer:!0,
profiles:$profiles$jscomp$2$$,threads:$profile$jscomp$62_threads$jscomp$11$$,pageId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$155_props_75293$$)})})})};
$app$main$ui$inspect$left_sidebar$make_collapsed_iref$$=function($id$jscomp$1076$$){return function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2048$collapsed$$,$id$jscomp$1076$$],null)),$APP.$app$main$store$state$$)}};
$app$main$ui$inspect$left_sidebar$left_sidebar$$=function($frame$jscomp$99_map__82923_props_82922$$){$frame$jscomp$99_map__82923_props_82922$$=$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$99_map__82923_props_82922$$);var $local$jscomp$35_map__82923__$1_selected$jscomp$219$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$99_map__82923_props_82922$$);$frame$jscomp$99_map__82923_props_82922$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$35_map__82923__$1_selected$jscomp$219$$,
$APP.$cljs$cst$1606$frame$$);var $objects$jscomp$841_page$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$35_map__82923__$1_selected$jscomp$219$$,$APP.$cljs$cst$1624$page$$);$local$jscomp$35_map__82923__$1_selected$jscomp$219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$35_map__82923__$1_selected$jscomp$219$$,$APP.$cljs$cst$2883$local$$);$local$jscomp$35_map__82923__$1_selected$jscomp$219$$=$APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$35_map__82923__$1_selected$jscomp$219$$);
$objects$jscomp$841_page$jscomp$178$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$841_page$jscomp$178$$);return(0,$APP.$rumext$v2$jsx$$)("aside",{className:"main_ui_inspect_left_sidebar__settings-bar-left",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_left_sidebar__settings-bar-inside",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_left_sidebar__element-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$left_sidebar$layer_item$$,
{item:$frame$jscomp$99_map__82923_props_82922$$,selected:$local$jscomp$35_map__82923__$1_selected$jscomp$219$$,index:0,objects:$objects$jscomp$841_page$jscomp$178$$,"sortable?":!1,"filtered?":!1,depth:-2,"hide-toggle?":!0})})})})};
$app$main$ui$inspect$render$handle_hover_shape$$=function($shape$jscomp$1109$$,$hover_QMARK_$jscomp$15$$){return function($event$jscomp$765$$){if($APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1109$$)||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1109$$))return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$765$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$765$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$hover_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1109$$),
$hover_QMARK_$jscomp$15$$))}};
$app$main$ui$inspect$render$select_shape$$=function($shape$jscomp$1110$$){return function($event$jscomp$766$$){if($APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1110$$)||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1110$$))return null;$APP.$app$util$dom$stop_propagation$$($event$jscomp$766$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$766$$);return $APP.$cljs$core$truth_$$($event$jscomp$766$$.shiftKey)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1110$$))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1110$$)))}};
$app$main$ui$inspect$render$shape_wrapper_factory$$=function($component$jscomp$138$$){return function($frame$jscomp$100_props_82924$$){var $shape$jscomp$1111$$=$frame$jscomp$100_props_82924$$.shape,$childs$jscomp$26$$=$frame$jscomp$100_props_82924$$.childs;$frame$jscomp$100_props_82924$$=$frame$jscomp$100_props_82924$$.frame;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1111$$))||
$APP.$cljs$core$contains_QMARK_$$($APP.$app$main$ui$shapes$svg_raw$graphic_element$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1111$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$78$tag$$],null)))?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape$jscomp$1111$$,onPointerEnter:$app$main$ui$inspect$render$handle_hover_shape$$($shape$jscomp$1111$$,
!0),onPointerLeave:$app$main$ui$inspect$render$handle_hover_shape$$($shape$jscomp$1111$$,!1),onClick:$app$main$ui$inspect$render$select_shape$$($shape$jscomp$1111$$),children:(0,$APP.$rumext$v2$jsx$$)($component$jscomp$138$$,{shape:$shape$jscomp$1111$$,frame:$frame$jscomp$100_props_82924$$,childs:$childs$jscomp$26$$,"is-child-selected?":!0})}):(0,$APP.$rumext$v2$jsx$$)($component$jscomp$138$$,{shape:$shape$jscomp$1111$$,frame:$frame$jscomp$100_props_82924$$,childs:$childs$jscomp$26$$})}};
$app$main$ui$inspect$render$frame_container_factory$$=function($objects$jscomp$842$$){var $shape_container$jscomp$8$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$842$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$842$$),$frame_wrapper$jscomp$3$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$frame$frame_shape$$($shape_container$jscomp$8$$));
return $APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_82927_props__$1$jscomp$108$$){var $shape$jscomp$1112$$=$props_82927_props__$1$jscomp$108$$.shape,$childs$jscomp$27$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82926_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$842$$,$p1__82926_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1112$$));$props_82927_props__$1$jscomp$108$$=
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},$props_82927_props__$1$jscomp$108$$),{shape:$shape$jscomp$1112$$,childs:$childs$jscomp$27$$});return(0,$APP.$rumext$v2$create_element$$)($frame_wrapper$jscomp$3$$,$props_82927_props__$1$jscomp$108$$)})};
$app$main$ui$inspect$render$group_container_factory$$=function($objects$jscomp$843$$){var $shape_container$jscomp$9$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$843$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$843$$),$group_wrapper$jscomp$3$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$group$group_shape$$($shape_container$jscomp$9$$));
return function($props_82930_props__$1$jscomp$109$$){var $childs$jscomp$28$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82929_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$843$$,$p1__82929_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_82930_props__$1$jscomp$109$$.shape));$props_82930_props__$1$jscomp$109$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},
$props_82930_props__$1$jscomp$109$$),{childs:$childs$jscomp$28$$});return(0,$APP.$rumext$v2$create_element$$)($group_wrapper$jscomp$3$$,$props_82930_props__$1$jscomp$109$$)}};
$app$main$ui$inspect$render$bool_container_factory$$=function($objects$jscomp$844$$){var $shape_container$jscomp$10$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$844$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$844$$),$bool_wrapper$jscomp$2$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$bool$bool_shape$$($shape_container$jscomp$10$$));
return function($props_82932_props__$1$jscomp$110$$){var $children$jscomp$316$$=$APP.$cljs$core$select_keys$$($objects$jscomp$844$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$844$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_82932_props__$1$jscomp$110$$.shape)));$props_82932_props__$1$jscomp$110$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},
$props_82932_props__$1$jscomp$110$$),{childs:$children$jscomp$316$$});return(0,$APP.$rumext$v2$create_element$$)($bool_wrapper$jscomp$2$$,$props_82932_props__$1$jscomp$110$$)}};
$app$main$ui$inspect$render$svg_raw_container_factory$$=function($objects$jscomp$845$$){var $shape_container$jscomp$11$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$845$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$845$$),$svg_raw_wrapper$jscomp$2$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$svg_raw$svg_raw_shape$$($shape_container$jscomp$11$$));
return function($props_82935_props__$1$jscomp$111$$){var $childs$jscomp$29$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82934_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$845$$,$p1__82934_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_82935_props__$1$jscomp$111$$.shape));$props_82935_props__$1$jscomp$111$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},
$props_82935_props__$1$jscomp$111$$),{childs:$childs$jscomp$29$$});return(0,$APP.$rumext$v2$create_element$$)($svg_raw_wrapper$jscomp$2$$,$props_82935_props__$1$jscomp$111$$)}};
$app$main$ui$inspect$render$shape_container_factory$$=function($objects$jscomp$846$$){var $path_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$path$path_shape$$),$text_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$text$text_shape$$),$rect_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$rect$rect_shape$$),$image_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$image$image_shape$$),
$circle_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$circle$circle_shape$$);return function($frame_container$jscomp$1_props_82937$$){var $opts$jscomp$312_shape$jscomp$1116$$=$frame_container$jscomp$1_props_82937$$.shape,$G__82939_G__82939__$1_frame$jscomp$101$$=$frame_container$jscomp$1_props_82937$$.frame;$frame_container$jscomp$1_props_82937$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$846$$)],
function(){return $app$main$ui$inspect$render$frame_container_factory$$($objects$jscomp$846$$)});var $group_container$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$846$$)],function(){return $app$main$ui$inspect$render$group_container_factory$$($objects$jscomp$846$$)}),$bool_container$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$846$$)],function(){return $app$main$ui$inspect$render$bool_container_factory$$($objects$jscomp$846$$)}),
$svg_raw_container$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$846$$)],function(){return $app$main$ui$inspect$render$svg_raw_container_factory$$($objects$jscomp$846$$)});if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($opts$jscomp$312_shape$jscomp$1116$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$312_shape$jscomp$1116$$)):$opts$jscomp$312_shape$jscomp$1116$$)){var $shape__$1$jscomp$121$$=
$APP.$cljs$core$truth_$$($G__82939_G__82939__$1_frame$jscomp$101$$)?$APP.$app$common$geom$shapes$translate_to_frame$$($opts$jscomp$312_shape$jscomp$1116$$,$G__82939_G__82939__$1_frame$jscomp$101$$):$opts$jscomp$312_shape$jscomp$1116$$;$opts$jscomp$312_shape$jscomp$1116$$={shape:$shape__$1$jscomp$121$$,frame:$G__82939_G__82939__$1_frame$jscomp$101$$};$G__82939_G__82939__$1_frame$jscomp$101$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$121$$);$G__82939_G__82939__$1_frame$jscomp$101$$=
$G__82939_G__82939__$1_frame$jscomp$101$$ instanceof $APP.$cljs$core$Keyword$$?$G__82939_G__82939__$1_frame$jscomp$101$$.$fqn$:null;switch($G__82939_G__82939__$1_frame$jscomp$101$$){case "frame":return(0,$APP.$rumext$v2$create_element$$)($frame_container$jscomp$1_props_82937$$,$opts$jscomp$312_shape$jscomp$1116$$);case "text":return(0,$APP.$rumext$v2$create_element$$)($text_wrapper$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);case "rect":return(0,$APP.$rumext$v2$create_element$$)($rect_wrapper$jscomp$1$$,
$opts$jscomp$312_shape$jscomp$1116$$);case "path":return(0,$APP.$rumext$v2$create_element$$)($path_wrapper$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);case "image":return(0,$APP.$rumext$v2$create_element$$)($image_wrapper$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);case "circle":return(0,$APP.$rumext$v2$create_element$$)($circle_wrapper$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);case "group":return(0,$APP.$rumext$v2$create_element$$)($group_container$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);
case "bool":return(0,$APP.$rumext$v2$create_element$$)($bool_container$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);case "svg-raw":return(0,$APP.$rumext$v2$create_element$$)($svg_raw_container$jscomp$1$$,$opts$jscomp$312_shape$jscomp$1116$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__82939_G__82939__$1_frame$jscomp$101$$)].join(""));}}else return null}};
$app$main$ui$inspect$render$render_frame_svg$$=function($local$jscomp$36_map__82943_props_82941$$){$local$jscomp$36_map__82943_props_82941$$=$APP.$rumext$v2$util$wrap_props$$($local$jscomp$36_map__82943_props_82941$$);var $frame__$1$jscomp$9_map__82943__$1$$=$APP.$cljs$core$__destructure_map$$($local$jscomp$36_map__82943_props_82941$$),$page$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$9_map__82943__$1$$,$APP.$cljs$cst$1624$page$$),$frame$jscomp$102$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$9_map__82943__$1$$,
$APP.$cljs$cst$1606$frame$$);$local$jscomp$36_map__82943_props_82941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$9_map__82943__$1$$,$APP.$cljs$cst$2883$local$$);var $size$jscomp$163$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$9_map__82943__$1$$,$APP.$cljs$cst$874$size$$),$objects$jscomp$847$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$179$$),$APP.$rumext$v2$adapt$$($frame$jscomp$102$$),
$APP.$rumext$v2$adapt$$($size$jscomp$163$$)],function(){return $APP.$app$main$ui$viewer$interactions$prepare_objects$$($frame$jscomp$102$$,$size$jscomp$163$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$179$$))});$frame__$1$jscomp$9_map__82943__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$847$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$102$$));
var $render$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$847$$)],function(){return $app$main$ui$inspect$render$frame_container_factory$$($objects$jscomp$847$$)});return(0,$APP.$rumext$v2$jsxs$$)("svg",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$163$$),xmlns:"http://www.w3.org/2000/svg",height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$163$$),children:[(0,$APP.$rumext$v2$jsx$$)($render$jscomp$2$$,
{shape:$frame__$1$jscomp$9_map__82943__$1$$,"view-box":$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$163$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$selection_feedback$selection_feedback$$,{frame:$frame__$1$jscomp$9_map__82943__$1$$,objects:$objects$jscomp$847$$,local:$local$jscomp$36_map__82943_props_82941$$,size:$size$jscomp$163$$})],id:"svg-frame",viewBox:$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$163$$),xmlnsXlink:"http://www.w3.org/1999/xlink",
fill:"none",version:"1.1"})};
$app$main$ui$viewer$inspect$handle_select_frame$$=function($event$jscomp$767$$){var $frame_id$jscomp$158$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$767$$),"value")),$over_section_QMARK_$$=$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$767$$),"inspect-svg-container"),$layout$jscomp$35$$=$APP.$goog$dom$getElement$$("viewer-layout"),$has_force_QMARK_$$=$APP.$app$util$dom$class_QMARK_$$($layout$jscomp$35$$,"force-visible");
$APP.$app$util$dom$prevent_default$$($event$jscomp$767$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$767$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($frame_id$jscomp$158$$));return $over_section_QMARK_$$?$has_force_QMARK_$$?$layout$jscomp$35$$!=null?$layout$jscomp$35$$.classList.remove("force-visible"):null:$APP.$app$util$dom$add_class_BANG_$$($layout$jscomp$35$$,"force-visible"):null};
$app$main$ui$viewer$inspect$viewport$$=function($local$jscomp$37_map__82956_props_82955$$){function $on_mouse_wheel$jscomp$3$$($event$jscomp$768_event__$1$jscomp$8$$){return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$768_event__$1$jscomp$8$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$768_event__$1$jscomp$8$$),$event$jscomp$768_event__$1$jscomp$8$$=$event$jscomp$768_event__$1$jscomp$8$$.getBrowserEvent(),$event$jscomp$768_event__$1$jscomp$8$$.deltaY+$event$jscomp$768_event__$1$jscomp$8$$.deltaX>
0?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$decrease_zoom$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$increase_zoom$$)):null}$local$jscomp$37_map__82956_props_82955$$=$APP.$rumext$v2$util$wrap_props$$($local$jscomp$37_map__82956_props_82955$$);var $map__82956__$1_share_id$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($local$jscomp$37_map__82956_props_82955$$);$local$jscomp$37_map__82956_props_82955$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,$APP.$cljs$cst$2883$local$$);var $file$jscomp$200$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,$APP.$cljs$cst$208$file$$),$page$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,$APP.$cljs$cst$1624$page$$),$frame$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,
$APP.$cljs$cst$1606$frame$$),$index$jscomp$585$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,$APP.$cljs$cst$1795$index$$),$viewer_pagination$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,$cljs$cst$6322$viewer_pagination$$),$size$jscomp$164$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,$APP.$cljs$cst$874$size$$);$map__82956__$1_share_id$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82956__$1_share_id$jscomp$29$$,
$APP.$cljs$cst$3237$share_id$$);var $inspect_svg_container_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_section_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1161$info$$),$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$=$APP.$cljs$core$_deref$$($current_section_STAR_$jscomp$1$$);$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$,
$APP.$cljs$cst$273$code$$);var $map__82959_on_pointer_down$jscomp$24$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$273$code$$,318,318,768,$APP.$cljs$cst$1510$x$$,!0,$APP.$cljs$cst$258$right$$,null),$map__82959__$1_on_pointer_move$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($map__82959_on_pointer_down$jscomp$24$$),$set_right_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82959__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4546$set_size$$),
$right_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82959__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$874$size$$);$map__82959_on_pointer_down$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82959__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4542$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82959__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$);
$map__82959__$1_on_pointer_move$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82959__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4544$on_pointer_move$$);var $handle_change_section$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($section$jscomp$46$$){return $APP.$cljs$core$reset_BANG_$$($current_section_STAR_$jscomp$1$$,$section$jscomp$46$$)}),$handle_expand$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($right_size$$)],
function(){var $G__82960$$=$right_size$$>318?318:768;return $set_right_size$$.$cljs$core$IFn$_invoke$arity$1$?$set_right_size$$.$cljs$core$IFn$_invoke$arity$1$($G__82960$$):$set_right_size$$($G__82960$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $key1$jscomp$10$$=$APP.$goog$events$listen$$($APP.$goog$global$$,"wheel",$on_mouse_wheel$jscomp$3$$,{passive:!1});return function(){return $APP.$goog$events$unlistenByKey$$($key1$jscomp$10$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$103$$))],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$103$$)))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$left_sidebar$left_sidebar$$,{frame:$frame$jscomp$103$$,local:$local$jscomp$37_map__82956_props_82955$$,page:$page$jscomp$180$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{id:"inspect-svg-wrapper",
"data-value":$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$103$$)])),onClick:$app$main$ui$viewer$inspect$handle_select_frame$$,className:"main_ui_viewer_inspect__inspect-svg-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($viewer_pagination$$,{index:$index$jscomp$585$$,"num-frames":$APP.$cljs$core$count$$($APP.$cljs$cst$5241$frames$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$180$$)),
"left-bar":!0,"right-bar":!0}),(0,$APP.$rumext$v2$jsx$$)("div",{id:"inspect-svg-container",ref:$inspect_svg_container_ref$$,className:"main_ui_viewer_inspect__inspect-svg-container",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$render$render_frame_svg$$,{frame:$frame$jscomp$103$$,page:$page$jscomp$180$$,local:$local$jscomp$37_map__82956_props_82955$$,size:$size$jscomp$164$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--right-sidebar-width":$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?
""+($right_size$$??"")+"px":null},className:"main_ui_viewer_inspect__sidebar-container "+($can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?"":"main_ui_viewer_inspect__not-expand")+" "+($can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?"main_ui_viewer_inspect__expanded":""),children:[$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__82959_on_pointer_down$jscomp$24$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$12$$,
onPointerMove:$map__82959__$1_on_pointer_move$jscomp$18$$,className:"main_ui_viewer_inspect__resize-area"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$inspect$right_sidebar$right_sidebar_STAR_$$,{frame:$frame$jscomp$103$$,selected:$APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$37_map__82956_props_82955$$),page:$page$jscomp$180$$,file:$file$jscomp$200$$,onChangeSection:$handle_change_section$$,onExpand:$handle_expand$jscomp$1$$,shareId:$map__82956__$1_share_id$jscomp$29$$})]})]})};
$app$main$ui$viewer$login$login_register_modal$$=function($main_section_props_82942$$){function $success_register$jscomp$1$$($data$jscomp$513$$){$APP.$cljs$core$reset_BANG_$$($register_token$jscomp$1$$,$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$513$$));return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5408$register_validate$$):$set_current_section$$($APP.$cljs$cst$5408$register_validate$$)}
function $success_login$jscomp$1$$(){return window.location.reload(!0)}function $success_email_sent$$($email$jscomp$20$$){$APP.$cljs$core$reset_BANG_$$($user_email$jscomp$1$$,$email$jscomp$20$$);return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$6324$email_sent$$):$set_current_section$$($cljs$cst$6324$email_sent$$)}$APP.$rumext$v2$util$wrap_props$$($main_section_props_82942$$);var $user_email$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),
$register_token$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$current_section_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1172$login$$),$current_section$jscomp$3$$=$APP.$cljs$core$_deref$$($current_section_STAR_$jscomp$2$$),$set_current_section$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__82940_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($current_section_STAR_$jscomp$2$$,$p1__82940_SHARP_$$)}),
$set_section$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$769_section$jscomp$47$$){$event$jscomp$769_section$jscomp$47$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$769_section$jscomp$47$$),"value"));return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$769_section$jscomp$47$$):
$set_current_section$$($event$jscomp$769_section$jscomp$47$$)}),$go_back_to_login$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1172$login$$):$set_current_section$$($APP.$cljs$cst$1172$login$$)});$main_section_props_82942$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$3$$,$APP.$cljs$cst$1172$login$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$3$$,
$cljs$cst$6323$register$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$3$$,$APP.$cljs$cst$5408$register_validate$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_viewer_login__modal-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue-with-penpot")}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:function($event$jscomp$770$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$770$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())},className:"main_ui_viewer_login__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__modal-content",children:[function(){var $G__82951__$1$$=$current_section$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$current_section$jscomp$3$$.$fqn$:null;switch($G__82951__$1$$){case "login":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$login$login_dialog_STAR_$$,{onSuccessCallback:$success_login$jscomp$1$$,origin:$APP.$cljs$cst$1592$viewer$$}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__links",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__recovery-request",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"recovery-request",className:"main_ui_viewer_login__recovery-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.forgot-password")})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__register",children:[(0,$APP.$rumext$v2$jsxs$$)("span",
{className:"main_ui_viewer_login__register-text",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register")," "]}),(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"register",className:"main_ui_viewer_login__register-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register-submit")})]})]})]});case "register":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_methods_STAR_$$,
{onSuccessCallback:$success_register$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__links",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__account",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.already-have-account")," "]}),(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"login",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-here")})]})})]});
case "register-validate":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_validate_form_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$_deref$$($register_token$jscomp$1$$)],null),onSuccessCallback:$success_email_sent$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__links",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_viewer_login__register",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"register",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.go-back")})})})]});case "recovery-request":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$recovery_request$recovery_request_page$$,{"go-back-callback":$go_back_to_login$$,"on-success-callback":$success_email_sent$$});case "email-sent":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__form-container",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_success_page_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$core$_deref$$($user_email$jscomp$1$$)],null)})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__82951__$1$$)].join(""));}}(),$main_section_props_82942$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__links",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$terms_register_STAR_$$,
{})}):null]})]})})};
$app$main$ui$viewer$share_link$prepare_params$$=function($p__82944_pages$jscomp$12$$){var $map__82945__$1_who_inspect$$=$APP.$cljs$core$__destructure_map$$($p__82944_pages$jscomp$12$$);$p__82944_pages$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82945__$1_who_inspect$$,$APP.$cljs$cst$2228$pages$$);var $who_comment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82945__$1_who_inspect$$,$APP.$cljs$cst$5405$who_comment$$);$map__82945__$1_who_inspect$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82945__$1_who_inspect$$,
$APP.$cljs$cst$5406$who_inspect$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2228$pages$$,$p__82944_pages$jscomp$12$$,$APP.$cljs$cst$5405$who_comment$$,$who_comment$$,$APP.$cljs$cst$5406$who_inspect$$,$map__82945__$1_who_inspect$$],null)};
$app$main$ui$viewer$share_link$share_link_dialog$$=function($perms_visible_QMARK__props_82950$$){function $on_comment_change$$($value$jscomp$1017$$){$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($options_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5405$who_comment$$,$value$jscomp$1017$$)}function $on_inspect_change$$($value$jscomp$1016$$){$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($options_STAR_$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5406$who_inspect$$,$value$jscomp$1016$$)}function $toggle_perms_visibility$$(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($perms_visible_STAR_$$,$APP.$cljs$core$not$$)}function $delete_link$$(){var $params$jscomp$452$$=$app$main$ui$viewer$share_link$prepare_params$$($options$jscomp$650$$),$slink$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__82948_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1467$flags$$.$cljs$core$IFn$_invoke$arity$1$($p1__82948_SHARP_$$),
$APP.$cljs$cst$1467$flags$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$452$$))},$slinks$$);$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$delete_share_link$$($slink$jscomp$1$$))}function $try_delete_link$$(){return $APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!0)}function $copy_link$$(){$APP.$app$util$clipboard$to_clipboard$$($current_link$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.link-copied-success"),$APP.$cljs$cst$2353$timeout$$,1E3],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"copy-share-link",
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer"],null))]))}function $create_link$$(){var $params$jscomp$451_params__$1$jscomp$63$$=$app$main$ui$viewer$share_link$prepare_params$$($options$jscomp$650$$);$params$jscomp$451_params__$1$jscomp$63$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$451_params__$1$jscomp$63$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$201$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$common$create_share_link$$($params$jscomp$451_params__$1$jscomp$63$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-share-link",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer",$cljs$cst$6327$can_comment$$,$APP.$cljs$cst$5405$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$451_params__$1$jscomp$63$$),$cljs$cst$6328$can_inspect_code$$,$APP.$cljs$cst$5406$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$451_params__$1$jscomp$63$$)],
null))]))}function $on_mark_checked_page$$($dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$){$dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$=$APP.$app$util$dom$get_target$$($dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$);var $checked_QMARK_$jscomp$8$$=$APP.$app$util$dom$checked_QMARK_$$($dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$),$page_id$jscomp$469$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$,
"page-id"));$dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$469$$,$APP.$cljs$core$first$$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$)));return 1<$APP.$cljs$core$count$$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$))||$dif_pages_QMARK__event$jscomp$772_target$jscomp$173$$?($APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($options_STAR_$$,
function($map__82958__$1_p__82957$$){$map__82958__$1_p__82957$$=$APP.$cljs$core$__destructure_map$$($map__82958__$1_p__82957$$);var $pages$jscomp$14_pages__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82958__$1_p__82957$$,$APP.$cljs$cst$2228$pages$$);$pages$jscomp$14_pages__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($checked_QMARK_$jscomp$8$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($pages$jscomp$14_pages__$1$jscomp$1$$,$page_id$jscomp$469$$):$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($pages$jscomp$14_pages__$1$jscomp$1$$,
$page_id$jscomp$469$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__82958__$1_p__82957$$,$APP.$cljs$cst$2228$pages$$,$pages$jscomp$14_pages__$1$jscomp$1$$),$cljs$cst$6326$all_pages$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($pages$jscomp$14_pages__$1$jscomp$1$$),$APP.$cljs$core$count$$($page_ids$jscomp$2$$)))})):null}function $on_toggle_all$$(){$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,
!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($options_STAR_$$,function($state$jscomp$1234$$){return $cljs$cst$6326$all_pages$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1234$$)===!0?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1234$$,$cljs$cst$6326$all_pages$$,!1),$APP.$cljs$cst$2228$pages$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$181$$)])):
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1234$$,$cljs$cst$6326$all_pages$$,!0),$APP.$cljs$cst$2228$pages$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$201$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2228$pages$$],
null))))})}var $file$jscomp$201$$=$perms_visible_QMARK__props_82950$$.file,$page$jscomp$181$$=$perms_visible_QMARK__props_82950$$.page,$current_page_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$181$$),$slinks$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$share_links$$),$router$jscomp$8$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$router$$),$route$jscomp$23$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$),$zoom_type$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_zoom_type$$),
$page_ids$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$201$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2228$pages$$),$perms_visible_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$perms_visible_QMARK__props_82950$$=$APP.$cljs$core$_deref$$($perms_visible_STAR_$$);var $confirm_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$confirm_QMARK_$$=$APP.$cljs$core$_deref$$($confirm_STAR_$$),
$options_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$6325$pages_mode$$,"current",$cljs$cst$6326$all_pages$$,!1,$APP.$cljs$cst$2228$pages$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$181$$)]),$APP.$cljs$cst$5405$who_comment$$,"team",$APP.$cljs$cst$5406$who_inspect$$,"team"],null)),$options$jscomp$650$$=$APP.$cljs$core$_deref$$($options_STAR_$$),
$current_link$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($slinks$$),$APP.$rumext$v2$adapt$$($options$jscomp$650$$),$APP.$rumext$v2$adapt$$($page_ids$jscomp$2$$)],function(){var $href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$=$app$main$ui$viewer$share_link$prepare_params$$($options$jscomp$650$$);$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$=
$APP.$cljs$core$__destructure_map$$($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$);var $pages$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$,$APP.$cljs$cst$2228$pages$$),$who_comment$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$,
$APP.$cljs$cst$5405$who_comment$$),$who_inspect$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$,$APP.$cljs$cst$5406$who_inspect$$),$slink$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__82946_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5406$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($p1__82946_SHARP_$$),
$who_inspect$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5405$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($p1__82946_SHARP_$$),$who_comment$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($p1__82946_SHARP_$$),$pages$jscomp$13$$)},$slinks$$);return $APP.$cljs$core$truth_$$($slink$$)?($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__82947_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($slink$$),$p1__82947_SHARP_$$)},$page_ids$jscomp$2$$),$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$23$$),
$APP.$cljs$cst$3237$share_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($slink$$)),$APP.$cljs$cst$2043$page_id$$,$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$),$APP.$cljs$cst$1795$index$$,"0"),$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$=$zoom_type$jscomp$2$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$,
$APP.$cljs$cst$2196$zoom$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$,$APP.$cljs$cst$2196$zoom$$,$zoom_type$jscomp$2$$),$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$=$APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$($router$jscomp$8$$,$APP.$cljs$cst$1592$viewer$$,$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$),
""+($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$config$public_uri$$,$APP.$cljs$cst$738$fragment$$,$href$jscomp$22_map__82953_map__82953__$1_page_id$jscomp$468_params__$1$jscomp$62_params__$2$jscomp$8$$)??"")):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__share-modal",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__share-link-dialog",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__share-link-header",
children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_viewer_share_link__share-link-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function($event$jscomp$771$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$771$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()},title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
className:"main_ui_viewer_share_link__modal-close-button",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__share-link-section",children:[$APP.$cljs$core$not$$($confirm_QMARK_$$)&&$current_link$$!=null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__custon-input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("input",
{type:"text",value:$APP.$cljs$core$truth_$$($current_link$$)?$current_link$$:"",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.placeholder"),readOnly:!0,className:"main_ui_viewer_share_link__input-text"}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.share.copy-link"),onClick:$copy_link$$,className:"main_ui_viewer_share_link__copy-button",children:$APP.$app$main$ui$icons$clipboard$$})]}):null,
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__hint-wrapper",children:[$confirm_QMARK_$$?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__hint",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-hint")}),$confirm_QMARK_$$===!0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__confirm-dialog",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__description",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.confirm-deletion-link-description")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__actions",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",onClick:function(){return $APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1)},value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),className:"main_ui_viewer_share_link__button-cancel"}),(0,$APP.$rumext$v2$jsx$$)("input",
{type:"button",onClick:$delete_link$$,value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.destroy-link"),className:"main_ui_viewer_share_link__button-danger"})]})]}):$current_link$$!=null?(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",onClick:$try_delete_link$$,value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.destroy-link"),className:"main_ui_viewer_share_link__button-danger"}):(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",onClick:$create_link$$,
value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.get-link"),className:"main_ui_viewer_share_link__button-active"})]})]}),$confirm_QMARK_$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__permissions-section",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$toggle_perms_visibility$$,className:"main_ui_viewer_share_link__manage-permissions",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_share_link__icon "+($APP.$cljs$core$truth_$$($perms_visible_QMARK__props_82950$$)?
"main_ui_viewer_share_link__rotated":""),children:$APP.$app$main$ui$icons$arrow$$}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.manage-ops")]}),$perms_visible_QMARK__props_82950$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[function(){var $all_selected_QMARK_$jscomp$2$$=$cljs$cst$6326$all_pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$),$pages$jscomp$15$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82949_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$201$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1630$pages_index$$,$p1__82949_SHARP_$$],null))},$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$201$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2228$pages$$],null))),$selected$jscomp$220$$=$APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__view-mode",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-pages")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__items",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($pages$jscomp$15$$))?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_viewer_share_link__checkbox-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:["page-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($current_page_id$jscomp$9$$)].join(""),className:"checked",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_share_link__checked",children:$APP.$app$main$ui$icons$status_tick$$}),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$181$$)]}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",
id:"page-"+($current_page_id$jscomp$9$$??""),"data-page-id":""+($current_page_id$jscomp$9$$??""),onChange:$on_mark_checked_page$$,checked:!0}),(0,$APP.$rumext$v2$jsx$$)("span",{children:[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.current-tag"))].join("")})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__select-all-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__checkbox-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"view-all",className:"main_ui_viewer_share_link__select-all-label",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$2$$)?"checked":"",children:$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$2$$)?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.view-all"),
(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"view-all",checked:$all_selected_QMARK_$jscomp$2$$,name:"pages-mode",onChange:$on_toggle_all$$})]})}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_share_link__count-pages",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("common.share-link.page-shared",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($selected$jscomp$220$$))]))})]}),(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_viewer_share_link__pages-selection",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$251$$,$id$jscomp$1078_p__82961$$){var $map__82962__$1_name$jscomp$506$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1078_p__82961$$);$id$jscomp$1078_p__82961$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82962__$1_name$jscomp$506$$,$APP.$cljs$cst$266$id$$);$map__82962__$1_name$jscomp$506$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82962__$1_name$jscomp$506$$,
$APP.$cljs$cst$725$name$$);$out_arr__44124__auto__$jscomp$251$$.push((0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_viewer_share_link__checkbox-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"page-"+($id$jscomp$1078_p__82961$$??""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$220$$,$id$jscomp$1078_p__82961$$)?"checked":"",children:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$220$$,$id$jscomp$1078_p__82961$$)?$APP.$app$main$ui$icons$status_tick$$:
null}),$map__82962__$1_name$jscomp$506$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_page_id$jscomp$9$$,$id$jscomp$1078_p__82961$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__current-tag",children:" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.current-tag")??"")}):null,(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"page-"+($id$jscomp$1078_p__82961$$??""),"data-page-id":""+($id$jscomp$1078_p__82961$$??""),onChange:$on_mark_checked_page$$,
checked:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$220$$,$id$jscomp$1078_p__82961$$)})]})},""+($id$jscomp$1078_p__82961$$??"")));return $out_arr__44124__auto__$jscomp$251$$},[],$pages$jscomp$15$$)})]})})]})}(),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__access-mode",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-can-comment")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__items",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_viewer_share_link__who-comment-select","default-value":""+($APP.$cljs$cst$5405$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$)??""),options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
"team",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.team-members")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"all",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.all-users")],null)],null),"on-change":$on_comment_change$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__inspect-mode",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_viewer_share_link__subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-can-inspect")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__items",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_viewer_share_link__who-inspect-select","default-value":""+($APP.$cljs$cst$5406$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$)??""),options:new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"team",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.team-members")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"all",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.all-users")],null)],null),"on-change":$on_inspect_change$$})})]})]}):
null]})]})]})})};
$app$main$ui$viewer$thumbnails$thumbnails_content$$=function($map__82964_map__82964__$1_props_82963$$){function $on_scroll$jscomp$3$$($event$jscomp$773_event__$1$jscomp$9$$){$event$jscomp$773_event__$1$jscomp$9$$=$event$jscomp$773_event__$1$jscomp$9$$.nativeEvent;return $event$jscomp$773_event__$1$jscomp$9$$.deltaY>0?$on_right_arrow_click$jscomp$2$$($event$jscomp$773_event__$1$jscomp$9$$):$on_left_arrow_click$jscomp$2$$($event$jscomp$773_event__$1$jscomp$9$$)}function $on_right_arrow_click$jscomp$2$$(){var $visible$jscomp$4$$=$APP.$cljs$core$_deref$$($width$jscomp$254$$)/
$APP.$cljs$core$_deref$$($element_width$$),$max_val$jscomp$7$$=$total$jscomp$27$$-$visible$jscomp$4$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$220$$,function($v$jscomp$694$$){return $v$jscomp$694$$<$max_val$jscomp$7$$?$v$jscomp$694$$+1:$v$jscomp$694$$})}function $on_left_arrow_click$jscomp$2$$(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$220$$,function($v$jscomp$693$$){return $v$jscomp$693$$>0?$v$jscomp$693$$-1:$v$jscomp$693$$})}
$map__82964_map__82964__$1_props_82963$$=$APP.$rumext$v2$util$wrap_props$$($map__82964_map__82964__$1_props_82963$$);$map__82964_map__82964__$1_props_82963$$=$APP.$cljs$core$__destructure_map$$($map__82964_map__82964__$1_props_82963$$);var $children$jscomp$317$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82964_map__82964__$1_props_82963$$,$APP.$cljs$cst$342$children$$),$expanded_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82964_map__82964__$1_props_82963$$,
$cljs$cst$6329$expanded_QMARK_$$),$total$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82964_map__82964__$1_props_82963$$,$APP.$cljs$cst$2328$total$$),$container$jscomp$100$$=(0,$APP.$rumext$v2$use_ref$$)(),$width$jscomp$254$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(document.documentElement.clientWidth),$element_width$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(152),$offset$jscomp$220$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($width$jscomp$254$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$100$$),"clientWidth"))});return $APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-list-expanded",
children:$children$jscomp$317$$})}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-content",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_left_arrow_click$jscomp$2$$,className:"main_ui_viewer_thumbnails__left-scroll-handler",children:$APP.$app$main$ui$icons$arrow$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_right_arrow_click$jscomp$2$$,className:"main_ui_viewer_thumbnails__right-scroll-handler",children:$APP.$app$main$ui$icons$arrow$$}),(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$container$jscomp$100$$,onWheel:$on_scroll$jscomp$3$$,className:"main_ui_viewer_thumbnails__thumbnails-list",children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($offset$jscomp$220$$)*152),"px"].join("")},className:"main_ui_viewer_thumbnails__thumbnails-list-inside",children:$children$jscomp$317$$})})]})};
$app$main$ui$viewer$thumbnails$thumbnails_summary$$=function($map__82966_on_toggle_expand$jscomp$2_props_82965$$){$map__82966_on_toggle_expand$jscomp$2_props_82965$$=$APP.$rumext$v2$util$wrap_props$$($map__82966_on_toggle_expand$jscomp$2_props_82965$$);var $map__82966__$1_total$jscomp$28$$=$APP.$cljs$core$__destructure_map$$($map__82966_on_toggle_expand$jscomp$2_props_82965$$);$map__82966_on_toggle_expand$jscomp$2_props_82965$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82966__$1_total$jscomp$28$$,
$APP.$cljs$cst$5797$on_toggle_expand$$);var $on_close$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82966__$1_total$jscomp$28$$,$APP.$cljs$cst$4994$on_close$$);$map__82966__$1_total$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82966__$1_total$jscomp$28$$,$APP.$cljs$cst$2328$total$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-summary",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_thumbnails__counter",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-frames",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($map__82966__$1_total$jscomp$28$$)]))}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_viewer_thumbnails__actions",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$map__82966_on_toggle_expand$jscomp$2_props_82965$$,className:"main_ui_viewer_thumbnails__expand-btn",children:$APP.$app$main$ui$icons$arrow$$}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$51$$,className:"main_ui_viewer_thumbnails__close-btn",children:$APP.$app$main$ui$icons$close$$})]})]})};
$app$main$ui$viewer$thumbnails$thumbnails_panel$$=function($frames$jscomp$35_map__82972_props_82971$$){function $on_close$jscomp$52$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$toggle_thumbnails_panel$$)}$frames$jscomp$35_map__82972_props_82971$$=$APP.$rumext$v2$util$wrap_props$$($frames$jscomp$35_map__82972_props_82971$$);var $container$jscomp$101_map__82972__$1$$=$APP.$cljs$core$__destructure_map$$($frames$jscomp$35_map__82972_props_82971$$);
$frames$jscomp$35_map__82972_props_82971$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$101_map__82972__$1$$,$APP.$cljs$cst$5241$frames$$);var $page$jscomp$182$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$101_map__82972__$1$$,$APP.$cljs$cst$1624$page$$),$index$jscomp$587$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$101_map__82972__$1$$,$APP.$cljs$cst$1795$index$$),$show_QMARK_$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$101_map__82972__$1$$,
$APP.$cljs$cst$5357$show_QMARK_$$),$thumbnail_data$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$101_map__82972__$1$$,$cljs$cst$6330$thumbnail_data$$),$expanded_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$expanded_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($expanded_state$$);$container$jscomp$101_map__82972__$1$$=(0,$APP.$rumext$v2$use_ref$$)();var $objects$jscomp$849$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$182$$),
$selected$jscomp$221$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_item_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($expanded_QMARK_$jscomp$4$$)],function($_$jscomp$3164$$,$index__$1$jscomp$25$$){$APP.$cljs$core$compare_and_set_BANG_$$($selected$jscomp$221$$,!1,!0);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_frame_by_index$$($index__$1$jscomp$25$$));return $APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$4$$)?
$on_close$jscomp$52$$():null}),$toggle_expand$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($expanded_state$$,$APP.$cljs$core$not$$)});return(0,$APP.$rumext$v2$jsxs$$)("section",{style:{display:$APP.$cljs$core$not$$($show_QMARK_$jscomp$6$$)?"none":null},ref:$container$jscomp$101_map__82972__$1$$,className:"main_ui_viewer_thumbnails__viewer-thumbnails "+($APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$4$$)?
"main_ui_viewer_thumbnails__expanded":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnails_summary$$,{"on-toggle-expand":$toggle_expand$$,"on-close":$on_close$jscomp$52$$,total:$APP.$cljs$core$count$$($frames$jscomp$35_map__82972_props_82971$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnails_content$$,{"expanded?":$expanded_QMARK_$jscomp$4$$,total:$APP.$cljs$core$count$$($frames$jscomp$35_map__82972_props_82971$$),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$252$$,
$frame$jscomp$105_p__82973$$){var $i$jscomp$544$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame$jscomp$105_p__82973$$,0,null);$frame$jscomp$105_p__82973$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame$jscomp$105_p__82973$$,1,null);$out_arr__44124__auto__$jscomp$252$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnail_item$$,{index:$i$jscomp$544$$,frame:$frame$jscomp$105_p__82973$$,"page-id":$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$182$$),
objects:$objects$jscomp$849$$,"on-click":$on_item_click$$,"selected?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$544$$,$index$jscomp$587$$),"thumbnail-data":$thumbnail_data$jscomp$2$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105_p__82973$$)??"")+"-"+($i$jscomp$544$$??"")));return $out_arr__44124__auto__$jscomp$252$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($frames$jscomp$35_map__82972_props_82971$$))})]})};
$app$main$ui$viewer$calculate_size$$=function($map__82979_objects$jscomp$850_x$jscomp$1365$$,$frame$jscomp$106_y$jscomp$549$$,$zoom$jscomp$170$$){$map__82979_objects$jscomp$850_x$jscomp$1365$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$($map__82979_objects$jscomp$850_x$jscomp$1365$$,$frame$jscomp$106_y$jscomp$549$$);var $height$jscomp$221_map__82979__$1$$=$APP.$cljs$core$__destructure_map$$($map__82979_objects$jscomp$850_x$jscomp$1365$$);$map__82979_objects$jscomp$850_x$jscomp$1365$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$221_map__82979__$1$$,$APP.$cljs$cst$1510$x$$);$frame$jscomp$106_y$jscomp$549$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$221_map__82979__$1$$,$APP.$cljs$cst$1511$y$$);var $width$jscomp$255$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$221_map__82979__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$221_map__82979__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$221_map__82979__$1$$,
$APP.$cljs$cst$1522$height$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$6331$base_width$$,$width$jscomp$255$$,$cljs$cst$6332$base_height$$,$height$jscomp$221_map__82979__$1$$,$APP.$cljs$cst$1510$x$$,$map__82979_objects$jscomp$850_x$jscomp$1365$$,$APP.$cljs$cst$1511$y$$,$frame$jscomp$106_y$jscomp$549$$,$APP.$cljs$cst$290$width$$,$width$jscomp$255$$*$zoom$jscomp$170$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$221_map__82979__$1$$*$zoom$jscomp$170$$,$APP.$cljs$cst$1925$vbox$$,
"0 0 "+($width$jscomp$255$$??"")+" "+($height$jscomp$221_map__82979__$1$$??"")],null)};
$app$main$ui$viewer$calculate_delta$$=function($size$jscomp$165$$,$selrect$jscomp$97$$,$delta_x$jscomp$8_p__82980$$,$zoom$jscomp$171$$){var $snap_v$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta_x$jscomp$8_p__82980$$,0,null),$snap_h$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta_x$jscomp$8_p__82980$$,1,null);$delta_x$jscomp$8_p__82980$$=function(){var $G__82984__$1$$=$snap_h$$ instanceof $APP.$cljs$core$Keyword$$?$snap_h$$.$fqn$:null;switch($G__82984__$1$$){case "left":return $APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$)-
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$);case "right":return $APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$)-($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)/$zoom$jscomp$171$$);case "center":return($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)/
$zoom$jscomp$171$$)/2-($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)-$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__82984__$1$$)].join(""));}}();var $delta_y$jscomp$6$$=function(){var $G__82985__$1$$=$snap_v$$ instanceof $APP.$cljs$core$Keyword$$?$snap_v$$.$fqn$:null;switch($G__82985__$1$$){case "top":return $APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$)-
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$);case "bottom":return $APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$)-($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)/$zoom$jscomp$171$$);case "center":return($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)/
$zoom$jscomp$171$$)/2-($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$165$$)-$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$97$$));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__82985__$1$$)].join(""));}}();return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($delta_x$jscomp$8_p__82980$$*$zoom$jscomp$171$$,$delta_y$jscomp$6$$*$zoom$jscomp$171$$)};
$app$main$ui$viewer$calculate_wrapper$$=function($size1$$,$size2$$,$zoom$jscomp$172$$){if($size1$$==null)return $size2$$;if($size2$$==null)return $size1$$;var $width$jscomp$256$$=function(){var $x__5110__auto__$jscomp$199$$=$cljs$cst$6331$base_width$$.$cljs$core$IFn$_invoke$arity$1$($size1$$),$y__5111__auto__$jscomp$199$$=$cljs$cst$6331$base_width$$.$cljs$core$IFn$_invoke$arity$1$($size2$$);return $x__5110__auto__$jscomp$199$$>$y__5111__auto__$jscomp$199$$?$x__5110__auto__$jscomp$199$$:$y__5111__auto__$jscomp$199$$}(),
$height$jscomp$222$$=function(){var $x__5110__auto__$jscomp$200$$=$cljs$cst$6332$base_height$$.$cljs$core$IFn$_invoke$arity$1$($size1$$),$y__5111__auto__$jscomp$200$$=$cljs$cst$6332$base_height$$.$cljs$core$IFn$_invoke$arity$1$($size2$$);return $x__5110__auto__$jscomp$200$$>$y__5111__auto__$jscomp$200$$?$x__5110__auto__$jscomp$200$$:$y__5111__auto__$jscomp$200$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$290$width$$,$width$jscomp$256$$*$zoom$jscomp$172$$,$APP.$cljs$cst$1522$height$$,
$height$jscomp$222$$*$zoom$jscomp$172$$,$APP.$cljs$cst$1925$vbox$$,["0 0 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$256$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($height$jscomp$222$$)].join("")],null)};
$app$main$ui$viewer$viewer_pagination$$=function($index$jscomp$588_map__82987_props_82986$$){$index$jscomp$588_map__82987_props_82986$$=$APP.$rumext$v2$util$wrap_props$$($index$jscomp$588_map__82987_props_82986$$);var $comment_sidebar_map__82987__$1$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$588_map__82987_props_82986$$);$index$jscomp$588_map__82987_props_82986$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__82987__$1$$,$APP.$cljs$cst$1795$index$$);var $num_frames$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__82987__$1$$,$cljs$cst$6333$num_frames$$),$left_bar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__82987__$1$$,$cljs$cst$6334$left_bar$$),$right_bar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__82987__$1$$,$cljs$cst$6335$right_bar$$);$comment_sidebar_map__82987__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__82987__$1$$,$cljs$cst$6336$comment_sidebar$$);
var $go_prev_frame$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_prev_frame$$)}),$go_next_frame$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_next_frame$$)}),$go_first_frame$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_first_frame$$)});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$index$jscomp$588_map__82987_props_82986$$>0?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_prev_frame$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.previous"),className:"main_ui_viewer__viewer-go-prev "+($APP.$cljs$core$truth_$$($left_bar$$)?"main_ui_viewer__left-bar":""),children:$APP.$app$main$ui$icons$arrow$$}):null,$index$jscomp$588_map__82987_props_82986$$+1<$num_frames$$?(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$go_next_frame$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"),className:"main_ui_viewer__viewer-go-next "+($APP.$cljs$core$truth_$$($comment_sidebar_map__82987__$1$$)?"main_ui_viewer__comment-sidebar":"")+" "+($APP.$cljs$core$truth_$$($right_bar$$)?"main_ui_viewer__right-bar":""),children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer__viewer-bottom "+($APP.$cljs$core$truth_$$($left_bar$$)?"main_ui_viewer__left-bar":
""),children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_first_frame$$,className:"main_ui_viewer__reset-button",children:$APP.$app$main$ui$icons$reload$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer__counter",children:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" / ",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$588_map__82987_props_82986$$+1,$num_frames$$],null))}),(0,$APP.$rumext$v2$jsx$$)("span",
{})]})]})};
$app$main$ui$viewer$viewer_overlay$$=function($frame$jscomp$108_map__82996_props_82995$$){$frame$jscomp$108_map__82996_props_82995$$=$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$108_map__82996_props_82995$$);var $interactions_mode$jscomp$3_map__82996__$1$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$108_map__82996_props_82995$$),$overlay$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$3_map__82996__$1$$,$APP.$cljs$cst$2024$overlay$$),$page$jscomp$184$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$3_map__82996__$1$$,$APP.$cljs$cst$1624$page$$);$frame$jscomp$108_map__82996_props_82995$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$3_map__82996__$1$$,$APP.$cljs$cst$1606$frame$$);var $zoom$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$3_map__82996__$1$$,$APP.$cljs$cst$2196$zoom$$),$wrapper_size$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$3_map__82996__$1$$,
$cljs$cst$6337$wrapper_size$$);$interactions_mode$jscomp$3_map__82996__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$3_map__82996__$1$$,$APP.$cljs$cst$5231$interactions_mode$$);var $close_click_outside_QMARK_$jscomp$1$$=$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$background_overlay_QMARK_$jscomp$1$$=$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$overlay_frame$$=
$APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$overlay_position$jscomp$5$$=$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$fixed_base_QMARK_$jscomp$2$$=$APP.$cljs$cst$5283$fixed_source_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$size$jscomp$166$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$184$$),$APP.$rumext$v2$adapt$$($overlay$jscomp$1$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$173$$)],
function(){return $app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$184$$),$APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$zoom$jscomp$173$$)}),$delta$jscomp$69$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($size$jscomp$166$$),$APP.$rumext$v2$adapt$$($overlay_frame$$),$APP.$rumext$v2$adapt$$($overlay$jscomp$1$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$173$$)],function(){return $app$main$ui$viewer$calculate_delta$$($size$jscomp$166$$,
$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($overlay_frame$$),$APP.$cljs$cst$5282$snap_to$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$zoom$jscomp$173$$)}),$on_click$jscomp$70$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($overlay$jscomp$1$$),$APP.$rumext$v2$adapt$$($close_click_outside_QMARK_$jscomp$1$$)],function(){if($APP.$cljs$core$truth_$$($close_click_outside_QMARK_$jscomp$1$$)){var $JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$=
$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$))$JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),
$APP.$app$common$types$shape$interactions$invert_direction$$($JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$)));else{$JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1390_frame_id$jscomp$inline_9594$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$);$JSCompiler_inline_result$jscomp$1390_frame_id$jscomp$inline_9594$$=
$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1390_frame_id$jscomp$inline_9594$$,null);$JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$=$JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1390_frame_id$jscomp$inline_9594$$)}return $JSCompiler_temp$jscomp$1387_JSCompiler_temp_const$jscomp$1388_temp__5823__auto__$jscomp$266$$}return null});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($close_click_outside_QMARK_$jscomp$1$$)?$close_click_outside_QMARK_$jscomp$1$$:$background_overlay_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$3$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$3$$),position:"absolute",left:0,top:0},onClick:$on_click$jscomp$70$$,
className:"main_ui_viewer__viewer-overlay-background "+($APP.$cljs$core$truth_$$($background_overlay_QMARK_$jscomp$1$$)?"main_ui_viewer__visible":"")}):null,$APP.$cljs$core$truth_$$($fixed_base_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"absolute",left:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$173$$,top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$173$$,width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$166$$),
height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$166$$),zIndex:2},className:"main_ui_viewer__viewport-container-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"overlay-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay_frame$$)??""),style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$166$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$166$$),position:"fixed"},className:"main_ui_viewer__viewer-overlay main_ui_viewer__viewport-container",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport$$,{frame:$overlay_frame$$,"base-frame":$frame$jscomp$108_map__82996_props_82995$$,"frame-offset":$overlay_position$jscomp$5$$,size:$size$jscomp$166$$,delta:$delta$jscomp$69$$,page:$page$jscomp$184$$,"interactions-mode":$interactions_mode$jscomp$3_map__82996__$1$$})})}):(0,$APP.$rumext$v2$jsx$$)("div",{id:"overlay-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay_frame$$)??""),style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$166$$),
height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$166$$),left:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$173$$,top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$173$$},className:"main_ui_viewer__viewer-overlay main_ui_viewer__viewport-container",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport$$,{frame:$overlay_frame$$,"base-frame":$frame$jscomp$108_map__82996_props_82995$$,
"frame-offset":$overlay_position$jscomp$5$$,size:$size$jscomp$166$$,delta:$delta$jscomp$69$$,page:$page$jscomp$184$$,"interactions-mode":$interactions_mode$jscomp$3_map__82996__$1$$})})]})};
$app$main$ui$viewer$viewer_wrapper$$=function($props_83000$$){var $users$jscomp$5$$=$props_83000$$.users,$overlays$jscomp$11$$=$props_83000$$.overlays,$zoom$jscomp$174$$=$props_83000$$.zoom,$wrapper_size$jscomp$4$$=$props_83000$$["wrapper-size"],$frame$jscomp$109$$=$props_83000$$.frame,$orig_frame$jscomp$3$$=$props_83000$$["orig-frame"],$file$jscomp$202$$=$props_83000$$.file,$orig_viewport_ref$$=$props_83000$$["orig-viewport-ref"],$section$jscomp$49$$=$props_83000$$.section,$orig_size$jscomp$1$$=
$props_83000$$["orig-size"],$current_viewport_ref$$=$props_83000$$["current-viewport-ref"],$page$jscomp$185$$=$props_83000$$.page,$interactions_mode$jscomp$4$$=$props_83000$$["interactions-mode"],$size$jscomp$167$$=$props_83000$$.size;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_pagination_and_sidebar$$,{section:$section$jscomp$49$$,index:$props_83000$$.index,page:$page$jscomp$185$$,users:$users$jscomp$5$$,frame:$frame$jscomp$109$$,
"interactions-mode":$interactions_mode$jscomp$4$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$4$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$4$$)},className:"main_ui_viewer__viewer-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer__viewer-clipper",children:[$APP.$cljs$core$truth_$$($orig_frame$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$orig_viewport_ref$$,
style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_size$jscomp$1$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($orig_size$jscomp$1$$),position:"relative"},className:"main_ui_viewer__viewport-container",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport$$,{frame:$orig_frame$jscomp$3$$,"base-frame":$orig_frame$jscomp$3$$,"frame-offset":$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),size:$orig_size$jscomp$1$$,
page:$page$jscomp$185$$,users:$users$jscomp$5$$,"interactions-mode":$interactions_mode$jscomp$4$$})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$current_viewport_ref$$,style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$167$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$167$$),position:"relative"},className:"main_ui_viewer__viewport-container",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport$$,
{frame:$frame$jscomp$109$$,"base-frame":$frame$jscomp$109$$,"frame-offset":$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),size:$size$jscomp$167$$,page:$page$jscomp$185$$,"interactions-mode":$interactions_mode$jscomp$4$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$253$$,$overlay$jscomp$2$$){$out_arr__44124__auto__$jscomp$253$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_overlay$$,{overlay:$overlay$jscomp$2$$,
page:$page$jscomp$185$$,frame:$frame$jscomp$109$$,zoom:$zoom$jscomp$174$$,"wrapper-size":$wrapper_size$jscomp$4$$,"interactions-mode":$interactions_mode$jscomp$4$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$2$$)??"")));return $out_arr__44124__auto__$jscomp$253$$},[],$overlays$jscomp$11$$)]})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$49$$,$APP.$cljs$cst$3436$comments$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$comments$comments_layer$$,
{file:$file$jscomp$202$$,users:$users$jscomp$5$$,frame:$frame$jscomp$109$$,page:$page$jscomp$185$$,zoom:$zoom$jscomp$174$$}):null]})]})};
$app$main$ui$viewer$viewer_content_STAR_$$=function($props_83010$$){var $data$jscomp$514$$=$props_83010$$.data,$index$jscomp$591$$=$props_83010$$.index,$section$jscomp$50$$=$props_83010$$.section,$interactions_mode$jscomp$5$$=$props_83010$$.interactionsMode,$page_id$jscomp$471$$=$props_83010$$.pageId,$share$jscomp$2$$=$props_83010$$.share,$share_id$jscomp$30$$=$props_83010$$.shareId,$map__83011__$1$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$514$$),$file$jscomp$203$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83011__$1$$,
$APP.$cljs$cst$208$file$$),$users$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83011__$1$$,$APP.$cljs$cst$5245$users$$),$project$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83011__$1$$,$APP.$cljs$cst$2230$project$$),$permissions$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83011__$1$$,$APP.$cljs$cst$1722$permissions$$),$allowed$jscomp$1$$=function(){var $and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$2051$interactions$$);if($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$)return $and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$;
if($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$3436$comments$$))$and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$=
$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$),$and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$)?
$and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$:$APP.$cljs$cst$5402$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$)===!0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5405$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$),"all");return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$)?
$and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$:($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$2672$inspect$$))?
($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$)?
$and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$:$APP.$cljs$cst$5402$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$)===!0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5406$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$),"all")):$and__5023__auto__$jscomp$1030_and__5023__auto__$jscomp$inline_9596_or__5025__auto__$jscomp$1413_or__5025__auto____$1$jscomp$159_or__5025__auto____$1$jscomp$inline_9597_or__5025__auto____$2$jscomp$42$$}(),
$local$jscomp$38$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_local$$),$nav_scroll$$=$APP.$cljs$cst$5273$nav_scroll$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38$$),$orig_viewport_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_viewport_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$viewer_section_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_animations$$=$APP.$rumext$v2$deref$$($app$main$ui$viewer$current_animations_ref$$),$page_id__$1$jscomp$27$$=$APP.$cljs$core$truth_$$($page_id$jscomp$471$$)?
$page_id$jscomp$471$$:$APP.$cljs$core$first$$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$203$$))),$page$jscomp$186$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$514$$),$APP.$rumext$v2$adapt$$($page_id__$1$jscomp$27$$)],function(){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$514$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2228$pages$$,$page_id__$1$jscomp$27$$],null))}),$text_shapes$jscomp$5$$=$APP.$app$main$ui$hooks$use_equal_memo$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$)))),$zoom$jscomp$175$$=$APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38$$),$zoom_type$jscomp$3$$=
$APP.$cljs$cst$2235$zoom_type$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38$$),$frames$jscomp$36$$=$APP.$cljs$cst$5241$frames$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$frame$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frames$jscomp$36$$,$index$jscomp$591$$),$fullscreen_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$ui$viewer$header$fullscreen_ref$$),$overlays$jscomp$12$$=$APP.$rumext$v2$deref$$($app$main$ui$viewer$current_overlays_ref$$),$orig_frame$jscomp$4$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_animations$$)],function(){var $animation_with_origin$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5279$orig_frame_id$$,$APP.$cljs$core$vals$$($current_animations$$));return $APP.$cljs$core$truth_$$($animation_with_origin$$)?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83004_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83004_SHARP_$$),
$APP.$cljs$cst$5279$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($animation_with_origin$$))},$frames$jscomp$36$$):null}),$size$jscomp$168$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame$jscomp$110$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$175$$)],function(){return $APP.$cljs$core$truth_$$($frame$jscomp$110$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$frame$jscomp$110$$,$zoom$jscomp$175$$):
null}),$orig_size$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($orig_frame$jscomp$4$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$175$$)],function(){return $APP.$cljs$core$truth_$$($orig_frame$jscomp$4$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$orig_frame$jscomp$4$$,$zoom$jscomp$175$$):null}),$wrapper_size$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($size$jscomp$168$$),
$APP.$rumext$v2$adapt$$($orig_size$jscomp$2$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$175$$)],function(){return $app$main$ui$viewer$calculate_wrapper$$($size$jscomp$168$$,$orig_size$jscomp$2$$,$zoom$jscomp$175$$)}),$click_on_screen$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$774_over_section_QMARK_$jscomp$1$$){$event$jscomp$774_over_section_QMARK_$jscomp$1$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($event$jscomp$774_over_section_QMARK_$jscomp$1$$),
"viewer-section");var $layout$jscomp$36$$=$APP.$goog$dom$getElement$$("viewer-layout"),$has_force_QMARK_$jscomp$1$$=$APP.$app$util$dom$get_data$$($layout$jscomp$36$$,"force-visible");return $APP.$cljs$core$truth_$$($event$jscomp$774_over_section_QMARK_$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($has_force_QMARK_$jscomp$1$$,"true")?$APP.$app$util$dom$set_data_BANG_$$($layout$jscomp$36$$,"force-visible",!1):$APP.$app$util$dom$set_data_BANG_$$($layout$jscomp$36$$,"force-visible",
!0):null}),$on_click$jscomp$71$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($section$jscomp$50$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$3436$comments$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$()):null}),$set_up_new_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $size__$1$jscomp$9_viewer_section$jscomp$1$$=
$APP.$goog$dom$getElement$$("viewer-section");$size__$1$jscomp$9_viewer_section$jscomp$1$$=$APP.$app$util$dom$get_client_size$$($size__$1$jscomp$9_viewer_section$jscomp$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$set_viewport_size$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$874$size$$,$size__$1$jscomp$9_viewer_section$jscomp$1$$],null)))}),$on_wheel$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$775_event__$1$jscomp$10$$){$event$jscomp$775_event__$1$jscomp$10$$=
$event$jscomp$775_event__$1$jscomp$10$$.getBrowserEvent();var $or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$=$APP.$goog$dom$getElement$$("inspect-svg-wrapper"),$section__$1$jscomp$3$$=$APP.$goog$dom$getElement$$("inspect-svg-container"),$JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$=$event$jscomp$775_event__$1$jscomp$10$$.target;$or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$=$APP.$app$util$dom$child_QMARK_$$($JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$,
$or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$);$JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$)?$or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$:$JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$.id,
"inspect-svg-container"):null;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$)){var $new_scroll_pos_norm_event$jscomp$1$$=$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$($event$jscomp$775_event__$1$jscomp$10$$);$JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$775_event__$1$jscomp$10$$);$or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$=
$event$jscomp$775_event__$1$jscomp$10$$.shiftKey;$new_scroll_pos_norm_event$jscomp$1$$=($or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$?$section__$1$jscomp$3$$!=null?$section__$1$jscomp$3$$.scrollLeft:null:$section__$1$jscomp$3$$!=null?$section__$1$jscomp$3$$.scrollTop:null)+$new_scroll_pos_norm_event$jscomp$1$$.pixelY;if($JSCompiler_inline_result$jscomp$2021_mod_QMARK_$jscomp$16_target$jscomp$174$$)return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$775_event__$1$jscomp$10$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$775_event__$1$jscomp$10$$);return $or__5025__auto__$jscomp$inline_9599_shift_QMARK_$jscomp$49_wrapper$jscomp$10$$?$section__$1$jscomp$3$$!=null?$APP.$app$util$object$set_BANG_$$($section__$1$jscomp$3$$,"scrollLeft",$new_scroll_pos_norm_event$jscomp$1$$):null:$section__$1$jscomp$3$$!=null?$APP.$app$util$object$set_BANG_$$($section__$1$jscomp$3$$,"scrollTop",$new_scroll_pos_norm_event$jscomp$1$$):null}return null}),$on_thumbnails_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_thumbnails_panel$$)}),
$on_exit_fullscreen$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$util$dom$fullscreen_QMARK_$$()?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$exit_fullscreen$$())});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6338$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer$$,$APP.$app$main$data$viewer$shortcuts$shortcuts$$);if($page$jscomp$186$$==null)throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("not-found",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2665$not_found$$],null),null])),null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$not$$($allowed$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_section$$($APP.$cljs$cst$2051$interactions$$)):
null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$203$$))],function(){var $name$jscomp$507$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$203$$);return $APP.$app$util$dom$set_html_title$$(["▶ ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.viewer",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$507$$])))].join(""))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){for(var $events$jscomp$5$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"click",$on_click$jscomp$71$$),$APP.$goog$events$listen$$($APP.$rumext$v2$ref_val$$($viewer_section_ref$$),"wheel",$on_wheel$jscomp$2$$,{passive:!1})],null),$c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$=$APP.$cljs$core$seq$$($APP.$app$util$dom$fullscreen_events$$),
$G__83093_chunk__83019_83081_seq__83018_83090__$1$$=null,$G__83094_count__83021_83082$$=0,$G__83092_i__83022_83083$$=0;;)if($G__83092_i__83022_83083$$<$G__83094_count__83021_83082$$){var $event_83084$$=$G__83093_chunk__83019_83081_seq__83018_83090__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__83092_i__83022_83083$$);$APP.$app$util$globals$document$$.addEventListener($event_83084$$,$on_exit_fullscreen$$,!1);$G__83092_i__83022_83083$$+=1}else if($c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$=
$APP.$cljs$core$seq$$($c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$))$G__83093_chunk__83019_83081_seq__83018_83090__$1$$=$c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__83093_chunk__83019_83081_seq__83018_83090__$1$$)?($c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$=$APP.$cljs$core$_chunked_first$$($G__83093_chunk__83019_83081_seq__83018_83090__$1$$),$G__83092_i__83022_83083$$=
$APP.$cljs$core$_chunked_rest$$($G__83093_chunk__83019_83081_seq__83018_83090__$1$$),$G__83093_chunk__83019_83081_seq__83018_83090__$1$$=$c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$,$G__83094_count__83021_83082$$=$APP.$cljs$core$count$$($c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$),$c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$=$G__83092_i__83022_83083$$):($c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$=
$APP.$cljs$core$first$$($G__83093_chunk__83019_83081_seq__83018_83090__$1$$),$APP.$app$util$globals$document$$.addEventListener($c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$,$on_exit_fullscreen$$,!1),$c__5548__auto___83091_event_83096_seq__83018_83080_temp__5825__auto___83089$$=$APP.$cljs$core$next$$($G__83093_chunk__83019_83081_seq__83018_83090__$1$$),$G__83093_chunk__83019_83081_seq__83018_83090__$1$$=null,$G__83094_count__83021_83082$$=0),$G__83092_i__83022_83083$$=
0;else break;return function(){for(var $c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$seq$$($events$jscomp$5$$),$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=null,$G__83115_G__83128_count__83030_83103_event$jscomp$776$$=0,$G__83113_G__83126_count__83040_i__83031_83104$$=0;;)if($G__83113_G__83126_count__83040_i__83031_83104$$<$G__83115_G__83128_count__83030_83103_event$jscomp$776$$){var $i__83041_key_83105$$=
$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__83113_G__83126_count__83040_i__83031_83104$$);$APP.$goog$events$unlistenByKey$$($i__83041_key_83105$$);$G__83113_G__83126_count__83040_i__83031_83104$$+=1}else if($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$))$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=
$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$)?($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$_chunked_first$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),
$G__83113_G__83126_count__83040_i__83031_83104$$=$APP.$cljs$core$_chunked_rest$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$,$G__83115_G__83128_count__83030_83103_event$jscomp$776$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$),
$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$G__83113_G__83126_count__83040_i__83031_83104$$):($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$first$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),$APP.$goog$events$unlistenByKey$$($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$),
$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$next$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=null,$G__83115_G__83128_count__83030_83103_event$jscomp$776$$=0),$G__83113_G__83126_count__83040_i__83031_83104$$=0;else break;$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=
$APP.$cljs$core$seq$$($APP.$app$util$dom$fullscreen_events$$);$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=null;for($i__83041_key_83105$$=$G__83113_G__83126_count__83040_i__83031_83104$$=0;;)if($i__83041_key_83105$$<$G__83113_G__83126_count__83040_i__83031_83104$$)$G__83115_G__83128_count__83030_83103_event$jscomp$776$$=$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__83041_key_83105$$),
$APP.$app$util$globals$document$$.removeEventListener($G__83115_G__83128_count__83030_83103_event$jscomp$776$$,$on_exit_fullscreen$$),$i__83041_key_83105$$+=1;else if($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$))$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=
$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$)?($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$_chunked_first$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),
$G__83113_G__83126_count__83040_i__83031_83104$$=$APP.$cljs$core$_chunked_rest$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$,$G__83115_G__83128_count__83030_83103_event$jscomp$776$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$),
$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$G__83113_G__83126_count__83040_i__83031_83104$$,$G__83113_G__83126_count__83040_i__83031_83104$$=$G__83115_G__83128_count__83030_83103_event$jscomp$776$$):($G__83115_G__83128_count__83030_83103_event$jscomp$776$$=$APP.$cljs$core$first$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),$APP.$app$util$globals$document$$.removeEventListener($G__83115_G__83128_count__83030_83103_event$jscomp$776$$,
$on_exit_fullscreen$$),$c__5548__auto__$jscomp$46_c__5548__auto___83112_key_83117_seq__83028_83101_seq__83038_temp__5825__auto__$jscomp$460_temp__5825__auto___83110$$=$APP.$cljs$core$next$$($G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$),$G__83114_G__83127_chunk__83029_83102_chunk__83039_seq__83028_83111__$1_seq__83038__$1$$=null,$G__83113_G__83126_count__83040_i__83031_83104$$=0),$i__83041_key_83105$$=0;else return null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$set_up_new_size$$.$cljs$core$IFn$_invoke$arity$0$?
$set_up_new_size$$.$cljs$core$IFn$_invoke$arity$0$():$set_up_new_size$$();window.addEventListener("resize",$set_up_new_size$$);return function(){return window.removeEventListener("resize",$set_up_new_size$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($nav_scroll$$)],function(){if(typeof $nav_scroll$$==="number"){var $viewer_section$jscomp$2$$=$APP.$goog$dom$getElement$$("viewer-section");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$reset_nav_scroll$$());
return $viewer_section$jscomp$2$$!=null?$APP.$app$util$object$set_BANG_$$($viewer_section$jscomp$2$$,"scrollTop",$nav_scroll$$):null}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fullscreen_QMARK_$jscomp$1$$)],function(){var $wrapper$jscomp$11$$=$APP.$goog$dom$getElement$$("viewer-layout"),$fullscreen_dom_QMARK__layout$jscomp$37$$=$app$util$dom$fullscreen_QMARK_$$();return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK_$jscomp$1$$,
$fullscreen_dom_QMARK__layout$jscomp$37$$)?$APP.$cljs$core$truth_$$($fullscreen_QMARK_$jscomp$1$$)?($fullscreen_dom_QMARK__layout$jscomp$37$$=$APP.$goog$dom$getElement$$("viewer-layout"),$APP.$app$util$dom$set_data_BANG_$$($fullscreen_dom_QMARK__layout$jscomp$37$$,"force-visible",!1),$app$util$webapi$request_fullscreen$$($wrapper$jscomp$11$$)):$app$util$webapi$exit_fullscreen$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($zoom_type$jscomp$3$$)],
function(){switch($zoom_type$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$zoom_type$jscomp$3$$.$fqn$:null){case "fit":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fit$$);case "fill":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fill$$);default:return null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$591$$),$APP.$rumext$v2$adapt$$($current_animations$$),
$APP.$rumext$v2$adapt$$($zoom_type$jscomp$3$$)],function(){switch($zoom_type$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$zoom_type$jscomp$3$$.$fqn$:null){case "fit":$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fit$$);break;case "fill":$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fill$$)}var $nav_animation$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83006_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($p1__83006_SHARP_$$),
$APP.$cljs$cst$5278$go_to_frame$$)},$APP.$cljs$core$vals$$($current_animations$$));if($APP.$cljs$core$truth_$$($nav_animation$$)){var $orig_viewport$jscomp$1$$=$APP.$rumext$v2$ref_val$$($orig_viewport_ref$jscomp$1$$),$current_viewport$jscomp$1$$=$APP.$rumext$v2$ref_val$$($current_viewport_ref$jscomp$1$$);return $app$main$ui$viewer$interactions$animate_go_to_frame$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($nav_animation$$),$current_viewport$jscomp$1$$,$orig_viewport$jscomp$1$$,
$size$jscomp$168$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_animations$$)],function(){if($APP.$cljs$core$truth_$$($current_animations$$))for(var $c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$=$APP.$cljs$core$seq$$($current_animations$$),$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=null,$G__83155_count__83052$$=0,$i__83053$$=
0;;)if($i__83053$$<$G__83155_count__83052$$){var $G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$=$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__83053$$),$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,0,null),$G__83154_animation_vals$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,1,null),$overlay_viewport_83138_seq__83050__$1$$=$APP.$app$util$dom$get_element$$(["overlay-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5284$overlay_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$))].join("")),$overlay_83139_overlay_viewport_83157$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83050$jscomp$1$$,
$chunk__83051$jscomp$1$$,$count__83052$jscomp$1$$,$i__83053$jscomp$1$$,$overlay_viewport_83138$jscomp$1$$,$vec__83063$jscomp$1$$,$overlay_frame_id$jscomp$1$$){return function($p1__83007_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__83007_SHARP_$$)),$overlay_frame_id$jscomp$1$$)}}($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,
$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$G__83155_count__83052$$,$i__83053$$,$overlay_viewport_83138_seq__83050__$1$$,$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$G__83154_animation_vals$$,$data$jscomp$514$$,$map__83011__$1$$,$file$jscomp$203$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$44$$,$allowed$jscomp$1$$,$local$jscomp$38$$,$nav_scroll$$,
$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$186$$,$text_shapes$jscomp$5$$,$zoom$jscomp$175$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$110$$,$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$12$$,$orig_frame$jscomp$4$$,$size$jscomp$168$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$71$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,
$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$591$$,$section$jscomp$50$$,$interactions_mode$jscomp$5$$,$page_id$jscomp$471$$,$share$jscomp$2$$,$share_id$jscomp$30$$),$overlays$jscomp$12$$),$overlay_83158_overlay_size_83140$$=$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83139_overlay_viewport_83157$$),$zoom$jscomp$175$$),$overlay_position_83141_overlay_size_83159$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83139_overlay_viewport_83157$$))*$zoom$jscomp$175$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83139_overlay_viewport_83157$$))*$zoom$jscomp$175$$],null);$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$5279$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$))?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83050$jscomp$2$$,$chunk__83051$jscomp$2$$,$count__83052$jscomp$2$$,$i__83053$jscomp$2$$,$overlay_viewport_83138$jscomp$2$$,$overlay_83139$jscomp$1$$,$overlay_size_83140$jscomp$1$$,$overlay_position_83141$jscomp$1$$,$vec__83063$jscomp$2$$,$overlay_frame_id$jscomp$2$$,$animation_vals$jscomp$2$$){return function($p1__83008_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83008_SHARP_$$),
$APP.$cljs$cst$5279$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($animation_vals$jscomp$2$$))}}($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$G__83155_count__83052$$,$i__83053$$,$overlay_viewport_83138_seq__83050__$1$$,$overlay_83139_overlay_viewport_83157$$,$overlay_83158_overlay_size_83140$$,$overlay_position_83141_overlay_size_83159$$,$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,
$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$G__83154_animation_vals$$,$data$jscomp$514$$,$map__83011__$1$$,$file$jscomp$203$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$44$$,$allowed$jscomp$1$$,$local$jscomp$38$$,$nav_scroll$$,$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$186$$,$text_shapes$jscomp$5$$,$zoom$jscomp$175$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$110$$,
$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$12$$,$orig_frame$jscomp$4$$,$size$jscomp$168$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$71$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$591$$,$section$jscomp$50$$,$interactions_mode$jscomp$5$$,$page_id$jscomp$471$$,$share$jscomp$2$$,$share_id$jscomp$30$$),$frames$jscomp$36$$):null;$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$=
$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$frame$jscomp$110$$,$zoom$jscomp$175$$);$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$=$APP.$cljs$core$truth_$$($G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,
$zoom$jscomp$175$$):null;$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$=$app$main$ui$viewer$calculate_wrapper$$($overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,$zoom$jscomp$175$$);$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$=$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$);switch($G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$ instanceof
$APP.$cljs$core$Keyword$$?$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$.$fqn$:null){case "open-overlay":$app$main$ui$viewer$interactions$animate_open_overlay$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$),$overlay_viewport_83138_seq__83050__$1$$,$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$overlay_83158_overlay_size_83140$$,$overlay_position_83141_overlay_size_83159$$);break;case "close-overlay":$app$main$ui$viewer$interactions$animate_close_overlay$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$),
$overlay_viewport_83138_seq__83050__$1$$,$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$overlay_83158_overlay_size_83140$$,$overlay_position_83141_overlay_size_83159$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83139_overlay_viewport_83157$$)))}$i__83053$$+=1}else{var $temp__5825__auto__$jscomp$461$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$);if($temp__5825__auto__$jscomp$461$$){$overlay_viewport_83138_seq__83050__$1$$=
$temp__5825__auto__$jscomp$461$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($overlay_viewport_83138_seq__83050__$1$$))$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$=$APP.$cljs$core$_chunked_first$$($overlay_viewport_83138_seq__83050__$1$$),$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=$APP.$cljs$core$_chunked_rest$$($overlay_viewport_83138_seq__83050__$1$$),$G__83154_animation_vals$$=$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,
$G__83155_count__83052$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$),$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$=$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=$G__83154_animation_vals$$;else{var $vec__83067$$=$APP.$cljs$core$first$$($overlay_viewport_83138_seq__83050__$1$$);$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__83067$$,0,null);$G__83154_animation_vals$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__83067$$,1,null);$overlay_83139_overlay_viewport_83157$$=$APP.$app$util$dom$get_element$$(["overlay-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5284$overlay_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$))].join(""));$overlay_83158_overlay_size_83140$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83050$jscomp$3$$,
$chunk__83051$jscomp$3$$,$count__83052$jscomp$3$$,$i__83053$jscomp$3$$,$overlay_viewport_83157$jscomp$1$$,$vec__83067$jscomp$1$$,$overlay_frame_id$jscomp$3$$){return function($p1__83007_SHARP_$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__83007_SHARP_$jscomp$1$$)),$overlay_frame_id$jscomp$3$$)}}($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,
$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$G__83155_count__83052$$,$i__83053$$,$overlay_83139_overlay_viewport_83157$$,$vec__83067$$,$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$G__83154_animation_vals$$,$overlay_viewport_83138_seq__83050__$1$$,$temp__5825__auto__$jscomp$461$$,$data$jscomp$514$$,$map__83011__$1$$,$file$jscomp$203$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$44$$,$allowed$jscomp$1$$,$local$jscomp$38$$,$nav_scroll$$,
$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$186$$,$text_shapes$jscomp$5$$,$zoom$jscomp$175$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$110$$,$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$12$$,$orig_frame$jscomp$4$$,$size$jscomp$168$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$71$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,
$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$591$$,$section$jscomp$50$$,$interactions_mode$jscomp$5$$,$page_id$jscomp$471$$,$share$jscomp$2$$,$share_id$jscomp$30$$),$overlays$jscomp$12$$);$overlay_position_83141_overlay_size_83159$$=$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83158_overlay_size_83140$$),$zoom$jscomp$175$$);$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83158_overlay_size_83140$$))*$zoom$jscomp$175$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83158_overlay_size_83140$$))*$zoom$jscomp$175$$],null);$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$5279$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$))?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83050$jscomp$4$$,$chunk__83051$jscomp$4$$,$count__83052$jscomp$4$$,$i__83053$jscomp$4$$,$overlay_viewport_83157$jscomp$2$$,$overlay_83158$jscomp$1$$,$overlay_size_83159$jscomp$1$$,$overlay_position_83160$jscomp$1$$,$vec__83067$jscomp$2$$,$overlay_frame_id$jscomp$4$$,$animation_vals$jscomp$4$$){return function($p1__83008_SHARP_$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83008_SHARP_$jscomp$1$$),
$APP.$cljs$cst$5279$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($animation_vals$jscomp$4$$))}}($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$G__83155_count__83052$$,$i__83053$$,$overlay_83139_overlay_viewport_83157$$,$overlay_83158_overlay_size_83140$$,$overlay_position_83141_overlay_size_83159$$,$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,
$vec__83067$$,$overlay_frame_id_size_83143__$1_wrapper_size_83145__$1$$,$G__83154_animation_vals$$,$overlay_viewport_83138_seq__83050__$1$$,$temp__5825__auto__$jscomp$461$$,$data$jscomp$514$$,$map__83011__$1$$,$file$jscomp$203$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$44$$,$allowed$jscomp$1$$,$local$jscomp$38$$,$nav_scroll$$,$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$186$$,$text_shapes$jscomp$5$$,
$zoom$jscomp$175$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$110$$,$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$12$$,$orig_frame$jscomp$4$$,$size$jscomp$168$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$71$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$591$$,$section$jscomp$50$$,$interactions_mode$jscomp$5$$,$page_id$jscomp$471$$,$share$jscomp$2$$,$share_id$jscomp$30$$),
$frames$jscomp$36$$):null;$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$=$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$frame$jscomp$110$$,$zoom$jscomp$175$$);$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=$APP.$cljs$core$truth_$$($G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),
$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$zoom$jscomp$175$$):null;$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$=$app$main$ui$viewer$calculate_wrapper$$($c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$,$zoom$jscomp$175$$);$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$);
switch($G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$.$fqn$:null){case "open-overlay":$app$main$ui$viewer$interactions$animate_open_overlay$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$),$overlay_83139_overlay_viewport_83157$$,$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,
$overlay_position_83141_overlay_size_83159$$,$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$);break;case "close-overlay":$app$main$ui$viewer$interactions$animate_close_overlay$$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83154_animation_vals$$),$overlay_83139_overlay_viewport_83157$$,$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$,$overlay_position_83141_overlay_size_83159$$,$G__83066_83146_orig_frame_83142__$1_orig_size_83144__$1_overlay_position_83160_vec__83063$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83158_overlay_size_83140$$)))}$c__5548__auto__$jscomp$47_seq__83050_size_83162__$1_wrapper_size_83164__$1$$=$APP.$cljs$core$next$$($overlay_viewport_83138_seq__83050__$1$$);$G__83070_83165_G__83153_chunk__83051_orig_frame_83161__$1_orig_size_83163__$1$$=null;$G__83155_count__83052$$=0}$i__83053$$=0}else return null}else return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes$jscomp$5$$)],
function(){var $fonts$jscomp$45_text_nodes$jscomp$2$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__83009_SHARP_$$){return $APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($p1__83009_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$text_shapes$jscomp$5$$]));$fonts$jscomp$45_text_nodes$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1757$font_id$$),$fonts$jscomp$45_text_nodes$jscomp$2$$);return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,$fonts$jscomp$45_text_nodes$jscomp$2$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{id:"viewer-layout","data-fullscreen":$fullscreen_QMARK_$jscomp$1$$,"data-force-visible":$APP.$cljs$cst$5263$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38$$),className:($APP.$cljs$core$truth_$$($APP.$cljs$cst$5263$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38$$))?
"main_ui_viewer__force-visible":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$2672$inspect$$)?"main_ui_viewer__viewer-layout":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$2672$inspect$$)?"main_ui_viewer__inspect-layout":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer__viewer-content",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_thumbnails_close$$,className:"main_ui_viewer__thumbnails-close "+
($APP.$cljs$core$not$$($APP.$cljs$cst$5263$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$38$$,!1))?"main_ui_viewer__invisible":"")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnails_panel$$,{frames:$frames$jscomp$36$$,"show?":$APP.$cljs$cst$5263$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$38$$,!1),page:$page$jscomp$186$$,index:$index$jscomp$591$$,"thumbnail-data":$APP.$cljs$cst$2229$thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$203$$)}),
(0,$APP.$rumext$v2$jsx$$)("section",{id:"viewer-section",ref:$viewer_section_ref$$,"data-viewer-section":!0,onClick:$click_on_screen$$,className:"main_ui_viewer__viewer-section "+($APP.$cljs$core$truth_$$($fullscreen_QMARK_$jscomp$1$$)?"main_ui_viewer__fullscreen":""),children:$APP.$cljs$core$empty_QMARK_$$($frames$jscomp$36$$)?(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_viewer__empty-state",children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.empty-state")})}):
$frame$jscomp$110$$==null?(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_viewer__empty-state",children:$index$jscomp$591$$!=null?(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.frame-not-found")}):null}):$frame$jscomp$110$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2672$inspect$$,$section$jscomp$50$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$inspect$viewport$$,{"viewer-pagination":$app$main$ui$viewer$viewer_pagination$$,
frame:$frame$jscomp$110$$,index:$index$jscomp$591$$,section:$section$jscomp$50$$,file:$file$jscomp$203$$,page:$page$jscomp$186$$,size:$size$jscomp$168$$,"interactions-mode":$interactions_mode$jscomp$5$$,"share-id":$share_id$jscomp$30$$,local:$local$jscomp$38$$}):(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_zoom$$),{value:$zoom$jscomp$175$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_wrapper$$,{overlays:$overlays$jscomp$12$$,"wrapper-size":$wrapper_size$jscomp$5$$,
zoom:$zoom$jscomp$175$$,"orig-frame":$orig_frame$jscomp$4$$,frame:$frame$jscomp$110$$,index:$index$jscomp$591$$,section:$section$jscomp$50$$,file:$file$jscomp$203$$,"orig-viewport-ref":$orig_viewport_ref$jscomp$1$$,"orig-size":$orig_size$jscomp$2$$,"current-viewport-ref":$current_viewport_ref$jscomp$1$$,page:$page$jscomp$186$$,size:$size$jscomp$168$$,"interactions-mode":$interactions_mode$jscomp$5$$,users:$users$jscomp$6$$})}):null})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$viewer$header$header$$,
{zoom:$zoom$jscomp$175$$,permissions:$permissions$jscomp$44$$,frame:$frame$jscomp$110$$,index:$index$jscomp$591$$,section:$section$jscomp$50$$,file:$file$jscomp$203$$,"shown-thumbnails":$APP.$cljs$cst$5263$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38$$),page:$page$jscomp$186$$,"interactions-mode":$interactions_mode$jscomp$5$$,project:$project$jscomp$45$$,share:$share$jscomp$2$$})]})};
$app$main$ui$viewer$viewer_STAR_$$=function($props_83072_props__$1$jscomp$112$$){var $file_id$jscomp$456$$=$props_83072_props__$1$jscomp$112$$.fileId,$page_id$jscomp$476$$=$props_83072_props__$1$jscomp$112$$.pageId,$share_id$jscomp$35$$=$props_83072_props__$1$jscomp$112$$.shareId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$456$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$476$$),$APP.$rumext$v2$adapt$$($share_id$jscomp$35$$)],function(){var $params$jscomp$453$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$456$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$476$$,$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$35$$],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$initialize$$($params$jscomp$453$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$finalize$$($params$jscomp$453$$))}});var $temp__5823__auto__$jscomp$267$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_data$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$267$$)?($props_83072_props__$1$jscomp$112$$=$APP.$app$util$object$merge$cljs$0core$0IFn$0_invoke$0arity$02$$($props_83072_props__$1$jscomp$112$$,{data:$temp__5823__auto__$jscomp$267$$,key:""+($file_id$jscomp$456$$??"")}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,{}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$viewer$viewer_content_STAR_$$,
$props_83072_props__$1$jscomp$112$$)]})):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})};$APP.$app$main$ui$viewer$viewer_page_STAR_$$=function($props_83074$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$viewer$viewer_STAR_$$,$props_83074$$)};$cljs$cst$6334$left_bar$$=new $APP.$cljs$core$Keyword$$(null,"left-bar","left-bar",569281306);
$cljs$cst$6330$thumbnail_data$$=new $APP.$cljs$core$Keyword$$(null,"thumbnail-data","thumbnail-data",-924635553);$cljs$cst$6324$email_sent$$=new $APP.$cljs$core$Keyword$$(null,"email-sent","email-sent",-1405729778);$cljs$cst$6335$right_bar$$=new $APP.$cljs$core$Keyword$$(null,"right-bar","right-bar",149870584);$cljs$cst$6326$all_pages$$=new $APP.$cljs$core$Keyword$$(null,"all-pages","all-pages",1017563062);
$cljs$cst$6329$expanded_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"expanded?","expanded?",2055832296);$cljs$cst$6325$pages_mode$$=new $APP.$cljs$core$Keyword$$(null,"pages-mode","pages-mode",1390854462);$cljs$cst$6333$num_frames$$=new $APP.$cljs$core$Keyword$$(null,"num-frames","num-frames",1569426540);$cljs$cst$6323$register$$=new $APP.$cljs$core$Keyword$$(null,"register","register",1968522516);
$cljs$cst$6328$can_inspect_code$$=new $APP.$cljs$core$Keyword$$(null,"can-inspect-code","can-inspect-code",-411585714);$cljs$cst$6338$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.ui.viewer","viewer","app.main.ui.viewer/viewer",-223008833);$cljs$cst$6331$base_width$$=new $APP.$cljs$core$Keyword$$(null,"base-width","base-width",127450703);$cljs$cst$6337$wrapper_size$$=new $APP.$cljs$core$Keyword$$(null,"wrapper-size","wrapper-size",-1999142846);
$cljs$cst$6336$comment_sidebar$$=new $APP.$cljs$core$Keyword$$(null,"comment-sidebar","comment-sidebar",-717905737);$cljs$cst$6321$hide_toggle_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hide-toggle?","hide-toggle?",-1874012773);$cljs$cst$6332$base_height$$=new $APP.$cljs$core$Keyword$$(null,"base-height","base-height",1012620781);$cljs$cst$6320$component_child_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"component-child?","component-child?",166589243);
$cljs$cst$6327$can_comment$$=new $APP.$cljs$core$Keyword$$(null,"can-comment","can-comment",718623455);$cljs$cst$6319$item$$=new $APP.$cljs$core$Keyword$$(null,"item","item",249373802);$cljs$cst$6322$viewer_pagination$$=new $APP.$cljs$core$Keyword$$(null,"viewer-pagination","viewer-pagination",-181925280);var $app$main$ui$inspect$left_sidebar$layer_item$$=function $app$main$ui$inspect$left_sidebar$layer_item$$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$){$hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$=$APP.$rumext$v2$util$wrap_props$$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$);$hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$=$APP.$cljs$core$__destructure_map$$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$);var $item$jscomp$148$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,$cljs$cst$6319$item$$),$selected$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,$APP.$cljs$cst$1921$selected$$),$objects$jscomp$840$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,$APP.$cljs$cst$1631$objects$$),$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,$APP.$cljs$cst$839$depth$$),$component_child_QMARK__select_shape$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,$cljs$cst$6320$component_child_QMARK_$$);$hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,
$cljs$cst$6321$hide_toggle_QMARK_$$);var $id$jscomp$1077$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$148$$),$selected_QMARK_$jscomp$29$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$218$$,$id$jscomp$1077$$),$item_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(null),$depth__$1$jscomp$1$$=$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$+1,$component_tree_QMARK_$$=$APP.$cljs$core$truth_$$($component_child_QMARK__select_shape$jscomp$1$$)?$component_child_QMARK__select_shape$jscomp$1$$:
$APP.$app$common$types$component$instance_root_QMARK_$$($item$jscomp$148$$)||$APP.$app$common$types$component$instance_head_QMARK_$$($item$jscomp$148$$);$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1077$$)],$app$main$ui$inspect$left_sidebar$make_collapsed_iref$$($id$jscomp$1077$$));var $expanded_QMARK_$jscomp$2$$=$APP.$cljs$core$not$$($APP.$rumext$v2$deref$$($collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$));
$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1077$$)],function($event$jscomp$763$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$763$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_collapse$$($id$jscomp$1077$$))});$component_child_QMARK__select_shape$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1077$$)],
function($event$jscomp$764$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$764$$);return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$764$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_selection$$($id$jscomp$1077$$)):$event$jscomp$764$$.shiftKey?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$shift_select_to$$($id$jscomp$1077$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($id$jscomp$1077$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$218$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$218$$),1)&&$selected_QMARK_$jscomp$29$$?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($item_ref$jscomp$8$$),!0):null});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_inner_STAR_$$,
{onSelectShape:$component_child_QMARK__select_shape$jscomp$1$$,children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1027$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$148$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1027$$)?$expanded_QMARK_$jscomp$2$$:$and__5023__auto__$jscomp$1027$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"children-"+($id$jscomp$1077$$??""),className:"main_ui_inspect_left_sidebar__element-children "+($selected_QMARK_$jscomp$29$$?
"main_ui_inspect_left_sidebar__parent-selected":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$250$$,$JSCompiler_temp_const$jscomp$2018_p__82918$$){var $JSCompiler_inline_result$jscomp$2020_index$jscomp$584$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2018_p__82918$$,0,null),$id__$1$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2018_p__82918$$,
1,null);$JSCompiler_temp_const$jscomp$2018_p__82918$$=$out_arr__44124__auto__$jscomp$250$$.push;var $temp__5825__auto__$jscomp$inline_9588$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$840$$,$id__$1$jscomp$22$$);$JSCompiler_inline_result$jscomp$2020_index$jscomp$584$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_9588$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$left_sidebar$layer_item$$,{item:$temp__5825__auto__$jscomp$inline_9588$$,selected:$selected$jscomp$218$$,
index:$JSCompiler_inline_result$jscomp$2020_index$jscomp$584$$,objects:$objects$jscomp$840$$,depth:$depth__$1$jscomp$1$$,"component-child?":$component_tree_QMARK_$$},""+($id__$1$jscomp$22$$??"")):null;$JSCompiler_temp_const$jscomp$2018_p__82918$$.call($out_arr__44124__auto__$jscomp$250$$,$JSCompiler_inline_result$jscomp$2020_index$jscomp$584$$);return $out_arr__44124__auto__$jscomp$250$$},[],$APP.$cljs$core$reverse$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$148$$))))}):
null,isComponentTree:$component_tree_QMARK_$$,isExpanded:$expanded_QMARK_$jscomp$2$$,isFiltered:!1,item:$item$jscomp$148$$,hideToggle:$hide_toggle_QMARK__map__82917_map__82917__$1_props_82916$$,isHighlighted:!1,ref:$item_ref$jscomp$8$$,depth:$depth__$1$jscomp$1$$,isSelected:$selected_QMARK_$jscomp$29$$,isReadOnly:!0,onToggleCollapse:$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$})};$APP.$app$common$logging$loggers$$.set("app.main.ui.viewer.login",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$51$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$51$$,$APP.$cljs$cst$5398$login_register$$,$app$main$ui$viewer$login$login_register_modal$$)});$APP.$app$common$logging$loggers$$.set("app.main.ui.viewer.share-link",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$52$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$52$$,$APP.$cljs$cst$5400$share_link$$,$app$main$ui$viewer$share_link$share_link_dialog$$)});var $app$main$ui$viewer$thumbnails$thumbnail_item$$,$p1__82967_SHARP_$jscomp$inline_9590$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__82970_props_82969_selected_QMARK_$jscomp$30$$){$map__82970_props_82969_selected_QMARK_$jscomp$30$$=$APP.$rumext$v2$util$wrap_props$$($map__82970_props_82969_selected_QMARK_$jscomp$30$$);var $map__82970__$1_thumbnail_data$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__82970_props_82969_selected_QMARK_$jscomp$30$$);$map__82970_props_82969_selected_QMARK_$jscomp$30$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,$APP.$cljs$cst$5784$selected_QMARK_$$);var $frame$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,$APP.$cljs$cst$1606$frame$$),$on_click$jscomp$69$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,$APP.$cljs$cst$3386$on_click$$),$index$jscomp$586$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,
$APP.$cljs$cst$1795$index$$),$objects$jscomp$848$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,$APP.$cljs$cst$1631$objects$$),$page_id$jscomp$470$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,$APP.$cljs$cst$2043$page_id$$);$map__82970__$1_thumbnail_data$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,$cljs$cst$6330$thumbnail_data$$);var $children_bounds$jscomp$3_children_ids$jscomp$13$$=
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$848$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$104$$));$children_bounds$jscomp$3_children_ids$jscomp$13$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame$jscomp$104$$],null),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($objects$jscomp$848$$),
$children_bounds$jscomp$3_children_ids$jscomp$13$$)));return(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:function($p1__82968_SHARP_$$){return $on_click$jscomp$69$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$69$$.$cljs$core$IFn$_invoke$arity$2$($p1__82968_SHARP_$$,$index$jscomp$586$$):$on_click$jscomp$69$$($p1__82968_SHARP_$$,$index$jscomp$586$$)},className:"main_ui_viewer_thumbnails__thumbnail-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_thumbnails__thumbnail-preview "+
($APP.$cljs$core$truth_$$($map__82970_props_82969_selected_QMARK_$jscomp$30$$)?"main_ui_viewer_thumbnails__selected":""),children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$frame_svg$$,{frame:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($frame$jscomp$104$$,$APP.$cljs$cst$5161$thumbnail$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82970__$1_thumbnail_data$jscomp$1$$,""+($page_id$jscomp$470$$??"")+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$104$$)??
""))),$APP.$cljs$cst$1913$children_bounds$$,$children_bounds$jscomp$3_children_ids$jscomp$13$$),objects:$objects$jscomp$848$$,"use-thumbnails":!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$104$$),className:"main_ui_viewer_thumbnails__thumbnail-info",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$104$$)})]})});
$app$main$ui$viewer$thumbnails$thumbnail_item$$=$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__82967_SHARP_$jscomp$inline_9590$$,$APP.$app$util$timers$idle_then_raf$$);var $app$main$ui$viewer$current_animations_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5266$viewer_animations$$,$APP.$app$main$store$state$$),$app$main$ui$viewer$current_overlays_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2232$viewer_overlays$$,$APP.$app$main$store$state$$),$app$main$ui$viewer$viewer_pagination_and_sidebar$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$589_map__82990_props_82989$$){$index$jscomp$589_map__82990_props_82989$$=
$APP.$rumext$v2$util$wrap_props$$($index$jscomp$589_map__82990_props_82989$$);var $map__82990__$1_page$jscomp$183$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$589_map__82990_props_82989$$),$and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82990__$1_page$jscomp$183$$,$APP.$cljs$cst$1366$section$$);$index$jscomp$589_map__82990_props_82989$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82990__$1_page$jscomp$183$$,
$APP.$cljs$cst$1795$index$$);var $users$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82990__$1_page$jscomp$183$$,$APP.$cljs$cst$5245$users$$),$frame$jscomp$107$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82990__$1_page$jscomp$183$$,$APP.$cljs$cst$1606$frame$$);$map__82990__$1_page$jscomp$183$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82990__$1_page$jscomp$183$$,$APP.$cljs$cst$1624$page$$);var $comments_local$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$);
$and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$=($and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$,$APP.$cljs$cst$3436$comments$$))?$APP.$cljs$cst$5013$show_sidebar_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($comments_local$$):$and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$;
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_pagination$$,{index:$index$jscomp$589_map__82990_props_82989$$,"num-frames":$APP.$cljs$core$count$$($APP.$cljs$cst$5241$frames$$.$cljs$core$IFn$_invoke$arity$1$($map__82990__$1_page$jscomp$183$$)),"comment-sidebar":$and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$}),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9592_section$jscomp$48_show_sidebar_QMARK_$jscomp$1$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$comments$comments_sidebar_STAR_$$,{profiles:$users$jscomp$4$$,frame:$frame$jscomp$107$$,page:$map__82990__$1_page$jscomp$183$$}):null]})});
//# sourceMappingURL=main-viewer.js.map
