import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$,$goog$functions$throttle$$,$module$contents$goog$array_slice$$,$module$contents$goog$array_splice$$,$cljs$tools$reader$macro_terminating_QMARK_$$,$app$common$math$sq$$,$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$,$goog$dom$getElementsByClass$$,$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$dom$select_target$$,$app$util$dom$get_parent_with_selector$$,$app$util$dom$valid_QMARK_$$,
$app$util$dom$set_value_BANG_$$,$app$util$dom$set_style_BANG_$$,$app$util$dom$is_in_viewport_QMARK_$$,$rumext$v2$throttle$$,$app$common$types$color$hue__GT_rgb$$,$app$common$types$tokens_lib$get_set_names$$,$app$common$types$tokens_lib$get_sets_at_path$$,$app$common$types$tokens_lib$enable_sets$$,$app$common$types$tokens_lib$disable_sets$$,$app$common$types$tokens_lib$set_path_exists_QMARK_$$,$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$,$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$,
$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$,$app$common$types$tokens_lib$get_all_tokens$$,$app$util$keyboard$mod_event_QMARK_$$,$app$util$mouse$get_pointer_movement$$,$app$main$ui$hooks$sortable_container_STAR_$$,$app$util$text$content$to_dom$create_random_key$$,$app$util$array$normalize_to_array$$,$app$util$array$without_nils$$,$app$util$array$filter$$,$app$util$text_editor$editor_select_all$$,$app$util$text_editor$cursor_to_end$$,$app$main$data$tinycolor$__GT_string$$,$app$main$ui$css_cursors$get_dynamic$$,
$cljs$tools$reader$ending_line_col_info$$,$cljs$tools$reader$starting_line_col_info$$,$app$util$dom$left_mouse_QMARK_$$,$app$util$dom$active_QMARK_$$,$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$,$app$render_wasm$api$end_page_transition_BANG_$$,$app$main$data$workspace$colors$recent_color_equal_QMARK_$$,$app$main$data$workspace$specialized_panel$interrupt_QMARK_$$,$app$util$shape_icon$get_shape_icon_by_type$$,$app$util$mouse$mouse_click_event_QMARK_$$,$app$common$types$shape$interactions$has_offset_effect_QMARK_$$,
$app$common$types$shape$interactions$has_way_QMARK_$$,$app$main$data$workspace$notifications$finalize$$,$app$main$ui$hooks$use_ref_callback$$,$app$main$ui$hooks$use_update_ref$$,$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$not_any_QMARK_$$,$cljs$core$not_every_QMARK_$$,$cljs$tools$reader$flatten_map$$,$app$common$path_names$merge_path_item_with_dot$$,$app$common$types$token$build_result$$,$promesa$impl$promise$all$$,$cljs$spec$alpha$explain_data_STAR_$$,$app$common$data$nth_index_of_STAR_$$,
$cljs$core$Namespace$$,$app$common$types$text$replace_all_case_insensitive$$,$app$common$types$color$remove_hash$$,$app$common$data$macros$truncate$$,$app$util$array$sort_BANG_$$,$app$render_wasm$api$begin_page_transition_BANG_$$,$app$render_wasm$api$apply_canvas_blur$$,$app$render_wasm$api$start_initial_load_transition_BANG_$$,$app$main$ui$workspace$viewport$utils$title_transform_use_width_QMARK_$$,$app$main$ui$workspace$viewport$utils$text_transform$$,$app$common$geom$shapes$intersect$on_segment_QMARK_$$,
$app$common$geom$shapes$intersect$orientation$$,$app$common$files$helpers$hidden_parent_QMARK_$$,$app$main$data$helpers$split_text_shapes$$,$app$common$files$helpers$unframed_shape_QMARK_$$,$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$versions$apply_snapshot$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition$$,
$app$main$data$workspace$colors$update_colorpicker_gradient$$,$app$main$data$workspace$common$toggle_toolbar_visibility$$,$app$main$data$modal$update_props$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$,$app$main$data$workspace$set_clipboard_style$$,$app$main$data$workspace$set_annotations_expanded$$,$app$main$data$workspace$start_rename_page_item$$,$app$main$data$workspace$set_margins_selected$$,$app$main$data$workspace$set_gap_selected$$,$app$main$data$workspace$set_paddings_selected$$,
$app$main$data$workspace$show_guide_context_menu$$,$app$main$data$workspace$show_page_item_context_menu$$,$app$main$data$workspace$set_assets_group_open$$,$app$main$data$workspace$set_assets_section_open$$,$app$main$data$workspace$workspace_focus_lost$$,$app$main$data$workspace$path$selection$update_area_selection$$,$app$main$data$workspace$path$drawing$reset_last_handler$$,$app$main$data$workspace$colors$pick_color_select$$,$app$main$data$workspace$colors$pick_color$$,$app$main$data$workspace$selection$update_selrect$$,
$app$main$data$workspace$update_layers_search_scope$$,$app$main$data$workspace$colors$select_colorpicker_gradient_stop$$,$app$common$types$file$get_base_font_size$$,$app$main$data$workspace$texts$cursor_to_end$$,$app$main$data$workspace$texts$select_all$$,$app$main$data$helpers$update_file$cljs$0core$0IFn$0_invoke$0arity$03$$,$clojure$set$superset_QMARK_$$,$app$common$files$tokens$shapes_applied_all_QMARK_$$,$cljs$tools$reader$unquote_QMARK_$$,$cljs$tools$reader$unquote_splicing_QMARK_$$,$app$main$data$workspace$set_preview_blend_mode$$,
$cljs$core$js_reserved_QMARK_$$,$app$main$data$workspace$grid_layout$editor$remove_selection$$,$app$main$data$workspace$path$selection$path_handler_leave$$,$app$main$data$workspace$path$selection$path_pointer_leave$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$,$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$,$app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$,$app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$,
$app$main$data$workspace$unset_preview_blend_mode$$,$app$main$data$workspace$stop_rename_page_item$$,$app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing$$,$app$main$data$workspace$grid_layout$editor$clear_selection$$,$app$main$data$workspace$path$selection$clear_area_selection$$,$app$main$data$workspace$path$drawing$close_path_drag_end$$,$app$main$data$workspace$colors$activate_colorpicker_image$$,$app$main$data$workspace$colors$finalize_colorpicker$$,
$app$main$data$workspace$colors$clear_color_components$$,$app$main$data$workspace$texts$clean_text_modifier$$,$app$main$data$workspace$texts$update_editor$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel$$,$app$main$data$project$finalize_project$$,$app$main$data$persistence$discard_persistence_state$$,$app$main$data$workspace$set_annotations_id_for_create$$,$app$util$text$content$to_dom$set_dataset$$,$app$main$ui$hooks$use_rxsub$$,$app$common$geom$shapes$intersect$intersects_line_ellipse_QMARK_$$,
$app$common$types$color$hsl__GT_rgb$$,$app$common$types$color$hex__GT_hsv$$,$app$common$types$color$sort_colors$$,$rumext$v2$use_debounce$$,$app$common$types$pages_list$get_last_page$$,$app$main$data$workspace$clear_assets_section_open$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$,$app$main$data$workspace$comments$handle_comment_layer_click$$,$app$main$data$workspace$common$initialized_QMARK_$$,$app$main$ui$workspace$viewport$utils$format_viewbox$$,$app$main$data$workspace$viewport$update_viewport_size$$,
$app$main$data$workspace$drawing$set_default_size$$,$app$main$data$workspace$transforms$fix_init_point$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation$$,$app$common$types$file$find_remote_shape$$,$app$main$data$workspace$colors$stop_picker$$,$app$main$data$workspace$colors$start_picker$$,$app$main$data$workspace$show_track_context_menu$$,$app$main$data$workspace$versions$exit_preview_cleanup$$,$app$main$data$workspace$versions$update_versions_state$$,$app$main$data$workspace$drawing$change_orientation$$,
$app$common$files$variant$get_primary_component$$,$cljs$core$TaggedLiteral$$,$cljs$tools$reader$garg$$,$app$main$data$workspace$versions$fetch_versions$$,$app$main$data$workspace$versions$unlock_version$$,$app$main$data$workspace$versions$lock_version$$,$app$main$data$workspace$versions$delete_version$$,$app$main$data$workspace$versions$rename_version$$,$app$main$data$workspace$versions$init_versions_state$$,$app$main$data$workspace$rename_file$$,$app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$,
$app$main$data$workspace$pages$finalize_page$$,$app$main$data$workspace$texts$gen_name$$,$app$common$types$shape$interactions$allowed_animation_QMARK_$$,$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$,$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$,$app$main$data$workspace$libraries$set_file_shared$$,$app$util$clipboard$to_clipboard_multi$$,$app$main$data$workspace$versions$pin_version$$,$app$main$data$workspace$texts$save_font$$,$app$common$geom$point$resize$$,$app$main$data$workspace$interactions$move_overlay_pos$$,
$app$main$data$workspace$path$streams$get_angle$$,$promesa$core$all$$,$malli$error$_get$$,$app$common$types$tokens_lib$split_set_str_path_prefix$$,$app$main$data$workspace$colors$split_color_components$$,$app$common$types$color$library_color__GT_color$$,$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$fonts$get_node_fonts$$,$app$common$types$text$content_has_text_QMARK_$$,$app$common$types$shape$layout$cells_in_area$$,$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$types$shape$layout$cells_by_column$$,$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$shape$layout$cells_by_row$$,$app$common$types$shape$layout$remove_cell_areas_after$$,$app$common$types$shape$layout$remove_cell_areas$$,$app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$tokens$errors$detail_errors$$,$app$main$data$workspace$tokens$errors$humanize_errors$$,
$app$main$data$workspace$show_grid_cell_context_menu$$,$app$main$data$workspace$pages$delete_page_components$$,$app$common$types$color$offset_spread$$,$app$common$types$shape$layout$swap_track_content$$,$app$common$data$natural_sort_key$$,$app$common$data$natural_compare$$,$app$common$data$invert_map$$,$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$color$hsv__GT_rgb$$,$app$main$data$workspace$grid_layout$editor$locate_board$$,$app$util$dom$bounding_rect__GT_rect$$,
$app$common$geom$shapes$text$overlaps_position_data_QMARK_$$,$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$,$app$common$types$text$replace_text_in_content$$,$cljs$spec$alpha$abbrev$$,$app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$,$app$main$data$workspace$viewport$finish_panning$$,$app$main$data$workspace$zoom$finish_zooming$$,$app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$,$app$main$data$workspace$viewport$activate_panning$$,$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$,
$app$render_wasm$text_editor$text_editor_blur$$,$app$render_wasm$text_editor$text_editor_select_word_boundary$$,$app$render_wasm$text_editor$text_editor_select_all$$,$app$render_wasm$text_editor$text_editor_move_cursor$$,$app$render_wasm$text_editor$text_editor_insert_paragraph$$,$app$render_wasm$text_editor$text_editor_delete_forward$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$render_wasm$text_editor$text_editor_pointer_up$$,
$app$render_wasm$text_editor$text_editor_pointer_move$$,$app$render_wasm$text_editor$text_editor_pointer_down$$,$app$render_wasm$text_editor$text_editor_toggle_overtype_mode$$,$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$,$app$render_wasm$text_editor$text_editor_focus$$,$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$render_wasm$text_editor$text_editor_export_selection$$,$app$render_wasm$text_editor$text_editor_encode_text_pre$$,
$app$render_wasm$text_editor$text_editor_insert_text$$,$app$main$data$workspace$transforms$get_handler_resize_origin$$,$app$main$data$workspace$transforms$get_handler_multiplier$$,$app$common$types$shape$interactions$calc_overlay_pos_initial$$,$app$common$types$shape$interactions$set_destination$$,$app$common$types$shape$interactions$set_action_type$$,$app$common$geom$shapes$distance_selrect$$,$app$common$geom$shapes$intersect$intersects_lines_ellipse_QMARK_$$,$app$common$types$path$get_handler$$,
$app$common$types$path$segment$curve_closest_point$$,$app$common$types$path$segment$path__GT_lines$$,$app$common$types$path$segment$closest_point$$,$app$util$dom$get_delta_position$$,$app$common$geom$shapes$has_point_rect_QMARK_$$,$app$main$data$helpers$get_selrect$$,$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$,$app$common$geom$point$normal_right$$,$app$main$data$persistence$discard_commit$$,$app$common$types$color$interpolate_color$$,$app$common$types$color$interpolate_gradient$$,
$app$main$data$workspace$colors$update_colorpicker_add_stop$$,$app$common$types$color$uniform_spread_QMARK_$$,$app$common$types$color$hsv__GT_hex$$,$cljs$tools$reader$resolve_symbol$$,$cljs$tools$reader$register_gensym$$,$cljs$tools$reader$register_arg$$,$cljs$tools$reader$check_eof_error$$,$cljs$tools$reader$read_regex$$,$cljs$tools$reader$read_token$$,$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$tools$reader$read_char_STAR_$$,$cljs$tools$reader$read_unmatched_delimiter$$,
$cljs$tools$reader$read_keyword$$,$cljs$tools$reader$read_symbol$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog$$,$app$main$data$workspace$colors$sort_colorpicker_stops$$,$app$common$text$fix_gradients$$,$app$common$text$build_style_index$$,$app$render_wasm$text_editor$merge_exported_texts_into_content$$,$app$common$types$variant$compare_properties$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$color$uniform_spread$$,$app$main$data$workspace$colors$update_colorpicker_add_auto$$,
$app$common$types$tokens_lib$update_tokens_group$$,$app$util$webapi$read_file_as_text$$,$app$util$strings$matches_search$$,$app$common$types$variant$find_boolean_pair$$,$app$common$types$file$get_shape_in_copy$$,$app$util$text_editor$get_content_changes$$,$app$common$geom$shapes$intersect$overlaps_text_QMARK_$$,$app$common$geom$shapes$intersect$overlaps_QMARK_$$,$app$common$types$shape$interactions$remove_interactions$$,$app$main$data$workspace$colors$get_color_from_colorpicker_state$$,$app$main$data$workspace$colors$colorpicker_onchange_runner$$,
$app$main$data$workspace$colors$initialize_colorpicker$$,$app$main$data$workspace$colors$materialize_color_components$$,$app$main$data$workspace$colors$activate_colorpicker_gradient$$,$app$util$text$content$to_dom$get_styles_from_attrs$$,$app$main$data$persistence$merge_commit$$,$app$common$path_names$sort_by_children$$,$app$common$path_names$compact_path$$,$app$common$data$reorder$$,$cljs$core$sorted_map$$,$app$common$path_names$join_path_with_dot$$,$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$common$path_names$group_by_first_segment$$,$app$common$path_names$sort_and_group_segments$$,$app$common$path_names$build_tree_root$$,$app$common$path_names$butlast_path$$,$app$common$types$token$join_font_family$$,$app$main$data$workspace$texts$generate_typography_name$$,$app$common$types$path$get_handlers$$,$app$common$types$path$segment$is_curve_QMARK_$$,$cljs$core$dedupe$cljs$0core$0IFn$0_invoke$0arity$00$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$,$app$main$data$workspace$colors$update_colorpicker_stops$$,
$app$main$data$fonts$update_recent_font$$,$app$common$path_names$inside_path_QMARK_$$,$app$main$data$workspace$texts$focus_editor$$,$app$main$features$use_feature$$,$app$main$data$workspace$versions$create_version$$,$app$main$refs$workspace_grid_edition_id$$,$app$main$refs$workspace_thumbnail_rendered_at$$,$app$main$refs$workspace_token_in_selected_set$$,$app$main$refs$grid_layout_child_QMARK_$$,$app$main$refs$flex_layout_child_QMARK_$$,$app$main$refs$all_layout_child_QMARK_$$,$app$main$refs$is_layout_child_QMARK_$$,
$app$main$refs$shape_parents$$,$app$main$refs$objects_by_id$$,$app$main$refs$object_by_id$$,$app$main$refs$token_sets_at_path_all_active$$,$app$main$refs$workspace_token_theme$$,$app$main$data$modal$allow_click_outside_BANG_$$,$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$shape$interactions$flow_to_QMARK_$$,$app$common$types$shape$interactions$flow_origin_QMARK_$$,$app$common$types$shape$interactions$has_direction_QMARK_$$,$app$common$types$shape$interactions$has_easing_QMARK_$$,
$app$common$types$shape$interactions$has_duration_QMARK_$$,$app$common$types$shape$interactions$has_animation_QMARK_$$,$app$common$types$shape$interactions$has_overlay_opts$$,$app$common$types$shape$interactions$destination_QMARK_$$,$app$main$data$workspace$bool$bool__GT_group$$,$app$common$types$modifiers$change_orientation_modifiers$$,$app$main$data$workspace$transforms$rotation_modifiers$$,$app$common$types$modifiers$resize_parent$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$types$modifiers$move_parent$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$util$dom$prevent_default_context_menu$$,$app$main$data$workspace$viewport$start_panning$$,$app$main$data$workspace$viewport$initialize_viewport$$,$app$main$data$workspace$viewport$sync_wasm_workspace_viewport$$,$app$main$data$workspace$zoom$start_zooming$$,$app$common$types$tokens_lib$group_by_type$$,$app$main$ui$hooks$resize$use_resize_observer$$,$app$main$data$persistence$update_file_revn$$,$app$main$data$persistence$update_status$$,$app$main$data$persistence$persist_commit$$,$app$main$data$persistence$append_commit$$,
$app$main$data$persistence$initialize_persistence$$,$cljs$tools$reader$impl$utils$ReaderConditional$$,$cljs$tools$reader$impl$utils$reader_conditional$$,$cljs$tools$reader$add_meta$$,$cljs$tools$reader$syntax_quote_coll$$,$cljs$tools$reader$syntax_quote_STAR_$$,$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$,$app$common$logic$tokens$toggle_token_set_group$$,$app$common$files$tokens$shapes_ids_by_applied_attributes$$,$app$main$data$workspace$select_assets$$,$app$main$data$workspace$check_in_asset$$,
$app$main$data$workspace$toggle_selected_assets$$,$app$main$data$workspace$grid_layout$editor$select_track_cells$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell$$,$app$main$data$workspace$guides$set_hover_guide$$,$app$main$data$workspace$path$selection$deselect_all$$,$app$main$data$workspace$path$selection$path_handler_enter$$,$app$main$data$workspace$path$selection$path_pointer_enter$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries$$,$app$main$data$workspace$libraries$unlink_file_from_library$$,
$app$main$refs$parents_by_ids$$,$app$main$data$workspace$path$edition$move_selected_path_point$$,$app$main$data$workspace$path$edition$modify_handler$$,$app$main$data$workspace$path$selection$select_node_area$$,$app$main$data$workspace$path$selection$handle_area_selection$$,$app$common$geom$shapes$transforms$update_shapes_geometry$$,$app$common$geom$shapes$update_shapes_geometry$$,$app$main$data$workspace$shape_layout$copy_grid_tracks$$,$app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$common$types$shape$layout$valid_area_cells_QMARK_$$,$app$common$types$shape$layout$duplicate_cells$$,$app$common$types$shape_tree$get_root_shapes$$,$app$common$types$shape_tree$get_root_frames_ids$$,$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$,$app$common$geom$shapes$fit_frame$fit_frame_modifiers$$,$app$main$data$workspace$interactions$connected_frame_QMARK_$$,$app$common$files$helpers$component_touched_QMARK_$$,$app$util$text$content$to_dom$get_paragraph_styles$$,
$app$main$data$workspace$layout$ensure_layout$$,$app$main$data$workspace$initialize_workspace_layout$$,$app$common$types$variant$same_variant_QMARK_$$,$app$main$data$workspace$select_single_asset$$,$app$main$data$workspace$grid_layout$editor$set_selection$$,$app$main$data$workspace$path$selection$select_node$$,$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$shape_layout$hover_layout_track$$,$app$main$data$workspace$highlight$clear_search_match_highlight$$,
$app$main$data$workspace$highlight$set_search_match_highlight$$,$app$main$data$workspace$path$streams$move_handler_stream$$,$app$main$data$workspace$path$streams$move_points_stream$$,$app$common$attrs$get_text_attrs_multi$$,$app$common$types$shape$layout$duplicate_column_at$$,$app$common$types$shape$layout$duplicate_row_at$$,$app$main$data$workspace$interactions$get_target_frame$$,$app$main$data$workspace$interactions$move_edit_interaction$$,$app$main$data$workspace$colors$update_colorpicker$$,$app$main$data$workspace$clipboard$copy_selected_text$$,
$app$main$data$workspace$specialized_panel$open_specialized_panel$$,$app$main$data$workspace$modifiers$set_rotation_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$modifiers$calculate_update_modifiers$$,$app$main$data$workspace$modifiers$update_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$texts$commit_update_text_modifier$$,$app$common$types$shape$layout$reorder_grid_tracks$$,$app$common$types$shape$layout$reorder_grid_track$$,$cljs$tools$reader$read_dispatch$$,
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$tools$reader$read_delimited$$,$cljs$tools$reader$read_list$$,$cljs$tools$reader$read_vector$$,$cljs$tools$reader$read_map$$,$cljs$tools$reader$read_number$$,$cljs$tools$reader$escape_char$$,$cljs$tools$reader$read_string_STAR_$$,$cljs$tools$reader$wrapping_reader$$,$cljs$tools$reader$read_meta$$,$cljs$tools$reader$read_set$$,$cljs$tools$reader$read_discard$$,$cljs$tools$reader$read_symbolic_value$$,$cljs$tools$reader$read_suppress$$,
$cljs$tools$reader$read_cond_delimited$$,$cljs$tools$reader$read_cond$$,$cljs$tools$reader$read_fn$$,$cljs$tools$reader$read_arg$$,$cljs$tools$reader$read_unquote$$,$cljs$tools$reader$read_syntax_quote$$,$cljs$tools$reader$read_namespaced_map$$,$cljs$tools$reader$macros$$,$cljs$tools$reader$dispatch_macros$$,$cljs$tools$reader$read_tagged$$,$cljs$tools$reader$read_STAR_$$,$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$,
$app$main$data$workspace$libraries$go_to_component_file$$,$app$main$data$workspace$show_component_in_assets$$,$app$main$data$common$go_to_feedback$$,$app$main$rasterizer$render_node$$,$app$util$text_editor$setup_block_styles$$,$app$common$types$fills$prepend$$,$app$main$data$workspace$media$create_shapes_svg$$,$app$main$data$workspace$bool$group__GT_bool$$,$app$main$data$workspace$comments$handle_interrupt$$,$app$main$data$workspace$comments$initialize_comments$$,$app$main$data$workspace$selection$deselect_all$$,
$app$render_wasm$api$set_focus_mode$$,$app$util$text_editor$insert_text$$,$app$util$text_editor$apply_block_styles_to_content$$,$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$snap$get_snap_points$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect$$,
$app$main$data$workspace$selection$handle_area_selection$$,$app$common$text$parse_draft_styles$$,$app$common$text$convert_from_draft$$,$app$util$text_editor$export_content$$,$app$util$text$content$to_dom$set_styles$$,$app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$text$content$to_dom$create_paragraph$$,$app$util$text$content$to_dom$create_root$$,$app$util$text$content$styles$get_style_defaults$$,$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$,
$app$main$data$workspace$tokens$library_edit$clear_tokens_types$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type$$,$app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$tokens$library_edit$open_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types$$,$app$main$data$workspace$colors$show_palette$$,$app$main$data$fonts$add_recent_font$$,$app$main$ui$hooks$use_persisted_state$$,
$app$main$ui$hooks$use_shared_state$$,$app$main$data$workspace$clipboard$copy_selected_css_nested$$,$app$main$data$workspace$clipboard$copy_selected_css$$,$app$main$ui$dashboard$subscription$main_menu_power_up_STAR_$$,$app$main$data$workspace$tokens$library_edit$drop_error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$,$app$main$data$style_dictionary$resolve_tokens_with_verbose_errors$$,$app$main$data$workspace$tokens$errors$error_ex_info$$,
$app$util$color$get_color_name$$,$app$main$data$workspace$clipboard$copy_as_image$$,$app$main$data$workspace$clipboard$copy_selected_svg$$,$app$main$data$workspace$modifiers$set_wasm_modifiers$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout$$,$app$main$data$workspace$transforms$resize_text_editor$$,$app$main$data$workspace$update_nudge$$,$app$main$data$workspace$finalize_workspace$$,$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$,$malli$error$_resolve_direct_error$$,$malli$error$humanize$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$schema$valid_QMARK_$$,$app$main$data$plugins$update_plugin_permissions_peek$$,$app$main$data$plugins$update_plugins_permissions_peek$$,$app$common$types$tokens_lib$export_dtcg_multi_file$$,$app$main$data$workspace$colors$add_recent_color$$,$app$main$data$workspace$colors$update_colorpicker_color$$,$app$main$data$workspace$colors$activate_colorpicker_color$$,$app$main$data$workspace$colors$apply_color_from_colorpicker$$,$app$main$data$workspace$path$drawing$start_path_from_point$$,$app$main$data$workspace$path$drawing$close_path_drag_start$$,
$app$common$schema$validation_errors$$,$app$common$files$tokens$make_node_token_name_schema$$,$app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$types$tokens_lib$walk_sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$logic$tokens$calculate_move_token_set_or_set_group$$,$app$common$types$tokens_lib$sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$tokens_lib$parse_single_set_dtcg_json$$,$app$common$logic$libraries$add_shape_to_main$$,
$app$common$logic$tokens$generate_toggle_token_set_group$$,$app$common$logic$tokens$generate_delete_token_set_group$$,$app$common$logic$libraries$update_grid_main_attrs$$,$app$common$logic$libraries$update_flex_child_main_attrs$$,$app$common$logic$libraries$generate_sync_shape_inverse$$,$app$common$logic$libraries$generate_reset_component$$,$app$common$logic$variant_properties$generate_reorder_variant_poperties$$,$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$04$$,
$app$common$logic$libraries$generate_restore_component$$,$app$common$logic$libraries$generate_duplicate_component$$,$app$common$files$shapes_helpers$prepare_create_empty_artboard$$,$app$common$logic$libraries$generate_duplicate_changes$$,$app$common$files$changes_builder$del_page$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$$,
$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens$$,$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$tokens$library_edit$duplicate_token$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group$$,$app$main$data$workspace$update_component_annotation$$,$app$main$data$workspace$change_pixel_grid_color$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$workspace$relocate_page$$,$app$main$data$workspace$update_page_position_data$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$variants$reorder_variant_poperties$$,$app$main$data$workspace$shape_layout$paste_grid_tracks$$,$app$main$data$workspace$shape_layout$create_cell_board$$,$app$main$data$workspace$shape_layout$duplicate_layout_track$$,$app$main$data$workspace$pages$delete_page$$,$app$main$data$workspace$pages$duplicate_page$$,$app$main$data$workspace$interactions$rename_flow$$,
$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$interactions$add_flow_selected_frame$$,$app$main$data$workspace$guides$update_guide_color$$,$app$main$data$workspace$guides$remove_frame_guides$$,$app$main$data$workspace$path$edition$drag_selected_points$$,$app$main$data$workspace$path$edition$split_segments$$,$app$main$data$workspace$libraries$update_component$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$workspace$libraries$update_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$libraries$reset_component$$,$app$main$data$workspace$libraries$reset_components$$,$app$main$data$workspace$libraries$detach_components$$,$app$main$data$workspace$libraries$restore_component$$,$app$main$data$workspace$libraries$restore_components$$,$app$main$data$workspace$libraries$add_multiple_components$$,$app$main$data$workspace$libraries$duplicate_typography$$,$app$main$data$workspace$libraries$delete_media$$,
$app$main$data$workspace$libraries$duplicate_color$$,$app$main$data$workspace$media$add_shapes_and_component$$,$app$main$data$workspace$media$process_svg_component$$,$app$main$data$workspace$media$process_img_component$$,$app$main$data$workspace$shape_layout$merge_cells$$,$app$main$data$workspace$colors$reorder_strokes$$,$app$main$data$workspace$colors$remove_all_strokes$$,$app$main$data$workspace$colors$remove_stroke$$,$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$04$$,
$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes$$,$app$main$data$workspace$texts$commit_position_data$$,$app$main$data$workspace$texts$commit_resize_text$$,$app$main$data$workspace$texts$finalize_editor_state$$,$app$main$data$workspace$texts$initialize_editor_state$$,$app$main$data$workspace$texts$remove_text_modifier$$,$app$main$data$workspace$colors$remove_fill$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$main$data$workspace$colors$detach_fill$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$colors$add_fill$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$colors$apply_color_from_palette$$,$app$main$data$workspace$colors$apply_color_from_assets$$,$app$main$data$workspace$texts$replace_text_in_shapes$$,$app$main$data$workspace$libraries$component_multi_swap$$,$app$main$data$workspace$transforms$selected_fit_content$$,$app$main$data$workspace$tokens$application$get_token_properties$$,
$app$main$data$workspace$tokens$library_edit$drop_token_set$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_group$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group$$,$app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69004$$,$app$main$data$workspace$transforms$start_resize$$,$app$main$data$workspace$start_resize$$,
$app$main$data$workspace$transforms$start_rotate$$,$app$main$data$workspace$transforms$change_orientation$$,$app$main$data$workspace$bool$change_bool_type$$,$app$main$data$workspace$bool$bool_to_group$$,$app$main$data$workspace$bool$group_to_bool$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected$$,$app$main$data$workspace$tokens$application$apply_token_from_input$$,$app$main$data$workspace$set_shape_proportion_lock$$,$app$main$data$workspace$shape_layout$reorder_layout_track$$,
$app$main$data$workspace$variants$combine_selected_as_variants$$,$app$main$data$workspace$interactions$finish_move_overlay_pos$$,$app$main$data$workspace$interactions$start_move_overlay_pos$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to$$,$app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$interactions$finish_edit_interaction$$,$app$main$data$workspace$interactions$start_edit_interaction$$,$app$main$data$workspace$path$edition$create_node_at_position$$,
$app$main$data$workspace$path$edition$start_move_handler$$,$app$main$data$workspace$path$edition$start_move_path_point$$,$app$main$data$workspace$path$shortcuts$get_tooltip$$,$app$main$data$workspace$colors$reorder_shadows$$,$app$main$data$workspace$colors$add_shadow$$,$app$main$data$workspace$colors$change_hide_fill_on_export$$,$app$main$data$workspace$colors$reorder_fills$$,$app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$texts$update_all_attrs$$,
$app$main$data$workspace$versions$exit_preview$$,$app$main$data$workspace$versions$restore_version$$,$app$main$data$workspace$versions$enter_restore$$,$app$main$data$workspace$versions$enter_preview$$,$app$main$data$workspace$media$upload_fill_image$$,$app$main$data$workspace$media$upload_media_components$$,$app$main$data$workspace$clipboard$paste_from_event$$,$app$main$data$workspace$shortcuts$get_tooltip$$,$cljs$spec$alpha$explain_printer$$,$cljs$spec$alpha$assert_STAR_$$,$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$,
$app$main$ui$workspace$colorpicker$color_inputs$color_inputs_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$list_item_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$grid_item_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$group__GT_paths$$,$app$main$ui$workspace$colorpicker$color_tokens$set_section_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$,$app$main$ui$workspace$colorpicker$color_tokens$filter_combined_tokens$$,
$app$main$ui$workspace$colorpicker$color_tokens$sort_combined_tokens$$,$app$main$ui$workspace$colorpicker$color_tokens$token_section_STAR_$$,$instaparse$auto_flatten_seq$conj_flat$$,$instaparse$auto_flatten_seq$delve$$,$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$auto_flatten_seq$AutoFlattenSeq$$,$instaparse$auto_flatten_seq$hash_cat$$,$instaparse$auto_flatten_seq$auto_flatten_seq$$,$instaparse$auto_flatten_seq$afs_QMARK_$$,$instaparse$auto_flatten_seq$true_count$$,
$instaparse$auto_flatten_seq$FlattenOnDemandVector$$,$JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$,$instaparse$auto_flatten_seq$convert_afs_to_vec$$,$instaparse$print$paren_for_tags$$,$instaparse$print$regexp_replace$$,$instaparse$print$regexp__GT_str$$,$instaparse$print$number__GT_hex_padded$$,$instaparse$print$char_range__GT_str$$,$instaparse$print$combinators__GT_str$$,$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$print$rule__GT_str$$,
$instaparse$print$Parser__GT_str$$,$instaparse$failure$print_reason$$,$instaparse$failure$pprint_failure$$,$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$instaparse$util$regexp_flags$$,$instaparse$reduction$singleton_QMARK_$$,$instaparse$reduction$apply_reduction$$,$instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$combinators_source$opt$$,
$instaparse$combinators_source$plus$$,$instaparse$combinators_source$star$$,$instaparse$combinators_source$rep$$,$instaparse$combinators_source$string$$,$instaparse$combinators_source$string_ci$$,$instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$combinators_source$regexp$$,$instaparse$combinators_source$nt$$,$instaparse$combinators_source$look$$,$instaparse$combinators_source$neg$$,$instaparse$combinators_source$hide$$,$instaparse$combinators_source$hide_tag$$,
$instaparse$combinators_source$unhide_all_content$$,$instaparse$combinators_source$unhide_tags$$,$instaparse$combinators_source$unhide_all$$,$instaparse$combinators_source$auto_whitespace$$,$goog$i18n$uChar$fromCharCode$$,$goog$i18n$uChar$getCodePointAround$$,$instaparse$gll$_parse$$,$instaparse$gll$_full_parse$$,$instaparse$gll$Failure$$,$instaparse$gll$Tramp$$,$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$,$instaparse$gll$make_success$$,$instaparse$gll$total_success_QMARK_$$,$instaparse$gll$Node$$,
$instaparse$gll$push_stack$$,$instaparse$gll$push_message$$,$instaparse$gll$listener_exists_QMARK_$$,$instaparse$gll$full_listener_exists_QMARK_$$,$instaparse$gll$result_exists_QMARK_$$,$instaparse$gll$node_get$$,$instaparse$gll$safe_with_meta$$,$instaparse$gll$push_result$$,$instaparse$gll$push_listener$$,$instaparse$gll$push_full_listener$$,$instaparse$gll$push_negative_listener$$,$instaparse$gll$fail$$,$instaparse$gll$step$$,$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$gll$NodeListener$$,
$instaparse$gll$LookListener$$,$instaparse$gll$TopListener$$,$instaparse$gll$string_parse$$,$instaparse$gll$string_full_parse$$,$instaparse$gll$string_case_insensitive_parse$$,$instaparse$gll$string_case_insensitive_full_parse$$,$instaparse$gll$char_range_parse$$,$instaparse$gll$char_range_full_parse$$,$instaparse$gll$re_match_at_front$$,$instaparse$gll$regexp_parse$$,$instaparse$gll$regexp_full_parse$$,$instaparse$gll$cat_parse$$,$instaparse$gll$cat_full_parse$$,$instaparse$gll$plus_parse$$,$instaparse$gll$plus_full_parse$$,
$instaparse$gll$rep_parse$$,$instaparse$gll$rep_full_parse$$,$instaparse$gll$star_parse$$,$instaparse$gll$star_full_parse$$,$instaparse$gll$alt_parse$$,$instaparse$gll$alt_full_parse$$,$instaparse$gll$ordered_alt_parse$$,$instaparse$gll$ordered_alt_full_parse$$,$instaparse$gll$opt_parse$$,$instaparse$gll$opt_full_parse$$,$instaparse$gll$non_terminal_parse$$,$instaparse$gll$non_terminal_full_parse$$,$instaparse$gll$lookahead_parse$$,$instaparse$gll$lookahead_full_parse$$,$instaparse$gll$negative_lookahead_parse$$,
$instaparse$gll$epsilon_parse$$,$instaparse$gll$epsilon_full_parse$$,$instaparse$gll$start_parser$$,$instaparse$gll$parse$$,$instaparse$gll$build_node_with_meta$$,$instaparse$cfg$string_PLUS_$$,$instaparse$cfg$make_cfg$$,$instaparse$cfg$escape$$,$instaparse$cfg$process_string$$,$instaparse$cfg$process_regexp$$,$instaparse$cfg$check_grammar$$,$instaparse$cfg$build_parser$cljs$0core$0IFn$0_invoke$0arity$03$$,$instaparse$cfg$build_parser_from_combinators$$,$instaparse$transform$merge_meta$$,$instaparse$abnf$project$$,
$instaparse$abnf$merge_core$$,$instaparse$abnf$alt_preserving_hide_tag$$,$instaparse$abnf$build_parser$$,$instaparse$viz$span$$,$instaparse$repeat$empty_result_QMARK_$$,$instaparse$repeat$parse_from_index$$,$instaparse$repeat$select_parse$$,$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$,$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$,$instaparse$repeat$repeat_parse_with_header$$,$instaparse$repeat$try_repeating_parse_strategy_with_header$$,$instaparse$repeat$try_repeating_parse_strategy$$,
$instaparse$core$unhide_parser$$,$instaparse$core$Parser$$,$instaparse$core$map__GT_Parser$$,$instaparse$core$parser$$,$instaparse$core$parser$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$instaparse$core$failure_QMARK_$$,$app$util$simple_math$expr_eval$$,$app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$token__GT_dropdown_option$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$generate_dropdown_options$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_token_groups_by_name$$,
$app$main$ui$workspace$tokens$management$forms$controls$utils$sort_groups_and_tokens$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$,$app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,
$app$main$ui$workspace$sidebar$options$rows$color_row$color_token_row_STAR_$$,$app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,$app$main$ui$workspace$colorpicker$gradients$format_rgb$$,$app$main$ui$workspace$colorpicker$gradients$gradient__GT_string$$,$app$main$ui$workspace$colorpicker$gradients$stop_input_row_STAR_$$,$app$main$ui$workspace$colorpicker$gradients$gradients_STAR_$$,$app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$,
$app$main$ui$workspace$colorpicker$harmony$harmony_selector_STAR_$$,$app$main$ui$workspace$colorpicker$hsva$hsva_selector_STAR_$$,$app$main$ui$workspace$colorpicker$libraries$libraries_STAR_$$,$app$main$ui$workspace$colorpicker$ramp$value_saturation_selector_STAR_$$,$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$,$app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$,$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$,$app$main$ui$workspace$colorpicker$colorpicker_STAR_$$,
$app$main$ui$workspace$colorpicker$calculate_position$$,$app$main$ui$workspace$colorpicker$group_sets$$,$app$main$ui$workspace$colorpicker$combine_groups_with_resolved$$,$app$main$ui$workspace$colorpicker$filter_non_empty_sets$$,$app$main$ui$workspace$colorpicker$add_tokens_to_sets$$,$app$main$ui$workspace$colorpicker$filter_active_sets$$,$app$main$ui$workspace$colorpicker$colorpicker_modal$$,$app$main$ui$workspace$sidebar$assets$common$apply_filters$$,$app$main$ui$workspace$sidebar$assets$common$add_group$$,
$app$main$ui$workspace$sidebar$assets$common$rename_group$$,$app$main$ui$workspace$sidebar$assets$common$ungroup$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$,$app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$section_icon$$,$app$main$ui$workspace$sidebar$assets$common$should_display_asset_count_QMARK_$$,$app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,
$app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$create_assets_group$$,$app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$,$app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$,$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$,$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$,$app$main$ui$workspace$sidebar$assets$common$create_counter_element$$,$app$main$ui$workspace$sidebar$assets$common$set_drag_image$$,
$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$,$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$,$app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$,$app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$$,$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$workspace$context_menu$prevent_default$$,
$app$main$ui$workspace$context_menu$menu_entry_STAR_$$,$app$main$ui$workspace$context_menu$menu_separator_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_edit_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_layer_position_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_flip_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_thumbnail_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_rename_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_group_STAR_$$,
$app$main$ui$workspace$context_menu$context_focus_mode_menu_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_path_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_layer_options_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_prototype_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_layout_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_component_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_guides_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_delete_STAR_$$,
$app$main$ui$workspace$context_menu$page_item_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$grid_track_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$grid_cells_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$guide_color_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_STAR_$$,$app$main$ui$workspace$coordinates$coordinates_STAR_$$,$app$main$ui$workspace$tokens$import_from_library$import_modal_library_STAR_$$,
$app$main$ui$workspace$libraries$get_library_summary$$,$app$main$ui$workspace$libraries$adapt_backend_summary$$,$app$main$ui$workspace$libraries$describe_library$$,$app$main$ui$workspace$libraries$library_description_STAR_$$,$app$main$ui$workspace$libraries$sample_library_entry_STAR_$$,$app$main$ui$workspace$libraries$libraries_tab_STAR_$$,$app$main$ui$workspace$libraries$extract_assets$$,$app$main$ui$workspace$libraries$updates_tab_STAR_$$,$app$main$ui$workspace$libraries$libraries_dialog$$,$app$main$ui$workspace$libraries$v2_info_dialog$$,
$app$main$ui$workspace$nudge$on_keydown$$,$app$main$ui$workspace$nudge$nudge_modal$$,$app$main$ui$workspace$color_palette$recent_colors_palette_STAR_$$,$app$main$ui$workspace$color_palette$make_library_colors_ref$$,$app$main$ui$workspace$color_palette$file_color_palette_STAR_$$,$app$main$ui$workspace$color_palette_ctx_menu$extract_colors$$,$app$main$ui$workspace$color_palette_ctx_menu$color_palette_ctx_menu_STAR_$$,$app$main$ui$workspace$text_palette$typography_item_STAR_$$,$app$main$ui$workspace$text_palette$palette_STAR_$$,
$app$main$ui$workspace$text_palette_ctx_menu$text_palette_ctx_menu_STAR_$$,$app$main$ui$workspace$palette$calculate_palette_style$$,$app$main$ui$workspace$palette$palette_STAR_$$,$app$main$ui$workspace$main_menu$shortcuts_STAR_$$,$app$main$ui$workspace$main_menu$file_menu_STAR_$$,$app$main$ui$workspace$main_menu$mcp_menu_STAR_$$,$app$main$ui$workspace$main_menu$menu_STAR_$$,$app$main$ui$workspace$left_header$left_header_STAR_$$,$app$main$data$workspace$history$initialize_history$$,$app$main$ui$workspace$right_header$right_header_STAR_$$,
$app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,$app$main$ui$workspace$sidebar$assets$groups$sort_groups$$,$app$main$ui$workspace$sidebar$assets$groups$group_assets$$,$app$main$ui$workspace$sidebar$assets$groups$name_group_dialog$$,$app$main$ui$workspace$sidebar$assets$colors$color_item$$,$app$main$ui$workspace$sidebar$assets$colors$colors_section_STAR_$$,$app$main$ui$components$editable_label$editable_label_STAR_$$,$app$main$ui$workspace$sidebar$assets$components$get_component_root_and_container$$,
$app$main$ui$workspace$sidebar$assets$components$components_item_STAR_$$,$app$main$ui$workspace$sidebar$assets$components$components_section_STAR_$$,$app$main$ui$components$editable_select$editable_select$$,$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_next_font$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_prev_font$$,$app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$,$app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$,$app$main$ui$workspace$sidebar$options$menus$typography$font_options$$,$app$main$ui$workspace$sidebar$options$menus$typography$spacing_options$$,$app$main$ui$workspace$sidebar$options$menus$typography$text_transform_options$$,$app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$typography$typography_entry$$,$app$main$ui$workspace$sidebar$assets$typographies$typography_item$$,
$app$main$ui$workspace$sidebar$assets$typographies$typographies_section_STAR_$$,$app$main$ui$workspace$sidebar$assets$file_library$create_file_ref$$,$app$main$ui$workspace$sidebar$assets$file_library$use_library_ref$$,$app$main$ui$workspace$sidebar$assets$file_library$use_selected$$,$app$main$ui$workspace$sidebar$assets$file_library$file_library_title_STAR_$$,$app$main$ui$workspace$sidebar$assets$file_library$extend_selected$$,$app$main$ui$workspace$sidebar$assets$file_library$file_library_content_STAR_$$,
$app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$,$app$main$ui$workspace$sidebar$assets$assets_local_library_STAR_$$,$app$main$ui$workspace$sidebar$debug$debug_panel_STAR_$$,$app$main$ui$workspace$sidebar$debug_shape_info$get_attrs$$,$app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,$app$main$ui$workspace$sidebar$debug_shape_info$cells_render$$,$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_attr$$,$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_info_STAR_$$,
$app$main$ui$workspace$sidebar$history$get_object$$,$app$main$ui$workspace$sidebar$history$extract_operation$$,$app$main$ui$workspace$sidebar$history$parse_change$$,$app$main$ui$workspace$sidebar$history$resolve_shape_types$$,$app$main$ui$workspace$sidebar$history$entry__GT_message$$,$app$main$ui$workspace$sidebar$history$entry__GT_icon$$,$app$main$ui$workspace$sidebar$history$is_shape_QMARK_$$,$app$main$ui$workspace$sidebar$history$parse_entry$$,$app$main$ui$workspace$sidebar$history$safe_name$$,
$app$main$ui$workspace$sidebar$history$select_entry$$,$app$main$ui$workspace$sidebar$history$history_entry_details_STAR_$$,$app$main$ui$workspace$sidebar$history$history_entry$$,$app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$,$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$,$app$main$ui$workspace$sidebar$layers$frame_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$layers$calc_reparented_objects$$,$app$main$ui$workspace$sidebar$layers$match_filters_QMARK_$$,
$app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$,$app$main$ui$workspace$sidebar$layers$use_search$$,$app$main$ui$workspace$sidebar$layers$on_scroll$$,$app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$,$app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$,$app$main$ui$ds$controls$utilities$token_field$token_field_STAR_$$,$app$main$ui$ds$controls$numeric_input$parse_value$$,$app$main$ui$ds$controls$numeric_input$get_option_by_name$$,$app$main$ui$ds$controls$numeric_input$get_token_op$$,
$app$main$ui$ds$controls$numeric_input$clean_token_name$$,$app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$,$app$main$ui$ds$controls$numeric_input$first_focusable_id$$,$app$main$ui$ds$controls$numeric_input$next_focus_index$$,$app$main$ui$ds$controls$numeric_input$find_token_by_name$$,$app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$,
$app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$,$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$,$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$,$app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$drawing$frame$options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$align$align_options_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$bool$bool_options_STAR_$$,$app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$variants_help_modal$variants_help_modal$$,$app$main$ui$workspace$sidebar$options$menus$component$component_annotation_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$get_variant_malformed_warning_message$$,$app$main$ui$workspace$sidebar$options$menus$component$get_variant_duplicated_warning_message$$,$app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$,
$app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$,$app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_property_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_copy_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_swap_item_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$workspace$sidebar$options$menus$component$same_component_file_QMARK_$$,$app$main$ui$workspace$sidebar$options$menus$component$same_component_QMARK_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_swap_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$move_empty_items_to_end$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_property_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$,$app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$interactions$event_type_name$$,$app$main$ui$workspace$sidebar$options$menus$interactions$action_summary$$,$app$main$ui$workspace$sidebar$options$menus$interactions$get_frames_options$$,$app$main$ui$workspace$sidebar$options$menus$interactions$get_shared_frames_options$$,$app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$interaction_item_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$interactions$page_flows_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$shape_flows_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_flex$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$wrap_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$align_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$align_content_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_content_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$simple_padding_selection_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$multiple_padding_selection_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_edit_mode$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$manage_values$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_track_info$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$open_flex_help$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$,$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$,$app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layer$opacity__GT_string$$,$app$main$ui$workspace$sidebar$options$menus$layer$on_change$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$,
$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_simple_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_multiple_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_section_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_horizontal$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_vertical$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$align_self_row$$,
$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_size_constraints_STAR_$$,$app$main$ui$workspace$sidebar$options$rows$shadow_row$shadow_row_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$shadow$remove_shadow_by_index$$,$app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$rows$stroke_row$stroke_row_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$bool$options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,
$app$main$ui$workspace$sidebar$options$shapes$circle$options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$color_selection$prepare_colors$$,$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$,$app$common$geom$grid$calculate_generic_grid$$,$app$common$geom$grid$calculate_column_grid$$,$app$common$geom$grid$calculate_row_grid$$,$app$common$geom$grid$calculate_square_grid$$,$app$common$geom$grid$grid_gutter$$,$app$common$geom$grid$grid_areas$$,$app$main$data$workspace$grid$add_frame_grid$$,
$app$main$data$workspace$grid$remove_frame_grid$$,$app$main$data$workspace$grid$set_frame_grid$$,$app$main$data$workspace$grid$set_default_grid$$,$app$main$ui$workspace$sidebar$options$menus$frame_grid$get_size_options$$,$app$main$ui$workspace$sidebar$options$menus$frame_grid$frame_grid_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$frame$options_STAR_$$,$app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,$app$main$ui$ds$controls$shared$dropdown_navigation$use_dropdown_navigation$$,
$app$main$ui$ds$controls$shared$searchable_options_dropdown$searchable_options_dropdown_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$token_typography_row$resolved_value_tooltip_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$token_typography_row$token_typography_row_STAR_$$,$app$util$text$ui$closest_text_editor_content$$,$app$main$ui$workspace$sidebar$options$menus$text$text_align_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$text_direction_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$vertical_align_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$text$grow_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$text_decoration_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$,$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$,$app$main$ui$workspace$sidebar$options$menus$text$find_token_by_id$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_eq$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_sel$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_eq$$,
$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_sel$$,$app$main$ui$workspace$sidebar$options$shapes$path$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$rect$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_fill_values$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_stroke_values$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$text$options_STAR_$$,
$app$main$ui$workspace$sidebar$options$single_shape_options_STAR_$$,$app$main$ui$workspace$sidebar$options$specialized_panel_STAR_$$,$app$main$ui$workspace$sidebar$options$design_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$,$app$main$ui$workspace$sidebar$options$on_option_tab_change$$,$app$main$ui$workspace$sidebar$options$options_content_STAR_$$,$app$main$ui$workspace$sidebar$options$make_page_objects_ref$$,$app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$,
$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts_keys_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$shortcut_subsection_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$shortcut_section_STAR_$$,
$app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR_$$,$app$main$ui$workspace$sidebar$sitemap$make_page_ref$$,$app$main$ui$workspace$sidebar$sitemap$page_item$$,$app$main$ui$workspace$sidebar$sitemap$page_item_wrapper$$,$app$main$ui$workspace$sidebar$sitemap$pages_list_STAR_$$,$app$main$ui$workspace$sidebar$sitemap$sitemap_STAR_$$,$app$main$ui$ds$product$avatar$avatar_STAR_$$,$app$main$ui$ds$product$milestone$milestone_STAR_$$,$app$main$ui$ds$utilities$date$date_STAR_$$,$app$main$ui$ds$product$milestone_group$milestone_group_STAR_$$,
$app$main$ui$workspace$sidebar$versions$get_versions_stored_days$$,$app$main$ui$workspace$sidebar$versions$get_versions_warning_subtext$$,$app$main$ui$workspace$sidebar$versions$group_snapshots$$,$app$main$ui$workspace$sidebar$versions$on_name_input_focus$$,$app$main$ui$workspace$sidebar$versions$on_create_version$$,$app$main$ui$workspace$sidebar$versions$on_edit_version$$,$app$main$ui$workspace$sidebar$versions$on_cancel_version_edition$$,$app$main$ui$workspace$sidebar$versions$on_rename_version$$,
$app$main$ui$workspace$sidebar$versions$on_delete_version$$,$app$main$ui$workspace$sidebar$versions$on_pin_version$$,$app$main$ui$workspace$sidebar$versions$on_lock_version$$,$app$main$ui$workspace$sidebar$versions$on_unlock_version$$,$app$main$ui$workspace$sidebar$versions$version_entry_STAR_$$,$app$main$ui$workspace$sidebar$versions$snapshot_entry_STAR_$$,$app$main$ui$workspace$sidebar$versions$versions_toolbox_STAR_$$,$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens$$,$app$main$data$workspace$tokens$remapping$scan_token_value_references$$,
$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$,$app$main$data$workspace$tokens$remapping$build_remap_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$remapping$remap_tokens$$,$app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$remapping$count_token_references$$,
$app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$,$app$main$ui$workspace$tokens$management$context_menu$clean_separators$$,$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$,$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_padding$$,
$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_margin$$,$app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_radius_for_corners$$,$app$main$ui$workspace$tokens$management$context_menu$default_actions$$,$app$main$ui$workspace$tokens$management$context_menu$allowed_shape_attributes$$,$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$,
$app$main$ui$workspace$tokens$management$context_menu$selection_actions$$,$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$,$app$main$ui$workspace$tokens$management$context_menu$menu_entry$$,$app$main$ui$workspace$tokens$management$context_menu$token_context_menu_tree$$,$app$main$ui$workspace$tokens$management$context_menu$token_context_menu$$,$app$main$ui$ds$layers$layer_button$layer_button_STAR_$$,$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$,$app$main$ui$ds$foundations$utilities$token$token_status$token_status_icon_STAR_$$,
$app$main$ui$workspace$tokens$management$token_pill$partially_applied_attr$$,$app$main$ui$workspace$tokens$management$token_pill$translate_and_format$$,$app$main$ui$workspace$tokens$management$token_pill$contains_reference_value_QMARK_$$,$app$main$ui$workspace$tokens$management$token_pill$applied_all_attributes_QMARK_$$,$app$main$ui$workspace$tokens$management$token_pill$attributes_match_selection_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$workspace$tokens$management$token_tree$token_tree_STAR_$$,
$app$main$ui$workspace$tokens$management$group$token_section_icon$$,$app$main$ui$workspace$tokens$management$group$token_group_STAR_$$,$app$main$ui$workspace$tokens$management$node_context_menu$prevent_default$$,$app$main$ui$workspace$tokens$management$node_context_menu$token_node_context_menu_STAR_$$,$app$main$ui$workspace$tokens$management$selected_set_info_STAR_$$,$app$main$ui$workspace$tokens$management$tokens_section_STAR_$$,$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set$$,$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set_group$$,
$app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$,$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$,$app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$inline_add_button_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$add_button_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_group_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$,
$app$main$ui$workspace$tokens$sets$lists$token_sets_tree_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$,$app$main$ui$workspace$tokens$sets$on_select_token_set_click$$,$app$main$ui$workspace$tokens$sets$on_toggle_token_set_click$$,$app$main$ui$workspace$tokens$sets$on_toggle_token_set_group_click$$,$app$main$ui$workspace$tokens$sets$sets_list_STAR_$$,$app$main$ui$workspace$tokens$sets$context_menu$prevent_default$$,$app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,
$app$main$ui$workspace$tokens$sets$context_menu$menu_STAR_$$,$app$main$ui$workspace$tokens$sets$context_menu$token_set_context_menu_STAR_$$,$app$main$ui$workspace$tokens$themes$theme_selector$themes_list$$,$app$main$ui$workspace$tokens$themes$theme_selector$open_tokens_theme_modal$$,$app$main$ui$workspace$tokens$themes$theme_selector$theme_options$$,$app$main$ui$workspace$tokens$themes$theme_selector$theme_selector$$,$app$main$ui$workspace$tokens$themes$themes_header_STAR_$$,$app$main$ui$workspace$tokens$sidebar$token_sets_list_STAR_$$,
$app$main$ui$workspace$tokens$sidebar$token_management_section_STAR_$$,$app$main$ui$workspace$tokens$sidebar$import_export_button_STAR_$$,$app$main$ui$workspace$tokens$sidebar$tokens_sidebar_tab_STAR_$$,$app$main$ui$workspace$sidebar$collapse_button_STAR_$$,$app$main$ui$workspace$sidebar$on_close_document_history$$,$app$main$ui$workspace$sidebar$right_sidebar_STAR_$$,$app$main$ui$workspace$sidebar$sidebar_STAR_$$,$app$util$zip$writer$$,$app$util$zip$add$$,$app$util$zip$read_as_text$$,$app$util$zip$close$$,
$app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$,$app$main$ui$workspace$tokens$export$0$modal$single_file_tab_STAR_$$,$app$main$ui$workspace$tokens$export$0$modal$download_tokens_zip_BANG_$$,$app$main$ui$workspace$tokens$export$0$modal$multi_file_tab_STAR_$$,$app$main$ui$workspace$tokens$export$0$modal$export_modal_body_STAR_$$,$app$main$ui$workspace$tokens$export$0$export_modal_STAR_$$,$app$main$data$workspace$tokens$import_export$group_by_value$$,$app$main$data$workspace$tokens$import_export$show_unknown_types_warning$$,
$app$main$data$workspace$tokens$import_export$decode_json$$,$app$main$data$workspace$tokens$import_export$parse_decoded_json$$,$app$main$data$workspace$tokens$import_export$validate_library$$,$app$main$data$workspace$tokens$import_export$import_file_stream$$,$app$main$data$workspace$tokens$import_export$import_directory_stream$$,$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$,$app$main$ui$workspace$tokens$import$0$modal$import_type_dropdown_STAR_$$,$app$main$ui$workspace$tokens$import$0$modal$has_token_files_QMARK_$$,
$app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$,$app$main$ui$workspace$tokens$import$0$modal$import_modal_body_STAR_$$,$app$main$ui$workspace$tokens$import$0$import_modal_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$color_input_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$indexed_color_input_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$first_focusable_id$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$use_navigation$$,
$app$main$ui$workspace$tokens$management$forms$controls$floating_dropdown$use_floating_dropdown$$,$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$token_at_cursor$$,$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$remove_self_token$$,$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox$value_combobox_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$fonts_combobox_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$composite_fonts_combobox_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value_tokenscript$$,
$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$input$input_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$input$on_composite_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$controls$select$select_indexed_STAR_$$,$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$,$app$main$ui$workspace$tokens$management$forms$validators$validate_resolve_token$$,$app$main$ui$workspace$tokens$management$forms$validators$validate_token_with$$,$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$,$app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$,$app$main$ui$workspace$tokens$management$forms$generic_form$get_value_for_validator$$,
$app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$color$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$font_family$check_font_family_token_self_reference$$,$app$main$ui$workspace$tokens$management$forms$font_family$validate_font_family_token$$,$app$main$ui$workspace$tokens$management$forms$font_family$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$check_shadow_token_self_reference$$,$app$main$ui$workspace$tokens$management$forms$shadow$check_empty_shadow_token$$,
$app$main$ui$workspace$tokens$management$forms$shadow$validate_shadow_token$$,$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$,$app$main$ui$workspace$tokens$management$forms$shadow$shadow_formset_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$composite_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$reference_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$tabs_wrapper_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$make_schema$$,
$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$,$app$main$ui$workspace$tokens$management$forms$shadow$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$typography$check_typography_token_self_reference$$,$app$main$ui$workspace$tokens$management$forms$typography$check_empty_typography_token$$,$app$main$ui$workspace$tokens$management$forms$typography$validate_typography_token$$,$app$main$ui$workspace$tokens$management$forms$typography$composite_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$typography$reference_form_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$typography$tabs_wrapper_STAR_$$,$app$main$ui$workspace$tokens$management$forms$typography$make_schema$$,$app$main$ui$workspace$tokens$management$forms$typography$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$form_container$form_container_STAR_$$,$app$main$ui$workspace$tokens$management$forms$modals$calculate_position$$,$app$main$ui$workspace$tokens$management$forms$modals$use_viewport_position_style$$,$app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,
$app$main$ui$workspace$tokens$management$forms$modals$boolean_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$border_radius_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$color_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$stroke_width_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$box_shadow_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$sizing_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$dimensions_modal$$,
$app$main$ui$workspace$tokens$management$forms$modals$number_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$opacity_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$other_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$rotation_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$spacing_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$string_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$typography_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$font_size_modal$$,
$app$main$ui$workspace$tokens$management$forms$modals$letter_spacing_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$font_familiy_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$text_case_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$text_decoration_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$font_weight_modal$$,$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_modal$$,
$app$main$ui$workspace$tokens$remapping_modal$token_remapping_modal$$,$app$main$data$workspace$tokens$typography$set_base_font_size$$,$app$main$ui$workspace$tokens$settings$menu$token_settings_STAR_$$,$app$main$ui$workspace$tokens$settings$token_settings_modal_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$,$app$main$ui$workspace$tokens$themes$create_modal$themes_overview$$,$app$main$ui$workspace$tokens$themes$create_modal$theme_inputs_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$theme_modal_buttons_STAR_$$,
$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$,$app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$,$app$main$ui$workspace$tokens$themes$create_modal$edit_theme$$,$app$main$ui$workspace$tokens$themes$create_modal$create_theme$$,$app$main$ui$workspace$tokens$themes$create_modal$themes_modal_body_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$token_themes_modal$$,$app$main$ui$flex_controls$common$flex_display_pill$$,
$app$main$ui$workspace$viewport$viewport_ref$init_observer$$,$app$main$ui$workspace$viewport$viewport_ref$on_change_bounds$$,$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$,$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$,$app$main$ui$flex_controls$gap$gap_display$$,$app$main$ui$flex_controls$gap$gap_rects$$,$app$main$ui$flex_controls$gap$gap_control$$,$app$main$ui$flex_controls$margin$margin_display$$,$app$main$ui$flex_controls$margin$margin_rects$$,$app$main$ui$flex_controls$margin$margin_control$$,
$app$main$ui$flex_controls$padding$padding_display$$,$app$main$ui$flex_controls$padding$padding_rects$$,$app$main$ui$flex_controls$padding$padding_control$$,$app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_preview_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_snap_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,$app$main$ui$workspace$shapes$text$editor$block_component$$,
$app$main$ui$workspace$shapes$text$editor$styles_fn$$,$app$main$ui$workspace$shapes$text$editor$get_blocks_to_setup$$,$app$main$ui$workspace$shapes$text$editor$get_blocks_to_add_styles$$,$app$main$ui$workspace$shapes$text$editor$shape__GT_justify$$,$app$main$ui$workspace$shapes$text$editor$text_editor_svg$$,$app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$,$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$,$app$main$ui$workspace$shapes$text$v2_editor$coalesce_per_tick$$,
$app$main$ui$workspace$shapes$text$v2_editor$load_fonts_BANG_$$,$app$main$ui$workspace$shapes$text$v2_editor$initialize_event_handlers$$,$app$main$ui$workspace$shapes$text$v2_editor$vertical_align_editor_classes$$,$app$main$ui$workspace$shapes$text$v2_editor$get_color_from_content$$,$app$main$ui$workspace$shapes$text$v2_editor$get_default_text_color$$,$app$main$ui$workspace$shapes$text$v2_editor$shape__GT_justify$$,$$jscomp$scope$m743970774$0$getRangeRects$$,$app$util$text_position_data$parse_text_nodes$$,
$app$util$text_svg_position$parse_text_nodes$$,$app$util$text_svg_position$resolve_font$$,$app$util$text_svg_position$process_text_node$$,$app$util$text_svg_position$calc_text_node_positions$$,$app$util$text_svg_position$calc_position_data$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$fix_position$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_shape$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$,
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$text_changes_renderer$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$text_modifiers_renderer$$,$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$,$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$workspace$shapes$text$v3_editor$text_editor$$,
$app$main$ui$workspace$viewport$actions$on_pointer_down$$,$app$main$ui$workspace$viewport$actions$on_move_selected$$,$app$main$ui$workspace$viewport$actions$on_frame_select$$,$app$main$ui$workspace$viewport$actions$on_frame_enter$$,$app$main$ui$workspace$viewport$actions$on_frame_leave$$,$app$main$ui$workspace$viewport$actions$on_click$$,$app$main$ui$workspace$viewport$actions$on_double_click$$,$app$main$ui$workspace$viewport$actions$on_context_menu$$,$app$main$ui$workspace$viewport$actions$on_menu_selected$$,
$app$main$ui$workspace$viewport$actions$on_pointer_up$$,$app$main$ui$workspace$viewport$actions$on_pointer_enter$$,$app$main$ui$workspace$viewport$actions$on_pointer_leave$$,$app$main$ui$workspace$viewport$actions$on_key_down$$,$app$main$ui$workspace$viewport$actions$on_key_up$$,$app$main$ui$workspace$viewport$actions$on_pointer_move$$,$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$,$app$main$ui$workspace$viewport$actions$schedule_scroll_BANG_$$,$app$main$ui$workspace$viewport$actions$on_mouse_wheel$$,
$app$main$ui$workspace$viewport$actions$on_drag_enter$$,$app$main$ui$workspace$viewport$actions$on_drag_over$$,$app$main$ui$workspace$viewport$actions$on_drop$$,$app$main$ui$workspace$viewport$actions$on_paste$$,$app$main$ui$workspace$viewport$debug$debug_content_bounds$$,$app$main$ui$workspace$viewport$debug$debug_layout_lines$$,$app$main$ui$workspace$viewport$debug$debug_parent_bounds$$,$app$main$ui$workspace$viewport$debug$debug_grid_layout$$,$app$main$ui$workspace$viewport$debug$debug_text_wasm_position_data$$,
$app$main$ui$workspace$viewport$drawarea$make_edit_path_ref$$,$app$main$ui$workspace$viewport$drawarea$generic_draw_area_STAR_$$,$app$main$ui$workspace$viewport$drawarea$path_draw_area_STAR_$$,$app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$,$app$main$ui$workspace$viewport$frame_grid$square_grid_STAR_$$,$app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$,$app$main$ui$workspace$viewport$frame_grid$frame_clip_area$$,$app$main$ui$workspace$viewport$frame_grid$has_grid_QMARK_$$,$app$main$ui$workspace$viewport$gradients$shadow_STAR_$$,
$app$main$ui$workspace$viewport$gradients$gradient_color_handler_STAR_$$,$app$main$ui$workspace$viewport$gradients$gradient_handler_transformed_STAR_$$,$app$main$ui$workspace$viewport$gradients$gradient_handlers_impl_STAR_$$,$app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$,$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$,$app$main$ui$workspace$viewport$grid_layout_editor$grid_edition_actions$$,$app$main$ui$workspace$viewport$grid_layout_editor$grid_editor_frame$$,
$app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$,$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$,$app$main$ui$workspace$viewport$grid_layout_editor$resize_cell_handler$$,$app$main$ui$workspace$viewport$grid_layout_editor$grid_cell_area_label$$,$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$,$app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,$app$main$ui$workspace$viewport$grid_layout_editor$marker_shape_d$$,$app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,
$app$main$ui$workspace$viewport$rulers$get_ruler_params$$,$app$main$ui$workspace$viewport$rulers$rulers_inside_path$$,$app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$,$app$main$ui$workspace$viewport$rulers$viewport_frame_STAR_$$,$app$main$ui$workspace$viewport$rulers$selection_area_STAR_$$,$app$main$ui$workspace$viewport$guides$use_guide$$,$app$main$ui$workspace$viewport$guides$guide_area_axis$$,$app$main$ui$workspace$viewport$guides$is_guide_inside_frame_QMARK_$$,$app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$,
$app$main$data$workspace$grid_layout$shortcuts$esc_pressed$$,$app$main$ui$workspace$viewport$hooks$setup_dom_events$$,$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$,$app$main$ui$workspace$viewport$hooks$setup_cursor$$,$app$main$ui$workspace$viewport$hooks$setup_keyboard$$,$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$,$app$main$ui$workspace$viewport$hooks$setup_viewport_modifiers$$,$app$main$ui$workspace$viewport$hooks$inside_vbox$$,$app$main$ui$workspace$viewport$hooks$setup_active_frames$$,
$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$,$app$main$ui$workspace$viewport$outline$outline$$,$app$main$ui$workspace$viewport$outline$shape_outlines$$,$app$main$ui$workspace$viewport$interactions$on_pointer_down$$,$app$main$ui$workspace$viewport$interactions$connect_to_shape$$,$app$main$ui$workspace$viewport$interactions$connect_to_point$$,$app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,$app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,$app$main$ui$workspace$viewport$interactions$interaction_handle_STAR_$$,
$app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$,$app$main$ui$workspace$viewport$interactions$interactions_STAR_$$,$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$,$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay$$,$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$,$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_wasm_STAR_$$,$app$main$ui$workspace$viewport$presence$active_cursors$$,$app$main$ui$workspace$viewport$selection$selection_rect$$,
$app$main$ui$workspace$viewport$selection$calculate_handlers$$,$app$main$ui$workspace$viewport$selection$rotation_handler$$,$app$main$ui$workspace$viewport$selection$resize_point_handler$$,$app$main$ui$workspace$viewport$selection$resize_side_handler$$,$app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$,$app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$,$app$main$ui$workspace$viewport$selection$text_edition_selection$$,$app$main$ui$workspace$viewport$selection$multiple_handlers_STAR_$$,
$app$main$ui$workspace$viewport$selection$multiple_selection_STAR_$$,$app$main$ui$workspace$viewport$selection$single_handlers_STAR_$$,$app$main$ui$workspace$viewport$selection$single_selection_STAR_$$,$app$main$ui$workspace$viewport$selection$area_STAR_$$,$app$main$ui$workspace$viewport$selection$handlers_STAR_$$,$app$main$ui$workspace$viewport$snap_distances$half_point$$,$app$main$ui$workspace$viewport$snap_distances$shape_distance_segment_STAR_$$,$app$main$ui$workspace$viewport$snap_distances$calculate_segments$$,
$app$main$ui$workspace$viewport$snap_distances$query_worker$$,$app$main$ui$workspace$viewport$snap_distances$shape_distance$$,$app$main$ui$workspace$viewport$snap_distances$snap_distances$$,$app$main$ui$workspace$viewport$snap_points$snap_point_STAR_$$,$app$main$ui$workspace$viewport$snap_points$snap_line_STAR_$$,$app$main$ui$workspace$viewport$snap_points$get_snap$$,$app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$,$app$main$ui$workspace$viewport$snap_points$process_snap_lines$$,$app$main$ui$workspace$viewport$snap_points$snap_feedback_STAR_$$,
$app$main$ui$workspace$viewport$path_actions$check_enabled$$,$app$main$ui$workspace$viewport$path_actions$path_actions_STAR_$$,$app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$,$app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$,$app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$,$app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$,$app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$,$app$main$ui$workspace$viewport$widgets$frame_flow_STAR_$$,$app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$,
$app$main$ui$workspace$viewport$widgets$button_add_STAR_$$,$app$main$ui$workspace$viewport_wasm$apply_modifiers_to_objects$$,$app$main$ui$workspace$viewport_wasm$apply_wasm_modifiers_to_ids$$,$app$main$ui$workspace$viewport_wasm$outline_wasm_source_ids$$,$app$main$ui$workspace$viewport_wasm$viewport_STAR_$$,$app$main$ui$workspace$viewport$apply_modifiers_to_selected$$,$app$main$ui$workspace$viewport$viewport_classic_STAR_$$,$app$main$ui$workspace$viewport$viewport_STAR_$$,$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$,
$app$main$ui$workspace$webgl_unavailable_modal$webgl_unavailable_modal_STAR_$$,$app$main$ui$workspace$workspace_content_STAR_$$,$app$main$ui$workspace$workspace_loader_STAR_$$,$app$main$ui$workspace$make_team_ref$$,$app$main$ui$workspace$make_file_ref$$,$app$main$ui$workspace$make_page_ref$$,$app$main$ui$workspace$workspace_inner_STAR_$$,$cljs$core$CHAR_MAP$$,$cljs$core$js_reserved_arr$$,$cljs$core$js_reserved$$,$cljs$core$NS_CACHE$$,$cljs$tools$reader$READ_EOF$$,$cljs$tools$reader$READ_FINISHED$$,
$cljs$tools$reader$_STAR_read_delim_STAR_$$,$cljs$tools$reader$_STAR_suppress_read_STAR_$$,$cljs$tools$reader$NO_MATCH$$,$cljs$tools$reader$arg_env$$,$cljs$tools$reader$gensym_env$$,$app$$,$app$main$$,$app$main$data$workspace$initialize_layout_71560$$,$app$main$data$workspace$update_page_position_data_71617$$,$app$main$data$workspace$finalize_workspace_71689$$,$app$main$data$workspace$rename_file_71701$$,$app$main$data$workspace$update_nudge_71712$$,$app$main$data$workspace$relocate_page_71822$$,
$app$main$data$workspace$set_shape_proportion_lock_71857$$,$app$main$data$workspace$workspace_focus_lost_71869$$,$app$main$data$workspace$set_assets_section_open_71901$$,$app$main$data$workspace$clear_assets_section_open_71906$$,$app$main$data$workspace$set_assets_group_open_71917$$,$app$main$data$workspace$toggle_selected_assets_71922$$,$app$main$data$workspace$select_single_asset_71928$$,$app$main$data$workspace$select_assets_71933$$,$app$main$data$workspace$unselect_all_assets_71944$$,$app$main$data$workspace$show_component_in_assets_71950$$,
$app$main$data$workspace$show_page_item_context_menu_71975$$,$app$main$data$workspace$show_track_context_menu_71983$$,$app$main$data$workspace$show_grid_cell_context_menu_72002$$,$app$main$data$workspace$show_guide_context_menu_72015$$,$app$main$data$workspace$change_pixel_grid_color_72057$$,$app$main$data$workspace$set_paddings_selected_72060$$,$app$main$data$workspace$set_gap_selected_72068$$,$app$main$data$workspace$set_margins_selected_72074$$,$app$main$data$workspace$start_rename_page_item_72090$$,
$app$main$data$workspace$stop_rename_page_item_72098$$,$app$main$data$workspace$update_component_annotation_72102$$,$app$main$data$workspace$set_annotations_expanded_72105$$,$app$main$data$workspace$set_annotations_id_for_create_72108$$,$app$main$data$workspace$set_preview_blend_mode_72113$$,$app$main$data$workspace$unset_preview_blend_mode_72118$$,$app$main$data$workspace$set_clipboard_style_72127$$,$app$main$data$workspace$update_layers_search_scope_72145$$,$app$main$store$$,$app$main$data$modal$update_modal_props_51453$$,
$app$main$data$common$go_to_feedback_52605$$,$app$main$data$persistence$update_status_55287$$,$app$main$data$persistence$update_file_revn_55299$$,$app$main$data$persistence$discard_commit_55307$$,$app$main$data$persistence$append_commit_55315$$,$app$main$data$persistence$discard_persistence_state_55325$$,$app$main$data$persistence$persist_commit_55337$$,$app$main$data$persistence$run_persistence_task_55357$$,$app$main$data$persistence$initialize_persistence_55381$$,$app$main$data$plugins$update_plugins_permissions_peek_66298$$,
$app$main$data$fonts$add_recent_font_55960$$,$app$main$data$project$finalize_project_55793$$,$app$main$data$workspace$zoom$start_zooming_66295$$,$app$main$data$workspace$zoom$finish_zooming_66329$$,$app$main$data$workspace$selection$update_selrect_67114$$,$app$main$data$workspace$selection$handle_area_selection_67138$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$,$app$main$data$workspace$bool$group_to_bool_67727$$,$app$main$data$workspace$bool$bool_to_group_67734$$,
$app$main$data$workspace$bool$change_bool_type_67740$$,$app$main$data$workspace$media$upload_fill_image_67753$$,$app$main$data$workspace$media$process_img_component_67775$$,$app$main$data$workspace$media$process_svg_component_67780$$,$app$main$data$workspace$layout$ensure_layout_67141$$,$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$,
$app$main$data$workspace$modifiers$update_modifiers_68687$$,$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$,$app$main$data$workspace$transforms$change_orientation_69093$$,$app$main$data$workspace$transforms$start_rotate_69112$$,$app$main$data$workspace$transforms$selected_fit_content_69401$$,$app$main$data$workspace$transforms$resize_text_editor_69407$$,$app$main$data$workspace$libraries$duplicate_color_69464$$,$app$main$data$workspace$libraries$delete_media_69478$$,$app$main$data$workspace$libraries$duplicate_typography_69508$$,
$app$main$data$workspace$libraries$add_multiple_components_69530$$,$app$main$data$workspace$libraries$duplicate_component_69559$$,$app$main$data$workspace$libraries$restore_component_69573$$,$app$main$data$workspace$libraries$restore_components_69577$$,$app$main$data$workspace$libraries$detach_components_69610$$,$app$main$data$workspace$libraries$nav_to_component_file_69637$$,$app$main$data$workspace$libraries$reset_component_69663$$,$app$main$data$workspace$libraries$reset_components_69668$$,$app$main$data$workspace$libraries$update_component_69685$$,
$app$main$data$workspace$libraries$update_component_sync_69716$$,$app$main$data$workspace$libraries$component_multi_swap_69796$$,$app$main$data$workspace$libraries$set_file_shared_69919$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$,$app$main$data$workspace$libraries$detach_library_69976$$,$app$main$data$workspace$texts$update_editor_70001$$,$app$main$data$workspace$texts$focus_editor_70026$$,$app$main$data$workspace$texts$finalize_editor_state_70040$$,$app$main$data$workspace$texts$initialize_editor_state_70057$$,
$app$main$data$workspace$texts$editor_select_all_70076$$,$app$main$data$workspace$texts$cursor_to_end_70085$$,$app$main$data$workspace$texts$commit_resize_text_70228$$,$app$main$data$workspace$texts$resize_text_70264$$,$app$main$data$workspace$texts$save_font_70272$$,$app$main$data$workspace$texts$commit_update_text_modifier_70286$$,$app$main$data$workspace$texts$update_text_modifier_70295$$,$app$main$data$workspace$texts$clean_text_modifier_70307$$,$app$main$data$workspace$texts$remove_text_modifier_70311$$,
$app$main$data$workspace$texts$commit_position_data_70318$$,$app$main$data$workspace$texts$update_position_data_70327$$,$app$main$data$workspace$texts$update_all_attrs_70342$$,$app$main$data$workspace$texts$add_typography_70356$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$,$app$main$data$workspace$texts$replace_text_in_shapes_70395$$,$app$main$data$workspace$clipboard$paste_from_event_70549$$,$app$main$data$workspace$clipboard$copy_selected_svg_70571$$,
$app$main$data$workspace$clipboard$copy_selected_css_70576$$,$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$,$app$main$data$workspace$clipboard$copy_selected_text_70607$$,$app$main$data$workspace$clipboard$copy_as_image_71066$$,$app$main$data$workspace$colors$show_palette_70402$$,$app$main$data$workspace$colors$start_picker_70408$$,$app$main$data$workspace$colors$stop_picker_70411$$,$app$main$data$workspace$colors$pick_color_70427$$,$app$main$data$workspace$colors$pick_color_select_70430$$,
$app$main$data$workspace$colors$reorder_fills_70459$$,$app$main$data$workspace$colors$add_fill_70502$$,$app$main$data$workspace$colors$detach_fill_70512$$,$app$main$data$workspace$colors$remove_fill_70523$$,$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$,$app$main$data$workspace$colors$change_stroke_attrs_70626$$,$app$main$data$workspace$colors$add_shadow_70672$$,$app$main$data$workspace$colors$remove_stroke_70693$$,$app$main$data$workspace$colors$remove_all_strokes_70719$$,$app$main$data$workspace$colors$reorder_shadow_70745$$,
$app$main$data$workspace$colors$reorder_strokes_70763$$,$app$main$data$workspace$colors$apply_color_from_palette_70840$$,$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$,$app$main$data$workspace$colors$add_recent_color_70884$$,$app$main$data$workspace$colors$apply_color_from_asserts_70894$$,$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$,$app$main$data$workspace$colors$initialize_colorpicker_70941$$,$app$main$data$workspace$colors$finalize_colorpicker_70947$$,
$app$main$data$workspace$colors$update_colorpicker_70955$$,$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$,$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$,$app$main$data$workspace$colors$update_colorpicker_stops_70989$$,$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$,$app$main$data$workspace$colors$remove_gradient_stop_71002$$,$app$main$data$workspace$colors$update_colorpicker_color_71008$$,$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$,
$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$,$app$main$data$workspace$colors$activate_colorpicker_color_71026$$,$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$,$app$main$data$workspace$colors$activate_colorpicker_image_71040$$,$app$main$data$workspace$drawing$change_orientation_70079$$,$app$main$data$workspace$drawing$change_preset_70088$$,$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$,$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$,
$app$main$data$workspace$path$drawing$start_path_from_point_69865$$,$app$main$data$workspace$path$drawing$reset_last_handler_69988$$,$app$main$data$workspace$path$selection$path_pointer_enter_69691$$,$app$main$data$workspace$path$selection$path_pointer_leave_69694$$,$app$main$data$workspace$path$selection$path_handler_enter_69700$$,$app$main$data$workspace$path$selection$path_handler_leave_69703$$,$app$main$data$workspace$path$selection$select_node_area_69719$$,$app$main$data$workspace$path$selection$select_node_69731$$,
$app$main$data$workspace$path$selection$deselect_all_69740$$,$app$main$data$workspace$path$selection$update_area_selection_69747$$,$app$main$data$workspace$path$selection$clear_area_selection_69753$$,$app$main$data$workspace$path$selection$handle_area_selection_69765$$,$app$main$data$workspace$path$edition$modify_handler_69813$$,$app$main$data$workspace$path$edition$move_point_69868$$,$app$main$data$workspace$path$edition$start_move_path_point_69877$$,$app$main$data$workspace$path$edition$drag_selected_points_69899$$,
$app$main$data$workspace$path$edition$start_move_handler_69946$$,$app$main$data$workspace$path$edition$split_segments_69991$$,$app$main$data$workspace$path$edition$create_node_at_position_69998$$,$app$main$data$workspace$comments$initialize_comments_70121$$,$app$main$data$workspace$comments$handle_interrupt_70129$$,$app$main$data$workspace$comments$handle_comment_layer_click_70132$$,$app$main$data$workspace$guides$remove_frame_guides_70278$$,$app$main$data$workspace$guides$update_guide_color_70300$$,
$app$main$data$workspace$guides$set_hover_guide_70304$$,$app$main$data$workspace$highlight$set_search_match_highlight_70324$$,$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$,$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$,$app$main$data$workspace$interactions$rename_flow_70438$$,$app$main$data$workspace$interactions$add_new_interaction_70468$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$,$app$main$data$workspace$interactions$start_edit_interaction_70518$$,
$app$main$data$workspace$interactions$move_edit_interaction_70539$$,$app$main$data$workspace$interactions$finish_edit_interaction_70553$$,$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$,$app$main$data$workspace$interactions$move_overlay_pos_70623$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$,$app$main$data$workspace$notifications$finalize_70664$$,$app$main$data$workspace$pages$finalize_page_70790$$,$app$main$data$workspace$pages$duplicate_page_70853$$,
$app$main$data$workspace$pages$delete_page_70977$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$,$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$,$app$main$data$workspace$grid_layout$editor$set_selection_70872$$,$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$,$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$,$app$main$data$workspace$grid_layout$editor$locate_board_70936$$,
$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$,$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$,$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$,$app$main$data$workspace$shape_layout$hover_layout_track_71221$$,$app$main$data$workspace$shape_layout$merge_cells_71269$$,$app$main$data$workspace$shape_layout$create_cell_board_71278$$,$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$,$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$,
$app$main$data$workspace$variants$reorder_variant_properties_71467$$,$app$main$data$workspace$variants$combine_selected_as_variants_71532$$,$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$,$app$main$data$workspace$viewport$initialize_viewport_71178$$,$app$main$data$workspace$viewport$update_viewport_size_71217$$,$app$main$data$workspace$viewport$activate_panning_71233$$,$app$main$data$workspace$viewport$start_panning_71240$$,$app$main$data$workspace$viewport$finish_panning_71253$$,
$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$,$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$,$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$,
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$,$app$main$data$workspace$tokens$library_edit$drop_error_72897$$,
$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$,$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$,
$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$,$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$,
$app$main$data$workspace$versions$init_versions_state_73284$$,$app$main$data$workspace$versions$update_versions_state_73289$$,$app$main$data$workspace$versions$fetch_versions_73294$$,$app$main$data$workspace$versions$create_version_73304$$,$app$main$data$workspace$versions$rename_version_73316$$,$app$main$data$workspace$versions$delete_version_73334$$,$app$main$data$workspace$versions$pin_version_73343$$,$app$main$data$workspace$versions$lock_version_73363$$,$app$main$data$workspace$versions$unlock_version_73368$$,
$app$main$data$workspace$versions$exit_preview_cleanup_73373$$,$app$main$data$workspace$versions$exit_preview_73381$$,$app$main$data$workspace$versions$restore_version_73390$$,$app$main$data$workspace$versions$enter_restore_73399$$,$app$main$data$workspace$versions$apply_snapshot_data_73405$$,$app$main$data$workspace$versions$enter_preview_73414$$;
$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($page_id$jscomp$119$$,$ids$jscomp$77$$){return $APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($page_id$jscomp$119$$,$ids$jscomp$77$$)};
$goog$functions$throttle$$=function($f$jscomp$6$$,$interval$jscomp$1$$){function $fire$$(){$timeout$jscomp$4$$=$APP.$goog$global$$.setTimeout($handleTimeout$$,$interval$jscomp$1$$);let $args$jscomp$8$$=$storedArgs$$;$storedArgs$$=[];$f$jscomp$6$$.apply(void 0,$args$jscomp$8$$)}function $handleTimeout$$(){$timeout$jscomp$4$$=0;$shouldFire$$&&($shouldFire$$=!1,$fire$$())}let $timeout$jscomp$4$$=0,$shouldFire$$=!1,$storedArgs$$=[];return function($var_args$jscomp$61$$){$storedArgs$$=arguments;$timeout$jscomp$4$$?
$shouldFire$$=!0:$fire$$()}};$module$contents$goog$array_slice$$=function($arr$jscomp$48$$,$start$jscomp$14$$,$opt_end$jscomp$9$$){return arguments.length<=2?Array.prototype.slice.call($arr$jscomp$48$$,$start$jscomp$14$$):Array.prototype.slice.call($arr$jscomp$48$$,$start$jscomp$14$$,$opt_end$jscomp$9$$)};
$module$contents$goog$array_splice$$=function($arr$jscomp$47$$,$index$jscomp$109$$,$howMany$jscomp$1$$,$var_args$jscomp$73$$){return Array.prototype.splice.apply($arr$jscomp$47$$,$module$contents$goog$array_slice$$(arguments,1))};$cljs$tools$reader$macro_terminating_QMARK_$$=function($ch$jscomp$25$$){switch($ch$jscomp$25$$){case '"':case ";":case "@":case "^":case "`":case "~":case "(":case ")":case "[":case "]":case "{":case "}":case "\\":return!0;default:return!1}};
$app$common$math$sq$$=function($v$jscomp$94$$){return $v$jscomp$94$$*$v$jscomp$94$$};$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$=function($s$jscomp$212$$,$val$jscomp$110$$,$from$jscomp$5$$){return typeof $s$jscomp$212$$==="string"&&typeof $val$jscomp$110$$==="string"?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$212$$,$val$jscomp$110$$,$from$jscomp$5$$):null};
$goog$dom$getElementsByClass$$=function($className$jscomp$1$$,$opt_el$jscomp$2$$){var $parent$jscomp$107$$=$opt_el$jscomp$2$$||document;return $parent$jscomp$107$$.querySelectorAll&&$parent$jscomp$107$$.querySelector?$parent$jscomp$107$$.querySelectorAll("."+$className$jscomp$1$$):$APP.$goog$dom$getElementsByTagNameAndClass_$$(document,"*",$className$jscomp$1$$,$opt_el$jscomp$2$$)};
$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ob$jscomp$8$$,$next_fn$jscomp$2$$,$error_fn$jscomp$2$$){$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$03$$($ob$jscomp$8$$,$next_fn$jscomp$2$$,$error_fn$jscomp$2$$)};$app$util$dom$select_target$$=function($event$jscomp$26$$){return $event$jscomp$26$$!=null?$event$jscomp$26$$.target.select():null};
$app$util$dom$get_parent_with_selector$$=function($current$jscomp$10_node$jscomp$179$$,$selector$jscomp$7$$){for(;;){var $JSCompiler_inline_result$jscomp$1483_or__5025__auto__$jscomp$inline_8034$$=($JSCompiler_inline_result$jscomp$1483_or__5025__auto__$jscomp$inline_8034$$=$current$jscomp$10_node$jscomp$179$$==null)?$JSCompiler_inline_result$jscomp$1483_or__5025__auto__$jscomp$inline_8034$$:$current$jscomp$10_node$jscomp$179$$.matches($selector$jscomp$7$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1483_or__5025__auto__$jscomp$inline_8034$$))return $current$jscomp$10_node$jscomp$179$$;
$current$jscomp$10_node$jscomp$179$$=$current$jscomp$10_node$jscomp$179$$.parentElement}};$app$util$dom$valid_QMARK_$$=function($node$jscomp$188_temp__5825__auto__$jscomp$107$$){return $node$jscomp$188_temp__5825__auto__$jscomp$107$$!=null?($node$jscomp$188_temp__5825__auto__$jscomp$107$$=$node$jscomp$188_temp__5825__auto__$jscomp$107$$.validity,$APP.$cljs$core$truth_$$($node$jscomp$188_temp__5825__auto__$jscomp$107$$)?$node$jscomp$188_temp__5825__auto__$jscomp$107$$.valid:null):null};
$app$util$dom$set_value_BANG_$$=function($node$jscomp$191$$,$value$jscomp$369$$){return $node$jscomp$191$$!=null?$node$jscomp$191$$.value=$value$jscomp$369$$:null};$app$util$dom$set_style_BANG_$$=function($node$jscomp$218$$,$style$jscomp$10$$,$value$jscomp$374$$){return $node$jscomp$218$$!=null?$node$jscomp$218$$.style.setProperty($style$jscomp$10$$,$value$jscomp$374$$):null};
$app$util$dom$is_in_viewport_QMARK_$$=function($element$jscomp$53_rect$jscomp$10$$){if($element$jscomp$53_rect$jscomp$10$$!=null){$element$jscomp$53_rect$jscomp$10$$=$element$jscomp$53_rect$jscomp$10$$.getBoundingClientRect();var $height$jscomp$39$$=function(){var $or__5025__auto__$jscomp$308$$=window.innerHeight;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$308$$)?$or__5025__auto__$jscomp$308$$:document.documentElement.clientHeight}(),$width$jscomp$47$$=function(){var $or__5025__auto__$jscomp$309$$=
window.innerWidth;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$309$$)?$or__5025__auto__$jscomp$309$$:document.documentElement.clientWidth}();return $element$jscomp$53_rect$jscomp$10$$.top>=0&&$element$jscomp$53_rect$jscomp$10$$.left>=0&&$element$jscomp$53_rect$jscomp$10$$.bottom<=$height$jscomp$39$$&&$element$jscomp$53_rect$jscomp$10$$.right<=$width$jscomp$47$$}return null};
$rumext$v2$throttle$$=function($component$jscomp$6$$,$ms$jscomp$37$$){return function($props_44998$$){var $tmp$jscomp$6$$=(0,$APP.$rumext$v2$useState$$)($props_44998$$),$state$jscomp$45$$=$tmp$jscomp$6$$[0],$set_state$$=$tmp$jscomp$6$$[1],$ref$jscomp$14$$=(0,$APP.$rumext$v2$useRef$$)(!1),$render$$=(0,$APP.$rumext$v2$useMemo$$)(function(){return $goog$functions$throttle$$(function($v$jscomp$499$$){return $APP.$rumext$v2$ref_val$$($ref$jscomp$14$$)?null:$set_state$$($v$jscomp$499$$)},$ms$jscomp$37$$)},
[]);(0,$APP.$rumext$v2$useEffect$$)(function(){return $render$$($props_44998$$)},[$props_44998$$]);(0,$APP.$rumext$v2$useEffect$$)(function(){return function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$14$$,!0)}},[]);return(0,$APP.$rumext$v2$create_element$$)($component$jscomp$6$$,$state$jscomp$45$$)}};
$app$common$types$color$hue__GT_rgb$$=function($v1$jscomp$24$$,$v2$jscomp$17$$,$vh$jscomp$2_vh__$1$$){$vh$jscomp$2_vh__$1$$=$vh$jscomp$2_vh__$1$$<0?$vh$jscomp$2_vh__$1$$+1:$vh$jscomp$2_vh__$1$$>1?$vh$jscomp$2_vh__$1$$-1:$vh$jscomp$2_vh__$1$$;return 6*$vh$jscomp$2_vh__$1$$<1?$v1$jscomp$24$$+($v2$jscomp$17$$-$v1$jscomp$24$$)*6*$vh$jscomp$2_vh__$1$$:2*$vh$jscomp$2_vh__$1$$<1?$v2$jscomp$17$$:3*$vh$jscomp$2_vh__$1$$<2?$v1$jscomp$24$$+($v2$jscomp$17$$-$v1$jscomp$24$$)*(2/3-$vh$jscomp$2_vh__$1$$)*6:$v1$jscomp$24$$};
$app$common$types$tokens_lib$get_set_names$$=function($JSCompiler_temp$jscomp$1486__$jscomp$1292$$){if($JSCompiler_temp$jscomp$1486__$jscomp$1292$$!=null&&$JSCompiler_temp$jscomp$1486__$jscomp$1292$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$!=null)$JSCompiler_temp$jscomp$1486__$jscomp$1292$$=$JSCompiler_temp$jscomp$1486__$jscomp$1292$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$($JSCompiler_temp$jscomp$1486__$jscomp$1292$$);else{var $m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$=
$app$common$types$tokens_lib$get_set_names$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1486__$jscomp$1292$$==null?null:$JSCompiler_temp$jscomp$1486__$jscomp$1292$$)];if($m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$!=null)$JSCompiler_temp$jscomp$1486__$jscomp$1292$$=$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1486__$jscomp$1292$$):
$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$($JSCompiler_temp$jscomp$1486__$jscomp$1292$$);else if($m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$=$app$common$types$tokens_lib$get_set_names$$._,$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$!=null)$JSCompiler_temp$jscomp$1486__$jscomp$1292$$=$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1486__$jscomp$1292$$):
$m__5372__auto__$jscomp$inline_8038_m__5374__auto__$jscomp$inline_8037$$($JSCompiler_temp$jscomp$1486__$jscomp$1292$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-set-names",$JSCompiler_temp$jscomp$1486__$jscomp$1292$$);}return $JSCompiler_temp$jscomp$1486__$jscomp$1292$$};
$app$common$types$tokens_lib$get_sets_at_path$$=function($JSCompiler_temp$jscomp$1487__$jscomp$1296$$,$path_str$jscomp$5$$){if($JSCompiler_temp$jscomp$1487__$jscomp$1296$$!=null&&$JSCompiler_temp$jscomp$1487__$jscomp$1296$$.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$!=null)$JSCompiler_temp$jscomp$1487__$jscomp$1296$$=$JSCompiler_temp$jscomp$1487__$jscomp$1296$$.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$($JSCompiler_temp$jscomp$1487__$jscomp$1296$$,$path_str$jscomp$5$$);
else{var $m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$=$app$common$types$tokens_lib$get_sets_at_path$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1487__$jscomp$1296$$==null?null:$JSCompiler_temp$jscomp$1487__$jscomp$1296$$)];if($m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$!=null)$JSCompiler_temp$jscomp$1487__$jscomp$1296$$=$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1487__$jscomp$1296$$,
$path_str$jscomp$5$$):$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$($JSCompiler_temp$jscomp$1487__$jscomp$1296$$,$path_str$jscomp$5$$);else if($m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$=$app$common$types$tokens_lib$get_sets_at_path$$._,$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$!=null)$JSCompiler_temp$jscomp$1487__$jscomp$1296$$=$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1487__$jscomp$1296$$,$path_str$jscomp$5$$):$m__5372__auto__$jscomp$inline_8043_m__5374__auto__$jscomp$inline_8042$$($JSCompiler_temp$jscomp$1487__$jscomp$1296$$,$path_str$jscomp$5$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-sets-at-path",$JSCompiler_temp$jscomp$1487__$jscomp$1296$$);}return $JSCompiler_temp$jscomp$1487__$jscomp$1296$$};
$app$common$types$tokens_lib$enable_sets$$=function($JSCompiler_temp$jscomp$1488__$jscomp$1302$$,$set_names$jscomp$3$$){if($JSCompiler_temp$jscomp$1488__$jscomp$1302$$!=null&&$JSCompiler_temp$jscomp$1488__$jscomp$1302$$.$app$common$types$tokens_lib$ITokenTheme$enable_sets$arity$2$!=null)$JSCompiler_temp$jscomp$1488__$jscomp$1302$$=$JSCompiler_temp$jscomp$1488__$jscomp$1302$$.$app$common$types$tokens_lib$ITokenTheme$enable_sets$arity$2$($JSCompiler_temp$jscomp$1488__$jscomp$1302$$,$set_names$jscomp$3$$);
else{var $m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$=$app$common$types$tokens_lib$enable_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1488__$jscomp$1302$$==null?null:$JSCompiler_temp$jscomp$1488__$jscomp$1302$$)];if($m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$!=null)$JSCompiler_temp$jscomp$1488__$jscomp$1302$$=$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1488__$jscomp$1302$$,
$set_names$jscomp$3$$):$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$($JSCompiler_temp$jscomp$1488__$jscomp$1302$$,$set_names$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$=$app$common$types$tokens_lib$enable_sets$$._,$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$!=null)$JSCompiler_temp$jscomp$1488__$jscomp$1302$$=$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1488__$jscomp$1302$$,$set_names$jscomp$3$$):$m__5372__auto__$jscomp$inline_8048_m__5374__auto__$jscomp$inline_8047$$($JSCompiler_temp$jscomp$1488__$jscomp$1302$$,$set_names$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.enable-sets",$JSCompiler_temp$jscomp$1488__$jscomp$1302$$);}return $JSCompiler_temp$jscomp$1488__$jscomp$1302$$};
$app$common$types$tokens_lib$disable_sets$$=function($JSCompiler_temp$jscomp$1489__$jscomp$1306$$,$set_names$jscomp$5$$){if($JSCompiler_temp$jscomp$1489__$jscomp$1306$$!=null&&$JSCompiler_temp$jscomp$1489__$jscomp$1306$$.$app$common$types$tokens_lib$ITokenTheme$disable_sets$arity$2$!=null)$JSCompiler_temp$jscomp$1489__$jscomp$1306$$=$JSCompiler_temp$jscomp$1489__$jscomp$1306$$.$app$common$types$tokens_lib$ITokenTheme$disable_sets$arity$2$($JSCompiler_temp$jscomp$1489__$jscomp$1306$$,$set_names$jscomp$5$$);
else{var $m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$=$app$common$types$tokens_lib$disable_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1489__$jscomp$1306$$==null?null:$JSCompiler_temp$jscomp$1489__$jscomp$1306$$)];if($m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$!=null)$JSCompiler_temp$jscomp$1489__$jscomp$1306$$=$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1489__$jscomp$1306$$,
$set_names$jscomp$5$$):$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$($JSCompiler_temp$jscomp$1489__$jscomp$1306$$,$set_names$jscomp$5$$);else if($m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$=$app$common$types$tokens_lib$disable_sets$$._,$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$!=null)$JSCompiler_temp$jscomp$1489__$jscomp$1306$$=$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1489__$jscomp$1306$$,$set_names$jscomp$5$$):$m__5372__auto__$jscomp$inline_8053_m__5374__auto__$jscomp$inline_8052$$($JSCompiler_temp$jscomp$1489__$jscomp$1306$$,$set_names$jscomp$5$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.disable-sets",$JSCompiler_temp$jscomp$1489__$jscomp$1306$$);}return $JSCompiler_temp$jscomp$1489__$jscomp$1306$$};
$app$common$types$tokens_lib$set_path_exists_QMARK_$$=function($JSCompiler_temp$jscomp$1490__$jscomp$1357$$,$path$jscomp$178$$){if($JSCompiler_temp$jscomp$1490__$jscomp$1357$$!=null&&$JSCompiler_temp$jscomp$1490__$jscomp$1357$$.$app$common$types$tokens_lib$ITokensLib$set_path_exists_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$1490__$jscomp$1357$$=$JSCompiler_temp$jscomp$1490__$jscomp$1357$$.$app$common$types$tokens_lib$ITokensLib$set_path_exists_QMARK_$arity$2$($JSCompiler_temp$jscomp$1490__$jscomp$1357$$,
$path$jscomp$178$$);else{var $m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$=$app$common$types$tokens_lib$set_path_exists_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1490__$jscomp$1357$$==null?null:$JSCompiler_temp$jscomp$1490__$jscomp$1357$$)];if($m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$!=null)$JSCompiler_temp$jscomp$1490__$jscomp$1357$$=$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1490__$jscomp$1357$$,$path$jscomp$178$$):$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$($JSCompiler_temp$jscomp$1490__$jscomp$1357$$,$path$jscomp$178$$);else if($m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$=$app$common$types$tokens_lib$set_path_exists_QMARK_$$._,$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$!=
null)$JSCompiler_temp$jscomp$1490__$jscomp$1357$$=$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1490__$jscomp$1357$$,$path$jscomp$178$$):$m__5372__auto__$jscomp$inline_8058_m__5374__auto__$jscomp$inline_8057$$($JSCompiler_temp$jscomp$1490__$jscomp$1357$$,$path$jscomp$178$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.set-path-exists?",
$JSCompiler_temp$jscomp$1490__$jscomp$1357$$);}return $JSCompiler_temp$jscomp$1490__$jscomp$1357$$};
$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$=function($JSCompiler_temp$jscomp$1491__$jscomp$1359$$,$path$jscomp$180$$){if($JSCompiler_temp$jscomp$1491__$jscomp$1359$$!=null&&$JSCompiler_temp$jscomp$1491__$jscomp$1359$$.$app$common$types$tokens_lib$ITokensLib$set_group_path_exists_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$1491__$jscomp$1359$$=$JSCompiler_temp$jscomp$1491__$jscomp$1359$$.$app$common$types$tokens_lib$ITokensLib$set_group_path_exists_QMARK_$arity$2$($JSCompiler_temp$jscomp$1491__$jscomp$1359$$,$path$jscomp$180$$);
else{var $m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$=$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1491__$jscomp$1359$$==null?null:$JSCompiler_temp$jscomp$1491__$jscomp$1359$$)];if($m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$!=null)$JSCompiler_temp$jscomp$1491__$jscomp$1359$$=$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1491__$jscomp$1359$$,
$path$jscomp$180$$):$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$($JSCompiler_temp$jscomp$1491__$jscomp$1359$$,$path$jscomp$180$$);else if($m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$=$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$._,$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$!=null)$JSCompiler_temp$jscomp$1491__$jscomp$1359$$=$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1491__$jscomp$1359$$,$path$jscomp$180$$):$m__5372__auto__$jscomp$inline_8063_m__5374__auto__$jscomp$inline_8062$$($JSCompiler_temp$jscomp$1491__$jscomp$1359$$,$path$jscomp$180$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.set-group-path-exists?",$JSCompiler_temp$jscomp$1491__$jscomp$1359$$);}return $JSCompiler_temp$jscomp$1491__$jscomp$1359$$};
$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$=function($JSCompiler_temp$jscomp$1492__$jscomp$1377$$,$group_path$jscomp$2$$){if($JSCompiler_temp$jscomp$1492__$jscomp$1377$$!=null&&$JSCompiler_temp$jscomp$1492__$jscomp$1377$$.$app$common$types$tokens_lib$ITokensLib$sets_at_path_all_active_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$1492__$jscomp$1377$$=$JSCompiler_temp$jscomp$1492__$jscomp$1377$$.$app$common$types$tokens_lib$ITokensLib$sets_at_path_all_active_QMARK_$arity$2$($JSCompiler_temp$jscomp$1492__$jscomp$1377$$,
$group_path$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$=$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1492__$jscomp$1377$$==null?null:$JSCompiler_temp$jscomp$1492__$jscomp$1377$$)];if($m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$!=null)$JSCompiler_temp$jscomp$1492__$jscomp$1377$$=$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1492__$jscomp$1377$$,$group_path$jscomp$2$$):$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$($JSCompiler_temp$jscomp$1492__$jscomp$1377$$,$group_path$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$=$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$._,$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$!=
null)$JSCompiler_temp$jscomp$1492__$jscomp$1377$$=$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1492__$jscomp$1377$$,$group_path$jscomp$2$$):$m__5372__auto__$jscomp$inline_8068_m__5374__auto__$jscomp$inline_8067$$($JSCompiler_temp$jscomp$1492__$jscomp$1377$$,$group_path$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.sets-at-path-all-active?",
$JSCompiler_temp$jscomp$1492__$jscomp$1377$$);}return $JSCompiler_temp$jscomp$1492__$jscomp$1377$$};
$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$=function($JSCompiler_temp$jscomp$1493__$jscomp$1381$$,$force_set_id$jscomp$1$$){if($JSCompiler_temp$jscomp$1493__$jscomp$1381$$!=null&&$JSCompiler_temp$jscomp$1493__$jscomp$1381$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets_force$arity$2$!=null)$JSCompiler_temp$jscomp$1493__$jscomp$1381$$=$JSCompiler_temp$jscomp$1493__$jscomp$1381$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets_force$arity$2$($JSCompiler_temp$jscomp$1493__$jscomp$1381$$,$force_set_id$jscomp$1$$);
else{var $m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$=$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1493__$jscomp$1381$$==null?null:$JSCompiler_temp$jscomp$1493__$jscomp$1381$$)];if($m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$!=null)$JSCompiler_temp$jscomp$1493__$jscomp$1381$$=$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1493__$jscomp$1381$$,
$force_set_id$jscomp$1$$):$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$($JSCompiler_temp$jscomp$1493__$jscomp$1381$$,$force_set_id$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$=$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$._,$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$!=null)$JSCompiler_temp$jscomp$1493__$jscomp$1381$$=$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1493__$jscomp$1381$$,$force_set_id$jscomp$1$$):$m__5372__auto__$jscomp$inline_8073_m__5374__auto__$jscomp$inline_8072$$($JSCompiler_temp$jscomp$1493__$jscomp$1381$$,$force_set_id$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-tokens-in-active-sets-force",$JSCompiler_temp$jscomp$1493__$jscomp$1381$$);}return $JSCompiler_temp$jscomp$1493__$jscomp$1381$$};
$app$common$types$tokens_lib$get_all_tokens$$=function($JSCompiler_temp$jscomp$1494__$jscomp$1383$$){if($JSCompiler_temp$jscomp$1494__$jscomp$1383$$!=null&&$JSCompiler_temp$jscomp$1494__$jscomp$1383$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens$arity$1$!=null)$JSCompiler_temp$jscomp$1494__$jscomp$1383$$=$JSCompiler_temp$jscomp$1494__$jscomp$1383$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens$arity$1$($JSCompiler_temp$jscomp$1494__$jscomp$1383$$);else{var $m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$=
$app$common$types$tokens_lib$get_all_tokens$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1494__$jscomp$1383$$==null?null:$JSCompiler_temp$jscomp$1494__$jscomp$1383$$)];if($m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$!=null)$JSCompiler_temp$jscomp$1494__$jscomp$1383$$=$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1494__$jscomp$1383$$):
$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$($JSCompiler_temp$jscomp$1494__$jscomp$1383$$);else if($m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$=$app$common$types$tokens_lib$get_all_tokens$$._,$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$!=null)$JSCompiler_temp$jscomp$1494__$jscomp$1383$$=$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1494__$jscomp$1383$$):
$m__5372__auto__$jscomp$inline_8077_m__5374__auto__$jscomp$inline_8076$$($JSCompiler_temp$jscomp$1494__$jscomp$1383$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-all-tokens",$JSCompiler_temp$jscomp$1494__$jscomp$1383$$);}return $JSCompiler_temp$jscomp$1494__$jscomp$1383$$};$app$util$keyboard$mod_event_QMARK_$$=function($event$jscomp$47$$){return $event$jscomp$47$$.$mod$===!0};$app$util$mouse$get_pointer_movement$$=function($ev$jscomp$3$$){return $ev$jscomp$3$$.$movement$};
$app$main$ui$hooks$sortable_container_STAR_$$=function($children$jscomp$198_props_52596$$){$children$jscomp$198_props_52596$$=$children$jscomp$198_props_52596$$.children;var $global_drag_end$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$hooks$sortable_ctx$$),{value:$global_drag_end$$,children:$children$jscomp$198_props_52596$$})};
$app$util$text$content$to_dom$create_random_key$$=function(){return Math.floor(Math.random()*Number.MAX_SAFE_INTEGER).toString(36)};$app$util$array$normalize_to_array$$=function($o$jscomp$267$$){return $APP.$cljs$core$array_QMARK_$$($o$jscomp$267$$)?$o$jscomp$267$$:[$o$jscomp$267$$]};$app$util$array$without_nils$$=function($o$jscomp$268$$){return $o$jscomp$268$$.filter(function($v$jscomp$581$$){return $v$jscomp$581$$!=null})};$app$util$array$filter$$=function($pred$jscomp$82$$,$o$jscomp$269$$){return $o$jscomp$269$$.filter($pred$jscomp$82$$)};
$app$util$text_editor$editor_select_all$$=function($state$jscomp$540$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.selectAll($state$jscomp$540$$)};$app$util$text_editor$cursor_to_end$$=function($state$jscomp$550$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.cursorToEnd($state$jscomp$550$$)};
$app$main$data$tinycolor$__GT_string$$=function($tc$jscomp$4$$,$format$jscomp$34$$){return $tc$jscomp$4$$.toString(function(){switch($format$jscomp$34$$){case "rgba":return"rgb";case "hsva":return"hsv";case "rgb":return"rgb";case "hsv":return"hsv";default:return"hex"}}())};$app$main$ui$css_cursors$get_dynamic$$=function($name$jscomp$414$$,$rotation$jscomp$17$$){return"cursor-"+($name$jscomp$414$$??"")+"-"+($APP.$cljs$core$mod$$(Math.floor($rotation$jscomp$17$$/10)*10,360)??"")};
$cljs$tools$reader$ending_line_col_info$$=function($rdr$jscomp$60$$){return $APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$60$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rdr$jscomp$60$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$rdr$jscomp$60$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null)],null):null};
$cljs$tools$reader$starting_line_col_info$$=function($rdr$jscomp$59$$){return $APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$59$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rdr$jscomp$59$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$rdr$jscomp$59$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null)-1|0],null):null};
$app$util$dom$left_mouse_QMARK_$$=function($bevent$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$bevent$$.nativeEvent.which)};$app$util$dom$active_QMARK_$$=function($node$jscomp$213$$){return $node$jscomp$213$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$globals$document$$.activeElement,$node$jscomp$213$$):null};
$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$=function($epoch$$){var $f$jscomp$815$$=$app$render_wasm$api$end_page_transition_BANG_$$,$handler$jscomp$28_temp__5825__auto___54478$$=$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$);$APP.$cljs$core$truth_$$($handler$jscomp$28_temp__5825__auto___54478$$)&&$APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",$handler$jscomp$28_temp__5825__auto___54478$$);$handler$jscomp$28_temp__5825__auto___54478$$=
function $app$render_wasm$api$set_transition_tiles_complete_handler_BANG__$_handler$$(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($epoch$$,$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_epoch_STAR_$$))?($APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",$app$render_wasm$api$set_transition_tiles_complete_handler_BANG__$_handler$$),$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$,null),$f$jscomp$815$$.$cljs$core$IFn$_invoke$arity$0$?
$f$jscomp$815$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$815$$()):null};$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$,$handler$jscomp$28_temp__5825__auto___54478$$);$APP.$app$util$globals$document$$.addEventListener("penpot:wasm:tiles-complete",$handler$jscomp$28_temp__5825__auto___54478$$)};
$app$render_wasm$api$end_page_transition_BANG_$$=function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$page_transition_QMARK_$$,!1);var $temp__5825__auto___54473$$=$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$);$APP.$cljs$core$truth_$$($temp__5825__auto___54473$$)&&$APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",$temp__5825__auto___54473$$);$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$,
null);return $APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$,null)};
$app$main$data$workspace$colors$recent_color_equal_QMARK_$$=function($c1$jscomp$36$$,$c2$jscomp$24$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c1$jscomp$36$$,$c2$jscomp$24$$)||$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$36$$)!=null&&$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$24$$)!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$36$$),$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$24$$))};
$app$main$data$workspace$specialized_panel$interrupt_QMARK_$$=function($e$jscomp$321$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$321$$,$APP.$cljs$cst$2169$interrupt$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$321$$,$APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$)};
$app$util$shape_icon$get_shape_icon_by_type$$=function($type$jscomp$576$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$576$$,$APP.$cljs$cst$1625$component$$))return"component";switch($type$jscomp$576$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$576$$.$fqn$:null){case "frame":return"board";case "image":return"img";case "shape":return"path";case "text":return"text";case "mask":return"mask";case "group":return"group";default:return null}};
$app$util$mouse$mouse_click_event_QMARK_$$=function($v$jscomp$545$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1939$click$$,$v$jscomp$545$$.type)};
$app$common$types$shape$interactions$has_offset_effect_QMARK_$$=function($interaction$jscomp$29$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$29$$),$APP.$cljs$cst$1941$navigate$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$29$$)),$APP.$cljs$cst$1958$slide$$)};
$app$common$types$shape$interactions$has_way_QMARK_$$=function($interaction$jscomp$25$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$25$$),$APP.$cljs$cst$1941$navigate$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$25$$)),$APP.$cljs$cst$1958$slide$$)};
$app$main$data$workspace$notifications$finalize$$=function($_$jscomp$2430$$){typeof $app$main$data$workspace$notifications$finalize_70664$$==="undefined"&&($app$main$data$workspace$notifications$finalize_70664$$=function($_$jscomp$2431$$,$meta70665$$){this.$_$=$_$jscomp$2431$$;this.$meta70665$=$meta70665$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$finalize_70664$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$notifications$finalize_70664$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4348$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_finalize$$},$app$main$data$workspace$notifications$finalize_70664$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70666$$,$meta70665__$1$$){return new $app$main$data$workspace$notifications$finalize_70664$$(this.$_$,$meta70665__$1$$)},$app$main$data$workspace$notifications$finalize_70664$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70665$});return new $app$main$data$workspace$notifications$finalize_70664$$($_$jscomp$2430$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$hooks$use_ref_callback$$=function($f$jscomp$811$$){var $ptr$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($f$jscomp$811$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ptr$jscomp$2$$,{f:$f$jscomp$811$$})});return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){function $G__52740$$($var_args$jscomp$1117$$){var $G__52741__i_args$jscomp$245$$=null;if(arguments.length>
0){$G__52741__i_args$jscomp$245$$=0;for(var $G__52741__a$$=Array(arguments.length-0);$G__52741__i_args$jscomp$245$$<$G__52741__a$$.length;)$G__52741__a$$[$G__52741__i_args$jscomp$245$$]=arguments[$G__52741__i_args$jscomp$245$$+0],++$G__52741__i_args$jscomp$245$$;$G__52741__i_args$jscomp$245$$=new $APP.$cljs$core$IndexedSeq$$($G__52741__a$$,0,null)}return $G__52740__delegate$$.call(this,$G__52741__i_args$jscomp$245$$)}function $G__52740__delegate$$($args$jscomp$244$$){var $obj$jscomp$191$$=$APP.$rumext$v2$ref_val$$($ptr$jscomp$2$$);
return $obj$jscomp$191$$?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$191$$.f,$args$jscomp$244$$):null}$G__52740$$.$cljs$lang$maxFixedArity$=0;$G__52740$$.$cljs$lang$applyTo$=function($arglist__52742_args$jscomp$246$$){$arglist__52742_args$jscomp$246$$=$APP.$cljs$core$seq$$($arglist__52742_args$jscomp$246$$);return $G__52740__delegate$$($arglist__52742_args$jscomp$246$$)};$G__52740$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__52740__delegate$$;return $G__52740$$}())};
$app$main$ui$hooks$use_update_ref$$=function($value$jscomp$471$$){var $ref$jscomp$26$$=(0,$APP.$rumext$v2$use_ref$$)($value$jscomp$471$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$471$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$26$$,$value$jscomp$471$$)});return $ref$jscomp$26$$};
$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$294$$,$coll$jscomp$765$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$28$$=$APP.$cljs$core$seq$$($coll$jscomp$765$$);if($temp__5825__auto__$jscomp$28$$){var $fst$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$28$$),$fv$$=$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$($fst$$):$f$jscomp$294$$($fst$$),$run$$=$APP.$cljs$core$cons$$($fst$$,
$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__23957_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fv$$,$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$($p1__23957_SHARP_$$):$f$jscomp$294$$($p1__23957_SHARP_$$))},$APP.$cljs$core$next$$($temp__5825__auto__$jscomp$28$$)));return $APP.$cljs$core$cons$$($run$$,$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$294$$,new $APP.$cljs$core$LazySeq$$(null,
function(){return $APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($run$$),$temp__5825__auto__$jscomp$28$$)},null,null)))}return null},null,null)};$cljs$core$not_any_QMARK_$$=function($pred$jscomp$3$$,$coll$jscomp$277$$){return $APP.$cljs$core$not$$($APP.$cljs$core$some$$($pred$jscomp$3$$,$coll$jscomp$277$$))};$cljs$core$not_every_QMARK_$$=function($pred$jscomp$1$$,$coll$jscomp$275$$){return!$APP.$cljs$core$every_QMARK_$$($pred$jscomp$1$$,$coll$jscomp$275$$)};
$cljs$tools$reader$flatten_map$$=function($G__25216_form$jscomp$18_s$jscomp$173$$){$G__25216_form$jscomp$18_s$jscomp$173$$=$APP.$cljs$core$seq$$($G__25216_form$jscomp$18_s$jscomp$173$$);for(var $G__25217_key_vals$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__25216_form$jscomp$18_s$jscomp$173$$){var $e$jscomp$127$$=$APP.$cljs$core$first$$($G__25216_form$jscomp$18_s$jscomp$173$$);$G__25216_form$jscomp$18_s$jscomp$173$$=$APP.$cljs$core$next$$($G__25216_form$jscomp$18_s$jscomp$173$$);
$G__25217_key_vals$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__25217_key_vals$$,$APP.$cljs$core$_key$$($e$jscomp$127$$)),$APP.$cljs$core$_val$$($e$jscomp$127$$))}else return $APP.$cljs$core$seq$$($APP.$cljs$core$_persistent_BANG_$$($G__25217_key_vals$$))};
$app$common$path_names$merge_path_item_with_dot$$=function($path$jscomp$159$$,$name$jscomp$180$$){return $APP.$cljs$core$empty_QMARK_$$($path$jscomp$159$$)?$name$jscomp$180$$:$APP.$cljs$core$empty_QMARK_$$($name$jscomp$180$$)?$path$jscomp$159$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$159$$)," • ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$180$$)].join("")};
$app$common$types$token$build_result$$=function($second_part_value$jscomp$437$$,$first_part_prefix_end$$,$suffix_start$$,$name$jscomp$176_ref$jscomp$21$$){$name$jscomp$176_ref$jscomp$21$$=["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$176_ref$jscomp$21$$),"}"].join("");$first_part_prefix_end$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($second_part_value$jscomp$437$$,0,$first_part_prefix_end$$);$second_part_value$jscomp$437$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($second_part_value$jscomp$437$$,
$suffix_start$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first_part_prefix_end$$),$name$jscomp$176_ref$jscomp$21$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($second_part_value$jscomp$437$$)].join(""),$APP.$cljs$cst$1997$cursor$$,$APP.$cljs$core$count$$($first_part_prefix_end$$)+$name$jscomp$176_ref$jscomp$21$$.length],null)};
$promesa$impl$promise$all$$=function($promises$$){return $promises$$.reduce(($acc$jscomp$79$$,$p$jscomp$117$$)=>$acc$jscomp$79$$.then($results$$=>$APP.$JSCompiler_StaticMethods_fmap$$($APP.$promesa$impl$promise$coerce$$($p$jscomp$117$$),$v$jscomp$291$$=>{$results$$.push($v$jscomp$291$$);return $results$$})),$APP.$promesa$impl$promise$resolved$$([]))};
$cljs$spec$alpha$explain_data_STAR_$$=function($spec$jscomp$21$$,$x$jscomp$882$$){var $path$jscomp$124_temp__5825__auto__$jscomp$77$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$via$jscomp$4$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$in$$jscomp$43$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$path$jscomp$124_temp__5825__auto__$jscomp$77$$=$APP.$cljs$spec$alpha$explain_STAR_$$($APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($spec$jscomp$21$$),$path$jscomp$124_temp__5825__auto__$jscomp$77$$,
$via$jscomp$4$$,$in$$jscomp$43$$,$x$jscomp$882$$);return $APP.$cljs$core$truth_$$($path$jscomp$124_temp__5825__auto__$jscomp$77$$)?$APP.$cljs$core$empty_QMARK_$$($path$jscomp$124_temp__5825__auto__$jscomp$77$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$981$cljs_DOT_spec_DOT_alpha_SLASH_problems$$,$path$jscomp$124_temp__5825__auto__$jscomp$77$$,$APP.$cljs$cst$982$cljs_DOT_spec_DOT_alpha_SLASH_spec$$,$spec$jscomp$21$$,$APP.$cljs$cst$983$cljs_DOT_spec_DOT_alpha_SLASH_value$$,
$x$jscomp$882$$],null):null};
$app$common$data$nth_index_of_STAR_$$=function($G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$,$G__31886_G__31886__$1_char$$jscomp$1$$,$dir$$){for(var $s$jscomp$290$$=$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$,$G__32277_G__32281_offset$jscomp$32$$=0,$G__32278_G__32282_cnt$jscomp$31$$=1;;){a:switch($G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$=$dir$$ instanceof $APP.$cljs$core$Keyword$$?$dir$$.$fqn$:null,$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$){case "forward":$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$=
$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$290$$,$G__31886_G__31886__$1_char$$jscomp$1$$);break a;case "backward":$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$290$$,$G__31886_G__31886__$1_char$$jscomp$1$$);break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$)].join(""));
}if($G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$==null)return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__32278_G__32282_cnt$jscomp$31$$,1))switch($G__31886_G__31886__$1_char$$jscomp$1$$=$dir$$,$G__31886_G__31886__$1_char$$jscomp$1$$=$G__31886_G__31886__$1_char$$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__31886_G__31886__$1_char$$jscomp$1$$.$fqn$:null,$G__31886_G__31886__$1_char$$jscomp$1$$){case "forward":return $G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$+
$G__32277_G__32281_offset$jscomp$32$$;case "backward":return $G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31886_G__31886__$1_char$$jscomp$1$$)].join(""));}else{var $G__31891_G__31891__$1$$=$dir$$;$G__31891_G__31891__$1$$=$G__31891_G__31891__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__31891_G__31891__$1$$.$fqn$:null;switch($G__31891_G__31891__$1$$){case "forward":$G__32277_G__32281_offset$jscomp$32$$=
$G__32277_G__32281_offset$jscomp$32$$+$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$+1;$G__32278_G__32282_cnt$jscomp$31$$+=1;$s$jscomp$290$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$290$$,$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$+1);continue;case "backward":$G__32278_G__32282_cnt$jscomp$31$$+=1;$s$jscomp$290$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$290$$,0,$G__31885__$1$jscomp$inline_8086_index$jscomp$130_string$jscomp$5$$);
continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31891_G__31891__$1$$)].join(""));}}break}};$cljs$core$Namespace$$=function($obj$jscomp$102$$,$name$jscomp$117$$){this.$obj$=$obj$jscomp$102$$;this.name=$name$jscomp$117$$;this.$cljs$lang$protocol_mask$partition0$$=6291456;this.$cljs$lang$protocol_mask$partition1$$=0};
$app$common$types$text$replace_all_case_insensitive$$=function($text$jscomp$21$$,$search$jscomp$1_search_len$$,$replacement$jscomp$13$$){var $text_lower$$=$APP.$cuerdas$core$lower$$($text$jscomp$21$$),$search_lower$jscomp$1$$=$APP.$cuerdas$core$lower$$($search$jscomp$1_search_len$$);$search$jscomp$1_search_len$$=$APP.$cljs$core$count$$($search$jscomp$1_search_len$$);for(var $G__46203_result$jscomp$171$$="",$idx$jscomp$74$$=0;;){var $G__46204_found$jscomp$17$$=$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($text_lower$$,
$search_lower$jscomp$1$$,$idx$jscomp$74$$);if($G__46204_found$jscomp$17$$==null)return[$G__46203_result$jscomp$171$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($text$jscomp$21$$,$idx$jscomp$74$$)].join("");$G__46203_result$jscomp$171$$=[$G__46203_result$jscomp$171$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($text$jscomp$21$$,$idx$jscomp$74$$,$G__46204_found$jscomp$17$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($replacement$jscomp$13$$)].join("");$idx$jscomp$74$$=
$G__46204_found$jscomp$17$$+=$search$jscomp$1_search_len$$}};$app$common$types$color$remove_hash$$=function($color$jscomp$13$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($color$jscomp$13$$,"#")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$13$$,1):$color$jscomp$13$$};
$app$common$data$macros$truncate$$=function($s$jscomp$291$$){var $JSCompiler_temp_const$jscomp$1505$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$,$y__5114__auto__$jscomp$inline_8088$$=$APP.$cljs$core$count$$($s$jscomp$291$$);return $JSCompiler_temp_const$jscomp$1505$$.call($APP.$cljs$core$subs$$,$s$jscomp$291$$,0,200<$y__5114__auto__$jscomp$inline_8088$$?200:$y__5114__auto__$jscomp$inline_8088$$)};
$app$util$array$sort_BANG_$$=function($a$jscomp$398$$){$APP.$module$contents$goog$array_sort$$($a$jscomp$398$$,$APP.$cljs$core$compare$$);return $a$jscomp$398$$};$app$render_wasm$api$begin_page_transition_BANG_$$=function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$page_transition_QMARK_$$,!0);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$render_wasm$api$transition_epoch_STAR_$$,$APP.$cljs$core$inc$$)};
$app$render_wasm$api$apply_canvas_blur$$=function(){var $already_QMARK__temp__5825__auto__$jscomp$175$$=$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$),$epoch$jscomp$2$$=$app$render_wasm$api$begin_page_transition_BANG_$$();$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$($epoch$jscomp$2$$);$APP.$cljs$core$truth_$$($already_QMARK__temp__5825__auto__$jscomp$175$$)||($already_QMARK__temp__5825__auto__$jscomp$175$$=$APP.$app$render_wasm$wasm$canvas_snapshot_url$$,
$APP.$cljs$core$truth_$$($already_QMARK__temp__5825__auto__$jscomp$175$$)&&typeof $already_QMARK__temp__5825__auto__$jscomp$175$$==="string"&&$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$,$already_QMARK__temp__5825__auto__$jscomp$175$$))};
$app$render_wasm$api$start_initial_load_transition_BANG_$$=function($background$jscomp$2_epoch$jscomp$1$$){($APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))||$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$)==null)&&typeof $background$jscomp$2_epoch$jscomp$1$$==="string"&&$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$,["data:image/svg+xml;charset\x3dutf-8,",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(encodeURIComponent(["\x3csvg xmlns\x3d'http://www.w3.org/2000/svg' width\x3d'1' height\x3d'1'\x3e\x3crect width\x3d'1' height\x3d'1' fill\x3d'",
$background$jscomp$2_epoch$jscomp$1$$,"'/\x3e\x3c/svg\x3e"].join("")))].join(""));$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))||($background$jscomp$2_epoch$jscomp$1$$=$app$render_wasm$api$begin_page_transition_BANG_$$(),$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$($background$jscomp$2_epoch$jscomp$1$$))};
$app$main$ui$workspace$viewport$utils$title_transform_use_width_QMARK_$$=function($map__73850__$1_p__73847_rotation$jscomp$19$$){$map__73850__$1_p__73847_rotation$jscomp$19$$=$APP.$cljs$core$__destructure_map$$($map__73850__$1_p__73847_rotation$jscomp$19$$);$map__73850__$1_p__73847_rotation$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73850__$1_p__73847_rotation$jscomp$19$$,$APP.$cljs$cst$1788$rotation$$);return $APP.$cljs$core$even_QMARK_$$($APP.$app$common$math$ceil$$(($map__73850__$1_p__73847_rotation$jscomp$19$$-
45)/90))};
$app$main$ui$workspace$viewport$utils$text_transform$$=function($p__73826_x$jscomp$1233$$,$zoom$jscomp$51$$){var $map__73827__$1_y$jscomp$453$$=$APP.$cljs$core$__destructure_map$$($p__73826_x$jscomp$1233$$);$p__73826_x$jscomp$1233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73827__$1_y$jscomp$453$$,$APP.$cljs$cst$1510$x$$);$map__73827__$1_y$jscomp$453$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73827__$1_y$jscomp$453$$,$APP.$cljs$cst$1511$y$$);var $inv_zoom$$=1/
$zoom$jscomp$51$$;return"scale("+($inv_zoom$$??"")+", "+($inv_zoom$$??"")+") translate("+$zoom$jscomp$51$$*$p__73826_x$jscomp$1233$$+", "+$zoom$jscomp$51$$*$map__73827__$1_y$jscomp$453$$+")"};
$app$common$geom$shapes$intersect$on_segment_QMARK_$$=function($p__48863_qx$$,$p__48864_px$jscomp$5$$,$p__48865_rx$jscomp$11$$){var $map__48866__$1_qy$$=$APP.$cljs$core$__destructure_map$$($p__48863_qx$$);$p__48863_qx$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48866__$1_qy$$,$APP.$cljs$cst$1510$x$$);$map__48866__$1_qy$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48866__$1_qy$$,$APP.$cljs$cst$1511$y$$);var $map__48867__$1_py$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($p__48864_px$jscomp$5$$);
$p__48864_px$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48867__$1_py$jscomp$4$$,$APP.$cljs$cst$1510$x$$);$map__48867__$1_py$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48867__$1_py$jscomp$4$$,$APP.$cljs$cst$1511$y$$);var $map__48868__$1_ry$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($p__48865_rx$jscomp$11$$);$p__48865_rx$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48868__$1_ry$jscomp$5$$,$APP.$cljs$cst$1510$x$$);
$map__48868__$1_ry$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48868__$1_ry$jscomp$5$$,$APP.$cljs$cst$1511$y$$);return $p__48863_qx$$<=Math.max($p__48864_px$jscomp$5$$,$p__48865_rx$jscomp$11$$)&&$p__48863_qx$$>=Math.min($p__48864_px$jscomp$5$$,$p__48865_rx$jscomp$11$$)&&$map__48866__$1_qy$$<=Math.max($map__48867__$1_py$jscomp$4$$,$map__48868__$1_ry$jscomp$5$$)&&$map__48866__$1_qy$$>=Math.min($map__48867__$1_py$jscomp$4$$,$map__48868__$1_ry$jscomp$5$$)};
$app$common$geom$shapes$intersect$orientation$$=function($p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$,$p2$jscomp$42_x2$jscomp$27$$,$p3$jscomp$9_x3$jscomp$2$$){var $map__48860__$1_y1$jscomp$31$$=$APP.$cljs$core$__destructure_map$$($p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$);$p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48860__$1_y1$jscomp$31$$,$APP.$cljs$cst$1510$x$$);$map__48860__$1_y1$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48860__$1_y1$jscomp$31$$,
$APP.$cljs$cst$1511$y$$);var $map__48861__$1_y2$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($p2$jscomp$42_x2$jscomp$27$$);$p2$jscomp$42_x2$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48861__$1_y2$jscomp$29$$,$APP.$cljs$cst$1510$x$$);$map__48861__$1_y2$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48861__$1_y2$jscomp$29$$,$APP.$cljs$cst$1511$y$$);var $map__48862__$1_y3$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($p3$jscomp$9_x3$jscomp$2$$);
$p3$jscomp$9_x3$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48862__$1_y3$jscomp$2$$,$APP.$cljs$cst$1510$x$$);$map__48862__$1_y3$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48862__$1_y3$jscomp$2$$,$APP.$cljs$cst$1511$y$$);$p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$=($map__48861__$1_y2$jscomp$29$$-$map__48860__$1_y1$jscomp$31$$)*($p3$jscomp$9_x3$jscomp$2$$-$p2$jscomp$42_x2$jscomp$27$$)-($map__48862__$1_y3$jscomp$2$$-$map__48861__$1_y2$jscomp$29$$)*
($p2$jscomp$42_x2$jscomp$27$$-$p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$);return $p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$>0?$APP.$cljs$cst$1894$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_clockwise$$:$p1$jscomp$53_v$jscomp$521_x1$jscomp$29$$<0?$APP.$cljs$cst$1895$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_counter_clockwise$$:$APP.$cljs$cst$1896$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$};
$app$common$files$helpers$hidden_parent_QMARK_$$=function($objects$jscomp$28$$,$shape_id$jscomp$6$$){for(;;){var $parent_id$jscomp$4$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$28$$,$shape_id$jscomp$6$$);if($parent_id$jscomp$4$$==null||$shape_id$jscomp$6$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_id$jscomp$6$$,$APP.$app$common$uuid$zero$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$4$$,$APP.$app$common$uuid$zero$$))return!1;
if($APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$28$$,$parent_id$jscomp$4$$),$APP.$cljs$cst$1620$hidden$$)))return!0;$shape_id$jscomp$6$$=$parent_id$jscomp$4$$}};
$app$main$data$helpers$split_text_shapes$$=function($objects$jscomp$117$$,$G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$){$G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$=$APP.$cljs$core$seq$$($G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$);for(var $G__49402_G__49405_text_ids$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__49403_G__49406_shape_ids$jscomp$2$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $id$jscomp$157_temp__5823__auto__$jscomp$108$$=$APP.$cljs$core$first$$($G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$);
if($APP.$cljs$core$truth_$$($id$jscomp$157_temp__5823__auto__$jscomp$108$$)){var $shape$jscomp$147$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$117$$,$id$jscomp$157_temp__5823__auto__$jscomp$108$$);$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$147$$)?($G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$),$G__49402_G__49405_text_ids$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__49402_G__49405_text_ids$$,
$id$jscomp$157_temp__5823__auto__$jscomp$108$$)):($G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__49401_G__49404_ids$jscomp$20_ids__$1$jscomp$1$$),$G__49403_G__49406_shape_ids$jscomp$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__49403_G__49406_shape_ids$jscomp$2$$,$id$jscomp$157_temp__5823__auto__$jscomp$108$$))}else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__49402_G__49405_text_ids$$,$G__49403_G__49406_shape_ids$jscomp$2$$],
null)}};$app$common$files$helpers$unframed_shape_QMARK_$$=function($shape$jscomp$14$$){return $shape$jscomp$14$$!=null&&!$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$14$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$14$$?.$frame_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$14$$,$APP.$cljs$cst$1607$frame_id$$),$APP.$app$common$uuid$zero$$)};
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$=function($stream$jscomp$23$$,$deps$jscomp$13$$,$on_subscribe$jscomp$2$$,$on_dispose$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$($deps$jscomp$13$$,function(){if($APP.$cljs$core$truth_$$($stream$jscomp$23$$)){var $sub$jscomp$13$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$23$$,$on_subscribe$jscomp$2$$);return function(){$APP.$beicon$v2$core$_dispose$$($sub$jscomp$13$$);return $APP.$cljs$core$truth_$$($on_dispose$$)?
$on_dispose$$.$cljs$core$IFn$_invoke$arity$0$?$on_dispose$$.$cljs$core$IFn$_invoke$arity$0$():$on_dispose$$():null}}return null})};$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$=function($stream$jscomp$22$$,$deps$jscomp$12$$,$on_subscribe$jscomp$1$$){$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$($stream$jscomp$22$$,$deps$jscomp$12$$,$on_subscribe$jscomp$1$$,null)};
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$=function($stream$jscomp$21$$,$on_subscribe$$){$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$($stream$jscomp$21$$,[],$on_subscribe$$)};
$app$main$data$workspace$versions$apply_snapshot$$=function($p__73403$$){var $map__73404__$1$$=$APP.$cljs$core$__destructure_map$$($p__73403$$),$id$jscomp$860$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73404__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$versions$apply_snapshot_data_73405$$==="undefined"&&($app$main$data$workspace$versions$apply_snapshot_data_73405$$=function($p__73403$jscomp$1$$,$map__73404$jscomp$1$$,$snapshot$jscomp$2$$,$id$jscomp$861$$,$meta73406$$){this.$p__73403$=
$p__73403$jscomp$1$$;this.$map__73404$=$map__73404$jscomp$1$$;this.$snapshot$=$snapshot$jscomp$2$$;this.id=$id$jscomp$861$$;this.$meta73406$=$meta73406$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$apply_snapshot_data_73405$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$apply_snapshot_data_73405$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5046$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_apply_snapshot_data$$},
$app$main$data$workspace$versions$apply_snapshot_data_73405$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73407$$,$meta73406__$1$$){return new $app$main$data$workspace$versions$apply_snapshot_data_73405$$(this.$p__73403$,this.$map__73404$,this.$snapshot$,this.id,$meta73406__$1$$)},$app$main$data$workspace$versions$apply_snapshot_data_73405$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73406$},$app$main$data$workspace$versions$apply_snapshot_data_73405$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$apply_snapshot_data_73405$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2795$$,$state$jscomp$1077$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1077$$,$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$assoc$$,this.id,this.$snapshot$)});return new $app$main$data$workspace$versions$apply_snapshot_data_73405$$($p__73403$$,$map__73404__$1$$,$map__73404__$1$$,$id$jscomp$860$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$start_token_set_edition$$=function($edition_id$$){typeof $app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$=function($edition_id$jscomp$1$$,$meta73065$$){this.$edition_id$=$edition_id$jscomp$1$$;this.$meta73065$=$meta73065$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4728$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_start_token_set_edition$$},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73066$$,$meta73065__$1$$){return new $app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$(this.$edition_id$,
$meta73065__$1$$)},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73065$},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2684$$,$state$jscomp$1001$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1001$$,
$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4729$token_set_edition_id$$,this.$edition_id$)});return new $app$main$data$workspace$tokens$library_edit$start_token_set_edition_73064$$($edition_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker_gradient$$=function($changes$jscomp$227$$){typeof $app$main$data$workspace$colors$update_colorpicker_gradient_71019$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_gradient_71019$$=function($changes$jscomp$228$$,$meta71020$$){this.$changes$=$changes$jscomp$228$$;this.$meta71020$=$meta71020$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4172$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient$$},$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71021$$,$meta71020__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_gradient_71019$$(this.$changes$,
$meta71020__$1$$)},$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71020$},$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_gradient_71019$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2271$$,$state$jscomp$658$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$658$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$colorpicker$$,$APP.$cljs$cst$1724$gradient$$],null),$APP.$cljs$core$merge$$,this.$changes$)});return new $app$main$data$workspace$colors$update_colorpicker_gradient_71019$$($changes$jscomp$227$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$common$toggle_toolbar_visibility$$=function(){typeof $app$main$data$workspace$common$toggle_toolbar_visibility_67290$$==="undefined"&&($app$main$data$workspace$common$toggle_toolbar_visibility_67290$$=function($meta67291$$){this.$meta67291$=$meta67291$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3754$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_toggle_toolbar_visibility$$},$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67292$$,$meta67291__$1$$){return new $app$main$data$workspace$common$toggle_toolbar_visibility_67290$$($meta67291__$1$$)},$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67291$},$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$toggle_toolbar_visibility_67290$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1996$$,$state$jscomp$421$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$421$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3752$hide_toolbar$$],null),$APP.$cljs$core$not$$)});return new $app$main$data$workspace$common$toggle_toolbar_visibility_67290$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$modal$update_props$$=function($props$jscomp$87$$){typeof $app$main$data$modal$update_modal_props_51453$$==="undefined"&&($app$main$data$modal$update_modal_props_51453$$=function($_type$jscomp$1$$,$props$jscomp$88$$,$meta51454$$){this.$_type$=$_type$jscomp$1$$;this.props=$props$jscomp$88$$;this.$meta51454$=$meta51454$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$modal$update_modal_props_51453$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$update_modal_props_51453$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2340$app_DOT_main_DOT_data_DOT_modal_SLASH_update_modal_props$$},$app$main$data$modal$update_modal_props_51453$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51455$$,$meta51454__$1$$){return new $app$main$data$modal$update_modal_props_51453$$(this.$_type$,this.props,$meta51454__$1$$)},$app$main$data$modal$update_modal_props_51453$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta51454$},$app$main$data$modal$update_modal_props_51453$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$update_modal_props_51453$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1426$$,$state$jscomp$105$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$105$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$105$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$,$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$merge$$,this.props):$state$jscomp$105$$});return new $app$main$data$modal$update_modal_props_51453$$($APP.$cljs$cst$2239$colorpicker$$,$props$jscomp$87$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$=function($meta72782$$){this.$meta72782$=$meta72782$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4692$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_tokens_paths$$},$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72783$$,$meta72782__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$($meta72782__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72782$},$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2651$$,$state$jscomp$970$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$970$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4693$folded_token_paths$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$)});return new $app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72781$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_clipboard_style$$=function($style$jscomp$47$$){typeof $app$main$data$workspace$set_clipboard_style_72127$$==="undefined"&&($app$main$data$workspace$set_clipboard_style_72127$$=function($style$jscomp$48$$,$meta72128$$){this.style=$style$jscomp$48$$;this.$meta72128$=$meta72128$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_clipboard_style_72127$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$set_clipboard_style_72127$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4532$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_clipboard_style$$},$app$main$data$workspace$set_clipboard_style_72127$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72129$$,$meta72128__$1$$){return new $app$main$data$workspace$set_clipboard_style_72127$$(this.style,$meta72128__$1$$)},$app$main$data$workspace$set_clipboard_style_72127$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72128$},$app$main$data$workspace$set_clipboard_style_72127$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_clipboard_style_72127$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2599$$,$state$jscomp$936$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$936$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$2225$clipboard_style$$],null),this.style)});return new $app$main$data$workspace$set_clipboard_style_72127$$($style$jscomp$47$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_annotations_expanded$$=function($expanded$jscomp$4$$){typeof $app$main$data$workspace$set_annotations_expanded_72105$$==="undefined"&&($app$main$data$workspace$set_annotations_expanded_72105$$=function($expanded$jscomp$5$$,$meta72106$$){this.$expanded$=$expanded$jscomp$5$$;this.$meta72106$=$meta72106$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_annotations_expanded_72105$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_expanded_72105$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4525$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_annotations_expanded$$},$app$main$data$workspace$set_annotations_expanded_72105$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72107$$,$meta72106__$1$$){return new $app$main$data$workspace$set_annotations_expanded_72105$$(this.$expanded$,$meta72106__$1$$)},$app$main$data$workspace$set_annotations_expanded_72105$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72106$},$app$main$data$workspace$set_annotations_expanded_72105$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_expanded_72105$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2593$$,$state$jscomp$931$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$931$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4526$workspace_annotations$$,
$APP.$cljs$cst$3547$expanded$$],null),this.$expanded$)});return new $app$main$data$workspace$set_annotations_expanded_72105$$($expanded$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$start_rename_page_item$$=function($id$jscomp$757$$){typeof $app$main$data$workspace$start_rename_page_item_72090$$==="undefined"&&($app$main$data$workspace$start_rename_page_item_72090$$=function($id$jscomp$758$$,$meta72091$$){this.id=$id$jscomp$758$$;this.$meta72091$=$meta72091$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$start_rename_page_item_72090$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$start_rename_page_item_72090$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4522$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_page_item$$},$app$main$data$workspace$start_rename_page_item_72090$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72092$$,$meta72091__$1$$){return new $app$main$data$workspace$start_rename_page_item_72090$$(this.id,$meta72091__$1$$)},$app$main$data$workspace$start_rename_page_item_72090$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72091$},$app$main$data$workspace$start_rename_page_item_72090$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_rename_page_item_72090$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2590$$,$state$jscomp$928$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$928$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$2207$page_item$$],null),this.id)});return new $app$main$data$workspace$start_rename_page_item_72090$$($id$jscomp$757$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_margins_selected$$=function($margins_selected$$){typeof $app$main$data$workspace$set_margins_selected_72074$$==="undefined"&&($app$main$data$workspace$set_margins_selected_72074$$=function($margins_selected$jscomp$1$$,$meta72075$$){this.$margins_selected$=$margins_selected$jscomp$1$$;this.$meta72075$=$meta72075$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_margins_selected_72074$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_margins_selected_72074$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4520$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_margins_selected$$},$app$main$data$workspace$set_margins_selected_72074$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72076$$,$meta72075__$1$$){return new $app$main$data$workspace$set_margins_selected_72074$$(this.$margins_selected$,$meta72075__$1$$)},$app$main$data$workspace$set_margins_selected_72074$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72075$},$app$main$data$workspace$set_margins_selected_72074$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_margins_selected_72074$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2588$$,$state$jscomp$924$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$924$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$2220$margins_selected$$],null),this.$margins_selected$)});return new $app$main$data$workspace$set_margins_selected_72074$$($margins_selected$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_gap_selected$$=function($gap_selected$$){typeof $app$main$data$workspace$set_gap_selected_72068$$==="undefined"&&($app$main$data$workspace$set_gap_selected_72068$$=function($gap_selected$jscomp$1$$,$meta72069$$){this.$gap_selected$=$gap_selected$jscomp$1$$;this.$meta72069$=$meta72069$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_gap_selected_72068$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$set_gap_selected_72068$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4519$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_gap_selected$$},$app$main$data$workspace$set_gap_selected_72068$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72070$$,$meta72069__$1$$){return new $app$main$data$workspace$set_gap_selected_72068$$(this.$gap_selected$,$meta72069__$1$$)},$app$main$data$workspace$set_gap_selected_72068$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72069$},$app$main$data$workspace$set_gap_selected_72068$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_gap_selected_72068$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2587$$,$state$jscomp$923$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$923$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2219$gap_selected$$],
null),this.$gap_selected$)});return new $app$main$data$workspace$set_gap_selected_72068$$($gap_selected$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_paddings_selected$$=function($paddings_selected$$){typeof $app$main$data$workspace$set_paddings_selected_72060$$==="undefined"&&($app$main$data$workspace$set_paddings_selected_72060$$=function($paddings_selected$jscomp$1$$,$meta72061$$){this.$paddings_selected$=$paddings_selected$jscomp$1$$;this.$meta72061$=$meta72061$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_paddings_selected_72060$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_paddings_selected_72060$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4518$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_paddings_selected$$},$app$main$data$workspace$set_paddings_selected_72060$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72062$$,$meta72061__$1$$){return new $app$main$data$workspace$set_paddings_selected_72060$$(this.$paddings_selected$,$meta72061__$1$$)},$app$main$data$workspace$set_paddings_selected_72060$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72061$},$app$main$data$workspace$set_paddings_selected_72060$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_paddings_selected_72060$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2586$$,$state$jscomp$922$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$922$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$2218$paddings_selected$$],null),this.$paddings_selected$)});return new $app$main$data$workspace$set_paddings_selected_72060$$($paddings_selected$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_guide_context_menu$$=function($p__72012$$){var $map__72013__$1$$=$APP.$cljs$core$__destructure_map$$($p__72012$$),$position$jscomp$165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72013__$1$$,$APP.$cljs$cst$1676$position$$),$guide$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72013__$1$$,$APP.$cljs$cst$3848$guide$$);typeof $app$main$data$workspace$show_guide_context_menu_72015$$==="undefined"&&($app$main$data$workspace$show_guide_context_menu_72015$$=
function($p__72012$jscomp$1$$,$map__72013$jscomp$1$$,$params$jscomp$305$$,$position$jscomp$166$$,$guide$jscomp$10$$,$meta72016$$){this.$p__72012$=$p__72012$jscomp$1$$;this.$map__72013$=$map__72013$jscomp$1$$;this.params=$params$jscomp$305$$;this.position=$position$jscomp$166$$;this.guide=$guide$jscomp$10$$;this.$meta72016$=$meta72016$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_guide_context_menu_72015$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_guide_context_menu_72015$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4513$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_guide_context_menu$$},$app$main$data$workspace$show_guide_context_menu_72015$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72017$$,$meta72016__$1$$){return new $app$main$data$workspace$show_guide_context_menu_72015$$(this.$p__72012$,this.$map__72013$,this.params,
this.position,this.guide,$meta72016__$1$$)},$app$main$data$workspace$show_guide_context_menu_72015$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72016$},$app$main$data$workspace$show_guide_context_menu_72015$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_guide_context_menu_72015$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,
$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$3848$guide$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3848$guide$$,this.guide]))))});return new $app$main$data$workspace$show_guide_context_menu_72015$$($p__72012$$,$map__72013__$1$$,$map__72013__$1$$,$position$jscomp$165$$,$guide$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_page_item_context_menu$$=function($p__71973$$){var $map__71974__$1$$=$APP.$cljs$core$__destructure_map$$($p__71973$$),$position$jscomp$163$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71974__$1$$,$APP.$cljs$cst$1676$position$$),$page$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71974__$1$$,$APP.$cljs$cst$1624$page$$);typeof $app$main$data$workspace$show_page_item_context_menu_71975$$==="undefined"&&($app$main$data$workspace$show_page_item_context_menu_71975$$=
function($p__71973$jscomp$1$$,$map__71974$jscomp$1$$,$params$jscomp$299$$,$position$jscomp$164$$,$page$jscomp$104$$,$meta71976$$){this.$p__71973$=$p__71973$jscomp$1$$;this.$map__71974$=$map__71974$jscomp$1$$;this.params=$params$jscomp$299$$;this.position=$position$jscomp$164$$;this.page=$page$jscomp$104$$;this.$meta71976$=$meta71976$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_page_item_context_menu_71975$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_page_item_context_menu_71975$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4508$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_page_item_context_menu$$},$app$main$data$workspace$show_page_item_context_menu_71975$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71977$$,$meta71976__$1$$){return new $app$main$data$workspace$show_page_item_context_menu_71975$$(this.$p__71973$,this.$map__71974$,
this.params,this.position,this.page,$meta71976__$1$$)},$app$main$data$workspace$show_page_item_context_menu_71975$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71976$},$app$main$data$workspace$show_page_item_context_menu_71975$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_page_item_context_menu_71975$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,
$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$1624$page$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1921$selected$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.page)]))))});return new $app$main$data$workspace$show_page_item_context_menu_71975$$($p__71973$$,$map__71974__$1$$,$map__71974__$1$$,$position$jscomp$163$$,$page$jscomp$103$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_assets_group_open$$=function($file_id$jscomp$283$$,$section$jscomp$14$$,$path$jscomp$243$$,$open_QMARK_$jscomp$6$$){typeof $app$main$data$workspace$set_assets_group_open_71917$$==="undefined"&&($app$main$data$workspace$set_assets_group_open_71917$$=function($file_id$jscomp$284$$,$section$jscomp$15$$,$path$jscomp$244$$,$open_QMARK_$jscomp$7$$,$meta71918$$){this.$file_id$=$file_id$jscomp$284$$;this.section=$section$jscomp$15$$;this.path=$path$jscomp$244$$;this.$open_QMARK_$=
$open_QMARK_$jscomp$7$$;this.$meta71918$=$meta71918$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_assets_group_open_71917$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_group_open_71917$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4498$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_assets_group_open$$},$app$main$data$workspace$set_assets_group_open_71917$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71919$$,$meta71918__$1$$){return new $app$main$data$workspace$set_assets_group_open_71917$$(this.$file_id$,this.section,this.path,this.$open_QMARK_$,$meta71918__$1$$)},$app$main$data$workspace$set_assets_group_open_71917$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71918$},$app$main$data$workspace$set_assets_group_open_71917$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_group_open_71917$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2569$$,$state$jscomp$908$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$908$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$4496$open_status$$,this.$file_id$,$APP.$cljs$cst$4382$groups$$,this.section,this.path],null),this.$open_QMARK_$)});return new $app$main$data$workspace$set_assets_group_open_71917$$($file_id$jscomp$283$$,$section$jscomp$14$$,$path$jscomp$243$$,$open_QMARK_$jscomp$6$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_assets_section_open$$=function($file_id$jscomp$281$$,$section$jscomp$12$$,$open_QMARK_$jscomp$4$$){typeof $app$main$data$workspace$set_assets_section_open_71901$$==="undefined"&&($app$main$data$workspace$set_assets_section_open_71901$$=function($file_id$jscomp$282$$,$section$jscomp$13$$,$open_QMARK_$jscomp$5$$,$meta71902$$){this.$file_id$=$file_id$jscomp$282$$;this.section=$section$jscomp$13$$;this.$open_QMARK_$=$open_QMARK_$jscomp$5$$;this.$meta71902$=$meta71902$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_assets_section_open_71901$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_section_open_71901$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4494$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_assets_section_open$$},$app$main$data$workspace$set_assets_section_open_71901$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71903$$,
$meta71902__$1$$){return new $app$main$data$workspace$set_assets_section_open_71901$$(this.$file_id$,this.section,this.$open_QMARK_$,$meta71902__$1$$)},$app$main$data$workspace$set_assets_section_open_71901$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71902$},$app$main$data$workspace$set_assets_section_open_71901$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_section_open_71901$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2567$$,$state$jscomp$906$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$906$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$4496$open_status$$,this.$file_id$,this.section],null),this.$open_QMARK_$)});return new $app$main$data$workspace$set_assets_section_open_71901$$($file_id$jscomp$281$$,$section$jscomp$12$$,$open_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$workspace_focus_lost$$=function(){typeof $app$main$data$workspace$workspace_focus_lost_71869$$==="undefined"&&($app$main$data$workspace$workspace_focus_lost_71869$$=function($meta71870$$){this.$meta71870$=$meta71870$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$workspace_focus_lost_71869$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_focus_lost_71869$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4492$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_focus_lost$$},$app$main$data$workspace$workspace_focus_lost_71869$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71871$$,$meta71870__$1$$){return new $app$main$data$workspace$workspace_focus_lost_71869$$($meta71870__$1$$)},$app$main$data$workspace$workspace_focus_lost_71869$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71870$},$app$main$data$workspace$workspace_focus_lost_71869$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_focus_lost_71869$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2566$$,$state$jscomp$905$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$905$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$4493$show_distances_QMARK_$$],null),!1)});return new $app$main$data$workspace$workspace_focus_lost_71869$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$update_area_selection$$=function($rect$jscomp$41$$){typeof $app$main$data$workspace$path$selection$update_area_selection_69747$$==="undefined"&&($app$main$data$workspace$path$selection$update_area_selection_69747$$=function($rect$jscomp$42$$,$meta69748$$){this.rect=$rect$jscomp$42$$;this.$meta69748$=$meta69748$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$update_area_selection_69747$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$update_area_selection_69747$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4244$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_update_area_selection$$},$app$main$data$workspace$path$selection$update_area_selection_69747$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69749$$,$meta69748__$1$$){return new $app$main$data$workspace$path$selection$update_area_selection_69747$$(this.rect,
$meta69748__$1$$)},$app$main$data$workspace$path$selection$update_area_selection_69747$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69748$},$app$main$data$workspace$path$selection$update_area_selection_69747$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$update_area_selection_69747$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2324$$,$state$jscomp$715$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$715$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1605$selrect$$],null),this.rect)});return new $app$main$data$workspace$path$selection$update_area_selection_69747$$($rect$jscomp$41$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$reset_last_handler$$=function(){typeof $app$main$data$workspace$path$drawing$reset_last_handler_69988$$==="undefined"&&($app$main$data$workspace$path$drawing$reset_last_handler_69988$$=function($meta69989$$){this.$meta69989$=$meta69989$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$reset_last_handler_69988$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$drawing$reset_last_handler_69988$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4232$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_reset_last_handler$$},$app$main$data$workspace$path$drawing$reset_last_handler_69988$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69990$$,$meta69989__$1$$){return new $app$main$data$workspace$path$drawing$reset_last_handler_69988$$($meta69989__$1$$)},$app$main$data$workspace$path$drawing$reset_last_handler_69988$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69989$},$app$main$data$workspace$path$drawing$reset_last_handler_69988$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$reset_last_handler_69988$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2315_id$jscomp$674$$,$state$jscomp$706$$){$_$jscomp$2315_id$jscomp$674$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$706$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$706$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2315_id$jscomp$674$$,$APP.$cljs$cst$3554$prev_handler$$],null),null)});return new $app$main$data$workspace$path$drawing$reset_last_handler_69988$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$pick_color_select$$=function($shift_QMARK_$jscomp$10$$){typeof $app$main$data$workspace$colors$pick_color_select_70430$$==="undefined"&&($app$main$data$workspace$colors$pick_color_select_70430$$=function($value$jscomp$592$$,$shift_QMARK_$jscomp$11$$,$meta70431$$){this.value=$value$jscomp$592$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$11$$;this.$meta70431$=$meta70431$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$pick_color_select_70430$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$pick_color_select_70430$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4136$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_pick_color_select$$},$app$main$data$workspace$colors$pick_color_select_70430$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70432$$,$meta70431__$1$$){return new $app$main$data$workspace$colors$pick_color_select_70430$$(this.value,this.$shift_QMARK_$,$meta70431__$1$$)},
$app$main$data$workspace$colors$pick_color_select_70430$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70431$},$app$main$data$workspace$colors$pick_color_select_70430$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$pick_color_select_70430$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2232$$,$state$jscomp$627$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$627$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$4132$picked_color_select$$],null),this.value),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$4133$picked_shift_QMARK_$$],null),this.$shift_QMARK_$)});return new $app$main$data$workspace$colors$pick_color_select_70430$$(!0,$shift_QMARK_$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$pick_color$$=function($rgba$jscomp$10$$){typeof $app$main$data$workspace$colors$pick_color_70427$$==="undefined"&&($app$main$data$workspace$colors$pick_color_70427$$=function($rgba$jscomp$11$$,$meta70428$$){this.$rgba$=$rgba$jscomp$11$$;this.$meta70428$=$meta70428$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$pick_color_70427$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$pick_color_70427$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4134$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_pick_color$$},$app$main$data$workspace$colors$pick_color_70427$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70429$$,$meta70428__$1$$){return new $app$main$data$workspace$colors$pick_color_70427$$(this.$rgba$,$meta70428__$1$$)},$app$main$data$workspace$colors$pick_color_70427$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70428$},$app$main$data$workspace$colors$pick_color_70427$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$pick_color_70427$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2231$$,$state$jscomp$626$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$626$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$4135$picked_color$$],null),this.$rgba$)});return new $app$main$data$workspace$colors$pick_color_70427$$($rgba$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$update_selrect$$=function($selrect$jscomp$41$$){typeof $app$main$data$workspace$selection$update_selrect_67114$$==="undefined"&&($app$main$data$workspace$selection$update_selrect_67114$$=function($selrect$jscomp$42$$,$meta67115$$){this.$selrect$=$selrect$jscomp$42$$;this.$meta67115$=$meta67115$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$update_selrect_67114$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$update_selrect_67114$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3589$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_update_selrect$$},$app$main$data$workspace$selection$update_selrect_67114$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67116$$,$meta67115__$1$$){return new $app$main$data$workspace$selection$update_selrect_67114$$(this.$selrect$,$meta67115__$1$$)},
$app$main$data$workspace$selection$update_selrect_67114$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67115$},$app$main$data$workspace$selection$update_selrect_67114$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$update_selrect_67114$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1917$$,$state$jscomp$356$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$356$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1605$selrect$$],null),this.$selrect$)});return new $app$main$data$workspace$selection$update_selrect_67114$$($selrect$jscomp$41$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_layers_search_scope$$=function($scope$jscomp$8$$){typeof $app$main$data$workspace$update_layers_search_scope_72145$$==="undefined"&&($app$main$data$workspace$update_layers_search_scope_72145$$=function($scope$jscomp$9$$,$meta72146$$){this.scope=$scope$jscomp$9$$;this.$meta72146$=$meta72146$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$update_layers_search_scope_72145$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_layers_search_scope_72145$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4539$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_layers_search_scope$$},$app$main$data$workspace$update_layers_search_scope_72145$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72147$$,$meta72146__$1$$){return new $app$main$data$workspace$update_layers_search_scope_72145$$(this.scope,$meta72146__$1$$)},
$app$main$data$workspace$update_layers_search_scope_72145$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72146$},$app$main$data$workspace$update_layers_search_scope_72145$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_layers_search_scope_72145$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2602$$,$state$jscomp$939$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$939$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4537$layers_search$$],null)))?$APP.$cljs$core$assoc_in$$($state$jscomp$939$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4537$layers_search$$,$APP.$cljs$cst$571$scope$$],null),this.scope):$state$jscomp$939$$});return new $app$main$data$workspace$update_layers_search_scope_72145$$($scope$jscomp$8$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$select_colorpicker_gradient_stop$$=function($index$jscomp$311$$){typeof $app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$==="undefined"&&($app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$=function($index$jscomp$312$$,$meta71024$$){this.index=$index$jscomp$312$$;this.$meta71024$=$meta71024$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4182$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_select_colorpicket_gradient_stop$$},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71025$$,$meta71024__$1$$){return new $app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$(this.index,
$meta71024__$1$$)},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71024$},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2272$$,$state$jscomp$659$$){var $self__$jscomp$5320$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$659$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$40$$){var $temp__5823__auto__$jscomp$185$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1733$stops$$,$self__$jscomp$5320$$.index],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$185$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state__$1$jscomp$40$$,
$APP.$cljs$cst$4164$current_color$$,$temp__5823__auto__$jscomp$185$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4162$editing_stop$$,$self__$jscomp$5320$$.index])):$state__$1$jscomp$40$$})});return new $app$main$data$workspace$colors$select_colorpicket_gradient_stop_71023$$($index$jscomp$311$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$file$get_base_font_size$$=function($file_data$jscomp$57$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($file_data$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$873$options$$,$APP.$cljs$cst$2576$base_font_size$$],null),"16px")};
$app$main$data$workspace$texts$cursor_to_end$$=function($p__70082$$){var $map__70084__$1$$=$APP.$cljs$core$__destructure_map$$($p__70082$$),$id$jscomp$610$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70084__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$texts$cursor_to_end_70085$$==="undefined"&&($app$main$data$workspace$texts$cursor_to_end_70085$$=function($p__70082$jscomp$1$$,$map__70084$jscomp$1$$,$shape$jscomp$571$$,$id$jscomp$611$$,$meta70086$$){this.$p__70082$=
$p__70082$jscomp$1$$;this.$map__70084$=$map__70084$jscomp$1$$;this.shape=$shape$jscomp$571$$;this.id=$id$jscomp$611$$;this.$meta70086$=$meta70086$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$cursor_to_end_70085$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$cursor_to_end_70085$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4008$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_cursor_to_end$$},
$app$main$data$workspace$texts$cursor_to_end_70085$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70087$$,$meta70086__$1$$){return new $app$main$data$workspace$texts$cursor_to_end_70085$$(this.$p__70082$,this.$map__70084$,this.shape,this.id,$meta70086__$1$$)},$app$main$data$workspace$texts$cursor_to_end_70085$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70086$},$app$main$data$workspace$texts$cursor_to_end_70085$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$cursor_to_end_70085$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2166$$,$state$jscomp$565$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$565$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,this.id],null),$app$util$text_editor$cursor_to_end$$)});return new $app$main$data$workspace$texts$cursor_to_end_70085$$($p__70082$$,$map__70084__$1$$,
$map__70084__$1$$,$id$jscomp$610$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$select_all$$=function($p__70073$$){var $map__70074__$1$$=$APP.$cljs$core$__destructure_map$$($p__70073$$),$id$jscomp$608$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70074__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$texts$editor_select_all_70076$$==="undefined"&&($app$main$data$workspace$texts$editor_select_all_70076$$=function($p__70073$jscomp$1$$,$map__70074$jscomp$1$$,$shape$jscomp$569$$,$id$jscomp$609$$,$meta70077$$){this.$p__70073$=
$p__70073$jscomp$1$$;this.$map__70074$=$map__70074$jscomp$1$$;this.shape=$shape$jscomp$569$$;this.id=$id$jscomp$609$$;this.$meta70077$=$meta70077$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$editor_select_all_70076$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$editor_select_all_70076$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4007$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_editor_select_all$$},
$app$main$data$workspace$texts$editor_select_all_70076$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70078$$,$meta70077__$1$$){return new $app$main$data$workspace$texts$editor_select_all_70076$$(this.$p__70073$,this.$map__70074$,this.shape,this.id,$meta70077__$1$$)},$app$main$data$workspace$texts$editor_select_all_70076$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70077$},$app$main$data$workspace$texts$editor_select_all_70076$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$editor_select_all_70076$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2165$$,$state$jscomp$564$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$564$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,this.id],null),$app$util$text_editor$editor_select_all$$)});return new $app$main$data$workspace$texts$editor_select_all_70076$$($p__70073$$,
$map__70074__$1$$,$map__70074__$1$$,$id$jscomp$608$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$helpers$update_file$cljs$0core$0IFn$0_invoke$0arity$03$$=function($state$jscomp$70$$,$file_id$jscomp$7$$,$f$jscomp$773$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$70$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$file_id$jscomp$7$$],null),$f$jscomp$773$$)};
$clojure$set$superset_QMARK_$$=function($set1$jscomp$1$$,$set2$jscomp$1$$){return $APP.$cljs$core$count$$($set1$jscomp$1$$)>=$APP.$cljs$core$count$$($set2$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__24298_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($set1$jscomp$1$$,$p1__24298_SHARP_$$)},$set2$jscomp$1$$)};
$app$common$files$tokens$shapes_applied_all_QMARK_$$=function($ids_by_attributes$$,$shape_ids$jscomp$15$$,$attributes$jscomp$19$$){return $APP.$cljs$core$every_QMARK_$$(function($p1__71729_SHARP_$$){return $clojure$set$superset_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids_by_attributes$$,$p1__71729_SHARP_$$),$shape_ids$jscomp$15$$)},$attributes$jscomp$19$$)};
$cljs$tools$reader$unquote_QMARK_$$=function($form$jscomp$17$$){return $APP.$cljs$core$seq_QMARK_$$($form$jscomp$17$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($form$jscomp$17$$),$APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$)};$cljs$tools$reader$unquote_splicing_QMARK_$$=function($form$jscomp$16$$){return $APP.$cljs$core$seq_QMARK_$$($form$jscomp$16$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($form$jscomp$16$$),$APP.$cljs$cst$233$clojure_DOT_core_SLASH_unquote_splicing$$)};
$app$main$data$workspace$set_preview_blend_mode$$=function($ids$jscomp$251$$,$blend_mode$jscomp$4$$){typeof $app$main$data$workspace$set_preview_blend_mode_72113$$==="undefined"&&($app$main$data$workspace$set_preview_blend_mode_72113$$=function($ids$jscomp$252$$,$blend_mode$jscomp$5$$,$meta72114$$){this.ids=$ids$jscomp$252$$;this.$blend_mode$=$blend_mode$jscomp$5$$;this.$meta72114$=$meta72114$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_preview_blend_mode_72113$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_preview_blend_mode_72113$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4529$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_preview_blend_mode$$},$app$main$data$workspace$set_preview_blend_mode_72113$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72115$$,$meta72114__$1$$){return new $app$main$data$workspace$set_preview_blend_mode_72113$$(this.ids,this.$blend_mode$,$meta72114__$1$$)},
$app$main$data$workspace$set_preview_blend_mode_72113$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72114$},$app$main$data$workspace$set_preview_blend_mode_72113$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_preview_blend_mode_72113$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2596$$,$state$jscomp$933$$){var $self__$jscomp$6414$$=this;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__72111_SHARP_$$,
$p2__72112_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__72111_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2241$workspace_preview_blend$$,$p2__72112_SHARP_$$],null),$self__$jscomp$6414$$.$blend_mode$)},$state$jscomp$933$$,$self__$jscomp$6414$$.ids)});return new $app$main$data$workspace$set_preview_blend_mode_72113$$($ids$jscomp$251$$,$blend_mode$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$js_reserved_QMARK_$$=function($x$jscomp$652$$){$cljs$core$js_reserved$$==null&&($cljs$core$js_reserved$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__24202_SHARP_$$,$p2__24203_SHARP_$$){$p1__24202_SHARP_$$[$p2__24203_SHARP_$$]=!0;return $p1__24202_SHARP_$$},{},$cljs$core$js_reserved_arr$$));return $cljs$core$js_reserved$$.hasOwnProperty($x$jscomp$652$$)};
$app$main$data$workspace$grid_layout$editor$remove_selection$$=function($grid_id$jscomp$7$$,$cell_id$jscomp$7$$){typeof $app$main$data$workspace$grid_layout$editor$remove_selection_70887$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$remove_selection_70887$$=function($grid_id$jscomp$8$$,$cell_id$jscomp$8$$,$meta70888$$){this.$grid_id$=$grid_id$jscomp$8$$;this.$cell_id$=$cell_id$jscomp$8$$;this.$meta70888$=$meta70888$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4386$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_remove_selection$$},$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70889$$,$meta70888__$1$$){return new $app$main$data$workspace$grid_layout$editor$remove_selection_70887$$(this.$grid_id$,this.$cell_id$,$meta70888__$1$$)},$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70888$},$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$remove_selection_70887$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2455$$,$state$jscomp$817$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$817$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$disj$$,this.$cell_id$)});return new $app$main$data$workspace$grid_layout$editor$remove_selection_70887$$($grid_id$jscomp$7$$,$cell_id$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_handler_leave$$=function($index$jscomp$326$$,$prefix$jscomp$54$$){typeof $app$main$data$workspace$path$selection$path_handler_leave_69703$$==="undefined"&&($app$main$data$workspace$path$selection$path_handler_leave_69703$$=function($index$jscomp$327$$,$prefix$jscomp$55$$,$meta69704$$){this.index=$index$jscomp$327$$;this.prefix=$prefix$jscomp$55$$;this.$meta69704$=$meta69704$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$selection$path_handler_leave_69703$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_leave_69703$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4239$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_handler_leave$$},$app$main$data$workspace$path$selection$path_handler_leave_69703$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69705$$,
$meta69704__$1$$){return new $app$main$data$workspace$path$selection$path_handler_leave_69703$$(this.index,this.prefix,$meta69704__$1$$)},$app$main$data$workspace$path$selection$path_handler_leave_69703$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69704$},$app$main$data$workspace$path$selection$path_handler_leave_69703$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_leave_69703$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2320_id$jscomp$679$$,$state$jscomp$711$$){$_$jscomp$2320_id$jscomp$679$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$711$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$711$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2320_id$jscomp$679$$,$APP.$cljs$cst$4238$hover_handlers$$],null),$APP.$cljs$core$disj$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.index,this.prefix],null))});return new $app$main$data$workspace$path$selection$path_handler_leave_69703$$($index$jscomp$326$$,$prefix$jscomp$54$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_pointer_leave$$=function($position$jscomp$140$$){typeof $app$main$data$workspace$path$selection$path_pointer_leave_69694$$==="undefined"&&($app$main$data$workspace$path$selection$path_pointer_leave_69694$$=function($position$jscomp$141$$,$meta69695$$){this.position=$position$jscomp$141$$;this.$meta69695$=$meta69695$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$path_pointer_leave_69694$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_leave_69694$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4236$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_pointer_leave$$},$app$main$data$workspace$path$selection$path_pointer_leave_69694$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69696$$,$meta69695__$1$$){return new $app$main$data$workspace$path$selection$path_pointer_leave_69694$$(this.position,
$meta69695__$1$$)},$app$main$data$workspace$path$selection$path_pointer_leave_69694$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69695$},$app$main$data$workspace$path$selection$path_pointer_leave_69694$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_leave_69694$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2318_id$jscomp$677$$,$state$jscomp$709$$){$_$jscomp$2318_id$jscomp$677$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$709$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$709$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2318_id$jscomp$677$$,$APP.$cljs$cst$4235$hover_points$$],null),$APP.$cljs$core$disj$$,this.position)});return new $app$main$data$workspace$path$selection$path_pointer_leave_69694$$($position$jscomp$140$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$=function($meta73089$$){this.$meta73089$=$meta73089$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4733$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_token_set_creation$$},$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73090$$,$meta73089__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$($meta73089__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73089$},$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2687$$,$state$jscomp$1004$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1004$$,
$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4731$token_set_new_path$$)});return new $app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73088$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$=function($p__73029$$){var $map__73030__$1$$=$APP.$cljs$core$__destructure_map$$($p__73029$$),$position$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73030__$1$$,$APP.$cljs$cst$1676$position$$);typeof $app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$=function($p__73029$jscomp$1$$,
$map__73030$jscomp$1$$,$params$jscomp$318$$,$position$jscomp$174$$,$meta73033$$){this.$p__73029$=$p__73029$jscomp$1$$;this.$map__73030$=$map__73030$jscomp$1$$;this.params=$params$jscomp$318$$;this.position=$position$jscomp$174$$;this.$meta73033$=$meta73033$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4725$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_assign_token_set_context_menu$$},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73034$$,$meta73033__$1$$){return new $app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$(this.$p__73029$,
this.$map__73030$,this.params,this.position,$meta73033__$1$$)},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73033$},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2682$$,$state$jscomp$999$$){return $APP.$cljs$core$truth_$$(this.params)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$999$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4726$token_set_context_menu$$,this.params):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$999$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4726$token_set_context_menu$$)});return new $app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73032$$($p__73029$$,
$map__73030__$1$$,$map__73030__$1$$,$position$jscomp$173$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$=function($p__73024$$){var $map__73025__$1$$=$APP.$cljs$core$__destructure_map$$($p__73024$$),$position$jscomp$171$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73025__$1$$,$APP.$cljs$cst$1676$position$$);typeof $app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$=function($p__73024$jscomp$1$$,
$map__73025$jscomp$1$$,$params$jscomp$316$$,$position$jscomp$172$$,$meta73027$$){this.$p__73024$=$p__73024$jscomp$1$$;this.$map__73025$=$map__73025$jscomp$1$$;this.params=$params$jscomp$316$$;this.position=$position$jscomp$172$$;this.$meta73027$=$meta73027$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4723$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_show_token_node_context_menu$$},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73028$$,$meta73027__$1$$){return new $app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$(this.$p__73024$,
this.$map__73025$,this.params,this.position,$meta73027__$1$$)},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73027$},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2681$$,$state$jscomp$998$$){return $APP.$cljs$core$truth_$$(this.params)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$998$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4724$token_node_context_menu$$,this.params):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$998$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4724$token_node_context_menu$$)});return new $app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73026$$($p__73024$$,
$map__73025__$1$$,$map__73025__$1$$,$position$jscomp$171$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$=function($p__73014$$){var $map__73015__$1$$=$APP.$cljs$core$__destructure_map$$($p__73014$$),$position$jscomp$169$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73015__$1$$,$APP.$cljs$cst$1676$position$$);typeof $app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$=function($p__73014$jscomp$1$$,$map__73015$jscomp$1$$,
$params$jscomp$314$$,$position$jscomp$170$$,$meta73017$$){this.$p__73014$=$p__73014$jscomp$1$$;this.$map__73015$=$map__73015$jscomp$1$$;this.params=$params$jscomp$314$$;this.position=$position$jscomp$170$$;this.$meta73017$=$meta73017$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4722$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_show_token_context_menu$$},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73018$$,$meta73017__$1$$){return new $app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$(this.$p__73014$,this.$map__73015$,this.params,this.position,$meta73017__$1$$)},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73017$},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2680$$,$state$jscomp$997$$){return $APP.$cljs$core$truth_$$(this.params)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$997$$,$APP.$cljs$cst$2137$workspace_tokens$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2206$token_context_menu$$,this.params):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$997$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2206$token_context_menu$$)});return new $app$main$data$workspace$tokens$library_edit$show_token_context_menu_73016$$($p__73014$$,$map__73015__$1$$,$map__73015__$1$$,$position$jscomp$169$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$unset_preview_blend_mode$$=function($ids$jscomp$253$$){typeof $app$main$data$workspace$unset_preview_blend_mode_72118$$==="undefined"&&($app$main$data$workspace$unset_preview_blend_mode_72118$$=function($ids$jscomp$254$$,$meta72119$$){this.ids=$ids$jscomp$254$$;this.$meta72119$=$meta72119$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$unset_preview_blend_mode_72118$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unset_preview_blend_mode_72118$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4530$app_DOT_main_DOT_data_DOT_workspace_SLASH_unset_preview_blend_mode$$},$app$main$data$workspace$unset_preview_blend_mode_72118$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72120$$,$meta72119__$1$$){return new $app$main$data$workspace$unset_preview_blend_mode_72118$$(this.ids,$meta72119__$1$$)},$app$main$data$workspace$unset_preview_blend_mode_72118$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72119$},$app$main$data$workspace$unset_preview_blend_mode_72118$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unset_preview_blend_mode_72118$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2597$$,$state$jscomp$934$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__72116_SHARP_$$,$p2__72117_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__72116_SHARP_$$,
$APP.$cljs$cst$2241$workspace_preview_blend$$,$APP.$cljs$core$dissoc$$,$p2__72117_SHARP_$$)},$state$jscomp$934$$,this.ids)});return new $app$main$data$workspace$unset_preview_blend_mode_72118$$($ids$jscomp$253$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$stop_rename_page_item$$=function(){typeof $app$main$data$workspace$stop_rename_page_item_72098$$==="undefined"&&($app$main$data$workspace$stop_rename_page_item_72098$$=function($meta72099$$){this.$meta72099$=$meta72099$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$stop_rename_page_item_72098$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$stop_rename_page_item_72098$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4523$app_DOT_main_DOT_data_DOT_workspace_SLASH_stop_rename_page_item$$},$app$main$data$workspace$stop_rename_page_item_72098$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72100$$,$meta72099__$1$$){return new $app$main$data$workspace$stop_rename_page_item_72098$$($meta72099__$1$$)},$app$main$data$workspace$stop_rename_page_item_72098$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72099$},$app$main$data$workspace$stop_rename_page_item_72098$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$stop_rename_page_item_72098$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2591_local$jscomp$22$$,$state$jscomp$929$$){$_$jscomp$2591_local$jscomp$22$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$929$$),$APP.$cljs$cst$2207$page_item$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$929$$,
$APP.$cljs$cst$1920$workspace_local$$,$_$jscomp$2591_local$jscomp$22$$)});return new $app$main$data$workspace$stop_rename_page_item_72098$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$=function($file_id$jscomp$291$$){typeof $app$main$data$workspace$unselect_all_assets_71944$$==="undefined"&&($app$main$data$workspace$unselect_all_assets_71944$$=function($file_id$jscomp$292$$,$meta71945$$){this.$file_id$=$file_id$jscomp$292$$;this.$meta71945$=$meta71945$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$unselect_all_assets_71944$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unselect_all_assets_71944$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4502$app_DOT_main_DOT_data_DOT_workspace_SLASH_unselect_all_assets$$},$app$main$data$workspace$unselect_all_assets_71944$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71946$$,$meta71945__$1$$){return new $app$main$data$workspace$unselect_all_assets_71944$$(this.$file_id$,$meta71945__$1$$)},$app$main$data$workspace$unselect_all_assets_71944$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71945$},$app$main$data$workspace$unselect_all_assets_71944$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unselect_all_assets_71944$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2573$$,$state$jscomp$912$$){return $APP.$cljs$core$truth_$$(this.$file_id$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$912$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$dissoc$$,this.$file_id$):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$912$$,$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1921$selected$$)});return new $app$main$data$workspace$unselect_all_assets_71944$$($file_id$jscomp$291$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing$$=function($grid_id$jscomp$13$$){typeof $app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$=function($grid_id$jscomp$14$$,$meta70924$$){this.$grid_id$=$grid_id$jscomp$14$$;this.$meta70924$=$meta70924$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4389$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_stop_grid_layout_editing$$},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70925$$,$meta70924__$1$$){return new $app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$(this.$grid_id$,
$meta70924__$1$$)},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70924$},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2458$$,$state$jscomp$820$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$820$$,
$APP.$cljs$cst$2240$workspace_grid_edition$$,$APP.$cljs$core$dissoc$$,this.$grid_id$)});return new $app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_70923$$($grid_id$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$clear_selection$$=function($grid_id$jscomp$9$$){typeof $app$main$data$workspace$grid_layout$editor$clear_selection_70891$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$clear_selection_70891$$=function($grid_id$jscomp$10$$,$meta70892$$){this.$grid_id$=$grid_id$jscomp$10$$;this.$meta70892$=$meta70892$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4387$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_clear_selection$$},$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70893$$,$meta70892__$1$$){return new $app$main$data$workspace$grid_layout$editor$clear_selection_70891$$(this.$grid_id$,
$meta70892__$1$$)},$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70892$},$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$clear_selection_70891$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2456$$,$state$jscomp$818$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$818$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1921$selected$$)});return new $app$main$data$workspace$grid_layout$editor$clear_selection_70891$$($grid_id$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$clear_area_selection$$=function(){typeof $app$main$data$workspace$path$selection$clear_area_selection_69753$$==="undefined"&&($app$main$data$workspace$path$selection$clear_area_selection_69753$$=function($meta69754$$){this.$meta69754$=$meta69754$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$clear_area_selection_69753$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$selection$clear_area_selection_69753$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4245$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_clear_area_selection$$},$app$main$data$workspace$path$selection$clear_area_selection_69753$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69755$$,$meta69754__$1$$){return new $app$main$data$workspace$path$selection$clear_area_selection_69753$$($meta69754__$1$$)},$app$main$data$workspace$path$selection$clear_area_selection_69753$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69754$},$app$main$data$workspace$path$selection$clear_area_selection_69753$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$clear_area_selection_69753$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2325$$,$state$jscomp$716$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$716$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1605$selrect$$)});
return new $app$main$data$workspace$path$selection$clear_area_selection_69753$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$close_path_drag_end$$=function(){typeof $app$main$data$workspace$path$drawing$close_path_drag_end_69851$$==="undefined"&&($app$main$data$workspace$path$drawing$close_path_drag_end_69851$$=function($meta69852$$){this.$meta69852$=$meta69852$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4220$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_end$$},$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69853$$,$meta69852__$1$$){return new $app$main$data$workspace$path$drawing$close_path_drag_end_69851$$($meta69852__$1$$)},$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69852$},$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$close_path_drag_end_69851$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2301_id$jscomp$668$$,$state$jscomp$692$$){$_$jscomp$2301_id$jscomp$668$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$692$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$692$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2301_id$jscomp$668$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3554$prev_handler$$)});return new $app$main$data$workspace$path$drawing$close_path_drag_end_69851$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$activate_colorpicker_image$$=function(){typeof $app$main$data$workspace$colors$activate_colorpicker_image_71040$$==="undefined"&&($app$main$data$workspace$colors$activate_colorpicker_image_71040$$=function($meta71041$$){this.$meta71041$=$meta71041$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$activate_colorpicker_image_71040$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$activate_colorpicker_image_71040$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4184$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_image$$},$app$main$data$workspace$colors$activate_colorpicker_image_71040$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71042$$,$meta71041__$1$$){return new $app$main$data$workspace$colors$activate_colorpicker_image_71040$$($meta71041__$1$$)},$app$main$data$workspace$colors$activate_colorpicker_image_71040$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71041$},$app$main$data$workspace$colors$activate_colorpicker_image_71040$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_image_71040$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2276$$,$state$jscomp$662$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$662$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$43$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$43$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1612$image$$),$APP.$cljs$cst$4162$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1733$stops$$,$APP.$cljs$cst$1724$gradient$$]))})});return new $app$main$data$workspace$colors$activate_colorpicker_image_71040$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$finalize_colorpicker$$=function(){typeof $app$main$data$workspace$colors$finalize_colorpicker_70947$$==="undefined"&&($app$main$data$workspace$colors$finalize_colorpicker_70947$$=function($meta70948$$){this.$meta70948$=$meta70948$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$finalize_colorpicker_70947$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$finalize_colorpicker_70947$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4171$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_finalize_colorpicker$$},$app$main$data$workspace$colors$finalize_colorpicker_70947$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70949$$,$meta70948__$1$$){return new $app$main$data$workspace$colors$finalize_colorpicker_70947$$($meta70948__$1$$)},$app$main$data$workspace$colors$finalize_colorpicker_70947$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70948$},$app$main$data$workspace$colors$finalize_colorpicker_70947$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$finalize_colorpicker_70947$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2261$$,$state$jscomp$648$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$648$$,$APP.$cljs$cst$2239$colorpicker$$)});return new $app$main$data$workspace$colors$finalize_colorpicker_70947$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$clear_color_components$$=function($data$jscomp$382$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($data$jscomp$382$$,$APP.$cljs$cst$2687$hex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$746$alpha$$,$APP.$cljs$cst$1743$r$$,$APP.$cljs$cst$1744$g$$,$APP.$cljs$cst$1520$b$$,$APP.$cljs$cst$1899$h$$,$APP.$cljs$cst$4168$s$$,$APP.$cljs$cst$3670$v$$,$APP.$cljs$cst$1612$image$$]))};
$app$main$data$workspace$texts$clean_text_modifier$$=function($id$jscomp$629$$){typeof $app$main$data$workspace$texts$clean_text_modifier_70307$$==="undefined"&&($app$main$data$workspace$texts$clean_text_modifier_70307$$=function($id$jscomp$630$$,$meta70308$$){this.id=$id$jscomp$630$$;this.$meta70308$=$meta70308$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$clean_text_modifier_70307$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$clean_text_modifier_70307$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4028$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_clean_text_modifier$$},$app$main$data$workspace$texts$clean_text_modifier_70307$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70309$$,$meta70308__$1$$){return new $app$main$data$workspace$texts$clean_text_modifier_70307$$(this.id,$meta70308__$1$$)},$app$main$data$workspace$texts$clean_text_modifier_70307$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70308$},$app$main$data$workspace$texts$clean_text_modifier_70307$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$clean_text_modifier_70307$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2184$$,$state$jscomp$583$$){var $self__$jscomp$5022$$=this,$current_value$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$583$$,
$APP.$cljs$cst$2238$workspace_text_modifier$$),$self__$jscomp$5022$$.id);return $APP.$beicon$v2$core$delay$$(100,(0,$APP.$beicon$v2$core$of$$)(function($state__$1$jscomp$25$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$25$$,$APP.$cljs$cst$2238$workspace_text_modifier$$),$self__$jscomp$5022$$.id)===$current_value$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$25$$,$APP.$cljs$cst$2238$workspace_text_modifier$$,
$APP.$cljs$core$dissoc$$,$self__$jscomp$5022$$.id):$state__$1$jscomp$25$$}))});return new $app$main$data$workspace$texts$clean_text_modifier_70307$$($id$jscomp$629$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$update_editor$$=function($editor$$){typeof $app$main$data$workspace$texts$update_editor_70001$$==="undefined"&&($app$main$data$workspace$texts$update_editor_70001$$=function($editor$jscomp$1$$,$meta70002$$){this.editor=$editor$jscomp$1$$;this.$meta70002$=$meta70002$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_editor_70001$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$update_editor_70001$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4002$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor$$},$app$main$data$workspace$texts$update_editor_70001$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70003$$,$meta70002__$1$$){return new $app$main$data$workspace$texts$update_editor_70001$$(this.editor,$meta70002__$1$$)},$app$main$data$workspace$texts$update_editor_70001$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70002$},$app$main$data$workspace$texts$update_editor_70001$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_editor_70001$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2159$$,$state$jscomp$559$$){return this.editor!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$559$$,$APP.$cljs$cst$2221$workspace_editor$$,this.editor):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$559$$,
$APP.$cljs$cst$2221$workspace_editor$$)});return new $app$main$data$workspace$texts$update_editor_70001$$($editor$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$specialized_panel$clear_specialized_panel$$=function(){typeof $app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$==="undefined"&&($app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$=function($meta67255$$){this.$meta67255$=$meta67255$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3763$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_clear_specialized_panel$$},$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67256$$,$meta67255__$1$$){return new $app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$($meta67255__$1$$)},
$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67255$},$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2005$$,$state$jscomp$429$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$429$$,
$APP.$cljs$cst$2242$specialized_panel$$)});return new $app$main$data$workspace$specialized_panel$clear_specialized_panel_67254$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$finalize_project$$=function($project_id$jscomp$9$$){typeof $app$main$data$project$finalize_project_55793$$==="undefined"&&($app$main$data$project$finalize_project_55793$$=function($project_id$jscomp$10$$,$meta55794$$){this.$project_id$=$project_id$jscomp$10$$;this.$meta55794$=$meta55794$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$finalize_project_55793$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$project$finalize_project_55793$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3513$app_DOT_main_DOT_data_DOT_project_SLASH_finalize_project$$},$app$main$data$project$finalize_project_55793$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55795$$,$meta55794__$1$$){return new $app$main$data$project$finalize_project_55793$$(this.$project_id$,$meta55794__$1$$)},$app$main$data$project$finalize_project_55793$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55794$},$app$main$data$project$finalize_project_55793$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$finalize_project_55793$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1859_project_id_SINGLEQUOTE_$$,$state$jscomp$301$$){$_$jscomp$1859_project_id_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$301$$,$APP.$cljs$cst$2174$current_project_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1859_project_id_SINGLEQUOTE_$$,
this.$project_id$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$301$$,$APP.$cljs$cst$2174$current_project_id$$):$state$jscomp$301$$});return new $app$main$data$project$finalize_project_55793$$($project_id$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$discard_persistence_state$$=function(){typeof $app$main$data$persistence$discard_persistence_state_55325$$==="undefined"&&($app$main$data$persistence$discard_persistence_state_55325$$=function($meta55326$$){this.$meta55326$=$meta55326$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$discard_persistence_state_55325$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$discard_persistence_state_55325$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3155$app_DOT_main_DOT_data_DOT_persistence_SLASH_discard_persistence_state$$},$app$main$data$persistence$discard_persistence_state_55325$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55327$$,$meta55326__$1$$){return new $app$main$data$persistence$discard_persistence_state_55325$$($meta55326__$1$$)},$app$main$data$persistence$discard_persistence_state_55325$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55326$},$app$main$data$persistence$discard_persistence_state_55325$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$discard_persistence_state_55325$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1656$$,$state$jscomp$189$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$189$$,$APP.$cljs$cst$2178$persistence$$)});return new $app$main$data$persistence$discard_persistence_state_55325$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_annotations_id_for_create$$=function($id$jscomp$761$$){typeof $app$main$data$workspace$set_annotations_id_for_create_72108$$==="undefined"&&($app$main$data$workspace$set_annotations_id_for_create_72108$$=function($id$jscomp$762$$,$meta72109$$){this.id=$id$jscomp$762$$;this.$meta72109$=$meta72109$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4527$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_annotations_id_for_create$$},$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72110$$,$meta72109__$1$$){return new $app$main$data$workspace$set_annotations_id_for_create_72108$$(this.id,$meta72109__$1$$)},
$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72109$},$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2594$$,$state$jscomp$932$$){return $APP.$cljs$core$truth_$$(this.id)?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$932$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4526$workspace_annotations$$,$APP.$cljs$cst$4528$id_for_create$$],null),this.id),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4526$workspace_annotations$$,$APP.$cljs$cst$3547$expanded$$],null),!0):$APP.$app$common$data$dissoc_in$$($state$jscomp$932$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4526$workspace_annotations$$,$APP.$cljs$cst$4528$id_for_create$$],null))},$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_id_for_create_72108$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return this.id!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"create-component-annotation"],null))):null});return new $app$main$data$workspace$set_annotations_id_for_create_72108$$($id$jscomp$761$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$text$content$to_dom$set_dataset$$=function($element$jscomp$66$$,$G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$){$G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$=$APP.$cljs$core$seq$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$);for(var $c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$=null,$G__53624_count__53502$$=0,$i__53503$$=0;;)if($i__53503$$<$G__53624_count__53502$$){var $data_value_vec__53517$$=
$c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__53503$$),$G__53623_data_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data_value_vec__53517$$,0,null);$data_value_vec__53517$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data_value_vec__53517$$,1,null);$APP.$app$util$dom$set_data_BANG_$$($element$jscomp$66$$,$APP.$cljs$core$name$$($G__53623_data_name$$),$data_value_vec__53517$$);$i__53503$$+=1}else if($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$=
$APP.$cljs$core$seq$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$)?($c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$=$APP.$cljs$core$_chunked_first$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$),$G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$=$APP.$cljs$core$_chunked_rest$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$),
$G__53623_data_name$$=$c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$,$G__53624_count__53502$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$),$c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$=$G__53623_data_name$$):($c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$=$APP.$cljs$core$first$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$),$G__53623_data_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$,
0,null),$data_value_vec__53517$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$,1,null),$APP.$app$util$dom$set_data_BANG_$$($element$jscomp$66$$,$APP.$cljs$core$name$$($G__53623_data_name$$),$data_value_vec__53517$$),$G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$=$APP.$cljs$core$next$$($G__53622_data$jscomp$255_seq__53500_seq__53500__$1_temp__5825__auto__$jscomp$165$$),$c__5548__auto__$jscomp$16_chunk__53501_vec__53537$$=
null,$G__53624_count__53502$$=0),$i__53503$$=0;else break};
$app$main$ui$hooks$use_rxsub$$=function(){var $vec__52587$$=(0,$APP.$rumext$v2$useState$$)(function(){return($APP.$app$main$streams$mouse_position$$!=null?$APP.$app$main$streams$mouse_position$$.$cljs$lang$protocol_mask$partition0$$&32768||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$APP.$app$main$streams$mouse_position$$.$cljs$core$IDeref$$||($APP.$app$main$streams$mouse_position$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$APP.$app$main$streams$mouse_position$$)):
$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$APP.$app$main$streams$mouse_position$$))?$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$):null}),$state$jscomp$150$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52587$$,0,null),$reset_state_BANG_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52587$$,1,null);(0,$APP.$rumext$v2$useEffect$$)(function(){var $sub$jscomp$12$$=$APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$streams$mouse_position$$,
function($p1__52583_SHARP_$$){return $reset_state_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$reset_state_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($p1__52583_SHARP_$$):$reset_state_BANG_$$($p1__52583_SHARP_$$)});return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$12$$)}},[$APP.$app$main$streams$mouse_position$$]);return $state$jscomp$150$$};
$app$common$geom$shapes$intersect$intersects_line_ellipse_QMARK_$$=function($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$,$a$jscomp$364_map__48914__$1_p__48908$$){var $determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$,0,null),$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$=$APP.$cljs$core$__destructure_map$$($determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$);$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$,$APP.$cljs$cst$1510$x$$);$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$,$APP.$cljs$cst$1511$y$$);$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$,1,null);var $map__48913__$1_y2$jscomp$32$$=
$APP.$cljs$core$__destructure_map$$($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$);$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48913__$1_y2$jscomp$32$$,$APP.$cljs$cst$1510$x$$);$map__48913__$1_y2$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48913__$1_y2$jscomp$32$$,$APP.$cljs$cst$1511$y$$);$a$jscomp$364_map__48914__$1_p__48908$$=$APP.$cljs$core$__destructure_map$$($a$jscomp$364_map__48914__$1_p__48908$$);
var $cx$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48914__$1_p__48908$$,$APP.$cljs$cst$1897$cx$$),$cy$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48914__$1_p__48908$$,$APP.$cljs$cst$1898$cy$$),$rx$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48914__$1_p__48908$$,$APP.$cljs$cst$1881$rx$$),$ry$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48914__$1_p__48908$$,
$APP.$cljs$cst$1882$ry$$);$a$jscomp$364_map__48914__$1_p__48908$$=$app$common$math$sq$$($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$-$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$)/($rx$jscomp$13$$*$rx$jscomp$13$$)+$app$common$math$sq$$($map__48913__$1_y2$jscomp$32$$-$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$)/($ry$jscomp$7$$*$ry$jscomp$7$$);$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$=(2*$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$*($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$-
$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$)-2*$cx$jscomp$11$$*($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$-$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$))/($rx$jscomp$13$$*$rx$jscomp$13$$)+(2*$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$*($map__48913__$1_y2$jscomp$32$$-$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$)-2*$cy$jscomp$12$$*($map__48913__$1_y2$jscomp$32$$-$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$))/($ry$jscomp$7$$*$ry$jscomp$7$$);
$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$=($determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$*$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$+$cx$jscomp$11$$*$cx$jscomp$11$$+-2*$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$*$cx$jscomp$11$$)/($rx$jscomp$13$$*$rx$jscomp$13$$)+($c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$*$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$+$cy$jscomp$12$$*$cy$jscomp$12$$+-2*$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$*
$cy$jscomp$12$$)/($ry$jscomp$7$$*$ry$jscomp$7$$)+-1;$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$*$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$-4*$a$jscomp$364_map__48914__$1_p__48908$$*$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$;if($APP.$app$common$math$almost_zero_QMARK_$$($a$jscomp$364_map__48914__$1_p__48908$$)){if($APP.$app$common$math$almost_zero_QMARK_$$($b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$))return null;
$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=-$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$/$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$;return $determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$>=0&&$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$<=1}return $determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$>=0?($c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$=(-$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$+Math.sqrt($determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$))/
(2*$a$jscomp$364_map__48914__$1_p__48908$$),$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=(-$b$jscomp$296_map__48913_p__48907_x2$jscomp$30$$-Math.sqrt($determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$))/(2*$a$jscomp$364_map__48914__$1_p__48908$$),$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$>=0&&$c$jscomp$278_map__48912__$1_t1$jscomp$9_y1$jscomp$34$$<=1||$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$>=0&&$determ_map__48912_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$<=
1):null};
$app$common$types$color$hsl__GT_rgb$$=function($l$jscomp$96_p__45455_temp1$$){var $h$jscomp$143_norm_h$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l$jscomp$96_p__45455_temp1$$,0,null),$o$jscomp$238_s$jscomp$515_temp2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l$jscomp$96_p__45455_temp1$$,1,null);$l$jscomp$96_p__45455_temp1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l$jscomp$96_p__45455_temp1$$,2,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$238_s$jscomp$515_temp2$$,0))return $o$jscomp$238_s$jscomp$515_temp2$$=
$l$jscomp$96_p__45455_temp1$$*255,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$o$jscomp$238_s$jscomp$515_temp2$$,$o$jscomp$238_s$jscomp$515_temp2$$,$o$jscomp$238_s$jscomp$515_temp2$$],null);$h$jscomp$143_norm_h$$/=360;$o$jscomp$238_s$jscomp$515_temp2$$=$l$jscomp$96_p__45455_temp1$$<.5?$l$jscomp$96_p__45455_temp1$$*(1+$o$jscomp$238_s$jscomp$515_temp2$$):$l$jscomp$96_p__45455_temp1$$+$o$jscomp$238_s$jscomp$515_temp2$$-$o$jscomp$238_s$jscomp$515_temp2$$*
$l$jscomp$96_p__45455_temp1$$;$l$jscomp$96_p__45455_temp1$$=$l$jscomp$96_p__45455_temp1$$*2-$o$jscomp$238_s$jscomp$515_temp2$$;return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(255*$app$common$types$color$hue__GT_rgb$$($l$jscomp$96_p__45455_temp1$$,$o$jscomp$238_s$jscomp$515_temp2$$,$h$jscomp$143_norm_h$$+1/3)),$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(255*$app$common$types$color$hue__GT_rgb$$($l$jscomp$96_p__45455_temp1$$,
$o$jscomp$238_s$jscomp$515_temp2$$,$h$jscomp$143_norm_h$$)),$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(255*$app$common$types$color$hue__GT_rgb$$($l$jscomp$96_p__45455_temp1$$,$o$jscomp$238_s$jscomp$515_temp2$$,$h$jscomp$143_norm_h$$-1/3))],null)};
$app$common$types$color$hex__GT_hsv$$=function($JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$){$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$=$APP.$app$common$types$color$hex__GT_rgb$$($JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$);var $hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$,
0,null),$green$jscomp$inline_8098$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$,1,null),$blue$jscomp$inline_8099$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$,2,null);$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$=
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$3$($hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$,$green$jscomp$inline_8098$$,$blue$jscomp$inline_8099$$);var $min$jscomp$inline_8101_sat$jscomp$inline_8103$$=$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$3$($hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$,$green$jscomp$inline_8098$$,$blue$jscomp$inline_8099$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($min$jscomp$inline_8101_sat$jscomp$inline_8103$$,
$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$))$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$],null);else{var $delta$jscomp$inline_8102$$=$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$-
$min$jscomp$inline_8101_sat$jscomp$inline_8103$$;$min$jscomp$inline_8101_sat$jscomp$inline_8103$$=$delta$jscomp$inline_8102$$/$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$;$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$=60*($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$,$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$)?
($green$jscomp$inline_8098$$-$blue$jscomp$inline_8099$$)/$delta$jscomp$inline_8102$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($green$jscomp$inline_8098$$,$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$)?2+($blue$jscomp$inline_8099$$-$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$)/$delta$jscomp$inline_8102$$:4+($hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$-$green$jscomp$inline_8098$$)/
$delta$jscomp$inline_8102$$);$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$=$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$<0?$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$+360:$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$;$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$>360?$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$-360:$hue__$1$jscomp$inline_8104_hue__$2$jscomp$inline_8105_red$jscomp$inline_8097$$,$min$jscomp$inline_8101_sat$jscomp$inline_8103$$,$JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$],null)}return $JSCompiler_inline_result$jscomp$1521_max$jscomp$inline_8100_p__45396$jscomp$inline_8096_v$jscomp$507$$};
$app$common$types$color$sort_colors$$=function($a$jscomp$348_ah$jscomp$1$$,$b$jscomp$279_bh$jscomp$1$$){var $av_vec__45523$$=$app$common$types$color$hex__GT_hsv$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$348_ah$jscomp$1$$));$a$jscomp$348_ah$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($av_vec__45523$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($av_vec__45523$$,1,null);$av_vec__45523$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($av_vec__45523$$,
2,null);var $bv_vec__45526$$=$app$common$types$color$hex__GT_hsv$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$279_bh$jscomp$1$$));$b$jscomp$279_bh$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bv_vec__45526$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bv_vec__45526$$,1,null);$bv_vec__45526$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bv_vec__45526$$,2,null);return $APP.$cljs$core$compare$$($APP.$app$common$math$floor$$($a$jscomp$348_ah$jscomp$1$$/
60*8)/8*100+$av_vec__45523$$/255*10,$APP.$app$common$math$floor$$($b$jscomp$279_bh$jscomp$1$$/60*8)/8*100+$bv_vec__45526$$/255*10)};
$rumext$v2$use_debounce$$=function($value$jscomp$387$$){var $vec__45009$$=(0,$APP.$rumext$v2$useState$$)($value$jscomp$387$$),$state$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45009$$,0,null),$update_fn$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45009$$,1,null),$update_fn__$1$$=(0,$APP.$rumext$v2$useMemo$$)(function(){return $APP.$goog$functions$debounce$$($update_fn$jscomp$3$$,100)},[100]);(0,$APP.$rumext$v2$useEffect$$)(function(){return $update_fn__$1$$.$cljs$core$IFn$_invoke$arity$1$?
$update_fn__$1$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$387$$):$update_fn__$1$$($value$jscomp$387$$)},[$value$jscomp$387$$]);return $state$jscomp$46$$};
$app$common$types$pages_list$get_last_page$$=function($file_data$jscomp$14$$){var $id$jscomp$247$$=$APP.$cljs$core$last$$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$14$$));return $APP.$cljs$core$truth_$$($id$jscomp$247$$)?$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$14$$,$id$jscomp$247$$):null};
$app$main$data$workspace$clear_assets_section_open$$=function(){typeof $app$main$data$workspace$clear_assets_section_open_71906$$==="undefined"&&($app$main$data$workspace$clear_assets_section_open_71906$$=function($meta71907$$){this.$meta71907$=$meta71907$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clear_assets_section_open_71906$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clear_assets_section_open_71906$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4497$app_DOT_main_DOT_data_DOT_workspace_SLASH_clear_assets_section_open$$},$app$main$data$workspace$clear_assets_section_open_71906$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71908$$,$meta71907__$1$$){return new $app$main$data$workspace$clear_assets_section_open_71906$$($meta71907__$1$$)},$app$main$data$workspace$clear_assets_section_open_71906$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71907$},$app$main$data$workspace$clear_assets_section_open_71906$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clear_assets_section_open_71906$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2568$$,$state$jscomp$907$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$907$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$4496$open_status$$],null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return new $app$main$data$workspace$clear_assets_section_open_71906$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$=function($meta73086$$){this.$meta73086$=$meta73086$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4732$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_token_set_edition$$},$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73087$$,$meta73086__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$($meta73086__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73086$},$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2686$$,$state$jscomp$1003$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1003$$,
$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4729$token_set_edition_id$$)});return new $app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73085$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$handle_comment_layer_click$$=function($position$jscomp$146$$){typeof $app$main$data$workspace$comments$handle_comment_layer_click_70132$$==="undefined"&&($app$main$data$workspace$comments$handle_comment_layer_click_70132$$=function($position$jscomp$147$$,$meta70133$$){this.position=$position$jscomp$147$$;this.$meta70133$=$meta70133$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$handle_comment_layer_click_70132$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_comment_layer_click_70132$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4275$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_handle_comment_layer_click$$},$app$main$data$workspace$comments$handle_comment_layer_click_70132$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70134$$,$meta70133__$1$$){return new $app$main$data$workspace$comments$handle_comment_layer_click_70132$$(this.position,
$meta70133__$1$$)},$app$main$data$workspace$comments$handle_comment_layer_click_70132$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70133$},$app$main$data$workspace$comments$handle_comment_layer_click_70132$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_comment_layer_click_70132$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2357_local$jscomp$9_page_id$jscomp$202$$,$file_id$jscomp$218_state$jscomp$741$$){$_$jscomp$2357_local$jscomp$9_page_id$jscomp$202$$=
$APP.$cljs$cst$2233$comments_local$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$218_state$jscomp$741$$);if($APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2357_local$jscomp$9_page_id$jscomp$202$$)!=null)return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$());$_$jscomp$2357_local$jscomp$9_page_id$jscomp$202$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$218_state$jscomp$741$$);$file_id$jscomp$218_state$jscomp$741$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$218_state$jscomp$741$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$create_draft$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1676$position$$,this.position,$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2357_local$jscomp$9_page_id$jscomp$202$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$218_state$jscomp$741$$],null)))});return new $app$main$data$workspace$comments$handle_comment_layer_click_70132$$($position$jscomp$146$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$common$initialized_QMARK_$$=function($state$jscomp$417$$){return $APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$417$$))&&$APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$417$$))};
$app$main$ui$workspace$viewport$utils$format_viewbox$$=function($vbox$jscomp$31$$){return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$31$$,0))??"")+" "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$31$$,0))??"")+" "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$31$$,
0))??"")+" "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$31$$,0))??"")};
$app$main$data$workspace$viewport$update_viewport_size$$=function($resize_type$$,$p__71215$$){var $map__71216__$1$$=$APP.$cljs$core$__destructure_map$$($p__71215$$),$width$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71216__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$142$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71216__$1$$,$APP.$cljs$cst$1522$height$$);typeof $app$main$data$workspace$viewport$update_viewport_size_71217$$==="undefined"&&($app$main$data$workspace$viewport$update_viewport_size_71217$$=
function($resize_type$jscomp$1$$,$p__71215$jscomp$1$$,$map__71216$jscomp$1$$,$size$jscomp$129$$,$width$jscomp$160$$,$height$jscomp$143$$,$meta71218$$){this.$resize_type$=$resize_type$jscomp$1$$;this.$p__71215$=$p__71215$jscomp$1$$;this.$map__71216$=$map__71216$jscomp$1$$;this.size=$size$jscomp$129$$;this.width=$width$jscomp$160$$;this.height=$height$jscomp$143$$;this.$meta71218$=$meta71218$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$update_viewport_size_71217$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_size_71217$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4450$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_size$$},$app$main$data$workspace$viewport$update_viewport_size_71217$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71219$$,$meta71218__$1$$){return new $app$main$data$workspace$viewport$update_viewport_size_71217$$(this.$resize_type$,
this.$p__71215$,this.$map__71216$,this.size,this.width,this.height,$meta71218__$1$$)},$app$main$data$workspace$viewport$update_viewport_size_71217$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71218$},$app$main$data$workspace$viewport$update_viewport_size_71217$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_size_71217$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2514$$,
$state$jscomp$865$$){var $self__$jscomp$6135$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$865$$,$APP.$cljs$cst$1920$workspace_local$$,function($map__71226__$1_p__71225$$){$map__71226__$1_p__71225$$=$APP.$cljs$core$__destructure_map$$($map__71226__$1_p__71225$$);var $hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71226__$1_p__71225$$,$APP.$cljs$cst$2203$vport$$);if($hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$==
null||$APP.$app$common$math$almost_zero_QMARK_$$($self__$jscomp$6135$$.width)||$APP.$app$common$math$almost_zero_QMARK_$$($self__$jscomp$6135$$.height))return $map__71226__$1_p__71225$$;var $vbox_x_SINGLEQUOTE__wprop$jscomp$1$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$)/$self__$jscomp$6135$$.width;$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$)/
$self__$jscomp$6135$$.height;var $vbox$jscomp$29$$=$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($map__71226__$1_p__71225$$),$vbox_x$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$29$$),$vbox_y$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$29$$),$vbox_width$jscomp$1$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$29$$),$vbox_height$jscomp$1$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$29$$),
$vbox_width_SINGLEQUOTE_$$=$vbox_width$jscomp$1$$/$vbox_x_SINGLEQUOTE__wprop$jscomp$1$$,$vbox_height_SINGLEQUOTE_$$=$vbox_height$jscomp$1$$/$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$;$vbox_x_SINGLEQUOTE__wprop$jscomp$1$$=function(){var $G__71230$$=$self__$jscomp$6135$$.$resize_type$;switch($G__71230$$ instanceof $APP.$cljs$core$Keyword$$?$G__71230$$.$fqn$:null){case "left":return $vbox_x$$+($vbox_width$jscomp$1$$-$vbox_width_SINGLEQUOTE_$$);case "right":return $vbox_x$$;default:return $vbox_x$$+
($vbox_width$jscomp$1$$-$vbox_width_SINGLEQUOTE_$$)/2}}();$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$=function(){var $G__71231$$=$self__$jscomp$6135$$.$resize_type$;switch($G__71231$$ instanceof $APP.$cljs$core$Keyword$$?$G__71231$$.$fqn$:null){case "top":return $vbox_y$$+($vbox_height$jscomp$1$$-$vbox_height_SINGLEQUOTE_$$);case "bottom":return $vbox_y$$;default:return $vbox_y$$+($vbox_height$jscomp$1$$-$vbox_height_SINGLEQUOTE_$$)/2}}();return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71226__$1_p__71225$$,
$APP.$cljs$cst$2203$vport$$,$self__$jscomp$6135$$.size),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$cst$1510$x$$],null),$vbox_x_SINGLEQUOTE__wprop$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$cst$1511$y$$],null),$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$cst$290$width$$],null),$vbox_width_SINGLEQUOTE_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$cst$1522$height$$],null),$vbox_height_SINGLEQUOTE_$$)})});return new $app$main$data$workspace$viewport$update_viewport_size_71217$$($resize_type$$,$p__71215$$,$map__71216__$1$$,$map__71216__$1$$,$width$jscomp$159$$,$height$jscomp$142$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$set_default_size$$=function($width$jscomp$153$$,$height$jscomp$137$$){typeof $app$main$data$workspace$drawing$change_preset_70088$$==="undefined"&&($app$main$data$workspace$drawing$change_preset_70088$$=function($width$jscomp$154$$,$height$jscomp$138$$,$meta70089$$){this.width=$width$jscomp$154$$;this.height=$height$jscomp$138$$;this.$meta70089$=$meta70089$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$change_preset_70088$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_preset_70088$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4271$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_change_preset$$},$app$main$data$workspace$drawing$change_preset_70088$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70090$$,$meta70089__$1$$){return new $app$main$data$workspace$drawing$change_preset_70088$$(this.width,this.height,$meta70089__$1$$)},$app$main$data$workspace$drawing$change_preset_70088$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70089$},$app$main$data$workspace$drawing$change_preset_70088$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_preset_70088$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2354$$,$state$jscomp$739$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$739$$,$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,
this.width,$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.height]))});return new $app$main$data$workspace$drawing$change_preset_70088$$($width$jscomp$153$$,$height$jscomp$137$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$fix_init_point$$=function($initial$jscomp$16$$,$G__68925__$1_handler$jscomp$32$$,$shape$jscomp$539_x$jscomp$1199$$){var $height$jscomp$123_selrect$jscomp$61$$=$shape$jscomp$539_x$jscomp$1199$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$539_x$jscomp$1199$$,$APP.$cljs$cst$1605$selrect$$);$shape$jscomp$539_x$jscomp$1199$$=$height$jscomp$123_selrect$jscomp$61$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$61$$,
$APP.$cljs$cst$1510$x$$);var $y$jscomp$432$$=$height$jscomp$123_selrect$jscomp$61$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$61$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$137$$=$height$jscomp$123_selrect$jscomp$61$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$61$$,$APP.$cljs$cst$290$width$$);$height$jscomp$123_selrect$jscomp$61$$=$height$jscomp$123_selrect$jscomp$61$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$61$$,
$APP.$cljs$cst$1522$height$$);$G__68925__$1_handler$jscomp$32$$=$G__68925__$1_handler$jscomp$32$$ instanceof $APP.$cljs$core$Keyword$$?$G__68925__$1_handler$jscomp$32$$.$fqn$:null;switch($G__68925__$1_handler$jscomp$32$$){case "left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$shape$jscomp$539_x$jscomp$1199$$);case "top":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1511$y$$,$y$jscomp$432$$);
case "top-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$shape$jscomp$539_x$jscomp$1199$$),$APP.$cljs$cst$1511$y$$,$y$jscomp$432$$);case "bottom-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$shape$jscomp$539_x$jscomp$1199$$),$APP.$cljs$cst$1511$y$$,$y$jscomp$432$$+
$height$jscomp$123_selrect$jscomp$61$$);case "right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$shape$jscomp$539_x$jscomp$1199$$+$width$jscomp$137$$);case "top-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$shape$jscomp$539_x$jscomp$1199$$+$width$jscomp$137$$),$APP.$cljs$cst$1511$y$$,$y$jscomp$432$$);case "bottom-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,
$APP.$cljs$cst$1510$x$$,$shape$jscomp$539_x$jscomp$1199$$+$width$jscomp$137$$),$APP.$cljs$cst$1511$y$$,$y$jscomp$432$$+$height$jscomp$123_selrect$jscomp$61$$);case "bottom":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1511$y$$,$y$jscomp$432$$+$height$jscomp$123_selrect$jscomp$61$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__68925__$1_handler$jscomp$32$$)].join(""));}};
$app$main$data$workspace$tokens$library_edit$start_token_set_creation$$=function($path$jscomp$252$$){typeof $app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$=function($path$jscomp$253$$,$meta73070$$){this.path=$path$jscomp$253$$;this.$meta73070$=$meta73070$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4730$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_start_token_set_creation$$},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73071$$,$meta73070__$1$$){return new $app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$(this.path,
$meta73070__$1$$)},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73070$},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2685$$,$state$jscomp$1002$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1002$$,
$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4731$token_set_new_path$$,this.path)});return new $app$main$data$workspace$tokens$library_edit$start_token_set_creation_73069$$($path$jscomp$252$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$file$find_remote_shape$$=function($var_args$jscomp$1093$$){for(var $args__5755__auto__$jscomp$199$$=[],$len__5749__auto___52335$$=arguments.length,$i__5750__auto___52336$$=0;;)if($i__5750__auto___52336$$<$len__5749__auto___52335$$)$args__5755__auto__$jscomp$199$$.push(arguments[$i__5750__auto___52336$$]),$i__5750__auto___52336$$+=1;else break;return $APP.$app$common$types$file$find_remote_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<
$args__5755__auto__$jscomp$199$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$199$$.slice(3),0,null):null)};
$app$main$data$workspace$colors$stop_picker$$=function(){typeof $app$main$data$workspace$colors$stop_picker_70411$$==="undefined"&&($app$main$data$workspace$colors$stop_picker_70411$$=function($meta70412$$){this.$meta70412$=$meta70412$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$stop_picker_70411$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$stop_picker_70411$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4131$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_stop_picker$$},$app$main$data$workspace$colors$stop_picker_70411$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70413$$,$meta70412__$1$$){return new $app$main$data$workspace$colors$stop_picker_70411$$($meta70412__$1$$)},$app$main$data$workspace$colors$stop_picker_70411$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70412$},$app$main$data$workspace$colors$stop_picker_70411$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$stop_picker_70411$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2230$$,$state$jscomp$625$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$625$$,$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4132$picked_color_select$$,$APP.$cljs$cst$4133$picked_shift_QMARK_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$4130$picking_color_QMARK_$$],null),!1)});return new $app$main$data$workspace$colors$stop_picker_70411$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$start_picker$$=function(){typeof $app$main$data$workspace$colors$start_picker_70408$$==="undefined"&&($app$main$data$workspace$colors$start_picker_70408$$=function($meta70409$$){this.$meta70409$=$meta70409$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$start_picker_70408$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$start_picker_70408$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4129$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_start_picker$$},$app$main$data$workspace$colors$start_picker_70408$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70410$$,$meta70409__$1$$){return new $app$main$data$workspace$colors$start_picker_70408$$($meta70409__$1$$)},$app$main$data$workspace$colors$start_picker_70408$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70409$},$app$main$data$workspace$colors$start_picker_70408$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$start_picker_70408$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2229$$,$state$jscomp$624$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$624$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$4130$picking_color_QMARK_$$],null),!0)});return new $app$main$data$workspace$colors$start_picker_70408$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_track_context_menu$$=function($p__71981$$){var $map__71982__$1$$=$APP.$cljs$core$__destructure_map$$($p__71981$$),$grid_id$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71982__$1$$,$APP.$cljs$cst$4420$grid_id$$),$type$jscomp$541$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71982__$1$$,$APP.$cljs$cst$139$type$$),$index$jscomp$367$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71982__$1$$,$APP.$cljs$cst$1795$index$$);
typeof $app$main$data$workspace$show_track_context_menu_71983$$==="undefined"&&($app$main$data$workspace$show_track_context_menu_71983$$=function($p__71981$jscomp$1$$,$map__71982$jscomp$1$$,$params$jscomp$301$$,$grid_id$jscomp$24$$,$type$jscomp$542$$,$index$jscomp$368$$,$meta71984$$){this.$p__71981$=$p__71981$jscomp$1$$;this.$map__71982$=$map__71982$jscomp$1$$;this.params=$params$jscomp$301$$;this.$grid_id$=$grid_id$jscomp$24$$;this.type=$type$jscomp$542$$;this.index=$index$jscomp$368$$;this.$meta71984$=
$meta71984$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_track_context_menu_71983$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_track_context_menu_71983$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4509$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_track_context_menu$$},$app$main$data$workspace$show_track_context_menu_71983$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71985$$,$meta71984__$1$$){return new $app$main$data$workspace$show_track_context_menu_71983$$(this.$p__71981$,this.$map__71982$,this.params,this.$grid_id$,this.type,this.index,$meta71984__$1$$)},$app$main$data$workspace$show_track_context_menu_71983$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71984$},$app$main$data$workspace$show_track_context_menu_71983$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_track_context_menu_71983$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$4510$grid_track$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4420$grid_id$$,this.$grid_id$,$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$1795$index$$,this.index]))))});return new $app$main$data$workspace$show_track_context_menu_71983$$($p__71981$$,
$map__71982__$1$$,$map__71982__$1$$,$grid_id$jscomp$23$$,$type$jscomp$541$$,$index$jscomp$367$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$exit_preview_cleanup$$=function(){typeof $app$main$data$workspace$versions$exit_preview_cleanup_73373$$==="undefined"&&($app$main$data$workspace$versions$exit_preview_cleanup_73373$$=function($meta73374$$){this.$meta73374$=$meta73374$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$exit_preview_cleanup_73373$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_cleanup_73373$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5041$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_exit_preview_cleanup$$},$app$main$data$workspace$versions$exit_preview_cleanup_73373$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73375$$,$meta73374__$1$$){return new $app$main$data$workspace$versions$exit_preview_cleanup_73373$$($meta73374__$1$$)},$app$main$data$workspace$versions$exit_preview_cleanup_73373$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73374$},
$app$main$data$workspace$versions$exit_preview_cleanup_73373$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_cleanup_73373$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2790_backup$$,$state$jscomp$1073$$){$_$jscomp$2790_backup$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1073$$,$APP.$cljs$cst$4469$workspace_versions$$),
$APP.$cljs$cst$5042$backup$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1073$$,$APP.$cljs$cst$4469$workspace_versions$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5042$backup$$),$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2217$read_only_QMARK_$$,$APP.$cljs$cst$5020$preview_id$$),$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2790_backup$$),$_$jscomp$2790_backup$$)});return new $app$main$data$workspace$versions$exit_preview_cleanup_73373$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$update_versions_state$$=function($version_state$$){typeof $app$main$data$workspace$versions$update_versions_state_73289$$==="undefined"&&($app$main$data$workspace$versions$update_versions_state_73289$$=function($version_state$jscomp$1$$,$meta73290$$){this.$version_state$=$version_state$jscomp$1$$;this.$meta73290$=$meta73290$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$update_versions_state_73289$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$update_versions_state_73289$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5022$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_update_versions_state$$},$app$main$data$workspace$versions$update_versions_state_73289$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73291$$,$meta73290__$1$$){return new $app$main$data$workspace$versions$update_versions_state_73289$$(this.$version_state$,
$meta73290__$1$$)},$app$main$data$workspace$versions$update_versions_state_73289$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73290$},$app$main$data$workspace$versions$update_versions_state_73289$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$update_versions_state_73289$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2780$$,$state$jscomp$1067$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1067$$,
$APP.$cljs$cst$4469$workspace_versions$$,$APP.$cljs$core$merge$$,this.$version_state$)});return new $app$main$data$workspace$versions$update_versions_state_73289$$($version_state$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$change_orientation$$=function($orientation$jscomp$5$$){typeof $app$main$data$workspace$drawing$change_orientation_70079$$==="undefined"&&($app$main$data$workspace$drawing$change_orientation_70079$$=function($orientation$jscomp$6$$,$meta70080$$){this.orientation=$orientation$jscomp$6$$;this.$meta70080$=$meta70080$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$change_orientation_70079$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_orientation_70079$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4270$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_change_orientation$$},$app$main$data$workspace$drawing$change_orientation_70079$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70081$$,$meta70080__$1$$){return new $app$main$data$workspace$drawing$change_orientation_70079$$(this.orientation,$meta70080__$1$$)},
$app$main$data$workspace$drawing$change_orientation_70079$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70080$},$app$main$data$workspace$drawing$change_orientation_70079$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_orientation_70079$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$,$state$jscomp$738$$){$_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$738$$,$APP.$cljs$cst$2189$workspace_drawing$$);var $map__70083__$1_width_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$);$_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70083__$1_width_SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$136$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70083__$1_width_SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$cst$1522$height$$);$map__70083__$1_width_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.orientation,$APP.$cljs$cst$1910$vertical$$)?Math.min($_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$,$height$jscomp$136$$):Math.max($_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$,$height$jscomp$136$$);$_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.orientation,$APP.$cljs$cst$1910$vertical$$)?Math.max($_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$,$height$jscomp$136$$):Math.min($_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$,$height$jscomp$136$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$738$$,$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$map__70083__$1_width_SINGLEQUOTE_$jscomp$1$$,
$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$2353_height_SINGLEQUOTE_$jscomp$1_map__70083_width$jscomp$152$$]))});return new $app$main$data$workspace$drawing$change_orientation_70079$$($orientation$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$files$variant$get_primary_component$$=function($JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$,$JSCompiler_temp_const$jscomp$1532_component_id$jscomp$32$$){var $JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$,$JSCompiler_temp_const$jscomp$1532_component_id$jscomp$32$$);
if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$))if($APP.$app$common$types$component$is_variant_QMARK_$$($JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$)){$JSCompiler_temp_const$jscomp$1532_component_id$jscomp$32$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$;var $objects$jscomp$inline_8112_page_id$jscomp$inline_8111$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$);
$objects$jscomp$inline_8112_page_id$jscomp$inline_8111$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$,$APP.$cljs$cst$1630$pages_index$$),$objects$jscomp$inline_8112_page_id$jscomp$inline_8111$$),$APP.$cljs$cst$1631$objects$$);$JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$=
$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$);$JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_8112_page_id$jscomp$inline_8111$$,$APP.$cljs$core$peek$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_8112_page_id$jscomp$inline_8111$$,
$JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$),$APP.$cljs$cst$1614$shapes$$)));$JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$,$JSCompiler_temp_const$jscomp$1532_component_id$jscomp$32$$.call($APP.$cljs$cst$1627$component_id$$,$JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$))}else $JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$=
$JSCompiler_inline_result$jscomp$1534_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8113$$;else $JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$=null;return $JSCompiler_temp$jscomp$1530_JSCompiler_temp$jscomp$1531_data$jscomp$300$$};$cljs$core$TaggedLiteral$$=function($tag$jscomp$13$$,$form$jscomp$3$$){this.tag=$tag$jscomp$13$$;this.form=$form$jscomp$3$$;this.$cljs$lang$protocol_mask$partition0$$=2153775360;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$tools$reader$garg$$=function($n$jscomp$174$$){return $APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([-1===$n$jscomp$174$$?"rest":["p",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$174$$)].join(""),"__",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$tools$reader$impl$utils$last_id$$,$APP.$cljs$core$inc$$)),"#"].join(""))};
$app$main$data$workspace$versions$fetch_versions$$=function(){typeof $app$main$data$workspace$versions$fetch_versions_73294$$==="undefined"&&($app$main$data$workspace$versions$fetch_versions_73294$$=function($meta73295$$){this.$meta73295$=$meta73295$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$fetch_versions_73294$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$fetch_versions_73294$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5023$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_fetch_versions$$},$app$main$data$workspace$versions$fetch_versions_73294$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73296$$,$meta73295__$1$$){return new $app$main$data$workspace$versions$fetch_versions_73294$$($meta73295__$1$$)},$app$main$data$workspace$versions$fetch_versions_73294$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73295$},$app$main$data$workspace$versions$fetch_versions_73294$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$fetch_versions_73294$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2781_temp__5825__auto__$jscomp$270$$,$state$jscomp$1068$$){$_$jscomp$2781_temp__5825__auto__$jscomp$270$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1068$$);return $APP.$cljs$core$truth_$$($_$jscomp$2781_temp__5825__auto__$jscomp$270$$)?$APP.$beicon$v2$core$map$$(function($p1__73293_SHARP_$$){return $app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$109$status$$,$APP.$cljs$cst$5024$loaded$$,$APP.$cljs$cst$142$data$$,$p1__73293_SHARP_$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5025$get_file_snapshots$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$2781_temp__5825__auto__$jscomp$270$$],null))):null});return new $app$main$data$workspace$versions$fetch_versions_73294$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$unlock_version$$=function($id$jscomp$854$$){typeof $app$main$data$workspace$versions$unlock_version_73368$$==="undefined"&&($app$main$data$workspace$versions$unlock_version_73368$$=function($id$jscomp$855$$,$meta73369$$){this.id=$id$jscomp$855$$;this.$meta73369$=$meta73369$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$unlock_version_73368$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$unlock_version_73368$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5039$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_unlock_version$$},$app$main$data$workspace$versions$unlock_version_73368$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73370$$,$meta73369__$1$$){return new $app$main$data$workspace$versions$unlock_version_73368$$(this.id,$meta73369__$1$$)},$app$main$data$workspace$versions$unlock_version_73368$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73369$},$app$main$data$workspace$versions$unlock_version_73368$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$unlock_version_73368$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5040$unlock_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$workspace$versions$unlock_version_73368$$($id$jscomp$854$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$lock_version$$=function($id$jscomp$852$$){typeof $app$main$data$workspace$versions$lock_version_73363$$==="undefined"&&($app$main$data$workspace$versions$lock_version_73363$$=function($id$jscomp$853$$,$meta73364$$){this.id=$id$jscomp$853$$;this.$meta73364$=$meta73364$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$lock_version_73363$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$lock_version_73363$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5037$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_lock_version$$},$app$main$data$workspace$versions$lock_version_73363$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73365$$,$meta73364__$1$$){return new $app$main$data$workspace$versions$lock_version_73363$$(this.id,$meta73364__$1$$)},$app$main$data$workspace$versions$lock_version_73363$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73364$},$app$main$data$workspace$versions$lock_version_73363$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$lock_version_73363$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5038$lock_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$workspace$versions$lock_version_73363$$($id$jscomp$852$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$delete_version$$=function($id$jscomp$848$$){typeof $app$main$data$workspace$versions$delete_version_73334$$==="undefined"&&($app$main$data$workspace$versions$delete_version_73334$$=function($id$jscomp$849$$,$meta73335$$){this.id=$id$jscomp$849$$;this.$meta73335$=$meta73335$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$delete_version_73334$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$delete_version_73334$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5034$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_delete_version$$},$app$main$data$workspace$versions$delete_version_73334$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73336$$,$meta73335__$1$$){return new $app$main$data$workspace$versions$delete_version_73334$$(this.id,$meta73335__$1$$)},$app$main$data$workspace$versions$delete_version_73334$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73335$},$app$main$data$workspace$versions$delete_version_73334$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$delete_version_73334$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5035$delete_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$workspace$versions$delete_version_73334$$($id$jscomp$848$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$rename_version$$=function($id$jscomp$846$$,$label$jscomp$22$$){typeof $app$main$data$workspace$versions$rename_version_73316$$==="undefined"&&($app$main$data$workspace$versions$rename_version_73316$$=function($id$jscomp$847$$,$label$jscomp$23$$,$meta73317$$){this.id=$id$jscomp$847$$;this.label=$label$jscomp$23$$;this.$meta73317$=$meta73317$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$rename_version_73316$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$rename_version_73316$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5029$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_rename_version$$},$app$main$data$workspace$versions$rename_version_73316$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73318$$,$meta73317__$1$$){return new $app$main$data$workspace$versions$rename_version_73316$$(this.id,this.label,$meta73317__$1$$)},
$app$main$data$workspace$versions$rename_version_73316$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73317$},$app$main$data$workspace$versions$rename_version_73316$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$rename_version_73316$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2783_file_id$jscomp$327$$,$state$jscomp$1070$$){$_$jscomp$2783_file_id$jscomp$327$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1070$$);
return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2152$editing$$,null],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"rename-version",$APP.$cljs$cst$1644$file_id$$,$_$jscomp$2783_file_id$jscomp$327$$],null))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5030$update_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$2287$label$$,this.label],null))))});return new $app$main$data$workspace$versions$rename_version_73316$$($id$jscomp$846$$,$label$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$init_versions_state$$=function(){typeof $app$main$data$workspace$versions$init_versions_state_73284$$==="undefined"&&($app$main$data$workspace$versions$init_versions_state_73284$$=function($meta73285$$){this.$meta73285$=$meta73285$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5021$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_init_versions_state$$},$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73286$$,$meta73285__$1$$){return new $app$main$data$workspace$versions$init_versions_state_73284$$($meta73285__$1$$)},$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73285$},$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2778$$,$state$jscomp$1066$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1066$$,$APP.$cljs$cst$4469$workspace_versions$$,$APP.$app$main$data$workspace$versions$default_state$$)},$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$init_versions_state_73284$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$fetch_versions$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$versions$fetch_versions$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$versions$fetch_versions$$())});return new $app$main$data$workspace$versions$init_versions_state_73284$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$rename_file$$=function($id$jscomp$740$$,$name$jscomp$355_name__$1$jscomp$12$$){$name$jscomp$355_name__$1$jscomp$12$$=$app$common$data$macros$truncate$$($name$jscomp$355_name__$1$jscomp$12$$);typeof $app$main$data$workspace$rename_file_71701$$==="undefined"&&($app$main$data$workspace$rename_file_71701$$=function($id$jscomp$741$$,$name$jscomp$356$$,$meta71702$$){this.id=$id$jscomp$741$$;this.name=$name$jscomp$356$$;this.$meta71702$=$meta71702$$;this.$cljs$lang$protocol_mask$partition0$$=
425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$rename_file_71701$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_file_71701$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4470$app_DOT_main_DOT_data_DOT_workspace_SLASH_rename_file$$},$app$main$data$workspace$rename_file_71701$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71703$$,$meta71702__$1$$){return new $app$main$data$workspace$rename_file_71701$$(this.id,
this.name,$meta71702__$1$$)},$app$main$data$workspace$rename_file_71701$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71702$},$app$main$data$workspace$rename_file_71701$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name],null)},$app$main$data$workspace$rename_file_71701$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_file_71701$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2541_file_id$jscomp$274$$,$state$jscomp$884$$){$_$jscomp$2541_file_id$jscomp$274$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$884$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$884$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,
$_$jscomp$2541_file_id$jscomp$274$$,$APP.$cljs$cst$725$name$$],null),this.name)},$app$main$data$workspace$rename_file_71701$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_file_71701$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4471$rename_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
this.id,$APP.$cljs$cst$725$name$$,this.name],null)))});return new $app$main$data$workspace$rename_file_71701$$($id$jscomp$740$$,$name$jscomp$355_name__$1$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$=function($color_str$jscomp$1_tc$jscomp$3$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("#",$APP.$cljs$core$first$$($color_str$jscomp$1_tc$jscomp$3$$))?($color_str$jscomp$1_tc$jscomp$3$$=(0,$APP.$shadow$js$shim$module$0tinycolor2$0default$$)($color_str$jscomp$1_tc$jscomp$3$$),$APP.$cuerdas$core$starts_with_QMARK_$$($color_str$jscomp$1_tc$jscomp$3$$.getFormat(),"hex")):null};
$app$main$data$workspace$pages$finalize_page$$=function($file_id$jscomp$243$$,$page_id$jscomp$231$$){typeof $app$main$data$workspace$pages$finalize_page_70790$$==="undefined"&&($app$main$data$workspace$pages$finalize_page_70790$$=function($file_id$jscomp$244$$,$page_id$jscomp$232$$,$meta70791$$){this.$file_id$=$file_id$jscomp$244$$;this.$page_id$=$page_id$jscomp$232$$;this.$meta70791$=$meta70791$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$finalize_page_70790$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$finalize_page_70790$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$},$app$main$data$workspace$pages$finalize_page_70790$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70792$$,$meta70791__$1$$){return new $app$main$data$workspace$pages$finalize_page_70790$$(this.$file_id$,this.$page_id$,$meta70791__$1$$)},$app$main$data$workspace$pages$finalize_page_70790$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70791$},$app$main$data$workspace$pages$finalize_page_70790$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$finalize_page_70790$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2443_exit_QMARK_$$,$G__70803_state$jscomp$806$$){var $local$jscomp$14$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($G__70803_state$jscomp$806$$),
$APP.$cljs$cst$2199$edition$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1923$edit_path$$,$APP.$cljs$cst$1921$selected$$]));$_$jscomp$2443_exit_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2532$workspace$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70803_state$jscomp$806$$,$APP.$cljs$cst$2171$route$$),$APP.$cljs$cst$142$data$$),
$APP.$cljs$cst$725$name$$));$G__70803_state$jscomp$806$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__70803_state$jscomp$806$$,$APP.$cljs$cst$4365$workspace_cache$$,$APP.$cljs$core$assoc$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$file_id$,this.$page_id$],null),$local$jscomp$14$$),$APP.$cljs$cst$1918$current_page_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$4367$workspace_trimmed_page$$,$APP.$cljs$cst$2226$workspace_focus_selected$$]));return $_$jscomp$2443_exit_QMARK_$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__70803_state$jscomp$806$$,$APP.$cljs$cst$2189$workspace_drawing$$):$G__70803_state$jscomp$806$$});return new $app$main$data$workspace$pages$finalize_page_70790$$($file_id$jscomp$243$$,$page_id$jscomp$231$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$gen_name$$=function($editor$jscomp$3_result$jscomp$301$$){return $editor$jscomp$3_result$jscomp$301$$!=null?($editor$jscomp$3_result$jscomp$301$$=$APP.$app$common$types$text$generate_shape_name$$($editor$jscomp$3_result$jscomp$301$$.getCurrentContent().getPlainText()),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editor$jscomp$3_result$jscomp$301$$,"")?$editor$jscomp$3_result$jscomp$301$$:null):null};
$app$common$types$shape$interactions$allowed_animation_QMARK_$$=function($action_type$jscomp$2$$,$animation_type$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($animation_type$$,$APP.$cljs$cst$1956$push$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1941$navigate$$,$action_type$jscomp$2$$)};
$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$=function($p$jscomp$205$$,$G__48941_lines$jscomp$2_lines__$1$$){var $G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$=0,$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$=$APP.$cljs$core$first$$($G__48941_lines$jscomp$2_lines__$1$$);for($G__48941_lines$jscomp$2_lines__$1$$=$APP.$cljs$core$rest$$($G__48941_lines$jscomp$2_lines__$1$$);;)if($APP.$cljs$core$truth_$$($G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$)){var $map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$=
$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$,$map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$=$APP.$cljs$core$__destructure_map$$($p$jscomp$205$$);$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$,$APP.$cljs$cst$1510$x$$);$map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$,
$APP.$cljs$cst$1511$y$$);var $map__48902$jscomp$inline_8121_x1$jscomp$inline_8123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$,0,null),$map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$=$APP.$cljs$core$__destructure_map$$($map__48902$jscomp$inline_8121_x1$jscomp$inline_8123$$);$map__48902$jscomp$inline_8121_x1$jscomp$inline_8123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$,
$APP.$cljs$cst$1510$x$$);$map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$,$APP.$cljs$cst$1511$y$$);$map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$,1,null);var $map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$=
$APP.$cljs$core$__destructure_map$$($map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$);$map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$,$APP.$cljs$cst$1510$x$$);$map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$,
$APP.$cljs$cst$1511$y$$);$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$=($map__48903$jscomp$inline_8125_p__48897$jscomp$inline_8117_x2$jscomp$inline_8127$$-$map__48902$jscomp$inline_8121_x1$jscomp$inline_8123$$)*($map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$-$map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$)-($G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$-$map__48902$jscomp$inline_8121_x1$jscomp$inline_8123$$)*($map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$-
$map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$);$G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$=$map__48902__$1$jscomp$inline_8122_y1$jscomp$inline_8124$$<=$map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$?$map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$>$map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$&&$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$>0?$G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$+1:$G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$:
$map__48903__$1$jscomp$inline_8126_y2$jscomp$inline_8128$$<=$map__48898__$1$jscomp$inline_8118_py$jscomp$inline_8120$$&&$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$<0?$G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$-1:$G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$;$G__48940_line$jscomp$24_line_side$jscomp$inline_8129_px$jscomp$inline_8119$$=$APP.$cljs$core$first$$($G__48941_lines$jscomp$2_lines__$1$$);$G__48941_lines$jscomp$2_lines__$1$$=$APP.$cljs$core$rest$$($G__48941_lines$jscomp$2_lines__$1$$)}else return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__48939_wn$jscomp$1_wn$jscomp$inline_8115$$,
0)};
$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$=function($G__48929_lines_a_pending$jscomp$7$$,$lines_b$$){var $G__48928_cur_line$$=$APP.$cljs$core$first$$($G__48929_lines_a_pending$jscomp$7$$);for($G__48929_lines_a_pending$jscomp$7$$=$APP.$cljs$core$rest$$($G__48929_lines_a_pending$jscomp$7$$);;){if($APP.$cljs$core$not$$($G__48928_cur_line$$))return!1;if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($cur_line$jscomp$1$$){return function($p1__48886_SHARP__q2$jscomp$inline_8136$$){var $p1$jscomp$inline_8133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_line$jscomp$1$$,
0,null),$q1$jscomp$inline_8134$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_line$jscomp$1$$,1,null),$p2$jscomp$inline_8135$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__48886_SHARP__q2$jscomp$inline_8136$$,0,null);$p1__48886_SHARP__q2$jscomp$inline_8136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__48886_SHARP__q2$jscomp$inline_8136$$,1,null);var $o1$jscomp$inline_8137$$=$app$common$geom$shapes$intersect$orientation$$($p1$jscomp$inline_8133$$,
$q1$jscomp$inline_8134$$,$p2$jscomp$inline_8135$$),$o2$jscomp$inline_8138$$=$app$common$geom$shapes$intersect$orientation$$($p1$jscomp$inline_8133$$,$q1$jscomp$inline_8134$$,$p1__48886_SHARP__q2$jscomp$inline_8136$$),$o3$jscomp$inline_8139$$=$app$common$geom$shapes$intersect$orientation$$($p2$jscomp$inline_8135$$,$p1__48886_SHARP__q2$jscomp$inline_8136$$,$p1$jscomp$inline_8133$$),$o4$jscomp$inline_8140$$=$app$common$geom$shapes$intersect$orientation$$($p2$jscomp$inline_8135$$,$p1__48886_SHARP__q2$jscomp$inline_8136$$,
$q1$jscomp$inline_8134$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o1$jscomp$inline_8137$$,$o2$jscomp$inline_8138$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o3$jscomp$inline_8139$$,$o4$jscomp$inline_8140$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o1$jscomp$inline_8137$$,$APP.$cljs$cst$1896$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&$app$common$geom$shapes$intersect$on_segment_QMARK_$$($p2$jscomp$inline_8135$$,$p1$jscomp$inline_8133$$,
$q1$jscomp$inline_8134$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o2$jscomp$inline_8138$$,$APP.$cljs$cst$1896$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&$app$common$geom$shapes$intersect$on_segment_QMARK_$$($p1__48886_SHARP__q2$jscomp$inline_8136$$,$p1$jscomp$inline_8133$$,$q1$jscomp$inline_8134$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o3$jscomp$inline_8139$$,$APP.$cljs$cst$1896$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&
$app$common$geom$shapes$intersect$on_segment_QMARK_$$($p1$jscomp$inline_8133$$,$p2$jscomp$inline_8135$$,$p1__48886_SHARP__q2$jscomp$inline_8136$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o4$jscomp$inline_8140$$,$APP.$cljs$cst$1896$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&$app$common$geom$shapes$intersect$on_segment_QMARK_$$($q1$jscomp$inline_8134$$,$p2$jscomp$inline_8135$$,$p1__48886_SHARP__q2$jscomp$inline_8136$$)}}($G__48928_cur_line$$,$G__48929_lines_a_pending$jscomp$7$$),
$lines_b$$)))return!0;$G__48928_cur_line$$=$APP.$cljs$core$first$$($G__48929_lines_a_pending$jscomp$7$$);$G__48929_lines_a_pending$jscomp$7$$=$APP.$cljs$core$rest$$($G__48929_lines_a_pending$jscomp$7$$)}};
$app$main$data$workspace$libraries$set_file_shared$$=function($id$jscomp$599$$,$is_shared$jscomp$1$$){typeof $app$main$data$workspace$libraries$set_file_shared_69919$$==="undefined"&&($app$main$data$workspace$libraries$set_file_shared_69919$$=function($id$jscomp$600$$,$is_shared$jscomp$2$$,$meta69920$$){this.id=$id$jscomp$600$$;this.$is_shared$=$is_shared$jscomp$2$$;this.$meta69920$=$meta69920$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3976$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_set_file_shared$$},$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69921$$,$meta69920__$1$$){return new $app$main$data$workspace$libraries$set_file_shared_69919$$(this.id,this.$is_shared$,$meta69920__$1$$)},
$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69920$},$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3977$shared$$,this.$is_shared$],null)},$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2145$$,$state$jscomp$530$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$530$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2182$is_shared$$,this.$is_shared$)},$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_69919$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp_const$jscomp$1539__$jscomp$2146$$,$JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$){$JSCompiler_temp_const$jscomp$1539__$jscomp$2146$$=
$APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3978$set_file_shared$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$2182$is_shared$$,this.$is_shared$],null)));$APP.$cljs$core$truth_$$(this.$is_shared$)?($JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$)))),
$JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"set-file-variants-shared",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace"],null))):$APP.$beicon$v2$core$empty$$()):
$JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$=null;return $APP.$beicon$v2$core$concat$$($JSCompiler_temp_const$jscomp$1539__$jscomp$2146$$,$JSCompiler_temp$jscomp$1540_has_variants_QMARK_$jscomp$inline_8142_state$jscomp$531$$)});return new $app$main$data$workspace$libraries$set_file_shared_69919$$($id$jscomp$599$$,$is_shared$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$clipboard$to_clipboard_multi$$=function($items$jscomp$31$$){var $clipboard$jscomp$2$$=navigator.clipboard;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($clipboard$jscomp$2$$)?$clipboard$jscomp$2$$.write:$clipboard$jscomp$2$$)){var $item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$119$$,$mime$$,$payload$jscomp$6$$){$acc$jscomp$119$$[$mime$$]=Promise.resolve(new Blob([$payload$jscomp$6$$],{type:$mime$$}));return $acc$jscomp$119$$},
{},$items$jscomp$31$$);$item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$=new ClipboardItem($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$);return $clipboard$jscomp$2$$.write([$item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$])}$item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$=function(){var $or__5025__auto__$jscomp$614$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$31$$,"text/plain");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$614$$)?
$or__5025__auto__$jscomp$614$$:$APP.$cljs$core$first$$($APP.$cljs$core$vals$$($items$jscomp$31$$))}();return $APP.$cljs$core$truth_$$($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$)?$clipboard$jscomp$2$$.writeText($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$178$$):null};
$app$main$data$workspace$versions$pin_version$$=function($id$jscomp$850$$){typeof $app$main$data$workspace$versions$pin_version_73343$$==="undefined"&&($app$main$data$workspace$versions$pin_version_73343$$=function($id$jscomp$851$$,$meta73344$$){this.id=$id$jscomp$851$$;this.$meta73344$=$meta73344$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$pin_version_73343$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$pin_version_73343$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5036$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_pin_version$$},$app$main$data$workspace$versions$pin_version_73343$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73345$$,$meta73344__$1$$){return new $app$main$data$workspace$versions$pin_version_73343$$(this.id,$meta73344__$1$$)},$app$main$data$workspace$versions$pin_version_73343$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73344$},$app$main$data$workspace$versions$pin_version_73343$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$pin_version_73343$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2787_params$jscomp$357_temp__5825__auto__$jscomp$271$$,$state$jscomp$1072$$){var $self__$jscomp$7012$$=this;$_$jscomp$2787_params$jscomp$357_temp__5825__auto__$jscomp$271$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73342_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73342_SHARP_$$),
$self__$jscomp$7012$$.id)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1072$$,$APP.$cljs$cst$4469$workspace_versions$$),$APP.$cljs$cst$142$data$$));return $APP.$cljs$core$truth_$$($_$jscomp$2787_params$jscomp$357_temp__5825__auto__$jscomp$271$$)?($_$jscomp$2787_params$jscomp$357_temp__5825__auto__$jscomp$271$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$7012$$.id,$APP.$cljs$cst$2287$label$$,
$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2787_params$jscomp$357_temp__5825__auto__$jscomp$271$$),$APP.$cljs$cst$5027$localized_date$$)],null),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2152$editing$$,$self__$jscomp$7012$$.id],null)),$app$main$data$workspace$versions$fetch_versions$$(),
$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"pin-version"],null)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5030$update_file_snapshot$$,$_$jscomp$2787_params$jscomp$357_temp__5825__auto__$jscomp$271$$))):null});return new $app$main$data$workspace$versions$pin_version_73343$$($id$jscomp$850$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$save_font$$=function($data$jscomp$373$$){typeof $app$main$data$workspace$texts$save_font_70272$$==="undefined"&&($app$main$data$workspace$texts$save_font_70272$$=function($data$jscomp$374$$,$meta70273$$){this.data=$data$jscomp$374$$;this.$meta70273$=$meta70273$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$save_font_70272$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$save_font_70272$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4023$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_save_font$$},$app$main$data$workspace$texts$save_font_70272$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70274$$,$meta70273__$1$$){return new $app$main$data$workspace$texts$save_font_70272$$(this.data,$meta70273__$1$$)},$app$main$data$workspace$texts$save_font_70272$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70273$},$app$main$data$workspace$texts$save_font_70272$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$save_font_70272$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2180_multiple_QMARK_$$,$state$jscomp$579$$){$_$jscomp$2180_multiple_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__70271_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__70271_SHARP_$$,
$APP.$cljs$cst$1616$multiple$$)},$APP.$cljs$core$vals$$(this.data));return $APP.$cljs$core$not$$($_$jscomp$2180_multiple_QMARK_$$)?$APP.$cljs$core$assoc_in$$($state$jscomp$579$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2201$default_font$$],null),this.data):$state$jscomp$579$$});return new $app$main$data$workspace$texts$save_font_70272$$($data$jscomp$373$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$geom$point$resize$$=function($vector$$,$new_length$$){var $old_length$$=$APP.$app$common$geom$point$length$$($vector$$);return $APP.$app$common$geom$point$scale$$($vector$$,$new_length$$/$old_length$$)};
$app$main$data$workspace$interactions$move_overlay_pos$$=function($pos$jscomp$112$$,$frame_pos$jscomp$1$$,$offset$jscomp$177$$){typeof $app$main$data$workspace$interactions$move_overlay_pos_70623$$==="undefined"&&($app$main$data$workspace$interactions$move_overlay_pos_70623$$=function($pos$jscomp$113$$,$frame_pos$jscomp$2$$,$offset$jscomp$178$$,$meta70624$$){this.pos=$pos$jscomp$113$$;this.$frame_pos$=$frame_pos$jscomp$2$$;this.offset=$offset$jscomp$178$$;this.$meta70624$=$meta70624$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$move_overlay_pos_70623$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_overlay_pos_70623$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4319$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_move_overlay_pos$$},$app$main$data$workspace$interactions$move_overlay_pos_70623$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70625$$,$meta70624__$1$$){return new $app$main$data$workspace$interactions$move_overlay_pos_70623$$(this.pos,this.$frame_pos$,this.offset,$meta70624__$1$$)},$app$main$data$workspace$interactions$move_overlay_pos_70623$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70624$},$app$main$data$workspace$interactions$move_overlay_pos_70623$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_overlay_pos_70623$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2404_pos__$1$jscomp$18$$,$state$jscomp$779$$){$_$jscomp$2404_pos__$1$jscomp$18$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$(this.pos,this.$frame_pos$),this.offset);return $APP.$cljs$core$assoc_in$$($state$jscomp$779$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4317$move_overlay_to$$],null),$_$jscomp$2404_pos__$1$jscomp$18$$)});return new $app$main$data$workspace$interactions$move_overlay_pos_70623$$($pos$jscomp$112$$,
$frame_pos$jscomp$1$$,$offset$jscomp$177$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$streams$get_angle$$=function($node$jscomp$331_rot_angle$$,$handler$jscomp$38_v2$jscomp$28$$,$opposite$jscomp$2_rot_sign_v1$jscomp$36$$){return $node$jscomp$331_rot_angle$$!=null&&$handler$jscomp$38_v2$jscomp$28$$!=null&&$opposite$jscomp$2_rot_sign_v1$jscomp$36$$!=null?($opposite$jscomp$2_rot_sign_v1$jscomp$36$$=$APP.$app$common$geom$point$subtract$$($opposite$jscomp$2_rot_sign_v1$jscomp$36$$,$node$jscomp$331_rot_angle$$),$handler$jscomp$38_v2$jscomp$28$$=$APP.$app$common$geom$point$subtract$$($handler$jscomp$38_v2$jscomp$28$$,
$node$jscomp$331_rot_angle$$),$node$jscomp$331_rot_angle$$=$APP.$app$common$geom$point$angle_with_other$$($opposite$jscomp$2_rot_sign_v1$jscomp$36$$,$handler$jscomp$38_v2$jscomp$28$$),$opposite$jscomp$2_rot_sign_v1$jscomp$36$$=$APP.$app$common$geom$point$angle_sign$$($opposite$jscomp$2_rot_sign_v1$jscomp$36$$,$handler$jscomp$38_v2$jscomp$28$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node$jscomp$331_rot_angle$$,$opposite$jscomp$2_rot_sign_v1$jscomp$36$$],
null)):null};$promesa$core$all$$=function($promises$jscomp$8$$){return $APP.$promesa$protocols$_fmap$$($promesa$impl$promise$all$$($APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($promises$jscomp$8$$)),$APP.$cljs$core$vec$$)};
$malli$error$_get$$=function($x$jscomp$829$$,$k$jscomp$436$$){return $APP.$cljs$core$set_QMARK_$$($x$jscomp$829$$)||$APP.$cljs$core$associative_QMARK_$$($x$jscomp$829$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$829$$,$k$jscomp$436$$):$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$829$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($x$jscomp$829$$),$k$jscomp$436$$):null};
$app$common$types$tokens_lib$split_set_str_path_prefix$$=function($G__49610__$1_path_str$jscomp$3$$){$G__49610__$1_path_str$jscomp$3$$=$G__49610__$1_path_str$jscomp$3$$==null?null:$APP.$cljs$core$re_matches$$(/^([SG]-)(.*)/,$G__49610__$1_path_str$jscomp$3$$);return $G__49610__$1_path_str$jscomp$3$$==null?null:$APP.$cljs$core$rest$$($G__49610__$1_path_str$jscomp$3$$)};
$app$main$data$workspace$colors$split_color_components$$=function($map__70901__$1_p__70900$$){$map__70901__$1_p__70900$$=$APP.$cljs$core$__destructure_map$$($map__70901__$1_p__70900$$);var $color$jscomp$97_value$jscomp$593$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70901__$1_p__70900$$,$APP.$cljs$cst$1298$color$$),$opacity$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70901__$1_p__70900$$,$APP.$cljs$cst$1734$opacity$$);$color$jscomp$97_value$jscomp$593$$=
$APP.$app$common$types$color$valid_hex_color_QMARK_$$($color$jscomp$97_value$jscomp$593$$)?$color$jscomp$97_value$jscomp$593$$:"#000000";var $b$jscomp$319_vec__70907$$=$APP.$app$common$types$color$hex__GT_rgb$$($color$jscomp$97_value$jscomp$593$$),$r$jscomp$117$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$319_vec__70907$$,0,null),$g$jscomp$138$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$319_vec__70907$$,1,null);$b$jscomp$319_vec__70907$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$319_vec__70907$$,
2,null);var $v$jscomp$595_vec__70910$$=$app$common$types$color$hex__GT_hsv$$($color$jscomp$97_value$jscomp$593$$),$h$jscomp$164$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$595_vec__70910$$,0,null),$s$jscomp$550$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$595_vec__70910$$,1,null);$v$jscomp$595_vec__70910$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$595_vec__70910$$,2,null);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__70901__$1_p__70900$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$2687$hex$$,$APP.$cljs$core$truth_$$($color$jscomp$97_value$jscomp$593$$)?$color$jscomp$97_value$jscomp$593$$:"000000",$APP.$cljs$cst$746$alpha$$,$APP.$cljs$core$truth_$$(isNaN($opacity$jscomp$28$$))?1:$APP.$cljs$core$truth_$$($opacity$jscomp$28$$)?$opacity$jscomp$28$$:1,$APP.$cljs$cst$1743$r$$,$r$jscomp$117$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$138$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$319_vec__70907$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$164$$,
$APP.$cljs$cst$4168$s$$,$s$jscomp$550$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$595_vec__70910$$],null)]))};
$app$common$types$color$library_color__GT_color$$=function($lcolor$$,$file_id$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$06$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$select_keys$$($lcolor$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1734$opacity$$],
null)),$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lcolor$$,$APP.$cljs$cst$266$id$$)),$APP.$cljs$cst$1736$ref_file$$,$file_id$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lcolor$$,$APP.$cljs$cst$296$path$$),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lcolor$$,$APP.$cljs$cst$725$name$$))};
$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$=function($coll$jscomp$144$$){return $APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$compare$$,$coll$jscomp$144$$)};
$app$main$fonts$get_node_fonts$$=function($node$jscomp$261_result$jscomp$231$$){$node$jscomp$261_result$jscomp$231$$=Array.from($APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$261_result$jscomp$231$$,"[style*\x3dfont]")).reduce(function($obj$jscomp$188$$,$font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$){var $font_variant_font_variant_id$jscomp$2_style$jscomp$13$$=$font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$.style,$font_family$jscomp$2$$=$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$.fontFamily;
$font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$294_map__53080_p__53076$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$294_map__53080_p__53076$$,0,null);$id$jscomp$294_map__53080_p__53076$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$294_map__53080_p__53076$$,1,null);var $family$jscomp$4_map__53080__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$294_map__53080_p__53076$$);
$id$jscomp$294_map__53080_p__53076$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$4_map__53080__$1$$,$APP.$cljs$cst$266$id$$);$family$jscomp$4_map__53080__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$4_map__53080__$1$$,$APP.$cljs$cst$2675$family$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$4_map__53080__$1$$,$font_family$jscomp$2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$294_map__53080_p__53076$$,
$font_family$jscomp$2$$)},$APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$,0,null);var $font$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$,1,null);$font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$16$$);$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$=
$APP.$app$main$fonts$get_variant$$($font$jscomp$16$$,$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$.fontVariant);$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_variant_font_variant_id$jscomp$2_style$jscomp$13$$);return $APP.$app$util$object$set_BANG_$$($obj$jscomp$188$$,""+($font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$??"")+":"+($font_variant_font_variant_id$jscomp$2_style$jscomp$13$$??""),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1757$font_id$$,$font_id$jscomp$3_node__$1$jscomp$66_vec__53073$$,$APP.$cljs$cst$1759$font_variant_id$$,$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$],null))},{});return Object.values($node$jscomp$261_result$jscomp$231$$)};
$app$common$types$text$content_has_text_QMARK_$$=function($content$jscomp$18$$,$search$$){var $search_lower$$=$APP.$cuerdas$core$lower$$($search$$);return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($p1__46039_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($p1__46039_SHARP_$$)),$search_lower$$)},$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,
$content$jscomp$18$$)))};
$app$common$types$shape$layout$cells_in_area$$=function($parent$jscomp$180$$,$first_row$$,$last_row$$,$first_column$$,$last_column$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__48354_row$jscomp$16$$){var $column_span$jscomp$8_map__48355__$1$$=$APP.$cljs$core$__destructure_map$$($p__48354_row$jscomp$16$$);$p__48354_row$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48355__$1$$,$APP.$cljs$cst$1656$row$$);var $column$jscomp$23$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48355__$1$$,$APP.$cljs$cst$216$column$$),$row_span$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48355__$1$$,$APP.$cljs$cst$1657$row_span$$);$column_span$jscomp$8_map__48355__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48355__$1$$,$APP.$cljs$cst$1658$column_span$$);return($p__48354_row$jscomp$16$$<=$first_row$$&&$first_row$$<=$p__48354_row$jscomp$16$$+
$row_span$jscomp$8$$+-1||$p__48354_row$jscomp$16$$<=$last_row$$&&$last_row$$<=$p__48354_row$jscomp$16$$+$row_span$jscomp$8$$+-1||$first_row$$<=$p__48354_row$jscomp$16$$&&$p__48354_row$jscomp$16$$<=$last_row$$||$first_row$$<=$p__48354_row$jscomp$16$$+$row_span$jscomp$8$$+-1&&$p__48354_row$jscomp$16$$+$row_span$jscomp$8$$+-1<=$last_row$$)&&($column$jscomp$23$$<=$first_column$$&&$first_column$$<=$column$jscomp$23$$+$column_span$jscomp$8_map__48355__$1$$+-1||$column$jscomp$23$$<=$last_column$$&&$last_column$$<=
$column$jscomp$23$$+$column_span$jscomp$8_map__48355__$1$$+-1||$first_column$$<=$column$jscomp$23$$&&$column$jscomp$23$$<=$last_column$$||$first_column$$<=$column$jscomp$23$$+$column_span$jscomp$8_map__48355__$1$$+-1&&$column$jscomp$23$$+$column_span$jscomp$8_map__48355__$1$$+-1<=$last_column$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$180$$)))};
$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$=function($parent$jscomp$178$$,$index$jscomp$160$$){return $APP.$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$178$$,$index$jscomp$160$$,!0)};
$app$common$types$shape$layout$cells_by_column$$=function($var_args$jscomp$916$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $APP.$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$=function($parent$jscomp$176$$,$index$jscomp$158$$){return $APP.$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$176$$,$index$jscomp$158$$,!0)};
$app$common$types$shape$layout$cells_by_row$$=function($var_args$jscomp$915$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $APP.$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$types$shape$layout$remove_cell_areas_after$$=function($parent$jscomp$139$$,$prop$jscomp$13$$,$index$jscomp$148$$){var $prop_span$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$13$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$cst$1658$column_span$$:$APP.$cljs$cst$1657$row_span$$,$cells$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$13$$,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?
$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$139$$,$index$jscomp$148$$):$app$common$types$shape$layout$cells_by_column$$($parent$jscomp$139$$,$index$jscomp$148$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$139$$,$index$jscomp$148$$):$app$common$types$shape$layout$cells_by_row$$($parent$jscomp$139$$,$index$jscomp$148$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$1$jscomp$39$$,$cell$jscomp$1$$){var $area_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1674$area$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$1$$)),$changed_cells$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop$jscomp$13$$),$index$jscomp$148$$+
1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$1$$,$prop_span$jscomp$1$$,1),function(){var $G__48018$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$jscomp$1$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$13$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop$jscomp$13$$)+1,$prop_span$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop_span$jscomp$1$$)-1])),$APP.$cljs$cst$1675$area_name$$);return $area_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48018$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$):$G__48018$$}()],null):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,
$prop$jscomp$13$$)<$index$jscomp$148$$+1&&$index$jscomp$148$$+1<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop$jscomp$13$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop_span$jscomp$1$$)-1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$1$$,$prop_span$jscomp$1$$,$index$jscomp$148$$+2-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,
$prop$jscomp$13$$)),function(){var $G__48020$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$jscomp$1$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$13$$,$index$jscomp$148$$+2,$prop_span$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,
$prop$jscomp$13$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop_span$jscomp$1$$)-1)-($index$jscomp$148$$+1)])),$APP.$cljs$cst$1675$area_name$$);return $area_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48020$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$):$G__48020$$}()],null):null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__48016_SHARP_$$,$p2__48017_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__48016_SHARP_$$,
$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p2__48017_SHARP_$$),$p2__48017_SHARP_$$)},$parent__$1$jscomp$39$$,$changed_cells$jscomp$1$$)},$parent$jscomp$139$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48015_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48015_SHARP_$$,$prop_span$jscomp$1$$)>1},$cells$jscomp$1$$))};
$app$common$types$shape$layout$remove_cell_areas$$=function($parent$jscomp$138$$,$prop$jscomp$12$$,$index$jscomp$147$$){var $prop_span$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$12$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$cst$1658$column_span$$:$APP.$cljs$cst$1657$row_span$$,$cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$12$$,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$138$$,
$index$jscomp$147$$):$app$common$types$shape$layout$cells_by_column$$($parent$jscomp$138$$,$index$jscomp$147$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$138$$,$index$jscomp$147$$):$app$common$types$shape$layout$cells_by_row$$($parent$jscomp$138$$,$index$jscomp$147$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$1$jscomp$38$$,
$cell$$){var $area_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1674$area$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$$)),$changed_cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$),$index$jscomp$147$$+1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$$,
$prop_span$$,1),function(){var $G__48005$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+1,$prop_span$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,
$prop_span$$)-1])),$APP.$cljs$cst$1675$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48005$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$):$G__48005$$}()],null):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)<$index$jscomp$147$$+1&&$index$jscomp$147$$+1<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop_span$$)-
1)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$$,$prop_span$$,$index$jscomp$147$$+1-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)),function(){var $G__48008$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$index$jscomp$147$$+1,$prop_span$$,1])),$APP.$cljs$cst$1675$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48008$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$):$G__48008$$}(),function(){var $G__48009$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$index$jscomp$147$$+2,$prop_span$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop_span$$)-1)-($index$jscomp$147$$+1)])),$APP.$cljs$cst$1675$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48009$$,$APP.$cljs$cst$1676$position$$,
$APP.$cljs$cst$1673$manual$$):$G__48009$$}()],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop_span$$)-1),$index$jscomp$147$$+1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$$,$prop_span$$,$index$jscomp$147$$+1-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,
$prop$jscomp$12$$)),function(){var $G__48010$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$index$jscomp$147$$+1,$prop_span$$,1])),$APP.$cljs$cst$1675$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48010$$,
$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$):$G__48010$$}()],null):null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__47992_SHARP_$$,$p2__47993_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__47992_SHARP_$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p2__47993_SHARP_$$),$p2__47993_SHARP_$$)},$parent__$1$jscomp$38$$,$changed_cells$$)},$parent$jscomp$138$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__47991_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__47991_SHARP_$$,$prop_span$$)>1},$cells$$))};
$app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$=function($index$jscomp$309$$){typeof $app$main$data$workspace$colors$remove_gradient_stop_71002$$==="undefined"&&($app$main$data$workspace$colors$remove_gradient_stop_71002$$=function($index$jscomp$310$$,$meta71003$$){this.index=$index$jscomp$310$$;this.$meta71003$=$meta71003$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_gradient_stop_71002$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_gradient_stop_71002$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4179$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_gradient_stop$$},$app$main$data$workspace$colors$remove_gradient_stop_71002$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71004$$,$meta71003__$1$$){return new $app$main$data$workspace$colors$remove_gradient_stop_71002$$(this.index,$meta71003__$1$$)},
$app$main$data$workspace$colors$remove_gradient_stop_71002$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71003$},$app$main$data$workspace$colors$remove_gradient_stop_71002$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_gradient_stop_71002$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2268$$,$state$jscomp$655$$){var $self__$jscomp$5307$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$655$$,
$APP.$cljs$cst$2239$colorpicker$$,function($map__71006__$1_p__71005$$){$map__71006__$1_p__71005$$=$APP.$cljs$core$__destructure_map$$($map__71006__$1_p__71005$$);var $editing_stop$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71006__$1_p__71005$$,$APP.$cljs$cst$4162$editing_stop$$),$stops$jscomp$15_stops__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71006__$1_p__71005$$,$APP.$cljs$cst$1733$stops$$);if($APP.$cljs$core$count$$($stops$jscomp$15_stops__$1$jscomp$6$$)>
2){var $delete_index_editing_stop__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$816$$=$self__$jscomp$5307$$.index;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$816$$)?$or__5025__auto__$jscomp$816$$:$APP.$cljs$core$truth_$$($editing_stop$jscomp$2$$)?$editing_stop$jscomp$2$$:0}(),$delete_stop$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$15_stops__$1$jscomp$6$$,$delete_index_editing_stop__$1$jscomp$1$$);$stops$jscomp$15_stops__$1$jscomp$6$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__70999_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($delete_stop$$,$p1__70999_SHARP_$$)}),$stops$jscomp$15_stops__$1$jscomp$6$$);$delete_index_editing_stop__$1$jscomp$1$$=$editing_stop$jscomp$2$$<$delete_index_editing_stop__$1$jscomp$1$$?$editing_stop$jscomp$2$$:$editing_stop$jscomp$2$$>$delete_index_editing_stop__$1$jscomp$1$$?$editing_stop$jscomp$2$$-1:$APP.$cljs$core$count$$($stops$jscomp$15_stops__$1$jscomp$6$$)>=
$editing_stop$jscomp$2$$?$APP.$cljs$core$count$$($stops$jscomp$15_stops__$1$jscomp$6$$)-1:$editing_stop$jscomp$2$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71006__$1_p__71005$$,$APP.$cljs$cst$4162$editing_stop$$,$delete_index_editing_stop__$1$jscomp$1$$),$APP.$cljs$cst$1733$stops$$,$stops$jscomp$15_stops__$1$jscomp$6$$)}return $map__71006__$1_p__71005$$})});return new $app$main$data$workspace$colors$remove_gradient_stop_71002$$($index$jscomp$309$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$209$$,$coll$jscomp$280$$){return function $cljs$core$keepi$$($idx$jscomp$17$$,$coll__$1$jscomp$100$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$4$$=$APP.$cljs$core$seq$$($coll__$1$jscomp$100$$);if($temp__5825__auto__$jscomp$4$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($temp__5825__auto__$jscomp$4$$)){for(var $c$jscomp$106$$=$APP.$cljs$core$_chunked_first$$($temp__5825__auto__$jscomp$4$$),$size$jscomp$32_x$jscomp$407$$=
$APP.$cljs$core$count$$($c$jscomp$106$$),$b$jscomp$130$$=$APP.$cljs$core$chunk_buffer$$($size$jscomp$32_x$jscomp$407$$),$i_26720$$=0;;)if($i_26720$$<$size$jscomp$32_x$jscomp$407$$){var $x_26721$$=function(){var $G__23381$$=$idx$jscomp$17$$+$i_26720$$,$G__23382$$=$APP.$cljs$core$_nth$$($c$jscomp$106$$,$i_26720$$);return $f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$($G__23381$$,$G__23382$$):$f$jscomp$209$$($G__23381$$,$G__23382$$)}();$x_26721$$!=null&&
$b$jscomp$130$$.add($x_26721$$);$i_26720$$+=1}else break;return $APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b$jscomp$130$$),$cljs$core$keepi$$($idx$jscomp$17$$+$size$jscomp$32_x$jscomp$407$$,$APP.$cljs$core$_chunked_rest$$($temp__5825__auto__$jscomp$4$$)))}$size$jscomp$32_x$jscomp$407$$=function(){var $G__23384$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$4$$);return $f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$17$$,
$G__23384$$):$f$jscomp$209$$($idx$jscomp$17$$,$G__23384$$)}();return $size$jscomp$32_x$jscomp$407$$==null?$cljs$core$keepi$$($idx$jscomp$17$$+1,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$4$$)):$APP.$cljs$core$cons$$($size$jscomp$32_x$jscomp$407$$,$cljs$core$keepi$$($idx$jscomp$17$$+1,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$4$$)))}return null},null,null)}(0,$coll$jscomp$280$$)};
$app$main$data$workspace$tokens$errors$detail_errors$$=function($errors$jscomp$19$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($err$jscomp$41_fexpr__71820$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$4602$error_SLASH_detail$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$41_fexpr__71820$$))){var $G__71821$$=$APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$41_fexpr__71820$$);
$err$jscomp$41_fexpr__71820$$=$APP.$cljs$cst$4602$error_SLASH_detail$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$41_fexpr__71820$$);return $err$jscomp$41_fexpr__71820$$.$cljs$core$IFn$_invoke$arity$1$?$err$jscomp$41_fexpr__71820$$.$cljs$core$IFn$_invoke$arity$1$($G__71821$$):$err$jscomp$41_fexpr__71820$$($G__71821$$)}return null},$errors$jscomp$19$$)))};
$app$main$data$workspace$tokens$errors$humanize_errors$$=function($errors$jscomp$18$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($err$jscomp$40_fexpr__71801$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__71801$$))){var $G__71802$$=$APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__71801$$);$err$jscomp$40_fexpr__71801$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__71801$$);
return $err$jscomp$40_fexpr__71801$$.$cljs$core$IFn$_invoke$arity$1$?$err$jscomp$40_fexpr__71801$$.$cljs$core$IFn$_invoke$arity$1$($G__71802$$):$err$jscomp$40_fexpr__71801$$($G__71802$$)}return $APP.$cljs$core$truth_$$($APP.$cljs$cst$882$error_SLASH_message$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__71801$$))?$APP.$cljs$cst$882$error_SLASH_message$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__71801$$):$err$jscomp$40_fexpr__71801$$},$errors$jscomp$18$$)};
$app$main$data$workspace$show_grid_cell_context_menu$$=function($p__71999$$){var $map__72001__$1$$=$APP.$cljs$core$__destructure_map$$($p__71999$$),$grid_id$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72001__$1$$,$APP.$cljs$cst$4420$grid_id$$);typeof $app$main$data$workspace$show_grid_cell_context_menu_72002$$==="undefined"&&($app$main$data$workspace$show_grid_cell_context_menu_72002$$=function($p__71999$jscomp$1$$,$map__72001$jscomp$1$$,$params$jscomp$303$$,$grid_id$jscomp$26$$,
$meta72003$$){this.$p__71999$=$p__71999$jscomp$1$$;this.$map__72001$=$map__72001$jscomp$1$$;this.params=$params$jscomp$303$$;this.$grid_id$=$grid_id$jscomp$26$$;this.$meta72003$=$meta72003$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_grid_cell_context_menu_72002$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_grid_cell_context_menu_72002$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4511$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_grid_cell_context_menu$$},$app$main$data$workspace$show_grid_cell_context_menu_72002$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72004$$,$meta72003__$1$$){return new $app$main$data$workspace$show_grid_cell_context_menu_72002$$(this.$p__71999$,this.$map__72001$,this.params,this.$grid_id$,$meta72003__$1$$)},$app$main$data$workspace$show_grid_cell_context_menu_72002$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72003$},$app$main$data$workspace$show_grid_cell_context_menu_72002$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_grid_cell_context_menu_72002$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2580_objects$jscomp$670$$,$cells$jscomp$28_state$jscomp$917$$){$_$jscomp$2580_objects$jscomp$670$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$28_state$jscomp$917$$);
var $grid$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2580_objects$jscomp$670$$,this.$grid_id$);$cells$jscomp$28_state$jscomp$917$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71996_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$p1__71996_SHARP_$$],null))},$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$28_state$jscomp$917$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1921$selected$$],null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$3057$grid_cells$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1659$grid$$,
$grid$jscomp$9$$,$APP.$cljs$cst$4512$cells$$,$cells$jscomp$28_state$jscomp$917$$]))))});return new $app$main$data$workspace$show_grid_cell_context_menu_72002$$($p__71999$$,$map__72001__$1$$,$map__72001__$1$$,$grid_id$jscomp$25$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$delete_page_components$$=function($changes$jscomp$250$$,$page$jscomp$99$$){var $components_to_delete$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70973_SHARP_$$){return $APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($p1__70973_SHARP_$$)===!0},$APP.$cljs$core$vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$99$$))));
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$77$$,$component_id$jscomp$68$$){return $APP.$app$common$files$changes_builder$delete_component$$($changes__$1$jscomp$77$$,$component_id$jscomp$68$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$99$$))},$changes$jscomp$250$$,$components_to_delete$jscomp$1$$)};
$app$common$types$color$offset_spread$$=function($from$jscomp$9$$,$to$jscomp$8$$,$num$jscomp$27$$){return $num$jscomp$27$$<=1?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from$jscomp$9$$],null):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__45548_SHARP_$$){return $APP.$app$common$math$precision$$($from$jscomp$9$$+($to$jscomp$8$$-$from$jscomp$9$$)/($num$jscomp$27$$-1)*$p1__45548_SHARP_$$,2)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(0,
$num$jscomp$27$$))};
$app$common$types$shape$layout$swap_track_content$$=function($parent$jscomp$149$$,$prop$jscomp$17$$,$from_track$$,$to_track$$){var $remap_tracks$$=$from_track$$>$to_track$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$from_track$$,$to_track$$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48144_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__48144_SHARP_$$,
$p1__48144_SHARP_$$+1],null)}),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($to_track$$,$from_track$$)):$from_track$$<$to_track$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$from_track$$,$to_track$$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48145_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__48145_SHARP_$$,$p1__48145_SHARP_$$-
1],null)}),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($from_track$$+1,$to_track$$+1)):null;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($parent$jscomp$149$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$update_vals$$,function($cell$jscomp$8$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$8$$,$prop$jscomp$17$$,function($p1__48146_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($remap_tracks$$,$p1__48146_SHARP_$$,
$p1__48146_SHARP_$$)})})};$app$common$data$natural_sort_key$$=function($s$jscomp$288$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($part$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/\d+/,$part$jscomp$1$$))?parseInt($part$jscomp$1$$):$part$jscomp$1$$},$APP.$cljs$core$re_seq$$(/\d+|\D+/,$s$jscomp$288$$))};
$app$common$data$natural_compare$$=function($G__32248_a$jscomp$232_ka$$,$G__32249_b$jscomp$189_kb$$){$G__32248_a$jscomp$232_ka$$=$app$common$data$natural_sort_key$$($G__32248_a$jscomp$232_ka$$);for($G__32249_b$jscomp$189_kb$$=$app$common$data$natural_sort_key$$($G__32249_b$jscomp$189_kb$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__32248_a$jscomp$232_ka$$)&&$APP.$cljs$core$empty_QMARK_$$($G__32249_b$jscomp$189_kb$$))return 0;if($APP.$cljs$core$empty_QMARK_$$($G__32248_a$jscomp$232_ka$$))return-1;if($APP.$cljs$core$empty_QMARK_$$($G__32249_b$jscomp$189_kb$$))return 1;
var $pa$jscomp$2_result$jscomp$92$$=$APP.$cljs$core$first$$($G__32248_a$jscomp$232_ka$$),$pb$$=$APP.$cljs$core$first$$($G__32249_b$jscomp$189_kb$$);$pa$jscomp$2_result$jscomp$92$$=typeof $pa$jscomp$2_result$jscomp$92$$==="number"&&typeof $pb$$==="number"?$APP.$cljs$core$compare$$($pa$jscomp$2_result$jscomp$92$$,$pb$$):typeof $pa$jscomp$2_result$jscomp$92$$==="string"&&typeof $pb$$==="string"?$APP.$cljs$core$compare$$($pa$jscomp$2_result$jscomp$92$$,$pb$$):typeof $pa$jscomp$2_result$jscomp$92$$===
"number"?-1:1;if($pa$jscomp$2_result$jscomp$92$$===0)$G__32248_a$jscomp$232_ka$$=$APP.$cljs$core$rest$$($G__32248_a$jscomp$232_ka$$),$G__32249_b$jscomp$189_kb$$=$APP.$cljs$core$rest$$($G__32249_b$jscomp$189_kb$$);else return $pa$jscomp$2_result$jscomp$92$$}};
$app$common$data$invert_map$$=function($m$jscomp$100$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__31770_v$jscomp$147$$){var $k$jscomp$270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31770_v$jscomp$147$$,0,null);$p__31770_v$jscomp$147$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31770_v$jscomp$147$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__31770_v$jscomp$147$$,$k$jscomp$270$$],null)},$m$jscomp$100$$))};
$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$=function($decoded_json$jscomp$1$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,function $app$common$types$tokens_lib$walk$jscomp$2$$($node$jscomp$251$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_inline_result$jscomp$1543$$=$APP.$cljs$core$truth_$$($APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$251$$):(0,$APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$)($node$jscomp$251$$))?$APP.$cljs$cst$2131$json_format_SLASH_legacy$$:$APP.$cljs$core$truth_$$($APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$251$$):(0,$APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$)($node$jscomp$251$$))?
$APP.$cljs$cst$2132$json_format_SLASH_dtcg$$:null;return $APP.$cljs$core$cons$$($JSCompiler_inline_result$jscomp$1543$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$map_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$map_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$251$$):$APP.$cljs$core$map_QMARK_$$($node$jscomp$251$$))?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$tokens_lib$walk$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($node$jscomp$251$$)])):
null)},null,null)}($decoded_json$jscomp$1$$))),$APP.$cljs$cst$2132$json_format_SLASH_dtcg$$)};
$app$common$types$color$hsv__GT_rgb$$=function($p__45404_sextant$$){var $h$jscomp$140_remainder$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45404_sextant$$,0,null),$s$jscomp$512_val3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45404_sextant$$,1,null),$brightness_brightness__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45404_sextant$$,2,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$512_val3$$,0))return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$brightness_brightness__$1$$,$brightness_brightness__$1$$],null);$p__45404_sextant$$=$APP.$app$common$math$floor$$($h$jscomp$140_remainder$jscomp$12$$/60)|0;$h$jscomp$140_remainder$jscomp$12$$=$h$jscomp$140_remainder$jscomp$12$$/60-$p__45404_sextant$$;$brightness_brightness__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($brightness_brightness__$1$$,0);var $val1$jscomp$2$$=$brightness_brightness__$1$$*
(1-$s$jscomp$512_val3$$)|0,$val2$jscomp$2$$=$brightness_brightness__$1$$*(1-$s$jscomp$512_val3$$*$h$jscomp$140_remainder$jscomp$12$$)|0;$s$jscomp$512_val3$$=$brightness_brightness__$1$$*(1-$s$jscomp$512_val3$$*(1-$h$jscomp$140_remainder$jscomp$12$$))|0;switch($p__45404_sextant$$){case 1:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val2$jscomp$2$$,$brightness_brightness__$1$$,$val1$jscomp$2$$],null);case 2:return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val1$jscomp$2$$,$brightness_brightness__$1$$,$s$jscomp$512_val3$$],null);case 3:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val1$jscomp$2$$,$val2$jscomp$2$$,$brightness_brightness__$1$$],null);case 4:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$512_val3$$,$val1$jscomp$2$$,$brightness_brightness__$1$$],null);case 5:return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$val1$jscomp$2$$,$val2$jscomp$2$$],null);case 6:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$s$jscomp$512_val3$$,$val1$jscomp$2$$],null);case 0:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$s$jscomp$512_val3$$,$val1$jscomp$2$$],null);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__45404_sextant$$)].join(""));}};
$app$main$data$workspace$grid_layout$editor$locate_board$$=function($grid_id$jscomp$15$$){typeof $app$main$data$workspace$grid_layout$editor$locate_board_70936$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$locate_board_70936$$=function($grid_id$jscomp$16$$,$meta70937$$){this.$grid_id$=$grid_id$jscomp$16$$;this.$meta70937$=$meta70937$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$locate_board_70936$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$locate_board_70936$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4390$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_locate_board$$},$app$main$data$workspace$grid_layout$editor$locate_board_70936$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70938$$,$meta70937__$1$$){return new $app$main$data$workspace$grid_layout$editor$locate_board_70936$$(this.$grid_id$,
$meta70937__$1$$)},$app$main$data$workspace$grid_layout$editor$locate_board_70936$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70937$},$app$main$data$workspace$grid_layout$editor$locate_board_70936$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$locate_board_70936$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2459_objects$jscomp$620$$,$state$jscomp$821$$){$_$jscomp$2459_objects$jscomp$620$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$821$$);var $srect$jscomp$8$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2459_objects$jscomp$620$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$grid_id$,$APP.$cljs$cst$1605$selrect$$],null));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$821$$,$APP.$cljs$cst$1920$workspace_local$$,function($map__70945__$1_p__70944$$){$map__70945__$1_p__70944$$=
$APP.$cljs$core$__destructure_map$$($map__70945__$1_p__70944$$);var $y__$1_zoom$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70945__$1_p__70944$$,$APP.$cljs$cst$2196$zoom$$),$vport$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70945__$1_p__70944$$,$APP.$cljs$cst$2203$vport$$),$height$jscomp$139_map__70946__$1$$=$APP.$cljs$core$__destructure_map$$($srect$jscomp$8$$),$x$jscomp$1212_x__$1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__70946__$1$$,
$APP.$cljs$cst$1510$x$$),$y$jscomp$445$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__70946__$1$$,$APP.$cljs$cst$1511$y$$),$srect__$1$jscomp$3_width$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__70946__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$139_map__70946__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__70946__$1$$,$APP.$cljs$cst$1522$height$$);$x$jscomp$1212_x__$1$jscomp$29$$=
$x$jscomp$1212_x__$1$jscomp$29$$+$srect__$1$jscomp$3_width$jscomp$155$$/2+-($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$5$$)/2/$y__$1_zoom$jscomp$38$$);$y__$1_zoom$jscomp$38$$=$y$jscomp$445$$+$height$jscomp$139_map__70946__$1$$/2+-($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$5$$)/2/$y__$1_zoom$jscomp$38$$);$srect__$1$jscomp$3_width$jscomp$155$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1212_x__$1$jscomp$29$$,
$y__$1_zoom$jscomp$38$$,$srect__$1$jscomp$3_width$jscomp$155$$,$height$jscomp$139_map__70946__$1$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($map__70945__$1_p__70944$$,$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$merge$$,$APP.$cljs$core$select_keys$$($srect__$1$jscomp$3_width$jscomp$155$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1523$x1$$,$APP.$cljs$cst$1525$x2$$,
$APP.$cljs$cst$1524$y1$$,$APP.$cljs$cst$1526$y2$$],null)))})});return new $app$main$data$workspace$grid_layout$editor$locate_board_70936$$($grid_id$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$dom$bounding_rect__GT_rect$$=function($rect$jscomp$9$$){return $rect$jscomp$9$$!=null?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(function(){var $or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$=$rect$jscomp$9$$.left;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$))return $or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$;$or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$)?$or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$:0}(),function(){var $or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$=$rect$jscomp$9$$.top;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$))return $or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$;$or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$)?$or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$:0}(),function(){var $or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$=$rect$jscomp$9$$.width;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$))return $or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$;$or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$)?$or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$:1}(),function(){var $or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$=$rect$jscomp$9$$.height;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$))return $or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$;$or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$)?$or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$:1}()):null};
$app$common$geom$shapes$text$overlaps_position_data_QMARK_$$=function($map__48859__$1_p__48858_points$jscomp$41$$,$position_data$jscomp$2$$){$map__48859__$1_p__48858_points$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($map__48859__$1_p__48858_points$jscomp$41$$);$map__48859__$1_p__48858_points$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48859__$1_p__48858_points$jscomp$41$$,$APP.$cljs$cst$1604$points$$);var $bounding_box$$=$APP.$app$common$geom$rect$points__GT_rect$$($map__48859__$1_p__48858_points$jscomp$41$$);
return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($JSCompiler_inline_result$jscomp$1544_p1__48857_SHARP_$$){$JSCompiler_inline_result$jscomp$1544_p1__48857_SHARP_$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1544_p1__48857_SHARP_$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1544_p1__48857_SHARP_$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1544_p1__48857_SHARP_$$));
return $APP.$app$common$geom$rect$overlaps_rects_QMARK_$$($bounding_box$$,$JSCompiler_inline_result$jscomp$1544_p1__48857_SHARP_$$)},$position_data$jscomp$2$$))};
$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$=function($decoded_json$jscomp$2$$){return $APP.$clojure$walk$postwalk$$(function($node$jscomp$252$$){var $G__50058__$1_G__50058__$2$$=$APP.$cljs$core$map_QMARK_$$($node$jscomp$252$$)&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$252$$,"value")&&$APP.$cljs$core$sequential_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$252$$,"value"))&&$APP.$cljs$core$map_QMARK_$$($APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$252$$,
"value")))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$252$$,"value",function($seq_value$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__50057_SHARP_$$){return $APP.$clojure$set$rename_keys$$($p1__50057_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,["type","$type"],null))},$seq_value$$)}):$node$jscomp$252$$;$G__50058__$1_G__50058__$2$$=($APP.$cljs$core$map_QMARK_$$($node$jscomp$252$$)&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$252$$,
"type")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("fontFamilies",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$252$$,"type"))&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$252$$,"value")&&$APP.$cljs$core$sequential_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$252$$,"value"))&&$APP.$cljs$core$map_QMARK_$$($APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$252$$,"value"))),$G__50058__$1_G__50058__$2$$);
return $APP.$cljs$core$map_QMARK_$$($node$jscomp$252$$)&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$252$$,"type")&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$252$$,"value")?$APP.$clojure$set$rename_keys$$($G__50058__$1_G__50058__$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["value","$value","type","$type"],null)):$G__50058__$1_G__50058__$2$$},$decoded_json$jscomp$2$$)};
$app$common$types$text$replace_text_in_content$$=function($content$jscomp$19$$,$search$jscomp$2$$,$replacement$jscomp$14$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$text$is_text_node_QMARK_$$,function($node$jscomp$235$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$235$$,$APP.$cljs$cst$1588$text$$,$app$common$types$text$replace_all_case_insensitive$$,$search$jscomp$2$$,$replacement$jscomp$14$$)},
$content$jscomp$19$$)};
$cljs$spec$alpha$abbrev$$=function($form$jscomp$113$$){return $APP.$cljs$core$seq_QMARK_$$($form$jscomp$113$$)?$APP.$clojure$walk$postwalk$$(function($form__$1$$){var $JSCompiler_inline_result$jscomp$1545_and__5023__auto__$jscomp$inline_8156$$=($JSCompiler_inline_result$jscomp$1545_and__5023__auto__$jscomp$inline_8156$$=$form__$1$$ instanceof $APP.$cljs$core$Symbol$$)?$APP.$cljs$core$namespace$$($form__$1$$):$JSCompiler_inline_result$jscomp$1545_and__5023__auto__$jscomp$inline_8156$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1545_and__5023__auto__$jscomp$inline_8156$$)?
$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$name$$($form__$1$$)):$APP.$cljs$core$seq_QMARK_$$($form__$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$28$fn$$,$APP.$cljs$core$first$$($form__$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$second$$($form__$1$$))?$APP.$cljs$core$last$$($form__$1$$):
$form__$1$$},$form$jscomp$113$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$150$$=$form$jscomp$113$$ instanceof $APP.$cljs$core$Symbol$$;return $and__5023__auto__$jscomp$150$$?$APP.$cljs$core$namespace$$($form$jscomp$113$$):$and__5023__auto__$jscomp$150$$}())?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$name$$($form$jscomp$113$$)):$form$jscomp$113$$};
$app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$=function($state$jscomp$338$$){return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$338$$,"render-wasm/v1")&&!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$338$$)?$APP.$app$render_wasm$api$view_interaction_end_BANG_$$():null};
$app$main$data$workspace$viewport$finish_panning$$=function(){typeof $app$main$data$workspace$viewport$finish_panning_71253$$==="undefined"&&($app$main$data$workspace$viewport$finish_panning_71253$$=function($meta71254$$){this.$meta71254$=$meta71254$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4454$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_finish_panning$$},$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71255$$,$meta71254__$1$$){return new $app$main$data$workspace$viewport$finish_panning_71253$$($meta71254__$1$$)},$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71254$},$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2518$$,$state$jscomp$869$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$869$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4452$panning$$)},$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$viewport$finish_panning_71253$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2519$$,$state$jscomp$870$$){return $app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$($state$jscomp$870$$)});return new $app$main$data$workspace$viewport$finish_panning_71253$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$zoom$finish_zooming$$=function(){typeof $app$main$data$workspace$zoom$finish_zooming_66329$$==="undefined"&&($app$main$data$workspace$zoom$finish_zooming_66329$$=function($meta66330$$){this.$meta66330$=$meta66330$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3587$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_finish_zooming$$},$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66331$$,$meta66330__$1$$){return new $app$main$data$workspace$zoom$finish_zooming_66329$$($meta66330__$1$$)},$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66330$},$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1915$$,$state$jscomp$354$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$354$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3588$zooming$$)},$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$finish_zooming_66329$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function($_$jscomp$1916$$,$state$jscomp$355$$){return $app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$($state$jscomp$355$$)});return new $app$main$data$workspace$zoom$finish_zooming_66329$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$=function($state$jscomp$337$$){return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$337$$,"render-wasm/v1")&&!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$337$$)?$APP.$app$render_wasm$api$view_interaction_start_BANG_$$():null};
$app$main$data$workspace$viewport$activate_panning$$=function(){typeof $app$main$data$workspace$viewport$activate_panning_71233$$==="undefined"&&($app$main$data$workspace$viewport$activate_panning_71233$$=function($meta71234$$){this.$meta71234$=$meta71234$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4451$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_activate_panning$$},$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71235$$,$meta71234__$1$$){return new $app$main$data$workspace$viewport$activate_panning_71233$$($meta71234__$1$$)},$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71234$},$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2515$$,$state$jscomp$866$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$866$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4452$panning$$],null),!0)},$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$activate_panning_71233$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2516$$,$state$jscomp$867$$){return $app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$($state$jscomp$867$$)});return new $app$main$data$workspace$viewport$activate_panning_71233$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_has_focus;try{var $JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$=
$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$()}catch($e53532$jscomp$inline_8172$$){$JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$=$e53532$jscomp$inline_8172$$;$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$)?$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$():null;$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_8171$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_8171$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_has_focus",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_8171$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_8170_code_num__52998__auto__$jscomp$inline_8169_fn_53530$jscomp$inline_8166_read_code_fn__52997__auto__$jscomp$inline_8168$$],
null),$JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$);}$JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$=$JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$!==0}else $JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$=null;return $JSCompiler_inline_result$jscomp$1547_JSCompiler_temp$jscomp$1546_cause53531$jscomp$inline_8167$$};
$app$render_wasm$text_editor$text_editor_blur$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_blur;try{var $JSCompiler_inline_result$jscomp$1548_cause53509$jscomp$inline_8175$$=$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$()}catch($e53510$jscomp$inline_8180$$){$JSCompiler_inline_result$jscomp$1548_cause53509$jscomp$inline_8175$$=
$e53510$jscomp$inline_8180$$;$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$)?
$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$():
null;$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_8179$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_8179$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_blur",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$inline_8179$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_8178_code_num__52998__auto__$jscomp$inline_8177_fn_53508$jscomp$inline_8174_read_code_fn__52997__auto__$jscomp$inline_8176$$],null),$JSCompiler_inline_result$jscomp$1548_cause53509$jscomp$inline_8175$$);}if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1548_cause53509$jscomp$inline_8175$$))return null;throw Error("TextEditor blur failed");}return null};
$app$render_wasm$text_editor$text_editor_select_word_boundary$$=function($cause53497_p__53494_x$jscomp$1161$$){var $code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$=$APP.$cljs$core$__destructure_map$$($cause53497_p__53494_x$jscomp$1161$$);$cause53497_p__53494_x$jscomp$1161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$,
$APP.$cljs$cst$1510$x$$);$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$,$APP.$cljs$cst$1511$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53496_hint__53000__auto__$jscomp$26$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_select_word_boundary;
try{return $fn_53496_hint__53000__auto__$jscomp$26$$($cause53497_p__53494_x$jscomp$1161$$,$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$)}catch($e53498$$){throw $cause53497_p__53494_x$jscomp$1161$$=$e53498$$,$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$)?$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$():
null,$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_53496_hint__53000__auto__$jscomp$26$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53496_hint__53000__auto__$jscomp$26$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_select_word_boundary",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53496_hint__53000__auto__$jscomp$26$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$26_code_num__52998__auto__$jscomp$26_map__53495__$1_read_code_fn__52997__auto__$jscomp$26_y$jscomp$399$$],
null),$cause53497_p__53494_x$jscomp$1161$$);}}else return null};
$app$render_wasm$text_editor$text_editor_select_all$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53491_fn_53490$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_select_all;try{$cause53491_fn_53490$$()}catch($e53492$$){$cause53491_fn_53490$$=$e53492$$;var $code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$)?$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$():
null;$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$25$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$25$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_select_all",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$25$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$25_code_num__52998__auto__$jscomp$25_read_code_fn__52997__auto__$jscomp$25$$],null),$cause53491_fn_53490$$);}}};
$app$render_wasm$text_editor$text_editor_move_cursor$$=function($cause53487_direction$jscomp$12$$,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$,$extend_selection_hint__53000__auto__$jscomp$24$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53486$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_move_cursor;try{$fn_53486$$($cause53487_direction$jscomp$12$$,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$,
$APP.$cljs$core$truth_$$($extend_selection_hint__53000__auto__$jscomp$24$$)?1:0)}catch($e53488$$){throw $cause53487_direction$jscomp$12$$=$e53488$$,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$)?
$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$():null,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$,$APP.$cljs$cst$2971$wasm_critical$$),$extend_selection_hint__53000__auto__$jscomp$24$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($extend_selection_hint__53000__auto__$jscomp$24$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_move_cursor",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$extend_selection_hint__53000__auto__$jscomp$24$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$24_code_num__52998__auto__$jscomp$24_read_code_fn__52997__auto__$jscomp$24_word_boundary$jscomp$2$$],null),$cause53487_direction$jscomp$12$$);}}};
$app$render_wasm$text_editor$text_editor_insert_paragraph$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53484_fn_53483$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_insert_paragraph;try{$cause53484_fn_53483$$()}catch($e53485$$){$cause53484_fn_53483$$=$e53485$$;var $code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$)?$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$():
null;$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$23$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$23$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_insert_paragraph",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$23$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$23_code_num__52998__auto__$jscomp$23_read_code_fn__52997__auto__$jscomp$23$$],null),$cause53484_fn_53483$$);}}};
$app$render_wasm$text_editor$text_editor_delete_forward$cljs$0core$0IFn$0_invoke$0arity$01$$=function($cause53481_word_boundary$jscomp$1$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_delete_forward;try{$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$($cause53481_word_boundary$jscomp$1$$)}catch($e53482$$){$cause53481_word_boundary$jscomp$1$$=
$e53482$$;$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$)?$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$():null;$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$22$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$22$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_delete_forward",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$22$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$22_code_num__52998__auto__$jscomp$22_fn_53480_read_code_fn__52997__auto__$jscomp$22$$],null),$cause53481_word_boundary$jscomp$1$$);}}};
$app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$=function($cause53476_word_boundary$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_delete_backward;try{$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$($cause53476_word_boundary$$)}catch($e53477$$){$cause53476_word_boundary$$=
$e53477$$;$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$)?$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$():null;$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$21$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$21$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_delete_backward",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$21$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$21_code_num__52998__auto__$jscomp$21_fn_53475_read_code_fn__52997__auto__$jscomp$21$$],null),$cause53476_word_boundary$$);}}};
$app$render_wasm$text_editor$text_editor_pointer_up$$=function($cause53400_p__53397_x$jscomp$1160$$){var $code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$=$APP.$cljs$core$__destructure_map$$($cause53400_p__53397_x$jscomp$1160$$);$cause53400_p__53397_x$jscomp$1160$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$,
$APP.$cljs$cst$1510$x$$);$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$,$APP.$cljs$cst$1511$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53399_hint__53000__auto__$jscomp$15$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_pointer_up;
try{return $fn_53399_hint__53000__auto__$jscomp$15$$($cause53400_p__53397_x$jscomp$1160$$,$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$)}catch($e53401$$){throw $cause53400_p__53397_x$jscomp$1160$$=$e53401$$,$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$)?$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$():
null,$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_53399_hint__53000__auto__$jscomp$15$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53399_hint__53000__auto__$jscomp$15$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_pointer_up",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53399_hint__53000__auto__$jscomp$15$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$15_code_num__52998__auto__$jscomp$15_map__53398__$1_read_code_fn__52997__auto__$jscomp$15_y$jscomp$398$$],
null),$cause53400_p__53397_x$jscomp$1160$$);}}else return null};
$app$render_wasm$text_editor$text_editor_pointer_move$$=function($cause53392_p__53389_x$jscomp$1159$$){var $code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$=$APP.$cljs$core$__destructure_map$$($cause53392_p__53389_x$jscomp$1159$$);$cause53392_p__53389_x$jscomp$1159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$,$APP.$cljs$cst$1510$x$$);
$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$,$APP.$cljs$cst$1511$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53391_hint__53000__auto__$jscomp$14$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_pointer_move;
try{return $fn_53391_hint__53000__auto__$jscomp$14$$($cause53392_p__53389_x$jscomp$1159$$,$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$)}catch($e53396$$){throw $cause53392_p__53389_x$jscomp$1159$$=$e53396$$,$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$)?$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$():
null,$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_53391_hint__53000__auto__$jscomp$14$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53391_hint__53000__auto__$jscomp$14$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_pointer_move",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53391_hint__53000__auto__$jscomp$14$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$14_code_num__52998__auto__$jscomp$14_map__53390__$1_read_code_fn__52997__auto__$jscomp$14_y$jscomp$397$$],
null),$cause53392_p__53389_x$jscomp$1159$$);}}else return null};
$app$render_wasm$text_editor$text_editor_pointer_down$$=function($cause53387_p__53378_x$jscomp$1158$$){var $code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$=$APP.$cljs$core$__destructure_map$$($cause53387_p__53378_x$jscomp$1158$$);$cause53387_p__53378_x$jscomp$1158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$,$APP.$cljs$cst$1510$x$$);
$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$,$APP.$cljs$cst$1511$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53386_hint__53000__auto__$jscomp$13$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_pointer_down;
try{return $fn_53386_hint__53000__auto__$jscomp$13$$($cause53387_p__53378_x$jscomp$1158$$,$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$)}catch($e53388$$){throw $cause53387_p__53378_x$jscomp$1158$$=$e53388$$,$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$)?$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$():
null,$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_53386_hint__53000__auto__$jscomp$13$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53386_hint__53000__auto__$jscomp$13$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_pointer_down",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53386_hint__53000__auto__$jscomp$13$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$13_code_num__52998__auto__$jscomp$13_map__53379__$1_read_code_fn__52997__auto__$jscomp$13_y$jscomp$396$$],
null),$cause53387_p__53378_x$jscomp$1158$$);}}else return null};
$app$render_wasm$text_editor$text_editor_toggle_overtype_mode$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53368_fn_53367$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_toggle_overtype_mode;try{$cause53368_fn_53367$$()}catch($e53370$$){$cause53368_fn_53367$$=$e53370$$;var $code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$)?$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$():
null;$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$12$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$12$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_toggle_overtype_mode",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$12$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$12_code_num__52998__auto__$jscomp$12_read_code_fn__52997__auto__$jscomp$12$$],null),$cause53368_fn_53367$$);
}}};
$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$=function($cause53352_p__53348_x$jscomp$1156$$){var $code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$=$APP.$cljs$core$__destructure_map$$($cause53352_p__53348_x$jscomp$1156$$);$cause53352_p__53348_x$jscomp$1156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$,$APP.$cljs$cst$1510$x$$);
$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$,$APP.$cljs$cst$1511$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53351_hint__53000__auto__$jscomp$10$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_set_cursor_from_offset;
try{return $fn_53351_hint__53000__auto__$jscomp$10$$($cause53352_p__53348_x$jscomp$1156$$,$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$)}catch($e53353$$){throw $cause53352_p__53348_x$jscomp$1156$$=$e53353$$,$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$)?$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$():
null,$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_53351_hint__53000__auto__$jscomp$10$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53351_hint__53000__auto__$jscomp$10$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_set_cursor_from_offset",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53351_hint__53000__auto__$jscomp$10$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$10_code_num__52998__auto__$jscomp$10_map__53350__$1_read_code_fn__52997__auto__$jscomp$10_y$jscomp$394$$],
null),$cause53352_p__53348_x$jscomp$1156$$);}}else return null};
$app$render_wasm$text_editor$text_editor_focus$$=function($buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$);
var $fn_53344$jscomp$inline_8182_hint__53000__auto__$jscomp$inline_8187$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_focus;try{var $JSCompiler_inline_result$jscomp$1550_cause53345$jscomp$inline_8183$$=$fn_53344$jscomp$inline_8182_hint__53000__auto__$jscomp$inline_8187$$($buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$[0],$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$[1],
$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$[2],$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$[3])}catch($e53346$jscomp$inline_8188$$){throw $JSCompiler_inline_result$jscomp$1550_cause53345$jscomp$inline_8183$$=$e53346$jscomp$inline_8188$$,$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$=$APP.$cljs$core$truth_$$($buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$)?$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$.$cljs$core$IFn$_invoke$arity$0$?
$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$.$cljs$core$IFn$_invoke$arity$0$():$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$():null,$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_53344$jscomp$inline_8182_hint__53000__auto__$jscomp$inline_8187$$=["WASM Error (",$APP.$app$common$data$name$$($buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53344$jscomp$inline_8182_hint__53000__auto__$jscomp$inline_8187$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_focus",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53344$jscomp$inline_8182_hint__53000__auto__$jscomp$inline_8187$$,$APP.$cljs$cst$273$code$$,$buffer$jscomp$66_code__52999__auto__$jscomp$inline_8186_code_num__52998__auto__$jscomp$inline_8185_id$jscomp$321_read_code_fn__52997__auto__$jscomp$inline_8184$$],
null),$JSCompiler_inline_result$jscomp$1550_cause53345$jscomp$inline_8183$$);}if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1550_cause53345$jscomp$inline_8183$$))return null;throw Error("TextEditor focus failed");}return null};
$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$=function($cause53143_ptr$jscomp$6$$){var $code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$=$APP.$app$render_wasm$wasm$internal_module$$.UTF8ToString;try{return $code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$($cause53143_ptr$jscomp$6$$)}catch($e53144$$){$cause53143_ptr$jscomp$6$$=$e53144$$;$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$)?$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$():null;$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$7$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$7$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"UTF8ToString",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$7$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$7_code_num__52998__auto__$jscomp$7_fn_53142_read_code_fn__52997__auto__$jscomp$7$$],null),$cause53143_ptr$jscomp$6$$);}};$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$=function($id$jscomp$330$$){$APP.$app$render_wasm$api$use_shape$$($id$jscomp$330$$);return $APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$00$$()};
$app$render_wasm$text_editor$text_editor_export_selection$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_export_selection;try{var $cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$=$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$()}catch($e53556$jscomp$inline_13158$$){$cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$=
$e53556$jscomp$inline_13158$$;$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$)?
$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$():
null;$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_13157$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_13157$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_export_selection",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$inline_13157$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_13156_code_num__52998__auto__$jscomp$inline_13155_fn_53554$jscomp$inline_13152_read_code_fn__52997__auto__$jscomp$inline_13154$$],null),$cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$);}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$)?$cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$!==0:$cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$))return $cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$=
$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$($cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$),$APP.$app$render_wasm$mem$free$$(),$cause53555$jscomp$inline_13153_ptr$jscomp$9_text$jscomp$34$$}return null};
$app$render_wasm$text_editor$text_editor_encode_text_pre$$=function($buf$jscomp$18_text$jscomp$29$$){if(!$APP.$cljs$core$empty_QMARK_$$($buf$jscomp$18_text$jscomp$29$$)&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$buf$jscomp$18_text$jscomp$29$$=(new TextEncoder).encode($buf$jscomp$18_text$jscomp$29$$);var $heapu8$jscomp$1$$=$APP.$app$render_wasm$mem$get_heap_u8$$(),$offset$jscomp$149$$=$APP.$app$render_wasm$mem$alloc$$($buf$jscomp$18_text$jscomp$29$$.byteLength);$APP.$app$render_wasm$mem$write_buffer$$($offset$jscomp$149$$,
$heapu8$jscomp$1$$,$buf$jscomp$18_text$jscomp$29$$)}};
$app$render_wasm$text_editor$text_editor_insert_text$$=function($cause53468_53726_text$jscomp$33$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$app$render_wasm$text_editor$text_editor_encode_text_pre$$($cause53468_53726_text$jscomp$33$$);var $code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_insert_text;try{$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$()}catch($e53472$$){$cause53468_53726_text$jscomp$33$$=$e53472$$;
$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$=$APP.$cljs$core$truth_$$($code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$)?$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$():null;$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___53730$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___53730$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_insert_text",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto___53730$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___53729_code_num__52998__auto___53728_fn_53467_53725_read_code_fn__52997__auto___53727$$],null),$cause53468_53726_text$jscomp$33$$);}!$APP.$cljs$core$empty_QMARK_$$($cause53468_53726_text$jscomp$33$$)&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$app$render_wasm$mem$free$$()}};
$app$main$data$workspace$transforms$get_handler_resize_origin$$=function($mx$jscomp$1_selrect$jscomp$60$$,$G__68922__$1_handler$jscomp$31$$){var $sx$jscomp$10$$=$mx$jscomp$1_selrect$jscomp$60$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$60$$,$APP.$cljs$cst$1510$x$$),$sy$jscomp$9$$=$mx$jscomp$1_selrect$jscomp$60$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$60$$,$APP.$cljs$cst$1511$y$$),$ex$jscomp$16_width$jscomp$136$$=
$mx$jscomp$1_selrect$jscomp$60$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$60$$,$APP.$cljs$cst$290$width$$),$ey$jscomp$1_height$jscomp$122$$=$mx$jscomp$1_selrect$jscomp$60$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$60$$,$APP.$cljs$cst$1522$height$$);$mx$jscomp$1_selrect$jscomp$60$$=$sx$jscomp$10$$+$ex$jscomp$16_width$jscomp$136$$/2;var $my$jscomp$1$$=$sy$jscomp$9$$+$ey$jscomp$1_height$jscomp$122$$/2;
$ex$jscomp$16_width$jscomp$136$$=$sx$jscomp$10$$+$ex$jscomp$16_width$jscomp$136$$;$ey$jscomp$1_height$jscomp$122$$=$sy$jscomp$9$$+$ey$jscomp$1_height$jscomp$122$$;$G__68922__$1_handler$jscomp$31$$=$G__68922__$1_handler$jscomp$31$$ instanceof $APP.$cljs$core$Keyword$$?$G__68922__$1_handler$jscomp$31$$.$fqn$:null;switch($G__68922__$1_handler$jscomp$31$$){case "right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($sx$jscomp$10$$,$my$jscomp$1$$);case "bottom":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$60$$,
$sy$jscomp$9$$);case "left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$16_width$jscomp$136$$,$my$jscomp$1$$);case "top":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$60$$,$ey$jscomp$1_height$jscomp$122$$);case "top-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($sx$jscomp$10$$,$ey$jscomp$1_height$jscomp$122$$);case "top-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$16_width$jscomp$136$$,
$ey$jscomp$1_height$jscomp$122$$);case "bottom-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($sx$jscomp$10$$,$sy$jscomp$9$$);case "bottom-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$16_width$jscomp$136$$,$sy$jscomp$9$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__68922__$1_handler$jscomp$31$$)].join(""));}};
$app$main$data$workspace$transforms$get_handler_multiplier$$=function($G__68916__$1_handler$jscomp$30$$){$G__68916__$1_handler$jscomp$30$$=$G__68916__$1_handler$jscomp$30$$ instanceof $APP.$cljs$core$Keyword$$?$G__68916__$1_handler$jscomp$30$$.$fqn$:null;switch($G__68916__$1_handler$jscomp$30$$){case "right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,0);case "bottom":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,1);case "left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,
0);case "top":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,-1);case "top-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1);case "top-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,-1);case "bottom-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,1);case "bottom-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__68916__$1_handler$jscomp$30$$)].join(""));}};
$app$common$types$shape$interactions$calc_overlay_pos_initial$$=function($dest_frame_destination$jscomp$9_overlay_size$$,$frame_size_orig_frame_shape$jscomp$158$$,$objects$jscomp$125$$,$overlay_pos_type$jscomp$3$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$3$$,$APP.$cljs$cst$1673$manual$$)&&$dest_frame_destination$jscomp$9_overlay_size$$!=null?($dest_frame_destination$jscomp$9_overlay_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$125$$,
$dest_frame_destination$jscomp$9_overlay_size$$),$dest_frame_destination$jscomp$9_overlay_size$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($dest_frame_destination$jscomp$9_overlay_size$$),$frame_size_orig_frame_shape$jscomp$158$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$158$$),$APP.$cljs$cst$1606$frame$$)?$frame_size_orig_frame_shape$jscomp$158$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$125$$,
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$158$$)),$frame_size_orig_frame_shape$jscomp$158$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$158$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$158$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_frame_destination$jscomp$9_overlay_size$$))/
2,($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$158$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($dest_frame_destination$jscomp$9_overlay_size$$))/2)):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0)};
$app$common$types$shape$interactions$set_destination$$=function($interaction$jscomp$6$$,$G__49023__$1_destination$jscomp$8$$){$G__49023__$1_destination$jscomp$8$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$6$$,$APP.$cljs$cst$1967$destination$$,$G__49023__$1_destination$jscomp$8$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$6$$),$APP.$cljs$cst$1946$open_overlay$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$6$$),$APP.$cljs$cst$1944$toggle_overlay$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49023__$1_destination$jscomp$8$$,$APP.$cljs$cst$1971$overlay_pos_type$$,$APP.$cljs$cst$1667$center$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1970$overlay_position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,
0)])):$G__49023__$1_destination$jscomp$8$$};
$app$common$types$shape$interactions$set_action_type$$=function($interaction$jscomp$1$$,$action_type$$){var $new_interaction$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$1$$),$action_type$$)?$interaction$jscomp$1$$:function(){var $G__49011__$1_overlay_pos_type$$=$action_type$$ instanceof $APP.$cljs$core$Keyword$$?$action_type$$.$fqn$:null;switch($G__49011__$1_overlay_pos_type$$){case "navigate":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1966$action_type$$,
$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1967$destination$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$1$$,$APP.$cljs$cst$1967$destination$$),$APP.$cljs$cst$1968$preserve_scroll$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,$APP.$cljs$cst$1968$preserve_scroll$$,!1)]));case "open-overlay":case "toggle-overlay":$G__49011__$1_overlay_pos_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,
$APP.$cljs$cst$1971$overlay_pos_type$$,$APP.$cljs$cst$1667$center$$);var $overlay_position$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,$APP.$cljs$cst$1970$overlay_position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1966$action_type$$,$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1971$overlay_pos_type$$,
$G__49011__$1_overlay_pos_type$$,$APP.$cljs$cst$1970$overlay_position$$,$overlay_position$$]));case "close-overlay":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1966$action_type$$,$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1967$destination$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$1$$,$APP.$cljs$cst$1967$destination$$)]));case "prev-screen":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,
$APP.$cljs$cst$1966$action_type$$,$action_type$$);case "open-url":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1966$action_type$$,$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1975$url$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,$APP.$cljs$cst$1975$url$$,"")]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__49011__$1_overlay_pos_type$$)].join(""));
}}();return $APP.$cljs$core$not$$(function(){var $G__49014$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($new_interaction$$));return $app$common$types$shape$interactions$allowed_animation_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$shape$interactions$allowed_animation_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($action_type$$,$G__49014$$):$app$common$types$shape$interactions$allowed_animation_QMARK_$$($action_type$$,
$G__49014$$)}())?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($new_interaction$$,$APP.$cljs$cst$1959$animation_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1969$animation$$])):$new_interaction$$};
$app$common$geom$shapes$distance_selrect$$=function($selrect$jscomp$25_y2$jscomp$34$$,$other$jscomp$185_y1$jscomp$36$$){var $x1$jscomp$34$$=$other$jscomp$185_y1$jscomp$36$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$185_y1$jscomp$36$$,$APP.$cljs$cst$1523$x1$$);$other$jscomp$185_y1$jscomp$36$$=$other$jscomp$185_y1$jscomp$36$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$185_y1$jscomp$36$$,$APP.$cljs$cst$1524$y1$$);var $x2$jscomp$32$$=$selrect$jscomp$25_y2$jscomp$34$$?.x2??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$25_y2$jscomp$34$$,$APP.$cljs$cst$1525$x2$$);$selrect$jscomp$25_y2$jscomp$34$$=$selrect$jscomp$25_y2$jscomp$34$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$25_y2$jscomp$34$$,$APP.$cljs$cst$1526$y2$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x1$jscomp$34$$-$x2$jscomp$32$$,$other$jscomp$185_y1$jscomp$36$$-$selrect$jscomp$25_y2$jscomp$34$$)};
$app$common$geom$shapes$intersect$intersects_lines_ellipse_QMARK_$$=function($rect_lines$jscomp$2$$,$p__48915_transform$jscomp$53$$){var $map__48916__$1$$=$APP.$cljs$core$__destructure_map$$($p__48915_transform$jscomp$53$$),$center$jscomp$22_cx$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48916__$1$$,$APP.$cljs$cst$1897$cx$$),$cy$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48916__$1$$,$APP.$cljs$cst$1898$cy$$);$p__48915_transform$jscomp$53$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48916__$1$$,$APP.$cljs$cst$1289$transform$$);$center$jscomp$22_cx$jscomp$12$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$22_cx$jscomp$12$$,$cy$jscomp$13$$);var $transform__$1$jscomp$2$$=$p__48915_transform$jscomp$53$$!=null?$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$22_cx$jscomp$12$$,$p__48915_transform$jscomp$53$$):null;return $APP.$cljs$core$some$$(function($p2$jscomp$44_p2__$1_p__48917$$){var $p1$jscomp$55_p1__$1$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$44_p2__$1_p__48917$$,0,null);$p2$jscomp$44_p2__$1_p__48917$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$44_p2__$1_p__48917$$,1,null);$p1$jscomp$55_p1__$1$jscomp$2$$=$transform__$1$jscomp$2$$!=null?$APP.$app$common$geom$point$transform$$($p1$jscomp$55_p1__$1$jscomp$2$$,$transform__$1$jscomp$2$$):$p1$jscomp$55_p1__$1$jscomp$2$$;$p2$jscomp$44_p2__$1_p__48917$$=$transform__$1$jscomp$2$$!=null?$APP.$app$common$geom$point$transform$$($p2$jscomp$44_p2__$1_p__48917$$,
$transform__$1$jscomp$2$$):$p2$jscomp$44_p2__$1_p__48917$$;return $app$common$geom$shapes$intersect$intersects_line_ellipse_QMARK_$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$55_p1__$1$jscomp$2$$,$p2$jscomp$44_p2__$1_p__48917$$],null),$map__48916__$1$$)},$rect_lines$jscomp$2$$)};
$app$common$types$path$get_handler$$=function($command$jscomp$18$$,$prefix$jscomp$42$$){return $APP.$app$common$types$path$segment$get_handler$$($command$jscomp$18$$,$prefix$jscomp$42$$)};
$app$common$types$path$segment$curve_closest_point$$=function($position$jscomp$7$$,$start$jscomp$205$$,$end$jscomp$70$$,$h1$jscomp$26$$,$h2$jscomp$20$$,$precision$jscomp$6$$){for(var $d$jscomp$226$$=$APP.$cljs$core$memoize$$(function($t$jscomp$85$$){return $APP.$app$common$geom$point$distance$$($position$jscomp$7$$,$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$205$$,$end$jscomp$70$$,$h1$jscomp$26$$,$h2$jscomp$20$$,$t$jscomp$85$$))}),$t1$jscomp$8_t1__$1$jscomp$1$$=
0,$G__48353_t2$jscomp$9_vec__48074$$=1;;){if($APP.$app$common$math$abs$$($t1$jscomp$8_t1__$1$jscomp$1$$-$G__48353_t2$jscomp$9_vec__48074$$)<=$precision$jscomp$6$$)return $APP.$cljs$core$with_meta$$($APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$205$$,$end$jscomp$70$$,$h1$jscomp$26$$,$h2$jscomp$20$$,$t1$jscomp$8_t1__$1$jscomp$1$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1852$t$$,$t1$jscomp$8_t1__$1$jscomp$1$$,$APP.$cljs$cst$1853$from_p$$,
$start$jscomp$205$$,$APP.$cljs$cst$1854$to_p$$,$end$jscomp$70$$],null));var $ht$jscomp$4$$=$t1$jscomp$8_t1__$1$jscomp$1$$+($G__48353_t2$jscomp$9_vec__48074$$-$t1$jscomp$8_t1__$1$jscomp$1$$)/2,$ht1$$=$t1$jscomp$8_t1__$1$jscomp$1$$+($G__48353_t2$jscomp$9_vec__48074$$-$t1$jscomp$8_t1__$1$jscomp$1$$)/4,$ht2$$=$t1$jscomp$8_t1__$1$jscomp$1$$+3*($G__48353_t2$jscomp$9_vec__48074$$-$t1$jscomp$8_t1__$1$jscomp$1$$)/4;$G__48353_t2$jscomp$9_vec__48074$$=$d$jscomp$226$$($ht1$$)<$d$jscomp$226$$($ht2$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$t1$jscomp$8_t1__$1$jscomp$1$$,$ht$jscomp$4$$],null):$d$jscomp$226$$($ht2$$)<$d$jscomp$226$$($ht1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ht$jscomp$4$$,$G__48353_t2$jscomp$9_vec__48074$$],null):$d$jscomp$226$$($ht$jscomp$4$$)<$d$jscomp$226$$($t1$jscomp$8_t1__$1$jscomp$1$$)&&$d$jscomp$226$$($ht$jscomp$4$$)<$d$jscomp$226$$($G__48353_t2$jscomp$9_vec__48074$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ht1$$,$ht2$$],null):$d$jscomp$226$$($t1$jscomp$8_t1__$1$jscomp$1$$)<$d$jscomp$226$$($G__48353_t2$jscomp$9_vec__48074$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$t1$jscomp$8_t1__$1$jscomp$1$$,$ht$jscomp$4$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ht$jscomp$4$$,$G__48353_t2$jscomp$9_vec__48074$$],null);$t1$jscomp$8_t1__$1$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48353_t2$jscomp$9_vec__48074$$,0,null);$G__48353_t2$jscomp$9_vec__48074$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48353_t2$jscomp$9_vec__48074$$,1,null)}};
$app$common$types$path$segment$path__GT_lines$$=function($G__48344_pending$jscomp$6_shape$jscomp$79$$){var $G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__48344_pending$jscomp$6_shape$jscomp$79$$));$G__48344_pending$jscomp$6_shape$jscomp$79$$=$APP.$cljs$core$rest$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__48344_pending$jscomp$6_shape$jscomp$79$$));for(var $result$jscomp$186$$=
$APP.$cljs$core$PersistentVector$EMPTY$$,$last_start$$=null,$prev_point$jscomp$2$$=null;;)if($APP.$cljs$core$truth_$$($G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$)){$G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$=$APP.$cljs$core$__destructure_map$$($G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$);var $command__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$,
$APP.$cljs$cst$1812$command$$),$params$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$,$APP.$cljs$cst$1430$params$$),$point$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1850$close_path$$,$command__$1$$)?$last_start$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$),$G__48345_result__$1$jscomp$19$$=function(){var $G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$=
$command__$1$$;switch($G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$ instanceof $APP.$cljs$core$Keyword$$?$G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$.$fqn$:null){case "line-to":return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$186$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$jscomp$2$$,$point$jscomp$26$$],null));case "curve-to":var $JSCompiler_inline_result$jscomp$10968_h1$jscomp$25$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$),
$APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$)),$h2$jscomp$19$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$),$APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$));$G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$10965$$=$result$jscomp$186$$;a:{for(var $start$jscomp$inline_13168$$=
$prev_point$jscomp$2$$,$end$jscomp$inline_13169$$=$point$jscomp$26$$,$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$=0,$G__47008$jscomp$inline_13177_result$jscomp$inline_13173$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $to$jscomp$inline_13174$$=Math.min(1,$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$+.1);$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$inline_13168$$,$end$jscomp$inline_13169$$,$JSCompiler_inline_result$jscomp$10968_h1$jscomp$25$$,$h2$jscomp$19$$,$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$),$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$inline_13168$$,$end$jscomp$inline_13169$$,$JSCompiler_inline_result$jscomp$10968_h1$jscomp$25$$,
$h2$jscomp$19$$,$to$jscomp$inline_13174$$)],null);$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47008$jscomp$inline_13177_result$jscomp$inline_13173$$,$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$);if($to$jscomp$inline_13174$$>=1){$JSCompiler_inline_result$jscomp$10968_h1$jscomp$25$$=$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$;
break a}$G__47008$jscomp$inline_13177_result$jscomp$inline_13173$$=$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$;$from$jscomp$inline_13172_line$jscomp$inline_13175_result__$1$jscomp$inline_13176$$=$to$jscomp$inline_13174$$}$JSCompiler_inline_result$jscomp$10968_h1$jscomp$25$$=void 0}return $G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$10965$$,$JSCompiler_inline_result$jscomp$10968_h1$jscomp$25$$);
case "move-to":return $G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$=$result$jscomp$186$$,$APP.$cljs$core$truth_$$($last_start$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$jscomp$2$$,$last_start$$],null)):$G__48044_G__48046_JSCompiler_temp_const$jscomp$10966$$;default:return $result$jscomp$186$$}}(),$G__48346_last_start__$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$command__$1$$)?$point$jscomp$26$$:$last_start$$;$G__48343_command$jscomp$10_map__48039__$1_temp__5823__auto__$jscomp$103$$=$APP.$cljs$core$first$$($G__48344_pending$jscomp$6_shape$jscomp$79$$);$G__48344_pending$jscomp$6_shape$jscomp$79$$=$APP.$cljs$core$rest$$($G__48344_pending$jscomp$6_shape$jscomp$79$$);var $G__48347$$=$point$jscomp$26$$;$result$jscomp$186$$=$G__48345_result__$1$jscomp$19$$;$last_start$$=$G__48346_last_start__$1$$;
$prev_point$jscomp$2$$=$G__48347$$}else return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$186$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$jscomp$2$$,$last_start$$],null))};
$app$common$types$path$segment$closest_point$$=function($content$jscomp$31$$,$position$jscomp$9$$,$precision$jscomp$7$$){return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__48094$$,$p__48095$$){var $min_p$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48094$$,0,null),$min_dist$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48094$$,1,null),$cur_p$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48095$$,
0,null),$cur_dist$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48095$$,1,null);return $p__48094$$!=null&&($APP.$cljs$core$not$$($p__48095$$)||$min_dist$$<=$cur_dist$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$min_p$$,$min_dist$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cur_p$$,$cur_dist$$],null)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__48087_point$jscomp$27_prev_segment$$){var $cur_segment$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48087_point$jscomp$27_prev_segment$$,0,null);$p__48087_point$jscomp$27_prev_segment$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48087_point$jscomp$27_prev_segment$$,1,null);var $from_p$jscomp$9$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($p__48087_point$jscomp$27_prev_segment$$),$to_p$jscomp$8$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment$jscomp$1$$),
$h1$jscomp$27$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1815$c1x$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,
$APP.$cljs$cst$1816$c1y$$],null))),$h2$jscomp$21$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1817$c2x$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1818$c2y$$],null)));$p__48087_point$jscomp$27_prev_segment$$=function(){var $G__48093_e1$jscomp$inline_8197$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment$jscomp$1$$);switch($G__48093_e1$jscomp$inline_8197$$ instanceof $APP.$cljs$core$Keyword$$?$G__48093_e1$jscomp$inline_8197$$.$fqn$:null){case "line-to":$G__48093_e1$jscomp$inline_8197$$=$APP.$app$common$geom$point$subtract$$($to_p$jscomp$8$$,$from_p$jscomp$9$$);var $e2$jscomp$inline_8198_t$jscomp$inline_8200$$=
$APP.$app$common$geom$point$subtract$$($position$jscomp$9$$,$from_p$jscomp$9$$),$len2$jscomp$inline_8199$$=$app$common$math$sq$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__48093_e1$jscomp$inline_8197$$))+$app$common$math$sq$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__48093_e1$jscomp$inline_8197$$));$e2$jscomp$inline_8198_t$jscomp$inline_8200$$=$APP.$app$common$geom$point$dot$$($G__48093_e1$jscomp$inline_8197$$,$e2$jscomp$inline_8198_t$jscomp$inline_8200$$)/$len2$jscomp$inline_8199$$;
return $e2$jscomp$inline_8198_t$jscomp$inline_8200$$>=0&&$e2$jscomp$inline_8198_t$jscomp$inline_8200$$<=1&&!$APP.$app$common$math$almost_zero_QMARK_$$($len2$jscomp$inline_8199$$)?$APP.$cljs$core$with_meta$$($APP.$app$common$geom$point$add$$($from_p$jscomp$9$$,$APP.$app$common$geom$point$scale$$($G__48093_e1$jscomp$inline_8197$$,$e2$jscomp$inline_8198_t$jscomp$inline_8200$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1852$t$$,$e2$jscomp$inline_8198_t$jscomp$inline_8200$$,$APP.$cljs$cst$1853$from_p$$,
$from_p$jscomp$9$$,$APP.$cljs$cst$1854$to_p$$,$to_p$jscomp$8$$],null)):$APP.$app$common$geom$point$distance$$($position$jscomp$9$$,$from_p$jscomp$9$$)<=$APP.$app$common$geom$point$distance$$($position$jscomp$9$$,$to_p$jscomp$8$$)?$from_p$jscomp$9$$:$to_p$jscomp$8$$;case "curve-to":return $app$common$types$path$segment$curve_closest_point$$($position$jscomp$9$$,$from_p$jscomp$9$$,$to_p$jscomp$8$$,$h1$jscomp$27$$,$h2$jscomp$21$$,$precision$jscomp$7$$);default:return null}}();return $APP.$cljs$core$truth_$$($p__48087_point$jscomp$27_prev_segment$$)?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__48087_point$jscomp$27_prev_segment$$,$APP.$app$common$geom$point$distance$$($p__48087_point$jscomp$27_prev_segment$$,$position$jscomp$9$$)],null):null},$APP.$app$common$data$with_prev$$($content$jscomp$31$$))))};
$app$util$dom$get_delta_position$$=function($e$jscomp$247_event$jscomp$32$$){$e$jscomp$247_event$jscomp$32$$=$e$jscomp$247_event$jscomp$32$$ instanceof $APP.$goog$events$BrowserEvent$$?$APP.$cljs$core$_deref$$($e$jscomp$247_event$jscomp$32$$):$e$jscomp$247_event$jscomp$32$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$247_event$jscomp$32$$.deltaX,$e$jscomp$247_event$jscomp$32$$.deltaY)};
$app$common$geom$shapes$has_point_rect_QMARK_$$=function($h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$,$param49305$$){var $lines$jscomp$inline_8204_x$jscomp$inline_13180$$=$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$inline_13181$$=$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$,
$APP.$cljs$cst$1511$y$$),$w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$=$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$,$APP.$cljs$cst$290$width$$);$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$=$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$,
$APP.$cljs$cst$1522$height$$);$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$,$y$jscomp$inline_13181$$)?($w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$=Math.max($w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$,.01),$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$=Math.max($h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$,.01),$lines$jscomp$inline_8204_x$jscomp$inline_13180$$=new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$,$y$jscomp$inline_13181$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$+$w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$,$y$jscomp$inline_13181$$)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$+$w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$,$y$jscomp$inline_13181$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$+$w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$,$y$jscomp$inline_13181$$+$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$+$w$jscomp$inline_13182_w__$1$jscomp$inline_13184$$,$y$jscomp$inline_13181$$+$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$,$y$jscomp$inline_13181$$+
$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$,$y$jscomp$inline_13181$$+$h$jscomp$inline_13183_h__$1$jscomp$inline_13185_param49304$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8204_x$jscomp$inline_13180$$,$y$jscomp$inline_13181$$)],
null)],null)):$lines$jscomp$inline_8204_x$jscomp$inline_13180$$=null;return $APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($param49305$$,$lines$jscomp$inline_8204_x$jscomp$inline_13180$$)};
$app$main$data$helpers$get_selrect$$=function($center$jscomp$29_selrect_transform$$,$shape$jscomp$149_width$jscomp$71$$){if($center$jscomp$29_selrect_transform$$!=null){var $map__49389__$1_transform$jscomp$57$$=$APP.$cljs$core$__destructure_map$$($center$jscomp$29_selrect_transform$$);$center$jscomp$29_selrect_transform$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49389__$1_transform$jscomp$57$$,$APP.$cljs$cst$1667$center$$);$shape$jscomp$149_width$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49389__$1_transform$jscomp$57$$,
$APP.$cljs$cst$290$width$$);var $height$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49389__$1_transform$jscomp$57$$,$APP.$cljs$cst$1522$height$$);$map__49389__$1_transform$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49389__$1_transform$jscomp$57$$,$APP.$cljs$cst$1289$transform$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$center__GT_rect$$.$cljs$core$IFn$_invoke$arity$3$($center$jscomp$29_selrect_transform$$,
$shape$jscomp$149_width$jscomp$71$$,$height$jscomp$64$$),$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$29_selrect_transform$$,$map__49389__$1_transform$jscomp$57$$)],null)}return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$149_width$jscomp$71$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$149_width$jscomp$71$$,$APP.$cljs$cst$1605$selrect$$),$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$149_width$jscomp$71$$)],
null)};
$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$=function($rect$jscomp$13_rect_points$$,$points$jscomp$44$$){$rect$jscomp$13_rect_points$$=$APP.$app$common$geom$rect$rect__GT_points$$($rect$jscomp$13_rect_points$$);var $rect_lines$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($rect$jscomp$13_rect_points$$),$points_lines$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$44$$);return $APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($APP.$cljs$core$first$$($rect$jscomp$13_rect_points$$),
$points_lines$$)||$APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($APP.$cljs$core$first$$($points$jscomp$44$$),$rect_lines$$)||$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$($rect_lines$$,$points_lines$$)};
$app$common$geom$point$normal_right$$=function($p__45832_x$jscomp$1050$$){var $map__45835__$1_y$jscomp$316$$=$APP.$cljs$core$__destructure_map$$($p__45832_x$jscomp$1050$$);$p__45832_x$jscomp$1050$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45835__$1_y$jscomp$316$$,$APP.$cljs$cst$1510$x$$);$map__45835__$1_y$jscomp$316$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45835__$1_y$jscomp$316$$,$APP.$cljs$cst$1511$y$$);return $APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($map__45835__$1_y$jscomp$316$$,
-$p__45832_x$jscomp$1050$$))};
$app$main$data$persistence$discard_commit$$=function($commit_id$jscomp$2$$){typeof $app$main$data$persistence$discard_commit_55307$$==="undefined"&&($app$main$data$persistence$discard_commit_55307$$=function($commit_id$jscomp$3$$,$meta55308$$){this.$commit_id$=$commit_id$jscomp$3$$;this.$meta55308$=$meta55308$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$discard_commit_55307$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$discard_commit_55307$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3153$app_DOT_main_DOT_data_DOT_persistence_SLASH_discard_commit$$},$app$main$data$persistence$discard_commit_55307$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55309$$,$meta55308__$1$$){return new $app$main$data$persistence$discard_commit_55307$$(this.$commit_id$,$meta55308__$1$$)},$app$main$data$persistence$discard_commit_55307$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55308$},$app$main$data$persistence$discard_commit_55307$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$discard_commit_55307$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1653$$,$state$jscomp$186$$){var $self__$jscomp$3515$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$186$$,$APP.$cljs$cst$2178$persistence$$,function($pstate$jscomp$1$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($pstate$jscomp$1$$,
$APP.$cljs$cst$1484$queue$$,function($queue$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3515$$.$commit_id$,$APP.$cljs$core$peek$$($queue$$)))return $APP.$cljs$core$pop$$($queue$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("invalid state",$APP.$cljs$core$PersistentArrayMap$EMPTY$$);}),$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$dissoc$$,$self__$jscomp$3515$$.$commit_id$)})});return new $app$main$data$persistence$discard_commit_55307$$($commit_id$jscomp$2$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$color$interpolate_color$$=function($a1$jscomp$6_c1$jscomp$22$$,$a2$jscomp$2_c2$jscomp$13$$,$offset$jscomp$95$$){if($offset$jscomp$95$$<=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($a1$jscomp$6_c1$jscomp$22$$,$APP.$cljs$cst$195$offset$$,$offset$jscomp$95$$);if($offset$jscomp$95$$>=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($a2$jscomp$2_c2$jscomp$13$$,$APP.$cljs$cst$195$offset$$,
$offset$jscomp$95$$);var $a$jscomp$349_tr_offset$$=($offset$jscomp$95$$-$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$))/($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$)-$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$)),$b$jscomp$280_b1$jscomp$2_vec__45539$$=$APP.$app$common$types$color$hex__GT_rgb$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$)),
$r$jscomp$95_r1$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$280_b1$jscomp$2_vec__45539$$,0,null),$g$jscomp$132_g1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$280_b1$jscomp$2_vec__45539$$,1,null);$b$jscomp$280_b1$jscomp$2_vec__45539$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$280_b1$jscomp$2_vec__45539$$,2,null);var $b2_vec__45542$$=$APP.$app$common$types$color$hex__GT_rgb$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$)),
$r2$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b2_vec__45542$$,0,null),$g2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b2_vec__45542$$,1,null);$b2_vec__45542$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b2_vec__45542$$,2,null);$a1$jscomp$6_c1$jscomp$22$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$);$a2$jscomp$2_c2$jscomp$13$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$);
$r$jscomp$95_r1$jscomp$12$$+=($r2$jscomp$11$$-$r$jscomp$95_r1$jscomp$12$$)*$a$jscomp$349_tr_offset$$;$g$jscomp$132_g1$$+=($g2$$-$g$jscomp$132_g1$$)*$a$jscomp$349_tr_offset$$;$b$jscomp$280_b1$jscomp$2_vec__45539$$+=($b2_vec__45542$$-$b$jscomp$280_b1$jscomp$2_vec__45539$$)*$a$jscomp$349_tr_offset$$;$a$jscomp$349_tr_offset$$=$a1$jscomp$6_c1$jscomp$22$$+($a2$jscomp$2_c2$jscomp$13$$-$a1$jscomp$6_c1$jscomp$22$$)*$a$jscomp$349_tr_offset$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1298$color$$,
$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$95_r1$jscomp$12$$,$g$jscomp$132_g1$$,$b$jscomp$280_b1$jscomp$2_vec__45539$$],null)),$APP.$cljs$cst$1734$opacity$$,$a$jscomp$349_tr_offset$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$95_r1$jscomp$12$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$132_g1$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$280_b1$jscomp$2_vec__45539$$,$APP.$cljs$cst$746$alpha$$,$a$jscomp$349_tr_offset$$,$APP.$cljs$cst$195$offset$$,
$offset$jscomp$95$$],null)};
$app$common$types$color$interpolate_gradient$$=function($end$jscomp$54_stops$jscomp$1$$,$offset$jscomp$97$$){var $idx$jscomp$73$$=$APP.$app$common$data$index_of_pred$$($end$jscomp$54_stops$jscomp$1$$,function($p1__45560_SHARP_$$){return $offset$jscomp$97$$<=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($p1__45560_SHARP_$$)}),$start$jscomp$188$$=$idx$jscomp$73$$==null?$APP.$cljs$core$last$$($end$jscomp$54_stops$jscomp$1$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$73$$,0)?
$APP.$cljs$core$first$$($end$jscomp$54_stops$jscomp$1$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$54_stops$jscomp$1$$,$idx$jscomp$73$$-1);$end$jscomp$54_stops$jscomp$1$$=$idx$jscomp$73$$==null?$APP.$cljs$core$last$$($end$jscomp$54_stops$jscomp$1$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$54_stops$jscomp$1$$,$idx$jscomp$73$$);return $app$common$types$color$interpolate_color$$($start$jscomp$188$$,$end$jscomp$54_stops$jscomp$1$$,$offset$jscomp$97$$)};
$app$main$data$workspace$colors$update_colorpicker_add_stop$$=function($offset$jscomp$174$$){typeof $app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$=function($offset$jscomp$175$$,$meta70982$$){this.offset=$offset$jscomp$175$$;this.$meta70982$=$meta70982$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4177$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_stop$$},$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70983$$,$meta70982__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$(this.offset,
$meta70982__$1$$)},$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70982$},$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2265$$,$state$jscomp$652$$){var $self__$jscomp$5295$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$652$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$34$$){var $stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$=$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$34$$);if(!$APP.$app$main$features$active_feature_QMARK_$$($state__$1$jscomp$34$$,"render-wasm/v1")||$APP.$cljs$core$count$$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$)<16){var $new_stop$jscomp$1$$=
$app$main$data$workspace$colors$split_color_components$$($app$common$types$color$interpolate_gradient$$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,$self__$jscomp$5295$$.offset));$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,$new_stop$jscomp$1$$);$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$));var $editing_stop$jscomp$1$$=$APP.$app$common$data$index_of_pred$$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,function($p1__70980_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_stop$jscomp$1$$,$p1__70980_SHARP_$$)});return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$34$$,
$APP.$cljs$cst$4162$editing_stop$$,$editing_stop$jscomp$1$$),$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,$editing_stop$jscomp$1$$)),$APP.$cljs$cst$1733$stops$$,$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$)}return $state__$1$jscomp$34$$})});return new $app$main$data$workspace$colors$update_colorpicker_add_stop_70981$$($offset$jscomp$174$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$color$uniform_spread_QMARK_$$=function($stops$$){var $cs$jscomp$2_expect_vals$$=$APP.$cljs$core$count$$($stops$$),$from$jscomp$10$$=$APP.$cljs$core$first$$($stops$$),$to$jscomp$9$$=$APP.$cljs$core$last$$($stops$$);$cs$jscomp$2_expect_vals$$=$app$common$types$color$offset_spread$$($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$10$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$9$$),$cs$jscomp$2_expect_vals$$);return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($ec_expected_offset$$,$stop$$){var $and__5023__auto__$jscomp$226$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($stop$$),$ec_expected_offset$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$226$$)?($ec_expected_offset$$=$app$common$types$color$interpolate_color$$($from$jscomp$10$$,$to$jscomp$9$$,$ec_expected_offset$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($ec_expected_offset$$),
$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($stop$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($ec_expected_offset$$),$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($stop$$))):$and__5023__auto__$jscomp$226$$},$cs$jscomp$2_expect_vals$$,$stops$$))};$app$common$types$color$hsv__GT_hex$$=function($hsv$$){return $APP.$app$common$types$color$rgb__GT_hex$$($app$common$types$color$hsv__GT_rgb$$($hsv$$))};
$cljs$tools$reader$resolve_symbol$$=function($s$jscomp$174$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("resolve-symbol is not implemented",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$242$sym$$,$s$jscomp$174$$],null));};
$cljs$tools$reader$register_gensym$$=function($sym$jscomp$18$$){if($APP.$cljs$core$not$$($cljs$tools$reader$gensym_env$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Gensym literal not in syntax-quote",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));var $gs_or__5025__auto__$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$tools$reader$gensym_env$$,$sym$jscomp$18$$);if($APP.$cljs$core$truth_$$($gs_or__5025__auto__$jscomp$58$$))return $gs_or__5025__auto__$jscomp$58$$;
$gs_or__5025__auto__$jscomp$58$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$name$$($sym$jscomp$18$$),0,$APP.$cljs$core$name$$($sym$jscomp$18$$).length-1),"__",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$tools$reader$impl$utils$last_id$$,$APP.$cljs$core$inc$$)),"__auto__"].join(""));$cljs$tools$reader$gensym_env$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$tools$reader$gensym_env$$,
$sym$jscomp$18$$,$gs_or__5025__auto__$jscomp$58$$);return $gs_or__5025__auto__$jscomp$58$$};
$cljs$tools$reader$register_arg$$=function($n$jscomp$175$$){if($APP.$cljs$core$truth_$$($cljs$tools$reader$arg_env$$)){var $g$jscomp$81_temp__5823__auto__$jscomp$24$$=$cljs$tools$reader$arg_env$$.call(null,$n$jscomp$175$$);if($APP.$cljs$core$truth_$$($g$jscomp$81_temp__5823__auto__$jscomp$24$$))return $g$jscomp$81_temp__5823__auto__$jscomp$24$$;$g$jscomp$81_temp__5823__auto__$jscomp$24$$=$cljs$tools$reader$garg$$($n$jscomp$175$$);$cljs$tools$reader$arg_env$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$tools$reader$arg_env$$,
$n$jscomp$175$$,$g$jscomp$81_temp__5823__auto__$jscomp$24$$);return $g$jscomp$81_temp__5823__auto__$jscomp$24$$}throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Arg literal not in #()",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));};
$cljs$tools$reader$check_eof_error$$=function($and__5023__auto__$jscomp$inline_8221_form$jscomp$11$$,$rdr$jscomp$76$$,$first_line$$){$and__5023__auto__$jscomp$inline_8221_form$jscomp$11$$===$cljs$tools$reader$READ_EOF$$&&($and__5023__auto__$jscomp$inline_8221_form$jscomp$11$$=$first_line$$<0,$APP.$cljs$tools$reader$impl$errors$throw_eof_error$$($rdr$jscomp$76$$,$and__5023__auto__$jscomp$inline_8221_form$jscomp$11$$?$first_line$$:$and__5023__auto__$jscomp$inline_8221_form$jscomp$11$$))};
$cljs$tools$reader$read_regex$$=function($rdr$jscomp$56$$){for(var $sb$jscomp$12$$=new $APP.$goog$string$StringBuffer$$,$ch_25006__$2_ch__$1$jscomp$2$$=$rdr$jscomp$56$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;){if('"'===$ch_25006__$2_ch__$1$jscomp$2$$)return $APP.$cljs$core$re_pattern$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$12$$));if($ch_25006__$2_ch__$1$jscomp$2$$==null)return $APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$56$$,
$APP.$cljs$cst$214$regex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$sb$jscomp$12$$]));$sb$jscomp$12$$.append($ch_25006__$2_ch__$1$jscomp$2$$);"\\"===$ch_25006__$2_ch__$1$jscomp$2$$&&($ch_25006__$2_ch__$1$jscomp$2$$=$rdr$jscomp$56$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),$ch_25006__$2_ch__$1$jscomp$2$$==null&&$APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$56$$,$APP.$cljs$cst$214$regex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$sb$jscomp$12$$])),
$sb$jscomp$12$$.append($ch_25006__$2_ch__$1$jscomp$2$$));$ch_25006__$2_ch__$1$jscomp$2$$=$rdr$jscomp$56$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null)}};
$cljs$tools$reader$read_token$$=function($rdr$jscomp$53$$,$ch$jscomp$26_kind$jscomp$11$$,$initch$jscomp$1$$){if($initch$jscomp$1$$==null)return $APP.$cljs$tools$reader$impl$errors$throw_eof_at_start$$($rdr$jscomp$53$$,$ch$jscomp$26_kind$jscomp$11$$);$APP.$cljs$tools$reader$sb$$.clear();for($ch$jscomp$26_kind$jscomp$11$$=$initch$jscomp$1$$;;){if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$26_kind$jscomp$11$$)||$cljs$tools$reader$macro_terminating_QMARK_$$($ch$jscomp$26_kind$jscomp$11$$)||
$ch$jscomp$26_kind$jscomp$11$$==null)return $ch$jscomp$26_kind$jscomp$11$$!=null&&$rdr$jscomp$53$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$(null,$ch$jscomp$26_kind$jscomp$11$$),$APP.$cljs$tools$reader$sb$$.toString();$APP.$cljs$tools$reader$sb$$.append($ch$jscomp$26_kind$jscomp$11$$);$ch$jscomp$26_kind$jscomp$11$$=$rdr$jscomp$53$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null)}};
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$=function($token$jscomp$19$$,$l$jscomp$74_length$jscomp$26$$,$base$jscomp$9$$){$l$jscomp$74_length$jscomp$26$$=1+$l$jscomp$74_length$jscomp$26$$;$APP.$cljs$core$count$$($token$jscomp$19$$)!==$l$jscomp$74_length$jscomp$26$$&&$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_literal$$($token$jscomp$19$$);for(var $i$jscomp$287$$=1,$G__25013_uc$$=0;;){if($i$jscomp$287$$===$l$jscomp$74_length$jscomp$26$$)return String.fromCharCode($G__25013_uc$$);
var $d$jscomp$101$$=$APP.$cljs$tools$reader$impl$utils$char_code$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$19$$,$i$jscomp$287$$),$base$jscomp$9$$);if($d$jscomp$101$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit_in_token$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$19$$,$i$jscomp$287$$),$token$jscomp$19$$);$G__25013_uc$$=$d$jscomp$101$$+$G__25013_uc$$*$base$jscomp$9$$;$i$jscomp$287$$+=1}};
$cljs$tools$reader$read_char_STAR_$$=function($rdr$jscomp$58$$){var $c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$=$rdr$jscomp$58$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$!=null){$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$=$cljs$tools$reader$macro_terminating_QMARK_$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$)||$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$)?
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$):$cljs$tools$reader$read_token$$($rdr$jscomp$58$$,$APP.$cljs$cst$215$character$$,$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$);var $ic_len$jscomp$54_token_len_uc$jscomp$2$$=$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$.length;if(1===$ic_len$jscomp$54_token_len_uc$jscomp$2$$)return $c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$.charAt(0);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"newline"))return"\n";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"space"))return" ";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"tab"))return"\t";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,
"backspace"))return"\b";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"formfeed"))return"\f";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"return"))return"\r";if($APP.$cljs$core$truth_$$($APP.$goog$string$internal$startsWith$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"u")))return $c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$=
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,4,16),$ic_len$jscomp$54_token_len_uc$jscomp$2$$=$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$.charCodeAt(0),$ic_len$jscomp$54_token_len_uc$jscomp$2$$>55295&&$ic_len$jscomp$54_token_len_uc$jscomp$2$$<57344?$APP.$cljs$tools$reader$impl$errors$throw_invalid_character_literal$$($rdr$jscomp$58$$,$ic_len$jscomp$54_token_len_uc$jscomp$2$$.toString(16)):
$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$;if($APP.$cljs$core$truth_$$($APP.$goog$string$internal$startsWith$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"o"))){--$ic_len$jscomp$54_token_len_uc$jscomp$2$$;if($ic_len$jscomp$54_token_len_uc$jscomp$2$$>3)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_octal_len$$($rdr$jscomp$58$$,$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$);$ic_len$jscomp$54_token_len_uc$jscomp$2$$=
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,$ic_len$jscomp$54_token_len_uc$jscomp$2$$,8);$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,1);return parseInt($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,8)<=255?$ic_len$jscomp$54_token_len_uc$jscomp$2$$:
$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$($rdr$jscomp$58$$)}return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$58$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unsupported character: ",$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8223$$,"."]))}return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$58$$)};
$cljs$tools$reader$read_unmatched_delimiter$$=function($rdr$jscomp$55$$,$ch$jscomp$28$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$55$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unmatched delimiter ",$ch$jscomp$28$$,"."]))};
$cljs$tools$reader$read_keyword$$=function($reader$jscomp$35$$){var $ch$jscomp$35_token$jscomp$23$$=$reader$jscomp$35$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$35_token$jscomp$23$$))return $APP.$cljs$tools$reader$impl$errors$throw_single_colon$$($reader$jscomp$35$$);$ch$jscomp$35_token$jscomp$23$$=$cljs$tools$reader$read_token$$($reader$jscomp$35$$,$APP.$cljs$cst$221$keyword$$,$ch$jscomp$35_token$jscomp$23$$);
var $name$jscomp$121_s$jscomp$171$$=$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($ch$jscomp$35_token$jscomp$23$$);if($name$jscomp$121_s$jscomp$171$$!=null){var $ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$=$name$jscomp$121_s$jscomp$171$$.$cljs$core$IIndexed$_nth$arity$2$(null,0);$name$jscomp$121_s$jscomp$171$$=$name$jscomp$121_s$jscomp$171$$.$cljs$core$IIndexed$_nth$arity$2$(null,1);if(":"===$ch$jscomp$35_token$jscomp$23$$.charAt(0)){if($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$!=
null)return $ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$,1)),$ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(null,$ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$),$APP.$cljs$core$truth_$$($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$)?
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$),$name$jscomp$121_s$jscomp$171$$):$APP.$cljs$tools$reader$impl$errors$throw_invalid$$($reader$jscomp$35$$,$APP.$cljs$cst$221$keyword$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$35_token$jscomp$23$$)].join(""));$ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$=null;return $APP.$cljs$core$truth_$$($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$)?
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$121_s$jscomp$171$$,1)):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($reader$jscomp$35$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid token: :",$ch$jscomp$35_token$jscomp$23$$]))}return $APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$19_sym$jscomp$inline_13187_temp__5823__auto__$jscomp$22$$,
$name$jscomp$121_s$jscomp$171$$)}return $APP.$cljs$tools$reader$impl$errors$throw_invalid$$($reader$jscomp$35$$,$APP.$cljs$cst$221$keyword$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$35_token$jscomp$23$$)].join(""))};
$cljs$tools$reader$read_symbol$$=function($end_line$jscomp$inline_8232_rdr$jscomp$69$$,$JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$){var $column$jscomp$7_vec__24703$$=$cljs$tools$reader$starting_line_col_info$$($end_line$jscomp$inline_8232_rdr$jscomp$69$$),$JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$7_vec__24703$$,0,null);$column$jscomp$7_vec__24703$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$7_vec__24703$$,
1,null);$JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$=$cljs$tools$reader$read_token$$($end_line$jscomp$inline_8232_rdr$jscomp$69$$,$APP.$cljs$cst$219$symbol$$,$JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$);if($JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$==null)return null;switch($JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$){case "nil":return null;case "true":return!0;case "false":return!1;case "/":return $APP.$cljs$cst$220$_SLASH_$$;
default:var $JSCompiler_temp_const$jscomp$1527_p$jscomp$39$$=$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$);if($JSCompiler_temp_const$jscomp$1527_p$jscomp$39$$!=null){$JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1527_p$jscomp$39$$.$cljs$core$IIndexed$_nth$arity$2$(null,0),$JSCompiler_temp_const$jscomp$1527_p$jscomp$39$$.$cljs$core$IIndexed$_nth$arity$2$(null,
1));$JSCompiler_temp_const$jscomp$1527_p$jscomp$39$$=$JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$.$cljs$core$IWithMeta$_with_meta$arity$2$;if($JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$==null)$JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$=null;else{var $file$jscomp$inline_8229_filem$jscomp$inline_8230$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($end_line$jscomp$inline_8232_rdr$jscomp$69$$);
$file$jscomp$inline_8229_filem$jscomp$inline_8230$$=$file$jscomp$inline_8229_filem$jscomp$inline_8230$$==null?null:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$file$jscomp$inline_8229_filem$jscomp$inline_8230$$],null);var $end_column$jscomp$inline_8233_vec__24696$jscomp$inline_8231$$=$cljs$tools$reader$ending_line_col_info$$($end_line$jscomp$inline_8232_rdr$jscomp$69$$);$end_line$jscomp$inline_8232_rdr$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$inline_8233_vec__24696$jscomp$inline_8231$$,
0,null);$end_column$jscomp$inline_8233_vec__24696$jscomp$inline_8231$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$inline_8233_vec__24696$jscomp$inline_8231$$,1,null);$JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file$jscomp$inline_8229_filem$jscomp$inline_8230$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$209$line$$,$JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$,$APP.$cljs$cst$216$column$$,$column$jscomp$7_vec__24703$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$inline_8232_rdr$jscomp$69$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$inline_8233_vec__24696$jscomp$inline_8231$$],null)]))}$JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$=$JSCompiler_temp_const$jscomp$1527_p$jscomp$39$$.call($JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$,
null,$JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$)}else $JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$=$APP.$cljs$tools$reader$impl$errors$throw_invalid$$($end_line$jscomp$inline_8232_rdr$jscomp$69$$,$APP.$cljs$cst$219$symbol$$,$JSCompiler_temp_const$jscomp$1528_initch$jscomp$4_token$jscomp$22$$);return $JSCompiler_inline_result$jscomp$1529_JSCompiler_temp$jscomp$1526_line$jscomp$17$$}};
$app$main$data$exports$assets$show_workspace_export_frames_dialog$$=function($frames$jscomp$17$$){typeof $app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$==="undefined"&&($app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$=function($frames$jscomp$18$$,$meta72445$$){this.frames=$frames$jscomp$18$$;this.$meta72445$=$meta72445$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4759$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_workspace_export_frames_dialog$$},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72446$$,$meta72445__$1$$){return new $app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$(this.frames,
$meta72445__$1$$)},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72445$},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2695_page$jscomp$111_page_name$jscomp$3$$,
$exports__$1$jscomp$6_state$jscomp$1009$$){var $file_id$jscomp$315$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($exports__$1$jscomp$6_state$jscomp$1009$$),$page_id$jscomp$341$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($exports__$1$jscomp$6_state$jscomp$1009$$);$_$jscomp$2695_page$jscomp$111_page_name$jscomp$3$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($exports__$1$jscomp$6_state$jscomp$1009$$);$_$jscomp$2695_page$jscomp$111_page_name$jscomp$3$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2695_page$jscomp$111_page_name$jscomp$3$$);$exports__$1$jscomp$6_state$jscomp$1009$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($frame$jscomp$40$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3109$enabled$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$341$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$315$$,$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$40$$),
$APP.$cljs$cst$1811$shape$$,$frame$jscomp$40$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$40$$)],null)},this.frames);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4760$export_frames$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1870$exports$$,$exports__$1$jscomp$6_state$jscomp$1009$$,$APP.$cljs$cst$1786$origin$$,"workspace:menu",$APP.$cljs$cst$725$name$$,
$_$jscomp$2695_page$jscomp$111_page_name$jscomp$3$$],null)))});return new $app$main$data$exports$assets$show_workspace_export_frames_dialog_72444$$($frames$jscomp$17$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$sort_colorpicker_stops$$=function(){typeof $app$main$data$workspace$colors$sort_colorpicker_stops_70996$$==="undefined"&&($app$main$data$workspace$colors$sort_colorpicker_stops_70996$$=function($meta70997$$){this.$meta70997$=$meta70997$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4181$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_sort_colorpicker_stops$$},$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70998$$,$meta70997__$1$$){return new $app$main$data$workspace$colors$sort_colorpicker_stops_70996$$($meta70997__$1$$)},$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70997$},
$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$sort_colorpicker_stops_70996$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2267$$,$state$jscomp$654$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$654$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$36$$){var $stop$jscomp$5_stops__$1$jscomp$5$$=function(){var $or__5025__auto__$jscomp$815$$=
$APP.$cljs$cst$4162$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$815$$)?$or__5025__auto__$jscomp$815$$:0}(),$stop__$1_stops$jscomp$14$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$36$$)),$stop_val$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stop__$1_stops$jscomp$14$$,
$stop$jscomp$5_stops__$1$jscomp$5$$);$stop$jscomp$5_stops__$1$jscomp$5$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stop__$1_stops$jscomp$14$$));$stop__$1_stops$jscomp$14$$=$APP.$app$common$data$index_of_pred$$($stop$jscomp$5_stops__$1$jscomp$5$$,function($p1__70995_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__70995_SHARP_$$,$stop_val$$)});
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$36$$,$APP.$cljs$cst$4162$editing_stop$$,$stop__$1_stops$jscomp$14$$),$APP.$cljs$cst$1733$stops$$,$stop$jscomp$5_stops__$1$jscomp$5$$)})});return new $app$main$data$workspace$colors$sort_colorpicker_stops_70996$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$text$fix_gradients$$=function($data$jscomp$368$$){function $update_fill$$($fill$jscomp$15$$){return $APP.$app$common$data$update_in_when$$($fill$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$139$type$$],null),$fix_type$$)}function $fix_type$$($type$jscomp$483$$){return typeof $type$jscomp$483$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$483$$):
$type$jscomp$483$$}return $APP.$app$common$data$update_when$$($data$jscomp$368$$,$APP.$cljs$cst$1634$fills$$,function($fills$jscomp$22$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($update_fill$$,$fills$jscomp$22$$)})};
$app$common$text$build_style_index$$=function($G__68810_length$jscomp$48_result$jscomp$299$$,$G__68811_ranges$jscomp$4_ranges__$1$$){$G__68810_length$jscomp$48_result$jscomp$299$$=$APP.$cljs$core$transient$0$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$constantly$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($G__68810_length$jscomp$48_result$jscomp$299$$)));for($G__68811_ranges$jscomp$4_ranges__$1$$=$APP.$cljs$core$seq$$($G__68811_ranges$jscomp$4_ranges__$1$$);;){var $temp__5823__auto__$jscomp$180$$=
$APP.$cljs$core$first$$($G__68811_ranges$jscomp$4_ranges__$1$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$180$$)){var $map__68678$$=$temp__5823__auto__$jscomp$180$$,$map__68678__$1$$=$APP.$cljs$core$__destructure_map$$($map__68678$$),$item$jscomp$88$$=$map__68678__$1$$,$offset$jscomp$171$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68678__$1$$,$APP.$cljs$cst$195$offset$$),$length__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68678__$1$$,$APP.$cljs$cst$255$length$$);
$G__68810_length$jscomp$48_result$jscomp$299$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$300$$,$ranges__$1$jscomp$1$$,$map__68678$jscomp$1$$,$map__68678__$1$jscomp$1$$,$item$jscomp$89$$){return function($result__$1$jscomp$35$$,$index$jscomp$290$$){var $prev$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result__$1$jscomp$35$$,$index$jscomp$290$$);return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result__$1$jscomp$35$$,
$index$jscomp$290$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($prev$jscomp$18$$,$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$89$$),$APP.$cljs$cst$108$val$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$89$$)))}}($G__68810_length$jscomp$48_result$jscomp$299$$,$G__68811_ranges$jscomp$4_ranges__$1$$,$map__68678$$,$map__68678__$1$$,$item$jscomp$88$$,$offset$jscomp$171$$,$length__$1$$,$temp__5823__auto__$jscomp$180$$),$G__68810_length$jscomp$48_result$jscomp$299$$,
$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($offset$jscomp$171$$,$offset$jscomp$171$$+$length__$1$$));$G__68811_ranges$jscomp$4_ranges__$1$$=$APP.$cljs$core$rest$$($G__68811_ranges$jscomp$4_ranges__$1$$)}else return $APP.$cljs$core$_persistent_BANG_$$($G__68810_length$jscomp$48_result$jscomp$299$$)}};
$app$render_wasm$text_editor$merge_exported_texts_into_content$$=function($content$jscomp$132$$,$exported_texts_new_paras$$){var $new_para_set_para_set$$=$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$132$$,$APP.$cljs$cst$342$children$$)),$orig_paras$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_para_set_para_set$$,$APP.$cljs$cst$342$children$$),$num_orig$$=$APP.$cljs$core$count$$($orig_paras$$),$last_orig_para$$=$APP.$cljs$core$seq$$($orig_paras$$)?
$APP.$cljs$core$last$$($orig_paras$$):null,$template_span$$=$APP.$cljs$core$truth_$$($last_orig_para$$)?$APP.$cljs$core$last$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($last_orig_para$$)):null;$exported_texts_new_paras$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($orig_para_para_idx$$,$exported_span_texts$$){$orig_para_para_idx$$=$orig_para_para_idx$$<$num_orig$$?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($orig_paras$$,$orig_para_para_idx$$):
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($last_orig_para$$,$APP.$cljs$cst$342$children$$);var $orig_spans$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($orig_para_para_idx$$,$APP.$cljs$cst$342$children$$),$num_orig_spans$$=$APP.$cljs$core$count$$($orig_spans$$),$last_orig_span$$=$APP.$cljs$core$seq$$($orig_spans$$)?$APP.$cljs$core$last$$($orig_spans$$):null;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($orig_para_para_idx$$,$APP.$cljs$cst$342$children$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($orig_span_span_idx$$,$new_text$$){$orig_span_span_idx$$=$orig_span_span_idx$$<$num_orig_spans$$?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($orig_spans$$,$orig_span_span_idx$$):$APP.$cljs$core$truth_$$($last_orig_span$$)?$last_orig_span$$:$template_span$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($orig_span_span_idx$$,$APP.$cljs$cst$1588$text$$,$new_text$$)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($exported_span_texts$$)),
$exported_span_texts$$))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($exported_texts_new_paras$$)),$exported_texts_new_paras$$);$new_para_set_para_set$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($new_para_set_para_set$$,$APP.$cljs$cst$342$children$$,$exported_texts_new_paras$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($content$jscomp$132$$,$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$new_para_set_para_set$$],null))};
$app$common$types$variant$compare_properties$cljs$0core$0IFn$0_invoke$0arity$02$$=function($grouped$jscomp$1_props_list$jscomp$1$$){$grouped$jscomp$1_props_list$jscomp$1$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$grouped$jscomp$1_props_list$jscomp$1$$));return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$){var $name$jscomp$187$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$,
0,null);$JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$,1,null);$JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$);
$JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$,$JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$))?$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$):!1;return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$name$jscomp$187$$,
$APP.$cljs$cst$260$value$$,$JSCompiler_inline_result$jscomp$1560_p__49283_vals$jscomp$inline_8236_values$jscomp$38$$],null)},$grouped$jscomp$1_props_list$jscomp$1$$)};
$app$common$types$color$uniform_spread$$=function($from$jscomp$11$$,$to$jscomp$10$$,$num_stops$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($offset$jscomp$96$$){return $app$common$types$color$interpolate_color$$($from$jscomp$11$$,$to$jscomp$10$$,$offset$jscomp$96$$)},$app$common$types$color$offset_spread$$($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$11$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$10$$),$num_stops$$))};
$app$main$data$workspace$colors$update_colorpicker_add_auto$$=function(){typeof $app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$=function($meta70969$$){this.$meta70969$=$meta70969$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4178$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_auto$$},$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70970$$,$meta70969__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$($meta70969__$1$$)},$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70969$},$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2264$$,$state$jscomp$651$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$651$$,$APP.$cljs$cst$2239$colorpicker$$,function($map__70972__$1_p__70971$$){$map__70972__$1_p__70971$$=
$APP.$cljs$core$__destructure_map$$($map__70972__$1_p__70971$$);var $stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70972__$1_p__70971$$,$APP.$cljs$cst$1733$stops$$),$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70972__$1_p__70971$$,$APP.$cljs$cst$4162$editing_stop$$);if(!$APP.$app$main$features$active_feature_QMARK_$$($map__70972__$1_p__70971$$,"render-wasm/v1")||
$APP.$cljs$core$count$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)<16){if($app$common$types$color$uniform_spread_QMARK_$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$))return $stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$app$common$types$color$uniform_spread$$($APP.$cljs$core$first$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$),$APP.$cljs$core$last$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$),
$APP.$cljs$core$count$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)+1)),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__70972__$1_p__70971$$,$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$)),$APP.$cljs$cst$1733$stops$$,$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$);
var $index$jscomp$308_map__70975_map__70975__$1_to_offset$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$,$APP.$cljs$core$count$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)-1)?$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$-1:$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$;$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,
$index$jscomp$308_map__70975_map__70975__$1_to_offset$$);$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$=$APP.$cljs$core$__destructure_map$$($editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$);$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$,$APP.$cljs$cst$195$offset$$);$index$jscomp$308_map__70975_map__70975__$1_to_offset$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$index$jscomp$308_map__70975_map__70975__$1_to_offset$$+1);$index$jscomp$308_map__70975_map__70975__$1_to_offset$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$308_map__70975_map__70975__$1_to_offset$$);$index$jscomp$308_map__70975_map__70975__$1_to_offset$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$308_map__70975_map__70975__$1_to_offset$$,$APP.$cljs$cst$195$offset$$);
var $new_stop$$=$app$main$data$workspace$colors$split_color_components$$($app$common$types$color$interpolate_gradient$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$+($index$jscomp$308_map__70975_map__70975__$1_to_offset$$-$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$)/2));$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,
$new_stop$$);$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$));$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$=$APP.$app$common$data$index_of_pred$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,function($p1__70967_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_stop$$,
$p1__70967_SHARP_$$)});return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__70972__$1_p__70971$$,$APP.$cljs$cst$4162$editing_stop$$,$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$),$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$editing_stop_editing_stop__$1_from_offset_map__70974_map__70974__$1$$)),
$APP.$cljs$cst$1733$stops$$,$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)}return $map__70972__$1_p__70971$$})});return new $app$main$data$workspace$colors$update_colorpicker_add_auto_70968$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$tokens_lib$update_tokens_group$$=function($active_tokens$$,$current_path$jscomp$1$$,$current_name$$,$new_name$jscomp$8$$){var $path_prefix$$=$APP.$cuerdas$core$replace$$($current_path$jscomp$1$$,$current_name$$,"");return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($new_token_obj_p__50041_token_obj$$){var $new_token_path_token_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_token_obj_p__50041_token_obj$$,0,null);$new_token_obj_p__50041_token_obj$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_token_obj_p__50041_token_obj$$,1,null);if($APP.$cuerdas$core$starts_with_QMARK_$$($new_token_path_token_path$$,$path_prefix$$)){$new_token_path_token_path$$=$APP.$cuerdas$core$replace$$($new_token_path_token_path$$,$current_name$$,$new_name$jscomp$8$$);var $G__50045$jscomp$inline_8238$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($new_token_obj_p__50041_token_obj$$,$APP.$cljs$cst$725$name$$,$new_token_path_token_path$$);$new_token_obj_p__50041_token_obj$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_token_obj_p__50041_token_obj$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50045$jscomp$inline_8238$$,$APP.$cljs$cst$296$path$$,$APP.$cuerdas$core$replace$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_token_obj_p__50041_token_obj$$),$current_name$$,$new_name$jscomp$8$$)):$G__50045$jscomp$inline_8238$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$new_token_path_token_path$$,$new_token_obj_p__50041_token_obj$$],null)}return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_token_path_token_path$$,$new_token_obj_p__50041_token_obj$$],null)},$active_tokens$$)};$app$util$webapi$read_file_as_text$$=function($file$jscomp$8$$){return $APP.$app$util$webapi$file_reader$$(function($p1__44831_SHARP_$$){return $p1__44831_SHARP_$$.readAsText($file$jscomp$8$$)})};
$app$util$strings$matches_search$$=function($name$jscomp$322_nm$jscomp$2$$,$search_term_st$jscomp$1$$){if($APP.$cuerdas$core$empty_QMARK_$$($search_term_st$jscomp$1$$))return!0;$search_term_st$jscomp$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$lower$$($search_term_st$jscomp$1$$));$name$jscomp$322_nm$jscomp$2$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$lower$$($name$jscomp$322_nm$jscomp$2$$));return $APP.$cuerdas$core$includes_QMARK_$$($name$jscomp$322_nm$jscomp$2$$,
$search_term_st$jscomp$1$$)};
$app$common$types$variant$find_boolean_pair$$=function($p__49317$$){var $a$jscomp$366$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49317$$,0,null),$b$jscomp$298$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49317$$,1,null),$a_SINGLEQUOTE_$jscomp$3$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$366$$)),$b_SINGLEQUOTE_$jscomp$1$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$298$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($p__49317$$),
2)?$APP.$cljs$core$some$$(function($f$jscomp$778_p__49322$$){var $t$jscomp$88$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$778_p__49322$$,0,null);$f$jscomp$778_p__49322$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$778_p__49322$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a_SINGLEQUOTE_$jscomp$3$$,$t$jscomp$88$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b_SINGLEQUOTE_$jscomp$1$$,$f$jscomp$778_p__49322$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$a$jscomp$366$$,
!0,$b$jscomp$298$$,!1]):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b_SINGLEQUOTE_$jscomp$1$$,$t$jscomp$88$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a_SINGLEQUOTE_$jscomp$3$$,$f$jscomp$778_p__49322$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$b$jscomp$298$$,!0,$a$jscomp$366$$,!1]):null},$APP.$app$common$types$variant$boolean_pairs$$):null};
$app$common$types$file$get_shape_in_copy$$=function($file_data$jscomp$42$$,$main_shape$$,$root_copy$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51800_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($p1__51800_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_shape$$))},$APP.$app$common$geom$shapes$tree_seq$get_children_seq$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_copy$$),
$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$42$$)))};
$app$util$text_editor$get_content_changes$$=function($old_state$$,$state$jscomp$558$$){var $old_blocks$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($old_state$$.getCurrentContent().getBlockMap().toJS(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!1])),$new_blocks$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$558$$.getCurrentContent().getBlockMap().toJS(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,
!1]));return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68867_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($new_blocks$$,$APP.$cljs$core$first$$($p1__68867_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($bstate_p__68869$$){var $bkey$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate_p__68869$$,0,null);$bstate_p__68869$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate_p__68869$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$bkey$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4000$old$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bstate_p__68869$$,"text"),$APP.$cljs$cst$4001$new$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_blocks$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$bkey$jscomp$1$$,"text"],null))],null)],null)})),$old_blocks$$),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68868_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($old_blocks$$,$APP.$cljs$core$first$$($p1__68868_SHARP_$$))}),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($bstate$jscomp$1_p__68873$$){var $bkey$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate$jscomp$1_p__68873$$,0,null);$bstate$jscomp$1_p__68873$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate$jscomp$1_p__68873$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$bkey$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4000$old$$,
null,$APP.$cljs$cst$4001$new$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bstate$jscomp$1_p__68873$$,"text")],null)],null)})),$new_blocks$$)]))};
$app$common$geom$shapes$intersect$overlaps_text_QMARK_$$=function($p__48923_position_data$jscomp$3$$,$rect$jscomp$16$$){var $map__48924__$1$$=$APP.$cljs$core$__destructure_map$$($p__48923_position_data$jscomp$3$$);$p__48923_position_data$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48924__$1$$,$APP.$cljs$cst$1891$position_data$$);if($p__48923_position_data$jscomp$3$$!=null&&$APP.$app$common$data$not_empty_QMARK_$$($p__48923_position_data$jscomp$3$$)){var $center$jscomp$24$$=
$APP.$app$common$geom$shapes$common$shape__GT_center$$($map__48924__$1$$);return $APP.$cljs$core$some$$(function($p1__48922_SHARP_$$){return $app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($rect$jscomp$16$$,$p1__48922_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$(function($rect_points$jscomp$3$$){return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($rect_points$jscomp$3$$,
$center$jscomp$24$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($map__48924__$1$$))},$APP.$app$common$geom$rect$rect__GT_points$$,$APP.$app$common$geom$shapes$text$position_data__GT_rect$$),$p__48923_position_data$jscomp$3$$))}return $app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($rect$jscomp$16$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($map__48924__$1$$))};
$app$common$geom$shapes$intersect$overlaps_QMARK_$$=function($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$,$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$){var $and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=
$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$);$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$)?
$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$:0)/2;$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$),
$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_PLUS_$$,2*$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$_PLUS_$$,2*$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$);
if($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=$APP.$cljs$core$not$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$))return $and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$;
if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)){if($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=
$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)))if($APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$))){var $JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=
$APP.$cljs$core$count$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$))>100;$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$);
$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$);$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$?
($JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$),$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=
$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$)):$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=
$app$common$types$path$segment$path__GT_lines$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$);$ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$))));
var $center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$=$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$,$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$);
$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$?$center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$:$APP.$cljs$core$truth_$$(!0)?$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$($APP.$cljs$core$first$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$),
$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$)||$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$,$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$):
!1}else $JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=null;else $JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$;
return $JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$}if($APP.$app$common$files$helpers$circle_shape_QMARK_$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)){if($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=
$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$))){$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=
$APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$);$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$);
var $height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$=$APP.$cljs$core$__destructure_map$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$);$center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$,
$APP.$cljs$cst$1510$x$$);var $ry$jscomp$inline_13218_y$jscomp$inline_13206$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$,
$APP.$cljs$cst$1522$height$$);$center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$+$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$/
2,$ry$jscomp$inline_13218_y$jscomp$inline_13206$$+$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$/2);$ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1897$cx$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$),
$APP.$cljs$cst$1898$cy$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$),$APP.$cljs$cst$1881$rx$$,$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$/2,$APP.$cljs$cst$1882$ry$$,$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$/
2,$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)],null);if($JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=$APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$,
$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$))$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$;
else{$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$=$APP.$cljs$core$first$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$);var $map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$=
$APP.$cljs$core$__destructure_map$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$);$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,
$APP.$cljs$cst$1897$cx$$);$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,$APP.$cljs$cst$1898$cy$$);$center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,$APP.$cljs$cst$1881$rx$$);$ry$jscomp$inline_13218_y$jscomp$inline_13206$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,
$APP.$cljs$cst$1882$ry$$);$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,$APP.$cljs$cst$1289$transform$$);var $center$jscomp$inline_13220$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$,
$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$);$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$=$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$!=
null?$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$inline_13220$$,$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$):null;$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$=$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$!=
null?$APP.$app$common$geom$point$transform$$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$,$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$):$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$;$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$=
$APP.$cljs$core$__destructure_map$$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$);$height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,
$APP.$cljs$cst$1510$x$$);$map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=
($and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$=$app$common$math$sq$$($height$jscomp$inline_13208_map__48906$jscomp$inline_13222_map__48921__$1$jscomp$inline_13204_point$jscomp$inline_13213_px$jscomp$inline_13224$$-$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$)/
($center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$*$center$jscomp$inline_13209_or__5025__auto__$jscomp$inline_13198_rx$jscomp$inline_13217_x$jscomp$inline_13205$$)+$app$common$math$sq$$($map__48905__$1$jscomp$inline_13214_map__48906__$1$jscomp$inline_13223_py$jscomp$inline_13225_transform$jscomp$inline_13219_transform__$1$jscomp$inline_13221$$-$JSCompiler_temp$jscomp$14055_cy$jscomp$inline_13216_or__5025__auto__$jscomp$inline_13211_path_lines$jscomp$inline_13196_points$jscomp$inline_14588_simple_QMARK_$jscomp$inline_13193_width$jscomp$inline_13207$$)/
($ry$jscomp$inline_13218_y$jscomp$inline_13206$$*$ry$jscomp$inline_13218_y$jscomp$inline_13206$$)<=1)?$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$:$app$common$geom$shapes$intersect$intersects_lines_ellipse_QMARK_$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$,
$ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)}}else $JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$=$and__5023__auto__$jscomp$256_cx$jscomp$inline_13215_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8240_or__5025__auto____$1$jscomp$inline_13212_rect_lines$jscomp$inline_13195_rect_points$jscomp$inline_13202_swidth$$;return $JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$}return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$)?
$app$common$geom$shapes$intersect$overlaps_text_QMARK_$$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$,$JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$):$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($JSCompiler_temp$jscomp$10969_JSCompiler_temp$jscomp$10970_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13203_rect_points$jscomp$inline_13194$$,
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13210_shape$jscomp$121_start_point$jscomp$inline_13197$$))};$app$common$types$shape$interactions$remove_interactions$$=function($f$jscomp$777$$,$interactions$jscomp$4$$){return $APP.$cljs$core$not_empty$$($APP.$app$common$data$removev$$($f$jscomp$777$$,$interactions$jscomp$4$$))};
$app$main$data$workspace$colors$get_color_from_colorpicker_state$$=function($JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$){var $map__70922__$1_opacity$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$),$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70922__$1_opacity$jscomp$29$$,$APP.$cljs$cst$139$type$$),
$JSCompiler_temp_const$jscomp$1571_current_color$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70922__$1_opacity$jscomp$29$$,$APP.$cljs$cst$4164$current_color$$);$JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70922__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1733$stops$$);var $gradient$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70922__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1724$gradient$$);
$map__70922__$1_opacity$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70922__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1734$opacity$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$,$APP.$cljs$cst$1298$color$$))$JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$clear_color_components$$($JSCompiler_temp_const$jscomp$1571_current_color$$),
$APP.$cljs$cst$195$offset$$);else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$,$APP.$cljs$cst$1612$image$$))$JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_temp_const$jscomp$1571_current_color$$,$APP.$cljs$cst$2687$hex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$746$alpha$$,
$APP.$cljs$cst$1743$r$$,$APP.$cljs$cst$1744$g$$,$APP.$cljs$cst$1520$b$$,$APP.$cljs$cst$1899$h$$,$APP.$cljs$cst$4168$s$$,$APP.$cljs$cst$3670$v$$,$APP.$cljs$cst$1298$color$$]));else{$JSCompiler_temp_const$jscomp$1571_current_color$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_temp_const$jscomp$1569$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1567$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1565$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1564$$=$APP.$cljs$cst$139$type$$;a:switch($G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$=$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$ instanceof $APP.$cljs$core$Keyword$$?$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$.$fqn$:null,$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$){case "linear-gradient":$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$=
$APP.$cljs$cst$287$linear$$;break a;case "radial-gradient":$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$=$APP.$cljs$cst$1728$radial$$;break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$)].join(""));}$JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$=$JSCompiler_temp_const$jscomp$1571_current_color$$.call($APP.$app$common$data$without_nils$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1734$opacity$$,$map__70922__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1724$gradient$$,$JSCompiler_temp_const$jscomp$1569$$.call($APP.$cljs$core$dissoc$$,$JSCompiler_temp_const$jscomp$1567$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp_const$jscomp$1565$$.call($APP.$cljs$core$assoc$$,$gradient$jscomp$18$$,$JSCompiler_temp_const$jscomp$1564$$,$G__70926__$1$jscomp$inline_8242_JSCompiler_inline_result$jscomp$1573_type$jscomp$490$$),$APP.$cljs$cst$1733$stops$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$clear_color_components$$,$JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$)),$APP.$cljs$cst$2543$shape_id$$)],null))}return $JSCompiler_temp$jscomp$1562_JSCompiler_temp$jscomp$1563_p__70921_stops$jscomp$9$$};
$app$main$data$workspace$colors$colorpicker_onchange_runner$$=function($on_change$jscomp$5$$){typeof $app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$==="undefined"&&($app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$=function($on_change$jscomp$6$$,$meta70930$$){this.$on_change$=$on_change$jscomp$6$$;this.$meta70930$=$meta70930$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4169$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpicker_onchange_runner$$},$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70931$$,$meta70930__$1$$){return new $app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$(this.$on_change$,
$meta70930__$1$$)},$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70930$},$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$,
$state$jscomp$646$$){$G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$=$state$jscomp$646$$==null?null:$APP.$cljs$cst$2239$colorpicker$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$646$$);$G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$=$G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$==null?null:$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$);
return $APP.$cljs$core$truth_$$($G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$)?this.$on_change$.$cljs$core$IFn$_invoke$arity$1$?this.$on_change$.$cljs$core$IFn$_invoke$arity$1$($G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$):this.$on_change$($G__70939__$1$jscomp$inline_8244__$jscomp$2258_temp__5825__auto__$jscomp$215$$):null});return new $app$main$data$workspace$colors$colorpicker_onchange_runner_70929$$($on_change$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$initialize_colorpicker$$=function($on_change$jscomp$7$$,$tab$$){typeof $app$main$data$workspace$colors$initialize_colorpicker_70941$$==="undefined"&&($app$main$data$workspace$colors$initialize_colorpicker_70941$$=function($on_change$jscomp$8$$,$tab$jscomp$1$$,$meta70942$$){this.$on_change$=$on_change$jscomp$8$$;this.tab=$tab$jscomp$1$$;this.$meta70942$=$meta70942$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4170$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_initialize_colorpicker$$},$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70943$$,$meta70942__$1$$){return new $app$main$data$workspace$colors$initialize_colorpicker_70941$$(this.$on_change$,
this.tab,$meta70942__$1$$)},$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70942$},$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2259_stopper$jscomp$20$$,$___$1$jscomp$1492$$,$stream$jscomp$65$$){$_$jscomp$2259_stopper$jscomp$20$$=
$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4171$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_finalize_colorpicker$$),$stream$jscomp$65$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4170$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_initialize_colorpicker$$),$stream$jscomp$65$$));return $APP.$beicon$v2$core$take_until$$($_$jscomp$2259_stopper$jscomp$20$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($app$main$data$workspace$colors$colorpicker_onchange_runner$$(this.$on_change$)),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$debounce$$(20,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4172$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient$$),$stream$jscomp$65$$)),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4173$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_color$$),
$stream$jscomp$65$$),$APP.$beicon$v2$core$debounce$$(20,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4174$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_gradient$$),$stream$jscomp$65$$)),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4175$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_stops$$),$stream$jscomp$65$$),
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4176$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient_opacity$$),$stream$jscomp$65$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4177$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_stop$$),$stream$jscomp$65$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4178$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_auto$$),
$stream$jscomp$65$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4179$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_gradient_stop$$),$stream$jscomp$65$$))))},$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$initialize_colorpicker_70941$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2260$$,
$state$jscomp$647$$){var $self__$jscomp$5275$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$647$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$30$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$30$$,$APP.$cljs$cst$139$type$$,$self__$jscomp$5275$$.tab)})});return new $app$main$data$workspace$colors$initialize_colorpicker_70941$$($on_change$jscomp$7$$,$tab$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$materialize_color_components$$=function($map__70919__$1_p__70918$$){$map__70919__$1_p__70918$$=$APP.$cljs$core$__destructure_map$$($map__70919__$1_p__70918$$);var $hex$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70919__$1_p__70918$$,$APP.$cljs$cst$2687$hex$$),$alpha$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70919__$1_p__70918$$,$APP.$cljs$cst$746$alpha$$);return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__70919__$1_p__70918$$,
$APP.$cljs$cst$1298$color$$,$hex$jscomp$6$$),$APP.$cljs$cst$1734$opacity$$,$alpha$jscomp$12$$))};
$app$main$data$workspace$colors$activate_colorpicker_gradient$$=function($type$jscomp$493$$){typeof $app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$==="undefined"&&($app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$=function($type$jscomp$494$$,$meta71034$$){this.type=$type$jscomp$494$$;this.$meta71034$=$meta71034$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4174$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_gradient$$},$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71035$$,$meta71034__$1$$){return new $app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$(this.type,
$meta71034__$1$$)},$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71034$},$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2275$$,$state$jscomp$661$$){var $self__$jscomp$5329$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$661$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$42$$){var $G__71039_gradient$jscomp$21$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1729$start_x$$,.5,$APP.$cljs$cst$1730$start_y$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5329$$.type,$APP.$cljs$cst$4163$linear_gradient$$)?0:.5,$APP.$cljs$cst$1731$end_x$$,.5,$APP.$cljs$cst$1732$end_y$$,1,$APP.$cljs$cst$290$width$$,
1],null),$color$jscomp$101$$=$APP.$cljs$cst$4164$current_color$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$42$$);$G__71039_gradient$jscomp$21$$=$APP.$app$common$data$dissoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$42$$,$APP.$cljs$cst$139$type$$,$self__$jscomp$5329$$.type),$APP.$cljs$cst$1724$gradient$$,$G__71039_gradient$jscomp$21$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$cst$1612$image$$],null));return $APP.$cljs$core$not$$($APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$42$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71039_gradient$jscomp$21$$,$APP.$cljs$cst$4162$editing_stop$$,0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1733$stops$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$app$main$data$workspace$colors$materialize_color_components$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$101$$,$APP.$cljs$cst$195$offset$$,0)),$app$main$data$workspace$colors$materialize_color_components$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$101$$,$APP.$cljs$cst$746$alpha$$,0),$APP.$cljs$cst$195$offset$$,1))],null)])):$G__71039_gradient$jscomp$21$$})});return new $app$main$data$workspace$colors$activate_colorpicker_gradient_71033$$($type$jscomp$493$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$text$content$to_dom$get_styles_from_attrs$$=function($node$jscomp$296$$,$attrs$jscomp$56_styles$jscomp$6$$){$attrs$jscomp$56_styles$jscomp$6$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$118$$,$key$jscomp$364$$){var $default_value$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$text$default_text_attrs$$,$key$jscomp$364$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$118$$,$key$jscomp$364$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$296$$,$key$jscomp$364$$,$default_value$jscomp$2$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$attrs$jscomp$56_styles$jscomp$6$$);var $fills$jscomp$18$$=$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$296$$)!=null||$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$296$$)!=null||$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$296$$)!=
null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$select_keys$$($node$jscomp$296$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1640$fill_color_ref_file$$],
null)))],null):$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$296$$)==null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#000000",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null):$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$296$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$56_styles$jscomp$6$$,
$APP.$cljs$cst$1634$fills$$,$fills$jscomp$18$$)};
$app$main$data$persistence$merge_commit$$=function($buffer$jscomp$79$$){return $APP.$beicon$v2$core$map$$(function($item$jscomp$56_p__55370$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$56_p__55370$$,0,null);var $rchg$jscomp$1_vec__55374$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$56_p__55370$$,1,null);$item$jscomp$56_p__55370$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($rchg$jscomp$1_vec__55374$$,0,null);var $uchg$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$app$main$data$persistence$xf_mapcat_undo$$,$rchg$jscomp$1_vec__55374$$);$rchg$jscomp$1_vec__55374$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$persistence$xf_mapcat_redo$$,$rchg$jscomp$1_vec__55374$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$56_p__55370$$,$APP.$cljs$cst$3137$undo_changes$$,
$uchg$jscomp$1$$),$APP.$cljs$cst$3133$redo_changes$$,$rchg$jscomp$1_vec__55374$$),$APP.$cljs$cst$3131$changes$$,$rchg$jscomp$1_vec__55374$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$1644$file_id$$,$buffer$jscomp$79$$)))};
$app$common$path_names$sort_by_children$$=function($segments$jscomp$10$$,$separator$jscomp$7$$){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($path$jscomp$164_path_length_segment$jscomp$39$$){$path$jscomp$164_path_length_segment$jscomp$39$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$164_path_length_segment$jscomp$39$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,
$separator$jscomp$7$$]));$path$jscomp$164_path_length_segment$jscomp$39$$=$APP.$cljs$core$count$$($path$jscomp$164_path_length_segment$jscomp$39$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$164_path_length_segment$jscomp$39$$,1)?1:0},$segments$jscomp$10$$)};
$app$common$path_names$compact_path$$=function($last_item_path$jscomp$160$$){var $G__49160_other_items_path_split$$=$APP.$app$common$path_names$split_path$$($last_item_path$jscomp$160$$);$last_item_path$jscomp$160$$=$APP.$cljs$core$last$$($G__49160_other_items_path_split$$);var $merge_path$$=$APP.$cljs$core$truth_$$(!0)?$app$common$path_names$merge_path_item_with_dot$$:$APP.$app$common$path_names$merge_path_item$$;$G__49160_other_items_path_split$$=$APP.$cljs$core$seq$$($APP.$cljs$core$butlast$$($G__49160_other_items_path_split$$));
for(var $G__49161_other_path$$="";;){var $item$jscomp$45_temp__5823__auto__$jscomp$110$$=$APP.$cljs$core$first$$($G__49160_other_items_path_split$$);if($APP.$cljs$core$truth_$$($item$jscomp$45_temp__5823__auto__$jscomp$110$$)){var $G__49108$jscomp$inline_8249_full_path$$=$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49161_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$):$merge_path$$($G__49161_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$);
$G__49108$jscomp$inline_8249_full_path$$=$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49108$jscomp$inline_8249_full_path$$,$last_item_path$jscomp$160$$):$merge_path$$($G__49108$jscomp$inline_8249_full_path$$,$last_item_path$jscomp$160$$);if($APP.$cljs$core$count$$($G__49108$jscomp$inline_8249_full_path$$)>35)return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?
$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49161_other_path$$,"..."):$merge_path$$($G__49161_other_path$$,"..."),$last_item_path$jscomp$160$$,!0],null);$G__49160_other_items_path_split$$=$APP.$cljs$core$next$$($G__49160_other_items_path_split$$);$G__49161_other_path$$=$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49161_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$):$merge_path$$($G__49161_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$)}else return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__49161_other_path$$,$last_item_path$jscomp$160$$,!1],null)}};
$app$common$data$reorder$$=function($v$jscomp$146_without_elem$$,$from_pos_from_pos__$1_insert_pos$$,$elem$jscomp$5_to_space_between_pos$$){var $max_space_pos_to_space_between_pos__$1$$=$APP.$cljs$core$count$$($v$jscomp$146_without_elem$$);$from_pos_from_pos__$1_insert_pos$$=$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($max_space_pos_to_space_between_pos__$1$$-1,$from_pos_from_pos__$1_insert_pos$$));$max_space_pos_to_space_between_pos__$1$$=
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($max_space_pos_to_space_between_pos__$1$$,$elem$jscomp$5_to_space_between_pos$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_pos_from_pos__$1_insert_pos$$,$max_space_pos_to_space_between_pos__$1$$))return $v$jscomp$146_without_elem$$;$elem$jscomp$5_to_space_between_pos$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$146_without_elem$$,
$from_pos_from_pos__$1_insert_pos$$);$v$jscomp$146_without_elem$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$146_without_elem$$,0,$from_pos_from_pos__$1_insert_pos$$)),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$146_without_elem$$,$from_pos_from_pos__$1_insert_pos$$+1));$from_pos_from_pos__$1_insert_pos$$=
$from_pos_from_pos__$1_insert_pos$$<$max_space_pos_to_space_between_pos__$1$$?$max_space_pos_to_space_between_pos__$1$$-1:$max_space_pos_to_space_between_pos__$1$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$146_without_elem$$,0,$from_pos_from_pos__$1_insert_pos$$)),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$elem$jscomp$5_to_space_between_pos$$],null)),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$146_without_elem$$,$from_pos_from_pos__$1_insert_pos$$))};
$cljs$core$sorted_map$$=function($var_args$jscomp$244$$){for(var $JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$=[],$G__28798$jscomp$inline_8254_len__5749__auto___28792$$=arguments.length,$G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$=0;;)if($G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$<$G__28798$jscomp$inline_8254_len__5749__auto___28792$$)$JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$.push(arguments[$G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$]),
$G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$+=1;else break;a:{$JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$=$APP.$cljs$core$seq$$(0<$JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$.length?new $APP.$cljs$core$IndexedSeq$$($JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$.slice(0),0,null):null);for($G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$=
$APP.$cljs$core$PersistentTreeMap$EMPTY$$;;)if($JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$)$G__28798$jscomp$inline_8254_len__5749__auto___28792$$=$APP.$cljs$core$next$$($APP.$cljs$core$next$$($JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$)),$G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$,
$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$),$APP.$cljs$core$second$$($JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$)),$JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$=$G__28798$jscomp$inline_8254_len__5749__auto___28792$$;else{$JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$=$G__28799$jscomp$inline_8255_i__5750__auto___28794_out$jscomp$inline_8253$$;
break a}$JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$=void 0}return $JSCompiler_inline_result$jscomp$1577_args__5755__auto__$jscomp$6_in$$jscomp$inline_8252$$};$app$common$path_names$join_path_with_dot$$=function($path_vec$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" • ",$path_vec$$)};
$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$=function($node$jscomp$246_updated_split_element_name$$,$element$jscomp$57_split_path_token$jscomp$45$$,$new_name$jscomp$5$$){$element$jscomp$57_split_path_token$jscomp$45$$=$APP.$cljs$core$truth_$$($element$jscomp$57_split_path_token$jscomp$45$$)?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$57_split_path_token$jscomp$45$$):$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$246_updated_split_element_name$$);
$element$jscomp$57_split_path_token$jscomp$45$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($element$jscomp$57_split_path_token$jscomp$45$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"."]));$node$jscomp$246_updated_split_element_name$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($element$jscomp$57_split_path_token$jscomp$45$$,$APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$246_updated_split_element_name$$),
$new_name$jscomp$5$$);return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($node$jscomp$246_updated_split_element_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,".",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]))};
$app$common$path_names$group_by_first_segment$$=function($segments$jscomp$11$$,$separator$jscomp$8$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$96$$,$segment$jscomp$40$$){var $first__49118_vec__49116$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$40$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,
$separator$jscomp$8$$])),$rest_path_seq__49117_seq__49117__$1$$=$APP.$cljs$core$seq$$($first__49118_vec__49116$$);$first__49118_vec__49116$$=$APP.$cljs$core$first$$($rest_path_seq__49117_seq__49117__$1$$);$rest_path_seq__49117_seq__49117__$1$$=$APP.$cljs$core$next$$($rest_path_seq__49117_seq__49117__$1$$);$rest_path_seq__49117_seq__49117__$1$$=$APP.$cljs$core$seq$$($rest_path_seq__49117_seq__49117__$1$$)?$APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rest_path_seq__49117_seq__49117__$1$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,$separator$jscomp$8$$,$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1])):null;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$96$$,$first__49118_vec__49116$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$truth_$$($rest_path_seq__49117_seq__49117__$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($segment$jscomp$40$$,
$APP.$cljs$cst$725$name$$,$rest_path_seq__49117_seq__49117__$1$$):$segment$jscomp$40$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$segments$jscomp$11$$)};
$app$common$path_names$sort_and_group_segments$$=function($segments$jscomp$12_sorted$$,$grouped_separator$jscomp$9$$){$segments$jscomp$12_sorted$$=$app$common$path_names$sort_by_children$$($segments$jscomp$12_sorted$$,$grouped_separator$jscomp$9$$);$grouped_separator$jscomp$9$$=$app$common$path_names$group_by_first_segment$$($segments$jscomp$12_sorted$$,$grouped_separator$jscomp$9$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$sorted_map$$(),$grouped_separator$jscomp$9$$)};
$app$common$path_names$build_tree_root$$=function($grouped_elements$jscomp$1_segments$jscomp$13$$){$grouped_elements$jscomp$1_segments$jscomp$13$$=$app$common$path_names$sort_and_group_segments$$($grouped_elements$jscomp$1_segments$jscomp$13$$,".");return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49139_remaining_segments$jscomp$2$$){var $segment_name$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49139_remaining_segments$jscomp$2$$,0,null);$p__49139_remaining_segments$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49139_remaining_segments$jscomp$2$$,1,null);return $app$common$path_names$build_tree_node$$($segment_name$jscomp$1$$,$p__49139_remaining_segments$jscomp$2$$,".",null,0)},$grouped_elements$jscomp$1_segments$jscomp$13$$)};
$app$common$path_names$butlast_path$$=function($path$jscomp$161_split$jscomp$3$$){$path$jscomp$161_split$jscomp$3$$=$APP.$app$common$path_names$split_path$$($path$jscomp$161_split$jscomp$3$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($path$jscomp$161_split$jscomp$3$$))?"":$APP.$app$common$path_names$join_path$$($APP.$cljs$core$butlast$$($path$jscomp$161_split$jscomp$3$$))};
$app$common$types$token$join_font_family$$=function($font_families$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$font_families$$)};
$app$main$data$workspace$texts$generate_typography_name$$=function($map__70351__$1_p__70350$$){$map__70351__$1_p__70350$$=$APP.$cljs$core$__destructure_map$$($map__70351__$1_p__70350$$);var $font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70351__$1_p__70350$$,$APP.$cljs$cst$1757$font_id$$),$font_variant_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70351__$1_p__70350$$,$APP.$cljs$cst$1759$font_variant_id$$);
$font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$=$APP.$app$main$fonts$get_font_data$$($font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$);$font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$=$APP.$cljs$core$__destructure_map$$($font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$);$font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$,
$APP.$cljs$cst$725$name$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__70351__$1_p__70350$$,$APP.$cljs$cst$725$name$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$32_map__70352_map__70352__$1_name$jscomp$333$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$stylize$cljs$0core$0IFn$0_invoke$0arity$04$$($font_variant_id$jscomp$16$$,$APP.$cuerdas$core$capital$$,$APP.$cuerdas$core$capital$$," "))].join(""))};
$app$common$types$path$get_handlers$$=function($content$jscomp$83_content__$1$jscomp$18$$){$content$jscomp$83_content__$1$jscomp$18$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$83_content__$1$jscomp$18$$);return $APP.$app$common$types$path$segment$get_handlers$$($content$jscomp$83_content__$1$jscomp$18$$)};
$app$common$types$path$segment$is_curve_QMARK_$$=function($content$jscomp$34$$,$point$jscomp$29$$){var $handler_points_handlers$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$path$segment$get_handlers$$($content$jscomp$34$$),$point$jscomp$29$$);$handler_points_handlers$jscomp$4$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48129_SHARP_$$){return $APP.$app$common$types$path$segment$get_handler_point$$($content$jscomp$34$$,$APP.$cljs$core$first$$($p1__48129_SHARP_$$),
$APP.$cljs$core$second$$($p1__48129_SHARP_$$))},$handler_points_handlers$jscomp$4$$);return $APP.$cljs$core$some$$(function($p1__48130_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$29$$,$p1__48130_SHARP_$$)},$handler_points_handlers$jscomp$4$$)};
$cljs$core$dedupe$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return function($rf$jscomp$20$$){var $pa$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$cst$104$cljs_DOT_core_SLASH_none$$);return function(){function $G__29654__2$$($result$jscomp$74$$,$input$jscomp$46$$){var $prior$$=$APP.$cljs$core$_deref$$($pa$jscomp$1$$);$APP.$cljs$core$_vreset_BANG_$$($pa$jscomp$1$$,$input$jscomp$46$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prior$$,$input$jscomp$46$$)?$result$jscomp$74$$:
$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$74$$,$input$jscomp$46$$):$rf$jscomp$20$$($result$jscomp$74$$,$input$jscomp$46$$)}function $G__29654__1$$($result$jscomp$73$$){return $rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$73$$):$rf$jscomp$20$$($result$jscomp$73$$)}function $G__29654__0$$(){return $rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$():
$rf$jscomp$20$$()}var $G__29654$$=null;$G__29654$$=function($result$jscomp$75$$,$input$jscomp$47$$){switch(arguments.length){case 0:return $G__29654__0$$.call(this);case 1:return $G__29654__1$$.call(this,$result$jscomp$75$$);case 2:return $G__29654__2$$.call(this,$result$jscomp$75$$,$input$jscomp$47$$)}throw Error("Invalid arity: "+arguments.length);};$G__29654$$.$cljs$core$IFn$_invoke$arity$0$=$G__29654__0$$;$G__29654$$.$cljs$core$IFn$_invoke$arity$1$=$G__29654__1$$;$G__29654$$.$cljs$core$IFn$_invoke$arity$2$=
$G__29654__2$$;return $G__29654$$}()}};
$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$=function($token_type$jscomp$8$$,$new_name$jscomp$27$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$=function($token_type$jscomp$9$$,$new_name$jscomp$28$$,$meta72789$$){this.$token_type$=$token_type$jscomp$9$$;this.$new_name$=$new_name$jscomp$28$$;this.$meta72789$=$meta72789$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4695$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_nested_token_path$$},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72790$$,$meta72789__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$(this.$token_type$,this.$new_name$,$meta72789__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72789$},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2653$$,$state$jscomp$972$$){var $type_str$$=$APP.$cljs$core$name$$(this.$token_type$),$segments$jscomp$14$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$new_name$,"."),$n_groups$$=$APP.$cljs$core$count$$($segments$jscomp$14$$)-1;return $n_groups$$>0?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$972$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,
$APP.$cljs$cst$4693$folded_token_paths$$],null),function($paths$jscomp$6$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ps$jscomp$24$$,$i$jscomp$511$$){return $APP.$app$main$data$workspace$tokens$library_edit$remove_path$$([$type_str$$,".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(".",$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$511$$,$segments$jscomp$14$$)))].join(""),$ps$jscomp$24$$)},
$APP.$cljs$core$truth_$$($paths$jscomp$6$$)?$paths$jscomp$6$$:$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$n_groups$$+1))}):$state$jscomp$972$$});return new $app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72788$$($token_type$jscomp$8$$,$new_name$jscomp$27$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker_stops$$=function($stops$jscomp$12$$){typeof $app$main$data$workspace$colors$update_colorpicker_stops_70989$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_stops_70989$$=function($stops$jscomp$13$$,$meta70990$$){this.stops=$stops$jscomp$13$$;this.$meta70990$=$meta70990$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_stops_70989$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_stops_70989$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4175$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_stops$$},$app$main$data$workspace$colors$update_colorpicker_stops_70989$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70991$$,$meta70990__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_stops_70989$$(this.stops,
$meta70990__$1$$)},$app$main$data$workspace$colors$update_colorpicker_stops_70989$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70990$},$app$main$data$workspace$colors$update_colorpicker_stops_70989$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_stops_70989$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2266$$,$state$jscomp$653$$){var $self__$jscomp$5299$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$653$$,
$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$35$$){var $or__5025__auto__$jscomp$inline_8257_stop$jscomp$4$$=$APP.$cljs$cst$4162$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$35$$);$or__5025__auto__$jscomp$inline_8257_stop$jscomp$4$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8257_stop$jscomp$4$$)?$or__5025__auto__$jscomp$inline_8257_stop$jscomp$4$$:0;var $cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$=$APP.$app$main$features$active_feature_QMARK_$$($state__$1$jscomp$35$$,
"render-wasm/v1");$cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$?$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(16,$self__$jscomp$5299$$.stops):$self__$jscomp$5299$$.stops);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$35$$,$APP.$cljs$cst$4164$current_color$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$,$or__5025__auto__$jscomp$inline_8257_stop$jscomp$4$$)),$APP.$cljs$cst$1733$stops$$,$cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$)})});return new $app$main$data$workspace$colors$update_colorpicker_stops_70989$$($stops$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$update_recent_font$$=function($state$jscomp$295$$,$file_id$jscomp$77$$,$font$jscomp$36$$){var $xform$jscomp$32$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__55953_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$36$$,$p1__55953_SHARP_$$)}),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(3));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$295$$,
$file_id$jscomp$77$$,function($p1__55954_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$font$jscomp$36$$],null),$xform$jscomp$32$$,$p1__55954_SHARP_$$)})};
$app$common$path_names$inside_path_QMARK_$$=function($child$jscomp$67_child_path$$,$parent$jscomp$186_parent_path$$){$child$jscomp$67_child_path$$=$APP.$app$common$path_names$split_path$$($child$jscomp$67_child_path$$);$parent$jscomp$186_parent_path$$=$APP.$app$common$path_names$split_path$$($parent$jscomp$186_parent_path$$);return $APP.$cljs$core$count$$($parent$jscomp$186_parent_path$$)<=$APP.$cljs$core$count$$($child$jscomp$67_child_path$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$186_parent_path$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($parent$jscomp$186_parent_path$$),$child$jscomp$67_child_path$$))};
$app$main$data$workspace$texts$focus_editor$$=function(){typeof $app$main$data$workspace$texts$focus_editor_70026$$==="undefined"&&($app$main$data$workspace$texts$focus_editor_70026$$=function($meta70027$$){this.$meta70027$=$meta70027$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$focus_editor_70026$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$focus_editor_70026$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4003$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_focus_editor$$},$app$main$data$workspace$texts$focus_editor_70026$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70028$$,$meta70027__$1$$){return new $app$main$data$workspace$texts$focus_editor_70026$$($meta70027__$1$$)},$app$main$data$workspace$texts$focus_editor_70026$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70027$},$app$main$data$workspace$texts$focus_editor_70026$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$focus_editor_70026$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $editor$jscomp$2$$=$APP.$cljs$cst$2221$workspace_editor$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$element$jscomp$71$$=$APP.$cljs$core$truth_$$($editor$jscomp$2$$)?$editor$jscomp$2$$.element:null,$and__5023__auto__$jscomp$inline_13227$$=
$editor$jscomp$2$$!=null;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13227$$?$editor$jscomp$2$$.focus:$and__5023__auto__$jscomp$inline_13227$$)?$editor$jscomp$2$$.focus():$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($element$jscomp$71$$)?$element$jscomp$71$$.focus:$element$jscomp$71$$)?$element$jscomp$71$$.focus():null})});return new $app$main$data$workspace$texts$focus_editor_70026$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$features$use_feature$$=function($feature$jscomp$8$$){var $enabled_features$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$features$features_ref$$);return $APP.$cljs$core$contains_QMARK_$$($enabled_features$jscomp$7$$,$feature$jscomp$8$$)};
$app$main$data$workspace$versions$create_version$$=function(){typeof $app$main$data$workspace$versions$create_version_73304$$==="undefined"&&($app$main$data$workspace$versions$create_version_73304$$=function($meta73305$$){this.$meta73305$=$meta73305$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$create_version_73304$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_73304$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5026$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_create_version$$},$app$main$data$workspace$versions$create_version_73304$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73306$$,$meta73305__$1$$){return new $app$main$data$workspace$versions$create_version_73304$$($meta73305__$1$$)},$app$main$data$workspace$versions$create_version_73304$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73305$},$app$main$data$workspace$versions$create_version_73304$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_73304$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2782$$,$state$jscomp$1069$$){var $label$jscomp$21$$=$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$time$now$$(),$APP.$cljs$cst$5027$localized_date$$),$file_id$jscomp$326$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1069$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,
$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-version"],null))),$APP.$beicon$v2$core$mapcat$$(function($id$jscomp$845_map__73314__$1_p__73312$$){$id$jscomp$845_map__73314__$1_p__73312$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$845_map__73314__$1_p__73312$$);$id$jscomp$845_map__73314__$1_p__73312$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$845_map__73314__$1_p__73312$$,
$APP.$cljs$cst$266$id$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2152$editing$$,$id$jscomp$845_map__73314__$1_p__73312$$],null)),$app$main$data$workspace$versions$fetch_versions$$())},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5028$create_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$326$$,$APP.$cljs$cst$2287$label$$,$label$jscomp$21$$],null))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__73303_SHARP_$$){return $p1__73303_SHARP_$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3151$saved$$,$p1__73303_SHARP_$$)},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$persistence_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,
!0],null)))))))});return new $app$main$data$workspace$versions$create_version_73304$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$refs$workspace_grid_edition_id$$=function($id$jscomp$226$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50382_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50382_SHARP_$$,$id$jscomp$226$$)},$APP.$app$main$refs$workspace_grid_edition$$)};
$app$main$refs$workspace_thumbnail_rendered_at$$=function($object_id$jscomp$1$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50367_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50367_SHARP_$$,$APP.$cljs$cst$2236$thumbnails_meta$$),$object_id$jscomp$1$$),$APP.$cljs$cst$2237$rendered_at$$)},$APP.$app$main$store$state$$)};
$app$main$refs$workspace_token_in_selected_set$$=function($token_id$jscomp$13$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$){var $JSCompiler_inline_result$jscomp$1524_temp__5825__auto__$jscomp$inline_8261$$=$APP.$app$main$data$workspace$tokens$selected_set$get_selected_token_set_id$$($G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1524_temp__5825__auto__$jscomp$inline_8261$$)?
($G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$),$G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$=$G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$,
$APP.$cljs$cst$2139$tokens_lib$$),$JSCompiler_inline_result$jscomp$1524_temp__5825__auto__$jscomp$inline_8261$$=$G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$==null?null:$APP.$app$common$types$tokens_lib$get_token$$($G__50111$jscomp$inline_8262_G__50111__$1$jscomp$inline_8263_p1__50325_SHARP_$$,$JSCompiler_inline_result$jscomp$1524_temp__5825__auto__$jscomp$inline_8261$$,$token_id$jscomp$13$$)):$JSCompiler_inline_result$jscomp$1524_temp__5825__auto__$jscomp$inline_8261$$=
null;return $JSCompiler_inline_result$jscomp$1524_temp__5825__auto__$jscomp$inline_8261$$},$APP.$app$main$store$state$$)};
$app$main$refs$grid_layout_child_QMARK_$$=function($ids$jscomp$32$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$173$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$,$objects$jscomp$173$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$173$$),$ids$jscomp$32$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};
$app$main$refs$flex_layout_child_QMARK_$$=function($ids$jscomp$31$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$172$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$,$objects$jscomp$172$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$172$$),$ids$jscomp$31$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};
$app$main$refs$all_layout_child_QMARK_$$=function($ids$jscomp$30$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$171$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$,$objects$jscomp$171$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$171$$),$ids$jscomp$30$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};
$app$main$refs$is_layout_child_QMARK_$$=function($ids$jscomp$29$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($objects$jscomp$170$$){return $APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$,$objects$jscomp$170$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$170$$),$ids$jscomp$29$$))},$APP.$app$main$refs$workspace_page_objects$$)};
$app$main$refs$shape_parents$$=function($id$jscomp$218$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$164$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$164$$)),$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$164$$,$id$jscomp$218$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};$app$main$refs$objects_by_id$$=function($ids$jscomp$26$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50239_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($p1__50239_SHARP_$$)),$ids$jscomp$26$$)},$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$)};
$app$main$refs$object_by_id$$=function($id$jscomp$217$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50235_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50235_SHARP_$$,$id$jscomp$217$$)},$APP.$app$main$refs$workspace_page_objects$$)};
$app$main$refs$token_sets_at_path_all_active$$=function($group_path$jscomp$4$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($lib$jscomp$4$$){return $APP.$cljs$core$truth_$$($lib$jscomp$4$$)?$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$($lib$jscomp$4$$,$group_path$jscomp$4$$):null},$APP.$app$main$refs$tokens_lib$$)};
$app$main$refs$workspace_token_theme$$=function($id$jscomp$224$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($lib$jscomp$2$$){return $APP.$cljs$core$truth_$$($lib$jscomp$2$$)?$APP.$app$common$types$tokens_lib$get_theme$$($lib$jscomp$2$$,$id$jscomp$224$$):null},$APP.$app$main$refs$tokens_lib$$)};
$app$main$data$modal$allow_click_outside_BANG_$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2339$allow_click_outside$$,!0],null)))};$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($props$jscomp$89$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($props$jscomp$89$$))};
$app$common$types$shape$interactions$flow_to_QMARK_$$=function($interactions$jscomp$7$$,$frame_id$jscomp$13$$){return $APP.$cljs$core$some$$(function($p1__49127_SHARP_$$){var $G__49130$jscomp$inline_8265_and__5023__auto__$jscomp$265$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__49127_SHARP_$$);var $fexpr__49129$jscomp$inline_8266$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1941$navigate$$,null,$APP.$cljs$cst$1942$close_overlay$$,
null,$APP.$cljs$cst$1944$toggle_overlay$$,null,$APP.$cljs$cst$1946$open_overlay$$,null],null),null);$G__49130$jscomp$inline_8265_and__5023__auto__$jscomp$265$$=$fexpr__49129$jscomp$inline_8266$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49129$jscomp$inline_8266$$.$cljs$core$IFn$_invoke$arity$1$($G__49130$jscomp$inline_8265_and__5023__auto__$jscomp$265$$):$fexpr__49129$jscomp$inline_8266$$($G__49130$jscomp$inline_8265_and__5023__auto__$jscomp$265$$);return $APP.$cljs$core$truth_$$($G__49130$jscomp$inline_8265_and__5023__auto__$jscomp$265$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__49127_SHARP_$$),$frame_id$jscomp$13$$):$G__49130$jscomp$inline_8265_and__5023__auto__$jscomp$265$$},$interactions$jscomp$7$$)};
$app$common$types$shape$interactions$flow_origin_QMARK_$$=function($interactions$jscomp$6$$){return $APP.$cljs$core$some$$(function($p1__49120_SHARP_$$){var $G__49122$jscomp$inline_8268_and__5023__auto__$jscomp$264$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__49120_SHARP_$$);var $fexpr__49121$jscomp$inline_8269$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1941$navigate$$,null,$APP.$cljs$cst$1942$close_overlay$$,
null,$APP.$cljs$cst$1944$toggle_overlay$$,null,$APP.$cljs$cst$1946$open_overlay$$,null],null),null);$G__49122$jscomp$inline_8268_and__5023__auto__$jscomp$264$$=$fexpr__49121$jscomp$inline_8269$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49121$jscomp$inline_8269$$.$cljs$core$IFn$_invoke$arity$1$($G__49122$jscomp$inline_8268_and__5023__auto__$jscomp$264$$):$fexpr__49121$jscomp$inline_8269$$($G__49122$jscomp$inline_8268_and__5023__auto__$jscomp$264$$);return $APP.$cljs$core$truth_$$($G__49122$jscomp$inline_8268_and__5023__auto__$jscomp$264$$)?
$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__49120_SHARP_$$)!=null:$G__49122$jscomp$inline_8268_and__5023__auto__$jscomp$264$$},$interactions$jscomp$6$$)};
$app$common$types$shape$interactions$has_direction_QMARK_$$=function($G__49107_interaction$jscomp$27$$){$G__49107_interaction$jscomp$27$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__49107_interaction$jscomp$27$$));var $fexpr__49106$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1956$push$$,null,$APP.$cljs$cst$1958$slide$$,null],null),null);return $fexpr__49106$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__49106$$.$cljs$core$IFn$_invoke$arity$1$($G__49107_interaction$jscomp$27$$):$fexpr__49106$$($G__49107_interaction$jscomp$27$$)};
$app$common$types$shape$interactions$has_easing_QMARK_$$=function($G__49102_interaction$jscomp$23$$){$G__49102_interaction$jscomp$23$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__49102_interaction$jscomp$23$$));var $fexpr__49101$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1956$push$$,null,$APP.$cljs$cst$1957$dissolve$$,null,$APP.$cljs$cst$1958$slide$$,
null],null),null);return $fexpr__49101$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49101$$.$cljs$core$IFn$_invoke$arity$1$($G__49102_interaction$jscomp$23$$):$fexpr__49101$$($G__49102_interaction$jscomp$23$$)};
$app$common$types$shape$interactions$has_duration_QMARK_$$=function($G__49100_interaction$jscomp$21$$){$G__49100_interaction$jscomp$21$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__49100_interaction$jscomp$21$$));var $fexpr__49099$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1956$push$$,null,$APP.$cljs$cst$1957$dissolve$$,null,$APP.$cljs$cst$1958$slide$$,
null],null),null);return $fexpr__49099$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49099$$.$cljs$core$IFn$_invoke$arity$1$($G__49100_interaction$jscomp$21$$):$fexpr__49099$$($G__49100_interaction$jscomp$21$$)};
$app$common$types$shape$interactions$has_animation_QMARK_$$=function($G__49082_interaction$jscomp$19$$){$G__49082_interaction$jscomp$19$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49082_interaction$jscomp$19$$);var $fexpr__49081$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1941$navigate$$,null,$APP.$cljs$cst$1942$close_overlay$$,null,$APP.$cljs$cst$1944$toggle_overlay$$,null,$APP.$cljs$cst$1946$open_overlay$$,
null],null),null);return $fexpr__49081$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49081$$.$cljs$core$IFn$_invoke$arity$1$($G__49082_interaction$jscomp$19$$):$fexpr__49081$$($G__49082_interaction$jscomp$19$$)};
$app$common$types$shape$interactions$has_overlay_opts$$=function($G__49025_interaction$jscomp$11$$){$G__49025_interaction$jscomp$11$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49025_interaction$jscomp$11$$);var $fexpr__49024$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$toggle_overlay$$,null,$APP.$cljs$cst$1946$open_overlay$$,null],null),null);return $fexpr__49024$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49024$$.$cljs$core$IFn$_invoke$arity$1$($G__49025_interaction$jscomp$11$$):
$fexpr__49024$$($G__49025_interaction$jscomp$11$$)};$app$common$types$shape$interactions$destination_QMARK_$$=function($interaction$jscomp$5$$){var $and__5023__auto__$jscomp$262$$=$APP.$app$common$types$shape$interactions$has_destination$$($interaction$jscomp$5$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$262$$)?$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$5$$)!=null:$and__5023__auto__$jscomp$262$$};
$app$main$data$workspace$bool$bool__GT_group$$=function($param49244$jscomp$inline_8272_shape$jscomp$447$$,$objects$jscomp$344$$){var $param49243$jscomp$inline_8271$$=$APP.$app$common$data$without_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($param49244$jscomp$inline_8272_shape$jscomp$447$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1608$group$$),$APP.$cljs$cst$1888$bool_type$$),$APP.$app$common$types$path$bool$group_style_properties$$);
$param49244$jscomp$inline_8272_shape$jscomp$447$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$344$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($param49244$jscomp$inline_8272_shape$jscomp$447$$));return $APP.$app$common$geom$shapes$transforms$update_group_selrect$$($param49243$jscomp$inline_8271$$,$param49244$jscomp$inline_8272_shape$jscomp$447$$)};
$app$common$types$modifiers$change_orientation_modifiers$$=function($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$,$orientation$jscomp$1_shape_transform$$){var $shape_transform_inv_width$jscomp$60$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$),$height$jscomp$53_new_height$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$),$new_width_scalev$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orientation$jscomp$1_shape_transform$$,$APP.$cljs$cst$1809$horiz$$)?$shape_transform_inv_width$jscomp$60$$>$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$:$shape_transform_inv_width$jscomp$60$$<$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$;$height$jscomp$53_new_height$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orientation$jscomp$1_shape_transform$$,
$APP.$cljs$cst$1809$horiz$$)?$shape_transform_inv_width$jscomp$60$$<$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$:$shape_transform_inv_width$jscomp$60$$>$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$;$orientation$jscomp$1_shape_transform$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$);$shape_transform_inv_width$jscomp$60$$=
$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$);var $shape_center$jscomp$1$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$),$map__48702_sr_width$jscomp$2$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$),$map__48702__$1_sr_height$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__48702_sr_width$jscomp$2$$);
$map__48702_sr_width$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48702__$1_sr_height$jscomp$2$$,$APP.$cljs$cst$290$width$$);$map__48702__$1_sr_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48702__$1_sr_height$jscomp$2$$,$APP.$cljs$cst$1522$height$$);$G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$));
$G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$=$orientation$jscomp$1_shape_transform$$!=null?$APP.$app$common$geom$matrix$transform_point_center$$($G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$,$shape_center$jscomp$1$$,$orientation$jscomp$1_shape_transform$$):$G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$;$new_width_scalev$$=$APP.$app$common$geom$point$divide$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($new_width_scalev$$,
$height$jscomp$53_new_height$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($map__48702_sr_width$jscomp$2$$,$map__48702__$1_sr_height$jscomp$2$$));return $APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($new_width_scalev$$,$G__48703$jscomp$inline_13229_origin$jscomp$16_shape$jscomp$74$$,$orientation$jscomp$1_shape_transform$$,$shape_transform_inv_width$jscomp$60$$)};
$app$main$data$workspace$transforms$rotation_modifiers$$=function($angle$jscomp$34$$,$shapes$jscomp$93$$,$center$jscomp$50$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69102_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__69102_SHARP_$$,$APP.$cljs$cst$1623$blocked$$,!1)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69103_SHARP_$$){return $APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__69103_SHARP_$$)))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69104_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69104_SHARP_$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$rotation_modifiers$$($p1__69104_SHARP_$$,
$center$jscomp$50$$,$angle$jscomp$34$$)],null)],null)})),$shapes$jscomp$93$$)};
$app$common$types$modifiers$resize_parent$cljs$0core$0IFn$0_invoke$0arity$05$$=function($vector$jscomp$13$$,$origin$jscomp$8$$,$transform$jscomp$32$$,$transform_inverse$jscomp$3$$){var $modifiers$jscomp$3_order$jscomp$9$$=$APP.$app$common$types$modifiers$empty$$(),$G__48646_modifiers__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($modifiers$jscomp$3_order$jscomp$9$$)?$modifiers$jscomp$3_order$jscomp$9$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$3_order$jscomp$9$$=($G__48646_modifiers__$1$jscomp$2$$?.$last_order$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48646_modifiers__$1$jscomp$2$$,$APP.$cljs$cst$1776$last_order$$))+1;$G__48646_modifiers__$1$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48646_modifiers__$1$jscomp$2$$,$APP.$cljs$cst$1776$last_order$$,$modifiers$jscomp$3_order$jscomp$9$$);return $APP.$app$common$types$modifiers$resize_vec_QMARK_$$($vector$jscomp$13$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48646_modifiers__$1$jscomp$2$$,$APP.$cljs$cst$1777$geometry_parent$$,
$APP.$app$common$types$modifiers$maybe_add_resize$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$3_order$jscomp$9$$,$APP.$cljs$cst$1799$resize$$,$vector$jscomp$13$$,$origin$jscomp$8$$,$transform$jscomp$32$$,$transform_inverse$jscomp$3$$,null,null,null,null,null)):$G__48646_modifiers__$1$jscomp$2$$};
$app$common$types$modifiers$move_parent$cljs$0core$0IFn$0_invoke$0arity$02$$=function($modifiers$jscomp$1_order$jscomp$7$$,$vector$jscomp$11$$){var $G__48638_modifiers__$1$$=$APP.$cljs$core$truth_$$($modifiers$jscomp$1_order$jscomp$7$$)?$modifiers$jscomp$1_order$jscomp$7$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$1_order$jscomp$7$$=($G__48638_modifiers__$1$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48638_modifiers__$1$$,$APP.$cljs$cst$1776$last_order$$))+
1;$G__48638_modifiers__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48638_modifiers__$1$$,$APP.$cljs$cst$1776$last_order$$,$modifiers$jscomp$1_order$jscomp$7$$);return $APP.$app$common$types$modifiers$move_vec_QMARK_$$($vector$jscomp$11$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48638_modifiers__$1$$,$APP.$cljs$cst$1777$geometry_parent$$,$APP.$app$common$types$modifiers$maybe_add_move$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$1_order$jscomp$7$$,
$APP.$cljs$cst$1798$move$$,$vector$jscomp$11$$,null,null,null,null,null,null,null,null)):$G__48638_modifiers__$1$$};
$app$util$dom$prevent_default_context_menu$$=function($event$jscomp$23$$){var $target$jscomp$112$$=$event$jscomp$23$$==null?null:$event$jscomp$23$$.target,$tag$jscomp$47$$=function(){var $G__46393__$1$$=$target$jscomp$112$$==null?null:$target$jscomp$112$$.tagName;return $G__46393__$1$$==null?null:$G__46393__$1$$.toLowerCase()}();return $APP.$cljs$core$truth_$$(function(){var $fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,["input",null,"textarea",null],null),null);$fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$=$fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$.$cljs$core$IFn$_invoke$arity$1$($tag$jscomp$47$$):$fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$($tag$jscomp$47$$);return $APP.$cljs$core$truth_$$($fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$)?$fexpr__46394$jscomp$inline_8274_or__5025__auto__$jscomp$301$$:
$target$jscomp$112$$==null?null:$target$jscomp$112$$.isContentEditable}())?null:$event$jscomp$23$$.preventDefault()};
$app$main$data$workspace$viewport$start_panning$$=function(){typeof $app$main$data$workspace$viewport$start_panning_71240$$==="undefined"&&($app$main$data$workspace$viewport$start_panning_71240$$=function($meta71241$$){this.$meta71241$=$meta71241$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$start_panning_71240$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$start_panning_71240$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4453$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_start_panning$$},$app$main$data$workspace$viewport$start_panning_71240$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71242$$,$meta71241__$1$$){return new $app$main$data$workspace$viewport$start_panning_71240$$($meta71241__$1$$)},$app$main$data$workspace$viewport$start_panning_71240$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71241$},$app$main$data$workspace$viewport$start_panning_71240$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$start_panning_71240$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2517_stopper$jscomp$37$$,$state$jscomp$868$$,$stream$jscomp$93$$){$_$jscomp$2517_stopper$jscomp$37$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4454$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_finish_panning$$),$stream$jscomp$93$$);var $zoom$jscomp$40$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$868$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null));return!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$868$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$868$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$4452$panning$$],null)))?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$viewport$activate_panning$$()),$APP.$beicon$v2$core$map$$(function($event$jscomp$106$$){var $delta$jscomp$53$$=$event$jscomp$106$$.$movement$;return $APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,function($p1__71238_SHARP_$$){return $p1__71238_SHARP_$$-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$53$$)/
$zoom$jscomp$40$$},$APP.$cljs$cst$1511$y$$,function($p1__71239_SHARP_$$){return $p1__71239_SHARP_$$-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$53$$)/$zoom$jscomp$40$$}],null))},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$4455$af$$,$APP.$beicon$v2$core$take_until$$($_$jscomp$2517_stopper$jscomp$37$$,$APP.$beicon$v2$core$filter$$(function($p1__71237_SHARP_$$){return $p1__71237_SHARP_$$.$movement$!=null},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,
$stream$jscomp$93$$)))))):null});return new $app$main$data$workspace$viewport$start_panning_71240$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport$initialize_viewport$$=function($p__71163$$){function $initialize$$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$,$local$jscomp$17_local__$1$$){var $page_id$jscomp$263_vx$jscomp$2$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$);$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$,$page_id$jscomp$263_vx$jscomp$2$$);$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$,
$APP.$app$common$uuid$zero$$,null);$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$);$local$jscomp$17_local__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$17_local__$1$$,$APP.$cljs$cst$2203$vport$$,$map__71164__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2196$zoom$$,
1,$APP.$cljs$cst$3577$zoom_inverse$$,1,$APP.$cljs$cst$3752$hide_toolbar$$,!1]));if($APP.$cljs$core$not$$($APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)))||$APP.$cljs$core$not$$($APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$))))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$17_local__$1$$,
$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__71164__$1$$,$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,0])));if($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)>$width$jscomp$157$$||$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)>
$height$jscomp$140$$){var $srect__$1$jscomp$4$$=$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$($map__71164__$1$$,$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$256$padding$$,40,$APP.$cljs$cst$3421$min_zoom$$,.01],null));$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__71164__$1$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect__$1$jscomp$4$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$17_local__$1$$,$APP.$cljs$cst$2196$zoom$$,$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$),
$APP.$cljs$cst$3577$zoom_inverse$$,1/$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$),$APP.$cljs$cst$1925$vbox$$,function($vbox$jscomp$26$$){return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$vbox$jscomp$26$$,$srect__$1$jscomp$4$$])))})}$page_id$jscomp$263_vx$jscomp$2$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)-$width$jscomp$157$$)/2;$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)-
$height$jscomp$140$$)/2;$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$=$APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71164__$1$$,$APP.$cljs$cst$1510$x$$,$page_id$jscomp$263_vx$jscomp$2$$),$APP.$cljs$cst$1511$y$$,$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$),
$APP.$cljs$cst$1676$position$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$17_local__$1$$,$APP.$cljs$cst$1925$vbox$$,$objects$jscomp$656_shapes$jscomp$119_srect$jscomp$9_state$jscomp$857_vbox$jscomp$25_vy$jscomp$3_zoom$jscomp$39$$)}function $update_STAR_$$($map__71172__$1_p__71171$$){$map__71172__$1_p__71171$$=$APP.$cljs$core$__destructure_map$$($map__71172__$1_p__71171$$);var $vport$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71172__$1_p__71171$$,
$APP.$cljs$cst$2203$vport$$),$wprop$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$6$$)/$width$jscomp$157$$,$hprop$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$6$$)/$height$jscomp$140$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71172__$1_p__71171$$,$APP.$cljs$cst$2203$vport$$,$map__71164__$1$$),$APP.$cljs$cst$1925$vbox$$,function($vbox$jscomp$24$$){return $APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($vbox$jscomp$24$$,
$APP.$cljs$cst$290$width$$,function($p1__71159_SHARP_$$){return $p1__71159_SHARP_$$/$wprop$$}),$APP.$cljs$cst$1522$height$$,function($p1__71160_SHARP_$$){return $p1__71160_SHARP_$$/$hprop$$}),$APP.$cljs$cst$874$size$$)})}var $map__71164__$1$$=$APP.$cljs$core$__destructure_map$$($p__71163$$),$width$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71164__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$140$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71164__$1$$,
$APP.$cljs$cst$1522$height$$);typeof $app$main$data$workspace$viewport$initialize_viewport_71178$$==="undefined"&&($app$main$data$workspace$viewport$initialize_viewport_71178$$=function($p__71163$jscomp$1$$,$map__71164$jscomp$1$$,$size$jscomp$127$$,$width$jscomp$158$$,$height$jscomp$141$$,$update_STAR_$jscomp$1$$,$initialize$jscomp$1$$,$setup$jscomp$1$$,$meta71179$$){this.$p__71163$=$p__71163$jscomp$1$$;this.$map__71164$=$map__71164$jscomp$1$$;this.size=$size$jscomp$127$$;this.width=$width$jscomp$158$$;
this.height=$height$jscomp$141$$;this.$update_STAR_$=$update_STAR_$jscomp$1$$;this.initialize=$initialize$jscomp$1$$;this.$setup$=$setup$jscomp$1$$;this.$meta71179$=$meta71179$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4447$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_initialize_viewport$$},$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71180$$,$meta71179__$1$$){return new $app$main$data$workspace$viewport$initialize_viewport_71178$$(this.$p__71163$,this.$map__71164$,this.size,this.width,this.height,this.$update_STAR_$,this.initialize,this.$setup$,$meta71179__$1$$)},$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71179$},$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2508$$,$state$jscomp$859$$){var $self__$jscomp$6120$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$859$$,$APP.$cljs$cst$1920$workspace_local$$,function($local$jscomp$19$$){return $self__$jscomp$6120$$.$setup$.$cljs$core$IFn$_invoke$arity$2$?
$self__$jscomp$6120$$.$setup$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$859$$,$local$jscomp$19$$):$self__$jscomp$6120$$.$setup$($state$jscomp$859$$,$local$jscomp$19$$)})},$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$initialize_viewport_71178$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2509$$,$state$jscomp$860$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$860$$)});
return new $app$main$data$workspace$viewport$initialize_viewport_71178$$($p__71163$$,$map__71164__$1$$,$map__71164__$1$$,$width$jscomp$157$$,$height$jscomp$140$$,$update_STAR_$$,$initialize$$,function($state$jscomp$858$$,$local$jscomp$18$$){var $JSCompiler_inline_result$jscomp$1581_and__5023__auto__$jscomp$inline_8276$$=$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$18$$);$JSCompiler_inline_result$jscomp$1581_and__5023__auto__$jscomp$inline_8276$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1581_and__5023__auto__$jscomp$inline_8276$$)?
$APP.$cljs$cst$2203$vport$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$18$$):$JSCompiler_inline_result$jscomp$1581_and__5023__auto__$jscomp$inline_8276$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1581_and__5023__auto__$jscomp$inline_8276$$)?$update_STAR_$$($local$jscomp$18$$):$initialize$$($state$jscomp$858$$,$local$jscomp$18$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport$sync_wasm_workspace_viewport$$=function(){typeof $app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$==="undefined"&&($app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$=function($meta71153$$){this.$meta71153$=$meta71153$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4446$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_sync_wasm_workspace_viewport$$},$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71154$$,$meta71153__$1$$){return new $app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$($meta71153__$1$$)},
$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71153$},$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2507$$,$state$jscomp$856$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$856$$)});
return new $app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71152$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$zoom$start_zooming$$=function($pt$jscomp$24$$){typeof $app$main$data$workspace$zoom$start_zooming_66295$$==="undefined"&&($app$main$data$workspace$zoom$start_zooming_66295$$=function($pt$jscomp$25$$,$meta66296$$){this.pt=$pt$jscomp$25$$;this.$meta66296$=$meta66296$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$start_zooming_66295$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$zoom$start_zooming_66295$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3586$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_start_zooming$$},$app$main$data$workspace$zoom$start_zooming_66295$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66297$$,$meta66296__$1$$){return new $app$main$data$workspace$zoom$start_zooming_66295$$(this.pt,$meta66296__$1$$)},$app$main$data$workspace$zoom$start_zooming_66295$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66296$},$app$main$data$workspace$zoom$start_zooming_66295$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$start_zooming_66295$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1914_stopper$jscomp$6$$,$state$jscomp$353$$,$stream$jscomp$38$$){var $self__$jscomp$4216$$=this;$_$jscomp$1914_stopper$jscomp$6$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3587$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_finish_zooming$$),
$stream$jscomp$38$$);return!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$353$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$353$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3588$zooming$$],null)))?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(function($s$jscomp$546$$){$app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$($s$jscomp$546$$);
return $s$jscomp$546$$}),(0,$APP.$beicon$v2$core$of$$)(function($p1__66293_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__66293_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3588$zooming$$],null),!0)}),$APP.$beicon$v2$core$map$$(function($delta$jscomp$31_scale$jscomp$25$$){$delta$jscomp$31_scale$jscomp$25$$=1+$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$31_scale$jscomp$25$$)/
100;return $APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4216$$.pt,$delta$jscomp$31_scale$jscomp$25$$)},$APP.$beicon$v2$core$take_until$$($_$jscomp$1914_stopper$jscomp$6$$,$APP.$beicon$v2$core$map$$($app$util$mouse$get_pointer_movement$$,$APP.$beicon$v2$core$filter$$(function($p1__66294_SHARP_$$){return $p1__66294_SHARP_$$.$movement$!=null},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,$stream$jscomp$38$$)))))):null});return new $app$main$data$workspace$zoom$start_zooming_66295$$($pt$jscomp$24$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$common$types$tokens_lib$group_by_type$$=function($tokens$jscomp$4_tokens_SINGLEQUOTE_$$){$tokens$jscomp$4_tokens_SINGLEQUOTE_$$=$APP.$cljs$core$map_QMARK_$$($tokens$jscomp$4_tokens_SINGLEQUOTE_$$)||$APP.$app$common$data$ordered_map_QMARK_$$($tokens$jscomp$4_tokens_SINGLEQUOTE_$$)?$APP.$cljs$core$vals$$($tokens$jscomp$4_tokens_SINGLEQUOTE_$$):$tokens$jscomp$4_tokens_SINGLEQUOTE_$$;return $APP.$cljs$core$group_by$$($APP.$cljs$cst$139$type$$,$tokens$jscomp$4_tokens_SINGLEQUOTE_$$)};
$app$main$ui$hooks$resize$use_resize_observer$$=function($callback$jscomp$91_node_ref$$){var $prev_val_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$observer_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$callback__$1$$=$app$main$ui$hooks$use_ref_callback$$($callback$jscomp$91_node_ref$$);$callback$jscomp$91_node_ref$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$335$$){if($node$jscomp$335$$!=null){var $G__71410_71430_observer_71421$$=$APP.$rumext$v2$ref_val$$($observer_ref$$),
$prev_val_71422$$=$APP.$rumext$v2$ref_val$$($prev_val_ref$$);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_val_71422$$,$node$jscomp$335$$)&&$G__71410_71430_observer_71421$$!=null&&($APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2683$action$$,"disconnect"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4547$js_SLASH_prev_val$$,$prev_val_71422$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4548$js_SLASH_node$$,$node$jscomp$335$$],null)],null)}),null,"app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$,!1),$G__71410_71430_observer_71421$$.disconnect(),
$APP.$rumext$v2$set_ref_val_BANG_$$($observer_ref$$,null));if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_val_71422$$,$node$jscomp$335$$)&&$node$jscomp$335$$!=null){var $observer_71429__$1$$=new ResizeObserver(function(){var $G__71408$$=$APP.$app$main$ui$hooks$resize$last_resize_type$$,$G__71409$$=$APP.$app$util$dom$get_client_size$$($node$jscomp$335$$);return $callback__$1$$.$cljs$core$IFn$_invoke$arity$2$?$callback__$1$$.$cljs$core$IFn$_invoke$arity$2$($G__71408$$,$G__71409$$):
$callback__$1$$($G__71408$$,$G__71409$$)});$APP.$rumext$v2$set_ref_val_BANG_$$($observer_ref$$,$observer_71429__$1$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2683$action$$,
"observe"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4548$js_SLASH_node$$,$node$jscomp$335$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4549$js_SLASH_observer$$,$observer_71429__$1$$],null)],null)}),null,"app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$,!1);$observer_71429__$1$$.observe($node$jscomp$335$$);$G__71410_71430_observer_71421$$=$APP.$app$main$ui$hooks$resize$last_resize_type$$;
var $G__71411_71431$$=$APP.$app$util$dom$get_client_size$$($node$jscomp$335$$);$callback__$1$$.$cljs$core$IFn$_invoke$arity$2$?$callback__$1$$.$cljs$core$IFn$_invoke$arity$2$($G__71410_71430_observer_71421$$,$G__71411_71431$$):$callback__$1$$($G__71410_71430_observer_71421$$,$G__71411_71431$$)}return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_val_ref$$,$node$jscomp$335$$)}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){var $temp__5825__auto__$jscomp$226$$=
$APP.$rumext$v2$ref_val$$($observer_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$226$$)?($APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2683$action$$,
"disconnect"],null)],null)}),null,"app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$,!1),$temp__5825__auto__$jscomp$226$$.disconnect()):null}});return $callback$jscomp$91_node_ref$$};
$app$main$data$persistence$update_file_revn$$=function($file_id$jscomp$39$$,$revn$jscomp$1$$){typeof $app$main$data$persistence$update_file_revn_55299$$==="undefined"&&($app$main$data$persistence$update_file_revn_55299$$=function($file_id$jscomp$40$$,$revn$jscomp$2$$,$meta55300$$){this.$file_id$=$file_id$jscomp$40$$;this.$revn$=$revn$jscomp$2$$;this.$meta55300$=$meta55300$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$update_file_revn_55299$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$update_file_revn_55299$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3152$app_DOT_main_DOT_data_DOT_persistence_SLASH_update_file_revn$$},$app$main$data$persistence$update_file_revn_55299$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55301$$,$meta55300__$1$$){return new $app$main$data$persistence$update_file_revn_55299$$(this.$file_id$,this.$revn$,$meta55300__$1$$)},$app$main$data$persistence$update_file_revn_55299$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55300$},$app$main$data$persistence$update_file_revn_55299$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$update_file_revn_55299$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1651$$,$state$jscomp$185$$){var $self__$jscomp$3510$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"update-file-revn"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,""+($self__$jscomp$3510$$.$file_id$??"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2270$revn$$,$self__$jscomp$3510$$.$revn$],
null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);return $app$main$data$helpers$update_file$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$185$$,$self__$jscomp$3510$$.$file_id$,function($p1__55298_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__55298_SHARP_$$,$APP.$cljs$cst$2270$revn$$,$APP.$cljs$core$max$$,$self__$jscomp$3510$$.$revn$)})},$app$main$data$persistence$update_file_revn_55299$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$update_file_revn_55299$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$persistence$revn_data$$,$APP.$cljs$core$update$$,this.$file_id$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$max$$,0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$revn$]))});return new $app$main$data$persistence$update_file_revn_55299$$($file_id$jscomp$39$$,
$revn$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$update_status$$=function($status$jscomp$14$$){typeof $app$main$data$persistence$update_status_55287$$==="undefined"&&($app$main$data$persistence$update_status_55287$$=function($status$jscomp$15$$,$meta55288$$){this.status=$status$jscomp$15$$;this.$meta55288$=$meta55288$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$update_status_55287$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$update_status_55287$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3148$app_DOT_main_DOT_data_DOT_persistence_SLASH_update_status$$},$app$main$data$persistence$update_status_55287$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55289$$,$meta55288__$1$$){return new $app$main$data$persistence$update_status_55287$$(this.status,$meta55288__$1$$)},$app$main$data$persistence$update_status_55287$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55288$},$app$main$data$persistence$update_status_55287$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$update_status_55287$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1650$$,$state$jscomp$184$$){var $self__$jscomp$3506$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$184$$,$APP.$cljs$cst$2178$persistence$$,function($pstate$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"update-status"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1863$from$$,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($pstate$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1864$to$$,$self__$jscomp$3506$$.status],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$144$trace$$,!1);var $status__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3506$$.status,$APP.$cljs$cst$111$pending$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($pstate$$),$APP.$cljs$cst$3149$saving$$)?
$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($pstate$$):$self__$jscomp$3506$$.status,$G__55293$$=function(){var $G__55294$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($pstate$$,$APP.$cljs$cst$109$status$$,$status__$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status__$1$$,$APP.$cljs$cst$849$error$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__55294$$,$APP.$cljs$cst$3150$run_id$$):$G__55294$$}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status__$1$$,
$APP.$cljs$cst$3151$saved$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__55293$$,$APP.$cljs$cst$3150$run_id$$):$G__55293$$})});return new $app$main$data$persistence$update_status_55287$$($status$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$persist_commit$$=function($commit_id$jscomp$4$$){typeof $app$main$data$persistence$persist_commit_55337$$==="undefined"&&($app$main$data$persistence$persist_commit_55337$$=function($commit_id$jscomp$5$$,$meta55338$$){this.$commit_id$=$commit_id$jscomp$5$$;this.$meta55338$=$meta55338$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$persist_commit_55337$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$persist_commit_55337$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3156$app_DOT_main_DOT_data_DOT_persistence_SLASH_persist_commit$$},$app$main$data$persistence$persist_commit_55337$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55339$$,$meta55338__$1$$){return new $app$main$data$persistence$persist_commit_55337$$(this.$commit_id$,$meta55338__$1$$)},$app$main$data$persistence$persist_commit_55337$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55338$},$app$main$data$persistence$persist_commit_55337$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$persist_commit_55337$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$,$state$jscomp$190$$){var $self__$jscomp$3528$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"persist-commit"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3146$commit_id$$,""+($self__$jscomp$3528$$.$commit_id$??"")],null)],null)}),
null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);$_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$190$$,$APP.$cljs$cst$2178$persistence$$),$APP.$cljs$cst$1795$index$$),$self__$jscomp$3528$$.$commit_id$);if($APP.$cljs$core$truth_$$($_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$)){var $map__55341__$1$$=
$APP.$cljs$core$__destructure_map$$($_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$),$file_id$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55341__$1$$,$APP.$cljs$cst$1644$file_id$$),$file_revn$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55341__$1$$,$APP.$cljs$cst$3139$file_revn$$);$_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55341__$1$$,
$APP.$cljs$cst$3143$file_vern$$);var $changes$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55341__$1$$,$APP.$cljs$cst$3131$changes$$),$features__$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55341__$1$$,$APP.$cljs$cst$227$features$$),$sid$$=$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$190$$),$revn$jscomp$3$$=function(){var $y__5111__auto__$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$data$persistence$revn_data$$),
$file_id$jscomp$41$$,0);return $file_revn$jscomp$2$$>$y__5111__auto__$jscomp$57$$?$file_revn$jscomp$2$$:$y__5111__auto__$jscomp$57$$}();$_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$227$features$$,$APP.$cljs$cst$2332$session_id$$,$APP.$cljs$cst$2270$revn$$,$APP.$cljs$cst$2577$vern$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$3146$commit_id$$,$APP.$cljs$cst$3131$changes$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$1569$created_at$$],
[$features__$1$jscomp$11$$,$sid$$,$revn$jscomp$3$$,$_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$,$file_id$jscomp$41$$,$self__$jscomp$3528$$.$commit_id$,$APP.$cljs$core$vec$$($changes$jscomp$5$$),$APP.$cljs$cst$1786$origin$$.$cljs$core$IFn$_invoke$arity$1$($map__55341__$1$$),$APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($map__55341__$1$$)]);var $permissions$jscomp$2$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$190$$);
return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$349$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$349$$)?$APP.$cljs$core$not$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$190$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2217$read_only_QMARK_$$],
null))):$and__5023__auto__$jscomp$349$$}())?$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$50$$){return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3157$authentication$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$50$$))?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3158$app_DOT_main_DOT_data_DOT_persistence_SLASH_error$$,
$cause$jscomp$50$$),$app$main$data$persistence$update_status$$($APP.$cljs$cst$849$error$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$discard_persistence_state$$()),$APP.$beicon$v2$core$throw$0$$($cause$jscomp$50$$))},$APP.$beicon$v2$core$mapcat$$(function($map__55352__$1_p__55351$$){$map__55352__$1_p__55351$$=$APP.$cljs$core$__destructure_map$$($map__55352__$1_p__55351$$);var $revn__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55352__$1_p__55351$$,$APP.$cljs$cst$2270$revn$$),
$lagged$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55352__$1_p__55351$$,$APP.$cljs$cst$3159$lagged$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"changes persisted"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3146$commit_id$$,""+($self__$jscomp$3528$$.$commit_id$??"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3159$lagged$$,$APP.$cljs$core$count$$($lagged$$)],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3160$app_DOT_main_DOT_data_DOT_persistence_SLASH_commit_persisted$$,
$map__55341__$1$$),$app$main$data$persistence$update_file_revn$$($file_id$jscomp$41$$,$revn__$1$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2265$update_file$$,$_$jscomp$1657_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$177$$))):null}return null});return new $app$main$data$persistence$persist_commit_55337$$($commit_id$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$append_commit$$=function($p__55313$$){var $map__55314__$1$$=$APP.$cljs$core$__destructure_map$$($p__55313$$),$id$jscomp$346$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55314__$1$$,$APP.$cljs$cst$266$id$$),$run_id$$=$APP.$app$common$uuid$next$$();typeof $app$main$data$persistence$append_commit_55315$$==="undefined"&&($app$main$data$persistence$append_commit_55315$$=function($p__55313$jscomp$1$$,$map__55314$jscomp$1$$,$commit$jscomp$7$$,$id$jscomp$347$$,
$run_id$jscomp$1$$,$meta55316$$){this.$p__55313$=$p__55313$jscomp$1$$;this.$map__55314$=$map__55314$jscomp$1$$;this.commit=$commit$jscomp$7$$;this.id=$id$jscomp$347$$;this.$run_id$=$run_id$jscomp$1$$;this.$meta55316$=$meta55316$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$append_commit_55315$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$append_commit_55315$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3154$app_DOT_main_DOT_data_DOT_persistence_SLASH_append_commit$$},$app$main$data$persistence$append_commit_55315$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55317$$,$meta55316__$1$$){return new $app$main$data$persistence$append_commit_55315$$(this.$p__55313$,this.$map__55314$,this.commit,this.id,this.$run_id$,$meta55316__$1$$)},$app$main$data$persistence$append_commit_55315$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55316$},
$app$main$data$persistence$append_commit_55315$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$append_commit_55315$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1654$$,$state$jscomp$187$$){var $self__$jscomp$3519$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"append-commit"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1578$method$$,"update"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3146$commit_id$$,""+($self__$jscomp$3519$$.id??"")],null)],
null)}),null,"app.main.data.persistence",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$187$$,$APP.$cljs$cst$2178$persistence$$,function($pstate$jscomp$2$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($pstate$jscomp$2$$,$APP.$cljs$cst$3150$run_id$$,$APP.$app$common$data$nilv$$,$self__$jscomp$3519$$.$run_id$),
$APP.$cljs$cst$1484$queue$$,$APP.$app$main$data$persistence$queue_conj$$,$self__$jscomp$3519$$.id),$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$assoc$$,$self__$jscomp$3519$$.id,$self__$jscomp$3519$$.commit)})},$app$main$data$persistence$append_commit_55315$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$append_commit_55315$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1655_pstate$jscomp$3$$,$state$jscomp$188$$){$_$jscomp$1655_pstate$jscomp$3$$=
$APP.$cljs$cst$2178$persistence$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$188$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$run_id$,$APP.$cljs$cst$3150$run_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1655_pstate$jscomp$3$$))?(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$persistence$run_persistence_task$$(),
$app$main$data$persistence$update_status$$($APP.$cljs$cst$3149$saving$$)):null});return new $app$main$data$persistence$append_commit_55315$$($p__55313$$,$map__55314__$1$$,$map__55314__$1$$,$id$jscomp$346$$,$run_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$initialize_persistence$$=function(){typeof $app$main$data$persistence$initialize_persistence_55381$$==="undefined"&&($app$main$data$persistence$initialize_persistence_55381$$=function($meta55382$$){this.$meta55382$=$meta55382$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$initialize_persistence_55381$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$initialize_persistence_55381$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3162$app_DOT_main_DOT_data_DOT_persistence_SLASH_initialize_persistence$$},$app$main$data$persistence$initialize_persistence_55381$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55383$$,$meta55382__$1$$){return new $app$main$data$persistence$initialize_persistence_55381$$($meta55382__$1$$)},$app$main$data$persistence$initialize_persistence_55381$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55382$},$app$main$data$persistence$initialize_persistence_55381$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$initialize_persistence_55381$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1660_stoper_s$jscomp$1$$,$___$1$jscomp$996_local_commits_s$$,$stream$jscomp$29$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"initialize persistence"],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);$_$jscomp$1660_stoper_s$jscomp$1$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3162$app_DOT_main_DOT_data_DOT_persistence_SLASH_initialize_persistence$$),$stream$jscomp$29$$);$___$1$jscomp$996_local_commits_s$$=
$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$cljs$core$empty_QMARK_$$),$APP.$beicon$v2$core$filter$$(function($p1__55377_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2883$local$$,$APP.$cljs$cst$193$source$$.$cljs$core$IFn$_invoke$arity$1$($p1__55377_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$stream$jscomp$29$$)))));
var $notifier_s$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"persistence beat"],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$144$trace$$,!1);return null},$APP.$beicon$v2$core$debounce$$(3E3,$___$1$jscomp$996_local_commits_s$$)),$APP.$beicon$v2$core$filter$$(function($p1__55378_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__55378_SHARP_$$,$APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$)},$stream$jscomp$29$$));return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function(){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3163$app_DOT_main_DOT_data_DOT_persistence_SLASH_persistence_notification$$)},
$notifier_s$$),$APP.$beicon$v2$core$take_until$$($_$jscomp$1660_stoper_s$jscomp$1$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$persistence$update_status$$($APP.$cljs$cst$111$pending$$)},$APP.$beicon$v2$core$debounce$$(200,$___$1$jscomp$996_local_commits_s$$))),$APP.$beicon$v2$core$finalize$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"finalize persistence: changes watcher"],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$delay$$(100,$_$jscomp$1660_stoper_s$jscomp$1$$),$APP.$beicon$v2$core$map$$($app$main$data$persistence$append_commit$$,$APP.$beicon$v2$core$mapcat$$($app$main$data$persistence$merge_commit$$,
$APP.$beicon$v2$core$buffer_until$$($notifier_s$$,$___$1$jscomp$996_local_commits_s$$))))),$APP.$beicon$v2$core$take_until$$($_$jscomp$1660_stoper_s$jscomp$1$$,$APP.$beicon$v2$core$mapcat$$(function($file_id$jscomp$42_p__55391$$){var $file_revn$jscomp$3_map__55392__$1$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$42_p__55391$$);$file_id$jscomp$42_p__55391$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_revn$jscomp$3_map__55392__$1$$,$APP.$cljs$cst$1644$file_id$$);$file_revn$jscomp$3_map__55392__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_revn$jscomp$3_map__55392__$1$$,$APP.$cljs$cst$3139$file_revn$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$update_file_revn$$($file_id$jscomp$42_p__55391$$,$file_revn$jscomp$3_map__55392__$1$$))},$APP.$beicon$v2$core$filter$$(function($p1__55380_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3164$remote$$,$APP.$cljs$cst$193$source$$.$cljs$core$IFn$_invoke$arity$1$($p1__55380_SHARP_$$))},
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$stream$jscomp$29$$))))))});return new $app$main$data$persistence$initialize_persistence_55381$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$tools$reader$impl$utils$ReaderConditional$$=function($splicing_QMARK_$$,$form$jscomp$7$$,$__meta$$,$__extmap$$,$__hash$jscomp$51$$){this.$splicing_QMARK_$=$splicing_QMARK_$$;this.form=$form$jscomp$7$$;this.$__meta$=$__meta$$;this.$__extmap$=$__extmap$$;this.$__hash$=$__hash$jscomp$51$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$tools$reader$impl$utils$reader_conditional$$=function($form$jscomp$9$$,$splicing_QMARK_$jscomp$2$$){return new $cljs$tools$reader$impl$utils$ReaderConditional$$($splicing_QMARK_$jscomp$2$$,$form$jscomp$9$$,null,null,null)};
$cljs$tools$reader$add_meta$$=function($form$jscomp$19$$,$ret$jscomp$62$$){return function(){var $and__5023__auto__$jscomp$39$$=$form$jscomp$19$$!=null?$form$jscomp$19$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$form$jscomp$19$$.$cljs$core$IWithMeta$$?!0:!1:!1;return $and__5023__auto__$jscomp$39$$?$APP.$cljs$core$seq$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$meta$$($form$jscomp$19$$),$APP.$cljs$cst$209$line$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$216$column$$,
$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$193$source$$]))):$and__5023__auto__$jscomp$39$$}()?new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$236$cljs_DOT_core_SLASH_with_meta$$,new $APP.$cljs$core$List$$(null,$ret$jscomp$62$$,new $APP.$cljs$core$List$$(null,function(){var $G__24887$$=$APP.$cljs$core$meta$$($form$jscomp$19$$);return $cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($G__24887$$):
$cljs$tools$reader$syntax_quote_STAR_$$($G__24887$$)}(),null,1,null),2,null),3,null):$ret$jscomp$62$$};
$cljs$tools$reader$syntax_quote_coll$$=function($type$jscomp$177$$,$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$){a:{$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$=$APP.$cljs$core$seq$$($G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$);for(var $G__25212$jscomp$inline_8284_r$jscomp$inline_8280_ret$jscomp$inline_8282$$=
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$){var $item$jscomp$inline_8281$$=$APP.$cljs$core$first$$($G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$);$G__25212$jscomp$inline_8284_r$jscomp$inline_8280_ret$jscomp$inline_8282$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__25212$jscomp$inline_8284_r$jscomp$inline_8280_ret$jscomp$inline_8282$$,
$cljs$tools$reader$unquote_QMARK_$$($item$jscomp$inline_8281$$)?new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$235$clojure_DOT_core_SLASH_list$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$core$second$$($item$jscomp$inline_8281$$),null,1,null),2,null):$cljs$tools$reader$unquote_splicing_QMARK_$$($item$jscomp$inline_8281$$)?$APP.$cljs$core$second$$($item$jscomp$inline_8281$$):new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$235$clojure_DOT_core_SLASH_list$$,new $APP.$cljs$core$List$$(null,$cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?
$cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_8281$$):$cljs$tools$reader$syntax_quote_STAR_$$($item$jscomp$inline_8281$$),null,1,null),2,null));$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$=$APP.$cljs$core$next$$($G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$)}else{$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$_persistent_BANG_$$($G__25212$jscomp$inline_8284_r$jscomp$inline_8280_ret$jscomp$inline_8282$$));break a}$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$=void 0}$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$=new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$237$cljs_DOT_core_SLASH_sequence$$,new $APP.$cljs$core$List$$(null,
$APP.$cljs$core$cons$$($APP.$cljs$cst$238$cljs_DOT_core_SLASH_concat$$,$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$),null,1,null),2,null);return $APP.$cljs$core$truth_$$($type$jscomp$177$$)?new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$239$cljs_DOT_core_SLASH_apply$$,new $APP.$cljs$core$List$$(null,$type$jscomp$177$$,new $APP.$cljs$core$List$$(null,$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$,
null,1,null),2,null),3,null):$G__25211$jscomp$inline_8283_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8279$$};
$cljs$tools$reader$syntax_quote_STAR_$$=function($form$jscomp$20$$){if($APP.$cljs$core$special_symbol_QMARK_$$($form$jscomp$20$$))var $JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$167$quote$$,new $APP.$cljs$core$List$$(null,$form$jscomp$20$$,null,
1,null),2,null);else if($form$jscomp$20$$ instanceof $APP.$cljs$core$Symbol$$)$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$167$quote$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$40$$=$APP.$cljs$core$not$$($APP.$cljs$core$namespace$$($form$jscomp$20$$));
return $and__5023__auto__$jscomp$40$$?$APP.$goog$string$internal$endsWith$$($APP.$cljs$core$name$$($form$jscomp$20$$),"#"):$and__5023__auto__$jscomp$40$$}())?$cljs$tools$reader$register_gensym$$($form$jscomp$20$$):function(){var $csym_sym$jscomp$19$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$20$$);return $APP.$cljs$core$truth_$$($APP.$goog$string$internal$endsWith$$($csym_sym$jscomp$19$$,"."))?($csym_sym$jscomp$19$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($csym_sym$jscomp$19$$,
0,$csym_sym$jscomp$19$$.length-1)),$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$tools$reader$resolve_symbol$$.call(null,$csym_sym$jscomp$19$$)),"."].join(""))):$cljs$tools$reader$resolve_symbol$$.call(null,$form$jscomp$20$$)}(),null,1,null),2,null);else if($cljs$tools$reader$unquote_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$APP.$cljs$core$second$$($form$jscomp$20$$);else{if($cljs$tools$reader$unquote_splicing_QMARK_$$($form$jscomp$20$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("unquote-splice not in list",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));if($APP.$cljs$core$coll_QMARK_$$($form$jscomp$20$$))if($form$jscomp$20$$!=null&&($form$jscomp$20$$.$cljs$lang$protocol_mask$partition0$$&67108864||$APP.$cljs$core$PROTOCOL_SENTINEL$$===
$form$jscomp$20$$.$cljs$core$IRecord$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=$form$jscomp$20$$;else if($APP.$cljs$core$map_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$cljs$tools$reader$syntax_quote_coll$$($APP.$cljs$core$count$$($form$jscomp$20$$)>=16?$APP.$cljs$cst$240$cljs_DOT_core_SLASH_hash_map$$:$APP.$cljs$cst$241$cljs_DOT_core_SLASH_array_map$$,$cljs$tools$reader$flatten_map$$($form$jscomp$20$$));else if($APP.$cljs$core$vector_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$243$cljs_DOT_core_SLASH_vec$$,new $APP.$cljs$core$List$$(null,$cljs$tools$reader$syntax_quote_coll$$(null,$form$jscomp$20$$),null,1,null),2,null);else if($APP.$cljs$core$set_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$cljs$tools$reader$syntax_quote_coll$$($APP.$cljs$cst$244$cljs_DOT_core_SLASH_hash_set$$,$form$jscomp$20$$);else if($APP.$cljs$core$seq_QMARK_$$($form$jscomp$20$$)||$APP.$cljs$core$list_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=function(){var $seq$jscomp$1$$=$APP.$cljs$core$seq$$($form$jscomp$20$$);
return $seq$jscomp$1$$?$cljs$tools$reader$syntax_quote_coll$$(null,$seq$jscomp$1$$):$APP.$cljs$core$list$$($APP.$cljs$cst$245$cljs_DOT_core_SLASH_list$$)}();else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Unknown Collection type",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$246$unsupported_operation$$],null));else $JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$form$jscomp$20$$ instanceof $APP.$cljs$core$Keyword$$||typeof $form$jscomp$20$$==="number"||typeof $form$jscomp$20$$==="string"||$form$jscomp$20$$==null||$form$jscomp$20$$ instanceof Boolean||$form$jscomp$20$$===!0||$form$jscomp$20$$===!1||$form$jscomp$20$$ instanceof RegExp?$form$jscomp$20$$:new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$167$quote$$,new $APP.$cljs$core$List$$(null,$form$jscomp$20$$,null,1,null),2,null)}return $cljs$tools$reader$add_meta$$($form$jscomp$20$$,$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$)};
$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$=function($or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$){$or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],
null));$or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$=$APP.$cljs$cst$925$types$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$)?$or__5025__auto__$jscomp$895_state$jscomp$964_value$jscomp$725$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$};
$app$common$logic$tokens$toggle_token_set_group$$=function($group_path$jscomp$7_sets_names$$,$tokens_lib$jscomp$21$$,$tokens_lib_theme$$){var $deactivate_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2124$all$$,null,$APP.$cljs$cst$2125$partial$$,null],null),null),$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$($tokens_lib$jscomp$21$$,$group_path$jscomp$7_sets_names$$));$group_path$jscomp$7_sets_names$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_name$$,$app$common$types$tokens_lib$get_sets_at_path$$($tokens_lib$jscomp$21$$,$group_path$jscomp$7_sets_names$$)));return $deactivate_QMARK_$$?$app$common$types$tokens_lib$disable_sets$$($tokens_lib_theme$$,$group_path$jscomp$7_sets_names$$):$app$common$types$tokens_lib$enable_sets$$($tokens_lib_theme$$,$group_path$jscomp$7_sets_names$$)};
$app$common$files$tokens$shapes_ids_by_applied_attributes$$=function($token$jscomp$72$$,$shapes$jscomp$121$$,$token_attributes$jscomp$2$$){var $conj_STAR_$jscomp$1$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$317$$,$shape$jscomp$762$$){var $shape_id$jscomp$130$$=$shape$jscomp$762$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$762$$,
$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result__$1$jscomp$40$$,$attr$jscomp$56$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($result__$1$jscomp$40$$,$attr$jscomp$56$$,$conj_STAR_$jscomp$1$$,$shape_id$jscomp$130$$)},$result$jscomp$317$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71723_SHARP_$$){return $APP.$app$common$files$tokens$token_attribute_applied_QMARK_$$($token$jscomp$72$$,$shape$jscomp$762$$,
$p1__71723_SHARP_$$)},$token_attributes$jscomp$2$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$shapes$jscomp$121$$)};
$app$main$data$workspace$select_assets$$=function($file_id$jscomp$289$$,$assets_ids$$,$type$jscomp$539$$){typeof $app$main$data$workspace$select_assets_71933$$==="undefined"&&($app$main$data$workspace$select_assets_71933$$=function($file_id$jscomp$290$$,$assets_ids$jscomp$1$$,$type$jscomp$540$$,$meta71934$$){this.$file_id$=$file_id$jscomp$290$$;this.$assets_ids$=$assets_ids$jscomp$1$$;this.type=$type$jscomp$540$$;this.$meta71934$=$meta71934$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$select_assets_71933$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_assets_71933$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4501$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_assets$$},$app$main$data$workspace$select_assets_71933$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71935$$,$meta71934__$1$$){return new $app$main$data$workspace$select_assets_71933$$(this.$file_id$,
this.$assets_ids$,this.type,$meta71934__$1$$)},$app$main$data$workspace$select_assets_71933$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71934$},$app$main$data$workspace$select_assets_71933$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_assets_71933$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2572$$,$state$jscomp$911$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$911$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$1921$selected$$,this.$file_id$,this.type],null),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,this.$assets_ids$))});return new $app$main$data$workspace$select_assets_71933$$($file_id$jscomp$289$$,$assets_ids$$,$type$jscomp$539$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$check_in_asset$$=function($items$jscomp$49_items__$1$jscomp$6$$,$element$jscomp$72$$){$items$jscomp$49_items__$1$jscomp$6$$=$APP.$cljs$core$truth_$$($items$jscomp$49_items__$1$jscomp$6$$)?$items$jscomp$49_items__$1$jscomp$6$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$cljs$core$contains_QMARK_$$($items$jscomp$49_items__$1$jscomp$6$$,$element$jscomp$72$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$49_items__$1$jscomp$6$$,$element$jscomp$72$$):
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$49_items__$1$jscomp$6$$,$element$jscomp$72$$)};
$app$main$data$workspace$toggle_selected_assets$$=function($file_id$jscomp$285$$,$asset_id$jscomp$12$$,$type$jscomp$535$$){typeof $app$main$data$workspace$toggle_selected_assets_71922$$==="undefined"&&($app$main$data$workspace$toggle_selected_assets_71922$$=function($file_id$jscomp$286$$,$asset_id$jscomp$13$$,$type$jscomp$536$$,$meta71923$$){this.$file_id$=$file_id$jscomp$286$$;this.$asset_id$=$asset_id$jscomp$13$$;this.type=$type$jscomp$536$$;this.$meta71923$=$meta71923$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$toggle_selected_assets_71922$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_selected_assets_71922$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4499$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_selected_assets$$},$app$main$data$workspace$toggle_selected_assets_71922$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71924$$,
$meta71923__$1$$){return new $app$main$data$workspace$toggle_selected_assets_71922$$(this.$file_id$,this.$asset_id$,this.type,$meta71923__$1$$)},$app$main$data$workspace$toggle_selected_assets_71922$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71923$},$app$main$data$workspace$toggle_selected_assets_71922$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_selected_assets_71922$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2570$$,$state$jscomp$909$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$909$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$1921$selected$$,this.$file_id$,this.type],null),$app$main$data$workspace$check_in_asset$$,this.$asset_id$)});return new $app$main$data$workspace$toggle_selected_assets_71922$$($file_id$jscomp$285$$,$asset_id$jscomp$12$$,
$type$jscomp$535$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$select_track_cells$$=function($grid_id$jscomp$17$$,$type$jscomp$507$$,$index$jscomp$352$$){typeof $app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$=function($grid_id$jscomp$18$$,$type$jscomp$508$$,$index$jscomp$353$$,$meta70951$$){this.$grid_id$=$grid_id$jscomp$18$$;this.type=$type$jscomp$508$$;this.index=$index$jscomp$353$$;this.$meta70951$=$meta70951$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4391$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_select_track_cells$$},$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70952$$,$meta70951__$1$$){return new $app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$(this.$grid_id$,this.type,this.index,$meta70951__$1$$)},$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70951$},$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$,$state$jscomp$822$$){$_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$822$$);$_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$,
this.$grid_id$);$_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$,this.index):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$,
this.index);$_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$822$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1921$selected$$],null),$_$jscomp$2460_cells$jscomp$22_objects$jscomp$621_parent$jscomp$276_selected$jscomp$88$$)});return new $app$main$data$workspace$grid_layout$editor$select_track_cells_70950$$($grid_id$jscomp$17$$,$type$jscomp$507$$,$index$jscomp$352$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$hover_grid_cell$$=function($grid_id$$,$cell_id$$,$add_to_set$$){typeof $app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$=function($grid_id$jscomp$1$$,$cell_id$jscomp$1$$,$add_to_set$jscomp$1$$,$meta70817$$){this.$grid_id$=$grid_id$jscomp$1$$;this.$cell_id$=$cell_id$jscomp$1$$;this.$add_to_set$=$add_to_set$jscomp$1$$;this.$meta70817$=$meta70817$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4383$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_hover_grid_cell$$},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70818$$,$meta70817__$1$$){return new $app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$(this.$grid_id$,this.$cell_id$,this.$add_to_set$,$meta70817__$1$$)},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70817$},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2452$$,$state$jscomp$814$$){var $self__$jscomp$5905$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$814$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,$self__$jscomp$5905$$.$grid_id$,$APP.$cljs$cst$2204$hover$$],null),function($hover_set_hover_set__$1$$){$hover_set_hover_set__$1$$=$APP.$cljs$core$truth_$$($hover_set_hover_set__$1$$)?$hover_set_hover_set__$1$$:
$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$cljs$core$truth_$$($self__$jscomp$5905$$.$add_to_set$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($hover_set_hover_set__$1$$,$self__$jscomp$5905$$.$cell_id$):$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($hover_set_hover_set__$1$$,$self__$jscomp$5905$$.$cell_id$)})});return new $app$main$data$workspace$grid_layout$editor$hover_grid_cell_70816$$($grid_id$$,$cell_id$$,$add_to_set$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$set_hover_guide$$=function($id$jscomp$714$$,$hover_QMARK_$$){typeof $app$main$data$workspace$guides$set_hover_guide_70304$$==="undefined"&&($app$main$data$workspace$guides$set_hover_guide_70304$$=function($id$jscomp$715$$,$hover_QMARK_$jscomp$1$$,$meta70305$$){this.id=$id$jscomp$715$$;this.$hover_QMARK_$=$hover_QMARK_$jscomp$1$$;this.$meta70305$=$meta70305$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$set_hover_guide_70304$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$set_hover_guide_70304$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4293$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_set_hover_guide$$},$app$main$data$workspace$guides$set_hover_guide_70304$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70306$$,$meta70305__$1$$){return new $app$main$data$workspace$guides$set_hover_guide_70304$$(this.id,this.$hover_QMARK_$,$meta70305__$1$$)},
$app$main$data$workspace$guides$set_hover_guide_70304$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70305$},$app$main$data$workspace$guides$set_hover_guide_70304$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$set_hover_guide_70304$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2381_sconj$$,$state$jscomp$758$$){$_$jscomp$2381_sconj$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $sdisj$jscomp$1$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$758$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4289$workspace_guides$$,$APP.$cljs$cst$2204$hover$$],null),$_$jscomp$2381_sconj$$,
this.id):$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$758$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4289$workspace_guides$$,$APP.$cljs$cst$2204$hover$$],null),$sdisj$jscomp$1$$,this.id)});return new $app$main$data$workspace$guides$set_hover_guide_70304$$($id$jscomp$714$$,$hover_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$deselect_all$$=function(){typeof $app$main$data$workspace$path$selection$deselect_all_69740$$==="undefined"&&($app$main$data$workspace$path$selection$deselect_all_69740$$=function($meta69741$$){this.$meta69741$=$meta69741$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$deselect_all_69740$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$deselect_all_69740$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4243$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_deselect_all$$},$app$main$data$workspace$path$selection$deselect_all_69740$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69742$$,$meta69741__$1$$){return new $app$main$data$workspace$path$selection$deselect_all_69740$$($meta69741__$1$$)},$app$main$data$workspace$path$selection$deselect_all_69740$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69741$},$app$main$data$workspace$path$selection$deselect_all_69740$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$deselect_all_69740$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2323_id$jscomp$682$$,$state$jscomp$714$$){$_$jscomp$2323_id$jscomp$682$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$714$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$714$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2323_id$jscomp$682$$,$APP.$cljs$cst$4241$selected_points$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$)});return new $app$main$data$workspace$path$selection$deselect_all_69740$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_handler_enter$$=function($index$jscomp$324$$,$prefix$jscomp$52$$){typeof $app$main$data$workspace$path$selection$path_handler_enter_69700$$==="undefined"&&($app$main$data$workspace$path$selection$path_handler_enter_69700$$=function($index$jscomp$325$$,$prefix$jscomp$53$$,$meta69701$$){this.index=$index$jscomp$325$$;this.prefix=$prefix$jscomp$53$$;this.$meta69701$=$meta69701$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$selection$path_handler_enter_69700$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_enter_69700$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4237$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_handler_enter$$},$app$main$data$workspace$path$selection$path_handler_enter_69700$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69702$$,
$meta69701__$1$$){return new $app$main$data$workspace$path$selection$path_handler_enter_69700$$(this.index,this.prefix,$meta69701__$1$$)},$app$main$data$workspace$path$selection$path_handler_enter_69700$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69701$},$app$main$data$workspace$path$selection$path_handler_enter_69700$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_enter_69700$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2319_id$jscomp$678$$,$state$jscomp$710$$){$_$jscomp$2319_id$jscomp$678$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$710$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$710$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2319_id$jscomp$678$$,$APP.$cljs$cst$4238$hover_handlers$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.index,this.prefix],null))});return new $app$main$data$workspace$path$selection$path_handler_enter_69700$$($index$jscomp$324$$,$prefix$jscomp$52$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_pointer_enter$$=function($position$jscomp$138$$){typeof $app$main$data$workspace$path$selection$path_pointer_enter_69691$$==="undefined"&&($app$main$data$workspace$path$selection$path_pointer_enter_69691$$=function($position$jscomp$139$$,$meta69692$$){this.position=$position$jscomp$139$$;this.$meta69692$=$meta69692$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$path_pointer_enter_69691$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_enter_69691$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4234$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_pointer_enter$$},$app$main$data$workspace$path$selection$path_pointer_enter_69691$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69693$$,$meta69692__$1$$){return new $app$main$data$workspace$path$selection$path_pointer_enter_69691$$(this.position,
$meta69692__$1$$)},$app$main$data$workspace$path$selection$path_pointer_enter_69691$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69692$},$app$main$data$workspace$path$selection$path_pointer_enter_69691$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_enter_69691$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2317_id$jscomp$676$$,$state$jscomp$708$$){$_$jscomp$2317_id$jscomp$676$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$708$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$708$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2317_id$jscomp$676$$,$APP.$cljs$cst$4235$hover_points$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),
this.position)});return new $app$main$data$workspace$path$selection$path_pointer_enter_69691$$($position$jscomp$138$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$cleanup_unlinked_libraries$$=function($file_id$jscomp$187$$,$libraries$jscomp$81$$){typeof $app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$==="undefined"&&($app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$=function($file_id$jscomp$188$$,$libraries$jscomp$82$$,$meta69963$$){this.$file_id$=$file_id$jscomp$188$$;this.libraries=$libraries$jscomp$82$$;this.$meta69963$=$meta69963$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3989$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_cleanup_unlinked_libraries$$},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69964$$,$meta69963__$1$$){return new $app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$(this.$file_id$,this.libraries,$meta69963__$1$$)},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69963$},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2152$$,$state$jscomp$536$$){var $self__$jscomp$4933$$=this,$linked_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$self__$jscomp$4933$$.libraries);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$536$$,$APP.$cljs$cst$1916$files$$,function($files$jscomp$13$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$131$$,
$id$jscomp$601$$,$file$jscomp$68$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2180$library_of$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$68$$),$self__$jscomp$4933$$.$file_id$)&&!$APP.$cljs$core$contains_QMARK_$$($linked_ids$$,$id$jscomp$601$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$601$$,$self__$jscomp$4933$$.$file_id$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$131$$,$id$jscomp$601$$):$acc$jscomp$131$$},
$files$jscomp$13$$,$files$jscomp$13$$)})});return new $app$main$data$workspace$libraries$cleanup_unlinked_libraries_69962$$($file_id$jscomp$187$$,$libraries$jscomp$81$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$unlink_file_from_library$$=function($file_id$jscomp$189$$,$library_id$jscomp$49$$){typeof $app$main$data$workspace$libraries$detach_library_69976$$==="undefined"&&($app$main$data$workspace$libraries$detach_library_69976$$=function($file_id$jscomp$190$$,$library_id$jscomp$50$$,$meta69977$$){this.$file_id$=$file_id$jscomp$190$$;this.$library_id$=$library_id$jscomp$50$$;this.$meta69977$=$meta69977$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3990$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_library$$},$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69978$$,$meta69977__$1$$){return new $app$main$data$workspace$libraries$detach_library_69976$$(this.$file_id$,
this.$library_id$,$meta69977__$1$$)},$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69977$},$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"detach-library",$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$3966$library_id$$,this.$library_id$],null)},$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2154$$,$state$jscomp$537$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$537$$,$APP.$cljs$cst$1916$files$$,
$APP.$cljs$core$dissoc$$,this.$library_id$)},$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_69976$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4939$$=this;return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$libraries$cleanup_unlinked_libraries$$,$self__$jscomp$4939$$.$file_id$),
$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3991$get_file_libraries$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4939$$.$file_id$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3992$unlink_file_from_library$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4939$$.$file_id$,$APP.$cljs$cst$3966$library_id$$,
$self__$jscomp$4939$$.$library_id$],null))))});return new $app$main$data$workspace$libraries$detach_library_69976$$($file_id$jscomp$189$$,$library_id$jscomp$49$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$refs$parents_by_ids$$=function($ids$jscomp$27$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$163$$){var $parent_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__50243_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$163$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p1__50243_SHARP_$$,$APP.$cljs$cst$1619$parent_id$$],null))}),$ids$jscomp$27$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__50244_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$163$$,$p1__50244_SHARP_$$)}),$parent_ids$$)},$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$)};
$app$main$data$workspace$path$edition$move_selected_path_point$$=function($from_point$jscomp$1$$,$to_point$$){typeof $app$main$data$workspace$path$edition$move_point_69868$$==="undefined"&&($app$main$data$workspace$path$edition$move_point_69868$$=function($from_point$jscomp$2$$,$to_point$jscomp$1$$,$meta69869$$){this.$from_point$=$from_point$jscomp$2$$;this.$to_point$=$to_point$jscomp$1$$;this.$meta69869$=$meta69869$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$edition$move_point_69868$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_point_69868$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4253$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_point$$},$app$main$data$workspace$path$edition$move_point_69868$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69870$$,$meta69869__$1$$){return new $app$main$data$workspace$path$edition$move_point_69868$$(this.$from_point$,
this.$to_point$,$meta69869__$1$$)},$app$main$data$workspace$path$edition$move_point_69868$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69869$},$app$main$data$workspace$path$edition$move_point_69868$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_point_69868$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2331_id$jscomp$689$$,$state$jscomp$722$$){$_$jscomp$2331_id$jscomp$689$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$722$$);var $content$jscomp$214_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$722$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));var $G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$=this.$to_point$;$G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$4203$shift_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(this.$to_point$))?$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$,this.$from_point$):$G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$;$G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$=$APP.$app$common$geom$point$subtract$$($G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$,
this.$from_point$);$content$jscomp$214_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$data$workspace$path$edition$modify_content_point$$,$content$jscomp$214_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$,$G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$);$G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$722$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2331_id$jscomp$689$$),$APP.$cljs$cst$4241$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $modifiers$jscomp$102$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$722$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),
$_$jscomp$2331_id$jscomp$689$$),$APP.$cljs$cst$1924$content_modifiers$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$content$jscomp$214_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$214_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$,$modifiers$jscomp$102$$,$G__69872$jscomp$inline_8288_delta$jscomp$49_points$jscomp$90_to_point__$1$$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$722$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2331_id$jscomp$689$$,$APP.$cljs$cst$4251$moving_nodes$$],null),!0),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2331_id$jscomp$689$$,$APP.$cljs$cst$1924$content_modifiers$$],null),$content$jscomp$214_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$)});
return new $app$main$data$workspace$path$edition$move_point_69868$$($from_point$jscomp$1$$,$to_point$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$modify_handler$$=function($id$jscomp$685$$,$index$jscomp$328$$,$prefix$jscomp$56$$,$dx$jscomp$23$$,$dy$jscomp$23$$,$match_opposite_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$path$edition$modify_handler_69813$$==="undefined"&&($app$main$data$workspace$path$edition$modify_handler_69813$$=function($id$jscomp$686$$,$index$jscomp$329$$,$prefix$jscomp$57$$,$dx$jscomp$24$$,$dy$jscomp$24$$,$match_opposite_QMARK_$jscomp$2$$,$meta69814$$){this.id=$id$jscomp$686$$;
this.index=$index$jscomp$329$$;this.prefix=$prefix$jscomp$57$$;this.dx=$dx$jscomp$24$$;this.dy=$dy$jscomp$24$$;this.$match_opposite_QMARK_$=$match_opposite_QMARK_$jscomp$2$$;this.$meta69814$=$meta69814$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$modify_handler_69813$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$modify_handler_69813$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4248$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_modify_handler$$},$app$main$data$workspace$path$edition$modify_handler_69813$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69815$$,$meta69814__$1$$){return new $app$main$data$workspace$path$edition$modify_handler_69813$$(this.id,this.index,this.prefix,this.dx,this.dy,this.$match_opposite_QMARK_$,$meta69814__$1$$)},$app$main$data$workspace$path$edition$modify_handler_69813$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69814$},$app$main$data$workspace$path$edition$modify_handler_69813$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$modify_handler_69813$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2328_modifiers$jscomp$100$$,$state$jscomp$719$$){var $content$jscomp$210_point$jscomp$72$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$719$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$_$jscomp$2328_modifiers$jscomp$100$$=$APP.$app$main$data$workspace$path$helpers$move_handler_modifiers$$($content$jscomp$210_point$jscomp$72$$,this.index,this.prefix,!1,this.$match_opposite_QMARK_$,this.dx,this.dy);var $cy$jscomp$19_vec__69819$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.prefix,$APP.$cljs$cst$1821$c1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1816$c1y$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1817$c2x$$,$APP.$cljs$cst$1818$c2y$$],null),$cx$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cy$jscomp$19_vec__69819$$,0,null);$cy$jscomp$19_vec__69819$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cy$jscomp$19_vec__69819$$,1,null);$content$jscomp$210_point$jscomp$72$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$210_point$jscomp$72$$,
this.index),$APP.$cljs$cst$1430$params$$),$cx$jscomp$18$$)+this.dx,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$210_point$jscomp$72$$,this.index),$APP.$cljs$cst$1430$params$$),$cy$jscomp$19_vec__69819$$)+this.dy);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$719$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,this.id,$APP.$cljs$cst$1924$content_modifiers$$],null),$APP.$cljs$core$merge$$,$_$jscomp$2328_modifiers$jscomp$100$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,this.id,$APP.$cljs$cst$4249$moving_handler$$],null),$content$jscomp$210_point$jscomp$72$$)});return new $app$main$data$workspace$path$edition$modify_handler_69813$$($id$jscomp$685$$,
$index$jscomp$328$$,$prefix$jscomp$56$$,$dx$jscomp$23$$,$dy$jscomp$23$$,$match_opposite_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$select_node_area$$=function($initial_set$jscomp$4$$,$remove_QMARK_$jscomp$8$$){typeof $app$main$data$workspace$path$selection$select_node_area_69719$$==="undefined"&&($app$main$data$workspace$path$selection$select_node_area_69719$$=function($initial_set$jscomp$5$$,$remove_QMARK_$jscomp$9$$,$meta69720$$){this.$initial_set$=$initial_set$jscomp$5$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$9$$;this.$meta69720$=$meta69720$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$select_node_area_69719$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_area_69719$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4240$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_select_node_area$$},$app$main$data$workspace$path$selection$select_node_area_69719$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69721$$,$meta69720__$1$$){return new $app$main$data$workspace$path$selection$select_node_area_69719$$(this.$initial_set$,this.$remove_QMARK_$,$meta69720__$1$$)},$app$main$data$workspace$path$selection$select_node_area_69719$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69720$},$app$main$data$workspace$path$selection$select_node_area_69719$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_area_69719$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2321_id$jscomp$680$$,$state$jscomp$712$$){var $selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$712$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1605$selrect$$);$_$jscomp$2321_id$jscomp$680$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$712$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$2199$edition$$);var $content$jscomp$209_positions$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$712$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$=$selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$!=null?$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$has_point_rect_QMARK_$$,
$selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$):$APP.$cljs$core$constantly$$(!1);$selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69715_SHARP_$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($p1__69715_SHARP_$$),$APP.$cljs$cst$1850$close_path$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$point$point$$,
$APP.$cljs$cst$1430$params$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$));$content$jscomp$209_positions$$=$APP.$cljs$core$truth_$$(this.$remove_QMARK_$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$disj$$,this.$initial_set$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$,$content$jscomp$209_positions$$)):
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(this.$initial_set$,$selected_point_QMARK__selrect$jscomp$72_xform$jscomp$37$$,$content$jscomp$209_positions$$);return $_$jscomp$2321_id$jscomp$680$$!=null?$APP.$cljs$core$assoc_in$$($state$jscomp$712$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2321_id$jscomp$680$$,$APP.$cljs$cst$4241$selected_points$$],null),$content$jscomp$209_positions$$):
$state$jscomp$712$$});return new $app$main$data$workspace$path$selection$select_node_area_69719$$($initial_set$jscomp$4$$,$remove_QMARK_$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$handle_area_selection$$=function($append_QMARK_$jscomp$2$$,$remove_QMARK_$jscomp$10$$){typeof $app$main$data$workspace$path$selection$handle_area_selection_69765$$==="undefined"&&($app$main$data$workspace$path$selection$handle_area_selection_69765$$=function($append_QMARK_$jscomp$3$$,$remove_QMARK_$jscomp$11$$,$valid_rect_QMARK_$jscomp$1$$,$meta69766$$){this.$append_QMARK_$=$append_QMARK_$jscomp$3$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$11$$;this.$valid_rect_QMARK_$=
$valid_rect_QMARK_$jscomp$1$$;this.$meta69766$=$meta69766$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$handle_area_selection_69765$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$handle_area_selection_69765$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4246$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_handle_area_selection$$},
$app$main$data$workspace$path$selection$handle_area_selection_69765$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69767$$,$meta69766__$1$$){return new $app$main$data$workspace$path$selection$handle_area_selection_69765$$(this.$append_QMARK_$,this.$remove_QMARK_$,this.$valid_rect_QMARK_$,$meta69766__$1$$)},$app$main$data$workspace$path$selection$handle_area_selection_69765$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69766$},$app$main$data$workspace$path$selection$handle_area_selection_69765$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$handle_area_selection_69765$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2326_id$jscomp$683$$,$selrect_stream$jscomp$1_state$jscomp$717$$,$stopper$jscomp$26_stream$jscomp$76$$){var $self__$jscomp$5503$$=this;$_$jscomp$2326_id$jscomp$683$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_stream$jscomp$1_state$jscomp$717$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$2199$edition$$);var $zoom$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_stream$jscomp$1_state$jscomp$717$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2196$zoom$$,1);$stopper$jscomp$26_stream$jscomp$76$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$26_stream$jscomp$76$$,null);var $from_p$jscomp$13$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),
$initial_set$jscomp$6$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$822$$=$self__$jscomp$5503$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$822$$)?$or__5025__auto__$jscomp$822$$:$self__$jscomp$5503$$.$remove_QMARK_$}())?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_stream$jscomp$1_state$jscomp$717$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2326_id$jscomp$683$$),$APP.$cljs$cst$4241$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$):$APP.$cljs$core$PersistentHashSet$EMPTY$$;$selrect_stream$jscomp$1_state$jscomp$717$$=$APP.$beicon$v2$core$take_until$$($stopper$jscomp$26_stream$jscomp$76$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5503$$.$valid_rect_QMARK_$,$zoom$jscomp$31$$),$APP.$beicon$v2$core$map$$(function($p1__69757_SHARP_$$){return $APP.$app$common$geom$rect$points__GT_rect$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_p$jscomp$13$$,$p1__69757_SHARP_$$],null))},$APP.$app$main$streams$mouse_position$$)));return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$823$$=$self__$jscomp$5503$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$823$$)?$or__5025__auto__$jscomp$823$$:$self__$jscomp$5503$$.$remove_QMARK_$}())?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$selection$deselect_all$$()),
$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$path$selection$update_area_selection$$,$selrect_stream$jscomp$1_state$jscomp$717$$),$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$path$selection$select_node_area$$($initial_set$jscomp$6$$,$self__$jscomp$5503$$.$remove_QMARK_$)},$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$($APP.$cljs$core$last$$,
$APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$selrect_stream$jscomp$1_state$jscomp$717$$))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$selection$clear_area_selection$$()))});return new $app$main$data$workspace$path$selection$handle_area_selection_69765$$($append_QMARK_$jscomp$2$$,$remove_QMARK_$jscomp$10$$,function($zoom$jscomp$30$$,$p__69763_width$jscomp$151$$){var $height$jscomp$135_map__69764__$1$$=$APP.$cljs$core$__destructure_map$$($p__69763_width$jscomp$151$$);
$p__69763_width$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$135_map__69764__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$135_map__69764__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$135_map__69764__$1$$,$APP.$cljs$cst$1522$height$$);return $p__69763_width$jscomp$151$$>10/$zoom$jscomp$30$$||$height$jscomp$135_map__69764__$1$$>10/$zoom$jscomp$30$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$geom$shapes$transforms$update_shapes_geometry$$=function($objects$jscomp$106$$,$ids$jscomp$17$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects__$1$jscomp$1$$,$id$jscomp$153$$){var $shape$jscomp$113_shape__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$1$$,$id$jscomp$153$$),$children$jscomp$164$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects__$1$jscomp$1$$,
$id$jscomp$153$$);$shape$jscomp$113_shape__$1$jscomp$6$$=$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$113_shape__$1$jscomp$6$$)?$APP.$app$common$geom$shapes$transforms$update_mask_selrect$$($shape$jscomp$113_shape__$1$jscomp$6$$,$children$jscomp$164$$):$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$113_shape__$1$jscomp$6$$)?$APP.$app$common$types$path$update_bool_shape$$($shape$jscomp$113_shape__$1$jscomp$6$$,$objects__$1$jscomp$1$$):
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$113_shape__$1$jscomp$6$$)?$APP.$app$common$geom$shapes$transforms$update_group_selrect$$($shape$jscomp$113_shape__$1$jscomp$6$$,$children$jscomp$164$$):$shape$jscomp$113_shape__$1$jscomp$6$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects__$1$jscomp$1$$,$id$jscomp$153$$,$shape$jscomp$113_shape__$1$jscomp$6$$)},$objects$jscomp$106$$,$ids$jscomp$17$$)};
$app$common$geom$shapes$update_shapes_geometry$$=function($param49287$$,$param49288$$){return $app$common$geom$shapes$transforms$update_shapes_geometry$$($param49287$$,$param49288$$)};
$app$main$data$workspace$shape_layout$copy_grid_tracks$$=function($grid_id$jscomp$19$$,$type$jscomp$531$$){typeof $app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$==="undefined"&&($app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$=function($grid_id$jscomp$20$$,$type$jscomp$532$$,$meta71291$$){this.$grid_id$=$grid_id$jscomp$20$$;this.type=$type$jscomp$532$$;this.$meta71291$=$meta71291$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4417$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_copy_grid_tracks$$},$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71292$$,$meta71291__$1$$){return new $app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$(this.$grid_id$,
this.type,$meta71291__$1$$)},$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71291$},$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$,
$state$jscomp$833$$){$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$833$$);var $grid$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$,this.$grid_id$);$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$833$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1921$selected$$],null));$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71289_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$7$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$p1__71289_SHARP_$$],null))},$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$);$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$);
var $last_column$jscomp$14_map__71293__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$);$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71293__$1$$,$APP.$cljs$cst$1715$first_row$$);var $last_row$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71293__$1$$,
$APP.$cljs$cst$1717$last_row$$),$first_column$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71293__$1$$,$APP.$cljs$cst$1716$first_column$$);$last_column$jscomp$14_map__71293__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71293__$1$$,$APP.$cljs$cst$1718$last_column$$);$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,
$APP.$cljs$cst$1656$row$$)?$APP.$cljs$core$vec$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$-1,$last_row$jscomp$14$$)):$APP.$cljs$core$vec$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($first_column$jscomp$14$$-1,$last_column$jscomp$14_map__71293__$1$$));return $APP.$cljs$core$assoc_in$$($state$jscomp$833$$,new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$4418$copied_tracks$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4419$track_indices$$,$_$jscomp$2482_cells$jscomp$27_first_row$jscomp$14_map__71293_objects$jscomp$638_selected$jscomp$94_track_indices$$,$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$4420$grid_id$$,this.$grid_id$],null))});return new $app$main$data$workspace$shape_layout$copy_grid_tracks_71290$$($grid_id$jscomp$19$$,
$type$jscomp$531$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$=function($grid_id$jscomp$3$$,$cell_id$jscomp$3$$,$shift_QMARK_$jscomp$29$$){typeof $app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$=function($grid_id$jscomp$4$$,$cell_id$jscomp$4$$,$shift_QMARK_$jscomp$30$$,$meta70844$$){this.$grid_id$=$grid_id$jscomp$4$$;this.$cell_id$=$cell_id$jscomp$4$$;this.$shift_QMARK_$=
$shift_QMARK_$jscomp$30$$;this.$meta70844$=$meta70844$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4384$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_add_to_selection$$},
$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70845$$,$meta70844__$1$$){return new $app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$(this.$grid_id$,this.$cell_id$,this.$shift_QMARK_$,$meta70844__$1$$)},$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70844$},$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$,$state$jscomp$815$$){var $self__$jscomp$5909$$=this;if($APP.$cljs$core$truth_$$($self__$jscomp$5909$$.$shift_QMARK_$)){$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$815$$);var $grid$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$,$self__$jscomp$5909$$.$grid_id$);$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=function(){var $or__5025__auto__$jscomp$839$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$815$$,$APP.$cljs$cst$2240$workspace_grid_edition$$),$self__$jscomp$5909$$.$grid_id$),$APP.$cljs$cst$1921$selected$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$839$$)?$or__5025__auto__$jscomp$839$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}();$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5909$$.$cell_id$],null));$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70834_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$4$$,
$APP.$cljs$cst$1696$layout_grid_cells$$),$p1__70834_SHARP_$$)},$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$);$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$);
var $last_column$jscomp$9_map__70856__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$);$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__70856__$1$$,$APP.$cljs$cst$1715$first_row$$);var $last_row$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__70856__$1$$,$APP.$cljs$cst$1717$last_row$$),$first_column$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__70856__$1$$,$APP.$cljs$cst$1716$first_column$$);$last_column$jscomp$9_map__70856__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__70856__$1$$,$APP.$cljs$cst$1718$last_column$$);$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$app$common$types$shape$layout$cells_in_area$$($grid$jscomp$4$$,$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$,$last_row$jscomp$9$$,$first_column$jscomp$9$$,$last_column$jscomp$9_map__70856__$1$$));return $APP.$cljs$core$assoc_in$$($state$jscomp$815$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,$self__$jscomp$5909$$.$grid_id$,$APP.$cljs$cst$1921$selected$$],null),$_$jscomp$2453_cells$jscomp$21_first_row$jscomp$9_map__70856_new_selected_objects$jscomp$618_selected$jscomp$86_selected__$1$jscomp$9$$)}return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$815$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2240$workspace_grid_edition$$,$self__$jscomp$5909$$.$grid_id$,$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$self__$jscomp$5909$$.$cell_id$)});return new $app$main$data$workspace$grid_layout$editor$add_to_selection_70843$$($grid_id$jscomp$3$$,$cell_id$jscomp$3$$,$shift_QMARK_$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$shape$layout$valid_area_cells_QMARK_$$=function($cells$jscomp$17$$){var $map__48403$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$17$$),$map__48403__$1$$=$APP.$cljs$core$__destructure_map$$($map__48403$$),$first_row$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48403__$1$$,$APP.$cljs$cst$1715$first_row$$),$last_row$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48403__$1$$,$APP.$cljs$cst$1717$last_row$$),
$first_column$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48403__$1$$,$APP.$cljs$cst$1716$first_column$$),$last_column$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48403__$1$$,$APP.$cljs$cst$1718$last_column$$),$cell_coords$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48403__$1$$,$APP.$cljs$cst$1719$cell_coords$$);return $APP.$cljs$core$every_QMARK_$$(function($p1__48399_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($cell_coords$jscomp$5$$,
$p1__48399_SHARP_$$)},function(){return function $app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48404$$($s__48405$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__48405__$1$$=$s__48405$$;;){var $fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$=$APP.$cljs$core$seq$$($s__48405__$1$$);if($fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$){var $xs__6385__auto__$jscomp$9$$=$fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$,$r$jscomp$83$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$9$$);
if($fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$=$APP.$cljs$core$seq$$(function($s__48405__$1$jscomp$1$$,$r$jscomp$84$$,$xs__6385__auto__$jscomp$10$$,$temp__5825__auto__$jscomp$121$$,$map__48403$jscomp$1$$,$map__48403__$1$jscomp$1$$,$first_row$jscomp$7$$,$last_row$jscomp$7$$,$first_column$jscomp$7$$,$last_column$jscomp$7$$,$cell_coords$jscomp$6$$){return function $app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48404_$_iter__48406$$($s__48407$$){return new $APP.$cljs$core$LazySeq$$(null,
function($s__48405__$1$jscomp$2$$,$r$jscomp$85$$){return function(){for(;;){var $s__48407__$2_temp__5825__auto____$1$jscomp$6$$=$APP.$cljs$core$seq$$($s__48407$$);if($s__48407__$2_temp__5825__auto____$1$jscomp$6$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__48407__$2_temp__5825__auto____$1$jscomp$6$$)){var $JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$=$APP.$cljs$core$_chunked_first$$($s__48407__$2_temp__5825__auto____$1$jscomp$6$$),$size__5502__auto__$jscomp$14$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$),
$b__48409_c$jscomp$264$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$14$$);a:{for(var $i__48408$jscomp$inline_8290$$=0;;)if($i__48408$jscomp$inline_8290$$<$size__5502__auto__$jscomp$14$$){var $c$jscomp$inline_8291$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$,$i__48408$jscomp$inline_8290$$);$b__48409_c$jscomp$264$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$85$$,$c$jscomp$inline_8291$$],
null));$i__48408$jscomp$inline_8290$$+=1}else{$JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$=!0;break a}$JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$=void 0}return $JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48409_c$jscomp$264$$),$app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48404_$_iter__48406$$($APP.$cljs$core$_chunked_rest$$($s__48407__$2_temp__5825__auto____$1$jscomp$6$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48409_c$jscomp$264$$),null)}$b__48409_c$jscomp$264$$=$APP.$cljs$core$first$$($s__48407__$2_temp__5825__auto____$1$jscomp$6$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$85$$,$b__48409_c$jscomp$264$$],null),$app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48404_$_iter__48406$$($APP.$cljs$core$rest$$($s__48407__$2_temp__5825__auto____$1$jscomp$6$$)))}return null}}}($s__48405__$1$jscomp$1$$,
$r$jscomp$84$$,$xs__6385__auto__$jscomp$10$$,$temp__5825__auto__$jscomp$121$$,$map__48403$jscomp$1$$,$map__48403__$1$jscomp$1$$,$first_row$jscomp$7$$,$last_row$jscomp$7$$,$first_column$jscomp$7$$,$last_column$jscomp$7$$,$cell_coords$jscomp$6$$),null,null)}}($s__48405__$1$$,$r$jscomp$83$$,$xs__6385__auto__$jscomp$9$$,$fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$,$map__48403$$,$map__48403__$1$$,$first_row$jscomp$6$$,$last_row$jscomp$6$$,$first_column$jscomp$6$$,$last_column$jscomp$6$$,
$cell_coords$jscomp$5$$)($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($first_column$jscomp$6$$,$last_column$jscomp$6$$+1))))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$,$app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48404$$($APP.$cljs$core$rest$$($s__48405__$1$$)));$s__48405__$1$$=$APP.$cljs$core$rest$$($s__48405__$1$$)}else return null}},null,null)}($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($first_row$jscomp$6$$,
$last_row$jscomp$6$$+1))}())};
$app$common$types$shape$layout$duplicate_cells$$=function($shape$jscomp$61$$,$prop$jscomp$15_to_cells$$,$from_index$jscomp$2_vec__48080$$,$shape__$1_to_index$$,$ids_map$$){var $vec__48077$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$15_to_cells$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$column_span$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$],null):new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1657$row_span$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$],null),$prop_span$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48077$$,0,null),$prop_other$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48077$$,1,null),$prop_other_span$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48077$$,2,null),$from_cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$15_to_cells$$,
$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$61$$,$from_index$jscomp$2_vec__48080$$):$app$common$types$shape$layout$cells_by_column$$($shape$jscomp$61$$,$from_index$jscomp$2_vec__48080$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$61$$,
$from_index$jscomp$2_vec__48080$$):$app$common$types$shape$layout$cells_by_row$$($shape$jscomp$61$$,$from_index$jscomp$2_vec__48080$$);$prop$jscomp$15_to_cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$15_to_cells$$,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$61$$,$shape__$1_to_index$$):$app$common$types$shape$layout$cells_by_column$$($shape$jscomp$61$$,
$shape__$1_to_index$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$61$$,$shape__$1_to_index$$):$app$common$types$shape$layout$cells_by_row$$($shape$jscomp$61$$,$shape__$1_to_index$$);var $to_cells_idx$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($prop_other$jscomp$1$$,$prop$jscomp$15_to_cells$$);$from_index$jscomp$2_vec__48080$$=function(){for(var $G__48578_from_cells__$1$$=
$APP.$cljs$core$seq$$($from_cells$$),$G__48579_matched$jscomp$2$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__48580_result$jscomp$156$$=$shape$jscomp$61$$;;){var $cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$=$APP.$cljs$core$first$$($G__48578_from_cells__$1$$);if($APP.$cljs$core$truth_$$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$)){var $G__48085$jscomp$inline_13234_G__48086$jscomp$inline_13235$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($to_cells_idx$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$,$prop_other$jscomp$1$$)),$APP.$cljs$core$select_keys$$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prop_other_span$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1678$justify_self$$],null)));$G__48085$jscomp$inline_13234_G__48086$jscomp$inline_13235$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1674$area$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48085$jscomp$inline_13234_G__48086$jscomp$inline_13235$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$):$G__48085$jscomp$inline_13234_G__48086$jscomp$inline_13235$$;$cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$,
$prop_span$jscomp$3$$),1)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48085$jscomp$inline_13234_G__48086$jscomp$inline_13235$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($ids_map$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$))):$G__48085$jscomp$inline_13234_G__48086$jscomp$inline_13235$$;$G__48578_from_cells__$1$$=$APP.$cljs$core$rest$$($G__48578_from_cells__$1$$);$G__48579_matched$jscomp$2$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48579_matched$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$));$G__48580_result$jscomp$156$$=$APP.$cljs$core$assoc_in$$($G__48580_result$jscomp$156$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$)],
null),$cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$)}else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__48580_result$jscomp$156$$,$G__48579_matched$jscomp$2$$],null)}}();$shape__$1_to_index$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_index$jscomp$2_vec__48080$$,0,null);var $matched$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_index$jscomp$2_vec__48080$$,1,null);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$2$jscomp$1$$,
$cell$jscomp$5$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$2$jscomp$1$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$5$$))},$shape__$1_to_index$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$143_map__48092__$1_p__48091$$){$id$jscomp$143_map__48092__$1_p__48091$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$143_map__48092__$1_p__48091$$);$id$jscomp$143_map__48092__$1_p__48091$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$143_map__48092__$1_p__48091$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$contains_QMARK_$$($matched$jscomp$1$$,$id$jscomp$143_map__48092__$1_p__48091$$)},$prop$jscomp$15_to_cells$$))};
$app$common$types$shape_tree$get_root_shapes$$=function($objects$jscomp$140$$){return $APP.$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$140$$,function($result$jscomp$209$$,$shape$jscomp$213$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$213$$)?$result$jscomp$209$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$209$$,$shape$jscomp$213$$)})};
$app$common$types$shape_tree$get_root_frames_ids$$=function($objects$jscomp$138$$){return $APP.$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$138$$,function($result$jscomp$207$$,$shape$jscomp$211$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$211$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$207$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$211$$)):
$result$jscomp$207$$})};$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$=function($svg_data$jscomp$3$$,$pos$jscomp$102$$,$objects$jscomp$357$$){var $selected$jscomp$34$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$app$common$uuid$next$$(),$svg_data$jscomp$3$$,$pos$jscomp$102$$,$objects$jscomp$357$$,$APP.$app$common$uuid$zero$$,null,$selected$jscomp$34$$,!1)};
$app$common$geom$shapes$fit_frame$fit_frame_modifiers$$=function($new_origin_objects$jscomp$114$$,$p__48851_resize_v_selrect$jscomp$21$$){var $center$jscomp$28_map__48852__$1$$=$APP.$cljs$core$__destructure_map$$($p__48851_resize_v_selrect$jscomp$21$$),$id$jscomp$155_ids$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48852__$1$$,$APP.$cljs$cst$266$id$$),$transform$jscomp$56_transform__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48852__$1$$,
$APP.$cljs$cst$1289$transform$$),$transform_inverse$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48852__$1$$,$APP.$cljs$cst$1787$transform_inverse$$);$p__48851_resize_v_selrect$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48852__$1$$,$APP.$cljs$cst$1605$selrect$$);var $origin$jscomp$18_points$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48852__$1$$,$APP.$cljs$cst$1604$points$$),
$show_content$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48852__$1$$,$APP.$cljs$cst$1876$show_content$$),$bounds$jscomp$8_children$jscomp$167$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($new_origin_objects$jscomp$114$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$28_map__48852__$1$$));if($APP.$app$common$data$not_empty_QMARK_$$($bounds$jscomp$8_children$jscomp$167$$)){$id$jscomp$155_ids$jscomp$19$$=
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($new_origin_objects$jscomp$114$$,$id$jscomp$155_ids$jscomp$19$$);$center$jscomp$28_map__48852__$1$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($center$jscomp$28_map__48852__$1$$);var $transform_inverse__$1$$=$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$28_map__48852__$1$$,$transform_inverse$jscomp$12$$);$transform$jscomp$56_transform__$1$jscomp$3$$=$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$28_map__48852__$1$$,
$transform$jscomp$56_transform__$1$jscomp$3$$);var $tr_objects$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__48846_SHARP_$$,$p2__48848_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__48846_SHARP_$$,$p2__48848_SHARP_$$,$APP.$app$common$geom$shapes$transforms$apply_transform$$,$transform_inverse__$1$$)},$new_origin_objects$jscomp$114$$,$id$jscomp$155_ids$jscomp$19$$);$bounds$jscomp$8_children$jscomp$167$$=$APP.$app$common$geom$rect$join_rects$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48850_SHARP_$$){return $APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($tr_objects$$,
$p1__48850_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1912$ignore_shadow_margin_QMARK_$$,$show_content$$,$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1],null))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48849_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tr_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__48849_SHARP_$$))},$bounds$jscomp$8_children$jscomp$167$$)));$new_origin_objects$jscomp$114$$=
$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$8_children$jscomp$167$$),$transform$jscomp$56_transform__$1$jscomp$3$$);$origin$jscomp$18_points$jscomp$47$$=$APP.$cljs$core$first$$($origin$jscomp$18_points$jscomp$47$$);$p__48851_resize_v_selrect$jscomp$21$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$8_children$jscomp$167$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($p__48851_resize_v_selrect$jscomp$21$$),
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$8_children$jscomp$167$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($p__48851_resize_v_selrect$jscomp$21$$));return $app$common$types$modifiers$move_parent$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$resize_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($p__48851_resize_v_selrect$jscomp$21$$,$origin$jscomp$18_points$jscomp$47$$,$transform$jscomp$56_transform__$1$jscomp$3$$,$transform_inverse__$1$$),
$APP.$app$common$geom$point$subtract$$($new_origin_objects$jscomp$114$$,$origin$jscomp$18_points$jscomp$47$$))}return null};
$app$main$data$workspace$interactions$connected_frame_QMARK_$$=function($objects$jscomp$607$$,$frame_id$jscomp$103$$){var $children$jscomp$249_or__5025__auto__$jscomp$829$$=$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$607$$,$frame_id$jscomp$103$$);$children$jscomp$249_or__5025__auto__$jscomp$829$$=$APP.$cljs$core$some$$($app$common$types$shape$interactions$flow_origin_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2051$interactions$$,$children$jscomp$249_or__5025__auto__$jscomp$829$$));
return $APP.$cljs$core$truth_$$($children$jscomp$249_or__5025__auto__$jscomp$829$$)?$children$jscomp$249_or__5025__auto__$jscomp$829$$:$APP.$cljs$core$some$$(function($p1__70450_SHARP_$$){return $app$common$types$shape$interactions$flow_to_QMARK_$$($p1__70450_SHARP_$$,$frame_id$jscomp$103$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2051$interactions$$,$APP.$cljs$core$vals$$($objects$jscomp$607$$)))};
$app$common$files$helpers$component_touched_QMARK_$$=function($objects$jscomp$43$$,$root_id$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$cst$1626$touched$$),$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$43$$,$root_id$$)))};
$app$util$text$content$to_dom$get_paragraph_styles$$=function($font_size$jscomp$7_paragraph$jscomp$6$$){var $styles$jscomp$7$$=$app$util$text$content$to_dom$get_styles_from_attrs$$($font_size$jscomp$7_paragraph$jscomp$6$$,$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$text$paragraph_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_node_attrs$$])));$font_size$jscomp$7_paragraph$jscomp$6$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__53613_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",
$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($p1__53613_SHARP_$$))},$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$7_paragraph$jscomp$6$$)))?"0":$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$7$$,$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$));var $line_height$jscomp$6_line_height__$1$jscomp$1$$=$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($styles$jscomp$7$$);
$line_height$jscomp$6_line_height__$1$jscomp$1$$=$line_height$jscomp$6_line_height__$1$jscomp$1$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$line_height$jscomp$6_line_height__$1$jscomp$1$$)?$line_height$jscomp$6_line_height__$1$jscomp$1$$:$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($styles$jscomp$7$$,$APP.$cljs$cst$1760$font_size$$,
$font_size$jscomp$7_paragraph$jscomp$6$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1765$line_height$$,$line_height$jscomp$6_line_height__$1$jscomp$1$$]))};
$app$main$data$workspace$layout$ensure_layout$$=function($name$jscomp$320$$){typeof $app$main$data$workspace$layout$ensure_layout_67141$$==="undefined"&&($app$main$data$workspace$layout$ensure_layout_67141$$=function($name$jscomp$321$$,$meta67142$$){this.name=$name$jscomp$321$$;this.$meta67142$=$meta67142$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layout$ensure_layout_67141$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$layout$ensure_layout_67141$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3733$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_ensure_layout$$},$app$main$data$workspace$layout$ensure_layout_67141$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67143$$,$meta67142__$1$$){return new $app$main$data$workspace$layout$ensure_layout_67141$$(this.name,$meta67142__$1$$)},$app$main$data$workspace$layout$ensure_layout_67141$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67142$},$app$main$data$workspace$layout$ensure_layout_67141$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$ensure_layout_67141$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1985$$,$state$jscomp$409$$){var $self__$jscomp$4432$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$409$$,$APP.$cljs$cst$2209$workspace_layout$$,function($stored$$){var $todel$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$layout$presets$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4432$$.name,$APP.$cljs$cst$3729$del$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$),$toadd$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$layout$presets$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$self__$jscomp$4432$$.name,$APP.$cljs$cst$3730$add$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($stored$$,$todel$$),$toadd$$)})});return new $app$main$data$workspace$layout$ensure_layout_67141$$($name$jscomp$320$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$initialize_workspace_layout$$=function($lname$jscomp$1$$){typeof $app$main$data$workspace$initialize_layout_71560$$==="undefined"&&($app$main$data$workspace$initialize_layout_71560$$=function($lname$jscomp$2$$,$meta71561$$){this.$lname$=$lname$jscomp$2$$;this.$meta71561$=$meta71561$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$initialize_layout_71560$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$initialize_layout_71560$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4456$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_layout$$},$app$main$data$workspace$initialize_layout_71560$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71562$$,$meta71561__$1$$){return new $app$main$data$workspace$initialize_layout_71560$$(this.$lname$,$meta71561__$1$$)},$app$main$data$workspace$initialize_layout_71560$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71561$},$app$main$data$workspace$initialize_layout_71560$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_layout_71560$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2520$$,$state$jscomp$871$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$871$$,$APP.$cljs$cst$2209$workspace_layout$$,function($p1__71558_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__71558_SHARP_$$)?
$p1__71558_SHARP_$$:$APP.$app$main$data$workspace$layout$default_layout$$}),$APP.$cljs$cst$2188$workspace_global$$,function($p1__71559_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__71559_SHARP_$$)?$p1__71559_SHARP_$$:$APP.$app$main$data$workspace$layout$default_global$$})},$app$main$data$workspace$initialize_layout_71560$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_layout_71560$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8295$$=this.$lname$;$JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8295$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8295$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$main$data$workspace$layout$presets$$,this.$lname$):$JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8295$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8295$$)?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$layout$ensure_layout$$(this.$lname$)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$layout$ensure_layout$$($APP.$cljs$cst$3727$layers$$))});return new $app$main$data$workspace$initialize_layout_71560$$($lname$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$variant$same_variant_QMARK_$$=function($components$jscomp$1_variant_ids$$){$components$jscomp$1_variant_ids$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2000$variant_id$$,$components$jscomp$1_variant_ids$$));var $not_blank_QMARK_$$=$APP.$cljs$core$complement$$($APP.$cuerdas$core$blank_QMARK_$$),$and__5023__auto__$jscomp$267$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($components$jscomp$1_variant_ids$$));
return $and__5023__auto__$jscomp$267$$?$not_blank_QMARK_$$($APP.$cljs$core$first$$($components$jscomp$1_variant_ids$$)):$and__5023__auto__$jscomp$267$$};
$app$main$data$workspace$select_single_asset$$=function($file_id$jscomp$287$$,$asset_id$jscomp$14$$,$type$jscomp$537$$){typeof $app$main$data$workspace$select_single_asset_71928$$==="undefined"&&($app$main$data$workspace$select_single_asset_71928$$=function($file_id$jscomp$288$$,$asset_id$jscomp$15$$,$type$jscomp$538$$,$meta71929$$){this.$file_id$=$file_id$jscomp$288$$;this.$asset_id$=$asset_id$jscomp$15$$;this.type=$type$jscomp$538$$;this.$meta71929$=$meta71929$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$select_single_asset_71928$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_single_asset_71928$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4500$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_single_asset$$},$app$main$data$workspace$select_single_asset_71928$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71930$$,$meta71929__$1$$){return new $app$main$data$workspace$select_single_asset_71928$$(this.$file_id$,
this.$asset_id$,this.type,$meta71929__$1$$)},$app$main$data$workspace$select_single_asset_71928$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71929$},$app$main$data$workspace$select_single_asset_71928$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_single_asset_71928$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2571$$,$state$jscomp$910$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$910$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$1921$selected$$,this.$file_id$,this.type],null),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.$asset_id$]))});return new $app$main$data$workspace$select_single_asset_71928$$($file_id$jscomp$287$$,$asset_id$jscomp$14$$,$type$jscomp$537$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$set_selection$$=function($grid_id$jscomp$5$$,$cell_id$jscomp$5$$){typeof $app$main$data$workspace$grid_layout$editor$set_selection_70872$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$set_selection_70872$$=function($grid_id$jscomp$6$$,$cell_id$jscomp$6$$,$meta70873$$){this.$grid_id$=$grid_id$jscomp$6$$;this.$cell_id$=$cell_id$jscomp$6$$;this.$meta70873$=$meta70873$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$grid_layout$editor$set_selection_70872$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$set_selection_70872$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4385$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_set_selection$$},$app$main$data$workspace$grid_layout$editor$set_selection_70872$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70874$$,
$meta70873__$1$$){return new $app$main$data$workspace$grid_layout$editor$set_selection_70872$$(this.$grid_id$,this.$cell_id$,$meta70873__$1$$)},$app$main$data$workspace$grid_layout$editor$set_selection_70872$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70873$},$app$main$data$workspace$grid_layout$editor$set_selection_70872$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$set_selection_70872$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2454$$,$state$jscomp$816$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$816$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1921$selected$$],null),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.$cell_id$]))});return new $app$main$data$workspace$grid_layout$editor$set_selection_70872$$($grid_id$jscomp$5$$,$cell_id$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$select_node$$=function($position$jscomp$142$$,$shift_QMARK_$jscomp$22$$){typeof $app$main$data$workspace$path$selection$select_node_69731$$==="undefined"&&($app$main$data$workspace$path$selection$select_node_69731$$=function($position$jscomp$143$$,$shift_QMARK_$jscomp$23$$,$meta69732$$){this.position=$position$jscomp$143$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$23$$;this.$meta69732$=$meta69732$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$selection$select_node_69731$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_69731$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4242$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_select_node$$},$app$main$data$workspace$path$selection$select_node_69731$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69733$$,$meta69732__$1$$){return new $app$main$data$workspace$path$selection$select_node_69731$$(this.position,
this.$shift_QMARK_$,$meta69732__$1$$)},$app$main$data$workspace$path$selection$select_node_69731$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69732$},$app$main$data$workspace$path$selection$select_node_69731$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_69731$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2322_id$jscomp$681$$,$state$jscomp$713$$){$_$jscomp$2322_id$jscomp$681$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$713$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);var $selected_points$jscomp$2_selected_points__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$713$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2322_id$jscomp$681$$),$APP.$cljs$cst$4241$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8297$$=this.$shift_QMARK_$;$JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8297$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8297$$)?$APP.$cljs$core$contains_QMARK_$$($selected_points$jscomp$2_selected_points__$1$jscomp$1$$,
this.position):$JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8297$$;$selected_points$jscomp$2_selected_points__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8297$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($selected_points$jscomp$2_selected_points__$1$jscomp$1$$,this.position):$APP.$cljs$core$truth_$$(this.$shift_QMARK_$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($selected_points$jscomp$2_selected_points__$1$jscomp$1$$,
this.position):$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.position]);return $_$jscomp$2322_id$jscomp$681$$!=null?$APP.$cljs$core$assoc_in$$($state$jscomp$713$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2322_id$jscomp$681$$,$APP.$cljs$cst$4241$selected_points$$],null),$selected_points$jscomp$2_selected_points__$1$jscomp$1$$):$state$jscomp$713$$});return new $app$main$data$workspace$path$selection$select_node_69731$$($position$jscomp$142$$,
$shift_QMARK_$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$235$$,$focus$jscomp$4$$){return $APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus$jscomp$4$$),$APP.$rumext$v2$adapt$$($objects$jscomp$235$$)],function(){return $APP.$app$common$files$focus$focus_objects$$($objects$jscomp$235$$,$focus$jscomp$4$$)})};
$app$main$data$workspace$shape_layout$hover_layout_track$$=function($ids$jscomp$233$$,$type$jscomp$527$$,$index$jscomp$360$$,$hover_QMARK_$jscomp$2$$){typeof $app$main$data$workspace$shape_layout$hover_layout_track_71221$$==="undefined"&&($app$main$data$workspace$shape_layout$hover_layout_track_71221$$=function($ids$jscomp$234$$,$type$jscomp$528$$,$index$jscomp$361$$,$hover_QMARK_$jscomp$3$$,$meta71222$$){this.ids=$ids$jscomp$234$$;this.type=$type$jscomp$528$$;this.index=$index$jscomp$361$$;this.$hover_QMARK_$=
$hover_QMARK_$jscomp$3$$;this.$meta71222$=$meta71222$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$hover_layout_track_71221$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$hover_layout_track_71221$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4408$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_hover_layout_track$$},
$app$main$data$workspace$shape_layout$hover_layout_track_71221$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71223$$,$meta71222__$1$$){return new $app$main$data$workspace$shape_layout$hover_layout_track_71221$$(this.ids,this.type,this.index,this.$hover_QMARK_$,$meta71222__$1$$)},$app$main$data$workspace$shape_layout$hover_layout_track_71221$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71222$},$app$main$data$workspace$shape_layout$hover_layout_track_71221$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$hover_layout_track_71221$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$,$G__71224__$1_G__71224__$2_state$jscomp$830$$){$_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($G__71224__$1_G__71224__$2_state$jscomp$830$$);$_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$,$APP.$cljs$core$first$$(this.ids));$_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$=$APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?$APP.$cljs$core$set$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$APP.$cljs$cst$1656$row$$)?$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$,
this.index):$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$,this.index)):null;$G__71224__$1_G__71224__$2_state$jscomp$830$$=$APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__71224__$1_G__71224__$2_state$jscomp$830$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,
$APP.$cljs$core$first$$(this.ids),$APP.$cljs$cst$4409$hover_track$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.type,this.index],null)):$G__71224__$1_G__71224__$2_state$jscomp$830$$;$G__71224__$1_G__71224__$2_state$jscomp$830$$=$APP.$cljs$core$not$$(this.$hover_QMARK_$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__71224__$1_G__71224__$2_state$jscomp$830$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,$APP.$cljs$core$first$$(this.ids),$APP.$cljs$cst$4409$hover_track$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.type,this.index],null)):$G__71224__$1_G__71224__$2_state$jscomp$830$$;
return $APP.$cljs$core$assoc_in$$($G__71224__$1_G__71224__$2_state$jscomp$830$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4295$highlighted$$],null),$_$jscomp$2474_highlighted$jscomp$1_objects$jscomp$630_shape$jscomp$736$$)});return new $app$main$data$workspace$shape_layout$hover_layout_track_71221$$($ids$jscomp$233$$,$type$jscomp$527$$,$index$jscomp$360$$,$hover_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$highlight$clear_search_match_highlight$$=function($match_ids$jscomp$2_match_ids__$1$jscomp$1$$){$match_ids$jscomp$2_match_ids__$1$jscomp$1$$=$APP.$cljs$core$set$$($match_ids$jscomp$2_match_ids__$1$jscomp$1$$);typeof $app$main$data$workspace$highlight$clear_search_match_highlight_70331$$==="undefined"&&($app$main$data$workspace$highlight$clear_search_match_highlight_70331$$=function($match_ids$jscomp$3$$,$meta70332$$){this.$match_ids$=$match_ids$jscomp$3$$;this.$meta70332$=
$meta70332$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4299$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_clear_search_match_highlight$$},$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70333$$,$meta70332__$1$$){return new $app$main$data$workspace$highlight$clear_search_match_highlight_70331$$(this.$match_ids$,$meta70332__$1$$)},$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70332$},$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$clear_search_match_highlight_70331$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2385$$,$state$jscomp$762$$){var $self__$jscomp$5690$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$762$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4295$highlighted$$],null),function($p1__70330_SHARP_$$){return $APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($p1__70330_SHARP_$$)?
$p1__70330_SHARP_$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$self__$jscomp$5690$$.$match_ids$)}),$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4298$search_match_highlight$$)});return new $app$main$data$workspace$highlight$clear_search_match_highlight_70331$$($match_ids$jscomp$2_match_ids__$1$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$highlight$set_search_match_highlight$$=function($current_id$jscomp$6$$,$match_ids_match_ids__$1$$){$match_ids_match_ids__$1$$=$APP.$cljs$core$set$$($match_ids_match_ids__$1$$);typeof $app$main$data$workspace$highlight$set_search_match_highlight_70324$$==="undefined"&&($app$main$data$workspace$highlight$set_search_match_highlight_70324$$=function($current_id$jscomp$7$$,$match_ids$jscomp$1$$,$meta70325$$){this.$current_id$=$current_id$jscomp$7$$;this.$match_ids$=$match_ids$jscomp$1$$;
this.$meta70325$=$meta70325$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$highlight$set_search_match_highlight_70324$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$set_search_match_highlight_70324$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4297$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_set_search_match_highlight$$},
$app$main$data$workspace$highlight$set_search_match_highlight_70324$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70326$$,$meta70325__$1$$){return new $app$main$data$workspace$highlight$set_search_match_highlight_70324$$(this.$current_id$,this.$match_ids$,$meta70325__$1$$)},$app$main$data$workspace$highlight$set_search_match_highlight_70324$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70325$},$app$main$data$workspace$highlight$set_search_match_highlight_70324$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$set_search_match_highlight_70324$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2384_highlighted$$,$state$jscomp$761$$){$_$jscomp$2384_highlighted$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$761$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4295$highlighted$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.$match_ids$),this.$current_id$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$761$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4298$search_match_highlight$$],null),this.$current_id$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4295$highlighted$$],null),$_$jscomp$2384_highlighted$$)});return new $app$main$data$workspace$highlight$set_search_match_highlight_70324$$($current_id$jscomp$6$$,$match_ids_match_ids__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$streams$move_handler_stream$$=function($start_point$jscomp$3$$,$node$jscomp$332$$,$handler$jscomp$39$$,$opposite$jscomp$3$$,$points$jscomp$86_vec__69604$$){var $zoom$jscomp$28$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$ranges$jscomp$7$$=
$APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$1$($points$jscomp$86_vec__69604$$),$d_pos$jscomp$1$$=10/$zoom$jscomp$28$$;$points$jscomp$86_vec__69604$$=$app$main$data$workspace$path$streams$get_angle$$($node$jscomp$332$$,$handler$jscomp$39$$,$opposite$jscomp$3$$);var $initial_angle$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($points$jscomp$86_vec__69604$$,0,null);return $APP.$beicon$v2$core$map$$(function($delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$){var $position$jscomp$124$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$,0,null);$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$,1,null);if($APP.$cljs$core$truth_$$($delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$)){$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$=
$APP.$app$common$geom$point$subtract$$($position$jscomp$124$$,$start_point$jscomp$3$$);$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$=$APP.$app$common$geom$point$add$$($handler$jscomp$39$$,$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$);var $rot_sign$jscomp$1_vec__69616$$=$app$main$data$workspace$path$streams$get_angle$$($node$jscomp$332$$,$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$,$opposite$jscomp$3$$),$rot_angle$jscomp$1_rot_handler$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($rot_sign$jscomp$1_vec__69616$$,0,null);$rot_sign$jscomp$1_vec__69616$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($rot_sign$jscomp$1_vec__69616$$,1,null);var $and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$;if($and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$=
$rot_angle$jscomp$1_rot_handler$$!=null)$and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$=$APP.$cljs$cst$4204$alt_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$124$$),$and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$)?
$and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$:180-$initial_angle$jscomp$1$$>.1,$and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$)?180-
$rot_angle$jscomp$1_rot_handler$$<=5:$and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$;$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13237_and__5023__auto____$1$jscomp$inline_13238_or__5025__auto__$jscomp$inline_13239_snap_opposite_angle_QMARK_$$)?($rot_angle$jscomp$1_rot_handler$$=$APP.$app$common$geom$point$rotate$$($delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$,
$node$jscomp$332$$,180-$rot_sign$jscomp$1_vec__69616$$*$rot_angle$jscomp$1_rot_handler$$),$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($rot_angle$jscomp$1_rot_handler$$,$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$)):$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$=$APP.$app$main$snap$get_snap_delta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$],null),$ranges$jscomp$7$$,$d_pos$jscomp$1$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$position$jscomp$124$$,$APP.$app$common$geom$point$add$$($position$jscomp$124$$,$delta$jscomp$48_handler__$1_p__69609_snap$jscomp$1_snap_toggled$jscomp$1$$)]))}return $position$jscomp$124$$},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$path$streams$snap_toggled_stream$$(),
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$04$$(function($position$jscomp$125$$,$shift_QMARK_$jscomp$14$$,$alt_QMARK_$jscomp$8$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($position$jscomp$125$$,$APP.$cljs$cst$4203$shift_QMARK_$$,$shift_QMARK_$jscomp$14$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4204$alt_QMARK_$$,$alt_QMARK_$jscomp$8$$]))},$APP.$sub$jscomp$inline_5572$$,$APP.$sub$jscomp$inline_5575$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$path$streams$to_pixel_snap$$,
$APP.$app$main$streams$mouse_position$$))))};
$app$main$data$workspace$path$streams$move_points_stream$$=function($start_point$jscomp$2$$,$selected_points$jscomp$1$$,$points$jscomp$85$$){var $zoom$jscomp$27$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$ranges$jscomp$6$$=$APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$85$$,
$selected_points$jscomp$1$$),$d_pos$$=10/$zoom$jscomp$27$$;return $APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$04$$(function($position$jscomp$123$$,$shift_QMARK_$jscomp$13$$,$alt_QMARK_$jscomp$7$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($position$jscomp$123$$,$APP.$cljs$cst$4203$shift_QMARK_$$,$shift_QMARK_$jscomp$13$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4204$alt_QMARK_$$,$alt_QMARK_$jscomp$7$$]))},$APP.$sub$jscomp$inline_5572$$,
$APP.$sub$jscomp$inline_5575$$,$APP.$beicon$v2$core$map$$(function($moved_points_p__69593_snap_snap_toggled$$){var $position$jscomp$122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($moved_points_p__69593_snap_snap_toggled$$,0,null);$moved_points_p__69593_snap_snap_toggled$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($moved_points_p__69593_snap_snap_toggled$$,1,null);if($APP.$cljs$core$truth_$$($moved_points_p__69593_snap_snap_toggled$$)){var $delta$jscomp$47$$=$APP.$app$common$geom$point$subtract$$($position$jscomp$122$$,
$start_point$jscomp$2$$);$moved_points_p__69593_snap_snap_toggled$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69589_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__69589_SHARP_$$,$delta$jscomp$47$$)},$selected_points$jscomp$1$$);$moved_points_p__69593_snap_snap_toggled$$=$APP.$app$main$snap$get_snap_delta$$($moved_points_p__69593_snap_snap_toggled$$,$ranges$jscomp$6$$,$d_pos$$);return $APP.$app$common$geom$point$add$$($position$jscomp$122$$,$moved_points_p__69593_snap_snap_toggled$$)}return $position$jscomp$122$$},
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$path$streams$snap_toggled_stream$$(),$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$path$streams$to_pixel_snap$$,$APP.$app$main$streams$mouse_position$$))))};
$app$common$attrs$get_text_attrs_multi$$=function($content$jscomp$151_map__55528__$1_p__55527$$,$attrs$jscomp$65_text_node_attrs$$){$content$jscomp$151_map__55528__$1_p__55527$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$151_map__55528__$1_p__55527$$);$content$jscomp$151_map__55528__$1_p__55527$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$151_map__55528__$1_p__55527$$,$APP.$cljs$cst$1637$content$$);var $root_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$app$common$types$text$text_valign_attrs$$),
$attrs$jscomp$65_text_node_attrs$$),$paragraph_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$app$common$types$text$paragraph_attrs$$),$attrs$jscomp$65_text_node_attrs$$);$attrs$jscomp$65_text_node_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$app$common$types$text$text_node_attrs$$),$attrs$jscomp$65_text_node_attrs$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_text_attrs$$,
$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_root_node_QMARK_$$,$content$jscomp$151_map__55528__$1_p__55527$$),$root_attrs$$),$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$content$jscomp$151_map__55528__$1_p__55527$$),
$paragraph_attrs$$),$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$content$jscomp$151_map__55528__$1_p__55527$$),$attrs$jscomp$65_text_node_attrs$$)]))};
$app$common$types$shape$layout$duplicate_column_at$$=function($G__48115_shape$jscomp$65$$,$objects$jscomp$91$$,$source_index$jscomp$1$$,$target_index$jscomp$1$$,$ids_map$jscomp$4$$){var $value$jscomp$399$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48115_shape$jscomp$65$$,$APP.$cljs$cst$1695$layout_grid_columns$$),$source_index$jscomp$1$$),$adjusted_source$jscomp$1$$=$target_index$jscomp$1$$<=$source_index$jscomp$1$$?$source_index$jscomp$1$$+
1:$source_index$jscomp$1$$;$G__48115_shape$jscomp$65$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48115_shape$jscomp$65$$,$APP.$cljs$cst$216$column$$,$source_index$jscomp$1$$),$value$jscomp$399$$,$target_index$jscomp$1$$),$APP.$cljs$cst$216$column$$,$adjusted_source$jscomp$1$$,$target_index$jscomp$1$$,$ids_map$jscomp$4$$);return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48115_shape$jscomp$65$$,$objects$jscomp$91$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48115_shape$jscomp$65$$,$objects$jscomp$91$$)};
$app$common$types$shape$layout$duplicate_row_at$$=function($G__48113_shape$jscomp$64$$,$objects$jscomp$90$$,$source_index$$,$target_index$$,$ids_map$jscomp$3$$){var $value$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48113_shape$jscomp$64$$,$APP.$cljs$cst$1694$layout_grid_rows$$),$source_index$$),$adjusted_source$$=$target_index$$<=$source_index$$?$source_index$$+1:$source_index$$;$G__48113_shape$jscomp$64$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48113_shape$jscomp$64$$,
$APP.$cljs$cst$1656$row$$,$source_index$$),$value$jscomp$398$$,$target_index$$),$APP.$cljs$cst$1656$row$$,$adjusted_source$$,$target_index$$,$ids_map$jscomp$3$$);return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48113_shape$jscomp$64$$,$objects$jscomp$90$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48113_shape$jscomp$64$$,$objects$jscomp$90$$)};
$app$main$data$workspace$interactions$get_target_frame$$=function($from_shape$jscomp$1_state$jscomp$773$$,$position$jscomp$151_target_frame$jscomp$6$$){var $objects$jscomp$610$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($from_shape$jscomp$1_state$jscomp$773$$),$from_frame_id_from_id$jscomp$1$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($from_shape$jscomp$1_state$jscomp$773$$));$from_shape$jscomp$1_state$jscomp$773$$=
$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($from_shape$jscomp$1_state$jscomp$773$$,$from_frame_id_from_id$jscomp$1$$);$from_frame_id_from_id$jscomp$1$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from_shape$jscomp$1_state$jscomp$773$$)?$from_frame_id_from_id$jscomp$1$$:$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($from_shape$jscomp$1_state$jscomp$773$$);$position$jscomp$151_target_frame$jscomp$6$$=$APP.$cljs$core$last$$($APP.$app$common$types$shape_tree$get_frames_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$610$$,
$position$jscomp$151_target_frame$jscomp$6$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$151_target_frame$jscomp$6$$),$APP.$app$common$uuid$zero$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$151_target_frame$jscomp$6$$),$from_frame_id_from_id$jscomp$1$$)?$position$jscomp$151_target_frame$jscomp$6$$:null};
$app$main$data$workspace$interactions$move_edit_interaction$$=function($_initial_pos$$,$position$jscomp$152$$){typeof $app$main$data$workspace$interactions$move_edit_interaction_70539$$==="undefined"&&($app$main$data$workspace$interactions$move_edit_interaction_70539$$=function($_initial_pos$jscomp$1$$,$position$jscomp$153$$,$meta70540$$){this.$_initial_pos$=$_initial_pos$jscomp$1$$;this.position=$position$jscomp$153$$;this.$meta70540$=$meta70540$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$move_edit_interaction_70539$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_edit_interaction_70539$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4312$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_move_edit_interaction$$},$app$main$data$workspace$interactions$move_edit_interaction_70539$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70541$$,$meta70540__$1$$){return new $app$main$data$workspace$interactions$move_edit_interaction_70539$$(this.$_initial_pos$,this.position,$meta70540__$1$$)},$app$main$data$workspace$interactions$move_edit_interaction_70539$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70540$},$app$main$data$workspace$interactions$move_edit_interaction_70539$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_edit_interaction_70539$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2399_end_frame$$,$state$jscomp$774$$){$_$jscomp$2399_end_frame$$=$app$main$data$workspace$interactions$get_target_frame$$($state$jscomp$774$$,this.position);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$774$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4313$draw_interaction_to$$],null),this.position),new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4314$draw_interaction_to_frame$$],null),$_$jscomp$2399_end_frame$$)});return new $app$main$data$workspace$interactions$move_edit_interaction_70539$$($_initial_pos$$,$position$jscomp$152$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker$$=function($p__70953$$){var $map__70954__$1$$=$APP.$cljs$core$__destructure_map$$($p__70953$$),$gradient$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70954__$1$$,$APP.$cljs$cst$1724$gradient$$);typeof $app$main$data$workspace$colors$update_colorpicker_70955$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_70955$$=function($p__70953$jscomp$1$$,$map__70954$jscomp$1$$,$data$jscomp$385$$,$gradient$jscomp$20$$,
$meta70956$$){this.$p__70953$=$p__70953$jscomp$1$$;this.$map__70954$=$map__70954$jscomp$1$$;this.data=$data$jscomp$385$$;this.gradient=$gradient$jscomp$20$$;this.$meta70956$=$meta70956$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_70955$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_70955$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4180$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker$$},$app$main$data$workspace$colors$update_colorpicker_70955$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70957$$,$meta70956__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_70955$$(this.$p__70953$,this.$map__70954$,this.data,this.gradient,$meta70956__$1$$)},$app$main$data$workspace$colors$update_colorpicker_70955$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70956$},$app$main$data$workspace$colors$update_colorpicker_70955$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_70955$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2262$$,$state$jscomp$649$$){var $self__$jscomp$5283$$=this,$shape_id$jscomp$108$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$649$$));
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$649$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$31$$){var $current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$=$APP.$cljs$cst$4164$current_color$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$);if($self__$jscomp$5283$$.gradient!=null){$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$=$APP.$cljs$cst$4162$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$);
$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$=$APP.$cljs$core$truth_$$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$)?$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$:0;var $new_stops$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5283$$.gradient)),$new_gradient$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5283$$.gradient,
$APP.$cljs$cst$1733$stops$$),$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$108$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$),$new_stops$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$),$new_gradient$$)?$state__$1$jscomp$31$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$31$$,
$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5283$$.data)),$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_stops$$,$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$)),$APP.$cljs$cst$1733$stops$$,$new_stops$$),$APP.$cljs$cst$1724$gradient$$,$new_gradient$$),$APP.$cljs$cst$4162$editing_stop$$,$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$)}return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$==
null||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5283$$.data),$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5283$$.data),$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13241_stop$jscomp$3$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$31$$,$APP.$cljs$cst$4164$current_color$$,$app$main$data$workspace$colors$split_color_components$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5283$$.data,$APP.$cljs$cst$1724$gradient$$))):$state__$1$jscomp$31$$,$APP.$cljs$cst$4162$editing_stop$$),$APP.$cljs$cst$1724$gradient$$),$APP.$cljs$cst$1733$stops$$)})});return new $app$main$data$workspace$colors$update_colorpicker_70955$$($p__70953$$,$map__70954__$1$$,
$map__70954__$1$$,$gradient$jscomp$19$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$copy_selected_text$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_text_70607$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_text_70607$$=function($meta70608$$){this.$meta70608$=$meta70608$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_text_70607$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_text_70607$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4109$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_text$$},$app$main$data$workspace$clipboard$copy_selected_text_70607$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70609$$,$meta70608__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_text_70607$$($meta70608__$1$$)},$app$main$data$workspace$clipboard$copy_selected_text_70607$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70608$},$app$main$data$workspace$clipboard$copy_selected_text_70607$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_text_70607$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$,$objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$){$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$);
$objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$);$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$),
$APP.$app$common$files$helpers$selected_with_children$$($objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$,$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$)));$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$);
var $objects__$1$jscomp$22$$=$APP.$app$common$files$helpers$selected_subtree$$($objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$,$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$);$objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects__$1$jscomp$22$$,
$_$jscomp$2215_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$));$objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$648_shape$jscomp$672$$){$id$jscomp$648_shape$jscomp$672$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$22$$,$id$jscomp$648_shape$jscomp$672$$);return $APP.$app$common$types$text$content__GT_text$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$648_shape$jscomp$672$$))},
$objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$));return $APP.$app$util$clipboard$to_clipboard$$($objects$jscomp$582_selected__$2_state$jscomp$608_text$jscomp$54$$)});return new $app$main$data$workspace$clipboard$copy_selected_text_70607$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$specialized_panel$open_specialized_panel$$=function(){typeof $app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$==="undefined"&&($app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$=function($type$jscomp$475$$,$meta67265$$){this.type=$type$jscomp$475$$;this.$meta67265$=$meta67265$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3764$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_open_specialized_panel$$},$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67266$$,$meta67265__$1$$){return new $app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$(this.type,
$meta67265__$1$$)},$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67265$},$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$,
$state$jscomp$430$$){$_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$430$$);$_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$430$$,$_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$);var $selected_ids$jscomp$2$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$430$$);
$_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$),$selected_ids$jscomp$2$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$430$$,$APP.$cljs$cst$2242$specialized_panel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$1614$shapes$$,$_$jscomp$2006_objects$jscomp$377_page_id$jscomp$138_selected_shapes$$],
null))},$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2007$$,$___$1$jscomp$1289$$,$stream$jscomp$43$$){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$specialized_panel$clear_specialized_panel$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($app$main$data$workspace$specialized_panel$interrupt_QMARK_$$,
$stream$jscomp$43$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3765$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_undo$$),$stream$jscomp$43$$))))});return new $app$main$data$workspace$specialized_panel$open_specialized_panel_67264$$($APP.$cljs$cst$3960$component_swap$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$set_rotation_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$=function($angle$jscomp$30$$,$shapes$jscomp$84$$,$center$jscomp$46$$){typeof $app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$==="undefined"&&($app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$=function($angle$jscomp$31$$,$shapes$jscomp$85$$,$center$jscomp$47$$,$meta68865$$){this.angle=$angle$jscomp$31$$;this.shapes=$shapes$jscomp$85$$;this.$center$=$center$jscomp$47$$;this.$meta68865$=
$meta68865$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3843$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_rotation_modifiers$$},$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68866$$,$meta68865__$1$$){return new $app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$(this.angle,this.shapes,this.$center$,$meta68865__$1$$)},$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68865$},$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2040_modif_tree$jscomp$51_objects$jscomp$468$$,$state$jscomp$451$$){var $self__$jscomp$4573$$=this;$_$jscomp$2040_modif_tree$jscomp$51_objects$jscomp$468$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$451$$);var $ids$jscomp$106$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$xf_rotation_shape$$,$self__$jscomp$4573$$.shapes);$_$jscomp$2040_modif_tree$jscomp$51_objects$jscomp$468$$=
$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($ids$jscomp$106$$,$_$jscomp$2040_modif_tree$jscomp$51_objects$jscomp$468$$,function($shape$jscomp$535$$){return $APP.$app$common$types$modifiers$rotation_modifiers$$($shape$jscomp$535$$,$self__$jscomp$4573$$.$center$,$self__$jscomp$4573$$.angle)}),$_$jscomp$2040_modif_tree$jscomp$51_objects$jscomp$468$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$451$$,
$APP.$cljs$cst$1922$workspace_modifiers$$,$_$jscomp$2040_modif_tree$jscomp$51_objects$jscomp$468$$)});return new $app$main$data$workspace$modifiers$set_rotation_modifiers_68864$$($angle$jscomp$30$$,$shapes$jscomp$84$$,$center$jscomp$46$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$calculate_update_modifiers$$=function($old_modif_tree$jscomp$1$$,$objects__$1$jscomp$19_state$jscomp$444$$,$ignore_constraints$jscomp$13$$,$ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$,$modif_tree$jscomp$32$$){var $objects$jscomp$464$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects__$1$jscomp$19_state$jscomp$444$$);$ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$=$APP.$cljs$core$not$$($ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$)&&
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($objects__$1$jscomp$19_state$jscomp$444$$),$APP.$cljs$cst$2210$snap_pixel_grid$$);$objects__$1$jscomp$19_state$jscomp$444$$=$APP.$app$main$data$workspace$modifiers$apply_text_modifiers$$($objects$jscomp$464$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$19_state$jscomp$444$$,$APP.$cljs$cst$2238$workspace_text_modifier$$));return $APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($old_modif_tree$jscomp$1$$,
$modif_tree$jscomp$32$$,$objects__$1$jscomp$19_state$jscomp$444$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3821$ignore_constraints$$,$ignore_constraints$jscomp$13$$,$APP.$cljs$cst$3822$snap_pixel_QMARK_$$,$ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$],null))};
$app$main$data$workspace$modifiers$update_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$=function($modif_tree$jscomp$35$$){typeof $app$main$data$workspace$modifiers$update_modifiers_68687$$==="undefined"&&($app$main$data$workspace$modifiers$update_modifiers_68687$$=function($modif_tree$jscomp$36$$,$ignore_constraints$jscomp$16$$,$ignore_snap_pixel$jscomp$4$$,$meta68688$$){this.$modif_tree$=$modif_tree$jscomp$36$$;this.$ignore_constraints$=$ignore_constraints$jscomp$16$$;this.$ignore_snap_pixel$=$ignore_snap_pixel$jscomp$4$$;
this.$meta68688$=$meta68688$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$update_modifiers_68687$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$update_modifiers_68687$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3829$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_update_modifiers$$},$app$main$data$workspace$modifiers$update_modifiers_68687$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68689$$,$meta68688__$1$$){return new $app$main$data$workspace$modifiers$update_modifiers_68687$$(this.$modif_tree$,this.$ignore_constraints$,this.$ignore_snap_pixel$,$meta68688__$1$$)},$app$main$data$workspace$modifiers$update_modifiers_68687$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68688$},$app$main$data$workspace$modifiers$update_modifiers_68687$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$update_modifiers_68687$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2031$$,$state$jscomp$445$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$445$$,$APP.$cljs$cst$1922$workspace_modifiers$$,$app$main$data$workspace$modifiers$calculate_update_modifiers$$,$state$jscomp$445$$,this.$ignore_constraints$,this.$ignore_snap_pixel$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$modif_tree$]))});return new $app$main$data$workspace$modifiers$update_modifiers_68687$$($modif_tree$jscomp$35$$,!1,!0,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$commit_update_text_modifier$$=function(){typeof $app$main$data$workspace$texts$commit_update_text_modifier_70286$$==="undefined"&&($app$main$data$workspace$texts$commit_update_text_modifier_70286$$=function($meta70287$$){this.$meta70287$=$meta70287$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$commit_update_text_modifier_70286$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$commit_update_text_modifier_70286$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4024$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_update_text_modifier$$},$app$main$data$workspace$texts$commit_update_text_modifier_70286$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70288$$,$meta70287__$1$$){return new $app$main$data$workspace$texts$commit_update_text_modifier_70286$$($meta70287__$1$$)},$app$main$data$workspace$texts$commit_update_text_modifier_70286$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70287$},$app$main$data$workspace$texts$commit_update_text_modifier_70286$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_update_text_modifier_70286$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2181_ids$jscomp$149_modif_tree$jscomp$60$$,$state$jscomp$580$$){$_$jscomp$2181_ids$jscomp$149_modif_tree$jscomp$60$$=$APP.$cljs$cst$4025$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$580$$);
$_$jscomp$2181_ids$jscomp$149_modif_tree$jscomp$60$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($_$jscomp$2181_ids$jscomp$149_modif_tree$jscomp$60$$,$APP.$app$common$types$modifiers$reflow$$());return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$update_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2181_ids$jscomp$149_modif_tree$jscomp$60$$))});return new $app$main$data$workspace$texts$commit_update_text_modifier_70286$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$shape$layout$reorder_grid_tracks$$=function($parent$jscomp$148$$,$prop$jscomp$16$$,$from_index$jscomp$3$$,$to_index$jscomp$1$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$148$$,$prop$jscomp$16$$,function($tracks$$){var $tr$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tracks$$,$from_index$jscomp$3$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$app$common$data$vec_without_nils$$($APP.$app$common$data$insert_at_index$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($tracks$$),
$from_index$jscomp$3$$,null),$to_index$jscomp$1$$+1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$tr$jscomp$1$$],null)],null))))})};
$app$common$types$shape$layout$reorder_grid_track$$=function($parent$jscomp$150_parent__$1$jscomp$40$$,$G__48151_from_index$jscomp$4$$,$to_index$jscomp$2$$,$move_content_QMARK__move_content_QMARK___$1$$,$tracks_props$$,$prop$jscomp$18$$){var $from_track$jscomp$1$$=$G__48151_from_index$jscomp$4$$+1,$to_track$jscomp$1$$=$to_index$jscomp$2$$<$G__48151_from_index$jscomp$4$$?$to_index$jscomp$2$$+2:$to_index$jscomp$2$$+1;$move_content_QMARK__move_content_QMARK___$1$$=$APP.$cljs$core$truth_$$($move_content_QMARK__move_content_QMARK___$1$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_track$jscomp$1$$,$to_track$jscomp$1$$):$move_content_QMARK__move_content_QMARK___$1$$;$parent$jscomp$150_parent__$1$jscomp$40$$=$APP.$cljs$core$truth_$$($move_content_QMARK__move_content_QMARK___$1$$)?$app$common$types$shape$layout$remove_cell_areas_after$$($app$common$types$shape$layout$remove_cell_areas$$($parent$jscomp$150_parent__$1$jscomp$40$$,$prop$jscomp$18$$,$G__48151_from_index$jscomp$4$$),$prop$jscomp$18$$,$to_index$jscomp$2$$):
$parent$jscomp$150_parent__$1$jscomp$40$$;$G__48151_from_index$jscomp$4$$=$app$common$types$shape$layout$reorder_grid_tracks$$($parent$jscomp$150_parent__$1$jscomp$40$$,$tracks_props$$,$G__48151_from_index$jscomp$4$$,$to_index$jscomp$2$$);return $APP.$cljs$core$truth_$$($move_content_QMARK__move_content_QMARK___$1$$)?$app$common$types$shape$layout$swap_track_content$$($G__48151_from_index$jscomp$4$$,$prop$jscomp$18$$,$from_track$jscomp$1$$,$to_track$jscomp$1$$):$G__48151_from_index$jscomp$4$$};
$cljs$tools$reader$read_dispatch$$=function($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$){$_$jscomp$169_temp__5823__auto__$jscomp$21$$=$rdr$jscomp$54$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($APP.$cljs$core$truth_$$($_$jscomp$169_temp__5823__auto__$jscomp$21$$)){var $temp__5823__auto____$1$jscomp$2$$=$cljs$tools$reader$dispatch_macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$dispatch_macros$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$169_temp__5823__auto__$jscomp$21$$):
$cljs$tools$reader$dispatch_macros$$($_$jscomp$169_temp__5823__auto__$jscomp$21$$);if($APP.$cljs$core$truth_$$($temp__5823__auto____$1$jscomp$2$$))return $temp__5823__auto____$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$4$?$temp__5823__auto____$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$4$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$):$temp__5823__auto____$1$jscomp$2$$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,
$pending_forms$$);$rdr$jscomp$54$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$(null,$_$jscomp$169_temp__5823__auto__$jscomp$21$$);return $cljs$tools$reader$read_tagged$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$tools$reader$read_tagged$$.$cljs$core$IFn$_invoke$arity$4$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$):$cljs$tools$reader$read_tagged$$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$)}return $APP.$cljs$tools$reader$impl$errors$throw_eof_at_dispatch$$($rdr$jscomp$54$$)};
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$=function($rdr$jscomp$57$$,$initch$jscomp$2$$,$base$jscomp$10$$,$length$jscomp$27$$,$exact_QMARK_$$){for(var $i$jscomp$288$$=1,$G__25020_uc$jscomp$1$$=$APP.$cljs$tools$reader$impl$utils$char_code$$($initch$jscomp$2$$,$base$jscomp$10$$);;){if($G__25020_uc$jscomp$1$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$($rdr$jscomp$57$$,$initch$jscomp$2$$);if($i$jscomp$288$$!==$length$jscomp$27$$){var $ch$jscomp$30$$=
$rdr$jscomp$57$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);var $JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$30$$);$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$||($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$=
$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$30$$):$cljs$tools$reader$macros$$($ch$jscomp$30$$),$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$)?$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$:
$ch$jscomp$30$$==null);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$))return $APP.$cljs$core$truth_$$($exact_QMARK_$$)?$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_len$$($rdr$jscomp$57$$,$i$jscomp$288$$,$length$jscomp$27$$):String.fromCharCode($G__25020_uc$jscomp$1$$);$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$=
$APP.$cljs$tools$reader$impl$utils$char_code$$($ch$jscomp$30$$,$base$jscomp$10$$);$rdr$jscomp$57$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$($rdr$jscomp$57$$,$ch$jscomp$30$$);$G__25020_uc$jscomp$1$$=$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8302_or__5025__auto____$1$jscomp$inline_8303$$+
$G__25020_uc$jscomp$1$$*$base$jscomp$10$$;$i$jscomp$288$$+=1}else return String.fromCharCode($G__25020_uc$jscomp$1$$)}};
$cljs$tools$reader$read_delimited$$=function($kind$jscomp$13$$,$delim$jscomp$1$$,$rdr$jscomp$62$$,$opts$jscomp$63$$,$pending_forms$jscomp$5$$){var $_STAR_read_delim_STAR__orig_val__24641$$=$cljs$tools$reader$_STAR_read_delim_STAR_$$;$cljs$tools$reader$_STAR_read_delim_STAR_$$=!0;try{a:{for(var $vec__24636$jscomp$inline_8310$$=$cljs$tools$reader$starting_line_col_info$$($rdr$jscomp$62$$),$start_line$jscomp$inline_8311$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24636$jscomp$inline_8310$$,
0,null),$start_column$jscomp$inline_8312$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24636$jscomp$inline_8310$$,1,null),$delim__$1$jscomp$inline_8313$$=$APP.$cljs$tools$reader$impl$utils$char$0$$($delim$jscomp$1$$),$a$jscomp$inline_8314$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){var $form$jscomp$inline_8315$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($rdr$jscomp$62$$,
!1,$cljs$tools$reader$READ_EOF$$,$delim__$1$jscomp$inline_8313$$,$opts$jscomp$63$$,$pending_forms$jscomp$5$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$62$$,!1,$cljs$tools$reader$READ_EOF$$,$delim__$1$jscomp$inline_8313$$,$opts$jscomp$63$$,$pending_forms$jscomp$5$$);if($form$jscomp$inline_8315$$===$cljs$tools$reader$READ_FINISHED$$){var $JSCompiler_inline_result$jscomp$1614$$=$APP.$cljs$core$_persistent_BANG_$$($a$jscomp$inline_8314$$);break a}if($form$jscomp$inline_8315$$===$cljs$tools$reader$READ_EOF$$){$JSCompiler_inline_result$jscomp$1614$$=
$APP.$cljs$tools$reader$impl$errors$throw_eof_delimited$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$62$$,$kind$jscomp$13$$,$start_line$jscomp$inline_8311$$,$start_column$jscomp$inline_8312$$,$APP.$cljs$core$count$$($a$jscomp$inline_8314$$));break a}$a$jscomp$inline_8314$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$inline_8314$$,$form$jscomp$inline_8315$$)}$JSCompiler_inline_result$jscomp$1614$$=void 0}return $JSCompiler_inline_result$jscomp$1614$$}finally{$cljs$tools$reader$_STAR_read_delim_STAR_$$=
$_STAR_read_delim_STAR__orig_val__24641$$}};
$cljs$tools$reader$read_list$$=function($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$,$_$jscomp$170_start_line$jscomp$1$$,$end_line_opts$jscomp$64$$,$end_column_pending_forms$jscomp$6_vec__24647$$){var $start_column$jscomp$1_vec__24644$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$);$_$jscomp$170_start_line$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$1_vec__24644$$,0,
null);$start_column$jscomp$1_vec__24644$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$1_vec__24644$$,1,null);var $JSCompiler_temp_const$jscomp$1615_the_list$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$201$list$$,")",$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$,$end_line_opts$jscomp$64$$,$end_column_pending_forms$jscomp$6_vec__24647$$);$end_column_pending_forms$jscomp$6_vec__24647$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$);
$end_line_opts$jscomp$64$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column_pending_forms$jscomp$6_vec__24647$$,0,null);$end_column_pending_forms$jscomp$6_vec__24647$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column_pending_forms$jscomp$6_vec__24647$$,1,null);$JSCompiler_temp_const$jscomp$1615_the_list$$=$APP.$cljs$core$empty_QMARK_$$($JSCompiler_temp_const$jscomp$1615_the_list$$)?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$list$$,
$JSCompiler_temp_const$jscomp$1615_the_list$$);if($APP.$cljs$core$truth_$$($_$jscomp$170_start_line$jscomp$1$$)){var $JSCompiler_temp_const$jscomp$1617$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$);$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$=
$JSCompiler_temp_const$jscomp$1617$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$170_start_line$jscomp$1$$,
$APP.$cljs$cst$216$column$$,$start_column$jscomp$1_vec__24644$$,$APP.$cljs$cst$217$end_line$$,$end_line_opts$jscomp$64$$,$APP.$cljs$cst$218$end_column$$,$end_column_pending_forms$jscomp$6_vec__24647$$],null)]))}else $JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$=null;return $APP.$cljs$core$with_meta$$($JSCompiler_temp_const$jscomp$1615_the_list$$,$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8317$$)};
$cljs$tools$reader$read_vector$$=function($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$,$_$jscomp$171_start_line$jscomp$2$$,$opts$jscomp$65_the_vector$$,$end_line$jscomp$1_pending_forms$jscomp$7$$){var $start_column$jscomp$2_vec__24660$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$);$_$jscomp$171_start_line$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$2_vec__24660$$,
0,null);$start_column$jscomp$2_vec__24660$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$2_vec__24660$$,1,null);$opts$jscomp$65_the_vector$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$200$vector$$,"]",$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$,$opts$jscomp$65_the_vector$$,$end_line$jscomp$1_pending_forms$jscomp$7$$);var $end_column$jscomp$1_vec__24663$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$);
$end_line$jscomp$1_pending_forms$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$1_vec__24663$$,0,null);$end_column$jscomp$1_vec__24663$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$1_vec__24663$$,1,null);if($APP.$cljs$core$truth_$$($_$jscomp$171_start_line$jscomp$2$$)){var $JSCompiler_temp_const$jscomp$1621$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$=
$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$);$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$=$JSCompiler_temp_const$jscomp$1621$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$171_start_line$jscomp$2$$,$APP.$cljs$cst$216$column$$,$start_column$jscomp$2_vec__24660$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$1_pending_forms$jscomp$7$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$1_vec__24663$$],null)]))}else $JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$=
null;return $APP.$cljs$core$with_meta$$($opts$jscomp$65_the_vector$$,$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8319$$)};
$cljs$tools$reader$read_map$$=function($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$,$_$jscomp$172_start_line$jscomp$3$$,$end_line$jscomp$2_opts$jscomp$66$$,$end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$){var $start_column$jscomp$3_vec__24673$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$);$_$jscomp$172_start_line$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$3_vec__24673$$,
0,null);$start_column$jscomp$3_vec__24673$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$3_vec__24673$$,1,null);var $JSCompiler_temp_const$jscomp$1624_the_map$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$202$map$$,"}",$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$,$end_line$jscomp$2_opts$jscomp$66$$,$end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$),$JSCompiler_temp_const$jscomp$1626_map_count$$=$APP.$cljs$core$count$$($JSCompiler_temp_const$jscomp$1624_the_map$$),
$ks$jscomp$19$$=$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$JSCompiler_temp_const$jscomp$1624_the_map$$),$key_set$$=$APP.$cljs$core$set$$($ks$jscomp$19$$);$end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$);$end_line$jscomp$2_opts$jscomp$66$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$,
0,null);$end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$,1,null);!$APP.$cljs$core$even_QMARK_$$($JSCompiler_temp_const$jscomp$1626_map_count$$)&&$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$,$_$jscomp$172_start_line$jscomp$3$$,$start_column$jscomp$3_vec__24673$$,$JSCompiler_temp_const$jscomp$1624_the_map$$);
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($key_set$$),$APP.$cljs$core$count$$($ks$jscomp$19$$))||$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$,$APP.$cljs$cst$202$map$$,$ks$jscomp$19$$);$JSCompiler_temp_const$jscomp$1624_the_map$$=$JSCompiler_temp_const$jscomp$1626_map_count$$<=2*$APP.$cljs$core$PersistentArrayMap$HASHMAP_THRESHOLD$$?$APP.$cljs$core$PersistentArrayMap$fromArray$$($APP.$cljs$core$to_array$$($JSCompiler_temp_const$jscomp$1624_the_map$$),
!0,!0):$APP.$cljs$core$PersistentHashMap$fromArray$$($APP.$cljs$core$to_array$$($JSCompiler_temp_const$jscomp$1624_the_map$$));$APP.$cljs$core$truth_$$($_$jscomp$172_start_line$jscomp$3$$)?($JSCompiler_temp_const$jscomp$1626_map_count$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$),
$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$=$JSCompiler_temp_const$jscomp$1626_map_count$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$],null):null,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$172_start_line$jscomp$3$$,$APP.$cljs$cst$216$column$$,$start_column$jscomp$3_vec__24673$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$2_opts$jscomp$66$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$2_pending_forms$jscomp$8_vec__24676$$],null)]))):$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$=null;return $APP.$cljs$core$with_meta$$($JSCompiler_temp_const$jscomp$1624_the_map$$,
$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8321$$)};
$cljs$tools$reader$read_number$$=function($rdr$jscomp$66$$,$initch$jscomp$3$$){for(var $sb$jscomp$13$$=function(){var $G__24683$$=new $APP.$goog$string$StringBuffer$$;$G__24683$$.append($initch$jscomp$3$$);return $G__24683$$}(),$ch$jscomp$32$$=$rdr$jscomp$66$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;){if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$32$$);
if($or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$)return $or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$;$or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$=$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$32$$):$cljs$tools$reader$macros$$($ch$jscomp$32$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$)?$or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$:
$ch$jscomp$32$$==null}())){var $G__25100_s$jscomp$170$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$13$$);$ch$jscomp$32$$!=null&&$rdr$jscomp$66$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$(null,$ch$jscomp$32$$);var $G__25101_or__5025__auto__$jscomp$52$$=$APP.$cljs$tools$reader$impl$commons$match_number$$($G__25100_s$jscomp$170$$);return $APP.$cljs$core$truth_$$($G__25101_or__5025__auto__$jscomp$52$$)?$G__25101_or__5025__auto__$jscomp$52$$:$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$66$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid number: ",$G__25100_s$jscomp$170$$,"."]))}$G__25100_s$jscomp$170$$=function(){var $G__24685$$=$sb$jscomp$13$$;$G__24685$$.append($ch$jscomp$32$$);return $G__24685$$}();$G__25101_or__5025__auto__$jscomp$52$$=$rdr$jscomp$66$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);$sb$jscomp$13$$=$G__25100_s$jscomp$170$$;$ch$jscomp$32$$=$G__25101_or__5025__auto__$jscomp$52$$}};
$cljs$tools$reader$escape_char$$=function($rdr$jscomp$67$$){var $ch$jscomp$33_ch__$1$jscomp$3$$=$rdr$jscomp$67$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);switch($ch$jscomp$33_ch__$1$jscomp$3$$){case "t":return"\t";case "r":return"\r";case "n":return"\n";case "\\":return"\\";case '"':return'"';case "b":return"\b";case "f":return"\f";case "u":return $ch$jscomp$33_ch__$1$jscomp$3$$=$rdr$jscomp$67$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),-1===parseInt($ch$jscomp$33_ch__$1$jscomp$3$$|
0,16)?$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_escape$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$):$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$,16,4,!0);default:return $APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($ch$jscomp$33_ch__$1$jscomp$3$$)?($ch$jscomp$33_ch__$1$jscomp$3$$=$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$,
8,3,!1),($ch$jscomp$33_ch__$1$jscomp$3$$|0)>255?$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$($rdr$jscomp$67$$):$ch$jscomp$33_ch__$1$jscomp$3$$):$APP.$cljs$tools$reader$impl$errors$throw_bad_escape_char$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$)}};
$cljs$tools$reader$read_string_STAR_$$=function($reader$jscomp$34$$){for(var $sb$jscomp$15$$=new $APP.$goog$string$StringBuffer$$,$ch$jscomp$34$$=$reader$jscomp$34$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;){if($ch$jscomp$34$$==null)return $APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($reader$jscomp$34$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['"',$sb$jscomp$15$$]));switch($ch$jscomp$34$$){case "\\":var $G__25114_G__25117$$=
function(){var $G__24692$$=$sb$jscomp$15$$;$G__24692$$.append($cljs$tools$reader$escape_char$$($reader$jscomp$34$$));return $G__24692$$}(),$G__25115_G__25118$$=$reader$jscomp$34$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);$sb$jscomp$15$$=$G__25114_G__25117$$;$ch$jscomp$34$$=$G__25115_G__25118$$;continue;case '"':return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$15$$);default:$G__25114_G__25117$$=function(){var $G__24694$$=$sb$jscomp$15$$;$G__24694$$.append($ch$jscomp$34$$);
return $G__24694$$}();$G__25115_G__25118$$=$reader$jscomp$34$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);$sb$jscomp$15$$=$G__25114_G__25117$$;$ch$jscomp$34$$=$G__25115_G__25118$$;continue}break}};
$cljs$tools$reader$wrapping_reader$$=function($sym$jscomp$16$$){return function($rdr$jscomp$70$$,$_$jscomp$174$$,$opts$jscomp$69$$,$pending_forms$jscomp$11$$){return new $APP.$cljs$core$List$$(null,$sym$jscomp$16$$,new $APP.$cljs$core$List$$(null,$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$70$$,!0,null,$opts$jscomp$69$$,$pending_forms$jscomp$11$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$70$$,
!0,null,$opts$jscomp$69$$,$pending_forms$jscomp$11$$),null,1,null),2,null)}};
$cljs$tools$reader$read_meta$$=function($m__$1$jscomp$2_rdr$jscomp$71$$,$_$jscomp$175_line$jscomp$18$$,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$){var $column$jscomp$8_vec__24746$$=$cljs$tools$reader$starting_line_col_info$$($m__$1$jscomp$2_rdr$jscomp$71$$);$_$jscomp$175_line$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$8_vec__24746$$,0,null);$column$jscomp$8_vec__24746$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$8_vec__24746$$,
1,null);var $m$jscomp$79$$=$APP.$cljs$tools$reader$impl$utils$desugar_meta$$($cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$):$cljs$tools$reader$read_STAR_$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$));$APP.$cljs$core$map_QMARK_$$($m$jscomp$79$$)||$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata$$($m__$1$jscomp$2_rdr$jscomp$71$$,
$m$jscomp$79$$);$o$jscomp$133_opts$jscomp$70$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$):$cljs$tools$reader$read_STAR_$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$);return $o$jscomp$133_opts$jscomp$70$$!=null&&($o$jscomp$133_opts$jscomp$70$$.$cljs$lang$protocol_mask$partition0$$&
131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$133_opts$jscomp$70$$.$cljs$core$IMeta$$)?($m__$1$jscomp$2_rdr$jscomp$71$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($_$jscomp$175_line$jscomp$18$$)?$APP.$cljs$core$seq_QMARK_$$($o$jscomp$133_opts$jscomp$70$$):$_$jscomp$175_line$jscomp$18$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($m$jscomp$79$$,$APP.$cljs$cst$209$line$$,$_$jscomp$175_line$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$216$column$$,
$column$jscomp$8_vec__24746$$])):$m$jscomp$79$$,$o$jscomp$133_opts$jscomp$70$$!=null&&($o$jscomp$133_opts$jscomp$70$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$133_opts$jscomp$70$$.$cljs$core$IWithMeta$$)?$APP.$cljs$core$with_meta$$($o$jscomp$133_opts$jscomp$70$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$meta$$($o$jscomp$133_opts$jscomp$70$$),$m__$1$jscomp$2_rdr$jscomp$71$$]))):
$o$jscomp$133_opts$jscomp$70$$.$meta$=$m__$1$jscomp$2_rdr$jscomp$71$$):$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata_target$$($m__$1$jscomp$2_rdr$jscomp$71$$,$o$jscomp$133_opts$jscomp$70$$)};
$cljs$tools$reader$read_set$$=function($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$,$_$jscomp$176_start_line$jscomp$4$$,$opts$jscomp$71_the_set$$,$end_line$jscomp$4_pending_forms$jscomp$13$$){var $start_column$jscomp$4_start_column__$1_vec__24775$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$);$_$jscomp$176_start_line$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$4_start_column__$1_vec__24775$$,
0,null);$start_column$jscomp$4_start_column__$1_vec__24775$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$4_start_column__$1_vec__24775$$,1,null);$start_column$jscomp$4_start_column__$1_vec__24775$$=$APP.$cljs$core$truth_$$($start_column$jscomp$4_start_column__$1_vec__24775$$)?$start_column$jscomp$4_start_column__$1_vec__24775$$-1|0:null;var $JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$203$set$$,"}",$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$,
$opts$jscomp$71_the_set$$,$end_line$jscomp$4_pending_forms$jscomp$13$$);$opts$jscomp$71_the_set$$=$APP.$cljs$core$set$$($JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$);var $end_column$jscomp$4_vec__24778$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$);$end_line$jscomp$4_pending_forms$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$4_vec__24778$$,0,null);$end_column$jscomp$4_vec__24778$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$4_vec__24778$$,1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$),$APP.$cljs$core$count$$($opts$jscomp$71_the_set$$))||$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$,
$APP.$cljs$cst$203$set$$,$JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$)]));$APP.$cljs$core$truth_$$($_$jscomp$176_start_line$jscomp$4$$)?($JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$),$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$=
$JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$176_start_line$jscomp$4$$,
$APP.$cljs$cst$216$column$$,$start_column$jscomp$4_start_column__$1_vec__24775$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$4_pending_forms$jscomp$13$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$4_vec__24778$$],null)]))):$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$=null;return $APP.$cljs$core$with_meta$$($opts$jscomp$71_the_set$$,$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8323$$)};
$cljs$tools$reader$read_discard$$=function($rdr$jscomp$73$$,$_$jscomp$177$$,$opts$jscomp$72$$,$pending_forms$jscomp$14$$){$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$73$$,!0,null,$opts$jscomp$72$$,$pending_forms$jscomp$14$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$73$$,!0,null,$opts$jscomp$72$$,$pending_forms$jscomp$14$$);return $rdr$jscomp$73$$};
$cljs$tools$reader$read_symbolic_value$$=function($rdr$jscomp$74$$,$_$jscomp$178_sym$jscomp$17$$,$opts$jscomp$73$$,$pending_forms$jscomp$15$$){$_$jscomp$178_sym$jscomp$17$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$74$$,!0,null,$opts$jscomp$73$$,$pending_forms$jscomp$15$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$74$$,!0,null,$opts$jscomp$73$$,$pending_forms$jscomp$15$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$222$NaN$$,
$_$jscomp$178_sym$jscomp$17$$)?Number.NaN:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$223$_Inf$$,$_$jscomp$178_sym$jscomp$17$$)?Number.NEGATIVE_INFINITY:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$224$Inf$$,$_$jscomp$178_sym$jscomp$17$$)?Number.POSITIVE_INFINITY:$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$74$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["Invalid token: ##",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$178_sym$jscomp$17$$)].join("")]))};
$cljs$tools$reader$read_suppress$$=function($first_line$jscomp$2$$,$rdr$jscomp$79$$,$opts$jscomp$75$$,$pending_forms$jscomp$16$$){var $_STAR_suppress_read_STAR__orig_val__24812$$=$cljs$tools$reader$_STAR_suppress_read_STAR_$$;$cljs$tools$reader$_STAR_suppress_read_STAR_$$=!0;try{var $form$jscomp$14$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($rdr$jscomp$79$$,!1,$cljs$tools$reader$READ_EOF$$,")",$opts$jscomp$75$$,
$pending_forms$jscomp$16$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$79$$,!1,$cljs$tools$reader$READ_EOF$$,")",$opts$jscomp$75$$,$pending_forms$jscomp$16$$);$cljs$tools$reader$check_eof_error$$($form$jscomp$14$$,$rdr$jscomp$79$$,$first_line$jscomp$2$$);return $form$jscomp$14$$===$cljs$tools$reader$READ_FINISHED$$?$cljs$tools$reader$READ_FINISHED$$:null}finally{$cljs$tools$reader$_STAR_suppress_read_STAR_$$=$_STAR_suppress_read_STAR__orig_val__24812$$}};
$cljs$tools$reader$read_cond_delimited$$=function($rdr$jscomp$81$$,$elementsToAdd$jscomp$inline_13252_splicing$$,$opts$jscomp$77_result$jscomp$80$$,$pending_forms$jscomp$18$$){var $first_line$jscomp$4$$=$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$81$$)?$APP.$cljs$tools$reader$reader_types$get_line_number$$($rdr$jscomp$81$$):-1;a:{for(var $G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$=
$cljs$tools$reader$NO_MATCH$$,$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$=null;;)if($G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$===$cljs$tools$reader$NO_MATCH$$){$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$=
$first_line$jscomp$4$$;$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$=$rdr$jscomp$81$$;var $G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$=$opts$jscomp$77_result$jscomp$80$$,$pending_forms$jscomp$inline_13246$$=$pending_forms$jscomp$18$$,$feature$jscomp$inline_13247_feature$jscomp$inline_14594$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,
!1,$cljs$tools$reader$READ_EOF$$,")",$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$,$pending_forms$jscomp$inline_13246$$):$cljs$tools$reader$read_STAR_$$($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,!1,$cljs$tools$reader$READ_EOF$$,")",$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$,$pending_forms$jscomp$inline_13246$$);$cljs$tools$reader$check_eof_error$$($feature$jscomp$inline_13247_feature$jscomp$inline_14594$$,$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,
$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($feature$jscomp$inline_13247_feature$jscomp$inline_14594$$,$cljs$tools$reader$READ_FINISHED$$))$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$=
$cljs$tools$reader$READ_FINISHED$$;else{var $rdr$jscomp$inline_14590_rdr$jscomp$inline_14593$$=$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,$form$jscomp$inline_14591_opts$jscomp$inline_14595$$=$feature$jscomp$inline_13247_feature$jscomp$inline_14594$$;$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$tools$reader$RESERVED_FEATURES$$,$form$jscomp$inline_14591_opts$jscomp$inline_14595$$))&&$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$inline_14590_rdr$jscomp$inline_14593$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Feature name ",$form$jscomp$inline_14591_opts$jscomp$inline_14595$$," is reserved"]));$rdr$jscomp$inline_14590_rdr$jscomp$inline_14593$$=$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$;$form$jscomp$inline_14591_opts$jscomp$inline_14595$$=$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$;($feature$jscomp$inline_13247_feature$jscomp$inline_14594$$ instanceof $APP.$cljs$core$Keyword$$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,$feature$jscomp$inline_13247_feature$jscomp$inline_14594$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$inline_14591_opts$jscomp$inline_14595$$,$APP.$cljs$cst$227$features$$),$feature$jscomp$inline_13247_feature$jscomp$inline_14594$$):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$inline_14590_rdr$jscomp$inline_14593$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Feature should be a keyword: ",$feature$jscomp$inline_13247_feature$jscomp$inline_14594$$])))?($G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,!1,$cljs$tools$reader$READ_EOF$$,")",$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$,
$pending_forms$jscomp$inline_13246$$):$cljs$tools$reader$read_STAR_$$($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,!1,$cljs$tools$reader$READ_EOF$$,")",$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$,$pending_forms$jscomp$inline_13246$$),$cljs$tools$reader$check_eof_error$$($G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$,$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,
$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$),$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$===$cljs$tools$reader$READ_FINISHED$$&&($G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$<0?$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["read-cond requires an even number of forms"])):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["read-cond starting on line ",$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$,
" requires an even number of forms"]))),$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$=$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$):($G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$=$cljs$tools$reader$read_suppress$$($G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$,
$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$,$G__24830$jscomp$inline_13248_opts$jscomp$inline_13245$$,$pending_forms$jscomp$inline_13246$$),$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$=$APP.$cljs$core$truth_$$($G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$)?
$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$:$cljs$tools$reader$NO_MATCH$$)}if($G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$===$cljs$tools$reader$READ_FINISHED$$){$opts$jscomp$77_result$jscomp$80$$=$cljs$tools$reader$READ_FINISHED$$;
break a}$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$=null}else if($G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$!==$cljs$tools$reader$READ_FINISHED$$)$G__25179$jscomp$inline_8329_finished$jscomp$inline_8326_rdr$jscomp$inline_13244_rdr$jscomp$inline_14598$$=$cljs$tools$reader$read_suppress$$($first_line$jscomp$4$$,$rdr$jscomp$81$$,$opts$jscomp$77_result$jscomp$80$$,$pending_forms$jscomp$18$$);
else{$opts$jscomp$77_result$jscomp$80$$=$G__25178$jscomp$inline_8328_first_line$jscomp$inline_13243_first_line$jscomp$inline_14599_match$jscomp$inline_8327_matched$jscomp$inline_8325_or__5025__auto__$jscomp$inline_13249$$;break a}$opts$jscomp$77_result$jscomp$80$$=void 0}return $opts$jscomp$77_result$jscomp$80$$===$cljs$tools$reader$READ_FINISHED$$?$rdr$jscomp$81$$:$APP.$cljs$core$truth_$$($elementsToAdd$jscomp$inline_13252_splicing$$)?$opts$jscomp$77_result$jscomp$80$$!=null&&($opts$jscomp$77_result$jscomp$80$$.$cljs$lang$protocol_mask$partition0$$&
16777216||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$opts$jscomp$77_result$jscomp$80$$.$cljs$core$ISequential$$)?($elementsToAdd$jscomp$inline_13252_splicing$$=$APP.$cljs$core$to_array$$($opts$jscomp$77_result$jscomp$80$$),$APP.$goog$partial$$($module$contents$goog$array_splice$$,$pending_forms$jscomp$18$$,0,0).apply(null,$elementsToAdd$jscomp$inline_13252_splicing$$),$rdr$jscomp$81$$):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$81$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Spliced form list in read-cond-splicing must implement ISequential"])):
$opts$jscomp$77_result$jscomp$80$$};
$cljs$tools$reader$read_cond$$=function($rdr$jscomp$82$$,$_$jscomp$179_splicing$jscomp$1$$,$opts$jscomp$78$$,$pending_forms$jscomp$19$$){if($APP.$cljs$core$not$$(function(){if($APP.$cljs$core$truth_$$($opts$jscomp$78$$)){var $G__24849$$=$APP.$cljs$cst$228$read_cond$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$78$$),$fexpr__24848$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$229$preserve$$,null,$APP.$cljs$cst$230$allow$$,null],null),
null);return $fexpr__24848$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__24848$$.$cljs$core$IFn$_invoke$arity$1$($G__24849$$):$fexpr__24848$$($G__24849$$)}return $opts$jscomp$78$$}()))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Conditional read not allowed",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$231$runtime_exception$$],null));var $ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$=$rdr$jscomp$82$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);
if($APP.$cljs$core$truth_$$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$))if($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$=($_$jscomp$179_splicing$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,"@"))?$rdr$jscomp$82$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null):$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,
$_$jscomp$179_splicing$jscomp$1$$&&($APP.$cljs$core$truth_$$($cljs$tools$reader$_STAR_read_delim_STAR_$$)||$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$82$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["cond-splice not in list"]))),$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$)?
$APP.$cljs$tools$reader$impl$commons$read_past$$($rdr$jscomp$82$$):$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,$APP.$cljs$core$truth_$$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$)){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,"("))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("read-cond body must be a list",new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$231$runtime_exception$$],null));var $_STAR_suppress_read_STAR__orig_val__24852$$=$cljs$tools$reader$_STAR_suppress_read_STAR_$$;$cljs$tools$reader$_STAR_suppress_read_STAR_$$=function(){var $or__5025__auto__$jscomp$56$$=$cljs$tools$reader$_STAR_suppress_read_STAR_$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$56$$)?$or__5025__auto__$jscomp$56$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$229$preserve$$,$APP.$cljs$cst$228$read_cond$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$78$$))}();
try{return $APP.$cljs$core$truth_$$($cljs$tools$reader$_STAR_suppress_read_STAR_$$)?$cljs$tools$reader$impl$utils$reader_conditional$$($cljs$tools$reader$read_list$$($rdr$jscomp$82$$,$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,$opts$jscomp$78$$,$pending_forms$jscomp$19$$),$_$jscomp$179_splicing$jscomp$1$$):$cljs$tools$reader$read_cond_delimited$$($rdr$jscomp$82$$,$_$jscomp$179_splicing$jscomp$1$$,$opts$jscomp$78$$,$pending_forms$jscomp$19$$)}finally{$cljs$tools$reader$_STAR_suppress_read_STAR_$$=
$_STAR_suppress_read_STAR__orig_val__24852$$}}else return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$82$$);else return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$82$$)};
$cljs$tools$reader$read_fn$$=function($i$jscomp$inline_14603_rdr$jscomp$83$$,$_$jscomp$180_arg_env_orig_val__24857$$,$G__25192$jscomp$inline_14605_opts$jscomp$79$$,$JSCompiler_temp_const$jscomp$inline_14606_pending_forms$jscomp$20$$){if($APP.$cljs$core$truth_$$($cljs$tools$reader$arg_env$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Nested #()s are not allowed",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));
$_$jscomp$180_arg_env_orig_val__24857$$=$cljs$tools$reader$arg_env$$;$cljs$tools$reader$arg_env$$=$cljs$core$sorted_map$$();try{$APP.$cljs$tools$reader$reader_types$unread$$($i$jscomp$inline_14603_rdr$jscomp$83$$,"(");var $form$jscomp$15$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($i$jscomp$inline_14603_rdr$jscomp$83$$,!0,null,$G__25192$jscomp$inline_14605_opts$jscomp$79$$,$JSCompiler_temp_const$jscomp$inline_14606_pending_forms$jscomp$20$$):
$cljs$tools$reader$read_STAR_$$($i$jscomp$inline_14603_rdr$jscomp$83$$,!0,null,$G__25192$jscomp$inline_14605_opts$jscomp$79$$,$JSCompiler_temp_const$jscomp$inline_14606_pending_forms$jscomp$20$$);var $JSCompiler_temp_const$jscomp$inline_14608_rargs$$=$APP.$cljs$core$_rseq$$($cljs$tools$reader$arg_env$$);if($JSCompiler_temp_const$jscomp$inline_14608_rargs$$){var $higharg$jscomp$inline_14601$$=$APP.$cljs$core$key$$($APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$inline_14608_rargs$$));a:{$i$jscomp$inline_14603_rdr$jscomp$83$$=
1;for(var $args$jscomp$inline_14604$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){if($i$jscomp$inline_14603_rdr$jscomp$83$$>$higharg$jscomp$inline_14601$$){var $args$jscomp$inline_14602$$=$APP.$cljs$core$_persistent_BANG_$$($args$jscomp$inline_14604$$);break a}$G__25192$jscomp$inline_14605_opts$jscomp$79$$=$i$jscomp$inline_14603_rdr$jscomp$83$$+1;$JSCompiler_temp_const$jscomp$inline_14606_pending_forms$jscomp$20$$=$APP.$cljs$core$conj_BANG_$$;var $JSCompiler_temp_const$jscomp$inline_14607$$=
$JSCompiler_temp_const$jscomp$inline_14606_pending_forms$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$;$JSCompiler_temp_const$jscomp$inline_14608_rargs$$=$args$jscomp$inline_14604$$;var $or__5025__auto__$jscomp$inline_14610$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$tools$reader$arg_env$$,$i$jscomp$inline_14603_rdr$jscomp$83$$);var $JSCompiler_inline_result$jscomp$inline_14609$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_14610$$)?$or__5025__auto__$jscomp$inline_14610$$:
$cljs$tools$reader$garg$$($i$jscomp$inline_14603_rdr$jscomp$83$$);var $G__25193$jscomp$inline_14611$$=$JSCompiler_temp_const$jscomp$inline_14607$$.call($JSCompiler_temp_const$jscomp$inline_14606_pending_forms$jscomp$20$$,$JSCompiler_temp_const$jscomp$inline_14608_rargs$$,$JSCompiler_inline_result$jscomp$inline_14609$$);$i$jscomp$inline_14603_rdr$jscomp$83$$=$G__25192$jscomp$inline_14605_opts$jscomp$79$$;$args$jscomp$inline_14604$$=$G__25193$jscomp$inline_14611$$}$args$jscomp$inline_14602$$=void 0}var $JSCompiler_temp$jscomp$14091$$=
$APP.$cljs$core$truth_$$($cljs$tools$reader$arg_env$$.call(null,-1))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($args$jscomp$inline_14602$$,$APP.$cljs$cst$148$_AMPERSAND_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$tools$reader$arg_env$$.call(null,-1)])):$args$jscomp$inline_14602$$}else $JSCompiler_temp$jscomp$14091$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$162$fn_STAR_$$,new $APP.$cljs$core$List$$(null,
$JSCompiler_temp$jscomp$14091$$,new $APP.$cljs$core$List$$(null,$form$jscomp$15$$,null,1,null),2,null),3,null)}finally{$cljs$tools$reader$arg_env$$=$_$jscomp$180_arg_env_orig_val__24857$$}};
$cljs$tools$reader$read_arg$$=function($n$jscomp$176_rdr$jscomp$84$$,$ch$jscomp$37_pct$$,$opts$jscomp$80$$,$pending_forms$jscomp$21$$){if($cljs$tools$reader$arg_env$$==null)return $cljs$tools$reader$read_symbol$$($n$jscomp$176_rdr$jscomp$84$$,$ch$jscomp$37_pct$$);$ch$jscomp$37_pct$$=$n$jscomp$176_rdr$jscomp$84$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$37_pct$$)||$cljs$tools$reader$macro_terminating_QMARK_$$($ch$jscomp$37_pct$$)||
$ch$jscomp$37_pct$$==null)return $cljs$tools$reader$register_arg$$(1);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ch$jscomp$37_pct$$,"\x26"))return $n$jscomp$176_rdr$jscomp$84$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),$cljs$tools$reader$register_arg$$(-1);$n$jscomp$176_rdr$jscomp$84$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($n$jscomp$176_rdr$jscomp$84$$,!0,null,$opts$jscomp$80$$,
$pending_forms$jscomp$21$$):$cljs$tools$reader$read_STAR_$$($n$jscomp$176_rdr$jscomp$84$$,!0,null,$opts$jscomp$80$$,$pending_forms$jscomp$21$$);if($APP.$cljs$core$integer_QMARK_$$($n$jscomp$176_rdr$jscomp$84$$))return $cljs$tools$reader$register_arg$$($n$jscomp$176_rdr$jscomp$84$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Arg literal must be %, %\x26 or %integer",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],
null));};
$cljs$tools$reader$read_unquote$$=function($JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$,$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$,$opts$jscomp$81$$,$pending_forms$jscomp$22$$){$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$=$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("@",
$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$)?($JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$=$cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$233$clojure_DOT_core_SLASH_unquote_splicing$$),$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$=$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$($JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$,
"@",$opts$jscomp$81$$,$pending_forms$jscomp$22$$)):$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$=$cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$)($JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$,"~",$opts$jscomp$81$$,$pending_forms$jscomp$22$$):$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$=null;return $JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$};
$cljs$tools$reader$read_syntax_quote$$=function($rdr$jscomp$86$$,$backquote_gensym_env_orig_val__24903$$,$opts$jscomp$82$$,$pending_forms$jscomp$23$$){$backquote_gensym_env_orig_val__24903$$=$cljs$tools$reader$gensym_env$$;$cljs$tools$reader$gensym_env$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;try{return $cljs$tools$reader$syntax_quote_STAR_$$($cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$86$$,!0,
null,$opts$jscomp$82$$,$pending_forms$jscomp$23$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$86$$,!0,null,$opts$jscomp$82$$,$pending_forms$jscomp$23$$))}finally{$cljs$tools$reader$gensym_env$$=$backquote_gensym_env_orig_val__24903$$}};
$cljs$tools$reader$read_namespaced_map$$=function($rdr$jscomp$87$$,$_$jscomp$181_start_line$jscomp$5$$,$end_line$jscomp$5_opts$jscomp$83$$,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$){var $start_column$jscomp$5_vec__24908$$=$cljs$tools$reader$starting_line_col_info$$($rdr$jscomp$87$$);$_$jscomp$181_start_line$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$5_vec__24908$$,0,null);$start_column$jscomp$5_vec__24908$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$5_vec__24908$$,
1,null);var $token$jscomp$24$$=$cljs$tools$reader$read_token$$($rdr$jscomp$87$$,$APP.$cljs$cst$247$namespaced_map$$,$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$87$$)),$keys$jscomp$20_temp__5823__auto__$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$24$$,":")?null.name:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(":",$APP.$cljs$core$first$$($token$jscomp$24$$))?function(){var $G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=
$token$jscomp$24$$==null?null:$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$24$$,1);$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$==null?null:$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$);
$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$==null?null:$APP.$cljs$tools$reader$impl$utils$second_SINGLEQUOTE_$$($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$);$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=
$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$==null?null:$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$);if($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$==null)$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=
null;else{var $G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(null,$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$);if($APP.$cljs$core$truth_$$($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$))$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=
$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$;else{$cljs$core$NS_CACHE$$==null&&($cljs$core$NS_CACHE$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$));$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cljs$core$NS_CACHE$$),$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$);if($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$!=null)$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=
$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$;else{$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$);
var $G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$);for(var $sb$jscomp$inline_14851$$=new $APP.$goog$string$StringBuffer$$,$i_30102$jscomp$inline_14852$$=
0;;)if($i_30102$jscomp$inline_14852$$<$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$.length){var $c_30103$jscomp$inline_14853$$=$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$.charAt($i_30102$jscomp$inline_14852$$),$sub_30104$jscomp$inline_14854$$=$APP.$module$contents$goog$object_get$$($cljs$core$CHAR_MAP$$,
$c_30103$jscomp$inline_14853$$);$sub_30104$jscomp$inline_14854$$!=null?$sb$jscomp$inline_14851$$.append($sub_30104$jscomp$inline_14854$$):$sb$jscomp$inline_14851$$.append($c_30103$jscomp$inline_14853$$);$i_30102$jscomp$inline_14852$$+=1}else break;$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$=$sb$jscomp$inline_14851$$.toString();$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$=
$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$===".."?"_DOT__DOT_":$APP.$cljs$core$truth_$$($cljs$core$js_reserved_QMARK_$$($G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$))?[$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$,
"$"].join(""):$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$;c:{$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$ instanceof
$APP.$cljs$core$Symbol$$?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$):$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$).split(".");for($G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$=
$APP.$goog$global$$;;){if($G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$==null){$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=null;break c}if($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$==
null){$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$;break c}$G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$=
$APP.$module$contents$goog$object_get$$($G__30152$jscomp$inline_14807_ctxt$jscomp$inline_14806_name$jscomp$inline_14850_name_SINGLEQUOTE_$jscomp$inline_14802_name_SINGLEQUOTE___$1$jscomp$inline_14803$$,$APP.$cljs$core$first$$($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$));$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=
$APP.$cljs$core$next$$($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$)}$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=void 0}$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$==
null?$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=null:($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$=new $cljs$core$Namespace$$($G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$,
$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$core$NS_CACHE$$,$APP.$cljs$core$assoc$$,$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$,$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$),
$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=$G__30153$jscomp$inline_14808_name$jscomp$inline_14801_new_ns$jscomp$inline_13268_ns_obj$jscomp$inline_13267_or__5025__auto__$jscomp$inline_8336_the_ns$jscomp$inline_13266_xs$jscomp$inline_14805$$)}$G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$=$APP.$cljs$core$truth_$$($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$)?
$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$.name):null}}return $G__24911__$1_G__24911__$2_G__24911__$3_G__24911__$4_JSCompiler_temp$jscomp$1537_temp__5825__auto__$jscomp$inline_8337$$}():function(){var $G__24912__$1$$=$token$jscomp$24$$==null?null:$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($token$jscomp$24$$);return $G__24912__$1$$==null?null:$APP.$cljs$tools$reader$impl$utils$second_SINGLEQUOTE_$$($G__24912__$1$$)}();
if($APP.$cljs$core$truth_$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$)){if($APP.$cljs$tools$reader$impl$commons$read_past$$($rdr$jscomp$87$$)==="{"){$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$247$namespaced_map$$,"}",$rdr$jscomp$87$$,$end_line$jscomp$5_opts$jscomp$83$$,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$);var $end_column$jscomp$5_vec__24917$$=$cljs$tools$reader$ending_line_col_info$$($rdr$jscomp$87$$);$end_line$jscomp$5_opts$jscomp$83$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$5_vec__24917$$,0,null);$end_column$jscomp$5_vec__24917$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$5_vec__24917$$,1,null);$APP.$cljs$core$odd_QMARK_$$($APP.$cljs$core$count$$($items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$))&&$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$($rdr$jscomp$87$$,null,null,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$);$keys$jscomp$20_temp__5823__auto__$jscomp$26$$=
$APP.$cljs$tools$reader$impl$utils$namespace_keys$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$),$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$));$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$=$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$APP.$cljs$core$rest$$($items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$core$set$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$)),
$APP.$cljs$core$count$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$))||$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($rdr$jscomp$87$$,$APP.$cljs$cst$247$namespaced_map$$,$keys$jscomp$20_temp__5823__auto__$jscomp$26$$);return $APP.$cljs$core$with_meta$$($APP.$cljs$core$zipmap$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$),$APP.$cljs$core$truth_$$($_$jscomp$181_start_line$jscomp$5$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $temp__5825__auto__$jscomp$51$$=
$APP.$cljs$tools$reader$reader_types$get_file_name$$($rdr$jscomp$87$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$51$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$temp__5825__auto__$jscomp$51$$],null):null}(),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$181_start_line$jscomp$5$$,$APP.$cljs$cst$216$column$$,$start_column$jscomp$5_vec__24908$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$5_opts$jscomp$83$$,$APP.$cljs$cst$218$end_column$$,
$end_column$jscomp$5_vec__24917$$],null)])):null)}return $APP.$cljs$tools$reader$impl$errors$throw_ns_map_no_map$$($rdr$jscomp$87$$,$token$jscomp$24$$)}return $APP.$cljs$tools$reader$impl$errors$throw_bad_ns$$($rdr$jscomp$87$$,$token$jscomp$24$$)};
$cljs$tools$reader$macros$$=function($ch$jscomp$40$$){switch($ch$jscomp$40$$){case '"':return $cljs$tools$reader$read_string_STAR_$$;case ":":return $cljs$tools$reader$read_keyword$$;case ";":return $APP.$cljs$tools$reader$impl$commons$read_comment$$;case "'":return $cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$167$quote$$);case "@":return $cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$248$clojure_DOT_core_SLASH_deref$$);case "^":return $cljs$tools$reader$read_meta$$;case "`":return $cljs$tools$reader$read_syntax_quote$$;
case "~":return $cljs$tools$reader$read_unquote$$;case "(":return $cljs$tools$reader$read_list$$;case ")":return $cljs$tools$reader$read_unmatched_delimiter$$;case "[":return $cljs$tools$reader$read_vector$$;case "]":return $cljs$tools$reader$read_unmatched_delimiter$$;case "{":return $cljs$tools$reader$read_map$$;case "}":return $cljs$tools$reader$read_unmatched_delimiter$$;case "\\":return $cljs$tools$reader$read_char_STAR_$$;case "%":return $cljs$tools$reader$read_arg$$;case "#":return $cljs$tools$reader$read_dispatch$$;
default:return null}};
$cljs$tools$reader$dispatch_macros$$=function($ch$jscomp$41$$){switch($ch$jscomp$41$$){case "^":return $cljs$tools$reader$read_meta$$;case "'":return $cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$166$var$$);case "(":return $cljs$tools$reader$read_fn$$;case "{":return $cljs$tools$reader$read_set$$;case "\x3c":return $APP.$cljs$tools$reader$impl$commons$throwing_reader$$("Unreadable form");case "\x3d":return $APP.$cljs$tools$reader$impl$commons$throwing_reader$$("read-eval not supported");case '"':return $cljs$tools$reader$read_regex$$;
case "!":return $APP.$cljs$tools$reader$impl$commons$read_comment$$;case "_":return $cljs$tools$reader$read_discard$$;case "?":return $cljs$tools$reader$read_cond$$;case ":":return $cljs$tools$reader$read_namespaced_map$$;case "#":return $cljs$tools$reader$read_symbolic_value$$;default:return null}};
$cljs$tools$reader$read_tagged$$=function($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,$G__24934_initch$jscomp$6_tag$jscomp$18$$,$opts$jscomp$84$$,$pending_forms$jscomp$25$$){$G__24934_initch$jscomp$6_tag$jscomp$18$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,
!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$);$G__24934_initch$jscomp$6_tag$jscomp$18$$ instanceof $APP.$cljs$core$Symbol$$||$APP.$cljs$tools$reader$impl$errors$throw_bad_reader_tag$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,$G__24934_initch$jscomp$6_tag$jscomp$18$$);if($APP.$cljs$core$truth_$$($cljs$tools$reader$_STAR_suppress_read_STAR_$$))return $G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,
!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$),new $cljs$core$TaggedLiteral$$($G__24934_initch$jscomp$6_tag$jscomp$18$$,$G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$);var $f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$=$APP.$cljs$tools$reader$_STAR_data_readers_STAR_$$.call(null,$G__24934_initch$jscomp$6_tag$jscomp$18$$);
$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$=$APP.$cljs$core$truth_$$($f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$)?$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$:$APP.$cljs$tools$reader$default_data_readers$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$tools$reader$default_data_readers$$.$cljs$core$IFn$_invoke$arity$1$($G__24934_initch$jscomp$6_tag$jscomp$18$$):(0,$APP.$cljs$tools$reader$default_data_readers$$)($G__24934_initch$jscomp$6_tag$jscomp$18$$);
return $APP.$cljs$core$truth_$$($f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$)?($G__24934_initch$jscomp$6_tag$jscomp$18$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,
$pending_forms$jscomp$25$$),$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$($G__24934_initch$jscomp$6_tag$jscomp$18$$):$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$($G__24934_initch$jscomp$6_tag$jscomp$18$$)):$APP.$cljs$core$truth_$$(null)?($f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$=
null,$G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$),$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$($G__24934_initch$jscomp$6_tag$jscomp$18$$,$G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$):$f$jscomp$337_or__5025__auto__$jscomp$inline_8339_temp__5823__auto__$jscomp$27$$($G__24934_initch$jscomp$6_tag$jscomp$18$$,$G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$)):$APP.$cljs$tools$reader$impl$errors$throw_unknown_reader_tag$$($G__24936_form$jscomp$inline_13271_rdr$jscomp$88$$,$G__24934_initch$jscomp$6_tag$jscomp$18$$)};
$cljs$tools$reader$read_STAR_$$=function($var_args$jscomp$326$$){switch(arguments.length){case 5:return $cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);case 6:return $cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$=function($reader$jscomp$37$$,$eof_error_QMARK_$jscomp$1$$,$sentinel$jscomp$2$$,$opts$jscomp$86$$,$pending_forms$jscomp$27$$){return $cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($reader$jscomp$37$$,$eof_error_QMARK_$jscomp$1$$,$sentinel$jscomp$2$$,null,$opts$jscomp$86$$,$pending_forms$jscomp$27$$)};
$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$=function($reader$jscomp$38$$,$e$jscomp$128_eof_error_QMARK_$jscomp$2$$,$d$jscomp$103_sentinel$jscomp$3$$,$return_on$jscomp$1$$,$opts$jscomp$87$$,$pending_forms$jscomp$28$$){try{a:{for(;;){if($pending_forms$jscomp$28$$.length==0){var $ch$jscomp$inline_13279$$=$reader$jscomp$38$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$inline_13279$$))continue;
else{if($ch$jscomp$inline_13279$$==null){var $JSCompiler_inline_result$jscomp$10981$$=$e$jscomp$128_eof_error_QMARK_$jscomp$2$$?$APP.$cljs$tools$reader$impl$errors$throw_eof_error$$($reader$jscomp$38$$,null):$d$jscomp$103_sentinel$jscomp$3$$;break a}if($ch$jscomp$inline_13279$$===$return_on$jscomp$1$$){$JSCompiler_inline_result$jscomp$10981$$=$cljs$tools$reader$READ_FINISHED$$;break a}if($APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($ch$jscomp$inline_13279$$)||("+"===$ch$jscomp$inline_13279$$||
"-"===$ch$jscomp$inline_13279$$)&&$APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($reader$jscomp$38$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null))){$JSCompiler_inline_result$jscomp$10981$$=$cljs$tools$reader$read_number$$($reader$jscomp$38$$,$ch$jscomp$inline_13279$$);break a}var $f$jscomp$inline_13280$$=$cljs$tools$reader$macros$$($ch$jscomp$inline_13279$$);if($f$jscomp$inline_13280$$!=null){var $res$jscomp$inline_13281$$=$f$jscomp$inline_13280$$.$cljs$core$IFn$_invoke$arity$4$?
$f$jscomp$inline_13280$$.$cljs$core$IFn$_invoke$arity$4$($reader$jscomp$38$$,$ch$jscomp$inline_13279$$,$opts$jscomp$87$$,$pending_forms$jscomp$28$$):$f$jscomp$inline_13280$$($reader$jscomp$38$$,$ch$jscomp$inline_13279$$,$opts$jscomp$87$$,$pending_forms$jscomp$28$$);if($res$jscomp$inline_13281$$===$reader$jscomp$38$$)continue;else{$JSCompiler_inline_result$jscomp$10981$$=$res$jscomp$inline_13281$$;break a}}else{$JSCompiler_inline_result$jscomp$10981$$=$cljs$tools$reader$read_symbol$$($reader$jscomp$38$$,
$ch$jscomp$inline_13279$$);break a}}}else{var $form$jscomp$inline_13282$$=$pending_forms$jscomp$28$$[0];Array.prototype.splice.call($pending_forms$jscomp$28$$,0,1);$JSCompiler_inline_result$jscomp$10981$$=$form$jscomp$inline_13282$$;break a}break}$JSCompiler_inline_result$jscomp$10981$$=void 0}return $JSCompiler_inline_result$jscomp$10981$$}catch($e24939$$){if($e24939$$ instanceof Error){$e$jscomp$128_eof_error_QMARK_$jscomp$2$$=$e24939$$;if($e$jscomp$128_eof_error_QMARK_$jscomp$2$$ instanceof $APP.$cljs$core$ExceptionInfo$$){$d$jscomp$103_sentinel$jscomp$3$$=
$APP.$cljs$core$ex_data$$($e$jscomp$128_eof_error_QMARK_$jscomp$2$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$206$reader_exception$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$103_sentinel$jscomp$3$$)))throw $e$jscomp$128_eof_error_QMARK_$jscomp$2$$;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$128_eof_error_QMARK_$jscomp$2$$.message,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$],null),$d$jscomp$103_sentinel$jscomp$3$$,$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($reader$jscomp$38$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$209$line$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$APP.$cljs$cst$216$column$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null),$APP.$cljs$cst$208$file$$,
$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_file_name$arity$1$(null)],null):null])),$e$jscomp$128_eof_error_QMARK_$jscomp$2$$);}throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$128_eof_error_QMARK_$jscomp$2$$.message,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$],
null),$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($reader$jscomp$38$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$209$line$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$APP.$cljs$cst$216$column$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null),$APP.$cljs$cst$208$file$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_file_name$arity$1$(null)],
null):null])),$e$jscomp$128_eof_error_QMARK_$jscomp$2$$);}throw $e24939$$;}};
$app$main$data$workspace$libraries$go_to_component_file$$=function($file_id$jscomp$153$$,$component$jscomp$79$$,$update_layout_QMARK_$$){typeof $app$main$data$workspace$libraries$nav_to_component_file_69637$$==="undefined"&&($app$main$data$workspace$libraries$nav_to_component_file_69637$$=function($file_id$jscomp$154$$,$component$jscomp$80$$,$update_layout_QMARK_$jscomp$1$$,$meta69638$$){this.$file_id$=$file_id$jscomp$154$$;this.component=$component$jscomp$80$$;this.$update_layout_QMARK_$=$update_layout_QMARK_$jscomp$1$$;
this.$meta69638$=$meta69638$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$nav_to_component_file_69637$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$nav_to_component_file_69637$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3937$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_nav_to_component_file$$},$app$main$data$workspace$libraries$nav_to_component_file_69637$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69639$$,$meta69638__$1$$){return new $app$main$data$workspace$libraries$nav_to_component_file_69637$$(this.$file_id$,this.component,this.$update_layout_QMARK_$,$meta69638__$1$$)},$app$main$data$workspace$libraries$nav_to_component_file_69637$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69638$},$app$main$data$workspace$libraries$nav_to_component_file_69637$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$nav_to_component_file_69637$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2118_params$jscomp$279$$,$state$jscomp$511$$){$_$jscomp$2118_params$jscomp$279$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$router$get_params$$($state$jscomp$511$$),$APP.$cljs$cst$1644$file_id$$,this.$file_id$),$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$(this.component)),
$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.component)),$APP.$cljs$cst$3938$update_layout$$,this.$update_layout_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,$_$jscomp$2118_params$jscomp$279$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,!0])))});return new $app$main$data$workspace$libraries$nav_to_component_file_69637$$($file_id$jscomp$153$$,
$component$jscomp$79$$,$update_layout_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_component_in_assets$$=function($component_id$jscomp$86$$){typeof $app$main$data$workspace$show_component_in_assets_71950$$==="undefined"&&($app$main$data$workspace$show_component_in_assets_71950$$=function($component_id$jscomp$87$$,$meta71951$$){this.$component_id$=$component_id$jscomp$87$$;this.$meta71951$=$meta71951$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4503$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_component_in_assets$$},$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71952$$,$meta71951__$1$$){return new $app$main$data$workspace$show_component_in_assets_71950$$(this.$component_id$,$meta71951__$1$$)},
$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71951$},$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2574_component$jscomp$93_fdata$jscomp$18$$,$cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$){var $file_id$jscomp$293$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$);$_$jscomp$2574_component$jscomp$93_fdata$jscomp$18$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$,$file_id$jscomp$293$$);$_$jscomp$2574_component$jscomp$93_fdata$jscomp$18$$=$app$common$files$variant$get_primary_component$$($_$jscomp$2574_component$jscomp$93_fdata$jscomp$18$$,this.$component_id$);
$cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2574_component$jscomp$93_fdata$jscomp$18$$);var $cpath__$1$jscomp$1$$=$APP.$app$common$path_names$split_path$$($cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$);$cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($i$jscomp$510$$){return $APP.$app$common$path_names$join_path$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$510$$+
1,$cpath__$1$jscomp$1$$))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($cpath__$1$jscomp$1$$)));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71949_SHARP_$$){return $app$main$data$workspace$set_assets_group_open$$($file_id$jscomp$293$$,$APP.$cljs$cst$1638$components$$,$p1__71949_SHARP_$$,!0)},$cpath$jscomp$4_paths$jscomp$2_state$jscomp$913$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,
$APP.$cljs$cst$3718$assets$$])),$app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$293$$,$APP.$cljs$cst$3532$library$$,!0),$app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$293$$,$APP.$cljs$cst$1638$components$$,!0),$app$main$data$workspace$select_single_asset$$($file_id$jscomp$293$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2574_component$jscomp$93_fdata$jscomp$18$$),$APP.$cljs$cst$1638$components$$)))},$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_component_in_assets_71950$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2575_file_id$jscomp$294$$,$component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$){$_$jscomp$2575_file_id$jscomp$294$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$);$component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$,
$_$jscomp$2575_file_id$jscomp$294$$);$component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$=$app$common$files$variant$get_primary_component$$($component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$,this.$component_id$);var $wrapper_id$$=["component-shape-id-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$94_fdata$jscomp$19_state$jscomp$914$$))].join("");return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $element$jscomp$inline_8341$$=
$APP.$goog$dom$getElement$$($wrapper_id$$);return $APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($element$jscomp$inline_8341$$,!1)})});return new $app$main$data$workspace$show_component_in_assets_71950$$($component_id$jscomp$86$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_feedback$$=function(){typeof $app$main$data$common$go_to_feedback_52605$$==="undefined"&&($app$main$data$common$go_to_feedback_52605$$=function($meta52606$$){this.$meta52606$=$meta52606$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_feedback_52605$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_feedback_52605$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2508$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_feedback$$},$app$main$data$common$go_to_feedback_52605$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52607$$,$meta52606__$1$$){return new $app$main$data$common$go_to_feedback_52605$$($meta52606__$1$$)},$app$main$data$common$go_to_feedback_52605$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52606$},$app$main$data$common$go_to_feedback_52605$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_feedback_52605$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2509$settings_feedback$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,!0,$APP.$cljs$cst$2458$app_DOT_main_DOT_router_SLASH_window_name$$,
"penpot-feedback"])))});return new $app$main$data$common$go_to_feedback_52605$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$rasterizer$render_node$$=function($data$jscomp$328_node$jscomp$304_p__67489$$){var $map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$328_node$jscomp$304_p__67489$$);$data$jscomp$328_node$jscomp$304_p__67489$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$,$APP.$cljs$cst$3766$node$$);var $styles$jscomp$11_styles__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$,
$APP.$cljs$cst$2940$styles$$),$width$jscomp$113_width__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$,$APP.$cljs$cst$290$width$$);$map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$,$APP.$cljs$cst$828$result$$);$width$jscomp$113_width__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($width$jscomp$113_width__$1$jscomp$2$$,
$APP.$app$util$dom$get_attribute$$($data$jscomp$328_node$jscomp$304_p__67489$$,"width"));$styles$jscomp$11_styles__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$11_styles__$1$jscomp$1$$,"");$data$jscomp$328_node$jscomp$304_p__67489$$=$data$jscomp$328_node$jscomp$304_p__67489$$!=null?(new XMLSerializer).serializeToString($data$jscomp$328_node$jscomp$304_p__67489$$):null;$map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$,
"blob");return $APP.$app$main$rasterizer$render$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$142$data$$,$data$jscomp$328_node$jscomp$304_p__67489$$,$APP.$cljs$cst$2940$styles$$,$styles$jscomp$11_styles__$1$jscomp$1$$,$APP.$cljs$cst$290$width$$,$width$jscomp$113_width__$1$jscomp$2$$,$APP.$cljs$cst$828$result$$,$map__67490__$1_result$jscomp$279_result__$1$jscomp$33$$],null))};
$app$util$text_editor$setup_block_styles$$=function($state$jscomp$551$$,$blocks$$,$attrs$jscomp$109$$){return $APP.$cljs$core$empty_QMARK_$$($blocks$$)?$state$jscomp$551$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$23$$,$block_key$jscomp$1$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.updateBlockData($state__$1$jscomp$23$$,$block_key$jscomp$1$$,$APP.$cljs$core$clj__GT_js$$($attrs$jscomp$109$$))},$state$jscomp$551$$,$blocks$$)};
$app$common$types$fills$prepend$$=function($fills$jscomp$8_fills__$1$jscomp$2$$,$fill$jscomp$7$$){$fills$jscomp$8_fills__$1$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fill$jscomp$7$$],null),$fills$jscomp$8_fills__$1$jscomp$2$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1755$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($fills$jscomp$8_fills__$1$jscomp$2$$):
$fills$jscomp$8_fills__$1$jscomp$2$$};
$app$main$data$workspace$media$create_shapes_svg$$=function($file_id$jscomp$104$$,$objects$jscomp$361$$,$pos$jscomp$103$$,$svg_data$jscomp$20$$){return $APP.$beicon$v2$core$map$$(function($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$){$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$=$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$,$pos$jscomp$103$$,
$objects$jscomp$361$$);var $root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$,0,null);$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$,1,null);var $frame_shape$jscomp$1$$=
$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1522$height$$],[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$103$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$)),$APP.$cljs$cst$1606$frame$$,$APP.$app$common$uuid$zero$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$103$$),$APP.$app$common$types$fills$create$$(),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$))])),
$root_svg_shape__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$1$$)]));$root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67760_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67760_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape__$1$$))},$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$));$root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($root_svg_shape__$1$$,
$APP.$cljs$cst$1614$shapes$$,$root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$);$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67761_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67761_SHARP_$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$1$$))},$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$);
$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$root_svg_shape_root_svg_shape__$2_shapes$jscomp$58$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$]));return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_shape$jscomp$1$$,$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67762$$],null)},function($svg_data__$1$jscomp$1$$){return $APP.$beicon$v2$core$map$$(function($p1__67759_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($svg_data__$1$jscomp$1$$,$APP.$cljs$cst$3673$image_data$$,$p1__67759_SHARP_$$)},$APP.$app$main$data$workspace$svg_upload$upload_images$$($svg_data__$1$jscomp$1$$,$file_id$jscomp$104$$))}($svg_data$jscomp$20$$))};
$app$main$data$workspace$bool$group__GT_bool$$=function($type$jscomp$453$$,$group$jscomp$31$$,$objects$jscomp$341$$){var $head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$341$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$31$$));$head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$453$$,$APP.$cljs$cst$2025$difference$$)?
$APP.$cljs$core$first$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$):$APP.$cljs$core$last$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$);$head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$=$APP.$cljs$core$contains_QMARK_$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$,$APP.$cljs$cst$1890$svg_attrs$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$,
$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$path$bool$get_default_fills$$()):$head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$;return $APP.$app$common$types$path$update_bool_shape$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($group$jscomp$31$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1610$bool$$),
$APP.$cljs$cst$1888$bool_type$$,$type$jscomp$453$$),$APP.$cljs$core$select_keys$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$54$$,$APP.$app$common$types$path$bool$style_properties$$)])),$objects$jscomp$341$$)};
$app$main$data$workspace$comments$handle_interrupt$$=function(){typeof $app$main$data$workspace$comments$handle_interrupt_70129$$==="undefined"&&($app$main$data$workspace$comments$handle_interrupt_70129$$=function($meta70130$$){this.$meta70130$=$meta70130$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$handle_interrupt_70129$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_interrupt_70129$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4274$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_handle_interrupt$$},$app$main$data$workspace$comments$handle_interrupt_70129$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70131$$,$meta70130__$1$$){return new $app$main$data$workspace$comments$handle_interrupt_70129$$($meta70130__$1$$)},$app$main$data$workspace$comments$handle_interrupt_70129$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70130$},$app$main$data$workspace$comments$handle_interrupt_70129$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_interrupt_70129$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2356_local$jscomp$8$$,$state$jscomp$740$$){$_$jscomp$2356_local$jscomp$8$$=$APP.$cljs$cst$2233$comments_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$740$$);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$3435$draft$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2356_local$jscomp$8$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$()):
$APP.$cljs$core$truth_$$($APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2356_local$jscomp$8$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$()):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$clear_edition_mode$$(),$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$(!0))});return new $app$main$data$workspace$comments$handle_interrupt_70129$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$initialize_comments$$=function($file_id$jscomp$216$$){typeof $app$main$data$workspace$comments$initialize_comments_70121$$==="undefined"&&($app$main$data$workspace$comments$initialize_comments_70121$$=function($file_id$jscomp$217$$,$meta70122$$){this.$file_id$=$file_id$jscomp$217$$;this.$meta70122$=$meta70122$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$initialize_comments_70121$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$initialize_comments_70121$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4272$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_initialize_comments$$},$app$main$data$workspace$comments$initialize_comments_70121$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70123$$,$meta70122__$1$$){return new $app$main$data$workspace$comments$initialize_comments_70121$$(this.$file_id$,$meta70122__$1$$)},
$app$main$data$workspace$comments$initialize_comments_70121$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70122$},$app$main$data$workspace$comments$initialize_comments_70121$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$initialize_comments_70121$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2355_stopper_s$jscomp$3$$,$___$1$jscomp$1585$$,$stream$jscomp$83$$){$_$jscomp$2355_stopper_s$jscomp$3$$=
$APP.$beicon$v2$core$filter$$(function($p1__70119_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4273$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_finalize$$,$p1__70119_SHARP_$$)},$stream$jscomp$83$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2355_stopper_s$jscomp$3$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$retrieve_comment_threads$$(this.$file_id$)),$APP.$beicon$v2$core$map$$($app$main$data$workspace$comments$handle_comment_layer_click$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$first$$,$APP.$beicon$v2$core$filter$$(function($p__70124_space$jscomp$2$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70124_space$jscomp$2$$,0,null);$p__70124_space$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70124_space$jscomp$2$$,1,null);return $APP.$cljs$core$not$$($p__70124_space$jscomp$2$$)},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5590$$,$APP.$beicon$v2$core$switch_map$$(function(){return $APP.$beicon$v2$core$take$$($APP.$app$main$streams$mouse_position$$)},
$APP.$beicon$v2$core$filter$$($app$util$mouse$mouse_click_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$mouse_event_QMARK_$$,$stream$jscomp$83$$))))))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$comments$handle_interrupt$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$common$interrupt_QMARK_$$,$stream$jscomp$83$$))))});return new $app$main$data$workspace$comments$initialize_comments_70121$$($file_id$jscomp$216$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$deselect_all$$=function($var_args$jscomp$1202$$){switch(arguments.length){case 0:return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$();case 1:return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$render_wasm$api$set_focus_mode$$=function($cause54254_54945_entries$jscomp$15_fn_54253_54944$$){if($APP.$cljs$core$empty_QMARK_$$($cause54254_54945_entries$jscomp$15_fn_54253_54944$$))return null;var $code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$=16*$APP.$cljs$core$count$$($cause54254_54945_entries$jscomp$15_fn_54253_54944$$),$heap$jscomp$13$$=$APP.$app$render_wasm$mem$get_heap_u32$$();$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$=
$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$);$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$10$$,$id$jscomp$333$$){return $APP.$app$render_wasm$mem$heap32$write_uuid$$($offset__$1$jscomp$10$$,$heap$jscomp$13$$,$id$jscomp$333$$)},$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$,
$cause54254_54945_entries$jscomp$15_fn_54253_54944$$);$cause54254_54945_entries$jscomp$15_fn_54253_54944$$=$APP.$app$render_wasm$wasm$internal_module$$._set_focus_mode;try{$cause54254_54945_entries$jscomp$15_fn_54253_54944$$()}catch($e54255$$){$cause54254_54945_entries$jscomp$15_fn_54253_54944$$=$e54255$$;$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$)?$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$():
null;$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54949$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54949$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_focus_mode",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54949$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54948_code_num__52998__auto___54947_offset$jscomp$158_read_code_fn__52997__auto___54946_size$jscomp$112$$],null),$cause54254_54945_entries$jscomp$15_fn_54253_54944$$);
}return $APP.$app$render_wasm$api$request_render$$("set-focus-mode")};$app$util$text_editor$insert_text$$=function($state$jscomp$553$$,$text$jscomp$52$$,$attrs$jscomp$111$$){var $style$jscomp$42$$=$APP.$app$common$text$attrs_to_styles$$($attrs$jscomp$111$$);return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.insertText($state$jscomp$553$$,$text$jscomp$52$$,$APP.$cljs$core$clj__GT_js$$($attrs$jscomp$111$$),$APP.$cljs$core$clj__GT_js$$($style$jscomp$42$$))};
$app$util$text_editor$apply_block_styles_to_content$$=function($$__$1$jscomp$20_state$jscomp$552$$,$blocks$jscomp$1$$){if($APP.$cljs$core$empty_QMARK_$$($blocks$jscomp$1$$))return $$__$1$jscomp$20_state$jscomp$552$$;var $selection$jscomp$8$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getSelection($$__$1$jscomp$20_state$jscomp$552$$);$$__$1$jscomp$20_state$jscomp$552$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$24$$,$bkey$$){var $attrs$jscomp$110$$=
$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getBlockData($state__$1$jscomp$24$$,$bkey$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0]));return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.applyInlineStyle($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.selectBlock($state__$1$jscomp$24$$,$bkey$$),$APP.$app$common$text$attrs_to_styles$$($attrs$jscomp$110$$))},
$$__$1$jscomp$20_state$jscomp$552$$,$blocks$jscomp$1$$);return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.setSelection($$__$1$jscomp$20_state$jscomp$552$$,$selection$jscomp$8$$)};
$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($message$jscomp$70_message$jscomp$inline_8346$$,$transfer$jscomp$8$$){var $worker$jscomp$9$$=$APP.$app$main$worker$instance$$;$message$jscomp$70_message$jscomp$inline_8346$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3111$sender_id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$3113$payload$$,$message$jscomp$70_message$jscomp$inline_8346$$,$APP.$cljs$cst$3114$buffer_QMARK_$$,!0,$APP.$cljs$cst$3124$transfer$$,
$transfer$jscomp$8$$],null);return $APP.$app$util$worker$send_message_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($worker$jscomp$9$$,$message$jscomp$70_message$jscomp$inline_8346$$,null)};
$app$main$snap$get_snap_points$$=function($page_id$jscomp$162$$,$frame_id$jscomp$83$$,$remove_snap_QMARK_$jscomp$1$$,$zoom$jscomp$13$$,$point$jscomp$57_value$jscomp$565$$,$coord$jscomp$7$$){$point$jscomp$57_value$jscomp$565$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$57_value$jscomp$565$$,$coord$jscomp$7$$);var $vbox$jscomp$18$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$);return $APP.$beicon$v2$core$map$$($APP.$app$main$snap$remove_from_snap_points$$($remove_snap_QMARK_$jscomp$1$$),
$APP.$beicon$v2$core$take$$($APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3849$index_SLASH_query_snap$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$162$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$83$$,$APP.$cljs$cst$2054$axis$$,$coord$jscomp$7$$,$APP.$cljs$cst$3850$bounds$$,$vbox$jscomp$18$$,$APP.$cljs$cst$3851$ranges$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$57_value$jscomp$565$$-.5/$zoom$jscomp$13$$,$point$jscomp$57_value$jscomp$565$$+.5/$zoom$jscomp$13$$],null)],null)],null))))};
$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$=function($initial_set$jscomp$2$$,$remove_QMARK_$jscomp$6$$,$ignore_groups_QMARK_$jscomp$3$$,$buffered_QMARK_$$){typeof $app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$==="undefined"&&($app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$=function($initial_set$jscomp$3$$,$remove_QMARK_$jscomp$7$$,$ignore_groups_QMARK_$jscomp$4$$,$buffered_QMARK_$jscomp$1$$,
$meta67353$$){this.$initial_set$=$initial_set$jscomp$3$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$7$$;this.$ignore_groups_QMARK_$=$ignore_groups_QMARK_$jscomp$4$$;this.$buffered_QMARK_$=$buffered_QMARK_$jscomp$1$$;this.$meta67353$=$meta67353$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3604$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shapes_by_current_selrect$$},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67354$$,$meta67353__$1$$){return new $app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$(this.$initial_set$,this.$remove_QMARK_$,this.$ignore_groups_QMARK_$,this.$buffered_QMARK_$,$meta67353__$1$$)},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67353$},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1932$$,$state$jscomp$369$$){var $self__$jscomp$4270$$=this,$page_id$jscomp$110$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$369$$),
$objects$jscomp$318$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$369$$,$page_id$jscomp$110$$),$selrect$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$369$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1605$selrect$$),$ask_worker$$=$APP.$cljs$core$truth_$$($self__$jscomp$4270$$.$buffered_QMARK_$)?$app$main$worker$ask_buffered_BANG_$$:$APP.$app$main$worker$ask_BANG_$$,
$filter_objs$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$complement$$(function($id$jscomp$491$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$318$$,$id$jscomp$491$$),$APP.$cljs$cst$1623$blocked$$,!1)})),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$helpers$hidden_parent_QMARK_$$,
$objects$jscomp$318$$)));return $selrect$jscomp$44$$!=null?$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$selection$select_shapes$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$truth_$$($self__$jscomp$4270$$.$remove_QMARK_$)?function($p1__67348_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$disj$$,$self__$jscomp$4270$$.$initial_set$,$p1__67348_SHARP_$$)}:function($p1__67349_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4270$$.$initial_set$,
$filter_objs$$,$p1__67349_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__67347_SHARP_$$){return $APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$318$$,$p1__67347_SHARP_$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,function(){var $G__67355$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3605$index_SLASH_query_selection$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$110$$,$APP.$cljs$cst$1611$rect$$,$selrect$jscomp$44$$,
$APP.$cljs$cst$3606$include_frames_QMARK_$$,!0,$APP.$cljs$cst$3607$ignore_groups_QMARK_$$,$self__$jscomp$4270$$.$ignore_groups_QMARK_$,$APP.$cljs$cst$3608$full_frame_QMARK_$$,!0,$APP.$cljs$cst$3609$using_selrect_QMARK_$$,!0],null);return $ask_worker$$.$cljs$core$IFn$_invoke$arity$1$?$ask_worker$$.$cljs$core$IFn$_invoke$arity$1$($G__67355$$):$ask_worker$$($G__67355$$)}())))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$selection$select_shapes_by_current_selrect_67352$$($initial_set$jscomp$2$$,
$remove_QMARK_$jscomp$6$$,$ignore_groups_QMARK_$jscomp$3$$,$buffered_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$=function($initial_set$jscomp$1$$,$remove_QMARK_$jscomp$5$$,$ignore_groups_QMARK_$jscomp$2$$){return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$($initial_set$jscomp$1$$,$remove_QMARK_$jscomp$5$$,$ignore_groups_QMARK_$jscomp$2$$,!0)};
$app$main$data$workspace$selection$select_shapes_by_current_selrect$$=function($var_args$jscomp$1203$$){switch(arguments.length){case 3:return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};
$app$main$data$workspace$selection$handle_area_selection$$=function($append_QMARK_$$,$remove_QMARK_$jscomp$3$$,$ignore_groups_QMARK_$$){typeof $app$main$data$workspace$selection$handle_area_selection_67138$$==="undefined"&&($app$main$data$workspace$selection$handle_area_selection_67138$$=function($append_QMARK_$jscomp$1$$,$remove_QMARK_$jscomp$4$$,$ignore_groups_QMARK_$jscomp$1$$,$meta67139$$){this.$append_QMARK_$=$append_QMARK_$jscomp$1$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$4$$;this.$ignore_groups_QMARK_$=$ignore_groups_QMARK_$jscomp$1$$;
this.$meta67139$=$meta67139$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$handle_area_selection_67138$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$handle_area_selection_67138$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3590$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_handle_area_selection$$},$app$main$data$workspace$selection$handle_area_selection_67138$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67140$$,$meta67139__$1$$){return new $app$main$data$workspace$selection$handle_area_selection_67138$$(this.$append_QMARK_$,this.$remove_QMARK_$,this.$ignore_groups_QMARK_$,$meta67139__$1$$)},$app$main$data$workspace$selection$handle_area_selection_67138$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67139$},$app$main$data$workspace$selection$handle_area_selection_67138$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$handle_area_selection_67138$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1918_stopper$jscomp$7$$,$init_selrect_selrect_stream_state$jscomp$357$$,$init_position_stream$jscomp$39$$){var $self__$jscomp$4229$$=this,$zoom$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($init_selrect_selrect_stream_state$jscomp$357$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2196$zoom$$,1);$_$jscomp$1918_stopper$jscomp$7$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($init_position_stream$jscomp$39$$,
null);$init_position_stream$jscomp$39$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);var $initial_set$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$684$$=$self__$jscomp$4229$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$684$$)?$or__5025__auto__$jscomp$684$$:$self__$jscomp$4229$$.$remove_QMARK_$}())?$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($init_selrect_selrect_stream_state$jscomp$357$$):
$APP.$linked$set$empty_linked_set$$;$init_selrect_selrect_stream_state$jscomp$357$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($init_position_stream$jscomp$39$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($init_position_stream$jscomp$39$$,$APP.$cljs$cst$1510$x$$),$init_position_stream$jscomp$39$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($init_position_stream$jscomp$39$$,$APP.$cljs$cst$1511$y$$),0,0);$init_selrect_selrect_stream_state$jscomp$357$$=
$APP.$beicon$v2$core$take_until$$($_$jscomp$1918_stopper$jscomp$7$$,$APP.$beicon$v2$core$filter$$(function($p1__67136_SHARP_$$){return($p1__67136_SHARP_$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__67136_SHARP_$$,$APP.$cljs$cst$290$width$$))>10/$zoom$jscomp$9$$||($p1__67136_SHARP_$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__67136_SHARP_$$,$APP.$cljs$cst$1522$height$$))>10/$zoom$jscomp$9$$},$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$(function($selrect$jscomp$43_selrect__$1$jscomp$2$$,
$p__67152_space_QMARK_$$){var $delta$jscomp$32_selrect__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67152_space_QMARK_$$,0,null);$p__67152_space_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67152_space_QMARK_$$,1,null);$selrect$jscomp$43_selrect__$1$jscomp$2$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($selrect$jscomp$43_selrect__$1$jscomp$2$$,$APP.$cljs$cst$1525$x2$$,$APP.$cljs$core$_PLUS_$$,
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$)),$APP.$cljs$cst$1526$y2$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$));$delta$jscomp$32_selrect__$2$$=$p__67152_space_QMARK_$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($selrect$jscomp$43_selrect__$1$jscomp$2$$,$APP.$cljs$cst$1523$x1$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$)),
$APP.$cljs$cst$1524$y1$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$)):$selrect$jscomp$43_selrect__$1$jscomp$2$$;return $APP.$app$common$geom$rect$update_rect$$($delta$jscomp$32_selrect__$2$$,$APP.$cljs$cst$3591$corners$$)},$init_selrect_selrect_stream_state$jscomp$357$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5590$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,
$APP.$beicon$v2$core$map$$(function($p__67157_to$jscomp$22$$){var $from$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67157_to$jscomp$22$$,0,null);$p__67157_to$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67157_to$jscomp$22$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($from$jscomp$20$$)?$p__67157_to$jscomp$22$$:$from$jscomp$20$$)?$APP.$app$common$geom$point$subtract$$($p__67157_to$jscomp$22$$,$from$jscomp$20$$):null},$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$streams$mouse_position$$)))))));
return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$685$$=$self__$jscomp$4229$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$685$$)?$or__5025__auto__$jscomp$685$$:$self__$jscomp$4229$$.$remove_QMARK_$}())?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$?$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$():
$app$main$data$workspace$selection$deselect_all$$()),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$selection$update_selrect$$,$init_selrect_selrect_stream_state$jscomp$357$$),$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$?$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$($initial_set$$,$self__$jscomp$4229$$.$remove_QMARK_$,
$self__$jscomp$4229$$.$ignore_groups_QMARK_$):$app$main$data$workspace$selection$select_shapes_by_current_selrect$$($initial_set$$,$self__$jscomp$4229$$.$remove_QMARK_$,$self__$jscomp$4229$$.$ignore_groups_QMARK_$)},$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$($APP.$cljs$core$last$$,$APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$init_selrect_selrect_stream_state$jscomp$357$$)))),
$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$?$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$($initial_set$$,$self__$jscomp$4229$$.$remove_QMARK_$,$self__$jscomp$4229$$.$ignore_groups_QMARK_$,!1):$app$main$data$workspace$selection$select_shapes_by_current_selrect$$($initial_set$$,$self__$jscomp$4229$$.$remove_QMARK_$,$self__$jscomp$4229$$.$ignore_groups_QMARK_$,
!1)},$APP.$beicon$v2$core$last$$($init_selrect_selrect_stream_state$jscomp$357$$))),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$selection$update_selrect$$(null))))});return new $app$main$data$workspace$selection$handle_area_selection_67138$$($append_QMARK_$$,$remove_QMARK_$jscomp$3$$,$ignore_groups_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$text$parse_draft_styles$$=function($styles$jscomp$15$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$87$$){var $v$jscomp$591_vec__68668$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$87$$,$APP.$cljs$cst$1904$style$$),"$$$",3);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$591_vec__68668$$,0,null);var $k$jscomp$648$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$591_vec__68668$$,
1,null);$v$jscomp$591_vec__68668$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$591_vec__68668$$,2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$302$key$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$648$$),$APP.$cljs$cst$108$val$$,$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$591_vec__68668$$),$APP.$cljs$cst$195$offset$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$87$$,
$APP.$cljs$cst$195$offset$$),$APP.$cljs$cst$255$length$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$87$$,$APP.$cljs$cst$255$length$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68660_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__68660_SHARP_$$,$APP.$cljs$cst$1904$style$$),"PENPOT$$$")},$styles$jscomp$15$$))};
$app$common$text$convert_from_draft$$=function($content$jscomp$172$$){function $split_texts$$($children$jscomp$243_text$jscomp$49$$,$styles$jscomp$16$$,$data$jscomp$369$$){var $cpoints$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,Array.from($children$jscomp$243_text$jscomp$49$$));$children$jscomp$243_text$jscomp$49$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($attrs$jscomp$inline_8356_p1__68686_SHARP_$$){var $start$jscomp$inline_8353_text$jscomp$inline_8355$$=
$APP.$cljs$core$ffirst$$($attrs$jscomp$inline_8356_p1__68686_SHARP_$$),$end$jscomp$inline_8354$$=$APP.$cljs$core$first$$($APP.$cljs$core$last$$($attrs$jscomp$inline_8356_p1__68686_SHARP_$$))+1;$start$jscomp$inline_8353_text$jscomp$inline_8355$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($cpoints$jscomp$2$$,$start$jscomp$inline_8353_text$jscomp$inline_8355$$,$end$jscomp$inline_8354$$));$attrs$jscomp$inline_8356_p1__68686_SHARP_$$=
$APP.$cljs$core$second$$($APP.$cljs$core$first$$($attrs$jscomp$inline_8356_p1__68686_SHARP_$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$text$fix_gradients$$($attrs$jscomp$inline_8356_p1__68686_SHARP_$$),$APP.$cljs$cst$1588$text$$,$start$jscomp$inline_8353_text$jscomp$inline_8355$$)},$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$second$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$text$build_style_index$$($APP.$cljs$core$count$$($cpoints$jscomp$2$$),
$app$common$text$parse_draft_styles$$($styles$jscomp$16$$)))));return $APP.$cljs$core$empty_QMARK_$$($children$jscomp$243_text$jscomp$49$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$243_text$jscomp$49$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$369$$,$APP.$cljs$cst$1588$text$$,"")):$children$jscomp$243_text$jscomp$49$$}return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($block$jscomp$1_data$jscomp$370$$){var $key$jscomp$384$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,$APP.$cljs$cst$302$key$$),$text$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,
$APP.$cljs$cst$1588$text$$),$styles$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,$APP.$cljs$cst$3994$inlineStyleRanges$$);$block$jscomp$1_data$jscomp$370$$=$app$common$text$fix_gradients$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,$APP.$cljs$cst$142$data$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($block$jscomp$1_data$jscomp$370$$,
$APP.$cljs$cst$302$key$$,$key$jscomp$384$$),$APP.$cljs$cst$139$type$$,"paragraph"),$APP.$cljs$cst$342$children$$,$split_texts$$($text$jscomp$50$$,$styles$jscomp$17$$,$block$jscomp$1_data$jscomp$370$$))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$172$$,$APP.$cljs$cst$3995$blocks$$))],null)],null)],null)};
$app$util$text_editor$export_content$$=function($content$jscomp$177$$){return $app$common$text$convert_from_draft$$($APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.convertToRaw($content$jscomp$177$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0])))};
$app$util$text$content$to_dom$set_styles$$=function($element$jscomp$67$$,$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$){for(var $G__53637_seq__53544_seq__53544__$1$$=$APP.$cljs$core$seq$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$),$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=null,$count__53546$$=0,$i__53547$$=0;;)if($i__53547$$<$count__53546$$){var $G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$=
$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__53547$$);$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$,0,null);$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$,
1,null);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$)){var $style_encode_53631_vec__53573_53630$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$);$style_encode_53631_vec__53573_53630$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_encode_53631_vec__53573_53630$$,
0,null);$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$=$style_encode_53631_vec__53573_53630$$.$cljs$core$IFn$_invoke$arity$1$?$style_encode_53631_vec__53573_53630$$.$cljs$core$IFn$_invoke$arity$1$($G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$):$style_encode_53631_vec__53573_53630$$($G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$);$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$),
$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$)}else $app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$),$APP.$app$util$text$content$styles$normalize_style_value$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$,$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$));$i__53547$$+=1}else if($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$=
$APP.$cljs$core$seq$$($G__53637_seq__53544_seq__53544__$1$$))$G__53637_seq__53544_seq__53544__$1$$=$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__53637_seq__53544_seq__53544__$1$$)?($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=$APP.$cljs$core$_chunked_first$$($G__53637_seq__53544_seq__53544__$1$$),$G__53637_seq__53544_seq__53544__$1$$=$APP.$cljs$core$_chunked_rest$$($G__53637_seq__53544_seq__53544__$1$$),
$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$=$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$,$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$),$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=
$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$,$count__53546$$=$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$):($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=$APP.$cljs$core$first$$($G__53637_seq__53544_seq__53544__$1$$),$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$,
0,null),$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$,1,null),$APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$)?($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$),$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$,0,null),$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=
$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$.$cljs$core$IFn$_invoke$arity$1$?$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$.$cljs$core$IFn$_invoke$arity$1$($G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$):$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$($G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$),
$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$),$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$)):$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$),
$APP.$app$util$text$content$styles$normalize_style_value$$($G__53638_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$166$$,$G__53639_style_encoded_value_53632_style_value$jscomp$2_vec__53569$$)),$G__53637_seq__53544_seq__53544__$1$$=$APP.$cljs$core$next$$($G__53637_seq__53544_seq__53544__$1$$),$c__5548__auto__$jscomp$17_chunk__53545_style_encode_53642_style_encoded_value_53643_vec__53576_vec__53579_53641$$=null,$count__53546$$=0),$i__53547$$=0;else break};
$app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$=function($element$jscomp$68_tag$jscomp$67$$,$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$,$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$){$element$jscomp$68_tag$jscomp$67$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$($element$jscomp$68_tag$jscomp$67$$);
$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=$APP.$cljs$core$seq$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$);for(var $G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=null,$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=
0,$G__53606_53673_child_53684_i__53590_53652$$=0;;)if($G__53606_53673_child_53684_i__53590_53652$$<$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$){var $attr_value_53655_vec__53599_53653$$=$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__53606_53673_child_53684_i__53590_53652$$),$attr_name_53654$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value_53655_vec__53599_53653$$,
0,null);$attr_value_53655_vec__53599_53653$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value_53655_vec__53599_53653$$,1,null);var $G__53602_53656$$=$attr_name_53654$$;switch($G__53602_53656$$ instanceof $APP.$cljs$core$Keyword$$?$G__53602_53656$$.$fqn$:null){case "data":$app$util$text$content$to_dom$set_dataset$$($element$jscomp$68_tag$jscomp$67$$,$attr_value_53655_vec__53599_53653$$);break;case "style":$app$util$text$content$to_dom$set_styles$$($element$jscomp$68_tag$jscomp$67$$,
$attr_value_53655_vec__53599_53653$$);break;default:$APP.$app$util$dom$set_attribute_BANG_$$($element$jscomp$68_tag$jscomp$67$$,$APP.$cljs$core$name$$($attr_name_53654$$),$attr_value_53655_vec__53599_53653$$)}$G__53606_53673_child_53684_i__53590_53652$$+=1}else if($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=$APP.$cljs$core$seq$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$))$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=
$APP.$cljs$core$_chunked_first$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$),$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=$APP.$cljs$core$_chunked_rest$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$),$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=
$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$,$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=$APP.$cljs$core$count$$($G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$);else{$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=$APP.$cljs$core$first$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$);
$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$,0,null);$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$,
1,null);$G__53606_53673_child_53684_i__53590_53652$$=$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$;switch($G__53606_53673_child_53684_i__53590_53652$$ instanceof $APP.$cljs$core$Keyword$$?$G__53606_53673_child_53684_i__53590_53652$$.$fqn$:null){case "data":$app$util$text$content$to_dom$set_dataset$$($element$jscomp$68_tag$jscomp$67$$,$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$);break;case "style":$app$util$text$content$to_dom$set_styles$$($element$jscomp$68_tag$jscomp$67$$,
$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$);break;default:$APP.$app$util$dom$set_attribute_BANG_$$($element$jscomp$68_tag$jscomp$67$$,$APP.$cljs$core$name$$($G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$),$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$)}$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=
$APP.$cljs$core$next$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$);$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=null;$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=0}$G__53606_53673_child_53684_i__53590_53652$$=0}else break;$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$=
$APP.$cljs$core$seq$$($c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$);$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=null;for($G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=0;;)if($G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$<
$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$)$G__53606_53673_child_53684_i__53590_53652$$=$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$),$APP.$app$util$dom$append_child_BANG_$$($element$jscomp$68_tag$jscomp$67$$,$G__53606_53673_child_53684_i__53590_53652$$),
$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$+=1;else if($c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$=$APP.$cljs$core$seq$$($c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$))$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$)?($c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$=$APP.$cljs$core$_chunked_first$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$),$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=
$APP.$cljs$core$_chunked_rest$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$),$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$,$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=$APP.$cljs$core$count$$($c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$),
$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$=$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$):($c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$=$APP.$cljs$core$first$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$),$APP.$app$util$dom$append_child_BANG_$$($element$jscomp$68_tag$jscomp$67$$,
$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$),$c__5548__auto___53691_child_53696_children$jscomp$200_seq__53607_53680_temp__5825__auto___53689$$=$APP.$cljs$core$next$$($G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$),$G__53666_G__53693_attrs$jscomp$55_chunk__53608_53681_seq__53587_53649_seq__53587_53664__$1_seq__53607_53690__$1_temp__5825__auto___53663$$=
null,$G__53667_G__53694_attr_name_53671_chunk__53588_53650_count__53609_53682$$=0),$G__53668_G__53692_attr_value_53672_c__5548__auto___53665_count__53589_53651_i__53610_53683_vec__53603_53670$$=0;else break;return $element$jscomp$68_tag$jscomp$67$$};
$app$util$text$content$to_dom$create_paragraph$$=function($paragraph$jscomp$11$$){return $app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$("div",new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,function(){var $or__5025__auto__$jscomp$591$$=$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$591$$)?$or__5025__auto__$jscomp$591$$:$app$util$text$content$to_dom$create_random_key$$()}(),
$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3079$itype$$,"paragraph",$APP.$cljs$cst$3080$saved_font_size$$,$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$)],null),$APP.$cljs$cst$1904$style$$,$app$util$text$content$to_dom$get_paragraph_styles$$($paragraph$jscomp$11$$)],null),$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$){var $JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$=
$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$);$JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$)?$JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$:
$app$util$text$content$to_dom$create_random_key$$();var $JSCompiler_temp_const$jscomp$14087_JSCompiler_temp_const$jscomp$inline_14627$$=$APP.$cljs$cst$142$data$$,$JSCompiler_temp_const$jscomp$14086$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3079$itype$$,"span"],null);var $JSCompiler_inline_result$jscomp$14089_node$jscomp$inline_14622_styles$jscomp$inline_14623$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$))?
$paragraph$jscomp$11$$:$JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$;$JSCompiler_inline_result$jscomp$14089_node$jscomp$inline_14622_styles$jscomp$inline_14623$$=$app$util$text$content$to_dom$get_styles_from_attrs$$($JSCompiler_inline_result$jscomp$14089_node$jscomp$inline_14622_styles$jscomp$inline_14623$$,$APP.$app$common$types$text$text_node_attrs$$);$JSCompiler_inline_result$jscomp$14089_node$jscomp$inline_14622_styles$jscomp$inline_14623$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$14089_node$jscomp$inline_14622_styles$jscomp$inline_14623$$,$APP.$cljs$cst$1765$line_height$$);$JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$,$JSCompiler_temp_const$jscomp$14087_JSCompiler_temp_const$jscomp$inline_14627$$,
$JSCompiler_temp_const$jscomp$14086$$,$APP.$cljs$cst$1904$style$$,$JSCompiler_inline_result$jscomp$14089_node$jscomp$inline_14622_styles$jscomp$inline_14623$$],null);$JSCompiler_temp_const$jscomp$14087_JSCompiler_temp_const$jscomp$inline_14627$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$)))?$JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("br"):($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$),
$JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$)?$JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$.replace(RegExp("/","g"),"/​"):null,$JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$=
$APP.$app$util$globals$document$$.createTextNode($JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$));return $app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$("span",$JSCompiler_temp_const$jscomp$14082_JSCompiler_temp_const$jscomp$14088_or__5025__auto__$jscomp$inline_13287$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$14087_JSCompiler_temp_const$jscomp$inline_14627$$,
[$JSCompiler_inline_result$jscomp$inline_14629_JSCompiler_temp$jscomp$inline_14628_p1__53616_SHARP__text$jscomp$inline_14630$$],null))},$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$)))};
$app$util$text$content$to_dom$create_root$$=function($JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$){var $root_styles$jscomp$2$$=$app$util$text$content$to_dom$get_styles_from_attrs$$($JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$,$APP.$app$common$types$text$text_valign_attrs$$),$filtered_paragraphs_paragraphs$jscomp$3$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,0,$APP.$cljs$cst$342$children$$],null));$filtered_paragraphs_paragraphs$jscomp$3$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$filtered_paragraphs_paragraphs$jscomp$3$$));$JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$=
$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$);$JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$)?$JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$:$app$util$text$content$to_dom$create_random_key$$();return $app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$("div",
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$JSCompiler_inline_result$jscomp$1650_or__5025__auto__$jscomp$inline_8360_root$jscomp$46$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3079$itype$$,"root"],null),$APP.$cljs$cst$1904$style$$,$root_styles$jscomp$2$$],null),$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$util$text$content$to_dom$create_paragraph$$,$filtered_paragraphs_paragraphs$jscomp$3$$))};
$app$util$text$content$styles$get_style_defaults$$=function($style_defaults$$){return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$115$$,$p__53439_style_value_v$jscomp$569$$){var $k$jscomp$625_style_name$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53439_style_value_v$jscomp$569$$,0,null);$p__53439_style_value_v$jscomp$569$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53439_style_value_v$jscomp$569$$,
1,null);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$k$jscomp$625_style_name$jscomp$2$$)){var $style_encode_vec__53443$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$k$jscomp$625_style_name$jscomp$2$$);$style_encode_vec__53443$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_encode_vec__53443$$,0,null);$k$jscomp$625_style_name$jscomp$2$$=$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($k$jscomp$625_style_name$jscomp$2$$);
$p__53439_style_value_v$jscomp$569$$=$APP.$app$util$text$content$styles$normalize_style_value$$($k$jscomp$625_style_name$jscomp$2$$,$style_encode_vec__53443$$.$cljs$core$IFn$_invoke$arity$1$?$style_encode_vec__53443$$.$cljs$core$IFn$_invoke$arity$1$($p__53439_style_value_v$jscomp$569$$):$style_encode_vec__53443$$($p__53439_style_value_v$jscomp$569$$))}else $k$jscomp$625_style_name$jscomp$2$$=$APP.$app$util$text$content$styles$get_style_name$$($k$jscomp$625_style_name$jscomp$2$$),$p__53439_style_value_v$jscomp$569$$=
$APP.$app$util$text$content$styles$normalize_style_value$$($k$jscomp$625_style_name$jscomp$2$$,$p__53439_style_value_v$jscomp$569$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$115$$,$k$jscomp$625_style_name$jscomp$2$$,$p__53439_style_value_v$jscomp$569$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$style_defaults$$))};
$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$=function($file_id$jscomp$300$$,$set_id$jscomp$26$$,$types$jscomp$5$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$util$storage$user$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4685$app_DOT_main_DOT_ui_DOT_workspace_DOT_tokens_SLASH_unfolded_token_types$$,$APP.$cljs$core$assoc_in$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$300$$,$set_id$jscomp$26$$],null),$APP.$cljs$core$vec$$($types$jscomp$5$$)]))};
$app$main$data$workspace$tokens$library_edit$clear_tokens_types$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$=function($meta72768$$){this.$meta72768$=$meta72768$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4691$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_tokens_types$$},$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72769$$,$meta72768__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$($meta72768__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72768$},$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2650_file_id$jscomp$306$$,$state$jscomp$969$$){$_$jscomp$2650_file_id$jscomp$306$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$969$$);var $set_id$jscomp$32$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$969$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$2138$selected_token_set_id$$],null));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2650_file_id$jscomp$306$$,$set_id$jscomp$32$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$969$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2650_file_id$jscomp$306$$,$set_id$jscomp$32$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$))});return new $app$main$data$workspace$tokens$library_edit$clear_tokens_types_72767$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$toggle_token_type$$=function($type$jscomp$555$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$=function($type$jscomp$556$$,$meta72763$$){this.type=$type$jscomp$556$$;this.$meta72763$=$meta72763$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4690$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_type$$},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72764$$,$meta72763__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$(this.type,
$meta72763__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72763$},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2649_file_id$jscomp$305$$,$new_state$jscomp$3_state$jscomp$968$$){$_$jscomp$2649_file_id$jscomp$305$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_state$jscomp$3_state$jscomp$968$$);var $set_id$jscomp$31$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_state$jscomp$3_state$jscomp$968$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$2138$selected_token_set_id$$],null)),$new_types$jscomp$2_types$jscomp$11$$=$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$($new_state$jscomp$3_state$jscomp$968$$);
$new_types$jscomp$2_types$jscomp$11$$=$APP.$cljs$core$contains_QMARK_$$($new_types$jscomp$2_types$jscomp$11$$,this.type)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types$jscomp$2_types$jscomp$11$$)?$new_types$jscomp$2_types$jscomp$11$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,this.type):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types$jscomp$2_types$jscomp$11$$)?$new_types$jscomp$2_types$jscomp$11$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,
this.type);$new_state$jscomp$3_state$jscomp$968$$=$APP.$cljs$core$assoc_in$$($new_state$jscomp$3_state$jscomp$968$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2649_file_id$jscomp$305$$,$set_id$jscomp$31$$,$new_types$jscomp$2_types$jscomp$11$$));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2649_file_id$jscomp$305$$,
$set_id$jscomp$31$$,$new_types$jscomp$2_types$jscomp$11$$);return $new_state$jscomp$3_state$jscomp$968$$});return new $app$main$data$workspace$tokens$library_edit$toggle_token_type_72762$$($type$jscomp$555$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$=function($type$jscomp$553$$){typeof $app$main$data$workspace$tokens$library_edit$close_token_type_72758$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$close_token_type_72758$$=function($type$jscomp$554$$,$meta72759$$){this.type=$type$jscomp$554$$;this.$meta72759$=$meta72759$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4689$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_close_token_type$$},$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72760$$,$meta72759__$1$$){return new $app$main$data$workspace$tokens$library_edit$close_token_type_72758$$(this.type,
$meta72759__$1$$)},$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72759$},$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$close_token_type_72758$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2648_file_id$jscomp$304$$,$new_state$jscomp$2_state$jscomp$967$$){$_$jscomp$2648_file_id$jscomp$304$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_state$jscomp$2_state$jscomp$967$$);var $set_id$jscomp$30$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_state$jscomp$2_state$jscomp$967$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$2138$selected_token_set_id$$],null)),$new_types$jscomp$1_types$jscomp$10$$=$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$($new_state$jscomp$2_state$jscomp$967$$);
$new_types$jscomp$1_types$jscomp$10$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types$jscomp$1_types$jscomp$10$$)?$new_types$jscomp$1_types$jscomp$10$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,this.type);$new_state$jscomp$2_state$jscomp$967$$=$APP.$cljs$core$assoc_in$$($new_state$jscomp$2_state$jscomp$967$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],
null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2648_file_id$jscomp$304$$,$set_id$jscomp$30$$,$new_types$jscomp$1_types$jscomp$10$$));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2648_file_id$jscomp$304$$,$set_id$jscomp$30$$,$new_types$jscomp$1_types$jscomp$10$$);return $new_state$jscomp$2_state$jscomp$967$$});return new $app$main$data$workspace$tokens$library_edit$close_token_type_72758$$($type$jscomp$553$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$open_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$=function($type$jscomp$550$$){typeof $app$main$data$workspace$tokens$library_edit$open_token_type_72751$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$open_token_type_72751$$=function($type$jscomp$551$$,$meta72752$$){this.type=$type$jscomp$551$$;this.$meta72752$=$meta72752$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4688$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_open_token_type$$},$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72753$$,$meta72752__$1$$){return new $app$main$data$workspace$tokens$library_edit$open_token_type_72751$$(this.type,
$meta72752__$1$$)},$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72752$},$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$open_token_type_72751$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2647_file_id$jscomp$303$$,$new_state$jscomp$1_state$jscomp$966$$){$_$jscomp$2647_file_id$jscomp$303$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_state$jscomp$1_state$jscomp$966$$);var $set_id$jscomp$29$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_state$jscomp$1_state$jscomp$966$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$2138$selected_token_set_id$$],null)),$new_types_types$jscomp$8$$=$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$($new_state$jscomp$1_state$jscomp$966$$);
$new_types_types$jscomp$8$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types_types$jscomp$8$$)?$new_types_types$jscomp$8$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,this.type);$new_state$jscomp$1_state$jscomp$966$$=$APP.$cljs$core$assoc_in$$($new_state$jscomp$1_state$jscomp$966$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],
null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2647_file_id$jscomp$303$$,$set_id$jscomp$29$$,$new_types_types$jscomp$8$$));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2647_file_id$jscomp$303$$,$set_id$jscomp$29$$,$new_types_types$jscomp$8$$);return $new_state$jscomp$1_state$jscomp$966$$});return new $app$main$data$workspace$tokens$library_edit$open_token_type_72751$$($type$jscomp$550$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types$$=function(){typeof $app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$=function($meta72745$$){this.$meta72745$=$meta72745$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4687$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_restore_unfolded_token_types$$},$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72746$$,$meta72745__$1$$){return new $app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$($meta72745__$1$$)},
$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72745$},$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2646_file_id$jscomp$302$$,$state$jscomp$965$$){$_$jscomp$2646_file_id$jscomp$302$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$965$$);var $set_id$jscomp$28$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$965$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$2138$selected_token_set_id$$],null)),$stored$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4685$app_DOT_main_DOT_ui_DOT_workspace_DOT_tokens_SLASH_unfolded_token_types$$,$_$jscomp$2646_file_id$jscomp$302$$,$set_id$jscomp$28$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$965$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2646_file_id$jscomp$302$$,
$set_id$jscomp$28$$,$stored$jscomp$1$$))});return new $app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72744$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$show_palette$$=function($selected$jscomp$77$$){typeof $app$main$data$workspace$colors$show_palette_70402$$==="undefined"&&($app$main$data$workspace$colors$show_palette_70402$$=function($selected$jscomp$78$$,$meta70403$$){this.selected=$selected$jscomp$78$$;this.$meta70403$=$meta70403$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$show_palette_70402$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$show_palette_70402$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4128$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_show_palette$$},$app$main$data$workspace$colors$show_palette_70402$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70404$$,$meta70403__$1$$){return new $app$main$data$workspace$colors$show_palette_70402$$(this.selected,$meta70403__$1$$)},$app$main$data$workspace$colors$show_palette_70402$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70403$},$app$main$data$workspace$colors$show_palette_70402$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$show_palette_70402$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$layout$toggle_layout_flag$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$3715$colorpalette$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3734$force_QMARK_$$,
!0])),$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4127$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$,this.selected))},$app$main$data$workspace$colors$show_palette_70402$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$show_palette_70402$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$,$G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$){a:{$JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$=
$APP.$cljs$cst$2188$workspace_global$$.$cljs$core$IFn$_invoke$arity$1$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$);$G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$=$APP.$cljs$core$seq$$($APP.$app$main$data$workspace$layout$layout_state_persistence_mapping$$);for(var $G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$=
null,$count__67225$jscomp$inline_8365$$=0,$i__67226$jscomp$inline_8366$$=0;;)if($i__67226$jscomp$inline_8366$$<$count__67225$jscomp$inline_8365$$){var $skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$=$G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__67226$jscomp$inline_8366$$),$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$,0,null);$skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$,1,null);$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$,
$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$,$APP.$cljs$cst$3748$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$,$APP.$cljs$cst$3748$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,
$APP.$cljs$core$dissoc$$,$skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$,$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$);$i__67226$jscomp$inline_8366$$+=1}else if($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$=
$APP.$cljs$core$seq$$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$)?($G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$=$APP.$cljs$core$_chunked_first$$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$),
$G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$=$APP.$cljs$core$_chunked_rest$$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$),$G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$=$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$,
$count__67225$jscomp$inline_8365$$=$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$=$APP.$cljs$core$count$$($G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$)):($G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$=$APP.$cljs$core$first$$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$),
$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$,0,null),$skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$,
1,null),$G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$,$G__67303$jscomp$inline_8376_c__5548__auto__$jscomp$inline_8373_key$jscomp$inline_8368_val_67296$jscomp$inline_8370$$,$APP.$cljs$cst$3748$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$,
$APP.$cljs$cst$3748$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$APP.$cljs$core$dissoc$$,$skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$skey$jscomp$inline_8369_vec__67236$jscomp$inline_8367$$,$G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$),
$G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$=$APP.$cljs$core$next$$($G__67301$jscomp$inline_8374_seq__67223$jscomp$inline_8363_seq__67223__$1$jscomp$inline_8372_state$jscomp$623_temp__5825__auto__$jscomp$inline_8371$$),$G__67302$jscomp$inline_8375_chunk__67224$jscomp$inline_8364_val_67305$jscomp$inline_8378_vec__67239$jscomp$inline_8377$$=null,$count__67225$jscomp$inline_8365$$=0),$i__67226$jscomp$inline_8366$$=
0;else{$JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$=null;break a}$JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$=void 0}return $JSCompiler_inline_result$jscomp$1651__$jscomp$2228_state$jscomp$inline_8362$$});return new $app$main$data$workspace$colors$show_palette_70402$$($selected$jscomp$77$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$add_recent_font$$=function($font$jscomp$37$$){typeof $app$main$data$fonts$add_recent_font_55960$$==="undefined"&&($app$main$data$fonts$add_recent_font_55960$$=function($font$jscomp$38$$,$meta55961$$){this.font=$font$jscomp$38$$;this.$meta55961$=$meta55961$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$add_recent_font_55960$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_recent_font_55960$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3508$app_DOT_main_DOT_data_DOT_fonts_SLASH_add_recent_font$$},$app$main$data$fonts$add_recent_font_55960$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55962$$,$meta55961__$1$$){return new $app$main$data$fonts$add_recent_font_55960$$(this.font,$meta55961__$1$$)},$app$main$data$fonts$add_recent_font_55960$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55961$},$app$main$data$fonts$add_recent_font_55960$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_recent_font_55960$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1853_file_id$jscomp$78$$,$state$jscomp$296$$){$_$jscomp$1853_file_id$jscomp$78$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$296$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$296$$,$APP.$cljs$cst$2214$recent_fonts$$,$app$main$data$fonts$update_recent_font$$,$_$jscomp$1853_file_id$jscomp$78$$,
this.font)},$app$main$data$fonts$add_recent_font_55960$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_recent_font_55960$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1854_recent_fonts$$,$state$jscomp$297$$){$_$jscomp$1854_recent_fonts$$=$APP.$cljs$cst$2214$recent_fonts$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$297$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2214$recent_fonts$$,$_$jscomp$1854_recent_fonts$$)});return new $app$main$data$fonts$add_recent_font_55960$$($font$jscomp$37$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$hooks$use_persisted_state$$=function($key$jscomp$347$$,$default$$jscomp$55$$){var $id$jscomp$304$$=(0,$APP.$rumext$v2$use_id$$)(),$state_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$key$jscomp$347$$,$default$$jscomp$55$$)}),$state$jscomp$156$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$2$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$156$$),
$APP.$rumext$v2$adapt$$($key$jscomp$347$$),$APP.$rumext$v2$adapt$$($id$jscomp$304$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$key$jscomp$347$$,$state$jscomp$156$$)});return $state_STAR_$jscomp$2$$};
$app$main$ui$hooks$use_shared_state$$=function($key$jscomp$346$$){var $default$$jscomp$54$$=$cljs$cst$5583$recent$$,$id$jscomp$303$$=(0,$APP.$rumext$v2$use_id$$)(),$state_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$key$jscomp$346$$,$default$$jscomp$54$$)}),$state$jscomp$155$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$1$$),$stream$jscomp$24$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$303$$)],
function(){return $APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$(function($p1__52664_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__52664_SHARP_$$),$key$jscomp$346$$)},$APP.$beicon$v2$core$filter$$(function($p1__52662_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__52662_SHARP_$$),$id$jscomp$303$$)},
$APP.$app$main$broadcast$stream$$)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$155$$),$APP.$rumext$v2$adapt$$($key$jscomp$346$$),$APP.$rumext$v2$adapt$$($id$jscomp$303$$)],function(){$APP.$app$main$broadcast$emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$303$$,$key$jscomp$346$$,$state$jscomp$155$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$key$jscomp$346$$,
$state$jscomp$155$$)});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$24$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$state_STAR_$jscomp$1$$));return $state_STAR_$jscomp$1$$};
$app$main$data$workspace$clipboard$copy_selected_css_nested$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$=function($meta70596$$){this.$meta70596$=$meta70596$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4108$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_css_nested$$},$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70597$$,$meta70596__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$($meta70596__$1$$)},$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70596$},$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2214_objects$jscomp$581$$,$css$jscomp$9_selected$jscomp$67_state$jscomp$607$$){$_$jscomp$2214_objects$jscomp$581$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($css$jscomp$9_selected$jscomp$67_state$jscomp$607$$);
$css$jscomp$9_selected$jscomp$67_state$jscomp$607$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2214_objects$jscomp$581$$),$APP.$app$common$files$helpers$selected_with_children$$($_$jscomp$2214_objects$jscomp$581$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($css$jscomp$9_selected$jscomp$67_state$jscomp$607$$)));$css$jscomp$9_selected$jscomp$67_state$jscomp$607$$=$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$($_$jscomp$2214_objects$jscomp$581$$,
$css$jscomp$9_selected$jscomp$67_state$jscomp$607$$,$css$jscomp$9_selected$jscomp$67_state$jscomp$607$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4097$with_prelude_QMARK_$$,!1],null));return $APP.$app$util$clipboard$to_clipboard$$($css$jscomp$9_selected$jscomp$67_state$jscomp$607$$)});return new $app$main$data$workspace$clipboard$copy_selected_css_nested_70595$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$copy_selected_css$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_css_70576$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_css_70576$$=function($meta70577$$){this.$meta70577$=$meta70577$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_css_70576$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_css_70576$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4107$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_css$$},$app$main$data$workspace$clipboard$copy_selected_css_70576$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70578$$,$meta70577__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_css_70576$$($meta70577__$1$$)},$app$main$data$workspace$clipboard$copy_selected_css_70576$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70577$},$app$main$data$workspace$clipboard$copy_selected_css_70576$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_css_70576$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2213_objects$jscomp$580$$,$css$jscomp$8_selected$jscomp$66_state$jscomp$606$$){$_$jscomp$2213_objects$jscomp$580$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($css$jscomp$8_selected$jscomp$66_state$jscomp$606$$);$css$jscomp$8_selected$jscomp$66_state$jscomp$606$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2213_objects$jscomp$580$$),
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($css$jscomp$8_selected$jscomp$66_state$jscomp$606$$));$css$jscomp$8_selected$jscomp$66_state$jscomp$606$$=$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$($_$jscomp$2213_objects$jscomp$580$$,$css$jscomp$8_selected$jscomp$66_state$jscomp$606$$,$css$jscomp$8_selected$jscomp$66_state$jscomp$606$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4097$with_prelude_QMARK_$$,
!1],null));return $APP.$app$util$clipboard$to_clipboard$$($css$jscomp$8_selected$jscomp$66_state$jscomp$606$$)});return new $app$main$data$workspace$clipboard$copy_selected_css_70576$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$subscription$main_menu_power_up_STAR_$$=function($close_sub_menu_props_73526$$){$close_sub_menu_props_73526$$=$close_sub_menu_props_73526$$.closeSubMenu;var $go_to_subscription$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5069$settings_subscription$$))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_dashboard_subscription__menu-item",onClick:$go_to_subscription$$,onKeyDown:function($event$jscomp$176$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$176$$))?$go_to_subscription$$.$cljs$core$IFn$_invoke$arity$0$?$go_to_subscription$$.$cljs$core$IFn$_invoke$arity$0$():$go_to_subscription$$():null},onPointerEnter:$close_sub_menu_props_73526$$,id:"file-menu-power-up",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.workspace.header.menu.option.power-up")})})};
$app$main$data$workspace$tokens$library_edit$drop_error$$=function($p__72895$$){var $map__72896__$1$$=$APP.$cljs$core$__destructure_map$$($p__72895$$),$error$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72896__$1$$,$APP.$cljs$cst$849$error$$),$to_path$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72896__$1$$,$APP.$cljs$cst$2655$to_path$$);typeof $app$main$data$workspace$tokens$library_edit$drop_error_72897$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$drop_error_72897$$=
function($p__72895$jscomp$1$$,$map__72896$jscomp$1$$,$error$jscomp$77$$,$to_path$jscomp$12$$,$meta72898$$){this.$p__72895$=$p__72895$jscomp$1$$;this.$map__72896$=$map__72896$jscomp$1$$;this.error=$error$jscomp$77$$;this.$to_path$=$to_path$jscomp$12$$;this.$meta72898$=$meta72898$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$drop_error_72897$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$drop_error_72897$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4711$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_error$$},$app$main$data$workspace$tokens$library_edit$drop_error_72897$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72899$$,$meta72898__$1$$){return new $app$main$data$workspace$tokens$library_edit$drop_error_72897$$(this.$p__72895$,this.$map__72896$,this.error,
this.$to_path$,$meta72898__$1$$)},$app$main$data$workspace$tokens$library_edit$drop_error_72897$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72898$},$app$main$data$workspace$tokens$library_edit$drop_error_72897$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_error_72897$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6630$$=this,$content$jscomp$225$$=function(){var $G__72900$$=
$self__$jscomp$6630$$.error;switch($G__72900$$ instanceof $APP.$cljs$core$Keyword$$?$G__72900$$.$fqn$:null){case "path-exists":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.token-set-exists-on-drop",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6630$$.$to_path$]));case "parent-to-child":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.drop-token-set-parent-to-child");default:return null}}();return $APP.$cljs$core$truth_$$($content$jscomp$225$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$content$jscomp$225$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,9E3],null))):null});return new $app$main$data$workspace$tokens$library_edit$drop_error_72897$$($p__72895$$,$map__72896__$1$$,$error$jscomp$76$$,$to_path$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$=function($JSCompiler_temp$jscomp$1652_error$jscomp$74$$){if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1652_error$jscomp$74$$)){var $JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1652_error$jscomp$74$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$)){var $JSCompiler_temp_const$jscomp$1654$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1653$$=$APP.$cljs$cst$141$message$$,$G__71797$jscomp$inline_8380$$=$APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1652_error$jscomp$74$$);$JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$=$JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$.$cljs$core$IFn$_invoke$arity$1$($G__71797$jscomp$inline_8380$$):
$JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$($G__71797$jscomp$inline_8380$$);$JSCompiler_temp$jscomp$1652_error$jscomp$74$$=$JSCompiler_temp_const$jscomp$1654$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$1652_error$jscomp$74$$,$JSCompiler_temp_const$jscomp$1653$$,$JSCompiler_inline_result$jscomp$1656_temp__5823__auto__$jscomp$191$$)}return $JSCompiler_temp$jscomp$1652_error$jscomp$74$$}return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1652_error$jscomp$74$$,
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unknown-error"))};
$app$main$data$workspace$tokens$errors$resolve_error_message$$=function($G__71796_error$jscomp$73$$){if($APP.$cljs$core$truth_$$($G__71796_error$jscomp$73$$)){var $temp__5823__auto__$jscomp$190$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__71796_error$jscomp$73$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$190$$)?($G__71796_error$jscomp$73$$=$APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($G__71796_error$jscomp$73$$),$temp__5823__auto__$jscomp$190$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$190$$.$cljs$core$IFn$_invoke$arity$1$($G__71796_error$jscomp$73$$):$temp__5823__auto__$jscomp$190$$($G__71796_error$jscomp$73$$)):$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($G__71796_error$jscomp$73$$)}return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unknown-error")};
$app$main$data$style_dictionary$resolve_tokens_with_verbose_errors$$=function($tokens$jscomp$32$$){return $APP.$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$tokens_lib$tokens_tree$$($tokens$jscomp$32$$),function($p1__72005_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$32$$,$p1__72005_SHARP_$$.original.name)},new $APP.$app$main$data$style_dictionary$StyleDictionary$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$style_dictionary$default_config$$,
$APP.$cljs$cst$3029$log$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4616$verbosity$$,"verbose"],null))))};
$app$main$data$workspace$tokens$errors$error_ex_info$$=function($err$jscomp$39_error_key$jscomp$2$$,$error_value$jscomp$1$$,$exception$jscomp$12$$){$err$jscomp$39_error_key$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$tokens$errors$error_with_value$$($err$jscomp$39_error_key$jscomp$2$$,$error_value$jscomp$1$$),$APP.$cljs$cst$4604$error_SLASH_exception$$,$exception$jscomp$12$$);return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$39_error_key$jscomp$2$$),
$err$jscomp$39_error_key$jscomp$2$$)};
$app$util$color$get_color_name$$=function($color$jscomp$41$$){var $or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($color$jscomp$41$$));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$))return $or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$;$or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$41$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$))return $or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$;$or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$41$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$)?
$or__5025__auto__$jscomp$498_or__5025__auto____$1$jscomp$53_or__5025__auto____$2$jscomp$13$$:$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$41$$)))};
$app$main$data$workspace$clipboard$copy_as_image$$=function(){typeof $app$main$data$workspace$clipboard$copy_as_image_71066$$==="undefined"&&($app$main$data$workspace$clipboard$copy_as_image_71066$$=function($meta71067$$){this.$meta71067$=$meta71067$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_as_image_71066$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_as_image_71066$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4123$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_as_image$$},$app$main$data$workspace$clipboard$copy_as_image_71066$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71068$$,$meta71067__$1$$){return new $app$main$data$workspace$clipboard$copy_as_image_71066$$($meta71067__$1$$)},$app$main$data$workspace$clipboard$copy_as_image_71066$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71067$},$app$main$data$workspace$clipboard$copy_as_image_71066$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_as_image_71066$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2226_export$_file_id$jscomp$206$$,$state$jscomp$622$$){$_$jscomp$2226_export$_file_id$jscomp$206$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$622$$);var $page_id$jscomp$193$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$622$$),$selected$jscomp$76$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$622$$));
$_$jscomp$2226_export$_file_id$jscomp$206$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$2226_export$_file_id$jscomp$206$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$193$$,$APP.$cljs$cst$2272$object_id$$,$selected$jscomp$76$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1534$png$$,$APP.$cljs$cst$1902$scale$$,2,$APP.$cljs$cst$1371$suffix$$,"",$APP.$cljs$cst$3109$enabled$$,!0,$APP.$cljs$cst$725$name$$,""],null);var $deferred$jscomp$12$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$,
$write_promise$$=$APP.$app$util$clipboard$to_clipboard_promise$$("image/png",$deferred$jscomp$12$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$),$APP.$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$empty$$(),$APP.$beicon$v2$core$first$$($APP.$beicon$v2$core$filter$$(function($p1__71065_SHARP_$$){return $p1__71065_SHARP_$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3151$saved$$,
$p1__71065_SHARP_$$)},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$persistence_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null))))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.clipboard.copying"))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($e$jscomp$326$$){console.error("clipboard error:",
$e$jscomp$326$$);$APP.$promesa$protocols$_reject_BANG_$$($deferred$jscomp$12$$,$e$jscomp$326$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.clipboard.image-copy-failed")))},$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.clipboard.image-copied"))},$APP.$beicon$v2$core$mapcat$$(function($blob$jscomp$36$$){$APP.$promesa$protocols$_resolve_BANG_$$($deferred$jscomp$12$$,
$blob$jscomp$36$$);return $APP.$beicon$v2$core$from$$($write_promise$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$beicon$v2$core$mapcat$$(function($map__71074__$1_p__71073_uri$jscomp$97$$){$map__71074__$1_p__71073_uri$jscomp$97$$=$APP.$cljs$core$__destructure_map$$($map__71074__$1_p__71073_uri$jscomp$97$$);$map__71074__$1_p__71073_uri$jscomp$97$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71074__$1_p__71073_uri$jscomp$97$$,$APP.$cljs$cst$1579$uri$$);return $APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$map__71074__$1_p__71073_uri$jscomp$97$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$],null))},$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$622$$,"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4124$wasm_export$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1579$uri$$,$APP.$app$main$data$exports$wasm$export_image_uri$$($_$jscomp$2226_export$_file_id$jscomp$206$$)],
null)):$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2177$export$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1870$exports$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2226_export$_file_id$jscomp$206$$],null),$APP.$cljs$cst$2313$profile_id$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$622$$),$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$4125$export_shapes$$,
$APP.$cljs$cst$2281$wait$$,!0],null))))))))});return new $app$main$data$workspace$clipboard$copy_as_image_71066$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$copy_selected_svg$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_svg_70571$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_svg_70571$$=function($meta70572$$){this.$meta70572$=$meta70572$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_svg_70571$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_svg_70571$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4106$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_svg$$},$app$main$data$workspace$clipboard$copy_selected_svg_70571$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70573$$,$meta70572__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_svg_70571$$($meta70572__$1$$)},$app$main$data$workspace$clipboard$copy_selected_svg_70571$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70572$},$app$main$data$workspace$clipboard$copy_selected_svg_70571$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_svg_70571$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$,$state$jscomp$605$$){var $objects$jscomp$579$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$605$$);$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$579$$),
$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$579$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$605$$)));var $parent_frame_id$jscomp$2$$=$APP.$app$common$files$helpers$common_parent_frame$$($objects$jscomp$579$$,$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$);$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70570_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_frame_id$jscomp$2$$,
$APP.$app$common$uuid$zero$$)?$p1__70570_SHARP_$$:$APP.$app$common$geom$shapes$translate_to_frame$$($p1__70570_SHARP_$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$579$$,$parent_frame_id$jscomp$2$$))},$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$);$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$=$APP.$app$util$code_beautify$format_code$$($APP.$app$util$code_gen$markup_svg$generate_markup$$($objects$jscomp$579$$,$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$),
"svg");return $app$util$clipboard$to_clipboard_multi$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,["image/svg+xml",$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$,"text/plain",$_$jscomp$2212_selected$jscomp$65_shapes$jscomp$113_svg_formatted$$],null))});return new $app$main$data$workspace$clipboard$copy_selected_svg_70571$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$set_wasm_modifiers$$=function($var_args$jscomp$1246$$){for(var $args__5755__auto__$jscomp$227$$=[],$len__5749__auto___68987$$=arguments.length,$i__5750__auto___68988$$=0;;)if($i__5750__auto___68988$$<$len__5749__auto___68987$$)$args__5755__auto__$jscomp$227$$.push(arguments[$i__5750__auto___68988$$]),$i__5750__auto___68988$$+=1;else break;return $APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<
$args__5755__auto__$jscomp$227$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$227$$.slice(1),0,null):null)};
$app$main$data$workspace$texts$v2_sync_wasm_text_layout$$=function($id$jscomp$640$$,$content$jscomp$188$$){typeof $app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$==="undefined"&&($app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$=function($id$jscomp$641$$,$content$jscomp$189$$,$meta70365$$){this.id=$id$jscomp$641$$;this.content=$content$jscomp$189$$;this.$meta70365$=$meta70365$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4038$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_sync_wasm_text_layout$$},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70366$$,$meta70365__$1$$){return new $app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$(this.id,
this.content,$meta70365__$1$$)},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70365$},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$,
$state$jscomp$594$$){$_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$594$$);$_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$,this.id);return $_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$!=null&&$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$)?
($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$=$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$,this.content)!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$))?$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$,
this.content):null,$_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$!=null?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$set_wasm_modifiers$$($_$jscomp$2197_modifiers$jscomp$95_objects$jscomp$519_shape$jscomp$588$$)):$APP.$beicon$v2$core$empty$$()):$APP.$beicon$v2$core$empty$$()},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function(){return $APP.$app$render_wasm$api$request_render$$("text-editor-v2-needslayout")});return new $app$main$data$workspace$texts$v2_sync_wasm_text_layout_70364$$($id$jscomp$640$$,$content$jscomp$188$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$resize_text_editor$$=function($id$jscomp$554$$,$p__69405$$){var $map__69406__$1$$=$APP.$cljs$core$__destructure_map$$($p__69405$$),$width$jscomp$139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69406__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69406__$1$$,$APP.$cljs$cst$1522$height$$);typeof $app$main$data$workspace$transforms$resize_text_editor_69407$$==="undefined"&&($app$main$data$workspace$transforms$resize_text_editor_69407$$=
function($id$jscomp$555$$,$p__69405$jscomp$1$$,$map__69406$jscomp$1$$,$width$jscomp$140$$,$height$jscomp$126$$,$meta69408$$){this.id=$id$jscomp$555$$;this.$p__69405$=$p__69405$jscomp$1$$;this.$map__69406$=$map__69406$jscomp$1$$;this.width=$width$jscomp$140$$;this.height=$height$jscomp$126$$;this.$meta69408$=$meta69408$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$resize_text_editor_69407$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$resize_text_editor_69407$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3889$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_resize_text_editor$$},$app$main$data$workspace$transforms$resize_text_editor_69407$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69409$$,$meta69408__$1$$){return new $app$main$data$workspace$transforms$resize_text_editor_69407$$(this.id,this.$p__69405$,
this.$map__69406$,this.width,this.height,$meta69408__$1$$)},$app$main$data$workspace$transforms$resize_text_editor_69407$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69408$},$app$main$data$workspace$transforms$resize_text_editor_69407$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$resize_text_editor_69407$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$,
$resize_v$jscomp$1_state$jscomp$477$$){$_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($resize_v$jscomp$1_state$jscomp$477$$);$_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$,this.id);$resize_v$jscomp$1_state$jscomp$477$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(this.width/
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$)),this.height/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$)));var $origin$jscomp$36$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$));
$_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$=$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([this.id,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($resize_v$jscomp$1_state$jscomp$477$$,$origin$jscomp$36$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()),
$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()))],null)]);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$set_wasm_modifiers$$($_$jscomp$2075_modifiers$jscomp$91_objects$jscomp$496_shape$jscomp$549$$))});return new $app$main$data$workspace$transforms$resize_text_editor_69407$$($id$jscomp$554$$,$p__69405$$,$map__69406__$1$$,
$width$jscomp$139$$,$height$jscomp$125$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_nudge$$=function($p__71710$$){var $map__71711__$1$$=$APP.$cljs$core$__destructure_map$$($p__71710$$),$big$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71711__$1$$,$APP.$cljs$cst$3876$big$$),$small$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71711__$1$$,$APP.$cljs$cst$3877$small$$);typeof $app$main$data$workspace$update_nudge_71712$$==="undefined"&&($app$main$data$workspace$update_nudge_71712$$=function($p__71710$jscomp$1$$,$map__71711$jscomp$1$$,
$params$jscomp$293$$,$big$jscomp$1$$,$small$jscomp$1$$,$meta71713$$){this.$p__71710$=$p__71710$jscomp$1$$;this.$map__71711$=$map__71711$jscomp$1$$;this.params=$params$jscomp$293$$;this.big=$big$jscomp$1$$;this.small=$small$jscomp$1$$;this.$meta71713$=$meta71713$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$update_nudge_71712$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_nudge_71712$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4472$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_nudge$$},$app$main$data$workspace$update_nudge_71712$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71714$$,$meta71713__$1$$){return new $app$main$data$workspace$update_nudge_71712$$(this.$p__71710$,this.$map__71711$,this.params,this.big,this.small,$meta71713__$1$$)},$app$main$data$workspace$update_nudge_71712$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71713$},$app$main$data$workspace$update_nudge_71712$$.prototype.$cljs$core$IDeref$_deref$arity$1$=
function(){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(this.params)},$app$main$data$workspace$update_nudge_71712$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_nudge_71712$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2544$$,$state$jscomp$885$$){var $self__$jscomp$6218$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$885$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3875$nudge$$],null),function($G__71721__$1_nudge$jscomp$1$$){$G__71721__$1_nudge$jscomp$1$$=typeof $self__$jscomp$6218$$.big==="number"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71721__$1_nudge$jscomp$1$$,$APP.$cljs$cst$3876$big$$,$self__$jscomp$6218$$.big):$G__71721__$1_nudge$jscomp$1$$;return typeof $self__$jscomp$6218$$.small==="number"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71721__$1_nudge$jscomp$1$$,
$APP.$cljs$cst$3877$small$$,$self__$jscomp$6218$$.small):$G__71721__$1_nudge$jscomp$1$$})},$app$main$data$workspace$update_nudge_71712$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_nudge_71712$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2545_nudge$jscomp$2$$,$state$jscomp$886$$){$_$jscomp$2545_nudge$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$886$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3875$nudge$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3875$nudge$$,$_$jscomp$2545_nudge$jscomp$2$$],null)))});return new $app$main$data$workspace$update_nudge_71712$$($p__71710$$,$map__71711__$1$$,$map__71711__$1$$,$big$$,$small$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$finalize_workspace$$=function($_team_id$$,$file_id$jscomp$271$$){typeof $app$main$data$workspace$finalize_workspace_71689$$==="undefined"&&($app$main$data$workspace$finalize_workspace_71689$$=function($_team_id$jscomp$1$$,$file_id$jscomp$272$$,$meta71690$$){this.$_team_id$=$_team_id$jscomp$1$$;this.$file_id$=$file_id$jscomp$272$$;this.$meta71690$=$meta71690$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$finalize_workspace_71689$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$finalize_workspace_71689$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$},$app$main$data$workspace$finalize_workspace_71689$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71691$$,$meta71690__$1$$){return new $app$main$data$workspace$finalize_workspace_71689$$(this.$_team_id$,this.$file_id$,$meta71690__$1$$)},$app$main$data$workspace$finalize_workspace_71689$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71690$},$app$main$data$workspace$finalize_workspace_71689$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$finalize_workspace_71689$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2536$$,$state$jscomp$881$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$881$$,
$APP.$cljs$cst$1917$current_file_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2222$workspace_editor_state$$,$APP.$cljs$cst$2224$workspace_wasm_editor_styles$$,$APP.$cljs$cst$4467$workspace_media_objects$$,$APP.$cljs$cst$4468$workspace_persistence$$,$APP.$cljs$cst$2216$workspace_presence$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$cst$4469$workspace_versions$$])),$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$2217$read_only_QMARK_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2200$options_mode$$],null),$APP.$cljs$cst$3732$design$$),$APP.$cljs$cst$1916$files$$,$APP.$app$common$data$update_vals$$,function($p1__71688_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__71688_SHARP_$$,$APP.$cljs$cst$142$data$$)})},$app$main$data$workspace$finalize_workspace_71689$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$finalize_workspace_71689$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2537_project_id$jscomp$15$$,$state$jscomp$882$$){$_$jscomp$2537_project_id$jscomp$15$$=$APP.$cljs$cst$2174$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$882$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$notifications$finalize$$(this.$file_id$),$app$main$data$project$finalize_project$$($_$jscomp$2537_project_id$jscomp$15$$),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4394$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_finalize_shape_layout$$),$app$main$data$workspace$colors$stop_picker$$(),$APP.$app$main$data$workspace$common$set_workspace_visited$$(),$APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$notifications$hide$$())});return new $app$main$data$workspace$finalize_workspace_71689$$($_team_id$$,$file_id$jscomp$271$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$=function($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$first__34870_p__34867$$,$JSCompiler_temp$jscomp$440_value$jscomp$295$$,$JSCompiler_inline_result$jscomp$441_default$$jscomp$inline_8387_options$jscomp$291$$){var $seq__34869_seq__34869__$1$$=$APP.$cljs$core$seq$$($first__34870_p__34867$$);$first__34870_p__34867$$=$APP.$cljs$core$first$$($seq__34869_seq__34869__$1$$);$seq__34869_seq__34869__$1$$=$APP.$cljs$core$next$$($seq__34869_seq__34869__$1$$);
$_QMARK_schema$jscomp$121_schema$jscomp$79$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$JSCompiler_inline_result$jscomp$441_default$$jscomp$inline_8387_options$jscomp$291$$);$seq__34869_seq__34869__$1$$&&($JSCompiler_inline_result$jscomp$441_default$$jscomp$inline_8387_options$jscomp$291$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$202$map$$,$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$121_schema$jscomp$79$$)),
$JSCompiler_inline_result$jscomp$441_default$$jscomp$inline_8387_options$jscomp$291$$=$APP.$malli$util$get$cljs$0core$0IFn$0_invoke$0arity$04$$($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$first__34870_p__34867$$,$JSCompiler_inline_result$jscomp$441_default$$jscomp$inline_8387_options$jscomp$291$$),$JSCompiler_temp$jscomp$440_value$jscomp$295$$=$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_inline_result$jscomp$441_default$$jscomp$inline_8387_options$jscomp$291$$,$seq__34869_seq__34869__$1$$,
$JSCompiler_temp$jscomp$440_value$jscomp$295$$,null));return $APP.$malli$util$assoc$cljs$0core$0IFn$0_invoke$0arity$04$$($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$first__34870_p__34867$$,$JSCompiler_temp$jscomp$440_value$jscomp$295$$,null)};
$malli$error$_resolve_direct_error$$=function($JSCompiler_temp_const$jscomp$1657__$jscomp$766$$,$error$jscomp$22$$,$options$jscomp$392$$){$JSCompiler_temp_const$jscomp$1657__$jscomp$766$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;var $JSCompiler_inline_result$jscomp$1658_JSCompiler_temp_const$jscomp$10988$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$10987$$=$APP.$cljs$cst$297$in$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$22$$);var $JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$=
$APP.$cljs$core$__destructure_map$$($error$jscomp$22$$);var $properties$jscomp$inline_13296_schema$jscomp$inline_13292$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$,$APP.$cljs$cst$298$schema$$),$default_locale$jscomp$inline_13295_map__35282__$1$jscomp$inline_13293$$=$APP.$cljs$core$__destructure_map$$($options$jscomp$392$$);$JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_locale$jscomp$inline_13295_map__35282__$1$jscomp$inline_13293$$,$APP.$cljs$cst$888$locale$$);$default_locale$jscomp$inline_13295_map__35282__$1$jscomp$inline_13293$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($default_locale$jscomp$inline_13295_map__35282__$1$jscomp$inline_13293$$,$APP.$cljs$cst$889$default_locale$$,$APP.$cljs$cst$883$en$$);$properties$jscomp$inline_13296_schema$jscomp$inline_13292$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$inline_13296_schema$jscomp$inline_13292$$);
$JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$=$APP.$malli$error$_maybe_localized$$($APP.$cljs$cst$890$error_SLASH_path$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$inline_13296_schema$jscomp$inline_13292$$),$JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$);$JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$)?$JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$:$APP.$malli$error$_maybe_localized$$($APP.$cljs$cst$890$error_SLASH_path$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$inline_13296_schema$jscomp$inline_13292$$),$default_locale$jscomp$inline_13295_map__35282__$1$jscomp$inline_13293$$);
$JSCompiler_inline_result$jscomp$1658_JSCompiler_temp_const$jscomp$10988$$=$JSCompiler_inline_result$jscomp$1658_JSCompiler_temp_const$jscomp$10988$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$10987$$,$JSCompiler_inline_result$jscomp$10990_locale$jscomp$inline_13294_map__35281__$1$jscomp$inline_13291_or__5025__auto__$jscomp$inline_13297$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1657__$jscomp$766$$,[$JSCompiler_inline_result$jscomp$1658_JSCompiler_temp_const$jscomp$10988$$,
$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$($error$jscomp$22$$,$options$jscomp$392$$)],null)};
$malli$error$humanize$cljs$0core$0IFn$0_invoke$0arity$02$$=function($errors$jscomp$10_p__35509$$){var $map__35512__$1$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$10_p__35509$$),$value$jscomp$314$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35512__$1$$,$APP.$cljs$cst$260$value$$);$errors$jscomp$10_p__35509$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35512__$1$$,$APP.$cljs$cst$570$errors$$);var $map__35513__$1$$=$APP.$cljs$core$__destructure_map$$(null),$wrap$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35513__$1$$,$APP.$cljs$cst$896$wrap$$,$APP.$cljs$cst$141$message$$),$resolve$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35513__$1$$,$APP.$cljs$cst$898$resolve$$,$malli$error$_resolve_direct_error$$);return $APP.$cljs$core$truth_$$($errors$jscomp$10_p__35509$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$73$$,$G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$){var $message$jscomp$46_vec__35518$$=
$resolve$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$resolve$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($map__35512__$1$$,$G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$,$map__35513__$1$$):$resolve$jscomp$1$$($map__35512__$1$$,$G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$,$map__35513__$1$$),$path$jscomp$115$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$46_vec__35518$$,0,null);$message$jscomp$46_vec__35518$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$46_vec__35518$$,1,null);$G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$,$APP.$cljs$cst$141$message$$,$message$jscomp$46_vec__35518$$);$G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$=$wrap$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?
$wrap$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$):$wrap$jscomp$2$$($G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$);return $malli$error$_push_in$$($acc$jscomp$73$$,$value$jscomp$314$$,$path$jscomp$115$$,$G__35521$jscomp$inline_8400_JSCompiler_inline_result$jscomp$1659_error$jscomp$27$$)},null,$errors$jscomp$10_p__35509$$):null};
$app$common$schema$valid_QMARK_$$=function($s$jscomp$378$$,$value$jscomp$316$$){try{return $APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$378$$,$value$jscomp$316$$)}catch($e40097$$){return!1}};
$app$main$data$plugins$update_plugin_permissions_peek$$=function($map__66292__$1_p__66291_url$jscomp$87$$){$map__66292__$1_p__66291_url$jscomp$87$$=$APP.$cljs$core$__destructure_map$$($map__66292__$1_p__66291_url$jscomp$87$$);var $plugin_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66292__$1_p__66291_url$jscomp$87$$,$APP.$cljs$cst$1720$plugin_id$$);$map__66292__$1_p__66291_url$jscomp$87$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66292__$1_p__66291_url$jscomp$87$$,
$APP.$cljs$cst$1975$url$$);$APP.$cljs$core$truth_$$($map__66292__$1_p__66291_url$jscomp$87$$)&&$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($new_manifest$jscomp$1_permissions$jscomp$11$$){$new_manifest$jscomp$1_permissions$jscomp$11$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($new_manifest$jscomp$1_permissions$jscomp$11$$);return $APP.$cljs$core$truth_$$($new_manifest$jscomp$1_permissions$jscomp$11$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$plugins$save_plugin_permissions_peek$$($plugin_id$jscomp$12$$,
$new_manifest$jscomp$1_permissions$jscomp$11$$)):null},function(){return null},$APP.$app$main$data$plugins$fetch_manifest$$($map__66292__$1_p__66291_url$jscomp$87$$))};
$app$main$data$plugins$update_plugins_permissions_peek$$=function(){typeof $app$main$data$plugins$update_plugins_permissions_peek_66298$$==="undefined"&&($app$main$data$plugins$update_plugins_permissions_peek_66298$$=function($meta66299$$){this.$meta66299$=$meta66299$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$update_plugins_permissions_peek_66298$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$update_plugins_permissions_peek_66298$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3408$app_DOT_main_DOT_data_DOT_plugins_SLASH_update_plugins_permissions_peek$$},$app$main$data$plugins$update_plugins_permissions_peek_66298$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66300$$,$meta66299__$1$$){return new $app$main$data$plugins$update_plugins_permissions_peek_66298$$($meta66299__$1$$)},$app$main$data$plugins$update_plugins_permissions_peek_66298$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66299$},$app$main$data$plugins$update_plugins_permissions_peek_66298$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$update_plugins_permissions_peek_66298$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1794_now$jscomp$5$$,$state$jscomp$250$$){$_$jscomp$1794_now$jscomp$5$$=$APP.$app$common$time$now$$();var $c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$app$common$time$minus$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3409$days$$,1],null)),$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$250$$,$APP.$cljs$cst$2227$plugins_permissions_peek$$),$APP.$cljs$cst$3410$updated_at$$,0);if($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$>$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$){$c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$app$plugins$register$plugins_list$$();
$c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$cljs$core$seq$$($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$);$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$=null;for(var $G__66431_count__66320_66419$$=0,$G__66429_i__66321_66420$$=0;;)if($G__66429_i__66321_66420$$<$G__66431_count__66320_66419$$){var $plugin_66421$$=$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__66429_i__66321_66420$$);$app$main$data$plugins$update_plugin_permissions_peek$$($plugin_66421$$);$G__66429_i__66321_66420$$+=1}else if($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$cljs$core$seq$$($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$))$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$=$c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$)?($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$cljs$core$_chunked_first$$($G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$),$G__66429_i__66321_66420$$=$APP.$cljs$core$_chunked_rest$$($G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$),$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$=$c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$,
$G__66431_count__66320_66419$$=$APP.$cljs$core$count$$($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$),$c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$G__66429_i__66321_66420$$):($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$cljs$core$first$$($G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$),$app$main$data$plugins$update_plugin_permissions_peek$$($c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$),
$c__5548__auto___66428_expiration_plugin_66435_plugins_seq__66318_66417_temp__5825__auto___66426$$=$APP.$cljs$core$next$$($G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$),$G__66430_chunk__66319_66418_seq__66318_66427__$1_updated_at$$=null,$G__66431_count__66320_66419$$=0),$G__66429_i__66321_66420$$=0;else break;return $APP.$cljs$core$assoc_in$$($state$jscomp$250$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2227$plugins_permissions_peek$$,
$APP.$cljs$cst$3410$updated_at$$],null),$_$jscomp$1794_now$jscomp$5$$)}return $state$jscomp$250$$});return new $app$main$data$plugins$update_plugins_permissions_peek_66298$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$tokens_lib$export_dtcg_multi_file$$=function($tokens_lib$jscomp$2$$){var $active_themes$jscomp$6_vec__50083$$=$APP.$app$common$types$tokens_lib$dtcg_export_themes$$($tokens_lib$jscomp$2$$),$themes$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($active_themes$jscomp$6_vec__50083$$,0,null);$active_themes$jscomp$6_vec__50083$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($active_themes$jscomp$6_vec__50083$$,1,null);var $sets$jscomp$11$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($token_set$jscomp$6_tokens$jscomp$19$$){var $name$jscomp$223$$=$APP.$app$common$types$tokens_lib$get_name$$($token_set$jscomp$6_tokens$jscomp$19$$);$token_set$jscomp$6_tokens$jscomp$19$$=$APP.$app$common$types$tokens_lib$get_tokens_$$($token_set$jscomp$6_tokens$jscomp$19$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$223$$),
".json"].join(""),$APP.$app$common$types$tokens_lib$tokens_tree$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($token_set$jscomp$6_tokens$jscomp$19$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2103$update_token_fn$$,$APP.$app$common$types$tokens_lib$token__GT_dtcg_token$$]))],null)},$APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$2$$)));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($sets$jscomp$11$$,
"$themes.json",$themes$jscomp$6$$),"$metadata.json",new $APP.$cljs$core$PersistentArrayMap$$(null,3,["tokenSetOrder",$app$common$types$tokens_lib$get_set_names$$($tokens_lib$jscomp$2$$),"activeThemes",$active_themes$jscomp$6_vec__50083$$,"activeSets",$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$2$$)],null))};
$app$main$data$workspace$colors$add_recent_color$$=function($color$jscomp$93_color__$1$jscomp$12$$){$color$jscomp$93_color__$1$jscomp$12$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$93_color__$1$jscomp$12$$);typeof $app$main$data$workspace$colors$add_recent_color_70884$$==="undefined"&&($app$main$data$workspace$colors$add_recent_color_70884$$=function($color$jscomp$94$$,$meta70885$$){this.color=$color$jscomp$94$$;this.$meta70885$=$meta70885$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4166$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_recent_color$$},$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70886$$,$meta70885__$1$$){return new $app$main$data$workspace$colors$add_recent_color_70884$$(this.color,$meta70885__$1$$)},$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70885$},$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2255_file_id$jscomp$207$$,$state$jscomp$643$$){var $self__$jscomp$5261$$=this;$_$jscomp$2255_file_id$jscomp$207$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$643$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$643$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2213$recent_colors$$,$_$jscomp$2255_file_id$jscomp$207$$],null),function($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$){$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$=
$APP.$app$common$data$removev$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$colors$recent_color_equal_QMARK_$$,$self__$jscomp$5261$$.color),$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$);$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$,$self__$jscomp$5261$$.color);return $APP.$cljs$core$count$$($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$)>
15?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$,1):$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$})},$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_recent_color_70884$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2256_recent_colors$$,$state$jscomp$644$$){$_$jscomp$2256_recent_colors$$=
$APP.$cljs$cst$2213$recent_colors$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$644$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2213$recent_colors$$,$_$jscomp$2256_recent_colors$$)});return new $app$main$data$workspace$colors$add_recent_color_70884$$($color$jscomp$93_color__$1$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker_color$$=function($changes$jscomp$225$$,$add_recent_QMARK_$$){typeof $app$main$data$workspace$colors$update_colorpicker_color_71008$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_color_71008$$=function($changes$jscomp$226$$,$add_recent_QMARK_$jscomp$1$$,$meta71009$$){this.$changes$=$changes$jscomp$226$$;this.$add_recent_QMARK_$=$add_recent_QMARK_$jscomp$1$$;this.$meta71009$=$meta71009$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4173$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_color$$},$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71010$$,$meta71009__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_color_71008$$(this.$changes$,this.$add_recent_QMARK_$,$meta71009__$1$$)},$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71009$},$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2269$$,$state$jscomp$656$$){var $self__$jscomp$5311$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$656$$,$APP.$cljs$cst$2239$colorpicker$$,function($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$){var $type$jscomp$491$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$);$G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$,
$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$merge$$,$self__$jscomp$5311$$.$changes$),$APP.$cljs$cst$4164$current_color$$,$app$main$data$workspace$colors$materialize_color_components$$),$APP.$cljs$cst$4164$current_color$$,function($p1__71007_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$491$$,$APP.$cljs$cst$1612$image$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__71007_SHARP_$$,$APP.$cljs$cst$1612$image$$):$p1__71007_SHARP_$$}),$APP.$cljs$cst$4164$current_color$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$cst$1736$ref_file$$);var $temp__5823__auto__$jscomp$184$$=$APP.$cljs$cst$4162$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$184$$))return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1733$stops$$,$temp__5823__auto__$jscomp$184$$],null),function($data$jscomp$386$$){return $app$main$data$workspace$colors$materialize_color_components$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$data$jscomp$386$$,$self__$jscomp$5311$$.$changes$])))});$G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$,
$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1733$stops$$,$APP.$cljs$cst$4162$editing_stop$$]));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1612$image$$,$type$jscomp$491$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1298$color$$):$G__71017_state__$1$jscomp$38_state__$2$jscomp$3$$})},$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_color_71008$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$,$ignore_color_QMARK__state$jscomp$657_type$jscomp$492$$){$_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$=$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($APP.$cljs$cst$2239$colorpicker$$.$cljs$core$IFn$_invoke$arity$1$($ignore_color_QMARK__state$jscomp$657_type$jscomp$492$$));
$ignore_color_QMARK__state$jscomp$657_type$jscomp$492$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$,$APP.$cljs$cst$139$type$$);$ignore_color_QMARK__state$jscomp$657_type$jscomp$492$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ignore_color_QMARK__state$jscomp$657_type$jscomp$492$$,$APP.$cljs$cst$1298$color$$)&&$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$)==
null;var $and__5023__auto__$jscomp$inline_8402$$=this.$add_recent_QMARK_$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8402$$)?!$ignore_color_QMARK__state$jscomp$657_type$jscomp$492$$:$and__5023__auto__$jscomp$inline_8402$$)?($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$select_keys$$($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1734$opacity$$],null))),$APP.$cljs$core$truth_$$($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$colors$add_recent_color$$($_$jscomp$2270_state__$1$jscomp$39_temp__5825__auto__$jscomp$216$$)):null):null});return new $app$main$data$workspace$colors$update_colorpicker_color_71008$$($changes$jscomp$225$$,
$add_recent_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$activate_colorpicker_color$$=function(){typeof $app$main$data$workspace$colors$activate_colorpicker_color_71026$$==="undefined"&&($app$main$data$workspace$colors$activate_colorpicker_color_71026$$=function($meta71027$$){this.$meta71027$=$meta71027$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4183$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_color$$},$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71028$$,$meta71027__$1$$){return new $app$main$data$workspace$colors$activate_colorpicker_color_71026$$($meta71027__$1$$)},$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71027$},$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2273$$,$state$jscomp$660$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$660$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$41$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$41$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1298$color$$),$APP.$cljs$cst$4162$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1733$stops$$,$APP.$cljs$cst$1724$gradient$$]))})},$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_color_71026$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$colors$update_colorpicker_color$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
!1))});return new $app$main$data$workspace$colors$activate_colorpicker_color_71026$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$apply_color_from_colorpicker$$=function($color$jscomp$91_color__$1$jscomp$11$$){$color$jscomp$91_color__$1$jscomp$11$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$91_color__$1$jscomp$11$$);typeof $app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$==="undefined"&&($app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$=function($color$jscomp$92$$,$meta70861$$){this.color=$color$jscomp$92$$;this.$meta70861$=$meta70861$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4161$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_colorpicker$$},$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70862$$,$meta70861__$1$$){return new $app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$(this.color,$meta70861__$1$$)},$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70861$},$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2254$$,$state$jscomp$642$$){var $self__$jscomp$5257$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$642$$,$APP.$cljs$cst$2239$colorpicker$$,function($state__$1$jscomp$29$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5257$$.color)))return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1612$image$$),$APP.$cljs$cst$4162$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1733$stops$$,$APP.$cljs$cst$1724$gradient$$]));if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5257$$.color)))return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1298$color$$),
$APP.$cljs$cst$4162$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1733$stops$$,$APP.$cljs$cst$1724$gradient$$]));var $gradient_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5257$$.color,$APP.$cljs$cst$1724$gradient$$),$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$287$linear$$,$gradient_type$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$4163$linear_gradient$$),$APP.$cljs$cst$4162$editing_stop$$,0),$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1612$image$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1728$radial$$,$gradient_type$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$4165$radial_gradient$$),$APP.$cljs$cst$4162$editing_stop$$,0),$APP.$cljs$cst$4164$current_color$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1612$image$$):null})});return new $app$main$data$workspace$colors$apply_color_from_colorpicker_70860$$($color$jscomp$91_color__$1$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$start_path_from_point$$=function($position$jscomp$135$$){typeof $app$main$data$workspace$path$drawing$start_path_from_point_69865$$==="undefined"&&($app$main$data$workspace$path$drawing$start_path_from_point_69865$$=function($position$jscomp$136$$,$meta69866$$){this.position=$position$jscomp$136$$;this.$meta69866$=$meta69866$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$start_path_from_point_69865$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_path_from_point_69865$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4221$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_path_from_point$$},$app$main$data$workspace$path$drawing$start_path_from_point_69865$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69867$$,$meta69866__$1$$){return new $app$main$data$workspace$path$drawing$start_path_from_point_69865$$(this.position,
$meta69866__$1$$)},$app$main$data$workspace$path$drawing$start_path_from_point_69865$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69866$},$app$main$data$workspace$path$drawing$start_path_from_point_69865$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_path_from_point_69865$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2302_stopper$jscomp$24$$,$drag_events_state$jscomp$693$$,
$stream$jscomp$70$$){$_$jscomp$2302_stopper$jscomp$24$$=$APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$70$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$,$stream$jscomp$70$$));$drag_events_state$jscomp$693$$=$APP.$beicon$v2$core$take_until$$($_$jscomp$2302_stopper$jscomp$24$$,$APP.$beicon$v2$core$map$$(function($p1__69864_SHARP_$$){return $APP.$app$main$data$workspace$path$drawing$drag_handler$cljs$0core$0IFn$0_invoke$0arity$04$$(null,
null,$APP.$cljs$cst$1821$c1$$,$p1__69864_SHARP_$$)},$APP.$app$main$data$workspace$path$streams$position_stream$$($drag_events_state$jscomp$693$$)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$add_node$$(this.position)),$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$($drag_events_state$jscomp$693$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$finish_drag$$()))))});
return new $app$main$data$workspace$path$drawing$start_path_from_point_69865$$($position$jscomp$135$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$close_path_drag_start$$=function($position$jscomp$133$$){typeof $app$main$data$workspace$path$drawing$close_path_drag_start_69836$$==="undefined"&&($app$main$data$workspace$path$drawing$close_path_drag_start_69836$$=function($position$jscomp$134$$,$meta69837$$){this.position=$position$jscomp$134$$;this.$meta69837$=$meta69837$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4219$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_start$$},$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69838$$,$meta69837__$1$$){return new $app$main$data$workspace$path$drawing$close_path_drag_start_69836$$(this.position,
$meta69837__$1$$)},$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69837$},$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$close_path_drag_start_69836$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$,$drag_events_stream_state$jscomp$691$$,
$stream$jscomp$69$$){var $self__$jscomp$5414$$=this;$_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($drag_events_stream_state$jscomp$691$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$get_handlers$$($_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$),
$self__$jscomp$5414$$.position);$_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$),1)?$APP.$cljs$core$first$$($_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$):null;var $idx$jscomp$95$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$,0,null),$prefix$jscomp$51$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2300_content$jscomp$203_handlers$jscomp$5_vec__69842$$,1,null);$drag_events_stream_state$jscomp$691$$=$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$69$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$,$stream$jscomp$69$$)),$APP.$beicon$v2$core$map$$(function($p1__69831_SHARP_$$){return $APP.$app$main$data$workspace$path$drawing$drag_handler$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$5414$$.position,
$idx$jscomp$95$$,$prefix$jscomp$51$$,$p1__69831_SHARP_$$)},$APP.$app$main$data$workspace$path$streams$position_stream$$($drag_events_stream_state$jscomp$691$$)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$add_node$$($self__$jscomp$5414$$.position)),$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$($drag_events_stream_state$jscomp$691$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$finish_drag$$()),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$close_path_drag_end$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$path$drawing$close_path_drag_end$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$path$drawing$close_path_drag_end$$()))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$common$finish_path$$()))});return new $app$main$data$workspace$path$drawing$close_path_drag_start_69836$$($position$jscomp$133$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$schema$validation_errors$$=function($JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$,$_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$){$_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$=$APP.$app$common$schema$schema$$($_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$);$_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$=$APP.$malli$core$explainer$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$,
null);$JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$=$_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$?$_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$):$_QMARK_schema$jscomp$inline_13299_explainer$jscomp$13_schema$jscomp$203$$($JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$);
$JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$=$malli$error$humanize$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$);return $APP.$cljs$core$not_empty$$($JSCompiler_inline_result$jscomp$1660_exp$jscomp$inline_8404_value$jscomp$319$$)};
$app$common$files$tokens$make_node_token_name_schema$$=function($active_tokens$jscomp$1$$,$tokens_tree$jscomp$2$$,$node$jscomp$339$$){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71669_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71669_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$token$schema_COLON_token_node_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71670_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71670_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-validation-error"))].join("")}])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71671_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.token-name-duplication-validation-error",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71671_SHARP_$$)]))}],null),function($name$jscomp$364_new_tokens$$){var $and__5023__auto__$jscomp$539_current_path$jscomp$2$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$339$$),$current_name$jscomp$1$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$339$$);$name$jscomp$364_new_tokens$$=$app$common$types$tokens_lib$update_tokens_group$$($active_tokens$jscomp$1$$,$and__5023__auto__$jscomp$539_current_path$jscomp$2$$,$current_name$jscomp$1$$,$name$jscomp$364_new_tokens$$);return($and__5023__auto__$jscomp$539_current_path$jscomp$2$$=$name$jscomp$364_new_tokens$$!=null)?$APP.$cljs$core$some$$(function($p__71680$$){var $token_name$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71680$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71680$$,1,null);return!$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$($token_name$jscomp$8$$,$tokens_tree$jscomp$2$$)},$name$jscomp$364_new_tokens$$):$and__5023__auto__$jscomp$539_current_path$jscomp$2$$}],null)],null)};
$app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$=function($s$jscomp$385_s__$1$jscomp$12$$,$k$jscomp$446$$,$v$jscomp$224_v__$1$jscomp$13$$){var $opts$jscomp$220$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$s$jscomp$385_s__$1$jscomp$12$$=$APP.$app$common$schema$schema$$($s$jscomp$385_s__$1$jscomp$12$$);$v$jscomp$224_v__$1$jscomp$13$$=$APP.$app$common$schema$schema$$($v$jscomp$224_v__$1$jscomp$13$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$385_s__$1$jscomp$12$$),
$APP.$cljs$cst$202$map$$))return $APP.$malli$util$assoc$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$385_s__$1$jscomp$12$$,$k$jscomp$446$$,$v$jscomp$224_v__$1$jscomp$13$$,$opts$jscomp$220$$);var $temp__5823__auto__$jscomp$75$$=$APP.$malli$util$find_first$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$385_s__$1$jscomp$12$$,function($s_SINGLEQUOTE_$$,$path$jscomp$117$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s_SINGLEQUOTE_$$),
$APP.$cljs$cst$202$map$$)?$path$jscomp$117$$:null});return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$75$$)?$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$385_s__$1$jscomp$12$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$75$$,$k$jscomp$446$$),$v$jscomp$224_v__$1$jscomp$13$$,$opts$jscomp$220$$):$s$jscomp$385_s__$1$jscomp$12$$};
$app$common$types$tokens_lib$walk_sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($nodes$jscomp$29$$,$map__49793__$1_p__49792$$){$map__49793__$1_p__49792$$=$APP.$cljs$core$__destructure_map$$($map__49793__$1_p__49792$$);var $skip_children_pred$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49793__$1_p__49792$$,$APP.$cljs$cst$2113$skip_children_pred$$,$APP.$cljs$core$constantly$$(!1)),$new_editing_set_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49793__$1_p__49792$$,
$APP.$cljs$cst$2114$new_editing_set_path$$);return function $app$common$types$tokens_lib$walk$$($node$jscomp$247$$,$p__49796$$){var $map__49797__$1$$=$APP.$cljs$core$__destructure_map$$($p__49796$$),$parent$jscomp$191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49797__$1$$,$APP.$cljs$cst$1365$parent$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$depth$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49797__$1$$,$APP.$cljs$cst$839$depth$$,0);return new $APP.$cljs$core$LazySeq$$(null,
function(){if($APP.$app$common$data$ordered_map_QMARK_$$($node$jscomp$247$$)){var $root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$new_editing_set_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$247$$,$APP.$cljs$cst$2115$new_QMARK_$$,!0):$node$jscomp$247$$;return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49785_SHARP_$$){return $app$common$types$tokens_lib$walk$$($p1__49785_SHARP_$$,
$map__49797__$1$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$]))}var $item$jscomp$51_k$jscomp$599_unprefixed_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$247$$,0,null);$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$247$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2115$new_QMARK_$$,
$item$jscomp$51_k$jscomp$599_unprefixed_path$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2115$new_QMARK_$$,!0,$APP.$cljs$cst$2116$group_QMARK_$$,!1,$APP.$cljs$cst$2117$parent_path$$,$parent$jscomp$191$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$13$$],null)],null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$)?$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$ instanceof
$APP.$app$common$types$tokens_lib$TokenSet$$:$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2116$group_QMARK_$$,!1,$APP.$cljs$cst$296$path$$,$APP.$app$common$types$tokens_lib$split_set_name$$($APP.$app$common$types$tokens_lib$get_name$$($root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$)),$APP.$cljs$cst$2117$parent_path$$,
$parent$jscomp$191$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$13$$,$APP.$cljs$cst$203$set$$,$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$],null)],null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$)?$APP.$app$common$data$ordered_map_QMARK_$$($root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$):$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$)){$item$jscomp$51_k$jscomp$599_unprefixed_path$$=$APP.$cljs$core$last$$($app$common$types$tokens_lib$split_set_str_path_prefix$$($item$jscomp$51_k$jscomp$599_unprefixed_path$$));
var $path$jscomp$175$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$191$$,$item$jscomp$51_k$jscomp$599_unprefixed_path$$);$item$jscomp$51_k$jscomp$599_unprefixed_path$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2116$group_QMARK_$$,!0,$APP.$cljs$cst$296$path$$,$path$jscomp$175$$,$APP.$cljs$cst$2117$parent_path$$,$parent$jscomp$191$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$13$$],null);if($APP.$cljs$core$truth_$$($skip_children_pred$$.$cljs$core$IFn$_invoke$arity$1$?
$skip_children_pred$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$175$$):$skip_children_pred$$($path$jscomp$175$$)))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$51_k$jscomp$599_unprefixed_path$$],null);$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$175$$,$new_editing_set_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$,
$APP.$cljs$cst$2115$new_QMARK_$$,!0):$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$;return $APP.$cljs$core$cons$$($item$jscomp$51_k$jscomp$599_unprefixed_path$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49786_SHARP_$$){return $app$common$types$tokens_lib$walk$$($p1__49786_SHARP_$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__49797__$1$$,$APP.$cljs$cst$1365$parent$$,$path$jscomp$175$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$839$depth$$,
$depth$jscomp$13$$+1])))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$root$jscomp$34_v$jscomp$534_v_SINGLEQUOTE_$jscomp$3$$])))}return null},null,null)}($APP.$cljs$core$truth_$$($nodes$jscomp$29$$)?$nodes$jscomp$29$$:$APP.$linked$map$empty_linked_map$$,null)};
$app$common$logic$tokens$calculate_move_token_set_or_set_group$$=function($tokens_lib$jscomp$23$$,$map__71915__$1_p__71914_prev_before$$){$map__71915__$1_p__71914_prev_before$$=$APP.$cljs$core$__destructure_map$$($map__71915__$1_p__71914_prev_before$$);var $from_index$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71915__$1_p__71914_prev_before$$,$APP.$cljs$cst$4676$from_index$$),$to_index$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71915__$1_p__71914_prev_before$$,
$APP.$cljs$cst$4677$to_index$$),$position$jscomp$167$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71915__$1_p__71914_prev_before$$,$APP.$cljs$cst$1676$position$$),$collapsed_paths$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__71915__$1_p__71914_prev_before$$,$APP.$cljs$cst$4678$collapsed_paths$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$tree$jscomp$19$$=$app$common$types$tokens_lib$walk_sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$get_set_tree$$($tokens_lib$jscomp$23$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2113$skip_children_pred$$,function($p1__71913_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($collapsed_paths$$,$p1__71913_SHARP_$$)}])),$from$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tree$jscomp$19$$,$from_index$jscomp$9$$),$to$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tree$jscomp$19$$,$to_index$jscomp$15$$),$G__71921__$1_before$jscomp$5$$=function(){var $G__71916__$1$$=
$position$jscomp$167$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$167$$.$fqn$:null;switch($G__71916__$1$$){case "top":return $to$jscomp$24$$;case "bot":return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tree$jscomp$19$$,$to_index$jscomp$15$$+1,null);case "center":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71916__$1$$)].join(""));}}();$map__71915__$1_p__71914_prev_before$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2116$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$))?
$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($element$jscomp$74$$){return $APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$74$$)<=$APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$)},$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($from_index$jscomp$9$$+1,$tree$jscomp$19$$))):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tree$jscomp$19$$,$from_index$jscomp$9$$+1,null);var $G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$=
function(){var $and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$center$$,$position$jscomp$167$$);return $and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$?$and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$:($and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2952$bot$$,
$position$jscomp$167$$))?($and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$=$APP.$cljs$cst$2116$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$)?$APP.$cljs$core$not$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_paths$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$))):$and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$):
$and__5023__auto__$jscomp$557_and__5023__auto____$1$jscomp$98_or__5025__auto__$jscomp$891$$}(),$from_path$jscomp$10$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$),$to_parent_path$$=$APP.$cljs$core$truth_$$($G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$)?$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$butlast$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$))),
$to_path$jscomp$10$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($to_parent_path$$,$APP.$cljs$core$last$$($from_path$jscomp$10$$));$G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$=function(){var $and__5023__auto__$jscomp$558_or__5025__auto__$jscomp$892$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_index$jscomp$9$$,$to_index$jscomp$15$$);if(!$and__5023__auto__$jscomp$558_or__5025__auto__$jscomp$892$$&&($and__5023__auto__$jscomp$558_or__5025__auto__$jscomp$892$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_path$jscomp$10$$,$to_path$jscomp$10$$)))switch($position$jscomp$167$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$167$$.$fqn$:null){case "top":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_index$jscomp$9$$,$to_index$jscomp$15$$-1);case "bot":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_index$jscomp$9$$,$to_index$jscomp$15$$);default:return null}else return $and__5023__auto__$jscomp$558_or__5025__auto__$jscomp$892$$}();
var $to_exists_QMARK_$$=function(){var $and__5023__auto__$jscomp$559$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2117$parent_path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$),$to_parent_path$$);return $and__5023__auto__$jscomp$559$$?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2116$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$))?$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$($tokens_lib$jscomp$23$$,$to_path$jscomp$10$$):$app$common$types$tokens_lib$set_path_exists_QMARK_$$($tokens_lib$jscomp$23$$,
$to_path$jscomp$10$$):$and__5023__auto__$jscomp$559$$}(),$parent_to_child_drop_QMARK_$$=function(){var $JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2117$parent_path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$),$to_parent_path$$);if($JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$){$JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$=
$APP.$cljs$cst$2116$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$)){$JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$);var $JSCompiler_temp_const$jscomp$inline_13303$$=$APP.$cljs$core$_EQ_$$,$JSCompiler_temp_const$jscomp$inline_13304$$=
$JSCompiler_temp_const$jscomp$inline_13303$$.$cljs$core$IFn$_invoke$arity$2$,$x__5113__auto__$jscomp$inline_13306$$=$APP.$cljs$core$count$$($to_path$jscomp$10$$),$y__5114__auto__$jscomp$inline_13307$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$);$JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$=$JSCompiler_temp_const$jscomp$inline_13304$$.call($JSCompiler_temp_const$jscomp$inline_13303$$,
$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($to_path$jscomp$10$$,0,$x__5113__auto__$jscomp$inline_13306$$<$y__5114__auto__$jscomp$inline_13307$$?$x__5113__auto__$jscomp$inline_13306$$:$y__5114__auto__$jscomp$inline_13307$$),$JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$)}return $JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$}return $JSCompiler_temp$jscomp$10972_and__5023__auto__$jscomp$560_and__5023__auto____$1$jscomp$99_v2$jscomp$inline_13302$$}();
if($APP.$cljs$core$truth_$$($G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$))return null;if($APP.$cljs$core$truth_$$($to_exists_QMARK_$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("move token set error: path exists",new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$4679$path_exists$$,$APP.$cljs$cst$296$path$$,$to_path$jscomp$10$$],null));if($APP.$cljs$core$truth_$$($parent_to_child_drop_QMARK_$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("move token set error: parent-to-child",
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$4680$parent_to_child$$,$APP.$cljs$cst$2654$from_path$$,$from_path$jscomp$10$$,$APP.$cljs$cst$2655$to_path$$,$to_path$jscomp$10$$],null));$G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2654$from_path$$,$from_path$jscomp$10$$,$APP.$cljs$cst$2655$to_path$$,$to_path$jscomp$10$$,$APP.$cljs$cst$2656$before_path$$,null,$APP.$cljs$cst$3180$before_group_QMARK_$$,
null],null);$G__71921__$1_before$jscomp$5$$=$APP.$cljs$core$truth_$$($G__71921__$1_before$jscomp$5$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$,$APP.$cljs$cst$2656$before_path$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($G__71921__$1_before$jscomp$5$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3180$before_group_QMARK_$$,$APP.$cljs$cst$2116$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__71921__$1_before$jscomp$5$$)])):
$G__71921_drop_as_direct_group_child_QMARK__identical_QMARK_$$;return $APP.$cljs$core$truth_$$($map__71915__$1_p__71914_prev_before$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71921__$1_before$jscomp$5$$,$APP.$cljs$cst$3181$prev_before_path$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($map__71915__$1_p__71914_prev_before$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3182$prev_before_group_QMARK_$$,$APP.$cljs$cst$2116$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__71915__$1_p__71914_prev_before$$)])):
$G__71921__$1_before$jscomp$5$$};
$app$common$types$tokens_lib$sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($tree$jscomp$6_tree__$1$$,$map__49820__$1_p__49819$$){$map__49820__$1_p__49819$$=$APP.$cljs$core$__destructure_map$$($map__49820__$1_p__49819$$);var $skip_children_pred$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49820__$1_p__49819$$,$APP.$cljs$cst$2113$skip_children_pred$$,$APP.$cljs$core$constantly$$(!1)),$new_at_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49820__$1_p__49819$$,$APP.$cljs$cst$2118$new_at_path$$),
$walk$jscomp$2$$=function $app$common$types$tokens_lib$walk$jscomp$1$$($p__49827$$,$parent_path$jscomp$3$$,$depth$jscomp$14$$){var $k$jscomp$600$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49827$$,0,null),$v$jscomp$535$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49827$$,1,null);return new $APP.$cljs$core$LazySeq$$(null,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2119$is_new$$,$k$jscomp$600$$)){var $item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$=
$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$APP.$cljs$core$empty_QMARK_$$($parent_path$jscomp$3$$)?"":$APP.$app$common$types$tokens_lib$join_set_path$$($parent_path$jscomp$3$$)]));return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2119$is_new$$,!0,
$APP.$cljs$cst$2120$is_group$$,!1,$APP.$cljs$cst$296$path$$,$APP.$app$common$types$tokens_lib$split_set_name$$($item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$.name),$APP.$cljs$cst$839$depth$$,$depth$jscomp$14$$,$APP.$cljs$cst$266$id$$,$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$.id,$APP.$cljs$cst$2121$token_set$$,$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$],null)],null)}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($v$jscomp$535$$)?$v$jscomp$535$$ instanceof
$APP.$app$common$types$tokens_lib$TokenSet$$:$v$jscomp$535$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2120$is_group$$,!1,$APP.$cljs$cst$296$path$$,$APP.$app$common$types$tokens_lib$split_set_name$$($APP.$app$common$types$tokens_lib$get_name$$($v$jscomp$535$$)),$APP.$cljs$cst$839$depth$$,$depth$jscomp$14$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$types$tokens_lib$get_id$$($v$jscomp$535$$),
$APP.$cljs$cst$2121$token_set$$,$v$jscomp$535$$],null)],null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($v$jscomp$535$$)?$APP.$app$common$data$ordered_map_QMARK_$$($v$jscomp$535$$):$v$jscomp$535$$)){$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$=$APP.$cljs$core$last$$($app$common$types$tokens_lib$split_set_str_path_prefix$$($k$jscomp$600$$));var $path$jscomp$176$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent_path$jscomp$3$$,$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$);
$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2120$is_group$$,!0,$APP.$cljs$cst$296$path$$,$path$jscomp$176$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$14$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$types$tokens_lib$join_set_path$$($path$jscomp$176$$)],null);if($APP.$cljs$core$truth_$$($skip_children_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$skip_children_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$176$$):
$skip_children_pred$jscomp$1$$($path$jscomp$176$$)))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$],null);var $v__$1$jscomp$27$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$176$$,$new_at_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$535$$,$APP.$cljs$cst$2119$is_new$$,!0):$v$jscomp$535$$;return $APP.$cljs$core$cons$$($item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49806_SHARP_$$){return $app$common$types$tokens_lib$walk$jscomp$1$$($p1__49806_SHARP_$$,$path$jscomp$176$$,$depth$jscomp$14$$+1)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v__$1$jscomp$27$$])))}return null},null,null)};$tree$jscomp$6_tree__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$new_at_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($tree$jscomp$6_tree__$1$$,
$APP.$cljs$cst$2119$is_new$$,!0):$tree$jscomp$6_tree__$1$$;return $APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$207$$,$item$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$53$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$207$$)},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49808_SHARP_$$){return $walk$jscomp$2$$($p1__49808_SHARP_$$,$APP.$cljs$core$PersistentVector$EMPTY$$,0)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tree$jscomp$6_tree__$1$$])))};
$app$common$types$tokens_lib$parse_single_set_dtcg_json$$=function($set_name$jscomp$25_set_name__$1$$,$decoded_json_tokens$jscomp$1_tokens$jscomp$16$$){$set_name$jscomp$25_set_name__$1$$=$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$($set_name$jscomp$25_set_name__$1$$);$decoded_json_tokens$jscomp$1_tokens$jscomp$16$$=$APP.$app$common$types$tokens_lib$flatten_nested_tokens_json$$($decoded_json_tokens$jscomp$1_tokens$jscomp$16$$,"");if($APP.$cljs$core$empty_QMARK_$$($decoded_json_tokens$jscomp$1_tokens$jscomp$16$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("the file doesn't contain any tokens",
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$2134$error_DOT_import_SLASH_invalid_json_data$$],null));return $APP.$app$common$types$tokens_lib$make_tokens_lib$$().$app$common$types$tokens_lib$ITokenSets$add_set$arity$2$(null,$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$set_name$jscomp$25_set_name__$1$$,$APP.$cljs$cst$2100$tokens$$,
$decoded_json_tokens$jscomp$1_tokens$jscomp$16$$])))};
$app$common$logic$libraries$add_shape_to_main$$=function($changes$jscomp$124_changes_SINGLEQUOTE_$jscomp$2$$,$shape$jscomp$420$$,$index$jscomp$257$$,$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$,$component_container$jscomp$3$$,$page$jscomp$55$$,$root_instance$jscomp$1$$,$root_main$jscomp$5$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$420$$),$page$jscomp$55$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["ADD [C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_container$jscomp$3$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$420$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$420$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $parent_shape$jscomp$2$$=$APP.$app$common$types$container$get_shape$$($page$jscomp$55$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$420$$)),$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__66680_SHARP_$$){return $APP.$app$common$types$component$is_main_of_QMARK_$$($p1__66680_SHARP_$$,
$parent_shape$jscomp$2$$)},$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_container$jscomp$3$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_main$jscomp$5$$))),$all_parents$jscomp$5$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)],
null),$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_container$jscomp$3$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$))),$updated_shapes$jscomp$4_vec__66681$$=$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$420$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$55$$,$APP.$cljs$cst$1631$objects$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2089$update_new_shape$$,function($new_shape$jscomp$9$$){return $APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$($new_shape$jscomp$9$$,$root_instance$jscomp$1$$,$root_main$jscomp$5$$):$APP.$app$common$logic$libraries$reposition_shape$$($new_shape$jscomp$9$$,
$root_instance$jscomp$1$$,$root_main$jscomp$5$$)},$APP.$cljs$cst$2090$update_original_shape$$,function($original_shape$jscomp$4$$,$new_shape$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($original_shape$jscomp$4$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$10$$))},$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)?
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)]));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($updated_shapes$jscomp$4_vec__66681$$,0,null);$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($updated_shapes$jscomp$4_vec__66681$$,
1,null);$updated_shapes$jscomp$4_vec__66681$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($updated_shapes$jscomp$4_vec__66681$$,2,null);$changes$jscomp$124_changes_SINGLEQUOTE_$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$37$$,$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$){var $JSCompiler_temp_const$jscomp$10992$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$;$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2610$add_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$),$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$),$APP.$cljs$cst$1607$frame_id$$,
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$),$APP.$cljs$cst$1795$index$$,$index$jscomp$257$$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2611$obj$$,$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$],null);$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$=$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($component_container$jscomp$3$$,$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$):$APP.$app$common$logic$libraries$make_change$$($component_container$jscomp$3$$,$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$);return $JSCompiler_temp_const$jscomp$10992$$.call($APP.$cljs$core$update$$,$changes__$1$jscomp$37$$,$APP.$cljs$cst$3133$redo_changes$$,
$APP.$cljs$core$conj$$,$G__66686$jscomp$inline_13310_JSCompiler_inline_result$jscomp$10994_shape_SINGLEQUOTE_$jscomp$6$$)},$changes$jscomp$124_changes_SINGLEQUOTE_$jscomp$2$$,$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$);$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$124_changes_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2624$reg_objects$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$),$APP.$cljs$cst$1614$shapes$$,$all_parents$jscomp$5$$],null));$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$38$$,
$shape_SINGLEQUOTE_$jscomp$7$$){var $shape_original$$=$APP.$app$common$types$container$get_shape$$($page$jscomp$55$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes__$1$jscomp$38$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,
$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$55$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1627$component_id$$,
$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$2044$component_root$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$7$$)],null)],null)],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$55$$),
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$2044$component_root$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],
null)],null)],null))},$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$,$updated_shapes$jscomp$4_vec__66681$$);$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$39$$,$shape_SINGLEQUOTE_$jscomp$8$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes__$1$jscomp$39$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2614$del_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$),$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$55$$),$APP.$cljs$cst$2556$ignore_touched$$,!0],null))},$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$,$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$);
return $APP.$app$common$files$changes_builder$apply_changes_local$$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)};
$app$common$logic$tokens$generate_toggle_token_set_group$$=function($changes$jscomp$288$$,$tokens_lib$jscomp$22$$,$group_path$jscomp$8$$){return $APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$288$$,$tokens_lib$jscomp$22$$,function($p1__71912_SHARP_$$){return $app$common$logic$tokens$toggle_token_set_group$$($group_path$jscomp$8$$,$tokens_lib$jscomp$22$$,$p1__71912_SHARP_$$)})};
$app$common$logic$tokens$generate_delete_token_set_group$$=function($changes$jscomp$291$$,$sets$jscomp$13_tokens_lib$jscomp$26$$,$path$jscomp$245$$){$sets$jscomp$13_tokens_lib$jscomp$26$$=$app$common$types$tokens_lib$get_sets_at_path$$($sets$jscomp$13_tokens_lib$jscomp$26$$,$path$jscomp$245$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$86$$,$set$jscomp$15$$){return $APP.$app$common$files$changes_builder$set_token_set$$($changes__$1$jscomp$86$$,
$APP.$app$common$types$tokens_lib$get_id$$($set$jscomp$15$$),null)},$changes$jscomp$291$$,$sets$jscomp$13_tokens_lib$jscomp$26$$)};
$app$common$logic$libraries$update_grid_main_attrs$$=function($changes$jscomp$139$$,$new_changes$jscomp$3_shape_main$jscomp$11$$,$shape_copy$jscomp$3$$,$main_container$jscomp$3$$,$copy_container$jscomp$2$$){var $ids_map$jscomp$12$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__66928_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($main_container$jscomp$3$$,$APP.$cljs$cst$1631$objects$$),
$p1__66928_SHARP_$$)}),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($main_shape$jscomp$2$$){var $copy_shape$jscomp$1$$=$app$common$types$file$get_shape_in_copy$$($copy_container$jscomp$2$$,$main_shape$jscomp$2$$,$shape_copy$jscomp$3$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($copy_shape$jscomp$1$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_shape$jscomp$2$$)],
null)})),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$3_shape_main$jscomp$11$$));$new_changes$jscomp$3_shape_main$jscomp$11$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$main_container$jscomp$3$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_container$jscomp$3$$)),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$3_shape_main$jscomp$11$$)],null),function($shape_main__$1$jscomp$1$$){var $new_cells$$=$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$shape$layout$remap_grid_cells$$($shape_copy$jscomp$3$$,$ids_map$jscomp$12$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape_main__$1$jscomp$1$$,
$APP.$cljs$cst$1696$layout_grid_cells$$,$new_cells$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null));return $APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$139$$,$new_changes$jscomp$3_shape_main$jscomp$11$$)};
$app$common$logic$libraries$update_flex_child_main_attrs$$=function($changes$jscomp$137$$,$new_changes$jscomp$2_shape_main$jscomp$9$$,$shape_copy$jscomp$1$$,$main_container$jscomp$1$$,$copy_container$jscomp$1$$,$omit_touched_QMARK_$jscomp$10$$){$new_changes$jscomp$2_shape_main$jscomp$9$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$main_container$jscomp$1$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_container$jscomp$1$$)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$2_shape_main$jscomp$9$$)],null),function($G__66915__$1_shape_main__$1$$){$G__66915__$1_shape_main__$1$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape_copy$jscomp$1$$))?$APP.$app$common$logic$libraries$propagate_attrs$$($G__66915__$1_shape_main__$1$$,$shape_copy$jscomp$1$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,null],null),null),$omit_touched_QMARK_$jscomp$10$$):$G__66915__$1_shape_main__$1$$;
return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape_copy$jscomp$1$$))?$APP.$app$common$logic$libraries$propagate_attrs$$($G__66915__$1_shape_main__$1$$,$shape_copy$jscomp$1$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,null],null),null),$omit_touched_QMARK_$jscomp$10$$):$G__66915__$1_shape_main__$1$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$2_shape_main$jscomp$9$$),function($child_main$jscomp$15$$){var $child_copy$jscomp$1$$=$app$common$types$file$get_shape_in_copy$$($copy_container$jscomp$1$$,$child_main$jscomp$15$$,$shape_copy$jscomp$1$$);
return $APP.$app$common$logic$libraries$propagate_attrs$$($child_main$jscomp$15$$,$child_copy$jscomp$1$$,$APP.$app$common$types$component$swap_keep_attrs$$,$omit_touched_QMARK_$jscomp$10$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null));return $APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$137$$,$new_changes$jscomp$2_shape_main$jscomp$9$$)};
$app$common$logic$libraries$generate_sync_shape_inverse$$=function($changes$jscomp$120_changes__$1$jscomp$27$$,$file$jscomp$54$$,$libraries$jscomp$50$$,$container$jscomp$51$$,$shape_id$jscomp$71$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($shape_id$jscomp$71$$,$container$jscomp$51$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync shape inverse"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$71$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);var $shape_inst$jscomp$6$$=
$APP.$app$common$types$container$get_shape$$($container$jscomp$51$$,$shape_id$jscomp$71$$),$library$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$50$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$)),$APP.$cljs$cst$142$data$$),$component$jscomp$67$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($library$jscomp$20$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$)),
$shape_main$jscomp$6$$=$APP.$cljs$core$truth_$$($component$jscomp$67$$)?$app$common$types$file$find_remote_shape$$($container$jscomp$51$$,$libraries$jscomp$50$$,$shape_inst$jscomp$6$$):null,$initial_root_QMARK_$jscomp$2$$=$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$root_main$jscomp$2$$=$APP.$app$common$types$file$get_component_root$$($library$jscomp$20$$,$component$jscomp$67$$);$changes$jscomp$120_changes__$1$jscomp$27$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$67$$)?
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$APP.$cljs$cst$2073$name_group$$):$component$jscomp$67$$)?$APP.$app$common$logic$libraries$generate_rename_component$$($changes$jscomp$120_changes__$1$jscomp$27$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$library$jscomp$20$$):$changes$jscomp$120_changes__$1$jscomp$27$$;
return $APP.$cljs$core$truth_$$($component$jscomp$67$$)?$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$?$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$($changes$jscomp$120_changes__$1$jscomp$27$$,$container$jscomp$51$$,$shape_inst$jscomp$6$$,$component$jscomp$67$$,$library$jscomp$20$$,$file$jscomp$54$$,$libraries$jscomp$50$$,$shape_main$jscomp$6$$,$shape_inst$jscomp$6$$,$root_main$jscomp$2$$,
$initial_root_QMARK_$jscomp$2$$):$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$($changes$jscomp$120_changes__$1$jscomp$27$$,$container$jscomp$51$$,$shape_inst$jscomp$6$$,$component$jscomp$67$$,$library$jscomp$20$$,$file$jscomp$54$$,$libraries$jscomp$50$$,$shape_main$jscomp$6$$,$shape_inst$jscomp$6$$,$root_main$jscomp$2$$,$initial_root_QMARK_$jscomp$2$$):$changes$jscomp$120_changes__$1$jscomp$27$$};
$app$common$logic$libraries$generate_reset_component$$=function($G__67015_changes$jscomp$148$$,$JSCompiler_temp$jscomp$1668_file_full$jscomp$1$$,$libraries$jscomp$58$$,$container$jscomp$66$$,$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$){var $objects$jscomp$292$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$66$$),$objects$jscomp$inline_8425_swap_slot$jscomp$4$$=$APP.$app$common$types$component$get_swap_slot$$($APP.$app$common$types$container$get_shape$$($container$jscomp$66$$,
$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$));$G__67015_changes$jscomp$148$$=$APP.$app$common$logic$libraries$generate_sync_shape_direct$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_container$$($G__67015_changes$jscomp$148$$,$container$jscomp$66$$),$objects$jscomp$292$$),$JSCompiler_temp$jscomp$1668_file_full$jscomp$1$$,$libraries$jscomp$58$$,$container$jscomp$66$$,$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$,
!0);$objects$jscomp$inline_8425_swap_slot$jscomp$4$$!=null?($head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$66$$,$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$),$objects$jscomp$inline_8425_swap_slot$jscomp$4$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$66$$),$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_8425_swap_slot$jscomp$4$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$)),$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$=$APP.$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($container$jscomp$66$$,$head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$),
$JSCompiler_temp$jscomp$1668_file_full$jscomp$1$$=$APP.$app$common$logic$libraries$generate_sync_shape_direct$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_container$$($G__67015_changes$jscomp$148$$,$container$jscomp$66$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$66$$)),$JSCompiler_temp$jscomp$1668_file_full$jscomp$1$$,$libraries$jscomp$58$$,$container$jscomp$66$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$inline_8427_id$jscomp$465_parent$jscomp$inline_8426_shape_inst$jscomp$inline_8424$$),
!0)):$JSCompiler_temp$jscomp$1668_file_full$jscomp$1$$=$G__67015_changes$jscomp$148$$;return $JSCompiler_temp$jscomp$1668_file_full$jscomp$1$$};
$app$common$logic$variant_properties$generate_reorder_variant_poperties$$=function($changes$jscomp$89$$,$related_components$jscomp$2_variant_id$jscomp$13$$,$from_pos$jscomp$1$$,$to_space_between_pos$jscomp$1$$){var $data$jscomp$312$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$89$$),$objects$jscomp$269$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$89$$);$related_components$jscomp$2_variant_id$jscomp$13$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$312$$,
$objects$jscomp$269$$,$related_components$jscomp$2_variant_id$jscomp$13$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$10$$,$component$jscomp$55$$){var $main_id$jscomp$3_props$jscomp$145$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$55$$),$props__$1$jscomp$22$$=$app$common$data$reorder$$($main_id$jscomp$3_props$jscomp$145$$,$from_pos$jscomp$1$$,$to_space_between_pos$jscomp$1$$);$main_id$jscomp$3_props$jscomp$145$$=
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$55$$);var $name$jscomp$286$$=$APP.$app$common$types$variant$properties_to_name$$($props__$1$jscomp$22$$);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$1$jscomp$10$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$55$$),function($p1__55849_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55849_SHARP_$$,
$APP.$cljs$cst$2001$variant_properties$$,$props__$1$jscomp$22$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$main_id$jscomp$3_props$jscomp$145$$],null),function($p1__55850_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55850_SHARP_$$,$APP.$cljs$cst$2002$variant_name$$,
$name$jscomp$286$$)})},$changes$jscomp$89$$,$related_components$jscomp$2_variant_id$jscomp$13$$)};
$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$04$$=function($changes$jscomp$108$$,$library_data$jscomp$23$$,$component_id$jscomp$40$$,$current_page$$){var $component$jscomp$62$$=$APP.$app$common$types$components_list$get_deleted_component$$($library_data$jscomp$23$$,$component_id$jscomp$40$$),$page$jscomp$53$$=function(){var $or__5025__auto__$jscomp$653_or__5025__auto____$1$jscomp$82$$=$APP.$app$common$types$file$get_component_page$$($library_data$jscomp$23$$,
$component$jscomp$62$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$653_or__5025__auto____$1$jscomp$82$$))return $or__5025__auto__$jscomp$653_or__5025__auto____$1$jscomp$82$$;$or__5025__auto__$jscomp$653_or__5025__auto____$1$jscomp$82$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__66264_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_page$$),$p1__66264_SHARP_$$)},$APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$23$$)))?
$current_page$$:null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$653_or__5025__auto____$1$jscomp$82$$)?$or__5025__auto__$jscomp$653_or__5025__auto____$1$jscomp$82$$:$app$common$types$pages_list$get_last_page$$($library_data$jscomp$23$$)}();return $APP.$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$08$$($changes$jscomp$108$$,$library_data$jscomp$23$$,$component_id$jscomp$40$$,$page$jscomp$53$$,null,null,null,null)};
$app$common$logic$libraries$generate_restore_component$$=function($changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$,$library_data$jscomp$26$$,$component_id$jscomp$43$$,$library_id$jscomp$29$$,$current_page$jscomp$1$$,$objects$jscomp$288$$){$changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$=$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$,$library_data$jscomp$26$$,
$component_id$jscomp$43$$,$current_page$jscomp$1$$);$changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$=$APP.$cljs$core$__destructure_map$$($changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$);var $changes__$1$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$,$APP.$cljs$cst$3131$changes$$),$shape$jscomp$429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$,
$APP.$cljs$cst$1811$shape$$),$parent_id$jscomp$42$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$429$$),$insert_before_QMARK_$$=function(){var $and__5023__auto__$jscomp$404$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$288$$,$parent_id$jscomp$42$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$404$$)?$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$288$$,
$parent_id$jscomp$42$$))):$and__5023__auto__$jscomp$404$$}(),$objects__$1$jscomp$7$$=function(){var $G__66973$$=function(){var $G__66974$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$288$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$429$$),$shape$jscomp$429$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$405$$=$parent_id$jscomp$42$$!=null;return $and__5023__auto__$jscomp$405$$?$insert_before_QMARK_$$:$and__5023__auto__$jscomp$405$$}())?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($G__66974$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$42$$,$APP.$cljs$cst$1614$shapes$$],null),function($p1__66970_SHARP_$$){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$429$$)],
null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__66970_SHARP_$$]))}):$G__66974$$}();return $parent_id$jscomp$42$$!=null&&$APP.$cljs$core$not$$($insert_before_QMARK_$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__66973$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$42$$,$APP.$cljs$cst$1614$shapes$$],null),$APP.$cljs$core$conj$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$429$$)):
$G__66973$$}(),$new_objects_ids$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66971_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__66971_SHARP_$$),$APP.$cljs$cst$2610$add_obj$$)},$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$44$$)));$changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$=
function(){var $G__66979$$=$APP.$app$common$files$changes_builder$resize_parents$$($APP.$app$common$files$changes_builder$with_objects$$($changes__$1$jscomp$44$$,$objects__$1$jscomp$7$$),$new_objects_ids$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$7$$,$parent_id$jscomp$42$$))?$APP.$app$common$files$changes_builder$reorder_children$$($G__66979$$,$parent_id$jscomp$42$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$7$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$42$$,$APP.$cljs$cst$1614$shapes$$],null))):$G__66979$$}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$142_changes__$2$jscomp$21_map__66972_map__66972__$1$$,$APP.$cljs$cst$1644$file_id$$,$library_id$jscomp$29$$)};
$app$common$logic$libraries$generate_duplicate_component$$=function($var_args$jscomp$1188$$){for(var $args__5755__auto__$jscomp$214$$=[],$len__5749__auto___67127$$=arguments.length,$i__5750__auto___67128$$=0;;)if($i__5750__auto___67128$$<$len__5749__auto___67127$$)$args__5755__auto__$jscomp$214$$.push(arguments[$i__5750__auto___67128$$]),$i__5750__auto___67128$$+=1;else break;return $APP.$app$common$logic$libraries$generate_duplicate_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],arguments[3],4<$args__5755__auto__$jscomp$214$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$214$$.slice(4),0,null):null)};
$app$common$files$shapes_helpers$prepare_create_empty_artboard$$=function($changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$,$frame_id$jscomp$48$$,$parent_id$jscomp$50$$,$objects$jscomp$328$$,$target_cell_id$jscomp$2$$){var $base_parent$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$328$$,$parent_id$jscomp$50$$),$attrs$jscomp$76$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,
0,$APP.$cljs$cst$290$width$$,.01,$APP.$cljs$cst$1522$height$$,.01],null),$shape$jscomp$440$$=$APP.$app$common$types$shape$setup_shape$$(function(){var $G__66208__$2_G__66208__$3_G__66208__$4$$=$frame_id$jscomp$48$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$76$$,$APP.$cljs$cst$266$id$$,$frame_id$jscomp$48$$):$attrs$jscomp$76$$;$G__66208__$2_G__66208__$3_G__66208__$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__66208__$2_G__66208__$3_G__66208__$4$$,
$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$48$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$50$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$]));$G__66208__$2_G__66208__$3_G__66208__$4$$=$APP.$cljs$core$with_meta$$($G__66208__$2_G__66208__$3_G__66208__$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,0],null));var $or__5025__auto__$jscomp$inline_8429$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$48$$,
$APP.$app$common$uuid$zero$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8429$$?$or__5025__auto__$jscomp$inline_8429$$:!0)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__66208__$2_G__66208__$3_G__66208__$4$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1875$hide_in_viewer$$,!0])):$G__66208__$2_G__66208__$3_G__66208__$4$$}());$changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$=
$APP.$app$common$files$shapes_helpers$prepare_add_shape$$($changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$,$shape$jscomp$440$$,$objects$jscomp$328$$);var $shape__$1$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$,0,null),$changes__$1$jscomp$60$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$,1,null);$changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$=
function(){return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$328$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)))?$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){return $target_cell_id$jscomp$2$$!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$60$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)],null),function($parent$jscomp$225$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$225$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$jscomp$1$$)),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$target_cell_id$jscomp$2$$,$APP.$cljs$cst$1614$shapes$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$48$$],null)),$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1672$auto$$)}):$changes__$1$jscomp$60$$}(),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)],null),$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)],null)):$changes__$1$jscomp$60$$}();return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$1$jscomp$33$$,$changes$jscomp$167_changes__$2$jscomp$29_vec__66205$$],null)};
$app$common$logic$libraries$generate_duplicate_changes$$=function($var_args$jscomp$1193$$){for(var $args__5755__auto__$jscomp$216$$=[],$len__5749__auto___67420$$=arguments.length,$i__5750__auto___67421$$=0;;)if($i__5750__auto___67421$$<$len__5749__auto___67420$$)$args__5755__auto__$jscomp$216$$.push(arguments[$i__5750__auto___67421$$]),$i__5750__auto___67421$$+=1;else break;return $APP.$app$common$logic$libraries$generate_duplicate_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],8<$args__5755__auto__$jscomp$216$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$216$$.slice(8),0,null):null)};
$app$common$files$changes_builder$del_page$$=function($changes$jscomp$34$$,$page$jscomp$40$$){var $page_id$jscomp$60$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$40$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$34$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2622$del_page$$,$APP.$cljs$cst$266$id$$,$page_id$jscomp$60$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2620$add_page$$,$APP.$cljs$cst$266$id$$,$page_id$jscomp$60$$,$APP.$cljs$cst$1624$page$$,$page$jscomp$40$$],null)))};
$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens$$=function($set_id$jscomp$43$$,$token_ids$jscomp$4$$){typeof $app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$=function($set_id$jscomp$44$$,$token_ids$jscomp$5$$,$meta72993$$){this.$set_id$=$set_id$jscomp$44$$;this.$token_ids$=$token_ids$jscomp$5$$;this.$meta72993$=$meta72993$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4720$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_delete_tokens$$},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72994$$,$meta72993__$1$$){return new $app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$(this.$set_id$,this.$token_ids$,$meta72993__$1$$)},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72993$},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$317_data$jscomp$428_it$jscomp$272$$,$state$jscomp$995$$){var $self__$jscomp$6666$$=this;$changes$jscomp$317_data$jscomp$428_it$jscomp$272$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$995$$);$changes$jscomp$317_data$jscomp$428_it$jscomp$272$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$318$$,$token_id$jscomp$21$$){return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$318$$,
$self__$jscomp$6666$$.$set_id$,$token_id$jscomp$21$$,null)},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$317_data$jscomp$428_it$jscomp$272$$),$self__$jscomp$6666$$.$token_ids$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$317_data$jscomp$428_it$jscomp$272$$),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-token-node"],null)))});return new $app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_72992$$($set_id$jscomp$43$$,$token_ids$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($set_id$jscomp$39$$,$token_ids$jscomp$2$$,$type$jscomp$559$$,$old_path$jscomp$1$$,$new_path$jscomp$1$$,$p__72967$$){var $map__72968__$1$$=$APP.$cljs$core$__destructure_map$$($p__72967$$),$undo_group$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72968__$1$$,$APP.$cljs$cst$3138$undo_group$$);typeof $app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$===
"undefined"&&($app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$=function($set_id$jscomp$40$$,$token_ids$jscomp$3$$,$type$jscomp$560$$,$old_path$jscomp$2$$,$new_path$jscomp$2$$,$p__72967$jscomp$1$$,$map__72968$jscomp$1$$,$undo_group$jscomp$42$$,$meta72972$$){this.$set_id$=$set_id$jscomp$40$$;this.$token_ids$=$token_ids$jscomp$3$$;this.type=$type$jscomp$560$$;this.$old_path$=$old_path$jscomp$2$$;this.$new_path$=$new_path$jscomp$2$$;this.$p__72967$=$p__72967$jscomp$1$$;this.$map__72968$=
$map__72968$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$42$$;this.$meta72972$=$meta72972$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4718$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_update_tokens$$},
$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72973$$,$meta72972__$1$$){return new $app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$(this.$set_id$,this.$token_ids$,this.type,this.$old_path$,this.$new_path$,this.$p__72967$,this.$map__72968$,this.$undo_group$,$meta72972__$1$$)},$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72972$},$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$,$state$jscomp$993$$){var $self__$jscomp$6658$$=this,$token_set$jscomp$17$$=$APP.$cljs$core$truth_$$($self__$jscomp$6658$$.$set_id$)?
$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$993$$,$self__$jscomp$6658$$.$set_id$):$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$993$$);$changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$993$$);$changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$315$$,$token_id$jscomp$18$$){var $token$jscomp$98_token_SINGLEQUOTE_$jscomp$3$$=$APP.$app$common$types$tokens_lib$get_token$$($APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$993$$),$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$17$$),$token_id$jscomp$18$$),$new_name$jscomp$32$$=$APP.$cuerdas$core$replace$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$98_token_SINGLEQUOTE_$jscomp$3$$),
$self__$jscomp$6658$$.$old_path$,$self__$jscomp$6658$$.$new_path$);$token$jscomp$98_token_SINGLEQUOTE_$jscomp$3$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token$jscomp$98_token_SINGLEQUOTE_$jscomp$3$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$new_name$jscomp$32$$],null)])))]));return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$315$$,$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$17$$),$token_id$jscomp$18$$,$token$jscomp$98_token_SINGLEQUOTE_$jscomp$3$$)},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$),
$self__$jscomp$6658$$.$token_ids$);$changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$=$self__$jscomp$6658$$.$undo_group$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$,$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$6658$$.$undo_group$):$changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$;$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($self__$jscomp$6658$$.type),
".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6658$$.$old_path$)].join(""));$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($self__$jscomp$6658$$.type),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6658$$.$new_path$)].join(""));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$314_changes__$1$jscomp$87_data$jscomp$426_it$jscomp$270$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2336$app_DOT_main_DOT_data_DOT_event_SLASH_event$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"bulk-update-tokens",$APP.$cljs$cst$139$type$$,$self__$jscomp$6658$$.type],null)))});return new $app$main$data$workspace$tokens$library_edit$bulk_update_tokens_72971$$($set_id$jscomp$39$$,$token_ids$jscomp$2$$,$type$jscomp$559$$,$old_path$jscomp$1$$,$new_path$jscomp$1$$,$p__72967$$,$map__72968__$1$$,$undo_group$jscomp$41$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$$=function($var_args$jscomp$1383$$){for(var $args__5755__auto__$jscomp$237$$=[],$len__5749__auto___73307$$=arguments.length,$i__5750__auto___73308$$=0;;)if($i__5750__auto___73308$$<$len__5749__auto___73307$$)$args__5755__auto__$jscomp$237$$.push(arguments[$i__5750__auto___73308$$]),$i__5750__auto___73308$$+=1;else break;return $app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],5<$args__5755__auto__$jscomp$237$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$237$$.slice(5),0,null):null)};$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$793$$,$params$jscomp$310$$){return $APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$(null,$id$jscomp$793$$,$params$jscomp$310$$)};
$app$main$data$workspace$tokens$library_edit$bulk_create_tokens$$=function($set_id$jscomp$35$$,$token_ids$$,$type$jscomp$557$$,$node$jscomp$347$$,$new_node_name$$){typeof $app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$=function($set_id$jscomp$36$$,$token_ids$jscomp$1$$,$type$jscomp$558$$,$node$jscomp$348$$,$new_node_name$jscomp$1$$,$meta72942$$){this.$set_id$=$set_id$jscomp$36$$;this.$token_ids$=
$token_ids$jscomp$1$$;this.type=$type$jscomp$558$$;this.node=$node$jscomp$348$$;this.$new_node_name$=$new_node_name$jscomp$1$$;this.$meta72942$=$meta72942$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4716$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_create_tokens$$},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72943$$,$meta72942__$1$$){return new $app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$(this.$set_id$,this.$token_ids$,this.type,this.node,this.$new_node_name$,$meta72942__$1$$)},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72942$},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$311_data$jscomp$424_it$jscomp$268$$,$state$jscomp$991$$){var $self__$jscomp$6650$$=this,$token_set$jscomp$15$$=$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$991$$,
$self__$jscomp$6650$$.$set_id$);$changes$jscomp$311_data$jscomp$424_it$jscomp$268$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$991$$);$changes$jscomp$311_data$jscomp$424_it$jscomp$268$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$312$$,$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$){$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$=$APP.$app$common$types$tokens_lib$get_token$$($APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$991$$),
$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$15$$),$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$);var $new_name$jscomp$31$$=$APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"."])),$APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6650$$.node),$self__$jscomp$6650$$.$new_node_name$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,".",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1])),$JSCompiler_temp_const$jscomp$1515$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$JSCompiler_temp_const$jscomp$1513$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1512$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$JSCompiler_temp_const$jscomp$1510$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$label$jscomp$inline_8431$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_name$jscomp$31$$),$id$jscomp$inline_8432$$=$APP.$app$common$uuid$next$$();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$test_helpers$ids_map$idmap$$,
$APP.$cljs$core$assoc$$,$label$jscomp$inline_8431$$,$id$jscomp$inline_8432$$);$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$=$JSCompiler_temp_const$jscomp$1515$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp_const$jscomp$1513$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$1512$$,$JSCompiler_temp_const$jscomp$1510$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$new_name$jscomp$31$$,$APP.$cljs$cst$266$id$$,$id$jscomp$inline_8432$$],null)])))]));return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$312$$,$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$15$$),$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$.id,$token$jscomp$96_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$)},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$changes$jscomp$311_data$jscomp$424_it$jscomp$268$$),$self__$jscomp$6650$$.$token_ids$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$311_data$jscomp$424_it$jscomp$268$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2336$app_DOT_main_DOT_data_DOT_event_SLASH_event$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"bulk-create-tokens",$APP.$cljs$cst$139$type$$,
$self__$jscomp$6650$$.type],null)))});return new $app$main$data$workspace$tokens$library_edit$bulk_create_tokens_72941$$($set_id$jscomp$35$$,$token_ids$$,$type$jscomp$557$$,$node$jscomp$347$$,$new_node_name$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$01$$=function($token$jscomp$93$$){return $APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$token$jscomp$93$$)};
$app$main$data$workspace$tokens$library_edit$duplicate_token$$=function($token_id$jscomp$22$$){typeof $app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$=function($token_id$jscomp$23$$,$meta73004$$){this.$token_id$=$token_id$jscomp$23$$;this.$meta73004$=$meta73004$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4721$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_duplicate_token$$},$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73005$$,$meta73004__$1$$){return new $app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$(this.$token_id$,
$meta73004__$1$$)},$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73004$},$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$,
$new_token_state$jscomp$996_temp__5825__auto____$2$$){$_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$=$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($new_token_state$jscomp$996_temp__5825__auto____$2$$);if($APP.$cljs$core$truth_$$($_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$)){var $temp__5825__auto____$1$jscomp$13$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($new_token_state$jscomp$996_temp__5825__auto____$2$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto____$1$jscomp$13$$)&&($new_token_state$jscomp$996_temp__5825__auto____$2$$=$APP.$app$common$types$tokens_lib$get_token$$($temp__5825__auto____$1$jscomp$13$$,$APP.$app$common$types$tokens_lib$get_id$$($_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$),this.$token_id$),$APP.$cljs$core$truth_$$($new_token_state$jscomp$996_temp__5825__auto____$2$$)))return $_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$=
$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens$$($temp__5825__auto____$1$jscomp$13$$,$APP.$app$common$types$tokens_lib$get_id$$($_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$))),$_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$),
$_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_token_state$jscomp$996_temp__5825__auto____$2$$),$_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1371$suffix$$,"copy"])),
$new_token_state$jscomp$996_temp__5825__auto____$2$$=$APP.$app$common$types$tokens_lib$rename$$($APP.$app$common$types$tokens_lib$reid$$($new_token_state$jscomp$996_temp__5825__auto____$2$$),$_$jscomp$2679_copy_name$jscomp$1_temp__5825__auto__$jscomp$247_tokens$jscomp$37_unames$jscomp$13$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$01$$($new_token_state$jscomp$996_temp__5825__auto____$2$$))}return null});return new $app$main$data$workspace$tokens$library_edit$duplicate_token_73003$$($token_id$jscomp$22$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$rename_token_set_group$$=function($set_group_path$jscomp$2$$,$set_group_fname$jscomp$2$$){typeof $app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$=function($set_group_path$jscomp$3$$,$set_group_fname$jscomp$3$$,$meta72844$$){this.$set_group_path$=$set_group_path$jscomp$3$$;this.$set_group_fname$=$set_group_fname$jscomp$3$$;this.$meta72844$=
$meta72844$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4703$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_rename_token_set_group$$},
$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72845$$,$meta72844__$1$$){return new $app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$(this.$set_group_path$,this.$set_group_fname$,$meta72844__$1$$)},$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72844$},$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $changes$jscomp$299_changes$jscomp$inline_8434$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this);var $set_group_path$jscomp$inline_8435$$=this.$set_group_path$,$set_group_fname$jscomp$inline_8436$$=this.$set_group_fname$,$undo_path$jscomp$inline_8437$$=$APP.$app$common$types$tokens_lib$replace_last_path_name$$($set_group_path$jscomp$inline_8435$$,
$set_group_fname$jscomp$inline_8436$$),$undo_fname$jscomp$inline_8438$$=$APP.$cljs$core$last$$($set_group_path$jscomp$inline_8435$$);$changes$jscomp$299_changes$jscomp$inline_8434$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$299_changes$jscomp$inline_8434$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2650$rename_token_set_group$$,$APP.$cljs$cst$2651$set_group_path$$,$set_group_path$jscomp$inline_8435$$,$APP.$cljs$cst$2652$set_group_fname$$,$set_group_fname$jscomp$inline_8436$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2650$rename_token_set_group$$,$APP.$cljs$cst$2651$set_group_path$$,$undo_path$jscomp$inline_8437$$,$APP.$cljs$cst$2652$set_group_fname$$,
$undo_fname$jscomp$inline_8438$$],null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$299_changes$jscomp$inline_8434$$))});return new $app$main$data$workspace$tokens$library_edit$rename_token_set_group_72843$$($set_group_path$jscomp$2$$,$set_group_fname$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_component_annotation$$=function($id$jscomp$759$$,$annotation$jscomp$4$$){typeof $app$main$data$workspace$update_component_annotation_72102$$==="undefined"&&($app$main$data$workspace$update_component_annotation_72102$$=function($id$jscomp$760$$,$annotation$jscomp$5$$,$meta72103$$){this.id=$id$jscomp$760$$;this.$annotation$=$annotation$jscomp$5$$;this.$meta72103$=$meta72103$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$update_component_annotation_72102$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_component_annotation_72102$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4524$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_component_annotation$$},$app$main$data$workspace$update_component_annotation_72102$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72104$$,$meta72103__$1$$){return new $app$main$data$workspace$update_component_annotation_72102$$(this.id,
this.$annotation$,$meta72103__$1$$)},$app$main$data$workspace$update_component_annotation_72102$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72103$},$app$main$data$workspace$update_component_annotation_72102$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_component_annotation_72102$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$281_data$jscomp$405_it$jscomp$250$$,$state$jscomp$930$$){var $self__$jscomp$6401$$=
this;$changes$jscomp$281_data$jscomp$405_it$jscomp$250$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$930$$);$changes$jscomp$281_data$jscomp$405_it$jscomp$250$$=$APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$281_data$jscomp$405_it$jscomp$250$$),$self__$jscomp$6401$$.id,function($component$jscomp$95$$){return $APP.$cljs$core$truth_$$($component$jscomp$95$$)?
$self__$jscomp$6401$$.$annotation$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$95$$,$APP.$cljs$cst$2542$annotation$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$95$$,$APP.$cljs$cst$2542$annotation$$,$self__$jscomp$6401$$.$annotation$):null});return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$281_data$jscomp$405_it$jscomp$250$$)),$self__$jscomp$6401$$.$annotation$==
null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-component-annotation"],null))):null)});return new $app$main$data$workspace$update_component_annotation_72102$$($id$jscomp$759$$,$annotation$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$change_pixel_grid_color$cljs$0core$0IFn$0_invoke$0arity$02$$=function($color$jscomp$110$$){typeof $app$main$data$workspace$change_pixel_grid_color_72057$$==="undefined"&&($app$main$data$workspace$change_pixel_grid_color_72057$$=function($page_id$jscomp$279$$,$color$jscomp$111$$,$meta72058$$){this.$page_id$=$page_id$jscomp$279$$;this.color=$color$jscomp$111$$;this.$meta72058$=$meta72058$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$change_pixel_grid_color_72057$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$change_pixel_grid_color_72057$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4517$app_DOT_main_DOT_data_DOT_workspace_SLASH_change_pixel_grid_color$$},$app$main$data$workspace$change_pixel_grid_color_72057$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72059$$,$meta72058__$1$$){return new $app$main$data$workspace$change_pixel_grid_color_72057$$(this.$page_id$,
this.color,$meta72058__$1$$)},$app$main$data$workspace$change_pixel_grid_color_72057$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72058$},$app$main$data$workspace$change_pixel_grid_color_72057$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$change_pixel_grid_color_72057$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$249_or__5025__auto__$jscomp$inline_8440_page_id__$1$jscomp$19$$,$changes$jscomp$280_page$jscomp$106_state$jscomp$921$$){$it$jscomp$249_or__5025__auto__$jscomp$inline_8440_page_id__$1$jscomp$19$$=
this.$page_id$;$it$jscomp$249_or__5025__auto__$jscomp$inline_8440_page_id__$1$jscomp$19$$=$APP.$cljs$core$truth_$$($it$jscomp$249_or__5025__auto__$jscomp$inline_8440_page_id__$1$jscomp$19$$)?$it$jscomp$249_or__5025__auto__$jscomp$inline_8440_page_id__$1$jscomp$19$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$280_page$jscomp$106_state$jscomp$921$$);$changes$jscomp$280_page$jscomp$106_state$jscomp$921$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$280_page$jscomp$106_state$jscomp$921$$,
$it$jscomp$249_or__5025__auto__$jscomp$inline_8440_page_id__$1$jscomp$19$$);$changes$jscomp$280_page$jscomp$106_state$jscomp$921$$=$APP.$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$280_page$jscomp$106_state$jscomp$921$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2059$pixel_grid_color$$,
$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$(this.color),$APP.$cljs$cst$2060$pixel_grid_opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$(this.color)],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$280_page$jscomp$106_state$jscomp$921$$))});return new $app$main$data$workspace$change_pixel_grid_color_72057$$(null,$color$jscomp$110$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$relocate_page$$=function($id$jscomp$753$$,$index$jscomp$365$$){typeof $app$main$data$workspace$relocate_page_71822$$==="undefined"&&($app$main$data$workspace$relocate_page_71822$$=function($id$jscomp$754$$,$index$jscomp$366$$,$meta71823$$){this.id=$id$jscomp$754$$;this.index=$index$jscomp$366$$;this.$meta71823$=$meta71823$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$relocate_page_71822$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$relocate_page_71822$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4487$app_DOT_main_DOT_data_DOT_workspace_SLASH_relocate_page$$},$app$main$data$workspace$relocate_page_71822$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71824$$,$meta71823__$1$$){return new $app$main$data$workspace$relocate_page_71822$$(this.id,this.index,$meta71823__$1$$)},$app$main$data$workspace$relocate_page_71822$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71823$},$app$main$data$workspace$relocate_page_71822$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$relocate_page_71822$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$278_it$jscomp$247_prev_index$jscomp$1$$,$page_id$jscomp$inline_8443_state$jscomp$901$$){$changes$jscomp$278_it$jscomp$247_prev_index$jscomp$1$$=$APP.$app$common$data$index_of$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$inline_8443_state$jscomp$901$$),
$APP.$cljs$cst$2228$pages$$),this.id);$page_id$jscomp$inline_8443_state$jscomp$901$$=this.id;$changes$jscomp$278_it$jscomp$247_prev_index$jscomp$1$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2623$mov_page$$,$APP.$cljs$cst$266$id$$,$page_id$jscomp$inline_8443_state$jscomp$901$$,$APP.$cljs$cst$1795$index$$,this.index],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2623$mov_page$$,$APP.$cljs$cst$266$id$$,$page_id$jscomp$inline_8443_state$jscomp$901$$,$APP.$cljs$cst$1795$index$$,$changes$jscomp$278_it$jscomp$247_prev_index$jscomp$1$$],null)));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$278_it$jscomp$247_prev_index$jscomp$1$$))});return new $app$main$data$workspace$relocate_page_71822$$($id$jscomp$753$$,$index$jscomp$365$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_page_position_data$cljs$0core$0IFn$0_invoke$0arity$02$$=function(){typeof $app$main$data$workspace$update_page_position_data_71617$$==="undefined"&&($app$main$data$workspace$update_page_position_data_71617$$=function($file_id$jscomp$260$$,$page_id$jscomp$265$$,$meta71618$$){this.$file_id$=$file_id$jscomp$260$$;this.$page_id$=$page_id$jscomp$265$$;this.$meta71618$=$meta71618$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$update_page_position_data_71617$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_page_position_data_71617$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4460$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_page_position_data$$},$app$main$data$workspace$update_page_position_data_71617$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71619$$,$meta71618__$1$$){return new $app$main$data$workspace$update_page_position_data_71617$$(this.$file_id$,
this.$page_id$,$meta71618__$1$$)},$app$main$data$workspace$update_page_position_data_71617$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71618$},$app$main$data$workspace$update_page_position_data_71617$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_page_position_data_71617$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$272_file_id__$1$jscomp$5_it$jscomp$243$$,$state$jscomp$874$$){var $self__$jscomp$6170$$=
this;$changes$jscomp$272_file_id__$1$jscomp$5_it$jscomp$243$$=function(){var $or__5025__auto__$jscomp$849$$=$self__$jscomp$6170$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$849$$)?$or__5025__auto__$jscomp$849$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$874$$)}();var $page_id__$1$jscomp$14$$=function(){var $or__5025__auto__$jscomp$850$$=$self__$jscomp$6170$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$850$$)?$or__5025__auto__$jscomp$850$$:
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$874$$)}();$changes$jscomp$272_file_id__$1$jscomp$5_it$jscomp$243$$=$APP.$cljs$core$reduce_kv$$(function($result$jscomp$314$$,$___$1$jscomp$1722$$,$shape$jscomp$751$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$751$$)&&$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$751$$)==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$314$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$751$$),$APP.$cljs$cst$2043$page_id$$,$page_id__$1$jscomp$14$$,$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,
$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$108$val$$,$APP.$app$render_wasm$api$calculate_position_data$$($shape$jscomp$751$$),$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2557$ignore_geometry$$,!0],null)],null)],null)):$result$jscomp$314$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$874$$,$changes$jscomp$272_file_id__$1$jscomp$5_it$jscomp$243$$,$page_id__$1$jscomp$14$$));return $APP.$app$common$data$not_empty_QMARK_$$($changes$jscomp$272_file_id__$1$jscomp$5_it$jscomp$243$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3133$redo_changes$$,$changes$jscomp$272_file_id__$1$jscomp$5_it$jscomp$243$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1,$APP.$cljs$cst$1786$origin$$,this,$APP.$cljs$cst$3142$tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1891$position_data$$,
null],null),null)],null))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$update_page_position_data_71617$$(null,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$reorder_variant_poperties$$=function($variant_id$jscomp$29$$,$from_pos$jscomp$8$$,$to_space_between_pos$jscomp$8$$){typeof $app$main$data$workspace$variants$reorder_variant_properties_71467$$==="undefined"&&($app$main$data$workspace$variants$reorder_variant_properties_71467$$=function($variant_id$jscomp$30$$,$from_pos$jscomp$9$$,$to_space_between_pos$jscomp$9$$,$meta71468$$){this.$variant_id$=$variant_id$jscomp$30$$;this.$from_pos$=$from_pos$jscomp$9$$;this.$to_space_between_pos$=
$to_space_between_pos$jscomp$9$$;this.$meta71468$=$meta71468$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$reorder_variant_properties_71467$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$reorder_variant_properties_71467$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4431$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_reorder_variant_properties$$},
$app$main$data$workspace$variants$reorder_variant_properties_71467$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71469$$,$meta71468__$1$$){return new $app$main$data$workspace$variants$reorder_variant_properties_71467$$(this.$variant_id$,this.$from_pos$,this.$to_space_between_pos$,$meta71468__$1$$)},$app$main$data$workspace$variants$reorder_variant_properties_71467$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71468$},$app$main$data$workspace$variants$reorder_variant_properties_71467$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$reorder_variant_properties_71467$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$269_it$jscomp$237_page_id$jscomp$255$$,$data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$){$changes$jscomp$269_it$jscomp$237_page_id$jscomp$255$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$);$data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$);var $objects$jscomp$648$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$,$changes$jscomp$269_it$jscomp$237_page_id$jscomp$255$$),$APP.$cljs$cst$1631$objects$$);$changes$jscomp$269_it$jscomp$237_page_id$jscomp$255$$=$app$common$logic$variant_properties$generate_reorder_variant_poperties$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$269_it$jscomp$237_page_id$jscomp$255$$),$data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$),$objects$jscomp$648$$),this.$variant_id$,this.$from_pos$,this.$to_space_between_pos$);$data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$269_it$jscomp$237_page_id$jscomp$255$$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$398_state$jscomp$844_undo_id$jscomp$71$$))});return new $app$main$data$workspace$variants$reorder_variant_properties_71467$$($variant_id$jscomp$29$$,$from_pos$jscomp$8$$,$to_space_between_pos$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$paste_grid_tracks$$=function($grid_id$jscomp$21$$){typeof $app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$==="undefined"&&($app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$=function($grid_id$jscomp$22$$,$meta71299$$){this.$grid_id$=$grid_id$jscomp$22$$;this.$meta71299$=$meta71299$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4421$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_paste_grid_tracks$$},$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71300$$,$meta71299__$1$$){return new $app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$(this.$grid_id$,
$meta71299__$1$$)},$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71299$},$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$,$state$jscomp$834_track_indices$jscomp$1$$){$changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$834_track_indices$jscomp$1$$);var $page$jscomp$102$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$834_track_indices$jscomp$1$$),$objects$jscomp$639$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$102$$),$libraries$jscomp$94$$=$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$834_track_indices$jscomp$1$$),$library_data$jscomp$34$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$834_track_indices$jscomp$1$$,
$changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$),$grid$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$639$$,this.$grid_id$),$copied_undo_id$jscomp$63$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$834_track_indices$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$4418$copied_tracks$$],
null));$state$jscomp$834_track_indices$jscomp$1$$=$APP.$cljs$cst$4419$track_indices$$.$cljs$core$IFn$_invoke$arity$1$($copied_undo_id$jscomp$63$$);var $type$jscomp$533$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($copied_undo_id$jscomp$63$$);$copied_undo_id$jscomp$63$$=Symbol();if($APP.$cljs$core$seq$$($state$jscomp$834_track_indices$jscomp$1$$)&&$type$jscomp$533$$!=null){var $shapes_by_track_fn$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$533$$,$APP.$cljs$cst$1656$row$$)?
$APP.$app$common$types$shape$layout$shapes_by_row$$:$APP.$app$common$types$shape$layout$shapes_by_column$$,$all_shapes$jscomp$2$$=$APP.$cljs$core$set$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__71294_SHARP_$$){return $shapes_by_track_fn$$.$cljs$core$IFn$_invoke$arity$3$?$shapes_by_track_fn$$.$cljs$core$IFn$_invoke$arity$3$($grid$jscomp$8$$,$p1__71294_SHARP_$$,!1):$shapes_by_track_fn$$($grid$jscomp$8$$,$p1__71294_SHARP_$$,!1)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$state$jscomp$834_track_indices$jscomp$1$$])));
$changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$=$APP.$app$common$logic$libraries$generate_duplicate_changes_update_indices$$($app$common$logic$libraries$generate_duplicate_changes$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$objects$jscomp$639$$,$page$jscomp$102$$,$all_shapes$jscomp$2$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$libraries$jscomp$94$$,$library_data$jscomp$34$$,$changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$),
$objects$jscomp$639$$,$all_shapes$jscomp$2$$);var $ids_map$jscomp$22$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71297_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71297_SHARP_$$),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($p1__71297_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2611$obj$$,$APP.$cljs$cst$266$id$$],null))],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__71301_p1__71296_SHARP_$$){$G__71301_p1__71296_SHARP_$$=$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($G__71301_p1__71296_SHARP_$$);return $all_shapes$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$all_shapes$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__71301_p1__71296_SHARP_$$):
$all_shapes$jscomp$2$$($G__71301_p1__71296_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71295_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__71295_SHARP_$$),$APP.$cljs$cst$2610$add_obj$$)},$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$))))),$duplicate_at_fn$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$533$$,
$APP.$cljs$cst$1656$row$$)?$app$common$types$shape$layout$duplicate_row_at$$:$app$common$types$shape$layout$duplicate_column_at$$,$tracks_prop$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$533$$,$APP.$cljs$cst$1656$row$$)?$APP.$cljs$cst$1694$layout_grid_rows$$:$APP.$cljs$cst$1695$layout_grid_columns$$,$sorted_indices$$=$APP.$cljs$core$vec$$($cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$834_track_indices$jscomp$1$$));$changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$=
$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$grid_id$],null),function($shape$jscomp$745_shape__$1$jscomp$63$$,$objects__$1$jscomp$29$$){$shape$jscomp$745_shape__$1$jscomp$63$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$745_shape__$1$jscomp$63$$,
$APP.$cljs$core$select_keys$$($grid$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1694$layout_grid_rows$$],null))]));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($s$jscomp$551$$,$actual_src_p__71302$$){var $offset$jscomp$181_target_idx$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($actual_src_p__71302$$,
0,null);$actual_src_p__71302$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($actual_src_p__71302$$,1,null);$offset$jscomp$181_target_idx$$=$APP.$cljs$core$count$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$8$$,$tracks_prop$jscomp$1$$))+$offset$jscomp$181_target_idx$$;return $duplicate_at_fn$$.$cljs$core$IFn$_invoke$arity$5$?$duplicate_at_fn$$.$cljs$core$IFn$_invoke$arity$5$($s$jscomp$551$$,$objects__$1$jscomp$29$$,$actual_src_p__71302$$,$offset$jscomp$181_target_idx$$,
$ids_map$jscomp$22$$):$duplicate_at_fn$$($s$jscomp$551$$,$objects__$1$jscomp$29$$,$actual_src_p__71302$$,$offset$jscomp$181_target_idx$$,$ids_map$jscomp$22$$)},$shape$jscomp$745_shape__$1$jscomp$63$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$sorted_indices$$))},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($copied_undo_id$jscomp$63$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$261_changes__$1$jscomp$81_file_id$jscomp$251_it$jscomp$229$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$grid_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($copied_undo_id$jscomp$63$$))}return null});
return new $app$main$data$workspace$shape_layout$paste_grid_tracks_71298$$($grid_id$jscomp$21$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$create_cell_board$$=function($layout_id$jscomp$10$$,$cell_ids$$){typeof $app$main$data$workspace$shape_layout$create_cell_board_71278$$==="undefined"&&($app$main$data$workspace$shape_layout$create_cell_board_71278$$=function($layout_id$jscomp$11$$,$cell_ids$jscomp$1$$,$meta71279$$){this.$layout_id$=$layout_id$jscomp$11$$;this.$cell_ids$=$cell_ids$jscomp$1$$;this.$meta71279$=$meta71279$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$shape_layout$create_cell_board_71278$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_cell_board_71278$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4416$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_cell_board$$},$app$main$data$workspace$shape_layout$create_cell_board_71278$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71280$$,$meta71279__$1$$){return new $app$main$data$workspace$shape_layout$create_cell_board_71278$$(this.$layout_id$,
this.$cell_ids$,$meta71279__$1$$)},$app$main$data$workspace$shape_layout$create_cell_board_71278$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71279$},$app$main$data$workspace$shape_layout$create_cell_board_71278$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_cell_board_71278$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$228_undo_id$jscomp$62$$,$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$){var $self__$jscomp$6018$$=
this,$it__$1$jscomp$104$$=this,$page_id$jscomp$247$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$),$objects$jscomp$637$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$),$frame_id$jscomp$108$$=$APP.$app$common$uuid$next$$();
$it$jscomp$228_undo_id$jscomp$62$$=Symbol();var $shape$jscomp$744$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$637$$,$self__$jscomp$6018$$.$layout_id$);$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71277_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$744$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$p1__71277_SHARP_$$],null))},$self__$jscomp$6018$$.$cell_ids$);var $selected$jscomp$93$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1614$shapes$$),$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$);$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$=
$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$);$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$=$APP.$cljs$core$__destructure_map$$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$);var $first_row$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,
$APP.$cljs$cst$1715$first_row$$),$first_column$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,$APP.$cljs$cst$1716$first_column$$),$last_row$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,$APP.$cljs$cst$1717$last_row$$),$last_column$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,$APP.$cljs$cst$1718$last_column$$),$target_cell$jscomp$10$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($shape$jscomp$744$$,$first_row$jscomp$12$$,$first_column$jscomp$12$$);$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$=function(){var $G__71285_G__71286$jscomp$inline_8447$$=
$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it__$1$jscomp$104$$,$page_id$jscomp$247$$),$objects$jscomp$637$$);$G__71285_G__71286$jscomp$inline_8447$$=$APP.$app$common$data$not_empty_QMARK_$$($selected$jscomp$93$$)?$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$9$($G__71285_G__71286$jscomp$inline_8447$$,$frame_id$jscomp$108$$,$self__$jscomp$6018$$.$layout_id$,
$objects$jscomp$637$$,$selected$jscomp$93$$,0,null,!0,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$)):$G__71285_G__71286$jscomp$inline_8447$$;return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$seq$$($selected$jscomp$93$$))?$app$common$files$shapes_helpers$prepare_create_empty_artboard$$($G__71285_G__71286$jscomp$inline_8447$$,$frame_id$jscomp$108$$,$self__$jscomp$6018$$.$layout_id$,$objects$jscomp$637$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$)):
$G__71285_G__71286$jscomp$inline_8447$$}();$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,0,null);$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,
1,null);$cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$frame_id$jscomp$108$$],null),function($shape__$1$jscomp$61$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$61$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1403$fill$$),$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1403$fill$$)}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6018$$.$layout_id$],null),function($shape__$1$jscomp$62$$){var $new_row_span$jscomp$1$$=
$last_row$jscomp$12$$-$first_row$jscomp$12$$+1,$new_col_span$$=$last_column$jscomp$12$$-$first_column$jscomp$12$$+1;return $APP.$app$common$types$shape$layout$resize_cell_area$$($shape__$1$jscomp$62$$,$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$),$first_row$jscomp$12$$,$first_column$jscomp$12$$,$new_row_span$jscomp$1$$,$new_col_span$$)});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($it$jscomp$228_undo_id$jscomp$62$$),
$APP.$app$main$data$changes$commit_changes$$($cells$jscomp$24_changes$jscomp$260_changes__$1$jscomp$80_map__71281_map__71281__$1_state$jscomp$832_vec__71282$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6018$$.$layout_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($it$jscomp$228_undo_id$jscomp$62$$))});
return new $app$main$data$workspace$shape_layout$create_cell_board_71278$$($layout_id$jscomp$10$$,$cell_ids$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$duplicate_layout_track$$=function($ids$jscomp$229$$,$type$jscomp$523$$,$index$jscomp$358$$){typeof $app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$==="undefined"&&($app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$=function($ids$jscomp$230$$,$type$jscomp$524$$,$index$jscomp$359$$,$meta71205$$){this.ids=$ids$jscomp$230$$;this.type=$type$jscomp$524$$;this.index=$index$jscomp$359$$;this.$meta71205$=$meta71205$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4406$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_duplicate_layout_track$$},$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71206$$,$meta71205__$1$$){return new $app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$(this.ids,this.type,this.index,$meta71205__$1$$)},$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71205$},$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$,$library_data$jscomp$33_state$jscomp$829$$){var $self__$jscomp$5982$$=this;$changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$33_state$jscomp$829$$);var $page$jscomp$101_undo_id$jscomp$54$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$33_state$jscomp$829$$),
$objects$jscomp$629$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$101_undo_id$jscomp$54$$),$libraries$jscomp$93$$=$APP.$app$main$data$helpers$lookup_libraries$$($library_data$jscomp$33_state$jscomp$829$$);$library_data$jscomp$33_state$jscomp$829$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($library_data$jscomp$33_state$jscomp$829$$,$changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$);var $shape_id$jscomp$120_shapes_by_track$$=
$APP.$cljs$core$first$$($self__$jscomp$5982$$.ids),$base_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$629$$,$shape_id$jscomp$120_shapes_by_track$$);$shape_id$jscomp$120_shapes_by_track$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5982$$.type,$APP.$cljs$cst$216$column$$)?$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$3$($base_shape$$,$self__$jscomp$5982$$.index,!1):$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$3$($base_shape$$,
$self__$jscomp$5982$$.index,!1);var $selected$jscomp$92$$=$APP.$cljs$core$set$$($shape_id$jscomp$120_shapes_by_track$$);$changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$=$APP.$app$common$logic$libraries$generate_duplicate_changes_update_indices$$($app$common$logic$libraries$generate_duplicate_changes$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$objects$jscomp$629$$,$page$jscomp$101_undo_id$jscomp$54$$,$selected$jscomp$92$$,
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$libraries$jscomp$93$$,$library_data$jscomp$33_state$jscomp$829$$,$changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$),$objects$jscomp$629$$,$selected$jscomp$92$$);var $ids_map$jscomp$21$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71203_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71203_SHARP_$$),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($p1__71203_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2611$obj$$,$APP.$cljs$cst$266$id$$],null))],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__71210_p1__71202_SHARP_$$){$G__71210_p1__71202_SHARP_$$=$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($G__71210_p1__71202_SHARP_$$);
return $selected$jscomp$92$$.$cljs$core$IFn$_invoke$arity$1$?$selected$jscomp$92$$.$cljs$core$IFn$_invoke$arity$1$($G__71210_p1__71202_SHARP_$$):$selected$jscomp$92$$($G__71210_p1__71202_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71201_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__71201_SHARP_$$),$APP.$cljs$cst$2610$add_obj$$)},$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$)))));
$changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$,$self__$jscomp$5982$$.ids,function($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$){$G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,
$APP.$cljs$core$select_keys$$($base_shape$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1694$layout_grid_rows$$],null))]));var $G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$=$self__$jscomp$5982$$.type;$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$=$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$ instanceof
$APP.$cljs$core$Keyword$$?$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$.$fqn$:null;switch($G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$){case "row":$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$=$self__$jscomp$5982$$.index;var $value$jscomp$inline_8453_value$jscomp$inline_8460$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,
$APP.$cljs$cst$1694$layout_grid_rows$$),$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$);$G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,$APP.$cljs$cst$1656$row$$,
$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$),$value$jscomp$inline_8453_value$jscomp$inline_8460$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$+1),$APP.$cljs$cst$1656$row$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$+1,$ids_map$jscomp$21$$);return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,
$objects__$1$jscomp$27$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$);case "column":return $G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$=$self__$jscomp$5982$$.index,$value$jscomp$inline_8453_value$jscomp$inline_8460$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,
$APP.$cljs$cst$1695$layout_grid_columns$$),$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$),$G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,
$APP.$cljs$cst$216$column$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$),$value$jscomp$inline_8453_value$jscomp$inline_8460$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$+1),$APP.$cljs$cst$216$column$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$,$G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$+1,$ids_map$jscomp$21$$),$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48096$jscomp$inline_8454_G__48104$jscomp$inline_8461_shape$jscomp$734_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71211_G__71211__$1_index$jscomp$inline_8451_index$jscomp$inline_8458$$)].join(""));
}},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null));$page$jscomp$101_undo_id$jscomp$54$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($page$jscomp$101_undo_id$jscomp$54$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$258_changes__$1$jscomp$79_file_id$jscomp$250_it$jscomp$227$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5982$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($page$jscomp$101_undo_id$jscomp$54$$))});return new $app$main$data$workspace$shape_layout$duplicate_layout_track_71204$$($ids$jscomp$229$$,$type$jscomp$523$$,$index$jscomp$358$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$delete_page$$=function($id$jscomp$732$$){typeof $app$main$data$workspace$pages$delete_page_70977$$==="undefined"&&($app$main$data$workspace$pages$delete_page_70977$$=function($id$jscomp$733$$,$meta70978$$){this.id=$id$jscomp$733$$;this.$meta70978$=$meta70978$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$delete_page_70977$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$pages$delete_page_70977$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4376$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_delete_page$$},$app$main$data$workspace$pages$delete_page_70977$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70979$$,$meta70978__$1$$){return new $app$main$data$workspace$pages$delete_page_70977$$(this.id,$meta70978__$1$$)},$app$main$data$workspace$pages$delete_page_70977$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70978$},$app$main$data$workspace$pages$delete_page_70977$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$delete_page_70977$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$,$state$jscomp$811$$){var $self__$jscomp$5893$$=this;$changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$811$$);
$changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$811$$,$changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$);var $page$jscomp$100_pindex$$=$APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$),$pages$jscomp$7_pages__$1$$=$APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$),
$index$jscomp$349_page__$1$jscomp$7$$=$APP.$app$common$data$index_of$$($pages$jscomp$7_pages__$1$$,$self__$jscomp$5893$$.id);$page$jscomp$100_pindex$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$100_pindex$$,$self__$jscomp$5893$$.id);if($page$jscomp$100_pindex$$==null)return $APP.$beicon$v2$core$empty$$();$index$jscomp$349_page__$1$jscomp$7$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$100_pindex$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$349_page__$1$jscomp$7$$);
$pages$jscomp$7_pages__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70976_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__70976_SHARP_$$,$self__$jscomp$5893$$.id)},$pages$jscomp$7_pages__$1$$);$changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$=$app$common$files$changes_builder$del_page$$($app$main$data$workspace$pages$delete_page_components$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$),$index$jscomp$349_page__$1$jscomp$7$$),$index$jscomp$349_page__$1$jscomp$7$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$251_fdata$jscomp$17_file_id$jscomp$249_it$jscomp$223$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5893$$.id,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$811$$))?$APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$first$$($pages$jscomp$7_pages__$1$$)],null)])):null)});return new $app$main$data$workspace$pages$delete_page_70977$$($id$jscomp$732$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$duplicate_page$$=function($page_id$jscomp$237$$){typeof $app$main$data$workspace$pages$duplicate_page_70853$$==="undefined"&&($app$main$data$workspace$pages$duplicate_page_70853$$=function($page_id$jscomp$238$$,$meta70854$$){this.$page_id$=$page_id$jscomp$238$$;this.$meta70854$=$meta70854$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$duplicate_page_70853$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$duplicate_page_70853$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4371$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_duplicate_page$$},$app$main$data$workspace$pages$duplicate_page_70853$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70855$$,$meta70854__$1$$){return new $app$main$data$workspace$pages$duplicate_page_70853$$(this.$page_id$,$meta70854__$1$$)},$app$main$data$workspace$pages$duplicate_page_70853$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70854$},$app$main$data$workspace$pages$duplicate_page_70853$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$duplicate_page_70853$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$,$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$809$$){function $add_comp$$($changes$jscomp$247$$,$component$jscomp$88_main$jscomp$2$$){var $new_component_id$jscomp$6$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$)),$new_variant_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$)),$main_instance_id$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$));
$component$jscomp$88_main$jscomp$2$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($fdata$jscomp$16$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$));return $APP.$app$common$files$changes_builder$add_component$$($changes$jscomp$247$$,$new_component_id$jscomp$6$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$),
$APP.$cljs$core$PersistentVector$EMPTY$$,$main_instance_id$jscomp$6$$,$new_page_id$$,$APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$),$new_variant_id$jscomp$1$$,$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$))}function $add_component_copy$$($objs$jscomp$17_objs__$1$jscomp$1$$,$id$jscomp$727$$,$new_shape$jscomp$20_shape$jscomp$720$$){var $children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$=
$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($fdata$jscomp$16$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$720$$)),$parent_id$jscomp$91$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$720$$),$APP.$app$common$uuid$zero$$)?$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$720$$):
null;$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$=$APP.$app$common$types$container$make_component_instance$cljs$0core$0IFn$0_invoke$0arity$05$$($page$jscomp$97$$,$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$,$fdata$jscomp$16$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$720$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$720$$)),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2092$keep_ids_QMARK_$$,!0,$APP.$cljs$cst$2549$force_frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$720$$),$APP.$cljs$cst$2550$force_parent_id$$,$parent_id$jscomp$91$$],null));$new_shape$jscomp$20_shape$jscomp$720$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$,0,null);$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$,1,null);$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape__$1$jscomp$54$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$54$$),
$shape__$1$jscomp$54$$],null)},$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$));$objs$jscomp$17_objs__$1$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objs$jscomp$17_objs__$1$jscomp$1$$,$id$jscomp$727$$,$new_shape$jscomp$20_shape$jscomp$720$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$objs$jscomp$17_objs__$1$jscomp$1$$,$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__70878$$]))}
var $it__$1$jscomp$97$$=this,$new_page_id$$=$APP.$app$common$uuid$next$$(),$fdata$jscomp$16$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$809$$);$changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fdata$jscomp$16$$,$APP.$cljs$cst$1630$pages_index$$);var $page$jscomp$97$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$,
this.$page_id$);$changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$=$APP.$app$common$files$helpers$get_used_names$$($changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$);$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$809$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$97$$);$changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$809$$,
$changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1628$suffix_fn$$,function($copy_count$jscomp$2$$){return" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.copy-suffix")??"")+(($copy_count$jscomp$2$$>1?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($copy_count$jscomp$2$$)].join(""):null)??"")}]));var $objects$jscomp$614$$=$APP.$cljs$core$update_vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$97$$),
function($p1__70846_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__70846_SHARP_$$,$APP.$cljs$cst$2964$use_for_thumbnail$$)}),$main_not_variant_ids$$=$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__70847_SHARP_$$){return $APP.$app$common$types$component$main_instance_QMARK_$$($APP.$cljs$core$_val$$($p1__70847_SHARP_$$))&&!$APP.$app$common$types$component$is_variant_QMARK_$$($APP.$cljs$core$_val$$($p1__70847_SHARP_$$))?$APP.$cljs$core$_key$$($p1__70847_SHARP_$$):
null},$objects$jscomp$614$$)),$ids_to_remove$$=$APP.$cljs$core$set$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70848_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$614$$,$p1__70848_SHARP_$$)},$main_not_variant_ids$$))),$variant_mains$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$is_variant_QMARK_$$,
$APP.$cljs$core$vals$$($objects$jscomp$614$$)),$variants_ids_map$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ids_map$jscomp$20$$,$shape$jscomp$721$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($ids_map$jscomp$20$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$721$$),$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$721$$),
$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$721$$),$APP.$app$common$uuid$next$$()]))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$variant_mains$$);$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$809$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$,$JSCompiler_temp_const$jscomp$11000_p__70903$$){var $id$jscomp$728$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11000_p__70903$$,0,null),$JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11000_p__70903$$,1,null);if($APP.$cljs$core$contains_QMARK_$$($main_not_variant_ids$$,$id$jscomp$728$$))$JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$=$add_component_copy$$($JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$,
$id$jscomp$728$$,$JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$);else if(!$APP.$cljs$core$contains_QMARK_$$($ids_to_remove$$,$id$jscomp$728$$))if($APP.$cljs$core$contains_QMARK_$$($variants_ids_map$$,$id$jscomp$728$$)){$JSCompiler_temp_const$jscomp$11000_p__70903$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__70897__$1$jscomp$inline_13322$$=$APP.$cljs$core$contains_QMARK_$$($JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$,$APP.$cljs$cst$1627$component_id$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$))):$JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$;$JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$=$APP.$cljs$core$contains_QMARK_$$($JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$,
$APP.$cljs$cst$2000$variant_id$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70897__$1$jscomp$inline_13322$$,$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$))):$G__70897__$1$jscomp$inline_13322$$;$JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$=$JSCompiler_temp_const$jscomp$11000_p__70903$$.call($APP.$cljs$core$assoc$$,
$JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$,$id$jscomp$728$$,$JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$)}else $JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$,$id$jscomp$728$$,$JSCompiler_inline_result$jscomp$11002_shape$jscomp$723$$);
return $JSCompiler_temp$jscomp$10997_JSCompiler_temp$jscomp$10998_JSCompiler_temp$jscomp$10999_objs$jscomp$18$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$objects$jscomp$614$$);var $objects__$2$$=$APP.$cljs$core$reduce_kv$$(function($objs$jscomp$19$$,$___$1$jscomp$1662$$,$p__70916$$){var $map__70917__$1$$=$APP.$cljs$core$__destructure_map$$($p__70916$$),$id$jscomp$729$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70917__$1$$,$APP.$cljs$cst$266$id$$),$parent_id$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70917__$1$$,
$APP.$cljs$cst$1619$parent_id$$),$frame_id$jscomp$106$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70917__$1$$,$APP.$cljs$cst$1607$frame_id$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objs$jscomp$19$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$id$jscomp$729$$,$id$jscomp$729$$),function(){var $G__70920$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__70917__$1$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$id$jscomp$729$$,$id$jscomp$729$$)),$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$parent_id$jscomp$92$$,$parent_id$jscomp$92$$)),$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$frame_id$jscomp$106$$,$frame_id$jscomp$106$$));return $APP.$cljs$core$contains_QMARK_$$($map__70917__$1$$,$APP.$cljs$cst$1614$shapes$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70920$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70851_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$p1__70851_SHARP_$$,$p1__70851_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($map__70917__$1$$))):$G__70920$$}())},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$809$$),
$page__$1$jscomp$6$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$97$$,$APP.$cljs$cst$725$name$$,$changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$),$APP.$cljs$cst$266$id$$,$new_page_id$$),$APP.$cljs$cst$1631$objects$$,$objects__$2$$);$changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$=function(){var $JSCompiler_inline_result$jscomp$1672_changes$jscomp$248$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($it__$1$jscomp$97$$),$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2620$add_page$$,$APP.$cljs$cst$266$id$$,$new_page_id$$,$APP.$cljs$cst$1624$page$$,
$page__$1$jscomp$6$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2622$del_page$$,$APP.$cljs$cst$266$id$$,$new_page_id$$],null)));$JSCompiler_inline_result$jscomp$1672_changes$jscomp$248$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($JSCompiler_inline_result$jscomp$1672_changes$jscomp$248$$,$page__$1$jscomp$6$$),$objects__$2$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($add_comp$$,$JSCompiler_inline_result$jscomp$1672_changes$jscomp$248$$,$variant_mains$$)}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$246_it$jscomp$221_name$jscomp$343_pages$jscomp$5_unames$jscomp$12$$))});return new $app$main$data$workspace$pages$duplicate_page_70853$$($page_id$jscomp$237$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$rename_flow$$=function($flow_id$jscomp$9$$,$name$jscomp$340$$){typeof $app$main$data$workspace$interactions$rename_flow_70438$$==="undefined"&&($app$main$data$workspace$interactions$rename_flow_70438$$=function($flow_id$jscomp$10$$,$name$jscomp$341$$,$meta70439$$){this.$flow_id$=$flow_id$jscomp$10$$;this.name=$name$jscomp$341$$;this.$meta70439$=$meta70439$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$rename_flow_70438$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$rename_flow_70438$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4304$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_rename_flow$$},$app$main$data$workspace$interactions$rename_flow_70438$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70440$$,$meta70439__$1$$){return new $app$main$data$workspace$interactions$rename_flow_70438$$(this.$flow_id$,this.name,$meta70439__$1$$)},
$app$main$data$workspace$interactions$rename_flow_70438$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70439$},$app$main$data$workspace$interactions$rename_flow_70438$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$rename_flow_70438$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2391_page$jscomp$92$$,$state$jscomp$767$$){var $self__$jscomp$5711$$=this;$_$jscomp$2391_page$jscomp$92$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$767$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$interactions$update_flow$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2391_page$jscomp$92$$),$self__$jscomp$5711$$.$flow_id$,function($p1__70437_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70437_SHARP_$$,$APP.$cljs$cst$725$name$$,$self__$jscomp$5711$$.name)}))});return new $app$main$data$workspace$interactions$rename_flow_70438$$($flow_id$jscomp$9$$,
$name$jscomp$340$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$=function($flow_id$jscomp$4$$){return $APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$flow_id$jscomp$4$$)};
$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$01$$=function($starting_frame$jscomp$1$$){return $APP.$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$04$$(null,null,null,$starting_frame$jscomp$1$$)};
$app$main$data$workspace$interactions$add_flow_selected_frame$$=function(){typeof $app$main$data$workspace$interactions$add_flow_selected_frame_70405$$==="undefined"&&($app$main$data$workspace$interactions$add_flow_selected_frame_70405$$=function($meta70406$$){this.$meta70406$=$meta70406$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4301$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_flow_selected_frame$$},$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70407$$,$meta70406__$1$$){return new $app$main$data$workspace$interactions$add_flow_selected_frame_70405$$($meta70406__$1$$)},$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70406$},$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-prototype-interaction"],null)},$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_flow_selected_frame_70405$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2388_selected$jscomp$80$$,$state$jscomp$764$$){$_$jscomp$2388_selected$jscomp$80$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$764$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$first$$($_$jscomp$2388_selected$jscomp$80$$)))});
return new $app$main$data$workspace$interactions$add_flow_selected_frame_70405$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$update_guide_color$$=function($guide_id$jscomp$2$$,$color$jscomp$103$$){typeof $app$main$data$workspace$guides$update_guide_color_70300$$==="undefined"&&($app$main$data$workspace$guides$update_guide_color_70300$$=function($guide_id$jscomp$3$$,$color$jscomp$104$$,$meta70301$$){this.$guide_id$=$guide_id$jscomp$3$$;this.color=$color$jscomp$104$$;this.$meta70301$=$meta70301$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$guides$update_guide_color_70300$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guide_color_70300$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4292$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_update_guide_color$$},$app$main$data$workspace$guides$update_guide_color_70300$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70302$$,$meta70301__$1$$){return new $app$main$data$workspace$guides$update_guide_color_70300$$(this.$guide_id$,
this.color,$meta70301__$1$$)},$app$main$data$workspace$guides$update_guide_color_70300$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70301$},$app$main$data$workspace$guides$update_guide_color_70300$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guide_color_70300$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$,$guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$){$changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$);$changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$=$APP.$cljs$core$__destructure_map$$($changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$);$guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$,$APP.$cljs$cst$2057$guides$$);
$guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$,this.$guide_id$);return $guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$!=null?($guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$=this.color!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$,$APP.$cljs$cst$1298$color$$,
this.color):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$,$APP.$cljs$cst$1298$color$$),$changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$=$APP.$app$common$files$changes_builder$set_guide$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$),this.$guide_id$,
$guide$jscomp$8_guides$jscomp$8_state$jscomp$757_updated_guide$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$240_it$jscomp$216_map__70303_map__70303__$1$$))):null});return new $app$main$data$workspace$guides$update_guide_color_70300$$($guide_id$jscomp$2$$,$color$jscomp$103$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$remove_frame_guides$$=function($frame_ids$jscomp$3$$){typeof $app$main$data$workspace$guides$remove_frame_guides_70278$$==="undefined"&&($app$main$data$workspace$guides$remove_frame_guides_70278$$=function($frame_ids$jscomp$4$$,$meta70279$$){this.$frame_ids$=$frame_ids$jscomp$4$$;this.$meta70279$=$meta70279$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4291$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_frame_guides$$},$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70280$$,$meta70279__$1$$){return new $app$main$data$workspace$guides$remove_frame_guides_70278$$(this.$frame_ids$,$meta70279__$1$$)},
$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70279$},$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$,$state$jscomp$754$$){$_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$754$$);$_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$);$_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$,$APP.$cljs$cst$2057$guides$$);var $frame_ids_set$$=$APP.$cljs$core$set$$(this.$frame_ids$),
$guide_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__70276_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_ids_set$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70276_SHARP_$$))}),$APP.$app$common$data$xf_COLON_map_id$$),$APP.$cljs$core$vals$$($_$jscomp$2376_guides$jscomp$5_map__70284_map__70284__$1$$));
return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$754$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4289$workspace_guides$$,$APP.$cljs$cst$2204$hover$$],null),function($hover$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$disj$$,$APP.$cljs$core$truth_$$($hover$$)?$hover$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$guide_ids$$)})},$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_frame_guides_70278$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$,$guides$jscomp$6_state$jscomp$755_to_remove$$){$changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($guides$jscomp$6_state$jscomp$755_to_remove$$);$changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$=
$APP.$cljs$core$__destructure_map$$($changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$);$guides$jscomp$6_state$jscomp$755_to_remove$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$,$APP.$cljs$cst$2057$guides$$);var $frame_ids_set$jscomp$1$$=$APP.$cljs$core$set$$(this.$frame_ids$);$guides$jscomp$6_state$jscomp$755_to_remove$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70277_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_ids_set$jscomp$1$$,
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70277_SHARP_$$))},$APP.$cljs$core$vals$$($guides$jscomp$6_state$jscomp$755_to_remove$$));$changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$133$$,$id$jscomp$712_map__70290__$1_p__70289$$){$id$jscomp$712_map__70290__$1_p__70289$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$712_map__70290__$1_p__70289$$);$id$jscomp$712_map__70290__$1_p__70289$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$712_map__70290__$1_p__70289$$,$APP.$cljs$cst$266$id$$);return $APP.$app$common$files$changes_builder$set_guide$$($acc$jscomp$133$$,$id$jscomp$712_map__70290__$1_p__70289$$,null)},$APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$),$guides$jscomp$6_state$jscomp$755_to_remove$$);
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$239_it$jscomp$215_map__70285_map__70285__$1$$))});return new $app$main$data$workspace$guides$remove_frame_guides_70278$$($frame_ids$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$drag_selected_points$$=function($start_position$jscomp$1$$){typeof $app$main$data$workspace$path$edition$drag_selected_points_69899$$==="undefined"&&($app$main$data$workspace$path$edition$drag_selected_points_69899$$=function($start_position$jscomp$2$$,$meta69900$$){this.$start_position$=$start_position$jscomp$2$$;this.$meta69900$=$meta69900$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$drag_selected_points_69899$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$drag_selected_points_69899$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4255$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_drag_selected_points$$},$app$main$data$workspace$path$edition$drag_selected_points_69899$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69901$$,$meta69900__$1$$){return new $app$main$data$workspace$path$edition$drag_selected_points_69899$$(this.$start_position$,
$meta69900__$1$$)},$app$main$data$workspace$path$edition$drag_selected_points_69899$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69900$},$app$main$data$workspace$path$edition$drag_selected_points_69899$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$drag_selected_points_69899$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2333_stopper$jscomp$27$$,$content$jscomp$215_points$jscomp$91_state$jscomp$724$$,
$id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$){var $self__$jscomp$5531$$=this;$_$jscomp$2333_stopper$jscomp$27$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$,null);$id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$215_points$jscomp$91_state$jscomp$724$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$2199$edition$$);$id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$215_points$jscomp$91_state$jscomp$724$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$),$APP.$cljs$cst$4241$selected_points$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $start_position__$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$min_key$$,function($p1__69894_SHARP_$$){return $APP.$app$common$geom$point$distance$$($self__$jscomp$5531$$.$start_position$,$p1__69894_SHARP_$$)},$id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$);$content$jscomp$215_points$jscomp$91_state$jscomp$724$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($content$jscomp$215_points$jscomp$91_state$jscomp$724$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$content$jscomp$215_points$jscomp$91_state$jscomp$724$$=$APP.$app$common$types$path$get_points$$($content$jscomp$215_points$jscomp$91_state$jscomp$724$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2333_stopper$jscomp$27$$,$APP.$beicon$v2$core$map$$(function($p1__69895_SHARP_$$){return $app$main$data$workspace$path$edition$move_selected_path_point$$($start_position__$1$$,
$p1__69895_SHARP_$$)},$app$main$data$workspace$path$streams$move_points_stream$$($start_position__$1$$,$id$jscomp$691_selected_points$jscomp$5_stream$jscomp$77$$,$content$jscomp$215_points$jscomp$91_state$jscomp$724$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$edition$apply_content_modifiers$$()))});return new $app$main$data$workspace$path$edition$drag_selected_points_69899$$($start_position$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$split_segments$$=function($id$jscomp$700$$,$p__69986$$){var $map__69987__$1$$=$APP.$cljs$core$__destructure_map$$($p__69986$$),$from_p$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69987__$1$$,$APP.$cljs$cst$1853$from_p$$),$to_p$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69987__$1$$,$APP.$cljs$cst$1854$to_p$$),$t$jscomp$96$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69987__$1$$,$APP.$cljs$cst$1852$t$$);
typeof $app$main$data$workspace$path$edition$split_segments_69991$$==="undefined"&&($app$main$data$workspace$path$edition$split_segments_69991$$=function($id$jscomp$701$$,$p__69986$jscomp$1$$,$map__69987$jscomp$1$$,$from_p$jscomp$15$$,$to_p$jscomp$13$$,$t$jscomp$97$$,$meta69992$$){this.id=$id$jscomp$701$$;this.$p__69986$=$p__69986$jscomp$1$$;this.$map__69987$=$map__69987$jscomp$1$$;this.$from_p$=$from_p$jscomp$15$$;this.$to_p$=$to_p$jscomp$13$$;this.t=$t$jscomp$97$$;this.$meta69992$=$meta69992$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4262$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_split_segments$$},$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69993$$,$meta69992__$1$$){return new $app$main$data$workspace$path$edition$split_segments_69991$$(this.id,this.$p__69986$,this.$map__69987$,this.$from_p$,this.$to_p$,this.t,$meta69992__$1$$)},$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69992$},$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$,$JSCompiler_temp_const$jscomp$793_state$jscomp$731$$){$JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_temp_const$jscomp$793_state$jscomp$731$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));
$JSCompiler_temp_const$jscomp$793_state$jscomp$731$$=$APP.$cljs$core$assoc_in$$($JSCompiler_temp_const$jscomp$793_state$jscomp$731$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,this.id,$APP.$cljs$cst$4199$old_content$$],null),$JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$);var $points$jscomp$inline_8470$$=$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.$to_p$,
this.$from_p$]),$value$jscomp$inline_8471$$=this.t;$JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$=$APP.$app$common$types$path$impl$path_data$$($JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$);$JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$=$APP.$app$common$types$path$segment$split_segments$$($JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$,
$points$jscomp$inline_8470$$,$value$jscomp$inline_8471$$);return $APP.$app$main$data$workspace$path$state$set_content$$($JSCompiler_temp_const$jscomp$793_state$jscomp$731$$,$APP.$app$common$types$path$impl$path_data$$($JSCompiler_inline_result$jscomp$794__$jscomp$2343_content$jscomp$217_content__$1$jscomp$inline_8472$$))},$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$split_segments_69991$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4197$preserve_move_to$$,!0],null)))});return new $app$main$data$workspace$path$edition$split_segments_69991$$($id$jscomp$700$$,$p__69986$$,$map__69987__$1$$,$from_p$jscomp$14$$,$to_p$jscomp$12$$,$t$jscomp$96$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$update_component$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$593$$,$undo_group$jscomp$24$$){typeof $app$main$data$workspace$libraries$update_component_69685$$==="undefined"&&($app$main$data$workspace$libraries$update_component_69685$$=function($id$jscomp$594$$,$undo_group$jscomp$25$$,$meta69686$$){this.id=$id$jscomp$594$$;this.$undo_group$=$undo_group$jscomp$25$$;this.$meta69686$=$meta69686$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$update_component_69685$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_69685$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3951$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component$$},$app$main$data$workspace$libraries$update_component_69685$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69687$$,$meta69686__$1$$){return new $app$main$data$workspace$libraries$update_component_69685$$(this.id,
this.$undo_group$,$meta69686__$1$$)},$app$main$data$workspace$libraries$update_component_69685$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69686$},$app$main$data$workspace$libraries$update_component_69685$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_69685$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file$jscomp$65_it$jscomp$200$$,$ldata$jscomp$3_state$jscomp$516$$){var $self__$jscomp$4854$$=
this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"UPDATE-COMPONENT of shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4854$$.id)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$4854$$.$undo_group$],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$,!1);var $page_id$jscomp$186_shape$jscomp$557$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($ldata$jscomp$3_state$jscomp$516$$),
$changes$jscomp$219_libraries$jscomp$74$$=$APP.$app$main$data$helpers$lookup_libraries$$($ldata$jscomp$3_state$jscomp$516$$);$file$jscomp$65_it$jscomp$200$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($ldata$jscomp$3_state$jscomp$516$$);var $fdata$jscomp$13$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$65_it$jscomp$200$$),$container$jscomp$71$$=$APP.$app$common$types$container$get_container$$($fdata$jscomp$13$$,$page_id$jscomp$186_shape$jscomp$557$$);
$page_id$jscomp$186_shape$jscomp$557$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$71$$,$self__$jscomp$4854$$.id);if($APP.$app$common$types$component$instance_head_QMARK_$$($page_id$jscomp$186_shape$jscomp$557$$)){$changes$jscomp$219_libraries$jscomp$74$$=$app$common$logic$libraries$generate_sync_shape_inverse$$($APP.$app$common$files$changes_builder$with_container$$($APP.$app$common$files$changes_builder$set_undo_group$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$self__$jscomp$4854$$.$undo_group$),$container$jscomp$71$$),$fdata$jscomp$13$$,$changes$jscomp$219_libraries$jscomp$74$$,$container$jscomp$71$$,$self__$jscomp$4854$$.id);$ldata$jscomp$3_state$jscomp$516$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($ldata$jscomp$3_state$jscomp$516$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$186_shape$jscomp$557$$));var $xf_filter$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3540$local_change_QMARK_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69674_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__69674_SHARP_$$,$APP.$cljs$cst$3540$local_change_QMARK_$$)})),$local_changes$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$219_libraries$jscomp$74$$,$APP.$cljs$cst$3133$redo_changes$$,function($p1__69675_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$xf_filter$$,$p1__69675_SHARP_$$)}),$APP.$cljs$cst$3137$undo_changes$$,function($p1__69676_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xf_filter$$,$p1__69676_SHARP_$$)}),$xf_remove$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3540$local_change_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69677_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__69677_SHARP_$$,
$APP.$cljs$cst$3540$local_change_QMARK_$$)})),$nonlocal_changes$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$219_libraries$jscomp$74$$,$APP.$cljs$cst$3133$redo_changes$$,function($p1__69678_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xf_remove$$,$p1__69678_SHARP_$$)}),$APP.$cljs$cst$3137$undo_changes$$,function($p1__69679_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$xf_remove$$,$p1__69679_SHARP_$$)});$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"UPDATE-COMPONENT finished"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3952$js_SLASH_local_changes$$,$APP.$app$main$data$workspace$libraries$log_changes$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($local_changes$$),$fdata$jscomp$13$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3953$js_SLASH_nonlocal_changes$$,$APP.$app$main$data$workspace$libraries$log_changes$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($nonlocal_changes$$),
$fdata$jscomp$13$$)],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$seq$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($local_changes$$))?$APP.$app$main$data$changes$commit_changes$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local_changes$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$65_it$jscomp$200$$))):null,$APP.$cljs$core$seq$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($nonlocal_changes$$))?
$APP.$app$main$data$changes$commit_changes$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nonlocal_changes$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ldata$jscomp$3_state$jscomp$516$$))):null)}return null});return new $app$main$data$workspace$libraries$update_component_69685$$($id$jscomp$593$$,$undo_group$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$update_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$=function($shape_id$jscomp$102$$,$file_id$jscomp$158$$){typeof $app$main$data$workspace$libraries$update_component_sync_69716$$==="undefined"&&($app$main$data$workspace$libraries$update_component_sync_69716$$=function($shape_id$jscomp$103$$,$file_id$jscomp$159$$,$undo_group$jscomp$27$$,$meta69717$$){this.$shape_id$=$shape_id$jscomp$103$$;this.$file_id$=$file_id$jscomp$159$$;this.$undo_group$=$undo_group$jscomp$27$$;
this.$meta69717$=$meta69717$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_component_sync_69716$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_sync_69716$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3954$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component_sync$$},$app$main$data$workspace$libraries$update_component_sync_69716$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69718$$,$meta69717__$1$$){return new $app$main$data$workspace$libraries$update_component_sync_69716$$(this.$shape_id$,this.$file_id$,this.$undo_group$,$meta69717__$1$$)},$app$main$data$workspace$libraries$update_component_sync_69716$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69717$},$app$main$data$workspace$libraries$update_component_sync_69716$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_sync_69716$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2127_current_file_id$jscomp$8$$,$state$jscomp$518$$){$_$jscomp$2127_current_file_id$jscomp$8$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$518$$);var $current_file_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2127_current_file_id$jscomp$8$$,this.$file_id$),$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$518$$);$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$=
$APP.$app$common$types$container$get_shape$$($component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$shape_id$);$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$);var $undo_id$jscomp$29$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$29$$),$app$main$data$workspace$libraries$update_component$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$shape_id$,
this.$undo_group$),$APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$($state$jscomp$518$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$file_id$,"frame"),$APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$($state$jscomp$518$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$file_id$,"component"),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$($_$jscomp$2127_current_file_id$jscomp$8$$,
this.$file_id$,$APP.$cljs$cst$1638$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$undo_group$):$APP.$app$main$data$workspace$libraries$sync_file$$($_$jscomp$2127_current_file_id$jscomp$8$$,this.$file_id$,$APP.$cljs$cst$1638$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$undo_group$),$current_file_QMARK_$$?null:$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$(this.$file_id$,
this.$file_id$,$APP.$cljs$cst$1638$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$undo_group$):$APP.$app$main$data$workspace$libraries$sync_file$$(this.$file_id$,this.$file_id$,$APP.$cljs$cst$1638$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$558$$,this.$undo_group$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$29$$))});return new $app$main$data$workspace$libraries$update_component_sync_69716$$($shape_id$jscomp$102$$,
$file_id$jscomp$158$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$reset_component$$=function($id$jscomp$590$$){typeof $app$main$data$workspace$libraries$reset_component_69663$$==="undefined"&&($app$main$data$workspace$libraries$reset_component_69663$$=function($id$jscomp$591$$,$meta69664$$){this.id=$id$jscomp$591$$;this.$meta69664$=$meta69664$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$reset_component_69663$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$libraries$reset_component_69663$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3948$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_reset_component$$},$app$main$data$workspace$libraries$reset_component_69663$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69665$$,$meta69664__$1$$){return new $app$main$data$workspace$libraries$reset_component_69663$$(this.id,$meta69664__$1$$)},$app$main$data$workspace$libraries$reset_component_69663$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69664$},$app$main$data$workspace$libraries$reset_component_69663$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$reset_component_69663$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$199_libraries$jscomp$73$$,$container$jscomp$70_data$jscomp$364_state$jscomp$515$$){var $self__$jscomp$4846$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"RESET-COMPONENT of shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4846$$.id)],
null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$,!1);$it$jscomp$199_libraries$jscomp$73$$=$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$70_data$jscomp$364_state$jscomp$515$$);var $page_id$jscomp$185_undo_id$jscomp$27$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$70_data$jscomp$364_state$jscomp$515$$),$file$jscomp$64$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($container$jscomp$70_data$jscomp$364_state$jscomp$515$$);
$container$jscomp$70_data$jscomp$364_state$jscomp$515$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$64$$);$container$jscomp$70_data$jscomp$364_state$jscomp$515$$=$APP.$app$common$types$container$get_container$$($container$jscomp$70_data$jscomp$364_state$jscomp$515$$,$page_id$jscomp$185_undo_id$jscomp$27$$);$page_id$jscomp$185_undo_id$jscomp$27$$=Symbol();var $changes$jscomp$218$$=$app$common$logic$libraries$generate_reset_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$file$jscomp$64$$,$it$jscomp$199_libraries$jscomp$73$$,$container$jscomp$70_data$jscomp$364_state$jscomp$515$$,$self__$jscomp$4846$$.id);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1546$msg$$,"RESET-COMPONENT finished"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3949$js_SLASH_rchanges$$,$APP.$app$main$data$workspace$libraries$log_changes$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$218$$),$file$jscomp$64$$)],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($page_id$jscomp$185_undo_id$jscomp$27$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$218$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($page_id$jscomp$185_undo_id$jscomp$27$$))});return new $app$main$data$workspace$libraries$reset_component_69663$$($id$jscomp$590$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$reset_components$$=function($ids$jscomp$146$$){typeof $app$main$data$workspace$libraries$reset_components_69668$$==="undefined"&&($app$main$data$workspace$libraries$reset_components_69668$$=function($ids$jscomp$147$$,$meta69669$$){this.ids=$ids$jscomp$147$$;this.$meta69669$=$meta69669$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$reset_components_69668$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$reset_components_69668$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3950$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_reset_components$$},$app$main$data$workspace$libraries$reset_components_69668$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69670$$,$meta69669__$1$$){return new $app$main$data$workspace$libraries$reset_components_69668$$(this.ids,$meta69669__$1$$)},
$app$main$data$workspace$libraries$reset_components_69668$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69669$},$app$main$data$workspace$libraries$reset_components_69668$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$reset_components_69668$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$28$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$28$$)),
$APP.$beicon$v2$core$map$$(function($p1__69667_SHARP_$$){return $app$main$data$workspace$libraries$reset_component$$($p1__69667_SHARP_$$)},$APP.$beicon$v2$core$from$$(this.ids)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$28$$)))});return new $app$main$data$workspace$libraries$reset_components_69668$$($ids$jscomp$146$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$detach_components$$=function($ids$jscomp$141$$){typeof $app$main$data$workspace$libraries$detach_components_69610$$==="undefined"&&($app$main$data$workspace$libraries$detach_components_69610$$=function($ids$jscomp$142$$,$meta69612$$){this.ids=$ids$jscomp$142$$;this.$meta69612$=$meta69612$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$detach_components_69610$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_components_69610$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3935$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_components$$},$app$main$data$workspace$libraries$detach_components_69610$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69613$$,$meta69612__$1$$){return new $app$main$data$workspace$libraries$detach_components_69610$$(this.ids,$meta69612__$1$$)},
$app$main$data$workspace$libraries$detach_components_69610$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69612$},$app$main$data$workspace$libraries$detach_components_69610$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_components_69610$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$26$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$26$$)),
$APP.$beicon$v2$core$map$$(function($p1__69608_SHARP_$$){return $APP.$app$main$data$workspace$libraries$detach_component$$($p1__69608_SHARP_$$)},$APP.$beicon$v2$core$from$$(this.ids)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$26$$)))});return new $app$main$data$workspace$libraries$detach_components_69610$$($ids$jscomp$141$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$restore_component$$=function($library_id$jscomp$34$$,$component_id$jscomp$52$$){typeof $app$main$data$workspace$libraries$restore_component_69573$$==="undefined"&&($app$main$data$workspace$libraries$restore_component_69573$$=function($library_id$jscomp$35$$,$component_id$jscomp$53$$,$meta69574$$){this.$library_id$=$library_id$jscomp$35$$;this.$component_id$=$component_id$jscomp$53$$;this.$meta69574$=$meta69574$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$restore_component_69573$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_component_69573$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3927$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_restore_component$$},$app$main$data$workspace$libraries$restore_component_69573$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69575$$,$meta69574__$1$$){return new $app$main$data$workspace$libraries$restore_component_69573$$(this.$library_id$,this.$component_id$,$meta69574__$1$$)},$app$main$data$workspace$libraries$restore_component_69573$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69574$},$app$main$data$workspace$libraries$restore_component_69573$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_component_69573$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($current_file_id$jscomp$6_it$jscomp$195_local_QMARK_$jscomp$4$$,$changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$){$current_file_id$jscomp$6_it$jscomp$195_local_QMARK_$jscomp$4$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$);$current_file_id$jscomp$6_it$jscomp$195_local_QMARK_$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_file_id$jscomp$6_it$jscomp$195_local_QMARK_$jscomp$4$$,this.$library_id$);
$changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$,this.$library_id$);var $comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,
this.$component_id$],null));$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$);$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$=$APP.$app$main$data$helpers$get_page$$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$,$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$);var $frames$jscomp$14_objects$jscomp$504$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$);
$changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$=$app$common$logic$libraries$generate_restore_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$,this.$component_id$,this.$library_id$,$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$,$frames$jscomp$14_objects$jscomp$504$$);$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$=$APP.$cljs$core$first$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2043$page_id$$,
$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$)));$frames$jscomp$14_objects$jscomp$504$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$211_ldata$jscomp$2_state$jscomp$507$$),
$current_file_id$jscomp$6_it$jscomp$195_local_QMARK_$jscomp$4$$?$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$179$$,$APP.$cljs$cst$1723$ids$$,$frames$jscomp$14_objects$jscomp$504$$],null)):null)});return new $app$main$data$workspace$libraries$restore_component_69573$$($library_id$jscomp$34$$,$component_id$jscomp$52$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$restore_components$$=function($components_data$$){typeof $app$main$data$workspace$libraries$restore_components_69577$$==="undefined"&&($app$main$data$workspace$libraries$restore_components_69577$$=function($components_data$jscomp$1$$,$meta69578$$){this.$components_data$=$components_data$jscomp$1$$;this.$meta69578$=$meta69578$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$restore_components_69577$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_components_69577$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3928$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_restore_components$$},$app$main$data$workspace$libraries$restore_components_69577$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69579$$,$meta69578__$1$$){return new $app$main$data$workspace$libraries$restore_components_69577$$(this.$components_data$,
$meta69578__$1$$)},$app$main$data$workspace$libraries$restore_components_69577$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69578$},$app$main$data$workspace$libraries$restore_components_69577$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_components_69577$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$24$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$24$$)),
$APP.$beicon$v2$core$map$$(function($p1__69576_SHARP_$$){return $app$main$data$workspace$libraries$restore_component$$($APP.$cljs$core$_val$$($p1__69576_SHARP_$$),$APP.$cljs$core$_key$$($p1__69576_SHARP_$$))},$APP.$beicon$v2$core$from$$(this.$components_data$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$24$$)))});return new $app$main$data$workspace$libraries$restore_components_69577$$($components_data$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$add_multiple_components$$=function(){typeof $app$main$data$workspace$libraries$add_multiple_components_69530$$==="undefined"&&($app$main$data$workspace$libraries$add_multiple_components_69530$$=function($meta69531$$){this.$meta69531$=$meta69531$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$add_multiple_components_69530$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$libraries$add_multiple_components_69530$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3922$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_multiple_components$$},$app$main$data$workspace$libraries$add_multiple_components_69530$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69532$$,$meta69531__$1$$){return new $app$main$data$workspace$libraries$add_multiple_components_69530$$($meta69531__$1$$)},$app$main$data$workspace$libraries$add_multiple_components_69530$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69531$},$app$main$data$workspace$libraries$add_multiple_components_69530$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_multiple_components_69530$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2107_can_make_component$jscomp$1_selected_objects$jscomp$1$$,$added_components_selected$jscomp$57_state$jscomp$502$$){var $objects$jscomp$502$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($added_components_selected$jscomp$57_state$jscomp$502$$);
$added_components_selected$jscomp$57_state$jscomp$502$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$502$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($added_components_selected$jscomp$57_state$jscomp$502$$));$_$jscomp$2107_can_make_component$jscomp$1_selected_objects$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69528_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$502$$,$p1__69528_SHARP_$$)},
$added_components_selected$jscomp$57_state$jscomp$502$$);$_$jscomp$2107_can_make_component$jscomp$1_selected_objects$jscomp$1$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69529_SHARP_$$){return $APP.$app$common$types$container$valid_shape_for_component_QMARK_$$($objects$jscomp$502$$,$p1__69529_SHARP_$$)},$_$jscomp$2107_can_make_component$jscomp$1_selected_objects$jscomp$1$$));$added_components_selected$jscomp$57_state$jscomp$502$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$580$$){return $APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$libraries$add_component2$cljs$0core$0IFn$0_invoke$0arity$02$$(null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$580$$],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1616$multiple$$,!0],null))},$added_components_selected$jscomp$57_state$jscomp$502$$);var $undo_id$jscomp$22$$=
Symbol();return $_$jscomp$2107_can_make_component$jscomp$1_selected_objects$jscomp$1$$?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$22$$)),$APP.$beicon$v2$core$from$$($added_components_selected$jscomp$57_state$jscomp$502$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$22$$))):null});return new $app$main$data$workspace$libraries$add_multiple_components_69530$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$duplicate_typography$$=function($file_id$jscomp$144$$,$typography_id$jscomp$6$$){typeof $app$main$data$workspace$libraries$duplicate_typography_69508$$==="undefined"&&($app$main$data$workspace$libraries$duplicate_typography_69508$$=function($file_id$jscomp$145$$,$typography_id$jscomp$7$$,$meta69509$$){this.$file_id$=$file_id$jscomp$145$$;this.$typography_id$=$typography_id$jscomp$7$$;this.$meta69509$=$meta69509$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$duplicate_typography_69508$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_typography_69508$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3919$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_typography$$},$app$main$data$workspace$libraries$duplicate_typography_69508$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69510$$,$meta69509__$1$$){return new $app$main$data$workspace$libraries$duplicate_typography_69508$$(this.$file_id$,this.$typography_id$,$meta69509__$1$$)},$app$main$data$workspace$libraries$duplicate_typography_69508$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69509$},$app$main$data$workspace$libraries$duplicate_typography_69508$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_typography_69508$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$,$state$jscomp$499$$){$changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$499$$);$changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,this.$typography_id$],null));$changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=(0,$APP.$app$common$types$typography$check_typography$$)($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()));
$changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=$APP.$app$common$files$changes_builder$add_typography$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$206_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$))});
return new $app$main$data$workspace$libraries$duplicate_typography_69508$$($file_id$jscomp$144$$,$typography_id$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$delete_media$$=function($p__69476$$){var $map__69477__$1$$=$APP.$cljs$core$__destructure_map$$($p__69476$$),$id$jscomp$574$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69477__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$libraries$delete_media_69478$$==="undefined"&&($app$main$data$workspace$libraries$delete_media_69478$$=function($p__69476$jscomp$1$$,$map__69477$jscomp$1$$,$id$jscomp$575$$,$meta69479$$){this.$p__69476$=$p__69476$jscomp$1$$;
this.$map__69477$=$map__69477$jscomp$1$$;this.id=$id$jscomp$575$$;this.$meta69479$=$meta69479$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3913$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_media$$},
$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69480$$,$meta69479__$1$$){return new $app$main$data$workspace$libraries$delete_media_69478$$(this.$p__69476$,this.$map__69477$,this.id,$meta69479__$1$$)},$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69479$},$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)},$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_media_69478$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$,
$id$jscomp$inline_8475_state$jscomp$494$$){$changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$inline_8475_state$jscomp$494$$);$changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$);
$id$jscomp$inline_8475_state$jscomp$494$$=this.id;var $library_data$jscomp$inline_8476_prev_object$jscomp$inline_8477$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$));$library_data$jscomp$inline_8476_prev_object$jscomp$inline_8477$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$inline_8476_prev_object$jscomp$inline_8477$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1639$media$$,$id$jscomp$inline_8475_state$jscomp$494$$],null));$changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2630$del_media$$,$APP.$cljs$cst$266$id$$,$id$jscomp$inline_8475_state$jscomp$494$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2628$add_media$$,$APP.$cljs$cst$2198$object$$,$library_data$jscomp$inline_8476_prev_object$jscomp$inline_8477$$],null)));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$202_changes$jscomp$inline_8474_data$jscomp$356_it$jscomp$183$$))});return new $app$main$data$workspace$libraries$delete_media_69478$$($p__69476$$,$map__69477__$1$$,$id$jscomp$574$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$duplicate_color$$=function($file_id$jscomp$137$$,$color_id$jscomp$6$$){typeof $app$main$data$workspace$libraries$duplicate_color_69464$$==="undefined"&&($app$main$data$workspace$libraries$duplicate_color_69464$$=function($file_id$jscomp$138$$,$color_id$jscomp$7$$,$meta69465$$){this.$file_id$=$file_id$jscomp$138$$;this.$color_id$=$color_id$jscomp$7$$;this.$meta69465$=$meta69465$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$duplicate_color_69464$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_color_69464$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3910$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_color$$},$app$main$data$workspace$libraries$duplicate_color_69464$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69466$$,$meta69465__$1$$){return new $app$main$data$workspace$libraries$duplicate_color_69464$$(this.$file_id$,
this.$color_id$,$meta69465__$1$$)},$app$main$data$workspace$libraries$duplicate_color_69464$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69465$},$app$main$data$workspace$libraries$duplicate_color_69464$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_color_69464$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$,
$state$jscomp$492$$){$changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$492$$);$changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=$APP.$app$common$types$library$get_color$$($changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$,this.$color_id$);$changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$,
$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$())));$changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=$APP.$app$common$files$changes_builder$add_color$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$199_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$))});
return new $app$main$data$workspace$libraries$duplicate_color_69464$$($file_id$jscomp$137$$,$color_id$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$add_shapes_and_component$$=function($JSCompiler_inline_result$jscomp$1669_changes$jscomp$inline_8479_it$jscomp$161$$,$file_data$jscomp$70_objects$jscomp$inline_8480$$,$main_instance_page$jscomp$inline_8488_page$jscomp$68$$,$changes$jscomp$178_name$jscomp$315$$,$p__67767_updated_shapes$jscomp$6_vec__67771$$){var $main_instance_id$jscomp$inline_8487_shape$jscomp$457$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67767_updated_shapes$jscomp$6_vec__67771$$,
0,null),$children$jscomp$215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67767_updated_shapes$jscomp$6_vec__67771$$,1,null);$p__67767_updated_shapes$jscomp$6_vec__67771$$=$APP.$app$common$types$container$convert_shape_in_component$$($main_instance_id$jscomp$inline_8487_shape$jscomp$457$$,$children$jscomp$215$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$70_objects$jscomp$inline_8480$$));var $component_shape$jscomp$5_id$jscomp$inline_8483$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67767_updated_shapes$jscomp$6_vec__67771$$,
0,null);$p__67767_updated_shapes$jscomp$6_vec__67771$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67767_updated_shapes$jscomp$6_vec__67771$$,1,null);$JSCompiler_inline_result$jscomp$1669_changes$jscomp$inline_8479_it$jscomp$161$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_inline_result$jscomp$1669_changes$jscomp$inline_8479_it$jscomp$161$$),
$main_instance_page$jscomp$inline_8488_page$jscomp$68$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$inline_8488_page$jscomp$68$$)),$file_data$jscomp$70_objects$jscomp$inline_8480$$);$file_data$jscomp$70_objects$jscomp$inline_8480$$=$APP.$cljs$core$cons$$($main_instance_id$jscomp$inline_8487_shape$jscomp$457$$,$children$jscomp$215$$);$JSCompiler_inline_result$jscomp$1669_changes$jscomp$inline_8479_it$jscomp$161$$=$APP.$app$common$files$changes_builder$add_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1669_changes$jscomp$inline_8479_it$jscomp$161$$,
$file_data$jscomp$70_objects$jscomp$inline_8480$$,null);$component_shape$jscomp$5_id$jscomp$inline_8483$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$5_id$jscomp$inline_8483$$);$main_instance_id$jscomp$inline_8487_shape$jscomp$457$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_id$jscomp$inline_8487_shape$jscomp$457$$);$main_instance_page$jscomp$inline_8488_page$jscomp$68$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$inline_8488_page$jscomp$68$$);
$changes$jscomp$178_name$jscomp$315$$=$APP.$app$common$files$changes_builder$add_component$$($JSCompiler_inline_result$jscomp$1669_changes$jscomp$inline_8479_it$jscomp$161$$,$component_shape$jscomp$5_id$jscomp$inline_8483$$,"",$changes$jscomp$178_name$jscomp$315$$,$p__67767_updated_shapes$jscomp$6_vec__67771$$,$main_instance_id$jscomp$inline_8487_shape$jscomp$457$$,$main_instance_page$jscomp$inline_8488_page$jscomp$68$$,null,null,null);return $APP.$app$main$data$changes$commit_changes$$($changes$jscomp$178_name$jscomp$315$$)};
$app$main$data$workspace$media$process_svg_component$$=function($svg_data$jscomp$21$$){typeof $app$main$data$workspace$media$process_svg_component_67780$$==="undefined"&&($app$main$data$workspace$media$process_svg_component_67780$$=function($svg_data$jscomp$22$$,$meta67781$$){this.$svg_data$=$svg_data$jscomp$22$$;this.$meta67781$=$meta67781$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$process_svg_component_67780$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_svg_component_67780$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3709$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_svg_component$$},$app$main$data$workspace$media$process_svg_component_67780$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67782$$,$meta67781__$1$$){return new $app$main$data$workspace$media$process_svg_component_67780$$(this.$svg_data$,$meta67781__$1$$)},
$app$main$data$workspace$media$process_svg_component_67780$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67781$},$app$main$data$workspace$media$process_svg_component_67780$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_svg_component_67780$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file_id$jscomp$106_it$jscomp$163$$,$pos$jscomp$106_state$jscomp$408$$){$file_id$jscomp$106_it$jscomp$163$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$106_state$jscomp$408$$);var $page$jscomp$70_page_id$jscomp$130$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$106_state$jscomp$408$$),$fdata$jscomp$9$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$106_state$jscomp$408$$,$file_id$jscomp$106_it$jscomp$163$$);$page$jscomp$70_page_id$jscomp$130$$=$APP.$app$main$data$helpers$get_page$$($fdata$jscomp$9$$,
$page$jscomp$70_page_id$jscomp$130$$);$pos$jscomp$106_state$jscomp$408$$=$APP.$app$main$data$helpers$get_viewport_center$$($pos$jscomp$106_state$jscomp$408$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$media$add_shapes_and_component$$,this,$fdata$jscomp$9$$,$page$jscomp$70_page_id$jscomp$130$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.$svg_data$)])),
$app$main$data$workspace$media$create_shapes_svg$$($file_id$jscomp$106_it$jscomp$163$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$70_page_id$jscomp$130$$),$pos$jscomp$106_state$jscomp$408$$,this.$svg_data$))});return new $app$main$data$workspace$media$process_svg_component_67780$$($svg_data$jscomp$21$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$process_img_component$$=function($media_obj$jscomp$1$$){typeof $app$main$data$workspace$media$process_img_component_67775$$==="undefined"&&($app$main$data$workspace$media$process_img_component_67775$$=function($media_obj$jscomp$2$$,$meta67776$$){this.$media_obj$=$media_obj$jscomp$2$$;this.$meta67776$=$meta67776$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$process_img_component_67775$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_img_component_67775$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3708$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_img_component$$},$app$main$data$workspace$media$process_img_component_67775$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67777$$,$meta67776__$1$$){return new $app$main$data$workspace$media$process_img_component_67775$$(this.$media_obj$,$meta67776__$1$$)},
$app$main$data$workspace$media$process_img_component_67775$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67776$},$app$main$data$workspace$media$process_img_component_67775$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_img_component_67775$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$,$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$){$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$);var $name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$);$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$,
$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$);$name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$=$APP.$app$main$data$helpers$get_page$$($JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$,$name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$);$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$=$APP.$app$main$data$helpers$get_viewport_center$$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$);
$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$media$add_shapes_and_component$$,this,$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$,$name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.$media_obj$)]));
var $frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$=$APP.$cljs$core$__destructure_map$$(this.$media_obj$);$name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$,$APP.$cljs$cst$725$name$$);var $width$jscomp$inline_8494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$,$APP.$cljs$cst$290$width$$),
$height$jscomp$inline_8495$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$,$APP.$cljs$cst$1522$height$$),$id$jscomp$inline_8496_img_fills$jscomp$inline_8499$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$,$APP.$cljs$cst$266$id$$),$mtype$jscomp$inline_8497$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$,
$APP.$cljs$cst$1726$mtype$$);$frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$),
$APP.$cljs$cst$290$width$$,$width$jscomp$inline_8494$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$inline_8495$$,$APP.$cljs$cst$725$name$$,$name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$],null));$id$jscomp$inline_8496_img_fills$jscomp$inline_8499$$=$APP.$app$common$types$fills$create$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1747$fill_opacity$$,1,$APP.$cljs$cst$1632$fill_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$id$jscomp$inline_8496_img_fills$jscomp$inline_8499$$,$APP.$cljs$cst$290$width$$,$width$jscomp$inline_8494$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$inline_8495$$,$APP.$cljs$cst$1726$mtype$$,$mtype$jscomp$inline_8497$$,$APP.$cljs$cst$1727$keep_aspect_ratio$$,!0],null)],null)]));$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$=
$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1522$height$$],[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$),$name$jscomp$inline_8493_page$jscomp$69_page_id$jscomp$129$$,
$width$jscomp$inline_8494$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$),$id$jscomp$inline_8496_img_fills$jscomp$inline_8499$$,
$height$jscomp$inline_8495$$]));$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$=(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_shape$jscomp$inline_8498_map__67766__$1$jscomp$inline_8492$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$],
null)],null));return $APP.$beicon$v2$core$map$$($JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$105_it$jscomp$162$$,$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8500_pos$jscomp$105_state$jscomp$407$$)});return new $app$main$data$workspace$media$process_img_component_67775$$($media_obj$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$merge_cells$$=function($layout_id$jscomp$6$$,$ids$jscomp$244$$){typeof $app$main$data$workspace$shape_layout$merge_cells_71269$$==="undefined"&&($app$main$data$workspace$shape_layout$merge_cells_71269$$=function($layout_id$jscomp$7$$,$ids$jscomp$245$$,$meta71270$$){this.$layout_id$=$layout_id$jscomp$7$$;this.ids=$ids$jscomp$245$$;this.$meta71270$=$meta71270$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$merge_cells_71269$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$merge_cells_71269$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4414$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_merge_cells$$},$app$main$data$workspace$shape_layout$merge_cells_71269$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71271$$,$meta71270__$1$$){return new $app$main$data$workspace$shape_layout$merge_cells_71269$$(this.$layout_id$,this.ids,$meta71270__$1$$)},
$app$main$data$workspace$shape_layout$merge_cells_71269$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71270$},$app$main$data$workspace$shape_layout$merge_cells_71269$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$merge_cells_71269$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6010$$=this,$undo_id$jscomp$60$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$60$$),
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6010$$.$layout_id$],null),function($shape$jscomp$742$$,$objects$jscomp$635$$){var $cells$jscomp$23_first_row$jscomp$11_map__71273$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71267_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$742$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$p1__71267_SHARP_$$],null))},$self__$jscomp$6010$$.ids);$cells$jscomp$23_first_row$jscomp$11_map__71273$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$23_first_row$jscomp$11_map__71273$$);var $last_column$jscomp$11_map__71273__$1$$=$APP.$cljs$core$__destructure_map$$($cells$jscomp$23_first_row$jscomp$11_map__71273$$);$cells$jscomp$23_first_row$jscomp$11_map__71273$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71273__$1$$,
$APP.$cljs$cst$1715$first_row$$);var $first_column$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71273__$1$$,$APP.$cljs$cst$1716$first_column$$),$last_row$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71273__$1$$,$APP.$cljs$cst$1717$last_row$$);$last_column$jscomp$11_map__71273__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71273__$1$$,$APP.$cljs$cst$1718$last_column$$);
var $target_cell$jscomp$9$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($shape$jscomp$742$$,$cells$jscomp$23_first_row$jscomp$11_map__71273$$,$first_column$jscomp$11$$);return $APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($shape$jscomp$742$$,$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$9$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$9$$),$cells$jscomp$23_first_row$jscomp$11_map__71273$$,
$first_column$jscomp$11$$,$last_row$jscomp$11$$-$cells$jscomp$23_first_row$jscomp$11_map__71273$$+1,$last_column$jscomp$11_map__71273__$1$$-$first_column$jscomp$11$$+1),$objects$jscomp$635$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$APP.$app$main$data$workspace$grid_layout$editor$clean_selection$$($self__$jscomp$6010$$.$layout_id$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6010$$.$layout_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$60$$))});return new $app$main$data$workspace$shape_layout$merge_cells_71269$$($layout_id$jscomp$6$$,$ids$jscomp$244$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$reorder_strokes$$=function($ids$jscomp$203$$,$from_pos$jscomp$6$$,$to_space_between_pos$jscomp$6$$){typeof $app$main$data$workspace$colors$reorder_strokes_70763$$==="undefined"&&($app$main$data$workspace$colors$reorder_strokes_70763$$=function($ids$jscomp$204$$,$from_pos$jscomp$7$$,$to_space_between_pos$jscomp$7$$,$meta70764$$){this.ids=$ids$jscomp$204$$;this.$from_pos$=$from_pos$jscomp$7$$;this.$to_space_between_pos$=$to_space_between_pos$jscomp$7$$;this.$meta70764$=
$meta70764$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$reorder_strokes_70763$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_strokes_70763$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4153$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_strokes$$},$app$main$data$workspace$colors$reorder_strokes_70763$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70765$$,$meta70764__$1$$){return new $app$main$data$workspace$colors$reorder_strokes_70763$$(this.ids,this.$from_pos$,this.$to_space_between_pos$,$meta70764__$1$$)},$app$main$data$workspace$colors$reorder_strokes_70763$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70764$},$app$main$data$workspace$colors$reorder_strokes_70763$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_strokes_70763$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5240$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5240$$.ids,function($p1__70759_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__70759_SHARP_$$,$APP.$cljs$cst$1636$strokes$$,$app$common$data$reorder$$,$self__$jscomp$5240$$.$from_pos$,$self__$jscomp$5240$$.$to_space_between_pos$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$reorder_strokes_70763$$($ids$jscomp$203$$,$from_pos$jscomp$6$$,$to_space_between_pos$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$remove_all_strokes$$=function($ids$jscomp$199$$){typeof $app$main$data$workspace$colors$remove_all_strokes_70719$$==="undefined"&&($app$main$data$workspace$colors$remove_all_strokes_70719$$=function($ids$jscomp$200$$,$meta70720$$){this.ids=$ids$jscomp$200$$;this.$meta70720$=$meta70720$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_all_strokes_70719$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_all_strokes_70719$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4151$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_all_strokes$$},$app$main$data$workspace$colors$remove_all_strokes_70719$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70721$$,$meta70720__$1$$){return new $app$main$data$workspace$colors$remove_all_strokes_70719$$(this.ids,$meta70720__$1$$)},$app$main$data$workspace$colors$remove_all_strokes_70719$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70720$},$app$main$data$workspace$colors$remove_all_strokes_70719$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_all_strokes_70719$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(this.ids,function($p1__70717_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70717_SHARP_$$,
$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$remove_all_strokes_70719$$($ids$jscomp$199$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$remove_stroke$$=function($ids$jscomp$197$$,$position$jscomp$117$$){typeof $app$main$data$workspace$colors$remove_stroke_70693$$==="undefined"&&($app$main$data$workspace$colors$remove_stroke_70693$$=function($ids$jscomp$198$$,$position$jscomp$118$$,$meta70694$$){this.ids=$ids$jscomp$198$$;this.position=$position$jscomp$118$$;this.$meta70694$=$meta70694$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_stroke_70693$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_stroke_70693$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4150$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_stroke$$},$app$main$data$workspace$colors$remove_stroke_70693$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70695$$,$meta70694__$1$$){return new $app$main$data$workspace$colors$remove_stroke_70693$$(this.ids,this.position,$meta70694__$1$$)},$app$main$data$workspace$colors$remove_stroke_70693$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70694$},$app$main$data$workspace$colors$remove_stroke_70693$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_stroke_70693$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){function $remove_fill_by_index$jscomp$1$$($values$jscomp$73$$,$index$jscomp$305$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filterv$$(function($p__70712$$){var $idx$jscomp$93$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70712$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70712$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$93$$,$index$jscomp$305$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$73$$)))}var $self__$jscomp$5228$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5228$$.ids,
function($shape$jscomp$688$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$688$$,$APP.$cljs$cst$1636$strokes$$,$remove_fill_by_index$jscomp$1$$,$self__$jscomp$5228$$.position)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$remove_stroke_70693$$($ids$jscomp$197$$,
$position$jscomp$117$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ids$jscomp$189$$,$attrs$jscomp$142$$,$index$jscomp$301$$){typeof $app$main$data$workspace$colors$change_stroke_attrs_70626$$==="undefined"&&($app$main$data$workspace$colors$change_stroke_attrs_70626$$=function($ids$jscomp$190$$,$attrs$jscomp$143$$,$index$jscomp$302$$,$options$jscomp$568$$,$meta70627$$){this.ids=$ids$jscomp$190$$;this.$attrs$=$attrs$jscomp$143$$;this.index=$index$jscomp$302$$;this.options=
$options$jscomp$568$$;this.$meta70627$=$meta70627$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_stroke_attrs_70626$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_stroke_attrs_70626$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4146$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_stroke_attrs$$},$app$main$data$workspace$colors$change_stroke_attrs_70626$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70628$$,$meta70627__$1$$){return new $app$main$data$workspace$colors$change_stroke_attrs_70626$$(this.ids,this.$attrs$,this.index,this.options,$meta70627__$1$$)},$app$main$data$workspace$colors$change_stroke_attrs_70626$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70627$},$app$main$data$workspace$colors$change_stroke_attrs_70626$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_stroke_attrs_70626$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5212$$=this,$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$=$APP.$cljs$core$keys$$($self__$jscomp$5212$$.$attrs$);$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$5212$$.options,$APP.$cljs$cst$3521$changed_sub_attr$$,$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5212$$.ids,
function($G__70646__$1_shape$jscomp$684$$){var $attrs__$1$jscomp$22_stroke$jscomp$21$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__70646__$1_shape$jscomp$684$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$self__$jscomp$5212$$.index],null)),$style_attrs$$=$APP.$app$main$data$workspace$colors$build_stroke_style_attrs$$($attrs__$1$jscomp$22_stroke$jscomp$21$$);$attrs__$1$jscomp$22_stroke$jscomp$21$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs__$1$jscomp$22_stroke$jscomp$21$$,
$style_attrs$$,$self__$jscomp$5212$$.$attrs$]));$G__70646__$1_shape$jscomp$684$$=$APP.$cljs$core$contains_QMARK_$$($G__70646__$1_shape$jscomp$684$$,$APP.$cljs$cst$1636$strokes$$)?$G__70646__$1_shape$jscomp$684$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70646__$1_shape$jscomp$684$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$);return $APP.$cljs$core$assoc_in$$($G__70646__$1_shape$jscomp$684$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1636$strokes$$,$self__$jscomp$5212$$.index],null),$attrs__$1$jscomp$22_stroke$jscomp$21$$)},$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$))});return new $app$main$data$workspace$colors$change_stroke_attrs_70626$$($ids$jscomp$189$$,$attrs$jscomp$142$$,$index$jscomp$301$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$188$$,$attrs$jscomp$141$$,$index$jscomp$300$$){return $app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$188$$,$attrs$jscomp$141$$,$index$jscomp$300$$)};
$app$main$data$workspace$texts$replace_layer_names_in_shapes$$=function($ids$jscomp$155$$,$search$jscomp$3$$,$replacement$jscomp$15$$){typeof $app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$==="undefined"&&($app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$=function($ids$jscomp$156$$,$search$jscomp$4$$,$replacement$jscomp$16$$,$meta70391$$){this.ids=$ids$jscomp$156$$;this.search=$search$jscomp$4$$;this.$replacement$=$replacement$jscomp$16$$;this.$meta70391$=$meta70391$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4047$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_replace_layer_names_in_shapes$$},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70392$$,$meta70391__$1$$){return new $app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$(this.ids,this.search,this.$replacement$,$meta70391__$1$$)},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70391$},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5075$$=this,$undo_group$jscomp$36$$=$APP.$app$common$uuid$next$$();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5075$$.ids,function($shape$jscomp$592$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$592$$,$APP.$cljs$cst$725$name$$,$app$common$types$text$replace_all_case_insensitive$$,$self__$jscomp$5075$$.search,$self__$jscomp$5075$$.$replacement$)},
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,null],null),null),$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$36$$],null)))});return new $app$main$data$workspace$texts$replace_layer_names_in_shapes_70390$$($ids$jscomp$155$$,$search$jscomp$3$$,$replacement$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$commit_position_data$$=function(){typeof $app$main$data$workspace$texts$commit_position_data_70318$$==="undefined"&&($app$main$data$workspace$texts$commit_position_data_70318$$=function($meta70319$$){this.$meta70319$=$meta70319$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4030$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_position_data$$},$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70320$$,$meta70319__$1$$){return new $app$main$data$workspace$texts$commit_position_data_70318$$($meta70319__$1$$)},$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70319$},$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2187$$,$state$jscomp$585$$){var $ids$jscomp$150$$=$APP.$cljs$core$keys$$($APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$585$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$585$$,$APP.$cljs$cst$2238$workspace_text_modifier$$,
function($p1__70317_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$,$p1__70317_SHARP_$$,$ids$jscomp$150$$)})},$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_position_data_70318$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2188$$,$state$jscomp$586$$){var $position_data$jscomp$9$$=$APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$586$$);
return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$keys$$($position_data$jscomp$9$$),function($shape$jscomp$586$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$586$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position_data$jscomp$9$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$586$$)))},
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3141$stack_undo_QMARK_$$,!0,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!1],null))),(0,$APP.$beicon$v2$core$of$$)(function($state__$1$jscomp$26$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state__$1$jscomp$26$$,$APP.$cljs$cst$4032$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$]))}))});
return new $app$main$data$workspace$texts$commit_position_data_70318$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$commit_resize_text$$=function(){typeof $app$main$data$workspace$texts$commit_resize_text_70228$$==="undefined"&&($app$main$data$workspace$texts$commit_resize_text_70228$$=function($meta70229$$){this.$meta70229$=$meta70229$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$commit_resize_text_70228$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_resize_text_70228$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4019$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_resize_text$$},$app$main$data$workspace$texts$commit_resize_text_70228$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70230$$,$meta70229__$1$$){return new $app$main$data$workspace$texts$commit_resize_text_70228$$($meta70229__$1$$)},$app$main$data$workspace$texts$commit_resize_text_70228$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70229$},$app$main$data$workspace$texts$commit_resize_text_70228$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_resize_text_70228$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2177_undo_id$jscomp$33$$,$ids$jscomp$148_state$jscomp$576$$){var $props$jscomp$195$$=$APP.$cljs$cst$4020$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$148_state$jscomp$576$$),$objects$jscomp$517$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$148_state$jscomp$576$$);
$_$jscomp$2177_undo_id$jscomp$33$$=Symbol();$ids$jscomp$148_state$jscomp$576$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$623_new_height$jscomp$3_vec__70242$$){var $shape$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$517$$,$id$jscomp$623_new_height$jscomp$3_vec__70242$$);$id$jscomp$623_new_height$jscomp$3_vec__70242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$195$$,
$id$jscomp$623_new_height$jscomp$3_vec__70242$$);var $JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$623_new_height$jscomp$3_vec__70242$$,0,null);$id$jscomp$623_new_height$jscomp$3_vec__70242$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$623_new_height$jscomp$3_vec__70242$$,1,null);var $old_dim$jscomp$inline_13324$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$583$$);
($JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$=$APP.$app$common$math$abs$$($old_dim$jscomp$inline_13324$$-$JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$)>.1&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$583$$),$APP.$cljs$cst$2036$auto_width$$))||($JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$583$$),
$JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$=$APP.$app$common$math$abs$$($JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$-$id$jscomp$623_new_height$jscomp$3_vec__70242$$)>.1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$583$$),$APP.$cljs$cst$2035$auto_height$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$583$$),
$APP.$cljs$cst$2036$auto_width$$)));return $JSCompiler_temp$jscomp$10945_new_width$jscomp$3_old_dim$jscomp$inline_13327$$}),$APP.$cljs$core$keys$$($props$jscomp$195$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2177_undo_id$jscomp$33$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$148_state$jscomp$576$$,function($grow_type$jscomp$7_p__70250$$){var $map__70251__$1_shape__$1$jscomp$45$$=
$APP.$cljs$core$__destructure_map$$($grow_type$jscomp$7_p__70250$$),$id$jscomp$624_new_width$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70251__$1_shape__$1$jscomp$45$$,$APP.$cljs$cst$266$id$$),$selrect$jscomp$67_shape_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70251__$1_shape__$1$jscomp$45$$,$APP.$cljs$cst$1605$selrect$$);$grow_type$jscomp$7_p__70250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70251__$1_shape__$1$jscomp$45$$,$APP.$cljs$cst$1770$grow_type$$);
var $map__70252__$1_shape_height$$=$APP.$cljs$core$__destructure_map$$($selrect$jscomp$67_shape_width$$);$selrect$jscomp$67_shape_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70252__$1_shape_height$$,$APP.$cljs$cst$290$width$$);$map__70252__$1_shape_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70252__$1_shape_height$$,$APP.$cljs$cst$1522$height$$);var $new_height$jscomp$4_vec__70253$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$195$$,
$id$jscomp$624_new_width$jscomp$4$$);$id$jscomp$624_new_width$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_height$jscomp$4_vec__70253$$,0,null);$new_height$jscomp$4_vec__70253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_height$jscomp$4_vec__70253$$,1,null);$map__70251__$1_shape__$1$jscomp$45$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$517$$,$map__70251__$1_shape__$1$jscomp$45$$)&&$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__70251__$1_shape__$1$jscomp$45$$)||
!($APP.$app$common$math$abs$$($selrect$jscomp$67_shape_width$$-$id$jscomp$624_new_width$jscomp$4$$)>.1&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$7_p__70250$$,$APP.$cljs$cst$2036$auto_width$$))?$map__70251__$1_shape__$1$jscomp$45$$:$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($map__70251__$1_shape__$1$jscomp$45$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($map__70251__$1_shape__$1$jscomp$45$$,
$APP.$cljs$cst$290$width$$,$id$jscomp$624_new_width$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,!0],null)));return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$517$$,$map__70251__$1_shape__$1$jscomp$45$$)&&$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__70251__$1_shape__$1$jscomp$45$$)||!($APP.$app$common$math$abs$$($map__70252__$1_shape_height$$-$new_height$jscomp$4_vec__70253$$)>
.1)||!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$7_p__70250$$,$APP.$cljs$cst$2035$auto_height$$)&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$7_p__70250$$,$APP.$cljs$cst$2036$auto_width$$)?$map__70251__$1_shape__$1$jscomp$45$$:$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($map__70251__$1_shape__$1$jscomp$45$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($map__70251__$1_shape__$1$jscomp$45$$,
$APP.$cljs$cst$1522$height$$,$new_height$jscomp$4_vec__70253$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,!0],null)))},new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$ids$jscomp$148_state$jscomp$576$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2177_undo_id$jscomp$33$$))});return new $app$main$data$workspace$texts$commit_resize_text_70228$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$finalize_editor_state$$=function($id$jscomp$604$$,$update_name_QMARK_$$){typeof $app$main$data$workspace$texts$finalize_editor_state_70040$$==="undefined"&&($app$main$data$workspace$texts$finalize_editor_state_70040$$=function($id$jscomp$605$$,$update_name_QMARK_$jscomp$1$$,$meta70041$$){this.id=$id$jscomp$605$$;this.$update_name_QMARK_$=$update_name_QMARK_$jscomp$1$$;this.$meta70041$=$meta70041$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$finalize_editor_state_70040$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$finalize_editor_state_70040$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4005$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$},$app$main$data$workspace$texts$finalize_editor_state_70040$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70042$$,$meta70041__$1$$){return new $app$main$data$workspace$texts$finalize_editor_state_70040$$(this.id,
this.$update_name_QMARK_$,$meta70041__$1$$)},$app$main$data$workspace$texts$finalize_editor_state_70040$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70041$},$app$main$data$workspace$texts$finalize_editor_state_70040$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$finalize_editor_state_70040$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$,$state$jscomp$561$$){var $self__$jscomp$4955$$=
this;if($app$main$data$workspace$common$initialized_QMARK_$$($state$jscomp$561$$)){$_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$561$$);$_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$,$self__$jscomp$4955$$.id);var $editor_state$jscomp$2_new_shape_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$561$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,$self__$jscomp$4955$$.id],null)),$content$jscomp$180$$=$editor_state$jscomp$2_new_shape_QMARK_$$.getCurrentContent(),$name$jscomp$330$$=$app$main$data$workspace$texts$gen_name$$($editor_state$jscomp$2_new_shape_QMARK_$$);$editor_state$jscomp$2_new_shape_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3643$workspace_new_text_shapes$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$561$$),
$self__$jscomp$4955$$.id);if($content$jscomp$180$$.hasText()){if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$561$$,"render-wasm/v1")){var $content__$1$jscomp$37$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$util$text_editor$export_content$$($content$jscomp$180$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$),
$APP.$cljs$cst$342$children$$)])),$new_size$jscomp$1$$=$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$,$content__$1$jscomp$37$$);return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_editor_state$$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$,null)),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$37$$,
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$))&&$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$561$$)!=null&&$_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4955$$.id],
null),function($shape__$1$jscomp$40$$){var $G__70044_G__70045$jscomp$inline_13330$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$40$$,$APP.$cljs$cst$1637$content$$,$content__$1$jscomp$37$$);var $and__5023__auto__$jscomp$inline_13332$$=$self__$jscomp$4955$$.$update_name_QMARK_$;$G__70044_G__70045$jscomp$inline_13330$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13332$$)?$name$jscomp$330$$!=null:$and__5023__auto__$jscomp$inline_13332$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70044_G__70045$jscomp$inline_13330$$,$APP.$cljs$cst$725$name$$,$name$jscomp$330$$):$G__70044_G__70045$jscomp$inline_13330$$;return $new_size$jscomp$1$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__70044_G__70045$jscomp$inline_13330$$,$APP.$app$common$types$modifiers$change_size$$($shape__$1$jscomp$40$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($new_size$jscomp$1$$),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($new_size$jscomp$1$$))):
$G__70044_G__70045$jscomp$inline_13330$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$editor_state$jscomp$2_new_shape_QMARK_$$?$self__$jscomp$4955$$.id:null],null))):null)}$content__$1$jscomp$37$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$util$text_editor$export_content$$($content$jscomp$180$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$),
$APP.$cljs$cst$342$children$$)]));var $modifiers$jscomp$94$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$561$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2238$workspace_text_modifier$$,$self__$jscomp$4955$$.id],null));return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_editor_state$$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$,null)),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$37$$,
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$))&&$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$561$$)!=null&&$_$jscomp$2162_objects$jscomp$510_shape$jscomp$565$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4955$$.id],
null),function($shape__$1$jscomp$41$$){var $G__70050_map__70049__$1$$=$APP.$cljs$core$__destructure_map$$($modifiers$jscomp$94$$),$width$jscomp$141$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70050_map__70049__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70050_map__70049__$1$$,$APP.$cljs$cst$1522$height$$),$position_data$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70050_map__70049__$1$$,$APP.$cljs$cst$1891$position_data$$);
$G__70050_map__70049__$1$$=function(){var $G__70051$$=function(){var $G__70052$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$41$$,$APP.$cljs$cst$1637$content$$,$content__$1$jscomp$37$$);return $APP.$cljs$core$truth_$$($position_data$jscomp$7$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70052$$,$APP.$cljs$cst$1891$position_data$$,$position_data$jscomp$7$$):$G__70052$$}();return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$482$$=$self__$jscomp$4955$$.$update_name_QMARK_$;
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$482$$)?$name$jscomp$330$$!=null:$and__5023__auto__$jscomp$482$$}())?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70051$$,$APP.$cljs$cst$725$name$$,$name$jscomp$330$$):$G__70051$$}();return $width$jscomp$141$$!=null||$height$jscomp$127$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__70050_map__70049__$1$$,$APP.$app$common$types$modifiers$change_size$$($shape__$1$jscomp$41$$,$width$jscomp$141$$,
$height$jscomp$127$$)):$G__70050_map__70049__$1$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$editor_state$jscomp$2_new_shape_QMARK_$$?$self__$jscomp$4955$$.id:null],null))):null)}return $self__$jscomp$4955$$.id!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$deselect_shape$$($self__$jscomp$4955$$.id),$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$self__$jscomp$4955$$.id]))):
null}return null});return new $app$main$data$workspace$texts$finalize_editor_state_70040$$($id$jscomp$604$$,$update_name_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$initialize_editor_state$$=function($p__70055$$){var $decorator$jscomp$1$$=$app$main$ui$workspace$shapes$text$editor$default_decorator$$,$map__70056__$1$$=$APP.$cljs$core$__destructure_map$$($p__70055$$),$id$jscomp$606$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70056__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$331$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70056__$1$$,$APP.$cljs$cst$725$name$$),$content$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70056__$1$$,
$APP.$cljs$cst$1637$content$$);typeof $app$main$data$workspace$texts$initialize_editor_state_70057$$==="undefined"&&($app$main$data$workspace$texts$initialize_editor_state_70057$$=function($p__70055$jscomp$1$$,$decorator$jscomp$2$$,$map__70056$jscomp$1$$,$shape$jscomp$567$$,$id$jscomp$607$$,$name$jscomp$332$$,$content$jscomp$182$$,$meta70058$$){this.$p__70055$=$p__70055$jscomp$1$$;this.$decorator$=$decorator$jscomp$2$$;this.$map__70056$=$map__70056$jscomp$1$$;this.shape=$shape$jscomp$567$$;this.id=
$id$jscomp$607$$;this.name=$name$jscomp$332$$;this.content=$content$jscomp$182$$;this.$meta70058$=$meta70058$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4006$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_initialize_editor_state$$},
$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70059$$,$meta70058__$1$$){return new $app$main$data$workspace$texts$initialize_editor_state_70057$$(this.$p__70055$,this.$decorator$,this.$map__70056$,this.shape,this.id,this.name,this.content,$meta70058__$1$$)},$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70058$},$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2163_editor$jscomp$4$$,$state$jscomp$562$$){var $self__$jscomp$4959$$=this,$text_state$$=function(){var $G__70064$$=$self__$jscomp$4959$$.content;return $G__70064$$==null?null:$APP.$app$util$text_editor$import_content$$($G__70064$$)}(),$attrs$jscomp$112$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$562$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2201$default_font$$],null))]));$_$jscomp$2163_editor$jscomp$4$$=function(){var $G__70065$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createEditorState($text_state$$,$self__$jscomp$4959$$.$decorator$);return $self__$jscomp$4959$$.content==null&&$attrs$jscomp$112$$!=null?
$APP.$app$util$text_editor$update_editor_current_block_data$$($G__70065$$,$attrs$jscomp$112$$):$G__70065$$}();return $APP.$cljs$core$assoc_in$$($state$jscomp$562$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,$self__$jscomp$4959$$.id],null),$_$jscomp$2163_editor$jscomp$4$$)},$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$initialize_editor_state_70057$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2164_editor$jscomp$5$$,$state$jscomp$563$$,$stream$jscomp$59$$){var $self__$jscomp$4960$$=this;$_$jscomp$2164_editor$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$563$$,$APP.$cljs$cst$2222$workspace_editor_state$$),$self__$jscomp$4960$$.id);var $update_name_QMARK_$jscomp$2$$=$self__$jscomp$4960$$.content==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4960$$.name,$app$main$data$workspace$texts$gen_name$$($_$jscomp$2164_editor$jscomp$5$$));return $APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$finalize_editor_state$$($self__$jscomp$4960$$.id,$update_name_QMARK_$jscomp$2$$)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2361$app_DOT_main_DOT_router_SLASH_navigate$$),
$stream$jscomp$59$$),$APP.$beicon$v2$core$filter$$(function($p1__70053_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4005$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$,$p1__70053_SHARP_$$)},$stream$jscomp$59$$))))});return new $app$main$data$workspace$texts$initialize_editor_state_70057$$($p__70055$$,$decorator$jscomp$1$$,$map__70056__$1$$,$map__70056__$1$$,$id$jscomp$606$$,$name$jscomp$331$$,$content$jscomp$181$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$remove_text_modifier$$=function($id$jscomp$631$$){typeof $app$main$data$workspace$texts$remove_text_modifier_70311$$==="undefined"&&($app$main$data$workspace$texts$remove_text_modifier_70311$$=function($id$jscomp$632$$,$meta70312$$){this.id=$id$jscomp$632$$;this.$meta70312$=$meta70312$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4029$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_remove_text_modifier$$},$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70313$$,$meta70312__$1$$){return new $app$main$data$workspace$texts$remove_text_modifier_70311$$(this.id,$meta70312__$1$$)},
$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70312$},$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2185$$,$state$jscomp$584$$){return $APP.$app$common$data$dissoc_in$$($state$jscomp$584$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2238$workspace_text_modifier$$,this.id],null))},$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$remove_text_modifier_70311$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3141$stack_undo_QMARK_$$,!0],null)))});return new $app$main$data$workspace$texts$remove_text_modifier_70311$$($id$jscomp$631$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$remove_fill$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$178$$,$position$jscomp$114$$){typeof $app$main$data$workspace$colors$remove_fill_70523$$==="undefined"&&($app$main$data$workspace$colors$remove_fill_70523$$=function($ids$jscomp$179$$,$position$jscomp$115$$,$options$jscomp$562$$,$meta70524$$){this.ids=$ids$jscomp$179$$;this.position=$position$jscomp$115$$;this.options=$options$jscomp$562$$;this.$meta70524$=$meta70524$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_fill_70523$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_fill_70523$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4142$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_fill$$},$app$main$data$workspace$colors$remove_fill_70523$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70525$$,$meta70524__$1$$){return new $app$main$data$workspace$colors$remove_fill_70523$$(this.ids,
this.position,this.options,$meta70524__$1$$)},$app$main$data$workspace$colors$remove_fill_70523$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70524$},$app$main$data$workspace$colors$remove_fill_70523$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_fill_70523$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2238_undo_id$jscomp$43$$,$state$jscomp$636$$){function $remove_fill_by_index$$($fills$jscomp$27$$,
$index$jscomp$296$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($i$jscomp$506$$,$o$jscomp$270$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$506$$,$index$jscomp$296$$)?$o$jscomp$270$$:null}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$)),$fills$jscomp$27$$)}
var $self__$jscomp$5196$$=this;$_$jscomp$2238_undo_id$jscomp$43$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2238_undo_id$jscomp$43$$)),$APP.$app$main$data$workspace$colors$transform_fill_STAR_$$($state$jscomp$636$$,$self__$jscomp$5196$$.ids,function($node$jscomp$325$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$325$$,$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$update$$,
$remove_fill_by_index$$,$self__$jscomp$5196$$.position)},$self__$jscomp$5196$$.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2238_undo_id$jscomp$43$$)))});return new $app$main$data$workspace$colors$remove_fill_70523$$($ids$jscomp$178$$,$position$jscomp$114$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$detach_fill$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$175$$,$position$jscomp$111$$){typeof $app$main$data$workspace$colors$detach_fill_70512$$==="undefined"&&($app$main$data$workspace$colors$detach_fill_70512$$=function($ids$jscomp$176$$,$position$jscomp$112$$,$options$jscomp$560$$,$meta70513$$){this.ids=$ids$jscomp$176$$;this.position=$position$jscomp$112$$;this.options=$options$jscomp$560$$;this.$meta70513$=$meta70513$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$detach_fill_70512$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$detach_fill_70512$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4141$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_detach_fill$$},$app$main$data$workspace$colors$detach_fill_70512$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70514$$,$meta70513__$1$$){return new $app$main$data$workspace$colors$detach_fill_70512$$(this.ids,
this.position,this.options,$meta70513__$1$$)},$app$main$data$workspace$colors$detach_fill_70512$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70513$},$app$main$data$workspace$colors$detach_fill_70512$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$detach_fill_70512$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2237_undo_id$jscomp$42$$,$state$jscomp$635$$){function $detach_fn$jscomp$1$$($fills$jscomp$26$$,
$index$jscomp$295$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($fills$jscomp$26$$,$index$jscomp$295$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1640$fill_color_ref_file$$)}var $self__$jscomp$5192$$=this;$_$jscomp$2237_undo_id$jscomp$42$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2237_undo_id$jscomp$42$$)),$APP.$app$main$data$workspace$colors$transform_fill_STAR_$$($state$jscomp$635$$,
$self__$jscomp$5192$$.ids,function($node$jscomp$324$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$324$$,$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$update$$,$detach_fn$jscomp$1$$,$self__$jscomp$5192$$.position)},$self__$jscomp$5192$$.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2237_undo_id$jscomp$42$$)))});return new $app$main$data$workspace$colors$detach_fill_70512$$($ids$jscomp$175$$,
$position$jscomp$111$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$add_fill$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$172$$){var $color__$1$jscomp$9$$=(0,$APP.$app$common$types$color$check_color$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#B1B2B5",$APP.$cljs$cst$1734$opacity$$,1],null));typeof $app$main$data$workspace$colors$add_fill_70502$$==="undefined"&&($app$main$data$workspace$colors$add_fill_70502$$=function($ids$jscomp$173$$,$color$jscomp$81$$,$options$jscomp$558$$,$meta70503$$){this.ids=
$ids$jscomp$173$$;this.color=$color$jscomp$81$$;this.options=$options$jscomp$558$$;this.$meta70503$=$meta70503$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_fill_70502$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_fill_70502$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4140$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_fill$$},
$app$main$data$workspace$colors$add_fill_70502$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70504$$,$meta70503__$1$$){return new $app$main$data$workspace$colors$add_fill_70502$$(this.ids,this.color,this.options,$meta70503__$1$$)},$app$main$data$workspace$colors$add_fill_70502$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70503$},$app$main$data$workspace$colors$add_fill_70502$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_fill_70502$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2236_undo_id$jscomp$41$$,$state$jscomp$634$$){$_$jscomp$2236_undo_id$jscomp$41$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2236_undo_id$jscomp$41$$)),$APP.$app$main$data$workspace$colors$transform_fill$cljs$0core$0IFn$0_invoke$0arity$05$$($state$jscomp$634$$,this.ids,this.color,function($node$jscomp$323$$,$attrs$jscomp$138$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($node$jscomp$323$$,
$APP.$cljs$cst$1634$fills$$,$app$common$types$fills$prepend$$,$attrs$jscomp$138$$)},this.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2236_undo_id$jscomp$41$$)))});return new $app$main$data$workspace$colors$add_fill_70502$$($ids$jscomp$172$$,$color__$1$jscomp$9$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$apply_color_from_palette$$=function($color$jscomp$89_color__$1$jscomp$10$$,$stroke_QMARK_$$){$color$jscomp$89_color__$1$jscomp$10$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$89_color__$1$jscomp$10$$);typeof $app$main$data$workspace$colors$apply_color_from_palette_70840$$==="undefined"&&($app$main$data$workspace$colors$apply_color_from_palette_70840$$=function($color$jscomp$90$$,$stroke_QMARK_$jscomp$1$$,$meta70841$$){this.color=$color$jscomp$90$$;
this.$stroke_QMARK_$=$stroke_QMARK_$jscomp$1$$;this.$meta70841$=$meta70841$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$apply_color_from_palette_70840$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_palette_70840$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4160$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_palette$$},
$app$main$data$workspace$colors$apply_color_from_palette_70840$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70842$$,$meta70841__$1$$){return new $app$main$data$workspace$colors$apply_color_from_palette_70840$$(this.color,this.$stroke_QMARK_$,$meta70841__$1$$)},$app$main$data$workspace$colors$apply_color_from_palette_70840$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70841$},$app$main$data$workspace$colors$apply_color_from_palette_70840$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_palette_70840$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$,$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$){$_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$);
$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$=$APP.$app$common$files$helpers$clean_loops$$($_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$));a:{for(var $pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$=$APP.$cljs$core$seq$$($G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$),
$G__70852$jscomp$inline_13340_result$jscomp$inline_13335$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($APP.$cljs$core$empty_QMARK_$$($pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$)){$_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$=$G__70852$jscomp$inline_13340_result$jscomp$inline_13335$$;break a}$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$=$APP.$cljs$core$first$$($pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$);
var $G__71141$jscomp$inline_13341_group_QMARK_$jscomp$inline_13337$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$,$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$);$pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$=$APP.$cljs$core$truth_$$($G__71141$jscomp$inline_13341_group_QMARK_$jscomp$inline_13337$$)?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$,$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$),$APP.$cljs$cst$1614$shapes$$)):$pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$;$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$=$APP.$cljs$core$not$$($G__71141$jscomp$inline_13341_group_QMARK_$jscomp$inline_13337$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__70852$jscomp$inline_13340_result$jscomp$inline_13335$$,$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$):$G__70852$jscomp$inline_13340_result$jscomp$inline_13335$$;$pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$=$G__71141$jscomp$inline_13341_group_QMARK_$jscomp$inline_13337$$=$APP.$cljs$core$rest$$($pending$jscomp$inline_13334_pending__$1$jscomp$inline_13338$$);
$G__70852$jscomp$inline_13340_result$jscomp$inline_13335$$=$G__71142$jscomp$inline_13342_cur$jscomp$inline_13336_result__$1$jscomp$inline_13339_selected$jscomp$79_state$jscomp$641$$}$_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$=void 0}return $APP.$cljs$core$truth_$$(this.$stroke_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$($_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$,this.color,0)):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$($_$jscomp$2253_ids$jscomp$206_objects$jscomp$592$$,
this.color,0))});return new $app$main$data$workspace$colors$apply_color_from_palette_70840$$($color$jscomp$89_color__$1$jscomp$10$$,$stroke_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$apply_color_from_assets$$=function($file_id$jscomp$208$$,$color$jscomp$95_color__$1$jscomp$13$$,$stroke_QMARK_$jscomp$2$$){$color$jscomp$95_color__$1$jscomp$13$$=(0,$APP.$app$common$types$color$check_library_color$$)($color$jscomp$95_color__$1$jscomp$13$$);typeof $app$main$data$workspace$colors$apply_color_from_asserts_70894$$==="undefined"&&($app$main$data$workspace$colors$apply_color_from_asserts_70894$$=function($file_id$jscomp$209$$,$color$jscomp$96$$,$stroke_QMARK_$jscomp$3$$,
$meta70895$$){this.$file_id$=$file_id$jscomp$209$$;this.color=$color$jscomp$96$$;this.$stroke_QMARK_$=$stroke_QMARK_$jscomp$3$$;this.$meta70895$=$meta70895$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$apply_color_from_asserts_70894$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_asserts_70894$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4167$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_asserts$$},
$app$main$data$workspace$colors$apply_color_from_asserts_70894$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70896$$,$meta70895__$1$$){return new $app$main$data$workspace$colors$apply_color_from_asserts_70894$$(this.$file_id$,this.color,this.$stroke_QMARK_$,$meta70895__$1$$)},$app$main$data$workspace$colors$apply_color_from_asserts_70894$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70895$},$app$main$data$workspace$colors$apply_color_from_asserts_70894$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_asserts_70894$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $color__$1$jscomp$14$$=$app$common$types$color$library_color__GT_color$$(this.color,this.$file_id$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$colors$apply_color_from_palette$$($color__$1$jscomp$14$$,this.$stroke_QMARK_$),$app$main$data$workspace$colors$add_recent_color$$($color__$1$jscomp$14$$))});return new $app$main$data$workspace$colors$apply_color_from_asserts_70894$$($file_id$jscomp$208$$,
$color$jscomp$95_color__$1$jscomp$13$$,$stroke_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$replace_text_in_shapes$$=function($ids$jscomp$157$$,$search$jscomp$5$$,$replacement$jscomp$17$$){typeof $app$main$data$workspace$texts$replace_text_in_shapes_70395$$==="undefined"&&($app$main$data$workspace$texts$replace_text_in_shapes_70395$$=function($ids$jscomp$158$$,$search$jscomp$6$$,$replacement$jscomp$18$$,$meta70396$$){this.ids=$ids$jscomp$158$$;this.search=$search$jscomp$6$$;this.$replacement$=$replacement$jscomp$18$$;this.$meta70396$=$meta70396$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$replace_text_in_shapes_70395$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_text_in_shapes_70395$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4048$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_replace_text_in_shapes$$},$app$main$data$workspace$texts$replace_text_in_shapes_70395$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70397$$,$meta70396__$1$$){return new $app$main$data$workspace$texts$replace_text_in_shapes_70395$$(this.ids,this.search,this.$replacement$,$meta70396__$1$$)},$app$main$data$workspace$texts$replace_text_in_shapes_70395$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70396$},$app$main$data$workspace$texts$replace_text_in_shapes_70395$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_text_in_shapes_70395$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2202_update_event$$,$state$jscomp$598$$){var $self__$jscomp$5079$$=this,$undo_group$jscomp$37$$=$APP.$app$common$uuid$next$$();$_$jscomp$2202_update_event$$=$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5079$$.ids,function($shape$jscomp$593$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$593$$))&&$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$593$$)!=
null){var $new_content$jscomp$6$$=$app$common$types$text$replace_text_in_content$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$593$$),$self__$jscomp$5079$$.search,$self__$jscomp$5079$$.$replacement$),$new_name$jscomp$24$$=$APP.$app$common$types$text$generate_shape_name$$($APP.$app$common$types$text$content__GT_text$$($new_content$jscomp$6$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$593$$,
$APP.$cljs$cst$1637$content$$,$new_content$jscomp$6$$),$APP.$cljs$cst$725$name$$,$new_name$jscomp$24$$)}return $shape$jscomp$593$$},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1637$content$$,null,$APP.$cljs$cst$725$name$$,null],null),null),$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$37$$],null));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($_$jscomp$2202_update_event$$),
$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$598$$,"render-wasm/v1")?$APP.$beicon$v2$core$map$$(function($p1__70393_SHARP_$$){return $APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$($p1__70393_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$37$$],null))},$APP.$beicon$v2$core$from$$($self__$jscomp$5079$$.ids)):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$texts$replace_text_in_shapes_70395$$($ids$jscomp$157$$,
$search$jscomp$5$$,$replacement$jscomp$17$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$component_multi_swap$$=function($shapes$jscomp$106$$,$file_id$jscomp$167$$,$id_new_component$jscomp$4$$){typeof $app$main$data$workspace$libraries$component_multi_swap_69796$$==="undefined"&&($app$main$data$workspace$libraries$component_multi_swap_69796$$=function($shapes$jscomp$107$$,$file_id$jscomp$168$$,$id_new_component$jscomp$5$$,$meta69797$$){this.shapes=$shapes$jscomp$107$$;this.$file_id$=$file_id$jscomp$168$$;this.$id_new_component$=$id_new_component$jscomp$5$$;
this.$meta69797$=$meta69797$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3958$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_multi_swap$$},$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69798$$,$meta69797__$1$$){return new $app$main$data$workspace$libraries$component_multi_swap_69796$$(this.shapes,this.$file_id$,this.$id_new_component$,$meta69797__$1$$)},$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69797$},$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$app$main$data$event$Event$_data$arity$1$=
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"component-swap"],null)},$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_multi_swap_69796$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2132$$,$state$jscomp$522$$){var $self__$jscomp$4875$$=this,$undo_id$jscomp$32$$=
Symbol();$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"COMPONENT-SWAP"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$208$file$$,$APP.$app$main$data$workspace$libraries$debug_pretty_file$$($self__$jscomp$4875$$.$file_id$,$state$jscomp$522$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3959$id_new_component$$,$self__$jscomp$4875$$.$id_new_component$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3646$undo_id$$,$undo_id$jscomp$32$$],null)],null)}),null,"app.main.data.workspace.libraries",
$APP.$cljs$cst$1161$info$$,!1);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$32$$)),$APP.$beicon$v2$core$map$$(function($p1__69790_SHARP_$$){return $APP.$app$main$data$workspace$libraries$component_swap$$($p1__69790_SHARP_$$,$self__$jscomp$4875$$.$file_id$,$self__$jscomp$4875$$.$id_new_component$,!1)},$APP.$beicon$v2$core$from$$($self__$jscomp$4875$$.shapes)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$32$$)),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$specialized_panel$open_specialized_panel$$()))});return new $app$main$data$workspace$libraries$component_multi_swap_69796$$($shapes$jscomp$106$$,$file_id$jscomp$167$$,$id_new_component$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$selected_fit_content$$=function(){typeof $app$main$data$workspace$transforms$selected_fit_content_69401$$==="undefined"&&($app$main$data$workspace$transforms$selected_fit_content_69401$$=function($meta69402$$){this.$meta69402$=$meta69402$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$selected_fit_content_69401$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$transforms$selected_fit_content_69401$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3888$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_selected_fit_content$$},$app$main$data$workspace$transforms$selected_fit_content_69401$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69403$$,$meta69402__$1$$){return new $app$main$data$workspace$transforms$selected_fit_content_69401$$($meta69402__$1$$)},$app$main$data$workspace$transforms$selected_fit_content_69401$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69402$},$app$main$data$workspace$transforms$selected_fit_content_69401$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$selected_fit_content_69401$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2074_undo_group$jscomp$16$$,$state$jscomp$476$$){var $objects$jscomp$495$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$476$$),$modifiers$jscomp$89_selected$jscomp$52$$=
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$476$$);$_$jscomp$2074_undo_group$jscomp$16$$=$APP.$app$common$uuid$next$$();$modifiers$jscomp$89_selected$jscomp$52$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modifiers$jscomp$90$$,$JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$){if($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$)){var $JSCompiler_temp_const$jscomp$1610_new_modif$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$objects__$1$jscomp$inline_8508$$=$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($objects$jscomp$495$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$),$APP.$cljs$cst$1708$layout_item_h_sizing$$],null),$APP.$cljs$cst$1672$auto$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$),$APP.$cljs$cst$1709$layout_item_v_sizing$$],null),$APP.$cljs$cst$1672$auto$$);$JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$reflow$$()],null)]),$objects__$1$jscomp$inline_8508$$);return $JSCompiler_temp_const$jscomp$1610_new_modif$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$modifiers$jscomp$90$$,$JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$]))}$JSCompiler_temp_const$jscomp$1610_new_modif$$=$app$common$geom$shapes$fit_frame$fit_frame_modifiers$$($objects$jscomp$495$$,
$JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$);return $JSCompiler_temp_const$jscomp$1610_new_modif$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($modifiers$jscomp$90$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$35$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,$JSCompiler_temp_const$jscomp$1610_new_modif$$],null)):$modifiers$jscomp$90$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$495$$),$modifiers$jscomp$89_selected$jscomp$52$$)));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$476$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modifiers$jscomp$89_selected$jscomp$52$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$_$jscomp$2074_undo_group$jscomp$16$$],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1810$modifiers$$,$modifiers$jscomp$89_selected$jscomp$52$$,$APP.$cljs$cst$3138$undo_group$$,$_$jscomp$2074_undo_group$jscomp$16$$],
null)))});return new $app$main$data$workspace$transforms$selected_fit_content_69401$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$tokens$application$get_token_properties$$=function($token$jscomp$89$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$89$$))};
$app$main$data$workspace$tokens$library_edit$drop_token_set$$=function($params$jscomp$308$$){typeof $app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$=function($params$jscomp$309$$,$meta72912$$){this.params=$params$jscomp$309$$;this.$meta72912$=$meta72912$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4713$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_token_set$$},$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72913$$,$meta72912__$1$$){return new $app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$(this.params,
$meta72912__$1$$)},$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72912$},$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$266$$,$state$jscomp$988$$){try{var $tokens_lib$jscomp$32$$=
$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$988$$),$changes$jscomp$inline_8510$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$temp__5823__auto__$jscomp$inline_8513$$=$app$common$logic$tokens$calculate_move_token_set_or_set_group$$($tokens_lib$jscomp$32$$,this.params);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_8513$$)){var $map__54328__$1$jscomp$inline_13346$$=$APP.$cljs$core$__destructure_map$$($temp__5823__auto__$jscomp$inline_8513$$),
$from_path$jscomp$inline_13347$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54328__$1$jscomp$inline_13346$$,$APP.$cljs$cst$2654$from_path$$),$to_path$jscomp$inline_13348$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54328__$1$jscomp$inline_13346$$,$APP.$cljs$cst$2655$to_path$$),$before_path$jscomp$inline_13349$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54328__$1$jscomp$inline_13346$$,$APP.$cljs$cst$2656$before_path$$),$before_group_QMARK_$jscomp$inline_13350$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54328__$1$jscomp$inline_13346$$,$APP.$cljs$cst$3180$before_group_QMARK_$$),$prev_before_path$jscomp$inline_13351$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54328__$1$jscomp$inline_13346$$,$APP.$cljs$cst$3181$prev_before_path$$),$prev_before_group_QMARK_$jscomp$inline_13352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54328__$1$jscomp$inline_13346$$,$APP.$cljs$cst$3182$prev_before_group_QMARK_$$);var $JSCompiler_temp$jscomp$10996$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_8510$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2653$move_token_set$$,$APP.$cljs$cst$2654$from_path$$,$from_path$jscomp$inline_13347$$,$APP.$cljs$cst$2655$to_path$$,$to_path$jscomp$inline_13348$$,
$APP.$cljs$cst$2656$before_path$$,$before_path$jscomp$inline_13349$$,$APP.$cljs$cst$2657$before_group$$,$before_group_QMARK_$jscomp$inline_13350$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2653$move_token_set$$,$APP.$cljs$cst$2654$from_path$$,$to_path$jscomp$inline_13348$$,$APP.$cljs$cst$2655$to_path$$,$from_path$jscomp$inline_13347$$,$APP.$cljs$cst$2656$before_path$$,$prev_before_path$jscomp$inline_13351$$,
$APP.$cljs$cst$2657$before_group$$,$prev_before_group_QMARK_$jscomp$inline_13352$$],null)))}else $JSCompiler_temp$jscomp$10996$$=$changes$jscomp$inline_8510$$;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($JSCompiler_temp$jscomp$10996$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())}catch($e72917$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$tokens$library_edit$drop_error$$($APP.$cljs$core$ex_data$$($e72917$$)))}});
return new $app$main$data$workspace$tokens$library_edit$drop_token_set_72911$$($params$jscomp$308$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$drop_token_set_group$$=function($drop_opts$$){typeof $app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$=function($drop_opts$jscomp$1$$,$meta72905$$){this.$drop_opts$=$drop_opts$jscomp$1$$;this.$meta72905$=$meta72905$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4712$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_token_set_group$$},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72906$$,$meta72905__$1$$){return new $app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$(this.$drop_opts$,
$meta72905__$1$$)},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72905$},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$265$$,$state$jscomp$987$$){try{var $changes$jscomp$inline_8515$$=
$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$tokens_lib$jscomp$inline_8516$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$987$$),$temp__5823__auto__$jscomp$inline_8518$$=$app$common$logic$tokens$calculate_move_token_set_or_set_group$$($tokens_lib$jscomp$inline_8516$$,this.$drop_opts$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_8518$$)){var $map__54331__$1$jscomp$inline_13356$$=$APP.$cljs$core$__destructure_map$$($temp__5823__auto__$jscomp$inline_8518$$),
$from_path$jscomp$inline_13357$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54331__$1$jscomp$inline_13356$$,$APP.$cljs$cst$2654$from_path$$),$to_path$jscomp$inline_13358$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54331__$1$jscomp$inline_13356$$,$APP.$cljs$cst$2655$to_path$$),$before_path$jscomp$inline_13359$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54331__$1$jscomp$inline_13356$$,$APP.$cljs$cst$2656$before_path$$),$before_group_QMARK_$jscomp$inline_13360$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54331__$1$jscomp$inline_13356$$,$APP.$cljs$cst$3180$before_group_QMARK_$$),$prev_before_path$jscomp$inline_13361$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54331__$1$jscomp$inline_13356$$,$APP.$cljs$cst$3181$prev_before_path$$),$prev_before_group_QMARK_$jscomp$inline_13362$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54331__$1$jscomp$inline_13356$$,$APP.$cljs$cst$3182$prev_before_group_QMARK_$$);var $JSCompiler_temp$jscomp$10995$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_8515$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2658$move_token_set_group$$,$APP.$cljs$cst$2654$from_path$$,$from_path$jscomp$inline_13357$$,$APP.$cljs$cst$2655$to_path$$,$to_path$jscomp$inline_13358$$,
$APP.$cljs$cst$2656$before_path$$,$before_path$jscomp$inline_13359$$,$APP.$cljs$cst$2657$before_group$$,$before_group_QMARK_$jscomp$inline_13360$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2658$move_token_set_group$$,$APP.$cljs$cst$2654$from_path$$,$to_path$jscomp$inline_13358$$,$APP.$cljs$cst$2655$to_path$$,$from_path$jscomp$inline_13357$$,$APP.$cljs$cst$2656$before_path$$,$prev_before_path$jscomp$inline_13361$$,
$APP.$cljs$cst$2657$before_group$$,$prev_before_group_QMARK_$jscomp$inline_13362$$],null)))}else $JSCompiler_temp$jscomp$10995$$=$changes$jscomp$inline_8515$$;var $temp__5825__auto__$jscomp$246$$=$JSCompiler_temp$jscomp$10995$$;return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$246$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($temp__5825__auto__$jscomp$246$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$()):null}catch($e72910$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$tokens$library_edit$drop_error$$($APP.$cljs$core$ex_data$$($e72910$$)))}});
return new $app$main$data$workspace$tokens$library_edit$drop_token_set_group_72904$$($drop_opts$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$delete_token_set_group$$=function($path$jscomp$250$$){typeof $app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$=function($path$jscomp$251$$,$meta72887$$){this.path=$path$jscomp$251$$;this.$meta72887$=$meta72887$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4710$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_set_group$$},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72888$$,$meta72887__$1$$){return new $app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$(this.path,
$meta72887__$1$$)},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72887$},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($data$jscomp$421_it$jscomp$264$$,$changes$jscomp$306_state$jscomp$986$$){$data$jscomp$421_it$jscomp$264$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$306_state$jscomp$986$$);$changes$jscomp$306_state$jscomp$986$$=$app$common$logic$tokens$generate_delete_token_set_group$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$data$jscomp$421_it$jscomp$264$$),$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$306_state$jscomp$986$$),
this.path);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$306_state$jscomp$986$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$delete_token_set_group_72886$$($path$jscomp$250$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$import_tokens_lib$$=function($lib$jscomp$10$$){typeof $app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$=function($lib$jscomp$11$$,$meta72873$$){this.$lib$=$lib$jscomp$11$$;this.$meta72873$=$meta72873$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4708$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_import_tokens_lib$$},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72874$$,$meta72873__$1$$){return new $app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$(this.$lib$,
$meta72873__$1$$)},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72873$},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$,
$state$jscomp$984_tokens_lib$jscomp$inline_8521$$){$changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$984_tokens_lib$jscomp$inline_8521$$);$changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$);
$state$jscomp$984_tokens_lib$jscomp$inline_8521$$=this.$lib$;var $library_data$jscomp$inline_8522_prev_tokens_lib$jscomp$inline_8523$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$));$library_data$jscomp$inline_8522_prev_tokens_lib$jscomp$inline_8523$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$inline_8522_prev_tokens_lib$jscomp$inline_8523$$,
$APP.$cljs$cst$2139$tokens_lib$$);$changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2641$set_tokens_lib$$,
$APP.$cljs$cst$2139$tokens_lib$$,$state$jscomp$984_tokens_lib$jscomp$inline_8521$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2641$set_tokens_lib$$,$APP.$cljs$cst$2139$tokens_lib$$,$library_data$jscomp$inline_8522_prev_tokens_lib$jscomp$inline_8523$$],null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$304_changes$jscomp$inline_8520_data$jscomp$419_it$jscomp$262$$),
$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$import_tokens_lib_72872$$($lib$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$toggle_token_set_group$$=function($group_path$jscomp$9$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$=function($group_path$jscomp$10$$,$meta72868$$){this.$group_path$=$group_path$jscomp$10$$;this.$meta72868$=$meta72868$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4707$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_set_group$$},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72869$$,$meta72868__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$(this.$group_path$,
$meta72868__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72868$},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2665_data$jscomp$418$$,$changes$jscomp$303_state$jscomp$983$$){$_$jscomp$2665_data$jscomp$418$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$303_state$jscomp$983$$);$changes$jscomp$303_state$jscomp$983$$=$app$common$logic$tokens$generate_toggle_token_set_group$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$_$jscomp$2665_data$jscomp$418$$),$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$303_state$jscomp$983$$),
this.$group_path$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$303_state$jscomp$983$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$toggle_token_set_group_72867$$($group_path$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69004$$=function($handler$jscomp$33$$,$ids$jscomp$110$$,$shape$jscomp$540$$,$resize$$,$normalize_proportion_lock$$,$meta69005$$){this.handler=$handler$jscomp$33$$;this.ids=$ids$jscomp$110$$;this.shape=$shape$jscomp$540$$;this.resize=$resize$$;this.$normalize_proportion_lock$=$normalize_proportion_lock$$;this.$meta69005$=$meta69005$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0};
$app$main$data$workspace$transforms$start_resize$$=function($handler$jscomp$35$$,$ids$jscomp$112$$,$shape$jscomp$542$$){return new $app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69004$$($handler$jscomp$35$$,$ids$jscomp$112$$,$shape$jscomp$542$$,function($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$,$initial$jscomp$17_initial__$1_initial__$2$$,$layout$jscomp$11_scale_text$$,$G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$,$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$){var $G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,
0,null),$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,1,null),$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,2,null),$point_snap_resize_origin__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,
3,null);$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$=$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$,$APP.$cljs$cst$1605$selrect$$);var $change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$=$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,$APP.$cljs$cst$290$width$$),$G__68990_height$jscomp$124$$=$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,$APP.$cljs$cst$1522$height$$),$rotation$jscomp$13_rotation__$1$$=$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$?.rotation??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$,$APP.$cljs$cst$1788$rotation$$),$change_height_QMARK__shape_center$jscomp$5$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$);$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$);
var $shape_transform_inverse$$=$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$);$rotation$jscomp$13_rotation__$1$$=$APP.$cljs$core$truth_$$($rotation$jscomp$13_rotation__$1$$)?$rotation$jscomp$13_rotation__$1$$:0;$initial$jscomp$17_initial__$1_initial__$2$$=$APP.$app$common$geom$matrix$transform_point_center$$($initial$jscomp$17_initial__$1_initial__$2$$,$change_height_QMARK__shape_center$jscomp$5$$,$shape_transform_inverse$$);
$initial$jscomp$17_initial__$1_initial__$2$$=$app$main$data$workspace$transforms$fix_init_point$$($initial$jscomp$17_initial__$1_initial__$2$$,$handler$jscomp$35$$,$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$);$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=$APP.$app$common$geom$matrix$transform_point_center$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($rotation$jscomp$13_rotation__$1$$,
0)?$point_snap_resize_origin__$1$$:$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$change_height_QMARK__shape_center$jscomp$5$$,$shape_transform_inverse$$);$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$,
$G__68990_height$jscomp$124$$);$layout$jscomp$11_scale_text$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$11_scale_text$$,$APP.$cljs$cst$3716$scale_text$$);$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$=$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$||$layout$jscomp$11_scale_text$$;$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=
$APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$subtract$$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$initial$jscomp$17_initial__$1_initial__$2$$),$app$main$data$workspace$transforms$get_handler_multiplier$$($handler$jscomp$35$$));$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$=$APP.$app$common$geom$point$divide$$($APP.$app$common$geom$point$add$$($change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$,
$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$),$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$);$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$,$APP.$cljs$cst$1510$x$$);$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$=$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$,
$APP.$cljs$cst$1511$y$$);$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=$APP.$app$common$geom$point$pos__GT_Point$$($APP.$app$common$math$almost_zero_QMARK_$$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$)?.001:$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,
$APP.$app$common$math$almost_zero_QMARK_$$($change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$)?.001:$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$);$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$?($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,
$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,$APP.$cljs$cst$257$left$$)?$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$APP.$cljs$cst$1510$x$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,$APP.$cljs$cst$1562$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,$APP.$cljs$cst$1563$bottom$$)?$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,
$APP.$cljs$cst$1511$y$$):Math.max($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$APP.$cljs$cst$1510$x$$),$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$APP.$cljs$cst$1511$y$$)),$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$,$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$)):
$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$=$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$;$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$,
$APP.$cljs$cst$1605$selrect$$);$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$=$app$main$data$workspace$transforms$get_handler_resize_origin$$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$handler$jscomp$35$$);$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=
$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$?$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$subtract$$($change_height_QMARK__shape_center$jscomp$5$$,$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$),$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$),
$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$),$change_height_QMARK__shape_center$jscomp$5$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,-1)),$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$):null;$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$=$APP.$app$common$geom$matrix$transform_point_center$$($change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$,
$change_height_QMARK__shape_center$jscomp$5$$,$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$);$point_snap_resize_origin__$1$$=$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$!=null?$APP.$app$common$geom$point$add$$($center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$,$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$):
$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$;$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$)?$APP.$app$main$data$workspace$modifiers$next_grow_type$$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$?.$grow_type$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$,
$APP.$cljs$cst$1770$grow_type$$),$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$):null;$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$=$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$,
$APP.$cljs$cst$1510$x$$),1));$change_height_QMARK__shape_center$jscomp$5$$=$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$,$APP.$cljs$cst$1511$y$$),1));$G__68990_height$jscomp$124$$=$APP.$app$common$types$modifiers$empty$$();
$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$=$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$!=null?$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($G__68990_height$jscomp$124$$,$G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$):
$G__68990_height$jscomp$124$$;$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$=$APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($G__68990__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14633$$,$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$,$point_snap_resize_origin__$1$$,$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,
$shape_transform_inverse$$);$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$=($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$,$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$)||$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$),
$APP.$cljs$cst$1697$fix$$)&&$change_width_QMARK__handler_origin_p$jscomp$inline_14632_shapev_width$jscomp$138_y$jscomp$inline_14634$$?$APP.$app$common$types$modifiers$change_property$$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$;$G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$=($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$,
$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$)||$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$),$APP.$cljs$cst$1697$fix$$)&&$change_height_QMARK__shape_center$jscomp$5$$?$APP.$app$common$types$modifiers$change_property$$($G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$,
$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__68990__$2_G__68990__$3_p__68972_selrect$jscomp$62_shape_transform$jscomp$1$$;$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$,$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$?.$grow_type$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$,$APP.$cljs$cst$1770$grow_type$$)):$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$)?$APP.$app$common$types$modifiers$change_property$$($G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$,$APP.$cljs$cst$1770$grow_type$$,$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$):$G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$;$layout$jscomp$11_scale_text$$&&
($G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$=$JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11003_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13367$$,$APP.$cljs$cst$1510$x$$),$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$truth_$$($G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$)?
$G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$:$APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1780$structure_child$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$StructureOperation$$($APP.$cljs$cst$1803$scale_content$$,null,$G__68990__$4_objects$jscomp$479_value$jscomp$inline_14637$$,null,null,null,null)));return $G__68990__$5_JSCompiler_temp$jscomp$14090_shape__$1$jscomp$39$$},function($alt_QMARK__p__69000$$){var $point$jscomp$63$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK__p__69000$$,
0,null),$shift_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK__p__69000$$,1,null);$alt_QMARK__p__69000$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK__p__69000$$,2,null);var $proportion_lock_QMARK_$$=$APP.$cljs$cst$1808$proportion_lock$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$542$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$63$$,$proportion_lock_QMARK_$$||$shift_QMARK_$$,
$alt_QMARK__p__69000$$],null)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$start_resize$$=function($param72150$$,$param72151$$,$param72152$$){return $app$main$data$workspace$transforms$start_resize$$($param72150$$,$param72151$$,$param72152$$)};
$app$main$data$workspace$transforms$start_rotate$$=function($shapes$jscomp$94$$){typeof $app$main$data$workspace$transforms$start_rotate_69112$$==="undefined"&&($app$main$data$workspace$transforms$start_rotate_69112$$=function($shapes$jscomp$95$$,$meta69113$$){this.shapes=$shapes$jscomp$95$$;this.$meta69113$=$meta69113$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3867$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_rotate$$},$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69114$$,$meta69113__$1$$){return new $app$main$data$workspace$transforms$start_rotate_69112$$(this.shapes,$meta69113__$1$$)},$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69113$},$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2054$$,$state$jscomp$460$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$460$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1289$transform$$],null),$APP.$cljs$cst$2863$rotate$$)},$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_rotate_69112$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2055_stopper$jscomp$12$$,$state$jscomp$461$$,$angle_stream_group$jscomp$37_stream$jscomp$49$$){var $self__$jscomp$4612$$=this;$_$jscomp$2055_stopper$jscomp$12$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($angle_stream_group$jscomp$37_stream$jscomp$49$$,
null);$angle_stream_group$jscomp$37_stream$jscomp$49$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($self__$jscomp$4612$$.shapes);var $group_center$$=$APP.$app$common$geom$rect$rect__GT_center$$($angle_stream_group$jscomp$37_stream$jscomp$49$$),$initial_angle$$=$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),$group_center$$);$angle_stream_group$jscomp$37_stream$jscomp$49$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$(function($p__69115_shift_QMARK_$jscomp$2$$){var $angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69115_shift_QMARK_$jscomp$2$$,0,null),$angle__$3$jscomp$inline_8531_mod_QMARK_$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69115_shift_QMARK_$jscomp$2$$,1,null);$p__69115_shift_QMARK_$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69115_shift_QMARK_$jscomp$2$$,2,null);$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$=$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$,
$group_center$$)-$initial_angle$$;$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$=$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$<0?360+$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$:$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$;$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$,360)?0:$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$;$angle__$3$jscomp$inline_8531_mod_QMARK_$jscomp$2$$=$APP.$cljs$core$truth_$$($angle__$3$jscomp$inline_8531_mod_QMARK_$jscomp$2$$)?$APP.$app$common$math$floor$$($angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$/
45)*45:$angle$jscomp$inline_8528_angle__$1$jscomp$inline_8529_angle__$2$jscomp$inline_8530_pos$jscomp$109$$;return $APP.$cljs$core$truth_$$($p__69115_shift_QMARK_$jscomp$2$$)?$APP.$app$common$math$floor$$($angle__$3$jscomp$inline_8531_mod_QMARK_$jscomp$2$$/15)*15:$angle__$3$jscomp$inline_8531_mod_QMARK_$jscomp$2$$},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$streams$mouse_position_mod$$,$APP.$sub$jscomp$inline_5572$$,$APP.$app$main$streams$mouse_position$$)));
return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$461$$,"render-wasm/v1")?$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2055_stopper$jscomp$12$$,$APP.$beicon$v2$core$map$$(function($p1__69109_SHARP_$$){return $app$main$data$workspace$modifiers$set_wasm_modifiers$$($app$main$data$workspace$transforms$rotation_modifiers$$($p1__69109_SHARP_$$,$self__$jscomp$4612$$.shapes,$group_center$$))},$angle_stream_group$jscomp$37_stream$jscomp$49$$)),
$APP.$beicon$v2$core$map$$(function($p1__69110_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($app$main$data$workspace$transforms$rotation_modifiers$$($p1__69110_SHARP_$$,$self__$jscomp$4612$$.shapes,$group_center$$))},$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2055_stopper$jscomp$12$$,$angle_stream_group$jscomp$37_stream$jscomp$49$$)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$())):$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2055_stopper$jscomp$12$$,
$APP.$beicon$v2$core$map$$(function($p1__69111_SHARP_$$){return $app$main$data$workspace$modifiers$set_rotation_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__69111_SHARP_$$,$self__$jscomp$4612$$.shapes,$group_center$$)},$angle_stream_group$jscomp$37_stream$jscomp$49$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$app$main$data$workspace$transforms$finish_transform$$()))});return new $app$main$data$workspace$transforms$start_rotate_69112$$($shapes$jscomp$94$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$change_orientation$$=function($ids$jscomp$118$$,$orientation$jscomp$3$$){typeof $app$main$data$workspace$transforms$change_orientation_69093$$==="undefined"&&($app$main$data$workspace$transforms$change_orientation_69093$$=function($ids$jscomp$119$$,$orientation$jscomp$4$$,$meta69094$$){this.ids=$ids$jscomp$119$$;this.orientation=$orientation$jscomp$4$$;this.$meta69094$=$meta69094$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3866$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_change_orientation$$},$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69095$$,$meta69094__$1$$){return new $app$main$data$workspace$transforms$change_orientation_69093$$(this.ids,
this.orientation,$meta69094__$1$$)},$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69094$},$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2052_modif_tree$jscomp$56_objects$jscomp$481$$,$state$jscomp$458$$){var $self__$jscomp$4606$$=
this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$458$$,"render-wasm/v1"))return $state$jscomp$458$$;$_$jscomp$2052_modif_tree$jscomp$56_objects$jscomp$481$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$458$$);$_$jscomp$2052_modif_tree$jscomp$56_objects$jscomp$481$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($self__$jscomp$4606$$.ids,
$_$jscomp$2052_modif_tree$jscomp$56_objects$jscomp$481$$,function($shape$jscomp$544$$){return $app$common$types$modifiers$change_orientation_modifiers$$($shape$jscomp$544$$,$self__$jscomp$4606$$.orientation)}),$_$jscomp$2052_modif_tree$jscomp$56_objects$jscomp$481$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$458$$,$APP.$cljs$cst$1922$workspace_modifiers$$,$_$jscomp$2052_modif_tree$jscomp$56_objects$jscomp$481$$)},$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$change_orientation_69093$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2053_modif_tree$jscomp$57_objects$jscomp$482$$,$state$jscomp$459$$){var $self__$jscomp$4607$$=this;return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$459$$,"render-wasm/v1")?($_$jscomp$2053_modif_tree$jscomp$57_objects$jscomp$482$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$459$$),
$_$jscomp$2053_modif_tree$jscomp$57_objects$jscomp$482$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($self__$jscomp$4607$$.ids,$_$jscomp$2053_modif_tree$jscomp$57_objects$jscomp$482$$,function($shape$jscomp$545$$){return $app$common$types$modifiers$change_orientation_modifiers$$($shape$jscomp$545$$,$self__$jscomp$4607$$.orientation)}),$_$jscomp$2053_modif_tree$jscomp$57_objects$jscomp$482$$),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($_$jscomp$2053_modif_tree$jscomp$57_objects$jscomp$482$$))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});return new $app$main$data$workspace$transforms$change_orientation_69093$$($ids$jscomp$118$$,$orientation$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$change_bool_type$$=function($shape_id$jscomp$79$$,$type$jscomp$458$$){typeof $app$main$data$workspace$bool$change_bool_type_67740$$==="undefined"&&($app$main$data$workspace$bool$change_bool_type_67740$$=function($shape_id$jscomp$80$$,$type$jscomp$459$$,$meta67741$$){this.$shape_id$=$shape_id$jscomp$80$$;this.type=$type$jscomp$459$$;this.$meta67741$=$meta67741$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bool$change_bool_type_67740$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$change_bool_type_67740$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3660$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_change_bool_type$$},$app$main$data$workspace$bool$change_bool_type_67740$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67742$$,$meta67741__$1$$){return new $app$main$data$workspace$bool$change_bool_type_67740$$(this.$shape_id$,this.type,$meta67741__$1$$)},$app$main$data$workspace$bool$change_bool_type_67740$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67741$},$app$main$data$workspace$bool$change_bool_type_67740$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$change_bool_type_67740$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1965_objects$jscomp$346$$,$state$jscomp$404$$){function $change_type$$($shape$jscomp$448$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$448$$,$APP.$cljs$cst$1888$bool_type$$,$self__$jscomp$4388$$.type)}
var $self__$jscomp$4388$$=this;$_$jscomp$1965_objects$jscomp$346$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$404$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($_$jscomp$1965_objects$jscomp$346$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1965_objects$jscomp$346$$,$self__$jscomp$4388$$.$shape_id$)))?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4388$$.$shape_id$],null),$change_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0],null)))});return new $app$main$data$workspace$bool$change_bool_type_67740$$($shape_id$jscomp$79$$,$type$jscomp$458$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$bool_to_group$$=function($shape_id$jscomp$77$$){typeof $app$main$data$workspace$bool$bool_to_group_67734$$==="undefined"&&($app$main$data$workspace$bool$bool_to_group_67734$$=function($shape_id$jscomp$78$$,$meta67735$$){this.$shape_id$=$shape_id$jscomp$78$$;this.$meta67735$=$meta67735$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bool$bool_to_group_67734$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$bool$bool_to_group_67734$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3659$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_bool_to_group$$},$app$main$data$workspace$bool$bool_to_group_67734$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67736$$,$meta67735__$1$$){return new $app$main$data$workspace$bool$bool_to_group_67734$$(this.$shape_id$,$meta67735__$1$$)},$app$main$data$workspace$bool$bool_to_group_67734$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67735$},$app$main$data$workspace$bool$bool_to_group_67734$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$bool_to_group_67734$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1964_objects$jscomp$345$$,$state$jscomp$403$$){$_$jscomp$1964_objects$jscomp$345$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$403$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($_$jscomp$1964_objects$jscomp$345$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1964_objects$jscomp$345$$,this.$shape_id$)))?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$shape_id$],null),$app$main$data$workspace$bool$bool__GT_group$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,
!0],null)))});return new $app$main$data$workspace$bool$bool_to_group_67734$$($shape_id$jscomp$77$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$group_to_bool$$=function($shape_id$jscomp$75$$,$type$jscomp$456$$){typeof $app$main$data$workspace$bool$group_to_bool_67727$$==="undefined"&&($app$main$data$workspace$bool$group_to_bool_67727$$=function($shape_id$jscomp$76$$,$type$jscomp$457$$,$meta67728$$){this.$shape_id$=$shape_id$jscomp$76$$;this.type=$type$jscomp$457$$;this.$meta67728$=$meta67728$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bool$group_to_bool_67727$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$group_to_bool_67727$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3658$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_group_to_bool$$},$app$main$data$workspace$bool$group_to_bool_67727$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67729$$,$meta67728__$1$$){return new $app$main$data$workspace$bool$group_to_bool_67727$$(this.$shape_id$,this.type,$meta67728__$1$$)},$app$main$data$workspace$bool$group_to_bool_67727$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67728$},$app$main$data$workspace$bool$group_to_bool_67727$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$group_to_bool_67727$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1963_objects$jscomp$343$$,$state$jscomp$402_update_fn$jscomp$22$$){$_$jscomp$1963_objects$jscomp$343$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$402_update_fn$jscomp$22$$);
$state$jscomp$402_update_fn$jscomp$22$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$bool$group__GT_bool$$,this.type);return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($_$jscomp$1963_objects$jscomp$343$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1963_objects$jscomp$343$$,this.$shape_id$)))?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$shape_id$],null),$state$jscomp$402_update_fn$jscomp$22$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0],null)))});return new $app$main$data$workspace$bool$group_to_bool_67727$$($shape_id$jscomp$75$$,$type$jscomp$456$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$apply_token_on_color_selected$$=function($color_operations$$,$token$jscomp$87$$){typeof $app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$=function($color_operations$jscomp$1$$,$token$jscomp$88$$,$meta72623$$){this.$color_operations$=$color_operations$jscomp$1$$;this.token=$token$jscomp$88$$;this.$meta72623$=$meta72623$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4657$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token_on_color_selected$$},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72624$$,$meta72623__$1$$){return new $app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$(this.$color_operations$,this.token,$meta72623__$1$$)},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72623$},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$6526$$=this,$undo_id$jscomp$87$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$87$$)),$APP.$beicon$v2$core$map$$(function($G__72629_G__72629__$1_cop$$){var $shape_ids$jscomp$103$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__72629_G__72629__$1_cop$$)],
null);$G__72629_G__72629__$1_cop$$=$APP.$cljs$cst$4158$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__72629_G__72629__$1_cop$$);$G__72629_G__72629__$1_cop$$=$G__72629_G__72629__$1_cop$$ instanceof $APP.$cljs$core$Keyword$$?$G__72629_G__72629__$1_cop$$.$fqn$:null;switch($G__72629_G__72629__$1_cop$$){case "fill":return $APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6526$$.token,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$103$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_fill$$],null));case "stroke":return $APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6526$$.token,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$103$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$],null));case "content":return $APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6526$$.token,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$103$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_fill$$],null));case "shadow":return $APP.$beicon$v2$core$empty$$();default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__72629_G__72629__$1_cop$$)].join(""));
}},$APP.$beicon$v2$core$from$$($self__$jscomp$6526$$.$color_operations$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$87$$)))});return new $app$main$data$workspace$tokens$application$apply_token_on_color_selected_72622$$($color_operations$$,$token$jscomp$87$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$apply_token_from_input$$=function($p__72612$$){var $map__72613__$1$$=$APP.$cljs$core$__destructure_map$$($p__72612$$),$token$jscomp$85$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72613__$1$$,$APP.$cljs$cst$1136$token$$),$attrs$jscomp$165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72613__$1$$,$APP.$cljs$cst$2645$attrs$$),$shape_ids$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72613__$1$$,$APP.$cljs$cst$4641$shape_ids$$),
$expand_with_children$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72613__$1$$,$APP.$cljs$cst$4653$expand_with_children$$);typeof $app$main$data$workspace$tokens$application$apply_token_from_input_72614$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_token_from_input_72614$$=function($p__72612$jscomp$1$$,$map__72613$jscomp$1$$,$token$jscomp$86$$,$attrs$jscomp$166$$,$shape_ids$jscomp$102$$,$expand_with_children$jscomp$3$$,$meta72615$$){this.$p__72612$=
$p__72612$jscomp$1$$;this.$map__72613$=$map__72613$jscomp$1$$;this.token=$token$jscomp$86$$;this.$attrs$=$attrs$jscomp$166$$;this.$shape_ids$=$shape_ids$jscomp$102$$;this.$expand_with_children$=$expand_with_children$jscomp$3$$;this.$meta72615$=$meta72615$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4656$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token_from_input$$},$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72616$$,$meta72615__$1$$){return new $app$main$data$workspace$tokens$application$apply_token_from_input_72614$$(this.$p__72612$,this.$map__72613$,this.token,this.$attrs$,this.$shape_ids$,this.$expand_with_children$,$meta72615__$1$$)},
$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72615$},$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_from_input_72614$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2640_shapes$jscomp$126_shapes__$1$jscomp$15$$,$attributes$jscomp$74_map__72621_state$jscomp$958$$){var $self__$jscomp$6522$$=
this,$objects$jscomp$677$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($attributes$jscomp$74_map__72621_state$jscomp$958$$);$_$jscomp$2640_shapes$jscomp$126_shapes__$1$jscomp$15$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$677$$)),$self__$jscomp$6522$$.$shape_ids$);$_$jscomp$2640_shapes$jscomp$126_shapes__$1$jscomp$15$$=
$APP.$cljs$core$truth_$$($self__$jscomp$6522$$.$expand_with_children$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$771$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$771$$),$APP.$cljs$cst$1608$group$$)?$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$677$$,
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$771$$)):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$771$$],null)}),$_$jscomp$2640_shapes$jscomp$126_shapes__$1$jscomp$15$$):$_$jscomp$2640_shapes$jscomp$126_shapes__$1$jscomp$15$$;$attributes$jscomp$74_map__72621_state$jscomp$958$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6522$$.token));
var $map__72621__$1_on_update_shape__$1$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($attributes$jscomp$74_map__72621_state$jscomp$958$$);$attributes$jscomp$74_map__72621_state$jscomp$958$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72621__$1_on_update_shape__$1$jscomp$1$$,$APP.$cljs$cst$1993$attributes$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72621__$1_on_update_shape__$1$jscomp$1$$,$APP.$cljs$cst$1102$_$$);var $on_update_shape$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72621__$1_on_update_shape__$1$jscomp$1$$,
$APP.$cljs$cst$4646$on_update_shape$$);$map__72621__$1_on_update_shape__$1$jscomp$1$$=$APP.$cljs$core$seq$$($self__$jscomp$6522$$.$attrs$)?function(){var $or__5025__auto__$jscomp$889$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$attr__GT_shape_update$$,$APP.$cljs$core$first$$($self__$jscomp$6522$$.$attrs$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$889$$)?$or__5025__auto__$jscomp$889$$:$on_update_shape$jscomp$4$$}():$on_update_shape$jscomp$4$$;
return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6522$$.token),$APP.$cljs$cst$1983$spacing$$)&&$self__$jscomp$6522$$.$attrs$==null?$APP.$app$main$data$workspace$tokens$application$apply_spacing_token_separated$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$self__$jscomp$6522$$.token,$APP.$cljs$cst$2599$attr$$,$self__$jscomp$6522$$.$attrs$,$APP.$cljs$cst$1614$shapes$$,
$_$jscomp$2640_shapes$jscomp$126_shapes__$1$jscomp$15$$],null)):$APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$empty_QMARK_$$($self__$jscomp$6522$$.$attrs$)?$attributes$jscomp$74_map__72621_state$jscomp$958$$:$self__$jscomp$6522$$.$attrs$,$APP.$cljs$cst$1136$token$$,$self__$jscomp$6522$$.token,$APP.$cljs$cst$4641$shape_ids$$,$self__$jscomp$6522$$.$shape_ids$,$APP.$cljs$cst$4646$on_update_shape$$,
$map__72621__$1_on_update_shape__$1$jscomp$1$$],null)))});return new $app$main$data$workspace$tokens$application$apply_token_from_input_72614$$($p__72612$$,$map__72613__$1$$,$token$jscomp$85$$,$attrs$jscomp$165$$,$shape_ids$jscomp$101$$,$expand_with_children$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_shape_proportion_lock$$=function($id$jscomp$755$$,$lock$jscomp$10$$){typeof $app$main$data$workspace$set_shape_proportion_lock_71857$$==="undefined"&&($app$main$data$workspace$set_shape_proportion_lock_71857$$=function($id$jscomp$756$$,$lock$jscomp$11$$,$meta71858$$){this.id=$id$jscomp$756$$;this.lock=$lock$jscomp$11$$;this.$meta71858$=$meta71858$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_shape_proportion_lock_71857$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_proportion_lock_71857$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4490$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_shape_proportion_lock$$},$app$main$data$workspace$set_shape_proportion_lock_71857$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71859$$,$meta71858__$1$$){return new $app$main$data$workspace$set_shape_proportion_lock_71857$$(this.id,this.lock,$meta71858__$1$$)},
$app$main$data$workspace$set_shape_proportion_lock_71857$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71858$},$app$main$data$workspace$set_shape_proportion_lock_71857$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_proportion_lock_71857$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6292$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6292$$.id],null),function($JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$){if($APP.$cljs$core$not$$($self__$jscomp$6292$$.lock))$JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$,$APP.$cljs$cst$1808$proportion_lock$$,!1);else{$JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$,$APP.$cljs$cst$1808$proportion_lock$$,!0);var $map__48925$jscomp$inline_8534_width$jscomp$inline_8536$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$),$height$jscomp$inline_8537_map__48925__$1$jscomp$inline_8535$$=$APP.$cljs$core$__destructure_map$$($map__48925$jscomp$inline_8534_width$jscomp$inline_8536$$);
$map__48925$jscomp$inline_8534_width$jscomp$inline_8536$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_8537_map__48925__$1$jscomp$inline_8535$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_8537_map__48925__$1$jscomp$inline_8535$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_8537_map__48925__$1$jscomp$inline_8535$$,$APP.$cljs$cst$1522$height$$);$JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$,
$APP.$cljs$cst$1807$proportion$$,$map__48925$jscomp$inline_8534_width$jscomp$inline_8536$$/$height$jscomp$inline_8537_map__48925__$1$jscomp$inline_8535$$)}return $JSCompiler_temp$jscomp$1525_shape$jscomp$757_shape$jscomp$inline_8533$$}))});return new $app$main$data$workspace$set_shape_proportion_lock_71857$$($id$jscomp$755$$,$lock$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$reorder_layout_track$$=function($ids$jscomp$231$$,$type$jscomp$525$$,$from_index$jscomp$7$$,$to_index$jscomp$11$$,$move_content_QMARK_$jscomp$3$$){typeof $app$main$data$workspace$shape_layout$reorder_layout_track_71212$$==="undefined"&&($app$main$data$workspace$shape_layout$reorder_layout_track_71212$$=function($ids$jscomp$232$$,$type$jscomp$526$$,$from_index$jscomp$8$$,$to_index$jscomp$12$$,$move_content_QMARK_$jscomp$4$$,$meta71213$$){this.ids=$ids$jscomp$232$$;
this.type=$type$jscomp$526$$;this.$from_index$=$from_index$jscomp$8$$;this.$to_index$=$to_index$jscomp$12$$;this.$move_content_QMARK_$=$move_content_QMARK_$jscomp$4$$;this.$meta71213$=$meta71213$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4407$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_reorder_layout_track$$},$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71214$$,$meta71213__$1$$){return new $app$main$data$workspace$shape_layout$reorder_layout_track_71212$$(this.ids,this.type,this.$from_index$,this.$to_index$,this.$move_content_QMARK_$,$meta71213__$1$$)},$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71213$},$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$reorder_layout_track_71212$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5986$$=this,$undo_id$jscomp$55$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$55$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5986$$.ids,
function($shape$jscomp$735$$){var $G__71220_G__71220__$1$$=$self__$jscomp$5986$$.type;$G__71220_G__71220__$1$$=$G__71220_G__71220__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__71220_G__71220__$1$$.$fqn$:null;switch($G__71220_G__71220__$1$$){case "row":return $app$common$types$shape$layout$reorder_grid_track$$($shape$jscomp$735$$,$self__$jscomp$5986$$.$from_index$,$self__$jscomp$5986$$.$to_index$,$self__$jscomp$5986$$.$move_content_QMARK_$,$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1656$row$$);
case "column":return $app$common$types$shape$layout$reorder_grid_track$$($shape$jscomp$735$$,$self__$jscomp$5986$$.$from_index$,$self__$jscomp$5986$$.$to_index$,$self__$jscomp$5986$$.$move_content_QMARK_$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$216$column$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71220_G__71220__$1$$)].join(""));}}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5986$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$55$$))});return new $app$main$data$workspace$shape_layout$reorder_layout_track_71212$$($ids$jscomp$231$$,$type$jscomp$525$$,$from_index$jscomp$7$$,$to_index$jscomp$11$$,$move_content_QMARK_$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$combine_selected_as_variants$$=function($options$jscomp$577$$){typeof $app$main$data$workspace$variants$combine_selected_as_variants_71532$$==="undefined"&&($app$main$data$workspace$variants$combine_selected_as_variants_71532$$=function($options$jscomp$578$$,$meta71533$$){this.options=$options$jscomp$578$$;this.$meta71533$=$meta71533$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$combine_selected_as_variants_71532$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$combine_selected_as_variants_71532$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4443$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_combine_selected_as_variants$$},$app$main$data$workspace$variants$combine_selected_as_variants_71532$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71534$$,$meta71533__$1$$){return new $app$main$data$workspace$variants$combine_selected_as_variants_71532$$(this.options,
$meta71533__$1$$)},$app$main$data$workspace$variants$combine_selected_as_variants_71532$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71533$},$app$main$data$workspace$variants$combine_selected_as_variants_71532$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$combine_selected_as_variants_71532$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2504_selected$jscomp$95$$,$state$jscomp$854$$){$_$jscomp$2504_selected$jscomp$95$$=
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$854$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$variants$combine_as_variants$$($_$jscomp$2504_selected$jscomp$95$$,this.options))});return new $app$main$data$workspace$variants$combine_selected_as_variants_71532$$($options$jscomp$577$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$finish_move_overlay_pos$$=function($index$jscomp$346$$,$frame_pos$jscomp$3$$,$offset$jscomp$179$$){typeof $app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$==="undefined"&&($app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$=function($index$jscomp$347$$,$frame_pos$jscomp$4$$,$offset$jscomp$180$$,$meta70644$$){this.index=$index$jscomp$347$$;this.$frame_pos$=$frame_pos$jscomp$4$$;this.offset=$offset$jscomp$180$$;this.$meta70644$=
$meta70644$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4320$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_finish_move_overlay_pos$$},$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70645$$,$meta70644__$1$$){return new $app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$(this.index,this.$frame_pos$,this.offset,$meta70644__$1$$)},$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70644$},$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2405$$,$state$jscomp$780$$){return $APP.$app$common$data$dissoc_in$$($APP.$app$common$data$dissoc_in$$($state$jscomp$780$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4317$move_overlay_to$$],null)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4318$move_overlay_index$$],null))},
$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$,$shape$jscomp$719_state$jscomp$781$$){$_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);
var $overlay_pos$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$,this.$frame_pos$),this.offset);$_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$719_state$jscomp$781$$);$_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$719_state$jscomp$781$$,$_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$);$shape$jscomp$719_state$jscomp$781$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$,$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$719_state$jscomp$781$$)));
$_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$=$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$719_state$jscomp$781$$);var $new_interactions$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2406_interactions$jscomp$13_objects$jscomp$612_page_id$jscomp$220_pos$jscomp$114$$,this.index,function($p1__70641_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70641_SHARP_$$,
$APP.$cljs$cst$1971$overlay_pos_type$$,$APP.$cljs$cst$1673$manual$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1970$overlay_position$$,$overlay_pos$jscomp$1$$]))});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$719_state$jscomp$781$$)],
null),function($p1__70642_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__70642_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2051$interactions$$,$new_interactions$jscomp$1$$],null)]))}))});return new $app$main$data$workspace$interactions$finish_move_overlay_pos_70643$$($index$jscomp$346$$,$frame_pos$jscomp$3$$,$offset$jscomp$179$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$start_move_overlay_pos$$=function($index$jscomp$344$$){typeof $app$main$data$workspace$interactions$start_move_overlay_pos_70590$$==="undefined"&&($app$main$data$workspace$interactions$start_move_overlay_pos_70590$$=function($index$jscomp$345$$,$meta70591$$){this.index=$index$jscomp$345$$;this.$meta70591$=$meta70591$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4316$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_start_move_overlay_pos$$},$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70592$$,$meta70591__$1$$){return new $app$main$data$workspace$interactions$start_move_overlay_pos_70590$$(this.index,
$meta70591__$1$$)},$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70591$},$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2402$$,$state$jscomp$777$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$777$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4317$move_overlay_to$$],null),null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4318$move_overlay_index$$],null),this.index)},$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$interactions$start_move_overlay_pos_70590$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2403_initial_pos$jscomp$3$$,$overlay_pos_state$jscomp$778$$,$stopper$jscomp$33_stream$jscomp$86$$){$_$jscomp$2403_initial_pos$jscomp$3$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);var $objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($overlay_pos_state$jscomp$778$$);
$stopper$jscomp$33_stream$jscomp$86$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$33_stream$jscomp$86$$,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$))){$objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($overlay_pos_state$jscomp$778$$);
$objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_state$jscomp$778$$,$objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$);var $shape$jscomp$718$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$,$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($overlay_pos_state$jscomp$778$$)));
$overlay_pos_state$jscomp$778$$=$APP.$cljs$cst$1970$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$718$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2051$interactions$$,this.index],null)));$objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$,
$shape$jscomp$718$$);var $frame_pos$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$611_orig_frame$jscomp$1_page_id$jscomp$219_selected$jscomp$82$$)),$offset$jscomp$176$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($_$jscomp$2403_initial_pos$jscomp$3$$,
$overlay_pos_state$jscomp$778$$),$frame_pos$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($p1__70586_SHARP_$$){return $app$main$data$workspace$interactions$move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$interactions$move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$($p1__70586_SHARP_$$,$frame_pos$$,$offset$jscomp$176$$):$app$main$data$workspace$interactions$move_overlay_pos$$($p1__70586_SHARP_$$,$frame_pos$$,$offset$jscomp$176$$)},$APP.$beicon$v2$core$take_until$$($stopper$jscomp$33_stream$jscomp$86$$,
$APP.$app$main$streams$mouse_position$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$interactions$finish_move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$interactions$finish_move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$(this.index,$frame_pos$$,$offset$jscomp$176$$):$app$main$data$workspace$interactions$finish_move_overlay_pos$$(this.index,$frame_pos$$,$offset$jscomp$176$$)))}return null});return new $app$main$data$workspace$interactions$start_move_overlay_pos_70590$$($index$jscomp$344$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$remove_all_interactions_nav_to$$=function($frame_id$jscomp$104$$){typeof $app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$==="undefined"&&($app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$=function($frame_id$jscomp$105$$,$meta70508$$){this.$frame_id$=$frame_id$jscomp$105$$;this.$meta70508$=$meta70508$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4309$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_all_interactions_nav_to$$},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70509$$,$meta70508__$1$$){return new $app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$(this.$frame_id$,
$meta70508__$1$$)},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70508$},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2396_page_id$jscomp$218$$,$objects$jscomp$609_state$jscomp$770$$){var $self__$jscomp$5731$$=
this;$_$jscomp$2396_page_id$jscomp$218$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$609_state$jscomp$770$$);$objects$jscomp$609_state$jscomp$770$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$609_state$jscomp$770$$,$_$jscomp$2396_page_id$jscomp$218$$);return $APP.$beicon$v2$core$from$$($APP.$app$common$data$vec_without_nils$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$716$$){var $interactions$jscomp$12$$=
$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$716$$),$new_interactions$$=$app$common$types$shape$interactions$remove_interactions$$(function($p1__70506_SHARP_$$){var $frame_id$jscomp$inline_8540$$=$self__$jscomp$5731$$.$frame_id$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__70506_SHARP_$$),$APP.$cljs$cst$1941$navigate$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__70506_SHARP_$$),
$frame_id$jscomp$inline_8540$$)},$interactions$jscomp$12$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($interactions$jscomp$12$$),$APP.$cljs$core$count$$($new_interactions$$))?$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$716$$)],null),function($shape__$1$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$53$$,
$APP.$cljs$cst$2051$interactions$$,$new_interactions$$)}):null},$APP.$cljs$core$vals$$($objects$jscomp$609_state$jscomp$770$$))))});return new $app$main$data$workspace$interactions$remove_all_interactions_nav_to_70507$$($frame_id$jscomp$104$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape$jscomp$708$$,$destination$jscomp$11$$){typeof $app$main$data$workspace$interactions$add_new_interaction_70468$$==="undefined"&&($app$main$data$workspace$interactions$add_new_interaction_70468$$=function($shape$jscomp$709$$,$destination$jscomp$12$$,$meta70469$$){this.shape=$shape$jscomp$709$$;this.destination=$destination$jscomp$12$$;this.$meta70469$=$meta70469$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_new_interaction_70468$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_new_interaction_70468$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4306$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_new_interaction$$},$app$main$data$workspace$interactions$add_new_interaction_70468$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70470$$,$meta70469__$1$$){return new $app$main$data$workspace$interactions$add_new_interaction_70468$$(this.shape,this.destination,$meta70469__$1$$)},$app$main$data$workspace$interactions$add_new_interaction_70468$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70469$},$app$main$data$workspace$interactions$add_new_interaction_70468$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_new_interaction_70468$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$,$objects$jscomp$608_state$jscomp$769$$){var $self__$jscomp$5719$$=this;$_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$608_state$jscomp$769$$);var $flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$608_state$jscomp$769$$,$_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$);
$objects$jscomp$608_state$jscomp$769$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$,$APP.$cljs$cst$1631$objects$$);$_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$=$app$common$files$helpers$get_root_frame$$($objects$jscomp$608_state$jscomp$769$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5719$$.shape));var $first_QMARK_$jscomp$1$$=$cljs$core$not_any_QMARK_$$(function($p1__70462_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($p1__70462_SHARP_$$))},
$APP.$cljs$core$vals$$($objects$jscomp$608_state$jscomp$769$$));$flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$,$APP.$cljs$cst$2056$flows$$);$flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$=$APP.$app$common$types$page$get_frame_flow$$($flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5719$$.shape)],null),function($shape__$1$jscomp$50$$){var $new_interaction$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$interactions$set_destination$$($APP.$app$common$types$shape$interactions$default_interaction$$,$self__$jscomp$5719$$.destination),$APP.$cljs$cst$1974$position_relative_to$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$50$$));
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$1$jscomp$50$$,$APP.$cljs$cst$2051$interactions$$,$APP.$app$common$types$shape$interactions$add_interaction$$,$new_interaction$jscomp$1$$)})),$APP.$cljs$core$truth_$$($self__$jscomp$5719$$.destination)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5719$$.destination],
null),$APP.$app$common$logic$shapes$show_in_viewer$$)):null,$APP.$cljs$core$not$$($app$main$data$workspace$interactions$connected_frame_QMARK_$$($objects$jscomp$608_state$jscomp$769$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$)))&&$flow$jscomp$4_flows$jscomp$5_page$jscomp$93$$==null?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2393_frame$jscomp$39_page_id$jscomp$215$$))):
null,$first_QMARK_$jscomp$1$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-prototype"],null))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-prototype-interaction"],null))))});return new $app$main$data$workspace$interactions$add_new_interaction_70468$$($shape$jscomp$708$$,
$destination$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$finish_edit_interaction$$=function($index$jscomp$342$$,$initial_pos$jscomp$1$$){typeof $app$main$data$workspace$interactions$finish_edit_interaction_70553$$==="undefined"&&($app$main$data$workspace$interactions$finish_edit_interaction_70553$$=function($index$jscomp$343$$,$initial_pos$jscomp$2$$,$meta70554$$){this.index=$index$jscomp$343$$;this.$initial_pos$=$initial_pos$jscomp$2$$;this.$meta70554$=$meta70554$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4315$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_finish_edit_interaction$$},$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70555$$,$meta70554__$1$$){return new $app$main$data$workspace$interactions$finish_edit_interaction_70553$$(this.index,this.$initial_pos$,$meta70554__$1$$)},$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70554$},$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2400$$,$state$jscomp$775$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$775$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4311$editing_interaction_index$$],null),null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4313$draw_interaction_to$$],
null),null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4314$draw_interaction_to_frame$$],null),null)},$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_edit_interaction_70553$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2401_position$jscomp$154$$,
$shape$jscomp$717_state$jscomp$776$$){function $change_interaction$$($G__70574__$1_interaction$jscomp$41$$){$G__70574__$1_interaction$jscomp$41$$=$APP.$cljs$core$not$$($APP.$app$common$types$shape$interactions$has_destination$$($G__70574__$1_interaction$jscomp$41$$))?$app$common$types$shape$interactions$set_action_type$$($G__70574__$1_interaction$jscomp$41$$,$APP.$cljs$cst$1941$navigate$$):$G__70574__$1_interaction$jscomp$41$$;return $app$common$types$shape$interactions$set_destination$$($G__70574__$1_interaction$jscomp$41$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$))}$_$jscomp$2401_position$jscomp$154$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);var $target_frame$jscomp$7$$=$app$main$data$workspace$interactions$get_target_frame$$($shape$jscomp$717_state$jscomp$776$$,$_$jscomp$2401_position$jscomp$154$$),$shape_id$jscomp$118_undo_id$jscomp$46$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$717_state$jscomp$776$$));
$shape$jscomp$717_state$jscomp$776$$=$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$717_state$jscomp$776$$,$shape_id$jscomp$118_undo_id$jscomp$46$$);$shape_id$jscomp$118_undo_id$jscomp$46$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($shape_id$jscomp$118_undo_id$jscomp$46$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1875$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$))?
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$)],null),function($p1__70552_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__70552_SHARP_$$,$APP.$cljs$cst$1875$hide_in_viewer$$)}):null,$shape$jscomp$717_state$jscomp$776$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2401_position$jscomp$154$$,
this.$initial_pos$)||this.index==null&&$target_frame$jscomp$7$$==null?null:this.index!=null&&$target_frame$jscomp$7$$==null?$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$717_state$jscomp$776$$,this.index):this.index==null?$app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$717_state$jscomp$776$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$)):
$APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($shape$jscomp$717_state$jscomp$776$$,this.index,$change_interaction$$,null),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($shape_id$jscomp$118_undo_id$jscomp$46$$))});return new $app$main$data$workspace$interactions$finish_edit_interaction_70553$$($index$jscomp$342$$,$initial_pos$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$start_edit_interaction$$=function($index$jscomp$340$$){typeof $app$main$data$workspace$interactions$start_edit_interaction_70518$$==="undefined"&&($app$main$data$workspace$interactions$start_edit_interaction_70518$$=function($index$jscomp$341$$,$meta70519$$){this.index=$index$jscomp$341$$;this.$meta70519$=$meta70519$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4310$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_start_edit_interaction$$},$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70520$$,$meta70519__$1$$){return new $app$main$data$workspace$interactions$start_edit_interaction_70518$$(this.index,
$meta70519__$1$$)},$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70519$},$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2397$$,$state$jscomp$771$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$771$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4311$editing_interaction_index$$],null),this.index)},$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_edit_interaction_70518$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2398_selected$jscomp$81$$,
$state$jscomp$772$$,$stopper$jscomp$32_stream$jscomp$85$$){var $initial_pos$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);$_$jscomp$2398_selected$jscomp$81$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$772$$);$stopper$jscomp$32_stream$jscomp$85$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$32_stream$jscomp$85$$,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($_$jscomp$2398_selected$jscomp$81$$))?
$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($p1__70517_SHARP_$$){return $app$main$data$workspace$interactions$move_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$interactions$move_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$($initial_pos$$,$p1__70517_SHARP_$$):$app$main$data$workspace$interactions$move_edit_interaction$$($initial_pos$$,$p1__70517_SHARP_$$)},$APP.$beicon$v2$core$take_until$$($stopper$jscomp$32_stream$jscomp$85$$,$APP.$app$main$streams$mouse_position$$)),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$interactions$finish_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$interactions$finish_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$(this.index,$initial_pos$$):$app$main$data$workspace$interactions$finish_edit_interaction$$(this.index,$initial_pos$$))):null});return new $app$main$data$workspace$interactions$start_edit_interaction_70518$$($index$jscomp$340$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$create_node_at_position$$=function($params$jscomp$282$$){typeof $app$main$data$workspace$path$edition$create_node_at_position_69998$$==="undefined"&&($app$main$data$workspace$path$edition$create_node_at_position_69998$$=function($params$jscomp$283$$,$meta69999$$){this.params=$params$jscomp$283$$;this.$meta69999$=$meta69999$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$create_node_at_position_69998$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$create_node_at_position_69998$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4263$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_create_node_at_position$$},$app$main$data$workspace$path$edition$create_node_at_position_69998$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70000$$,$meta69999__$1$$){return new $app$main$data$workspace$path$edition$create_node_at_position_69998$$(this.params,
$meta69999__$1$$)},$app$main$data$workspace$path$edition$create_node_at_position_69998$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69999$},$app$main$data$workspace$path$edition$create_node_at_position_69998$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$create_node_at_position_69998$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2345_id$jscomp$702$$,$state$jscomp$732$$){$_$jscomp$2345_id$jscomp$702$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$732$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2345_id$jscomp$702$$],null),$APP.$app$common$types$path$convert_to_path$$),$app$main$data$workspace$path$edition$split_segments$$($_$jscomp$2345_id$jscomp$702$$,this.params))});return new $app$main$data$workspace$path$edition$create_node_at_position_69998$$($params$jscomp$282$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$start_move_handler$$=function($index$jscomp$332$$,$prefix$jscomp$59$$){typeof $app$main$data$workspace$path$edition$start_move_handler_69946$$==="undefined"&&($app$main$data$workspace$path$edition$start_move_handler_69946$$=function($index$jscomp$333$$,$prefix$jscomp$60$$,$meta69947$$){this.index=$index$jscomp$333$$;this.prefix=$prefix$jscomp$60$$;this.$meta69947$=$meta69947$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$edition$start_move_handler_69946$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_handler_69946$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4259$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_move_handler$$},$app$main$data$workspace$path$edition$start_move_handler_69946$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69948$$,
$meta69947__$1$$){return new $app$main$data$workspace$path$edition$start_move_handler_69946$$(this.index,this.prefix,$meta69947__$1$$)},$app$main$data$workspace$path$edition$start_move_handler_69946$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69947$},$app$main$data$workspace$path$edition$start_move_handler_69946$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_handler_69946$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,$points$jscomp$93_state$jscomp$728$$,$stream$jscomp$79$$){var $self__$jscomp$5545$$=this,$id$jscomp$695$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$93_state$jscomp$728$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);$_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$=$APP.$app$common$data$prefix_keyword$$($self__$jscomp$5545$$.prefix,
$APP.$cljs$cst$1510$x$$);var $cy$jscomp$21_op_idx$jscomp$1$$=$APP.$app$common$data$prefix_keyword$$($self__$jscomp$5545$$.prefix,$APP.$cljs$cst$1511$y$$),$modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$93_state$jscomp$728$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),
$id$jscomp$695$$),$APP.$cljs$cst$1924$content_modifiers$$),$start_delta_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$,$self__$jscomp$5545$$.index),$_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,0),$start_delta_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$,
$self__$jscomp$5545$$.index),$cy$jscomp$21_op_idx$jscomp$1$$,0);$_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($points$jscomp$93_state$jscomp$728$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$points$jscomp$93_state$jscomp$728$$=$APP.$app$common$types$path$get_points$$($_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$);
var $point$jscomp$74$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5545$$.prefix,$APP.$cljs$cst$1821$c1$$)?$self__$jscomp$5545$$.index-1:$self__$jscomp$5545$$.index)),$handler$jscomp$42$$=$app$common$types$path$get_handler$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,
$self__$jscomp$5545$$.index),$self__$jscomp$5545$$.prefix);$modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$=$APP.$app$common$types$path$opposite_index$$($_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,$self__$jscomp$5545$$.index,$self__$jscomp$5545$$.prefix);$cy$jscomp$21_op_idx$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$,0,null);$modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$,
1,null);$_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$=$APP.$app$common$types$path$get_handler_point$$($_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,$cy$jscomp$21_op_idx$jscomp$1$$,$modifiers$jscomp$103_op_prefix$jscomp$1_vec__69959$$);return $APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$695$$],null),$APP.$app$common$types$path$convert_to_path$$)),$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$79$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$streams$finish_edition_QMARK_$$,$stream$jscomp$79$$)),$APP.$beicon$v2$core$map$$(function($alt_QMARK_$jscomp$12_p__69965$$){var $map__69966__$1_shift_QMARK_$jscomp$28$$=
$APP.$cljs$core$__destructure_map$$($alt_QMARK_$jscomp$12_p__69965$$),$G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69966__$1_shift_QMARK_$jscomp$28$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$444$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69966__$1_shift_QMARK_$jscomp$28$$,$APP.$cljs$cst$1511$y$$);$alt_QMARK_$jscomp$12_p__69965$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69966__$1_shift_QMARK_$jscomp$28$$,
$APP.$cljs$cst$4204$alt_QMARK_$$);$map__69966__$1_shift_QMARK_$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69966__$1_shift_QMARK_$jscomp$28$$,$APP.$cljs$cst$4203$shift_QMARK_$$);$G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$,$y$jscomp$444$$);$G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$=$APP.$cljs$core$truth_$$($map__69966__$1_shift_QMARK_$jscomp$28$$)?
$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$,$point$jscomp$74$$):$G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$;return $app$main$data$workspace$path$edition$modify_handler$$($id$jscomp$695$$,$self__$jscomp$5545$$.index,$self__$jscomp$5545$$.prefix,$start_delta_x$$+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($handler$jscomp$42$$)),
$start_delta_y$$+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__69967$jscomp$inline_8542_pos$jscomp$111_x$jscomp$1211$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($handler$jscomp$42$$)),$APP.$cljs$core$not$$($alt_QMARK_$jscomp$12_p__69965$$))},$app$main$data$workspace$path$streams$move_handler_stream$$($handler$jscomp$42$$,$point$jscomp$74$$,$handler$jscomp$42$$,$_$jscomp$2338_content$jscomp$216_cx$jscomp$20_opposite$jscomp$4$$,$points$jscomp$93_state$jscomp$728$$))),$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$edition$apply_content_modifiers$$()))))});
return new $app$main$data$workspace$path$edition$start_move_handler_69946$$($index$jscomp$332$$,$prefix$jscomp$59$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$start_move_path_point$$=function($position$jscomp$144$$,$shift_QMARK_$jscomp$24$$){typeof $app$main$data$workspace$path$edition$start_move_path_point_69877$$==="undefined"&&($app$main$data$workspace$path$edition$start_move_path_point_69877$$=function($position$jscomp$145$$,$shift_QMARK_$jscomp$25$$,$meta69878$$){this.position=$position$jscomp$145$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$25$$;this.$meta69878$=$meta69878$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$start_move_path_point_69877$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_path_point_69877$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4254$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_move_path_point$$},$app$main$data$workspace$path$edition$start_move_path_point_69877$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69879$$,$meta69878__$1$$){return new $app$main$data$workspace$path$edition$start_move_path_point_69877$$(this.position,this.$shift_QMARK_$,$meta69878__$1$$)},$app$main$data$workspace$path$edition$start_move_path_point_69877$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69878$},$app$main$data$workspace$path$edition$start_move_path_point_69877$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_path_point_69877$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($JSCompiler_temp_const$jscomp$1695__$jscomp$2332_id$jscomp$690$$,$JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$){$JSCompiler_temp_const$jscomp$1695__$jscomp$2332_id$jscomp$690$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);$JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$JSCompiler_temp_const$jscomp$1695__$jscomp$2332_id$jscomp$690$$),$APP.$cljs$cst$4241$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);
var $JSCompiler_temp_const$jscomp$1694_selected_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$,this.position);$JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$=$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$02$$;$JSCompiler_temp_const$jscomp$1695__$jscomp$2332_id$jscomp$690$$=$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp_const$jscomp$1695__$jscomp$2332_id$jscomp$690$$],null),$APP.$app$common$types$path$convert_to_path$$);$JSCompiler_temp_const$jscomp$1694_selected_QMARK_$$=$JSCompiler_temp_const$jscomp$1694_selected_QMARK_$$?null:$app$main$data$workspace$path$selection$select_node$$(this.position,this.$shift_QMARK_$);var $G__69890$jscomp$inline_8544_JSCompiler_inline_result$jscomp$1697$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);
$G__69890$jscomp$inline_8544_JSCompiler_inline_result$jscomp$1697$$=$app$main$data$workspace$path$edition$drag_selected_points$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$path$edition$drag_selected_points$$.$cljs$core$IFn$_invoke$arity$1$($G__69890$jscomp$inline_8544_JSCompiler_inline_result$jscomp$1697$$):$app$main$data$workspace$path$edition$drag_selected_points$$($G__69890$jscomp$inline_8544_JSCompiler_inline_result$jscomp$1697$$);return $JSCompiler_temp_const$jscomp$1696_selected_points$jscomp$4_state$jscomp$723$$((0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$1695__$jscomp$2332_id$jscomp$690$$,
$JSCompiler_temp_const$jscomp$1694_selected_QMARK_$$,$G__69890$jscomp$inline_8544_JSCompiler_inline_result$jscomp$1697$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$selection$select_node$$(this.position,this.$shift_QMARK_$)))});return new $app$main$data$workspace$path$edition$start_move_path_point_69877$$($position$jscomp$144$$,$shift_QMARK_$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$shortcuts$get_tooltip$$=function($shortcut$jscomp$6$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$path$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shortcut$jscomp$6$$,$APP.$cljs$cst$2946$tooltip$$],null))};
$app$main$data$workspace$colors$reorder_shadows$$=function($ids$jscomp$201$$,$from_pos$jscomp$4$$,$to_space_between_pos$jscomp$4$$){typeof $app$main$data$workspace$colors$reorder_shadow_70745$$==="undefined"&&($app$main$data$workspace$colors$reorder_shadow_70745$$=function($ids$jscomp$202$$,$from_pos$jscomp$5$$,$to_space_between_pos$jscomp$5$$,$meta70746$$){this.ids=$ids$jscomp$202$$;this.$from_pos$=$from_pos$jscomp$5$$;this.$to_space_between_pos$=$to_space_between_pos$jscomp$5$$;this.$meta70746$=
$meta70746$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$reorder_shadow_70745$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_shadow_70745$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4152$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_shadow$$},$app$main$data$workspace$colors$reorder_shadow_70745$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70747$$,$meta70746__$1$$){return new $app$main$data$workspace$colors$reorder_shadow_70745$$(this.ids,this.$from_pos$,this.$to_space_between_pos$,$meta70746__$1$$)},$app$main$data$workspace$colors$reorder_shadow_70745$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70746$},$app$main$data$workspace$colors$reorder_shadow_70745$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_shadow_70745$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5236$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5236$$.ids,function($p1__70741_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__70741_SHARP_$$,$APP.$cljs$cst$1654$shadow$$,$app$common$data$reorder$$,$self__$jscomp$5236$$.$from_pos$,$self__$jscomp$5236$$.$to_space_between_pos$)}))});return new $app$main$data$workspace$colors$reorder_shadow_70745$$($ids$jscomp$201$$,
$from_pos$jscomp$4$$,$to_space_between_pos$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$add_shadow$$=function($ids$jscomp$193$$){var $shadow__$1$jscomp$10$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1905$drop_shadow$$,$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,.2],null),$APP.$cljs$cst$1650$offset_x$$,4,$APP.$cljs$cst$1651$offset_y$$,4,$APP.$cljs$cst$1653$blur$$,
4,$APP.$cljs$cst$1652$spread$$,0,$APP.$cljs$cst$1620$hidden$$,!1],null);typeof $app$main$data$workspace$colors$add_shadow_70672$$==="undefined"&&($app$main$data$workspace$colors$add_shadow_70672$$=function($ids$jscomp$194$$,$shadow$jscomp$1$$,$meta70673$$){this.ids=$ids$jscomp$194$$;this.shadow=$shadow$jscomp$1$$;this.$meta70673$=$meta70673$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_shadow_70672$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_shadow_70672$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4148$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_shadow$$},$app$main$data$workspace$colors$add_shadow_70672$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70674$$,$meta70673__$1$$){return new $app$main$data$workspace$colors$add_shadow_70672$$(this.ids,this.shadow,$meta70673__$1$$)},$app$main$data$workspace$colors$add_shadow_70672$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70673$},$app$main$data$workspace$colors$add_shadow_70672$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_shadow_70672$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5220$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5220$$.ids,function($shape$jscomp$686$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$686$$,
$APP.$cljs$cst$1654$shadow$$,function($p1__70670_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5220$$.shadow],null),$p1__70670_SHARP_$$)})}))});return new $app$main$data$workspace$colors$add_shadow_70672$$($ids$jscomp$193$$,$shadow__$1$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_hide_fill_on_export$$=function($ids$jscomp$183$$,$hide_fill_on_export$$){typeof $app$main$data$workspace$colors$change_hide_fill_on_export_70561$$==="undefined"&&($app$main$data$workspace$colors$change_hide_fill_on_export_70561$$=function($ids$jscomp$184$$,$hide_fill_on_export$jscomp$1$$,$meta70562$$){this.ids=$ids$jscomp$184$$;this.$hide_fill_on_export$=$hide_fill_on_export$jscomp$1$$;this.$meta70562$=$meta70562$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4144$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_hide_fill_on_export$$},$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70563$$,$meta70562__$1$$){return new $app$main$data$workspace$colors$change_hide_fill_on_export_70561$$(this.ids,this.$hide_fill_on_export$,$meta70562__$1$$)},$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70562$},$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_hide_fill_on_export_70561$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2240_page_id$jscomp$195$$,$shape_ids$jscomp$14_state$jscomp$638$$){$_$jscomp$2240_page_id$jscomp$195$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_ids$jscomp$14_state$jscomp$638$$);var $objects$jscomp$591$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($shape_ids$jscomp$14_state$jscomp$638$$,$_$jscomp$2240_page_id$jscomp$195$$);$shape_ids$jscomp$14_state$jscomp$638$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$(function($p1__70560_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$591$$,$p1__70560_SHARP_$$)))}),this.ids);var $attrs$jscomp$139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1874$hide_fill_on_export$$,this.$hide_fill_on_export$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$14_state$jscomp$638$$,function($shape$jscomp$682$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$682$$),
$APP.$cljs$cst$1606$frame$$)?$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$682$$,$attrs$jscomp$139$$])):$shape$jscomp$682$$}))});return new $app$main$data$workspace$colors$change_hide_fill_on_export_70561$$($ids$jscomp$183$$,$hide_fill_on_export$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$reorder_fills$$=function($ids$jscomp$163$$,$from_pos$jscomp$2$$,$to_space_between_pos$jscomp$2$$){typeof $app$main$data$workspace$colors$reorder_fills_70459$$==="undefined"&&($app$main$data$workspace$colors$reorder_fills_70459$$=function($ids$jscomp$164$$,$from_pos$jscomp$3$$,$to_space_between_pos$jscomp$3$$,$meta70460$$){this.ids=$ids$jscomp$164$$;this.$from_pos$=$from_pos$jscomp$3$$;this.$to_space_between_pos$=$to_space_between_pos$jscomp$3$$;this.$meta70460$=$meta70460$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$reorder_fills_70459$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_fills_70459$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4137$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_fills$$},$app$main$data$workspace$colors$reorder_fills_70459$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70461$$,$meta70460__$1$$){return new $app$main$data$workspace$colors$reorder_fills_70459$$(this.ids,this.$from_pos$,this.$to_space_between_pos$,$meta70460__$1$$)},$app$main$data$workspace$colors$reorder_fills_70459$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70460$},$app$main$data$workspace$colors$reorder_fills_70459$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_fills_70459$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2233_objects$jscomp$590_text_ids$jscomp$4$$,$shape_ids$jscomp$13_state$jscomp$631_vec__70465$$){function $transform_attrs$jscomp$1$$($object$jscomp$33$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$6$($object$jscomp$33$$,$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$update$$,$app$common$data$reorder$$,$self__$jscomp$5176$$.$from_pos$,$self__$jscomp$5176$$.$to_space_between_pos$)}var $self__$jscomp$5176$$=this;$_$jscomp$2233_objects$jscomp$590_text_ids$jscomp$4$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shape_ids$jscomp$13_state$jscomp$631_vec__70465$$);$shape_ids$jscomp$13_state$jscomp$631_vec__70465$$=$app$main$data$helpers$split_text_shapes$$($_$jscomp$2233_objects$jscomp$590_text_ids$jscomp$4$$,$self__$jscomp$5176$$.ids);$_$jscomp$2233_objects$jscomp$590_text_ids$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$13_state$jscomp$631_vec__70465$$,0,null);$shape_ids$jscomp$13_state$jscomp$631_vec__70465$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$13_state$jscomp$631_vec__70465$$,1,null);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70458_SHARP_$$){return $APP.$app$main$data$workspace$texts$update_text_with_function$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__70458_SHARP_$$,$transform_attrs$jscomp$1$$,null)},$_$jscomp$2233_objects$jscomp$590_text_ids$jscomp$4$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$13_state$jscomp$631_vec__70465$$,
$transform_attrs$jscomp$1$$)))});return new $app$main$data$workspace$colors$reorder_fills_70459$$($ids$jscomp$163$$,$from_pos$jscomp$2$$,$to_space_between_pos$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_id$jscomp$195$$,$group_path$jscomp$5$$){typeof $app$main$data$workspace$texts$add_typography_70356$$==="undefined"&&($app$main$data$workspace$texts$add_typography_70356$$=function($file_id$jscomp$196$$,$group_path$jscomp$6$$,$meta70357$$){this.$file_id$=$file_id$jscomp$196$$;this.$group_path$=$group_path$jscomp$6$$;this.$meta70357$=$meta70357$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$add_typography_70356$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$add_typography_70356$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4036$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_add_typography$$},$app$main$data$workspace$texts$add_typography_70356$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70358$$,$meta70357__$1$$){return new $app$main$data$workspace$texts$add_typography_70356$$(this.$file_id$,
this.$group_path$,$meta70357__$1$$)},$app$main$data$workspace$texts$add_typography_70356$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70357$},$app$main$data$workspace$texts$add_typography_70356$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$add_typography_70356$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$,$state$jscomp$592_typ$$){var $self__$jscomp$5054$$=
this;$_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$592_typ$$);var $objects$jscomp$518_xform$jscomp$36$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$592_typ$$);$objects$jscomp$518_xform$jscomp$36$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$518_xform$jscomp$36$$)),
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$text_shape_QMARK_$$));var $shapes$jscomp$108$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$518_xform$jscomp$36$$,$_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$);$_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$=$APP.$cljs$core$first$$($shapes$jscomp$108$$);var $values$jscomp$72$$=$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4011$editor_state$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$592_typ$$,$APP.$cljs$cst$2222$workspace_editor_state$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$)),$APP.$cljs$cst$1811$shape$$,$_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null)),$multiple_QMARK_$jscomp$1$$=
function(){var $or__5025__auto__$jscomp$805$$=1>$APP.$cljs$core$count$$($shapes$jscomp$108$$);return $or__5025__auto__$jscomp$805$$?$or__5025__auto__$jscomp$805$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$APP.$cljs$cst$1616$multiple$$),$APP.$cljs$core$vals$$($values$jscomp$72$$))}(),$values__$1$jscomp$2$$=$APP.$cljs$core$select_keys$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$72$$),
$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$text$text_font_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_spacing_attrs$$,$APP.$app$common$types$text$text_transform_attrs$$]))),$values__$2$$=function(){var $G__70359__$1$$=typeof $APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$2$$)==="number"?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($values__$1$jscomp$2$$,
$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$core$str$$):$values__$1$jscomp$2$$;return typeof $APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$2$$)==="number"?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__70359__$1$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$core$str$$):$G__70359__$1$$}(),$typ_id$$=$APP.$app$common$uuid$next$$();$state$jscomp$592_typ$$=function(){var $G__70360$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$main$data$workspace$texts$generate_typography_name$$($APP.$cljs$core$truth_$$($multiple_QMARK_$jscomp$1$$)?
$APP.$app$common$types$text$default_typography$$:$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_typography$$,$values__$2$$]))),$APP.$cljs$cst$266$id$$,$typ_id$$);return typeof $self__$jscomp$5054$$.$group_path$==="string"?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__70360$$,$APP.$cljs$cst$725$name$$,function($p1__70353_SHARP_$$){return[$self__$jscomp$5054$$.$group_path$,
" / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__70353_SHARP_$$)].join("")}):$G__70360$$}();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$592_typ$$,!0),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-asset-to-library",$APP.$cljs$cst$2545$asset_type$$,"typography"],
null))),$APP.$cljs$core$not$$($multiple_QMARK_$jscomp$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_attrs$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2195_selected$jscomp$61_shape$jscomp$587$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1756$typography_ref_id$$,$typ_id$$,$APP.$cljs$cst$1642$typography_ref_file$$,$self__$jscomp$5054$$.$file_id$],null))):null)});return new $app$main$data$workspace$texts$add_typography_70356$$($file_id$jscomp$195$$,
$group_path$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$update_all_attrs$$=function($ids$jscomp$151$$,$attrs$jscomp$133$$){typeof $app$main$data$workspace$texts$update_all_attrs_70342$$==="undefined"&&($app$main$data$workspace$texts$update_all_attrs_70342$$=function($ids$jscomp$152$$,$attrs$jscomp$134$$,$meta70343$$){this.ids=$ids$jscomp$152$$;this.$attrs$=$attrs$jscomp$134$$;this.$meta70343$=$meta70343$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_all_attrs_70342$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_all_attrs_70342$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4034$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_all_attrs$$},$app$main$data$workspace$texts$update_all_attrs_70342$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70344$$,$meta70343__$1$$){return new $app$main$data$workspace$texts$update_all_attrs_70342$$(this.ids,this.$attrs$,$meta70343__$1$$)},$app$main$data$workspace$texts$update_all_attrs_70342$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70343$},$app$main$data$workspace$texts$update_all_attrs_70342$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_all_attrs_70342$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5046$$=this,$undo_id$jscomp$34$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$34$$)),$APP.$beicon$v2$core$map$$(function($p1__70341_SHARP_$$){return $APP.$app$main$data$workspace$texts$update_attrs$$($p1__70341_SHARP_$$,
$self__$jscomp$5046$$.$attrs$)},$APP.$beicon$v2$core$from$$($self__$jscomp$5046$$.ids)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$34$$)))});return new $app$main$data$workspace$texts$update_all_attrs_70342$$($ids$jscomp$151$$,$attrs$jscomp$133$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$exit_preview$$=function(){typeof $app$main$data$workspace$versions$exit_preview_73381$$==="undefined"&&($app$main$data$workspace$versions$exit_preview_73381$$=function($meta73382$$){this.$meta73382$=$meta73382$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$exit_preview_73381$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_73381$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5043$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_exit_preview$$},$app$main$data$workspace$versions$exit_preview_73381$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73383$$,$meta73382__$1$$){return new $app$main$data$workspace$versions$exit_preview_73381$$($meta73382__$1$$)},$app$main$data$workspace$versions$exit_preview_73381$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73382$},$app$main$data$workspace$versions$exit_preview_73381$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_73381$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2791_file_id$jscomp$330$$,$page_id$jscomp$344_state$jscomp$1074$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$344_state$jscomp$1074$$,$APP.$cljs$cst$4469$workspace_versions$$),$APP.$cljs$cst$5042$backup$$))?($_$jscomp$2791_file_id$jscomp$330$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$344_state$jscomp$1074$$),$page_id$jscomp$344_state$jscomp$1074$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$344_state$jscomp$1074$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$exit_preview_cleanup$$(),$APP.$app$main$data$workspace$pages$initialize_page$$($_$jscomp$2791_file_id$jscomp$330$$,$page_id$jscomp$344_state$jscomp$1074$$))):null});return new $app$main$data$workspace$versions$exit_preview_73381$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$restore_version$$=function($id$jscomp$856$$){typeof $app$main$data$workspace$versions$restore_version_73390$$==="undefined"&&($app$main$data$workspace$versions$restore_version_73390$$=function($id$jscomp$857$$,$meta73391$$){this.id=$id$jscomp$857$$;this.$meta73391$=$meta73391$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$restore_version_73390$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$restore_version_73390$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5044$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_restore_version$$},$app$main$data$workspace$versions$restore_version_73390$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73392$$,$meta73391__$1$$){return new $app$main$data$workspace$versions$restore_version_73390$$(this.id,$meta73391__$1$$)},$app$main$data$workspace$versions$restore_version_73390$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73391$},$app$main$data$workspace$versions$restore_version_73390$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_73390$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2792$$,$state$jscomp$1075$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1075$$,$APP.$cljs$cst$4469$workspace_versions$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5042$backup$$),$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2217$read_only_QMARK_$$,$APP.$cljs$cst$5020$preview_id$$)},$app$main$data$workspace$versions$restore_version_73390$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_73390$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2793_file_id$jscomp$331$$,$state$jscomp$1076$$){$_$jscomp$2793_file_id$jscomp$331$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1076$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3719$document_history$$)),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$versions$initialize_version$$()},$APP.$app$main$data$workspace$versions$wait_for_persistence$$($_$jscomp$2793_file_id$jscomp$331$$,
this.id)))});return new $app$main$data$workspace$versions$restore_version_73390$$($id$jscomp$856$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$enter_restore$$=function($id$jscomp$858$$){typeof $app$main$data$workspace$versions$enter_restore_73399$$==="undefined"&&($app$main$data$workspace$versions$enter_restore_73399$$=function($id$jscomp$859$$,$meta73400$$){this.id=$id$jscomp$859$$;this.$meta73400$=$meta73400$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$enter_restore_73399$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$enter_restore_73399$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5045$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_enter_restore$$},$app$main$data$workspace$versions$enter_restore_73399$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73401$$,$meta73400__$1$$){return new $app$main$data$workspace$versions$enter_restore_73399$$(this.id,$meta73400__$1$$)},$app$main$data$workspace$versions$enter_restore_73399$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73400$},$app$main$data$workspace$versions$enter_restore_73399$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$enter_restore_73399$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7037$$=this,$output_s$$=$APP.$beicon$v2$core$subject$$();return $APP.$beicon$v2$core$merge$$($output_s$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.restore-warning"),$APP.$cljs$cst$2350$controls$$,$APP.$cljs$cst$2352$inline_actions$$,$APP.$cljs$cst$2355$cancel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.updates.dismiss"),$APP.$cljs$cst$2354$callback$$,function(){$output_s$$.next($APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$5032$restore_dialog$$])));$output_s$$.next($app$main$data$workspace$versions$exit_preview$$());return $output_s$$.complete()}],null),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.restore"),$APP.$cljs$cst$2354$callback$$,function(){$output_s$$.next($app$main$data$workspace$versions$restore_version$$($self__$jscomp$7037$$.id));return $output_s$$.complete()}],null),
$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$5032$restore_dialog$$]))))});return new $app$main$data$workspace$versions$enter_restore_73399$$($id$jscomp$858$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$enter_preview$$=function($id$jscomp$862$$){typeof $app$main$data$workspace$versions$enter_preview_73414$$==="undefined"&&($app$main$data$workspace$versions$enter_preview_73414$$=function($id$jscomp$863$$,$meta73415$$){this.id=$id$jscomp$863$$;this.$meta73415$=$meta73415$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5047$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_enter_preview$$},$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73416$$,$meta73415__$1$$){return new $app$main$data$workspace$versions$enter_preview_73414$$(this.id,$meta73415__$1$$)},$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73415$},$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2796_file$jscomp$89$$,$state$jscomp$1078$$){$_$jscomp$2796_file$jscomp$89$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$1078$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1078$$,
$APP.$cljs$cst$4469$workspace_versions$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$backup$$,$_$jscomp$2796_file$jscomp$89$$),$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2217$read_only_QMARK_$$,!0,$APP.$cljs$cst$5020$preview_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id]))},$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$enter_preview_73414$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2797_features__$1$jscomp$25_team_id$jscomp$118$$,$label$jscomp$24_state$jscomp$1079$$){var $self__$jscomp$7046$$=this,$file_id$jscomp$332$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($label$jscomp$24_state$jscomp$1079$$),$page_id$jscomp$345$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($label$jscomp$24_state$jscomp$1079$$);$_$jscomp$2797_features__$1$jscomp$25_team_id$jscomp$118$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($label$jscomp$24_state$jscomp$1079$$);
$_$jscomp$2797_features__$1$jscomp$25_team_id$jscomp$118$$=$APP.$app$main$features$get_enabled_features$$($label$jscomp$24_state$jscomp$1079$$,$_$jscomp$2797_features__$1$jscomp$25_team_id$jscomp$118$$);var $snapshot$jscomp$3$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73412_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$7046$$.id,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73412_SHARP_$$))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($label$jscomp$24_state$jscomp$1079$$,
$APP.$cljs$cst$4469$workspace_versions$$),$APP.$cljs$cst$142$data$$));$label$jscomp$24_state$jscomp$1079$$=function(){var $or__5025__auto__$jscomp$937$$=$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($snapshot$jscomp$3$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$937$$)?$or__5025__auto__$jscomp$937$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.preview.unnamed")}();var $output_s$jscomp$1$$=$APP.$beicon$v2$core$subject$$();return $APP.$beicon$v2$core$merge$$($output_s$jscomp$1$$,
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.preview-banner-title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$label$jscomp$24_state$jscomp$1079$$])),$APP.$cljs$cst$2350$controls$$,$APP.$cljs$cst$2352$inline_actions$$,$APP.$cljs$cst$2355$cancel$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.exit"),$APP.$cljs$cst$2354$callback$$,function(){$output_s$jscomp$1$$.next($APP.$app$main$data$notifications$hide$$());$output_s$jscomp$1$$.next($app$main$data$workspace$versions$exit_preview$$());return $output_s$jscomp$1$$.complete()}],null),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.restore"),
$APP.$cljs$cst$2354$callback$$,function(){$output_s$jscomp$1$$.next($APP.$app$main$data$notifications$hide$$());$output_s$jscomp$1$$.next($app$main$data$workspace$versions$enter_restore$$($self__$jscomp$7046$$.id));return $output_s$jscomp$1$$.complete()}],null),$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$5048$preview_dialog$$]))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($err$jscomp$44$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.versions",$APP.$cljs$cst$849$error$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"failed to load snapshot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$332$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5049$snapshot_id$$,$self__$jscomp$7046$$.id],null)],null)}),$err$jscomp$44$$,"app.main.data.workspace.versions",$APP.$cljs$cst$849$error$$,!1);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$exit_preview$$())},$APP.$beicon$v2$core$mapcat$$(function($snapshot__$1$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$apply_snapshot$$($snapshot__$1$$),$APP.$app$main$data$workspace$pages$initialize_page$$($file_id$jscomp$332$$,
$page_id$jscomp$345$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5050$get_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$332$$,$APP.$cljs$cst$266$id$$,$self__$jscomp$7046$$.id,$APP.$cljs$cst$227$features$$,$_$jscomp$2797_features__$1$jscomp$25_team_id$jscomp$118$$],null)))))});return new $app$main$data$workspace$versions$enter_preview_73414$$($id$jscomp$862$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$upload_fill_image$$=function($file$jscomp$60$$,$on_success$jscomp$26$$){typeof $app$main$data$workspace$media$upload_fill_image_67753$$==="undefined"&&($app$main$data$workspace$media$upload_fill_image_67753$$=function($file$jscomp$61$$,$on_success$jscomp$27$$,$meta67754$$){this.file=$file$jscomp$61$$;this.$on_success$=$on_success$jscomp$27$$;this.$meta67754$=$meta67754$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$media$upload_fill_image_67753$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$upload_fill_image_67753$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3707$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_upload_fill_image$$},$app$main$data$workspace$media$upload_fill_image_67753$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67755$$,$meta67754__$1$$){return new $app$main$data$workspace$media$upload_fill_image_67753$$(this.file,
this.$on_success$,$meta67754__$1$$)},$app$main$data$workspace$media$upload_fill_image_67753$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67754$},$app$main$data$workspace$media$upload_fill_image_67753$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$upload_fill_image_67753$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1979$$,$state$jscomp$406$$){var $self__$jscomp$4408$$=this,$file_id$jscomp$103$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$406$$);$APP.$app$main$data$media$notify_start_loading$$();return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$media$handle_media_error$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($image$jscomp$23$$){$self__$jscomp$4408$$.$on_success$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$4408$$.$on_success$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$23$$):
$self__$jscomp$4408$$.$on_success$($image$jscomp$23$$);return $APP.$app$main$data$media$notify_finished_loading$$()},$APP.$beicon$v2$core$mapcat$$(function($p1__67752_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2282$upload_file_media_object$$,$p1__67752_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($content$jscomp$162$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$103$$,$APP.$cljs$cst$725$name$$,
$APP.$app$main$data$media$file_QMARK_$$($content$jscomp$162$$)?$content$jscomp$162$$.name:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image"),$APP.$cljs$cst$2574$is_local$$,!1,$APP.$cljs$cst$1637$content$$,$content$jscomp$162$$],null)},$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,(0,$APP.$beicon$v2$core$of$$)($self__$jscomp$4408$$.file))))))});return new $app$main$data$workspace$media$upload_fill_image_67753$$($file$jscomp$60$$,$on_success$jscomp$26$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$upload_media_components$$=function($params$jscomp$255_params__$1$jscomp$37$$){$params$jscomp$255_params__$1$jscomp$37$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($params$jscomp$255_params__$1$jscomp$37$$,$APP.$cljs$cst$3693$local_QMARK_$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3695$on_image$$,function($p1__67785_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$process_img_component$$($p1__67785_SHARP_$$))},
$APP.$cljs$cst$3696$on_svg$$,function($p1__67786_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$process_svg_component$$($p1__67786_SHARP_$$))}]));return $APP.$app$main$data$workspace$media$process_media_objects$$($params$jscomp$255_params__$1$jscomp$37$$)};
$app$main$data$workspace$clipboard$paste_from_event$$=function($event$jscomp$96$$,$in_viewport_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$clipboard$paste_from_event_70549$$==="undefined"&&($app$main$data$workspace$clipboard$paste_from_event_70549$$=function($event$jscomp$97$$,$in_viewport_QMARK_$jscomp$2$$,$meta70550$$){this.event=$event$jscomp$97$$;this.$in_viewport_QMARK_$=$in_viewport_QMARK_$jscomp$2$$;this.$meta70550$=$meta70550$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$clipboard$paste_from_event_70549$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_from_event_70549$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4105$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_from_event$$},$app$main$data$workspace$clipboard$paste_from_event_70549$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70551$$,$meta70550__$1$$){return new $app$main$data$workspace$clipboard$paste_from_event_70549$$(this.event,
this.$in_viewport_QMARK_$,$meta70550__$1$$)},$app$main$data$workspace$clipboard$paste_from_event_70549$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70550$},$app$main$data$workspace$clipboard$paste_from_event_70549$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_from_event_70549$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$,
$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$){$JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$);$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$,$APP.$cljs$cst$139$type$$],null))):
$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$;if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$))$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$=$APP.$beicon$v2$core$empty$$();else{$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$=
$APP.$app$main$data$workspace$clipboard$create_paste_from_blob$$(this.$in_viewport_QMARK_$,!1);$JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$=this.event;var $is_input_QMARK_$jscomp$inline_13372_target$jscomp$inline_13370$$=$APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$),$content_editable_QMARK_$jscomp$inline_13371$$=$is_input_QMARK_$jscomp$inline_13372_target$jscomp$inline_13370$$.isContentEditable;
$is_input_QMARK_$jscomp$inline_13372_target$jscomp$inline_13370$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($is_input_QMARK_$jscomp$inline_13372_target$jscomp$inline_13370$$),"INPUT");$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($content_editable_QMARK_$jscomp$inline_13371$$)?$content_editable_QMARK_$jscomp$inline_13371$$:$is_input_QMARK_$jscomp$inline_13372_target$jscomp$inline_13370$$)?($JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$=
$JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$.getBrowserEvent(),$JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$=$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$.clipboardData,$APP.$app$main$data$workspace$clipboard$default_options$$)):
$JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$=$APP.$beicon$v2$core$empty$$();$JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$=$APP.$beicon$v2$core$mapcat$$($JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$,$JSCompiler_temp$jscomp$14061__$jscomp$2211_event$jscomp$inline_13369_event$jscomp$inline_14639_objects$jscomp$578$$)}return $JSCompiler_temp$jscomp$10947_JSCompiler_temp_const$jscomp$10948_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$604$$});
return new $app$main$data$workspace$clipboard$paste_from_event_70549$$($event$jscomp$96$$,$in_viewport_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shortcuts$get_tooltip$$=function($shortcut$jscomp$3$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shortcut$jscomp$3$$,$APP.$cljs$cst$2946$tooltip$$],null))};
$cljs$spec$alpha$explain_printer$$=function($ed$jscomp$1$$){if($APP.$cljs$core$truth_$$($ed$jscomp$1$$)){var $problems$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33860_SHARP_$$){return-$APP.$cljs$core$count$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__33860_SHARP_$$))},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33859_SHARP_$$){return-$APP.$cljs$core$count$$($APP.$cljs$cst$297$in$$.$cljs$core$IFn$_invoke$arity$1$($p1__33859_SHARP_$$))},
$APP.$cljs$cst$981$cljs_DOT_spec_DOT_alpha_SLASH_problems$$.$cljs$core$IFn$_invoke$arity$1$($ed$jscomp$1$$)));$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $sb__5670__auto__$jscomp$2$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__33864_35023$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__33865_35024$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=
!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$2$$){return $sb__5670__auto__$jscomp$2$$.append($x__5671__auto__$jscomp$2$$)};try{for(var $seq__33868_35028$$=$APP.$cljs$core$seq$$($problems$$),$chunk__33869_35029$$=null,$count__33870_35030$$=0,$i__33871_35031$$=0;;)if($i__33871_35031$$<$count__33870_35030$$){var $map__33933_35032$$=$chunk__33869_35029$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__33871_35031$$),$map__33933_35033__$1$$=$APP.$cljs$core$__destructure_map$$($map__33933_35032$$),
$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$=$map__33933_35033__$1$$,$path_35035$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33933_35033__$1$$,$APP.$cljs$cst$296$path$$),$pred_35036$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33933_35033__$1$$,$APP.$cljs$cst$351$pred$$),$val_35037$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33933_35033__$1$$,$APP.$cljs$cst$108$val$$),$reason_35038$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33933_35033__$1$$,
$APP.$cljs$cst$984$reason$$),$via_35039$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33933_35033__$1$$,$APP.$cljs$cst$143$via$$),$in_35040$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33933_35033__$1$$,$APP.$cljs$cst$297$in$$);$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$val_35037$$]));$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" - failed: "]));
$APP.$cljs$core$truth_$$($reason_35038$$)?$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$reason_35038$$])):$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$alpha$abbrev$$($pred_35036$$)]));$APP.$cljs$core$empty_QMARK_$$($in_35040$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" in: ",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$in_35040$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($path_35035$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" at: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$path_35035$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($via_35039$$)||
$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" spec: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$last$$($via_35039$$)]))].join("")]));var $seq__33937_35045$$=$APP.$cljs$core$seq$$($G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$);$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$=null;for(var $chunk__33991_35105_count__33939_35047_prob_35092$$=
0,$count__33992_35106_i__33940_35048$$=0;;)if($count__33992_35106_i__33940_35048$$<$chunk__33991_35105_count__33939_35047_prob_35092$$){var $vec__33967_35049$$=$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$count__33992_35106_i__33940_35048$$),$k_35050$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33967_35049$$,0,null),$v_35051$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33967_35049$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__33972$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__33972$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33972$$.$cljs$core$IFn$_invoke$arity$1$($k_35050$$):$fexpr__33972$$($k_35050$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_35050$$]))," "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_35051$$])));$count__33992_35106_i__33940_35048$$+=1}else{var $temp__5825__auto___35058$$=$APP.$cljs$core$seq$$($seq__33937_35045$$);if($temp__5825__auto___35058$$){var $G__35064_i__33993_35107_seq__33937_35060__$1$$=$temp__5825__auto___35058$$;
if($APP.$cljs$core$chunked_seq_QMARK_$$($G__35064_i__33993_35107_seq__33937_35060__$1$$)){var $c__5548__auto___35062$$=$APP.$cljs$core$_chunked_first$$($G__35064_i__33993_35107_seq__33937_35060__$1$$),$G__35063$$=$APP.$cljs$core$_chunked_rest$$($G__35064_i__33993_35107_seq__33937_35060__$1$$);$G__35064_i__33993_35107_seq__33937_35060__$1$$=$c__5548__auto___35062$$;var $G__35065$$=$APP.$cljs$core$count$$($c__5548__auto___35062$$);$seq__33937_35045$$=$G__35063$$;$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$=
$G__35064_i__33993_35107_seq__33937_35060__$1$$;$chunk__33991_35105_count__33939_35047_prob_35092$$=$G__35065$$}else{var $vec__33979_35067$$=$APP.$cljs$core$first$$($G__35064_i__33993_35107_seq__33937_35060__$1$$),$k_35068$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33979_35067$$,0,null),$v_35069$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33979_35067$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__33986$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__33986$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33986$$.$cljs$core$IFn$_invoke$arity$1$($k_35068$$):$fexpr__33986$$($k_35068$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_35068$$]))," "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_35069$$])));$seq__33937_35045$$=$APP.$cljs$core$next$$($G__35064_i__33993_35107_seq__33937_35060__$1$$);$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$=null;$chunk__33991_35105_count__33939_35047_prob_35092$$=
0}$count__33992_35106_i__33940_35048$$=0}else break}$APP.$cljs$core$newline$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$i__33871_35031$$+=1}else{var $temp__5825__auto___35083$$=$APP.$cljs$core$seq$$($seq__33868_35028$$);if($temp__5825__auto___35083$$){$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$=$temp__5825__auto___35083$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$)){var $c__5548__auto___35085$$=$APP.$cljs$core$_chunked_first$$($G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$),
$G__35086$$=$APP.$cljs$core$_chunked_rest$$($G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$);$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$=$c__5548__auto___35085$$;var $G__35088$$=$APP.$cljs$core$count$$($c__5548__auto___35085$$);$seq__33868_35028$$=$G__35086$$;$chunk__33869_35029$$=$G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$;$count__33870_35030$$=$G__35088$$}else{var $map__33989_35090$$=$APP.$cljs$core$first$$($G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$),
$map__33989_35091__$1$$=$APP.$cljs$core$__destructure_map$$($map__33989_35090$$);$chunk__33991_35105_count__33939_35047_prob_35092$$=$map__33989_35091__$1$$;var $path_35093$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33989_35091__$1$$,$APP.$cljs$cst$296$path$$),$pred_35094$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33989_35091__$1$$,$APP.$cljs$cst$351$pred$$),$val_35095$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33989_35091__$1$$,$APP.$cljs$cst$108$val$$),
$reason_35096$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33989_35091__$1$$,$APP.$cljs$cst$984$reason$$),$via_35097$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33989_35091__$1$$,$APP.$cljs$cst$143$via$$),$in_35098$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33989_35091__$1$$,$APP.$cljs$cst$297$in$$);$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$val_35095$$]));$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" - failed: "]));
$APP.$cljs$core$truth_$$($reason_35096$$)?$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$reason_35096$$])):$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$alpha$abbrev$$($pred_35094$$)]));$APP.$cljs$core$empty_QMARK_$$($in_35098$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" in: ",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$in_35098$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($path_35093$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" at: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$path_35093$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($via_35097$$)||
$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" spec: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$last$$($via_35097$$)]))].join("")]));var $seq__33990_35104$$=$APP.$cljs$core$seq$$($chunk__33991_35105_count__33939_35047_prob_35092$$);$chunk__33991_35105_count__33939_35047_prob_35092$$=null;for($G__35064_i__33993_35107_seq__33937_35060__$1$$=
$count__33992_35106_i__33940_35048$$=0;;)if($G__35064_i__33993_35107_seq__33937_35060__$1$$<$count__33992_35106_i__33940_35048$$){var $vec__34002_35108$$=$chunk__33991_35105_count__33939_35047_prob_35092$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__35064_i__33993_35107_seq__33937_35060__$1$$),$k_35109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34002_35108$$,0,null),$v_35110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34002_35108$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__34005$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__34005$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__34005$$.$cljs$core$IFn$_invoke$arity$1$($k_35109$$):$fexpr__34005$$($k_35109$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_35109$$]))," "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_35110$$])));$G__35064_i__33993_35107_seq__33937_35060__$1$$+=1}else{var $temp__5825__auto___35117__$1$$=$APP.$cljs$core$seq$$($seq__33990_35104$$);if($temp__5825__auto___35117__$1$$){var $G__35121_seq__33990_35118__$1$$=$temp__5825__auto___35117__$1$$;
if($APP.$cljs$core$chunked_seq_QMARK_$$($G__35121_seq__33990_35118__$1$$)){var $c__5548__auto___35119$$=$APP.$cljs$core$_chunked_first$$($G__35121_seq__33990_35118__$1$$),$G__35120$$=$APP.$cljs$core$_chunked_rest$$($G__35121_seq__33990_35118__$1$$);$G__35121_seq__33990_35118__$1$$=$c__5548__auto___35119$$;var $G__35122$$=$APP.$cljs$core$count$$($c__5548__auto___35119$$);$seq__33990_35104$$=$G__35120$$;$chunk__33991_35105_count__33939_35047_prob_35092$$=$G__35121_seq__33990_35118__$1$$;$count__33992_35106_i__33940_35048$$=
$G__35122$$}else{var $vec__34007_35127$$=$APP.$cljs$core$first$$($G__35121_seq__33990_35118__$1$$),$k_35128$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34007_35127$$,0,null),$v_35129$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34007_35127$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__34010$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,
$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__34010$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__34010$$.$cljs$core$IFn$_invoke$arity$1$($k_35128$$):$fexpr__34010$$($k_35128$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_35128$$])),
" "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_35129$$])));$seq__33990_35104$$=$APP.$cljs$core$next$$($G__35121_seq__33990_35118__$1$$);$chunk__33991_35105_count__33939_35047_prob_35092$$=null;$count__33992_35106_i__33940_35048$$=0}$G__35064_i__33993_35107_seq__33937_35060__$1$$=0}else break}$APP.$cljs$core$newline$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$seq__33868_35028$$=$APP.$cljs$core$next$$($G__35087_chunk__33938_35046_prob_35034_seq__33868_35084__$1$$);
$chunk__33869_35029$$=null;$count__33870_35030$$=0}$i__33871_35031$$=0}else break}}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__33865_35024$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__33864_35023$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$2$$)}()]))}else $APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Success!"]))};
$cljs$spec$alpha$assert_STAR_$$=function($spec$jscomp$45$$,$x$jscomp$940$$){if(!$APP.$cljs$spec$alpha$valid_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($spec$jscomp$45$$,$x$jscomp$940$$)){var $ed$jscomp$4$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$spec$alpha$explain_data_STAR_$$($spec$jscomp$45$$,$x$jscomp$940$$),$APP.$cljs$cst$1132$cljs_DOT_spec_DOT_alpha_SLASH_failure$$,
$APP.$cljs$cst$1133$assertion_failed$$)]));throw Error(["Spec assertion failed\n",function(){var $sb__5670__auto__$jscomp$4$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__34911_35637$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__34913_35638$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$4$$){return $sb__5670__auto__$jscomp$4$$.append($x__5671__auto__$jscomp$4$$)};
try{$cljs$spec$alpha$explain_printer$$.call(null,$ed$jscomp$4$$)}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__34913_35638$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__34911_35637$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$4$$)}()].join(""));}};
$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$=function($val$jscomp$194$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($val$jscomp$194$$),"#")?$val$jscomp$194$$:["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$194$$)].join("")};
$app$main$ui$workspace$colorpicker$color_inputs$color_inputs_STAR_$$=function($props_75416_red$jscomp$4$$){function $on_key_down_property$$($property$jscomp$81$$,$max_value$jscomp$2$$){return $on_key_down_step$$($max_value$jscomp$2$$,function($p1__75413_SHARP_$$){return $apply_property_change$$($property$jscomp$81$$,$p1__75413_SHARP_$$)})}function $on_key_down_step$$($max_value$jscomp$1$$,$on_step$$){return function($e$jscomp$340$$){var $new_value$jscomp$9_up_QMARK_$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($e$jscomp$340$$),
$and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($e$jscomp$340$$);$and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$=$APP.$cljs$core$truth_$$($new_value$jscomp$9_up_QMARK_$$)?$new_value$jscomp$9_up_QMARK_$$:$and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$)?
$e$jscomp$340$$.shiftKey||$e$jscomp$340$$.altKey:$and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$)&&($APP.$app$util$dom$prevent_default$$($e$jscomp$340$$),$and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$340$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$))?
($new_value$jscomp$9_up_QMARK_$$=$APP.$app$common$math$clamp$$($and__5023__auto__$jscomp$inline_13376_down_QMARK__temp__5825__auto__$jscomp$327$$+($e$jscomp$340$$.shiftKey?$APP.$cljs$core$truth_$$($new_value$jscomp$9_up_QMARK_$$)?10:-10:$e$jscomp$340$$.altKey?$APP.$cljs$core$truth_$$($new_value$jscomp$9_up_QMARK_$$)?.1:-.1:null),0,$max_value$jscomp$1$$),$app$util$dom$set_value_BANG_$$($APP.$app$util$dom$get_target$$($e$jscomp$340$$),$new_value$jscomp$9_up_QMARK_$$),$on_step$$.$cljs$core$IFn$_invoke$arity$1$?
$on_step$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$9_up_QMARK_$$):$on_step$$($new_value$jscomp$9_up_QMARK_$$)):null}}function $on_change_property$$($property$jscomp$80$$,$max_value$$){return function($e$jscomp$339_val$jscomp$200$$){$e$jscomp$339_val$jscomp$200$$=$APP.$app$common$math$clamp$$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$339_val$jscomp$200$$)),0,$max_value$$);return $e$jscomp$339_val$jscomp$200$$!=null?
$apply_property_change$$($property$jscomp$80$$,$e$jscomp$339_val$jscomp$200$$):null}}function $apply_property_change$$($property$jscomp$79$$,$val$jscomp$199$$){var $g$jscomp$142_new_l_val__$1$jscomp$15$$=function(){switch($property$jscomp$79$$ instanceof $APP.$cljs$core$Keyword$$?$property$jscomp$79$$.$fqn$:null){case "s":return $val$jscomp$199$$/100;case "v":return $val$jscomp$199$$/100*255;case "hsl-s":case "hsl-l":return $val$jscomp$199$$/100;case "alpha":return $val$jscomp$199$$/100;default:return $val$jscomp$199$$}}();
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$79$$,$APP.$cljs$cst$746$alpha$$)){var $G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$746$alpha$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$],null);return $on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$):
$on_change$jscomp$34$$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$)}if($APP.$cljs$core$truth_$$(function(){var $fexpr__75438$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1743$r$$,null,$APP.$cljs$cst$1744$g$$,null,$APP.$cljs$cst$1520$b$$,null],null),null);return $fexpr__75438$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__75438$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$79$$):$fexpr__75438$$($property$jscomp$79$$)}())){$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$color$jscomp$135$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$property$jscomp$79$$],[$g$jscomp$142_new_l_val__$1$jscomp$15$$])]));var $h$jscomp$169_map__75440__$1_vec__75446$$=$APP.$cljs$core$__destructure_map$$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$);$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$169_map__75440__$1_vec__75446$$,$APP.$cljs$cst$1743$r$$);$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$169_map__75440__$1_vec__75446$$,$APP.$cljs$cst$1744$g$$);var $b$jscomp$342_vec__75456$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$169_map__75440__$1_vec__75446$$,$APP.$cljs$cst$1520$b$$),$hex__$1$jscomp$2$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$b$jscomp$342_vec__75456$$],null)),$v$jscomp$633_vec__75441_vec__75449$$=$app$common$types$color$hex__GT_hsv$$($hex__$1$jscomp$2$$);$h$jscomp$169_map__75440__$1_vec__75446$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$633_vec__75441_vec__75449$$,0,null);var $s$jscomp$561$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$633_vec__75441_vec__75449$$,
1,null);$v$jscomp$633_vec__75441_vec__75449$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$633_vec__75441_vec__75449$$,2,null);$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2687$hex$$,$hex__$1$jscomp$2$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$169_map__75440__$1_vec__75446$$,$APP.$cljs$cst$4168$s$$,$s$jscomp$561$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$633_vec__75441_vec__75449$$,
$APP.$cljs$cst$1743$r$$,$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$342_vec__75456$$],null);return $on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$):$on_change$jscomp$34$$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$)}if($APP.$cljs$core$truth_$$(function(){var $fexpr__75445$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5422$hsl_l$$,null,$cljs$cst$5423$hsl_s$$,null],null),null);return $fexpr__75445$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__75445$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$79$$):$fexpr__75445$$($property$jscomp$79$$)}()))return $G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$79$$,
$cljs$cst$5423$hsl_s$$)?$g$jscomp$142_new_l_val__$1$jscomp$15$$:$hsl_s$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$79$$,$cljs$cst$5422$hsl_l$$)?$g$jscomp$142_new_l_val__$1$jscomp$15$$:$hsl_l$$,$h$jscomp$169_map__75440__$1_vec__75446$$=$app$common$types$color$hsl__GT_rgb$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$1$$,$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,
$g$jscomp$142_new_l_val__$1$jscomp$15$$],null)),$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$169_map__75440__$1_vec__75446$$,0,null),$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$169_map__75440__$1_vec__75446$$,1,null),$b$jscomp$342_vec__75456$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$169_map__75440__$1_vec__75446$$,
2,null),$hex__$1$jscomp$2$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$b$jscomp$342_vec__75456$$],null)),$v$jscomp$633_vec__75441_vec__75449$$=$app$common$types$color$hex__GT_hsv$$($hex__$1$jscomp$2$$),$h$jscomp$169_map__75440__$1_vec__75446$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$633_vec__75441_vec__75449$$,
0,null),$s$jscomp$561$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$633_vec__75441_vec__75449$$,1,null),$v$jscomp$633_vec__75441_vec__75449$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$633_vec__75441_vec__75449$$,2,null),$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2687$hex$$,$hex__$1$jscomp$2$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$169_map__75440__$1_vec__75446$$,
$APP.$cljs$cst$4168$s$$,$s$jscomp$561$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$633_vec__75441_vec__75449$$,$APP.$cljs$cst$1743$r$$,$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$342_vec__75456$$],null),$on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$):
$on_change$jscomp$34$$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$);$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$color$jscomp$135$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$property$jscomp$79$$],[$g$jscomp$142_new_l_val__$1$jscomp$15$$])]));$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=
$APP.$cljs$core$__destructure_map$$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$);$h$jscomp$169_map__75440__$1_vec__75446$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1899$h$$);$s$jscomp$561$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,
$APP.$cljs$cst$4168$s$$);$v$jscomp$633_vec__75441_vec__75449$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$3670$v$$);$hex__$1$jscomp$2$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$169_map__75440__$1_vec__75446$$,$s$jscomp$561$$,$v$jscomp$633_vec__75441_vec__75449$$],null));$b$jscomp$342_vec__75456$$=
$APP.$app$common$types$color$hex__GT_rgb$$($hex__$1$jscomp$2$$);$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$342_vec__75456$$,0,null);$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$342_vec__75456$$,1,null);$b$jscomp$342_vec__75456$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$342_vec__75456$$,2,null);
$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2687$hex$$,$hex__$1$jscomp$2$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$169_map__75440__$1_vec__75446$$,$APP.$cljs$cst$4168$s$$,$s$jscomp$561$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$633_vec__75441_vec__75449$$,$APP.$cljs$cst$1743$r$$,$G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1744$g$$,
$g$jscomp$142_new_l_val__$1$jscomp$15$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$342_vec__75456$$],null);return $on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$):$on_change$jscomp$34$$($G__75437_G__75444_G__75454_G__75459_map__75440_map__75455_map__75455__$1_new_s_r$jscomp$121$$)}function $setup_hex_color$$($G__75434_hex__$1$jscomp$1$$){var $b$jscomp$341_vec__75428$$=
$APP.$app$common$types$color$hex__GT_rgb$$($G__75434_hex__$1$jscomp$1$$),$r$jscomp$120$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$341_vec__75428$$,0,null),$g$jscomp$141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$341_vec__75428$$,1,null);$b$jscomp$341_vec__75428$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$341_vec__75428$$,2,null);var $v$jscomp$632_vec__75431$$=$app$common$types$color$hex__GT_hsv$$($G__75434_hex__$1$jscomp$1$$),
$h$jscomp$168$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$632_vec__75431$$,0,null),$s$jscomp$560$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$632_vec__75431$$,1,null);$v$jscomp$632_vec__75431$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$632_vec__75431$$,2,null);$G__75434_hex__$1$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2687$hex$$,$G__75434_hex__$1$jscomp$1$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$168$$,
$APP.$cljs$cst$4168$s$$,$s$jscomp$560$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$632_vec__75431$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$120$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$141$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$341_vec__75428$$],null);return $on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($G__75434_hex__$1$jscomp$1$$):$on_change$jscomp$34$$($G__75434_hex__$1$jscomp$1$$)}var $on_change$jscomp$34$$=$props_75416_red$jscomp$4$$.onChange,$disable_opacity$$=
$props_75416_red$jscomp$4$$.disableOpacity,$color$jscomp$135$$=$props_75416_red$jscomp$4$$.color,$hsb_mode_mode$jscomp$47$$=$props_75416_red$jscomp$4$$.mode,$on_mode_change$$=$props_75416_red$jscomp$4$$.onModeChange,$type$jscomp$606$$=$props_75416_red$jscomp$4$$.type,$alpha$jscomp$14_map__75424__$1$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$135$$);$props_75416_red$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$1743$r$$);var $green$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$1744$g$$),$blue$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$1520$b$$),$hue$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$1899$h$$),$saturation$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$4168$s$$),$value$jscomp$784$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$3670$v$$),$hex$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$2687$hex$$);$alpha$jscomp$14_map__75424__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$746$alpha$$);$hsb_mode_mode$jscomp$47$$=$APP.$cljs$core$truth_$$($hsb_mode_mode$jscomp$47$$)?$hsb_mode_mode$jscomp$47$$:
$cljs$cst$5421$hsb$$;var $vec__75425$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_75416_red$jscomp$4$$)?$APP.$cljs$core$truth_$$($green$jscomp$4$$)?$blue$jscomp$4$$:$green$jscomp$4$$:$props_75416_red$jscomp$4$$)?$APP.$app$common$types$color$rgb__GT_hsl$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$props_75416_red$jscomp$4$$,$green$jscomp$4$$,$blue$jscomp$4$$],null)):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0,0,0],null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75425$$,0,null);var $hsl_s$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75425$$,1,null),$hsl_l$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75425$$,2,null),$refs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1743$r$$,$APP.$cljs$cst$3670$v$$,$APP.$cljs$cst$4168$s$$,$cljs$cst$5422$hsl_l$$,$APP.$cljs$cst$1744$g$$,$APP.$cljs$cst$2687$hex$$,$APP.$cljs$cst$1899$h$$,$APP.$cljs$cst$1520$b$$,
$APP.$cljs$cst$746$alpha$$,$cljs$cst$5423$hsl_s$$],[(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null)]);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$135$$),
$APP.$rumext$v2$adapt$$($type$jscomp$606$$),$APP.$rumext$v2$adapt$$($hsb_mode_mode$jscomp$47$$)],function(){for(var $G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$=$APP.$cljs$core$seq$$($APP.$cljs$core$keys$$($refs$$)),$G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$=null,$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$=0,$i__75466$$=0;;)if($i__75466$$<$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$){var $ref_key$jscomp$1$$=$G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__75466$$),$property_val_75495$$=function(){var $G__75476$$=$ref_key$jscomp$1$$;switch($G__75476$$ instanceof $APP.$cljs$core$Keyword$$?$G__75476$$.$fqn$:null){case "hsl-s":return $hsl_s$$;case "hsl-l":return $hsl_l$$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$135$$,$ref_key$jscomp$1$$)}}(),$property_ref_75496$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($refs$$,$ref_key$jscomp$1$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$686$$=
$property_val_75495$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$686$$)?$property_ref_75496$$:$and__5023__auto__$jscomp$686$$}())){var $node_75499_temp__5825__auto___75498$$=$APP.$rumext$v2$ref_val$$($property_ref_75496$$);if($APP.$cljs$core$truth_$$($node_75499_temp__5825__auto___75498$$)){var $new_val_75500$$=function(){var $G__75477$$=$ref_key$jscomp$1$$;switch($G__75477$$ instanceof $APP.$cljs$core$Keyword$$?$G__75477$$.$fqn$:null){case "s":case "alpha":return $APP.$app$common$math$precision$$($property_val_75495$$*
100,2);case "v":return $APP.$app$common$math$precision$$($property_val_75495$$/255*100,2);case "hsl-s":case "hsl-l":return $APP.$app$common$math$precision$$($property_val_75495$$*100,2);default:return $property_val_75495$$}}();$app$util$dom$set_value_BANG_$$($node_75499_temp__5825__auto___75498$$,$new_val_75500$$)}}$i__75466$$+=1}else if($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$=$APP.$cljs$core$seq$$($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$))$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$=
$APP.$cljs$core$_chunked_first$$($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$),$G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$=$APP.$cljs$core$_chunked_rest$$($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$),$G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$=$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$,$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$=$APP.$cljs$core$count$$($G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$);
else{$ref_key$jscomp$1$$=$APP.$cljs$core$first$$($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$);var $property_val_75511$$=function(){var $G__75479$$=$ref_key$jscomp$1$$;switch($G__75479$$ instanceof $APP.$cljs$core$Keyword$$?$G__75479$$.$fqn$:null){case "hsl-s":return $hsl_s$$;case "hsl-l":return $hsl_l$$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$135$$,$ref_key$jscomp$1$$)}}(),$property_ref_75512$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($refs$$,
$ref_key$jscomp$1$$);$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$687$$=$property_val_75511$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$687$$)?$property_ref_75512$$:$and__5023__auto__$jscomp$687$$}())&&($G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$=$APP.$rumext$v2$ref_val$$($property_ref_75512$$),$APP.$cljs$core$truth_$$($G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$)&&($G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$=
function(){var $G__75482$$=$ref_key$jscomp$1$$;switch($G__75482$$ instanceof $APP.$cljs$core$Keyword$$?$G__75482$$.$fqn$:null){case "s":case "alpha":return $APP.$app$common$math$precision$$($property_val_75511$$*100,2);case "v":return $APP.$app$common$math$precision$$($property_val_75511$$/255*100,2);case "hsl-s":case "hsl-l":return $APP.$app$common$math$precision$$($property_val_75511$$*100,2);default:return $property_val_75511$$}}(),$app$util$dom$set_value_BANG_$$($G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$,
$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$)));$G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$=$APP.$cljs$core$next$$($G__75506_seq__75463_seq__75463__$1_temp__5825__auto__$jscomp$328$$);$G__75507_chunk__75464_node_75515_temp__5825__auto___75514__$1$$=null;$G__75508_c__5548__auto__$jscomp$36_count__75465_new_val_75516$$=0}$i__75466$$=0}else return null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__color-values "+
($APP.$cljs$core$truth_$$($disable_opacity$$)?"main_ui_workspace_colorpicker_color_inputs__disable-opacity":""),children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$688$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$606$$,$cljs$cst$5424$rgb$$);return $and__5023__auto__$jscomp$688$$?$on_mode_change$$:$and__5023__auto__$jscomp$688$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__model-switcher",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{type:"button",onClick:function(){return $on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5421$hsb$$):$on_mode_change$$($cljs$cst$5421$hsb$$)},className:"main_ui_workspace_colorpicker_color_inputs__model-pill "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsb_mode_mode$jscomp$47$$,$cljs$cst$5421$hsb$$)?"main_ui_workspace_colorpicker_color_inputs__model-pill-active":""),children:"HSB"}),(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",
onClick:function(){return $on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5425$hsl$$):$on_mode_change$$($cljs$cst$5425$hsl$$)},className:"main_ui_workspace_colorpicker_color_inputs__model-pill "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsb_mode_mode$jscomp$47$$,$cljs$cst$5425$hsl$$)?"main_ui_workspace_colorpicker_color_inputs__model-pill-active":""),children:"HSL"})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__colors-row",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$606$$,$cljs$cst$5424$rgb$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"red-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"R"}),(0,$APP.$rumext$v2$jsx$$)("input",{id:"red-value",ref:$APP.$cljs$cst$1743$r$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),
type:"number",min:0,max:255,defaultValue:$props_75416_red$jscomp$4$$,onChange:$on_change_property$$($APP.$cljs$cst$1743$r$$,255),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1743$r$$,255)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"green-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"G"}),(0,$APP.$rumext$v2$jsx$$)("input",{id:"green-value",
ref:$APP.$cljs$cst$1744$g$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),type:"number",min:0,max:255,defaultValue:$green$jscomp$4$$,onChange:$on_change_property$$($APP.$cljs$cst$1744$g$$,255),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1744$g$$,255)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"blue-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"B"}),
(0,$APP.$rumext$v2$jsx$$)("input",{id:"blue-value",ref:$APP.$cljs$cst$1520$b$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),type:"number",min:0,max:255,defaultValue:$blue$jscomp$4$$,onChange:$on_change_property$$($APP.$cljs$cst$1520$b$$,255),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1520$b$$,255)})]})]}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsb_mode_mode$jscomp$47$$,$cljs$cst$5425$hsl$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"hue-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"H"}),(0,$APP.$rumext$v2$jsx$$)("input",{id:"hue-value",ref:$APP.$cljs$cst$1899$h$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),type:"number",min:0,max:360,defaultValue:$hue$jscomp$1$$,onChange:$on_change_property$$($APP.$cljs$cst$1899$h$$,360),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1899$h$$,
360)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"hsl-saturation-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"S"}),(0,$APP.$rumext$v2$jsx$$)("input",{min:0,onChange:$on_change_property$$($cljs$cst$5423$hsl_s$$,100),max:100,id:"hsl-saturation-value",type:"number",ref:$cljs$cst$5423$hsl_s$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),defaultValue:$APP.$app$common$math$precision$$($hsl_s$$*
100,2),onKeyDown:$on_key_down_property$$($cljs$cst$5423$hsl_s$$,100),step:1})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"lightness-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"L"}),(0,$APP.$rumext$v2$jsx$$)("input",{min:0,onChange:$on_change_property$$($cljs$cst$5422$hsl_l$$,100),max:100,id:"lightness-value",type:"number",ref:$cljs$cst$5422$hsl_l$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),
defaultValue:$APP.$app$common$math$precision$$($hsl_l$$*100,2),onKeyDown:$on_key_down_property$$($cljs$cst$5422$hsl_l$$,100),step:1})]})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"hue-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"H"}),(0,$APP.$rumext$v2$jsx$$)("input",{id:"hue-value",
ref:$APP.$cljs$cst$1899$h$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),type:"number",min:0,max:360,defaultValue:$hue$jscomp$1$$,onChange:$on_change_property$$($APP.$cljs$cst$1899$h$$,360),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1899$h$$,360)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"saturation-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"S"}),
(0,$APP.$rumext$v2$jsx$$)("input",{min:0,onChange:$on_change_property$$($APP.$cljs$cst$4168$s$$,100),max:100,id:"saturation-value",type:"number",ref:$APP.$cljs$cst$4168$s$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),defaultValue:$saturation$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$4168$s$$,100),step:1})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"brightness-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",
children:"B(V)"}),(0,$APP.$rumext$v2$jsx$$)("input",{id:"brightness-value",ref:$APP.$cljs$cst$3670$v$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),type:"number",min:0,max:100,defaultValue:$value$jscomp$784$$,onChange:$on_change_property$$($APP.$cljs$cst$3670$v$$,100),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$3670$v$$,100)})]})]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__hex-alpha-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper main_ui_workspace_colorpicker_color_inputs__hex",
children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"hex-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"HEX"}),(0,$APP.$rumext$v2$jsx$$)("input",{id:"hex-value",ref:$APP.$cljs$cst$2687$hex$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),defaultValue:$hex$jscomp$9$$,onChange:function($e$jscomp$337_val$jscomp$197$$){$e$jscomp$337_val$jscomp$197$$=$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$((0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$337_val$jscomp$197$$));
return $APP.$app$common$types$color$valid_hex_color_QMARK_$$($e$jscomp$337_val$jscomp$197$$)?$setup_hex_color$$($e$jscomp$337_val$jscomp$197$$):null},onBlur:function($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$){$e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$=(0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$);$e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$=$APP.$app$common$types$color$color_string_QMARK_$$($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$)?
$APP.$app$common$types$color$parse$$($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$):$APP.$app$common$types$color$valid_hex_color_QMARK_$$($app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$))?$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$):null;return $e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$!=null?$setup_hex_color$$($e$jscomp$338_val$jscomp$198_val__$1$jscomp$14$$):null}})]}),
$APP.$cljs$core$not$$($disable_opacity$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"alpha-value",className:"main_ui_workspace_colorpicker_color_inputs__input-label",children:"A"}),(0,$APP.$rumext$v2$jsx$$)("input",{min:0,onChange:$on_change_property$$($APP.$cljs$cst$746$alpha$$,100),max:100,id:"alpha-value",type:"number",ref:$APP.$cljs$cst$746$alpha$$.$cljs$core$IFn$_invoke$arity$1$($refs$$),
defaultValue:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75424__$1$$,$APP.$cljs$cst$1616$multiple$$)?"":$alpha$jscomp$14_map__75424__$1$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$746$alpha$$,100),step:1})]}):null]})]})};$app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-token-empty-state",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("color-token.empty-state")})};
$app$main$ui$workspace$colorpicker$color_tokens$list_item_STAR_$$=function($on_click$jscomp$33_props_75522$$){var $selected$jscomp$137$$=void 0,$on_token_pill_click$$=void 0,$token$jscomp$116$$=void 0;({token:$token$jscomp$116$$,onTokenPillClick:$on_token_pill_click$$,selected:$selected$jscomp$137$$}=$on_click$jscomp$33_props_75522$$);$on_click$jscomp$33_props_75522$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$116$$),$APP.$rumext$v2$adapt$$($on_token_pill_click$$)],
function($event$jscomp$287$$){return $on_token_pill_click$$.$cljs$core$IFn$_invoke$arity$2$?$on_token_pill_click$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$287$$,$token$jscomp$116$$):$on_token_pill_click$$($event$jscomp$287$$,$token$jscomp$116$$)});var $id_tooltip$$=(0,$APP.$rumext$v2$use_id$$)(),$resolved$jscomp$3$$=$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$116$$),$color_value$jscomp$3$$=$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($resolved$jscomp$3$$),
$item_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{id:$id_tooltip$$,style:{width:"100%"},triggerRef:$item_ref$$,content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$116$$),children:(0,$APP.$rumext$v2$jsxs$$)("button",{ref:$item_ref$$,"aria-labelledby":$id_tooltip$$,onClick:$on_click$jscomp$33_props_75522$$,className:"main_ui_workspace_colorpicker_color_tokens__color-token-item "+($APP.$cljs$core$truth_$$($selected$jscomp$137$$)?
"main_ui_workspace_colorpicker_color_tokens__color-token-selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color_value$jscomp$3$$,tooltipContent:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$3$$])),size:"small"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__token-name",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$116$$)}),$APP.$cljs$core$truth_$$($selected$jscomp$137$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_colorpicker_color_tokens__token-selected-icon"}):null]})})};
$app$main$ui$workspace$colorpicker$color_tokens$grid_item_STAR_$$=function($on_click$jscomp$34_props_75549$$){var $selected$jscomp$138$$=void 0,$on_token_pill_click$jscomp$1$$=void 0,$token$jscomp$117$$=void 0;({token:$token$jscomp$117$$,onTokenPillClick:$on_token_pill_click$jscomp$1$$,selected:$selected$jscomp$138$$}=$on_click$jscomp$34_props_75549$$);$on_click$jscomp$34_props_75549$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$117$$),$APP.$rumext$v2$adapt$$($on_token_pill_click$jscomp$1$$)],
function($event$jscomp$288$$){return $on_token_pill_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_token_pill_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$288$$,$token$jscomp$117$$):$on_token_pill_click$jscomp$1$$($event$jscomp$288$$,$token$jscomp$117$$)});var $resolved$jscomp$4$$=$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$117$$),$token_name$jscomp$14$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$117$$),$color_value$jscomp$4$$=
$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($resolved$jscomp$4$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-token-item-grid "+($APP.$cljs$core$truth_$$($selected$jscomp$138$$)?"main_ui_workspace_colorpicker_color_tokens__color-token-selected-grid":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color_value$jscomp$4$$,tooltipContent:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")??"")+": "}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_color_tokens__token-name",children:$token_name$jscomp$14$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$4$$]))})]}),
onClick:$on_click$jscomp$34_props_75549$$,size:"medium"})})};
$app$main$ui$workspace$colorpicker$color_tokens$group__GT_paths$$=function($m$jscomp$221$$){var $parts$jscomp$23$$=function(){var $temp__5825__auto__$jscomp$329$$=$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$221$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$329$$)?$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$329$$,/\//):null}();return $APP.$cljs$core$seq$$($parts$jscomp$23$$)?$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($i$jscomp$514$$){return $APP.$cljs$core$vec$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$514$$,
$parts$jscomp$23$$))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$APP.$cljs$core$count$$($parts$jscomp$23$$)+1))):$APP.$cljs$core$PersistentHashSet$EMPTY$$};
$app$main$ui$workspace$colorpicker$color_tokens$set_section_STAR_$$=function($props_75603_toggle_list_style$$){var $on_token_change$$=void 0,$collapsed$jscomp$2$$=void 0,$name$jscomp$436$$=void 0,$applied_token$$=void 0,$toggle_sets_open$$=void 0,$group_or_set$$=void 0,$color_origin$$=void 0;({collapsed:$collapsed$jscomp$2$$,toggleSetsOpen:$toggle_sets_open$$,groupOrSet:$group_or_set$$,name:$name$jscomp$436$$,colorOrigin:$color_origin$$,onTokenChange:$on_token_change$$,appliedToken:$applied_token$$}=
$props_75603_toggle_list_style$$);var $list_style_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$201$list$$),$list_style$$=$APP.$cljs$core$_deref$$($list_style_STAR_$$);$props_75603_toggle_list_style$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($list_style$$)],function(){var $new_style$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$201$list$$,$list_style$$)?$APP.$cljs$cst$1659$grid$$:$APP.$cljs$cst$201$list$$;
return $APP.$cljs$core$reset_BANG_$$($list_style_STAR_$$,$new_style$$)});var $toggle_set$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($name$jscomp$436$$),$APP.$rumext$v2$adapt$$($toggle_sets_open$$)],function(){return $toggle_sets_open$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_sets_open$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$436$$):$toggle_sets_open$$($name$jscomp$436$$)}),$objects$jscomp$762$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),
$selected$jscomp$139$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),$selected_shapes$jscomp$11$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$139$$),$APP.$rumext$v2$adapt$$($objects$jscomp$762$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$762$$)),$selected$jscomp$139$$)}),
$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$11$$);$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$);var $has_color_tokens_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$,$APP.$cljs$cst$1403$fill$$),
$has_stroke_tokens_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$,$APP.$cljs$cst$1739$stroke_color$$),$on_token_pill_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$11$$)],function($event$jscomp$289$$,$token$jscomp$118$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$289$$);return $APP.$cljs$core$seq$$($selected_shapes$jscomp$11$$)?
$on_token_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_token_change$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$289$$,$token$jscomp$118$$):$on_token_change$$($event$jscomp$289$$,$token$jscomp$118$$):null});$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($group_or_set$$)],function(){var $JSCompiler_temp_const$jscomp$1699_path_set$$=$app$main$ui$workspace$colorpicker$color_tokens$group__GT_paths$$($group_or_set$$),
$JSCompiler_temp_const$jscomp$1698_id$jscomp$924$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($group_or_set$$))),$JSCompiler_temp_const$jscomp$1701$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$1700$$=$APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,
$APP.$cljs$cst$2100$tokens$$]));$JSCompiler_temp_const$jscomp$1699_path_set$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1699_path_set$$)?$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5426$expand_token_sets$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5427$paths$$,$JSCompiler_temp_const$jscomp$1699_path_set$$],null)):null;$JSCompiler_temp_const$jscomp$1698_id$jscomp$924$$=$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($JSCompiler_temp_const$jscomp$1698_id$jscomp$924$$);
var $JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$1298$color$$);var $map__75605__$1$jscomp$inline_8549_title$jscomp$inline_8551$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$);$JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75605__$1$jscomp$inline_8549_title$jscomp$inline_8551$$,$APP.$cljs$cst$4550$modal$$);$map__75605__$1$jscomp$inline_8549_title$jscomp$inline_8551$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75605__$1$jscomp$inline_8549_title$jscomp$inline_8551$$,$APP.$cljs$cst$939$title$$);var $window_size$jscomp$inline_8552_y$jscomp$inline_8555$$=$APP.$app$util$dom$get_window_size$$(),$left_sidebar$jscomp$inline_8553_x$jscomp$inline_8554$$=
$APP.$goog$dom$getElement$$("left-sidebar-aside");$left_sidebar$jscomp$inline_8553_x$jscomp$inline_8554$$=($APP.$app$util$dom$get_data$$($left_sidebar$jscomp$inline_8553_x$jscomp$inline_8554$$,"width")|0)-30;$window_size$jscomp$inline_8552_y$jscomp$inline_8555$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($window_size$jscomp$inline_8552_y$jscomp$inline_8555$$)/2-196;$JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$=$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1510$x$$,$left_sidebar$jscomp$inline_8553_x$jscomp$inline_8554$$,$APP.$cljs$cst$1511$y$$,$window_size$jscomp$inline_8552_y$jscomp$inline_8555$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$4659$fields$$,$APP.$cljs$cst$4659$fields$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$),$APP.$cljs$cst$939$title$$,$map__75605__$1$jscomp$inline_8549_title$jscomp$inline_8551$$,
$APP.$cljs$cst$2683$action$$,"create",$cljs$cst$5428$token_type$$,$APP.$cljs$cst$1298$color$$],null));return $JSCompiler_temp_const$jscomp$1701$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_temp_const$jscomp$1700$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp_const$jscomp$1699_path_set$$,$JSCompiler_temp_const$jscomp$1698_id$jscomp$924$$,$JSCompiler_inline_result$jscomp$1703_map__75605$jscomp$inline_8548_modal$jscomp$inline_8550$$]))});var $icon_id$jscomp$5$$=
$APP.$cljs$core$truth_$$($collapsed$jscomp$2$$)?"arrow-right":"arrow-down";return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_workspace_colorpicker_color_tokens__color-token-set",children:[(0,$APP.$rumext$v2$jsxs$$)("header",{className:"main_ui_workspace_colorpicker_color_tokens__set-title-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{"aria-controls":["set-panel-",$APP.$app$common$data$name$$($name$jscomp$436$$)].join(""),"aria-expanded":$APP.$cljs$core$not$$($collapsed$jscomp$2$$),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("inspect.tabs.styles.toggle-style",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$436$$])),onClick:$toggle_set$$,className:"main_ui_workspace_colorpicker_color_tokens__set-title-btn",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon_id$jscomp$5$$,size:"s",className:"main_ui_workspace_colorpicker_color_tokens__set-title-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_colorpicker_color_tokens__set-title",children:$name$jscomp$436$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__set-title-actions "+($APP.$cljs$core$truth_$$($collapsed$jscomp$2$$)?"main_ui_workspace_colorpicker_color_tokens__set-title-action-hidden":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$props_75603_toggle_list_style$$,variant:"action","aria-label":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$201$list$$,
$list_style$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.grid-view"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.list-view"),icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$201$list$$,$list_style$$)?"flex-grid":"view-as-list"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$11$$,variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.add-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["color"])),icon:"add"})]})]}),$APP.$cljs$core$not$$($collapsed$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{id:["set-panel-",$APP.$app$common$data$name$$($name$jscomp$436$$)].join(""),className:"main_ui_workspace_colorpicker_color_tokens__color-token-list "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($list_style$$,$APP.$cljs$cst$201$list$$)?
"main_ui_workspace_colorpicker_color_tokens__list-view":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($list_style$$,$APP.$cljs$cst$1659$grid$$)?"main_ui_workspace_colorpicker_color_tokens__grid-view":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$114$$,$token$jscomp$119$$){$out_arr__44124__auto__$jscomp$114$$.push(function(){var $selected_QMARK_$jscomp$1$$=function(){var $G__75608$$=$color_origin$$;switch($G__75608$$ instanceof
$APP.$cljs$core$Keyword$$?$G__75608$$.$fqn$:null){case "fill":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($has_color_tokens_QMARK_$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$119$$));case "stroke-color":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($has_stroke_tokens_QMARK_$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$119$$));case "color-selection":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_token$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$119$$));default:return!1}}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1659$grid$$,$list_style$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$grid_item_STAR_$$,{onTokenPillClick:$on_token_pill_click$jscomp$2$$,selected:$selected_QMARK_$jscomp$1$$,token:$token$jscomp$119$$},["token-grid-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$119$$))].join("")):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$list_item_STAR_$$,{onTokenPillClick:$on_token_pill_click$jscomp$2$$,selected:$selected_QMARK_$jscomp$1$$,token:$token$jscomp$119$$},["token-list-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$119$$))].join(""))}());return $out_arr__44124__auto__$jscomp$114$$},[],$APP.$cljs$cst$2100$tokens$$.$cljs$core$IFn$_invoke$arity$1$($group_or_set$$))}):null]})};
$app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$=function($group$jscomp$47_p__75609$$){var $map__75610__$1_sets$jscomp$14$$=$APP.$cljs$core$__destructure_map$$($group$jscomp$47_p__75609$$);$group$jscomp$47_p__75609$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75610__$1_sets$jscomp$14$$,$APP.$cljs$cst$1608$group$$);$map__75610__$1_sets$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75610__$1_sets$jscomp$14$$,$APP.$cljs$cst$2108$sets$$);
return $APP.$cljs$core$truth_$$($group$jscomp$47_p__75609$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$47_p__75609$$)," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$map__75610__$1_sets$jscomp$14$$))),")"].join(""):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($map__75610__$1_sets$jscomp$14$$))};
$app$main$ui$workspace$colorpicker$color_tokens$filter_combined_tokens$$=function($combined_tokens$$,$term$jscomp$6$$){var $term__$1$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($term$jscomp$6$$));return $APP.$cuerdas$core$blank_QMARK_$$($term__$1$$)?$combined_tokens$$:$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__75614__$1_p__75613$$){$map__75614__$1_p__75613$$=
$APP.$cljs$core$__destructure_map$$($map__75614__$1_p__75613$$);var $filtered$jscomp$1_tokens$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75614__$1_p__75613$$,$APP.$cljs$cst$2100$tokens$$);$filtered$jscomp$1_tokens$jscomp$38$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75612_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__75612_SHARP_$$)),$term__$1$$)},
$filtered$jscomp$1_tokens$jscomp$38$$);return $APP.$cljs$core$seq$$($filtered$jscomp$1_tokens$jscomp$38$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__75614__$1_p__75613$$,$APP.$cljs$cst$2100$tokens$$,$filtered$jscomp$1_tokens$jscomp$38$$):null},$combined_tokens$$))};
$app$main$ui$workspace$colorpicker$color_tokens$sort_combined_tokens$$=function($combined_tokens$jscomp$1$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($entry$jscomp$69$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$69$$,$APP.$cljs$cst$2100$tokens$$,function($p1__75615_SHARP_$$){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$p1__75615_SHARP_$$)})},$combined_tokens$jscomp$1$$)};
$app$main$ui$workspace$colorpicker$color_tokens$token_section_STAR_$$=function($filter_term_props_75616$$){var $on_token_change$jscomp$1$$=void 0,$combined_tokens$jscomp$2$$=void 0,$applied_token$jscomp$1$$=void 0,$color_origin$jscomp$1$$=void 0;({combinedTokens:$combined_tokens$jscomp$2$$,colorOrigin:$color_origin$jscomp$1$$,onTokenChange:$on_token_change$jscomp$1$$,appliedToken:$applied_token$jscomp$1$$}=$filter_term_props_75616$$);var $sets$jscomp$15$$=$APP.$cljs$core$set$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$,
$combined_tokens$jscomp$2$$)),$filter_term_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("");$filter_term_props_75616$$=$APP.$cljs$core$_deref$$($filter_term_STAR_$$);var $open_sets_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($sets$jscomp$15$$),$open_sets$$=$APP.$cljs$core$_deref$$($open_sets_STAR_$$),$toggle_sets_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_sets$$)],function($name$jscomp$437$$){return $APP.$cljs$core$contains_QMARK_$$($open_sets$$,
$name$jscomp$437$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($open_sets_STAR_$$,$APP.$cljs$core$disj$$,$name$jscomp$437$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($open_sets_STAR_$$,$APP.$cljs$core$conj$$,$name$jscomp$437$$)}),$on_filter_tokens$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filter_term_props_75616$$)],function($event$jscomp$290$$){$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$$,$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$290$$)));
return $APP.$cljs$core$reset_BANG_$$($open_sets_STAR_$$,$sets$jscomp$15$$)}),$filtered_combined_sorted_tokens$$=$app$main$ui$workspace$colorpicker$color_tokens$filter_combined_tokens$$($combined_tokens$jscomp$2$$,$filter_term_props_75616$$);$filtered_combined_sorted_tokens$$=$app$main$ui$workspace$colorpicker$color_tokens$sort_combined_tokens$$($filtered_combined_sorted_tokens$$);return $APP.$cljs$core$seq$$($combined_tokens$jscomp$2$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-tokens-section",
children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{placeholder:"Search by token name",icon:"search",maxLength:255,variant:"comfortable",className:"main_ui_workspace_colorpicker_color_tokens__search-input",defaultValue:$filter_term_props_75616$$,onChange:$on_filter_tokens$$}),$APP.$cljs$core$seq$$($filtered_combined_sorted_tokens$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-tokens-inputs",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$115$$,
$JSCompiler_inline_result$jscomp$1706_combined_sets$$){var $JSCompiler_temp_const$jscomp$1704$$=$out_arr__44124__auto__$jscomp$115$$.push,$name$jscomp$inline_8557$$=$app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$($JSCompiler_inline_result$jscomp$1706_combined_sets$$);$JSCompiler_inline_result$jscomp$1706_combined_sets$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$set_section_STAR_$$,{collapsed:!$APP.$cljs$core$contains_QMARK_$$($open_sets$$,$name$jscomp$inline_8557$$),
toggleSetsOpen:$toggle_sets_open$jscomp$1$$,colorOrigin:$color_origin$jscomp$1$$,onTokenChange:$on_token_change$jscomp$1$$,name:$name$jscomp$inline_8557$$,appliedToken:$applied_token$jscomp$1$$,groupOrSet:$JSCompiler_inline_result$jscomp$1706_combined_sets$$},["set-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$inline_8557$$)].join(""));$JSCompiler_temp_const$jscomp$1704$$.call($out_arr__44124__auto__$jscomp$115$$,$JSCompiler_inline_result$jscomp$1706_combined_sets$$);return $out_arr__44124__auto__$jscomp$115$$},
[],$filtered_combined_sorted_tokens$$)}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$,{})]}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$,{})};
$instaparse$auto_flatten_seq$conj_flat$$=function($JSCompiler_temp$jscomp$1707_self$jscomp$81$$,$obj$jscomp$212$$){if($JSCompiler_temp$jscomp$1707_self$jscomp$81$$!=null&&$JSCompiler_temp$jscomp$1707_self$jscomp$81$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$!=null)$JSCompiler_temp$jscomp$1707_self$jscomp$81$$=$JSCompiler_temp$jscomp$1707_self$jscomp$81$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$($JSCompiler_temp$jscomp$1707_self$jscomp$81$$,$obj$jscomp$212$$);else{var $m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$=
$instaparse$auto_flatten_seq$conj_flat$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1707_self$jscomp$81$$==null?null:$JSCompiler_temp$jscomp$1707_self$jscomp$81$$)];if($m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$!=null)$JSCompiler_temp$jscomp$1707_self$jscomp$81$$=$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1707_self$jscomp$81$$,
$obj$jscomp$212$$):$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$($JSCompiler_temp$jscomp$1707_self$jscomp$81$$,$obj$jscomp$212$$);else if($m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$=$instaparse$auto_flatten_seq$conj_flat$$._,$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$!=null)$JSCompiler_temp$jscomp$1707_self$jscomp$81$$=$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1707_self$jscomp$81$$,$obj$jscomp$212$$):$m__5372__auto__$jscomp$inline_8562_m__5374__auto__$jscomp$inline_8561$$($JSCompiler_temp$jscomp$1707_self$jscomp$81$$,$obj$jscomp$212$$);else throw $APP.$cljs$core$missing_protocol$$("ConjFlat.conj-flat",$JSCompiler_temp$jscomp$1707_self$jscomp$81$$);}return $JSCompiler_temp$jscomp$1707_self$jscomp$81$$};
$instaparse$auto_flatten_seq$delve$$=function($G__75653_v$jscomp$634_v__$1$jscomp$29$$,$G__75654_index$jscomp$409_index__$1$jscomp$19$$){for($G__75653_v$jscomp$634_v__$1$jscomp$29$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__75653_v$jscomp$634_v__$1$jscomp$29$$,$G__75654_index$jscomp$409_index__$1$jscomp$19$$);;)if($APP.$cljs$core$truth_$$($instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__75653_v$jscomp$634_v__$1$jscomp$29$$):
$instaparse$auto_flatten_seq$afs_QMARK_$$($G__75653_v$jscomp$634_v__$1$jscomp$29$$)))$G__75653_v$jscomp$634_v__$1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75653_v$jscomp$634_v__$1$jscomp$29$$,0),$G__75654_index$jscomp$409_index__$1$jscomp$19$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__75654_index$jscomp$409_index__$1$jscomp$19$$,0);else return $G__75654_index$jscomp$409_index__$1$jscomp$19$$};
$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$=function($v$jscomp$637$$,$index$jscomp$411$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_temp_const$jscomp$1712$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$637$$,$index$jscomp$411$$);a:{var $G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$=$v$jscomp$637$$;for(var $G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$=$index$jscomp$411$$;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$),
1)){$G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$=$APP.$cljs$core$peek$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$)<($instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$($G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$):$instaparse$auto_flatten_seq$true_count$$($G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$))-
1?$instaparse$auto_flatten_seq$delve$$($G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$peek$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$)+1],null)):null;break a}var $JSCompiler_temp_const$jscomp$inline_13380$$=$APP.$cljs$core$peek$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$);var $G__75622$jscomp$inline_13382_JSCompiler_inline_result$jscomp$inline_13381$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$,$APP.$cljs$core$pop$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$));$G__75622$jscomp$inline_13382_JSCompiler_inline_result$jscomp$inline_13381$$=$instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$($G__75622$jscomp$inline_13382_JSCompiler_inline_result$jscomp$inline_13381$$):
$instaparse$auto_flatten_seq$true_count$$($G__75622$jscomp$inline_13382_JSCompiler_inline_result$jscomp$inline_13381$$);if($JSCompiler_temp_const$jscomp$inline_13380$$<$G__75622$jscomp$inline_13382_JSCompiler_inline_result$jscomp$inline_13381$$-1){$G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$=$instaparse$auto_flatten_seq$delve$$($G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$),
$APP.$cljs$core$peek$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$)+1));break a}$G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$=$APP.$cljs$core$pop$$($G__75656$jscomp$inline_13384_index$jscomp$inline_13379$$)}$G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$=void 0}return $APP.$cljs$core$cons$$($JSCompiler_temp_const$jscomp$1712$$,$APP.$cljs$core$truth_$$($G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$)?
$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$637$$,$G__75655$jscomp$inline_13383_temp__5825__auto__$jscomp$inline_8566_v$jscomp$inline_13378$$):null)},null,null)};
$instaparse$auto_flatten_seq$AutoFlattenSeq$$=function($v$jscomp$638$$,$premix_hashcode$$,$hashcode$$,$cnt$jscomp$47$$,$dirty$$){this.v=$v$jscomp$638$$;this.$premix_hashcode$=$premix_hashcode$$;this.$hashcode$=$hashcode$$;this.$cnt$=$cnt$jscomp$47$$;this.$dirty$=$dirty$$;this.$cached_seq$=null;this.$cljs$lang$protocol_mask$partition0$$=31850958;this.$cljs$lang$protocol_mask$partition1$$=0};
$instaparse$auto_flatten_seq$hash_cat$$=function($v1$jscomp$38$$,$v2$jscomp$30$$){var $JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$=$APP.$cljs$core$count$$($v2$jscomp$30$$);a:if($JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$===0)$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$=1;else{$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$|=
0;for(var $G__75648$jscomp$inline_8579_G__75651$jscomp$inline_8581_y$jscomp$inline_8575$$=1,$G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$=31;;){var $t$jscomp$inline_8577$$=$APP.$cljs$core$even_QMARK_$$($JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$);$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$=$APP.$cljs$core$quot$$($JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$,
2);if($t$jscomp$inline_8577$$)$G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$=(0,$APP.$cljs$core$imul$$)($G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$,$G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$);else{if($JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$===0){$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$=
(0,$APP.$cljs$core$imul$$)($G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$,$G__75648$jscomp$inline_8579_G__75651$jscomp$inline_8581_y$jscomp$inline_8575$$);break a}$G__75648$jscomp$inline_8579_G__75651$jscomp$inline_8581_y$jscomp$inline_8575$$=(0,$APP.$cljs$core$imul$$)($G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$,$G__75648$jscomp$inline_8579_G__75651$jscomp$inline_8581_y$jscomp$inline_8575$$);$G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$=
(0,$APP.$cljs$core$imul$$)($G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$,$G__75649$jscomp$inline_8580_G__75652$jscomp$inline_8582_z$jscomp$inline_8576$$)}}$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$=void 0}$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$|=0;return(0,$APP.$cljs$core$imul$$)($JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$,
$v1$jscomp$38$$.$premix_hashcode$)+($v2$jscomp$30$$.$premix_hashcode$-$JSCompiler_inline_result$jscomp$1708_c$jscomp$302_e$jscomp$341_n$jscomp$inline_8574_n__$1$jscomp$inline_8578$$)};
$instaparse$auto_flatten_seq$auto_flatten_seq$$=function($v$jscomp$640_v__$1$jscomp$30$$){$v$jscomp$640_v__$1$jscomp$30$$=$APP.$cljs$core$vec$$($v$jscomp$640_v__$1$jscomp$30$$);a:{var $G__75661$jscomp$inline_13389_JSCompiler_inline_result$jscomp$11009_unmixed_hash$jscomp$inline_13387$$=1;for(var $G__75662$jscomp$inline_13390_coll__$1$jscomp$inline_13388$$=$APP.$cljs$core$seq$$($v$jscomp$640_v__$1$jscomp$30$$);;)if($G__75662$jscomp$inline_13390_coll__$1$jscomp$inline_13388$$!=null)$G__75661$jscomp$inline_13389_JSCompiler_inline_result$jscomp$11009_unmixed_hash$jscomp$inline_13387$$=
(0,$APP.$cljs$core$imul$$)(31,$G__75661$jscomp$inline_13389_JSCompiler_inline_result$jscomp$11009_unmixed_hash$jscomp$inline_13387$$)+$APP.$cljs$core$hash$$($APP.$cljs$core$first$$($G__75662$jscomp$inline_13390_coll__$1$jscomp$inline_13388$$))|0,$G__75662$jscomp$inline_13390_coll__$1$jscomp$inline_13388$$=$APP.$cljs$core$next$$($G__75662$jscomp$inline_13390_coll__$1$jscomp$inline_13388$$);else break a;$G__75661$jscomp$inline_13389_JSCompiler_inline_result$jscomp$11009_unmixed_hash$jscomp$inline_13387$$=
void 0}return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($v$jscomp$640_v__$1$jscomp$30$$,$G__75661$jscomp$inline_13389_JSCompiler_inline_result$jscomp$11009_unmixed_hash$jscomp$inline_13387$$,$APP.$cljs$core$hash$$($v$jscomp$640_v__$1$jscomp$30$$),$APP.$cljs$core$count$$($v$jscomp$640_v__$1$jscomp$30$$),!1)};$instaparse$auto_flatten_seq$afs_QMARK_$$=function($s$jscomp$562$$){return $s$jscomp$562$$ instanceof $instaparse$auto_flatten_seq$AutoFlattenSeq$$};
$instaparse$auto_flatten_seq$true_count$$=function($v$jscomp$641$$){return $instaparse$auto_flatten_seq$afs_QMARK_$$($v$jscomp$641$$)?$APP.$cljs$core$count$$($v$jscomp$641$$.v):$APP.$cljs$core$count$$($v$jscomp$641$$)};
$instaparse$auto_flatten_seq$FlattenOnDemandVector$$=function($v$jscomp$644$$,$hashcode$jscomp$2$$,$cnt$jscomp$49$$,$flat$$){this.v=$v$jscomp$644$$;this.$hashcode$=$hashcode$jscomp$2$$;this.$cnt$=$cnt$jscomp$49$$;this.flat=$flat$$;this.$cljs$lang$protocol_mask$partition0$$=167142175;this.$cljs$lang$protocol_mask$partition1$$=2048};
$JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$=function($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$){$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.flat))&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.flat,function(){var $JSCompiler_inline_result$jscomp$1718_v$jscomp$inline_8584$$=
$APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.v);$JSCompiler_inline_result$jscomp$1718_v$jscomp$inline_8584$$=$APP.$cljs$core$persistent_BANG_$$($instaparse$auto_flatten_seq$flat_vec_helper$$($APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$JSCompiler_inline_result$jscomp$1718_v$jscomp$inline_8584$$));return $APP.$cljs$core$with_meta$$($JSCompiler_inline_result$jscomp$1718_v$jscomp$inline_8584$$,$APP.$cljs$core$meta$$($APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.v)))}),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.v,function(){return null}));return $APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.flat)};
$instaparse$auto_flatten_seq$convert_afs_to_vec$$=function($afs$jscomp$1$$){return $APP.$cljs$core$truth_$$($afs$jscomp$1$$.$dirty$)?$APP.$cljs$core$truth_$$($afs$jscomp$1$$.$cached_seq$)?$APP.$cljs$core$vec$$($APP.$cljs$core$seq$$($afs$jscomp$1$$)):new $instaparse$auto_flatten_seq$FlattenOnDemandVector$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($afs$jscomp$1$$.v),$afs$jscomp$1$$.$hashcode$,$afs$jscomp$1$$.$cnt$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null)):$afs$jscomp$1$$.v};
$instaparse$print$paren_for_tags$$=function($JSCompiler_inline_result$jscomp$1719_tag_set$$,$G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$,$parser$jscomp$16$$){($G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$=$APP.$cljs$core$not$$($G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$))?($G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$=
$parser$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$parser$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$78$tag$$):$parser$jscomp$16$$($APP.$cljs$cst$78$tag$$),$JSCompiler_inline_result$jscomp$1719_tag_set$$=$JSCompiler_inline_result$jscomp$1719_tag_set$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1719_tag_set$$.$cljs$core$IFn$_invoke$arity$1$($G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$):$JSCompiler_inline_result$jscomp$1719_tag_set$$($G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$)):
$JSCompiler_inline_result$jscomp$1719_tag_set$$=$G__75663$jscomp$inline_8589_and__5023__auto__$jscomp$inline_8588_hidden_QMARK_$jscomp$3$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1719_tag_set$$)?["(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$?$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$16$$,!1):$instaparse$print$combinators__GT_str$$($parser$jscomp$16$$,
!1)),")"].join(""):$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$?$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$16$$,!1):$instaparse$print$combinators__GT_str$$($parser$jscomp$16$$,!1)};$instaparse$print$regexp_replace$$=function($s$jscomp$564$$){switch($s$jscomp$564$$){case "\n":return"\\n";case "\b":return"\\b";case "\f":return"\\f";case "\r":return"\\r";case "\t":return"\\t";default:return $s$jscomp$564$$}};
$instaparse$print$regexp__GT_str$$=function($r$jscomp$122$$){return $APP.$clojure$string$replace$$(['#"',$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($r$jscomp$122$$.source,1),'"'].join(""),/[\s]/,$instaparse$print$regexp_replace$$)};$instaparse$print$number__GT_hex_padded$$=function($n$jscomp$296$$){return $n$jscomp$296$$<=4095?["0000",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$296$$.toString(16))].join("").substr(-4):$n$jscomp$296$$.toString(16)};
$instaparse$print$char_range__GT_str$$=function($lo$jscomp$5_p__75674$$){var $hi$jscomp$7_map__75675__$1$$=$APP.$cljs$core$__destructure_map$$($lo$jscomp$5_p__75674$$);$lo$jscomp$5_p__75674$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hi$jscomp$7_map__75675__$1$$,$cljs$cst$5439$lo$$);$hi$jscomp$7_map__75675__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hi$jscomp$7_map__75675__$1$$,$cljs$cst$5440$hi$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($lo$jscomp$5_p__75674$$,
$hi$jscomp$7_map__75675__$1$$)?["%x",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$number__GT_hex_padded$$($lo$jscomp$5_p__75674$$))].join(""):["%x",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$number__GT_hex_padded$$($lo$jscomp$5_p__75674$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$number__GT_hex_padded$$($hi$jscomp$7_map__75675__$1$$))].join("")};
$instaparse$print$combinators__GT_str$$=function($var_args$jscomp$1416$$){switch(arguments.length){case 1:return $instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],!1);case 2:return $instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$,$hidden_QMARK_$jscomp$4$$){var $map__75682__$1$$=$APP.$cljs$core$__destructure_map$$($_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$);$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75682__$1$$,$APP.$cljs$cst$646$parser$$);var $_STAR_print_fn_STAR__orig_val__75686_75713__STAR_print_fn_STAR__orig_val__75690_75717_parser1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75682__$1$$,$cljs$cst$5441$parser1$$),$parser2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75682__$1$$,$cljs$cst$5442$parser2$$),$parsers$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75682__$1$$,
$cljs$cst$5443$parsers$$),$G__75683__$1_tag$jscomp$89$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75682__$1$$,$APP.$cljs$cst$78$tag$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$690$$=$APP.$cljs$core$not$$($hidden_QMARK_$jscomp$4$$);return $and__5023__auto__$jscomp$690$$?$APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$):$and__5023__auto__$jscomp$690$$}()))return["\x3c",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($map__75682__$1$$,
!0)),"\x3e"].join("");$G__75683__$1_tag$jscomp$89$$=$G__75683__$1_tag$jscomp$89$$ instanceof $APP.$cljs$core$Keyword$$?$G__75683__$1_tag$jscomp$89$$.$fqn$:null;switch($G__75683__$1_tag$jscomp$89$$){case "epsilon":return"ε";case "opt":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$)),"?"].join("");
case "plus":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$)),"+"].join("");case "star":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$)),
"*"].join("");case "rep":return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$),$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$))?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$)),"{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$)),
",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$)),"}"].join(""):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$)),"{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$)),
"}"].join("");case "alt":return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" | ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($instaparse$print$paren_for_tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5438$ord$$,null],null),null),$hidden_QMARK_$jscomp$4$$),$parsers$jscomp$6$$));case "ord":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_tags$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$717$alt$$,null],null),null),$hidden_QMARK_$jscomp$4$$,$_STAR_print_fn_STAR__orig_val__75686_75713__STAR_print_fn_STAR__orig_val__75690_75717_parser1$$))," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_tags$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$717$alt$$,null],null),null),$hidden_QMARK_$jscomp$4$$,$parser2$$))].join("");case "cat":return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($instaparse$print$paren_for_tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5438$ord$$,null,$APP.$cljs$cst$717$alt$$,null],null),null),$hidden_QMARK_$jscomp$4$$),$parsers$jscomp$6$$));case "string":var $sb__5670__auto__$jscomp$8$$=new $APP.$goog$string$StringBuffer$$;$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$=
$APP.$cljs$core$_STAR_print_newline_STAR_$$;$_STAR_print_fn_STAR__orig_val__75686_75713__STAR_print_fn_STAR__orig_val__75690_75717_parser1$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$8$$){return $sb__5670__auto__$jscomp$8$$.append($x__5671__auto__$jscomp$8$$)};try{$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$)]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__75686_75713__STAR_print_fn_STAR__orig_val__75690_75717_parser1$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$8$$);case "string-ci":$sb__5670__auto__$jscomp$8$$=new $APP.$goog$string$StringBuffer$$;$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$=
$APP.$cljs$core$_STAR_print_newline_STAR_$$;$_STAR_print_fn_STAR__orig_val__75686_75713__STAR_print_fn_STAR__orig_val__75690_75717_parser1$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$9$$){return $sb__5670__auto__$jscomp$8$$.append($x__5671__auto__$jscomp$9$$)};try{$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$)]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__75686_75713__STAR_print_fn_STAR__orig_val__75690_75717_parser1$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$8$$);case "char":return $instaparse$print$char_range__GT_str$$($map__75682__$1$$);case "regexp":return $instaparse$print$regexp__GT_str$$($cljs$cst$5444$regexp$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$));
case "nt":return $APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($map__75682__$1$$)),1);case "look":return["\x26",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$))].join("");case "neg":return["!",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__75685_75712__STAR_print_newline_STAR__orig_val__75689_75716_p__75681_parser$jscomp$17$$))].join("");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75683__$1_tag$jscomp$89$$)].join(""));}};
$instaparse$print$rule__GT_str$$=function($JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$,$parser$jscomp$18$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5445$reduction_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$18$$)),$APP.$cljs$cst$561$raw$$))$JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$=["\x3c",$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$),"\x3e \x3d ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$18$$,
!1))].join("");else{var $temp__5823__auto__$jscomp$inline_8592$$=$APP.$cljs$core$namespace$$($JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$);$JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$=[$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_8592$$)?[$temp__5823__auto__$jscomp$inline_8592$$,"/",$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$)].join(""):$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$)," \x3d ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$18$$,
!1))].join("")}return $JSCompiler_temp$jscomp$1720_non_terminal$jscomp$1$$};
$instaparse$print$Parser__GT_str$$=function($map__75696__$1_p__75695$$){$map__75696__$1_p__75695$$=$APP.$cljs$core$__destructure_map$$($map__75696__$1_p__75695$$);var $grammar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75696__$1_p__75695$$,$cljs$cst$5447$grammar$$),$start$jscomp$233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75696__$1_p__75695$$,$cljs$cst$5448$start_production$$);return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$cons$$($instaparse$print$rule__GT_str$$($start$jscomp$233$$,
$grammar$$.$cljs$core$IFn$_invoke$arity$1$?$grammar$$.$cljs$core$IFn$_invoke$arity$1$($start$jscomp$233$$):$grammar$$($start$jscomp$233$$)),function(){return function $instaparse$print$Parser__GT_str_$_iter__75697$$($s__75698$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$=$s__75698$$;;)if($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$=$APP.$cljs$core$seq$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$)){var $JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$=
$APP.$cljs$core$_chunked_first$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$),$size__5502__auto__$jscomp$39$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$),$b__75700_non_terminal$jscomp$2$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$39$$);a:{for(var $i__75699$jscomp$inline_8594$$=0;;)if($i__75699$jscomp$inline_8594$$<$size__5502__auto__$jscomp$39$$){var $b$jscomp$inline_13394_vec__75701$jscomp$inline_8595$$=
$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$,$i__75699$jscomp$inline_8594$$),$non_terminal$jscomp$inline_8596_x$jscomp$inline_13395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13394_vec__75701$jscomp$inline_8595$$,0,null),$parser$jscomp$inline_8597$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13394_vec__75701$jscomp$inline_8595$$,1,null);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($non_terminal$jscomp$inline_8596_x$jscomp$inline_13395$$,
$start$jscomp$233$$)&&($b$jscomp$inline_13394_vec__75701$jscomp$inline_8595$$=$b__75700_non_terminal$jscomp$2$$,$non_terminal$jscomp$inline_8596_x$jscomp$inline_13395$$=$instaparse$print$rule__GT_str$$($non_terminal$jscomp$inline_8596_x$jscomp$inline_13395$$,$parser$jscomp$inline_8597$$),$b$jscomp$inline_13394_vec__75701$jscomp$inline_8595$$.add($non_terminal$jscomp$inline_8596_x$jscomp$inline_13395$$));$i__75699$jscomp$inline_8594$$+=1}else{$JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$=
!0;break a}$JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$=void 0}return $JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75700_non_terminal$jscomp$2$$),$instaparse$print$Parser__GT_str_$_iter__75697$$($APP.$cljs$core$_chunked_rest$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75700_non_terminal$jscomp$2$$),
null)}$JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$=$APP.$cljs$core$first$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$);$b__75700_non_terminal$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$,0,null);$JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$,
1,null);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b__75700_non_terminal$jscomp$2$$,$start$jscomp$233$$))return $APP.$cljs$core$cons$$($instaparse$print$rule__GT_str$$($b__75700_non_terminal$jscomp$2$$,$JSCompiler_inline_result$jscomp$1722_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__75704$$),$instaparse$print$Parser__GT_str_$_iter__75697$$($APP.$cljs$core$rest$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$)));$s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$=
$APP.$cljs$core$rest$$($s__75698__$1_s__75698__$2_temp__5825__auto__$jscomp$331$$)}else return null},null,null)}($grammar$$)}()))};
$instaparse$failure$print_reason$$=function($r$jscomp$123$$){$APP.$cljs$core$truth_$$($cljs$cst$5449$NOT$$.$cljs$core$IFn$_invoke$arity$1$($r$jscomp$123$$))?($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["NOT "])),$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5449$NOT$$.$cljs$core$IFn$_invoke$arity$1$($r$jscomp$123$$)]))):$APP.$cljs$core$truth_$$($cljs$cst$5450$char_range$$.$cljs$core$IFn$_invoke$arity$1$($r$jscomp$123$$))?
$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$print$char_range__GT_str$$($r$jscomp$123$$)])):$r$jscomp$123$$ instanceof RegExp?$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$print$regexp__GT_str$$($r$jscomp$123$$)])):$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$r$jscomp$123$$]))};
$instaparse$failure$pprint_failure$$=function($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$){$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=$APP.$cljs$core$__destructure_map$$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$);var $G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$,$APP.$cljs$cst$209$line$$),$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$,
$APP.$cljs$cst$216$column$$),$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$,$APP.$cljs$cst$1588$text$$);$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$,
$APP.$cljs$cst$984$reason$$);$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["Parse error at line ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),", column ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),
":"].join("")]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$]));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$)?$APP.$cljs$core$integer_QMARK_$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$):
$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$)?($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=$APP.$clojure$string$replace$$($G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$,/[^\s]/," "),$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$<=
1?"^":[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$,0,$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$-1),"^"].join("")):$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=
null;$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$]));$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5451$expecting$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1273$full$$,$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$)));$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5451$expecting$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$($APP.$cljs$cst$1273$full$$),
$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$)));$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=$APP.$cljs$core$count$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$)+$APP.$cljs$core$count$$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$);
$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$!==0&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$)?$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Expected:"])):$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Expected one of:"])));
$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$APP.$cljs$core$seq$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$);$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=
null;for(var $G__75761_i__75728_75752_i__75734$$=$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=0;;)if($G__75761_i__75728_75752_i__75734$$<$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$){var $r_75753$$=$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__75761_i__75728_75752_i__75734$$);$instaparse$failure$print_reason$$($r_75753$$);
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" (followed by end-of-string)"]));$G__75761_i__75728_75752_i__75734$$+=1}else if($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$APP.$cljs$core$seq$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$))$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=
$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$)?($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=
$APP.$cljs$core$_chunked_first$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),$G__75761_i__75728_75752_i__75734$$=$APP.$cljs$core$_chunked_rest$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=
$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$,$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=$APP.$cljs$core$count$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=
$G__75761_i__75728_75752_i__75734$$):($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$APP.$cljs$core$first$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),$instaparse$failure$print_reason$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" (followed by end-of-string)"])),$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$APP.$cljs$core$next$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),
$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=null,$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=0),$G__75761_i__75728_75752_i__75734$$=0;else break;$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$);
$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=null;for($G__75761_i__75728_75752_i__75734$$=$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=0;;)if($G__75761_i__75728_75752_i__75734$$<$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$)$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=
$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__75761_i__75728_75752_i__75734$$),$instaparse$failure$print_reason$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),$APP.$cljs$core$println$$(),$G__75761_i__75728_75752_i__75734$$+=1;else if($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=
$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$))$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$)?
($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=$APP.$cljs$core$_chunked_first$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=$APP.$cljs$core$_chunked_rest$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),
$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$,$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$),
$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$,$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=$G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$):($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$=
$APP.$cljs$core$first$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),$instaparse$failure$print_reason$$($G__75762_G__75776_chunk__75726_75750_line$jscomp$28_marker_text$jscomp$inline_13399_r$jscomp$124_seq__75725_75759__$1_total$jscomp$21$$),$APP.$cljs$core$println$$(),$c__5548__auto__$jscomp$37_map__75724__$1_p__75723_partial_reasons_reason$jscomp$26_seq__75731_temp__5825__auto__$jscomp$332$$=
$APP.$cljs$core$next$$($G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$),$G__75775_JSCompiler_inline_result$jscomp$11014_c__5548__auto___75760_chunk__75732_column$jscomp$38_full_reasons_r_75765_seq__75725_75749_seq__75731__$1_temp__5825__auto___75758$$=null,$G__75763_G__75774_count__75727_75751_count__75733_text$jscomp$81$$=0),$G__75761_i__75728_75752_i__75734$$=0;else break};
$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($message$jscomp$115$$){throw $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$message$jscomp$115$$);};$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($message$jscomp$116$$){throw $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$message$jscomp$116$$);};
$instaparse$util$regexp_flags$$=function($re$jscomp$23$$){var $G__75784__$1_G__75784__$2$$=$APP.$cljs$core$truth_$$($re$jscomp$23$$.ignoreCase)?"i":"";$G__75784__$1_G__75784__$2$$=$APP.$cljs$core$truth_$$($re$jscomp$23$$.multiline)?[$G__75784__$1_G__75784__$2$$,"m"].join(""):$G__75784__$1_G__75784__$2$$;return $APP.$cljs$core$truth_$$($re$jscomp$23$$.unicode)?[$G__75784__$1_G__75784__$2$$,"u"].join(""):$G__75784__$1_G__75784__$2$$};
$instaparse$reduction$singleton_QMARK_$$=function($s$jscomp$565$$){return $APP.$cljs$core$seq$$($s$jscomp$565$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$next$$($s$jscomp$565$$))};
$instaparse$reduction$apply_reduction$$=function($f$jscomp$853$$,$content$jscomp$243_result$jscomp$344$$){var $G__75792$$=$cljs$cst$5445$reduction_type$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$853$$);switch($G__75792$$ instanceof $APP.$cljs$core$Keyword$$?$G__75792$$.$fqn$:null){case "raw":return $instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$content$jscomp$243_result$jscomp$344$$);case "hiccup":return $instaparse$auto_flatten_seq$convert_afs_to_vec$$($instaparse$auto_flatten_seq$auto_flatten_seq$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$853$$)],null)).$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$content$jscomp$243_result$jscomp$344$$));case "enlive":return $content$jscomp$243_result$jscomp$344$$=$instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$content$jscomp$243_result$jscomp$344$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$853$$),$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$count$$($content$jscomp$243_result$jscomp$344$$)===0?null:$content$jscomp$243_result$jscomp$344$$],null);default:return $f$jscomp$853$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$853$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$243_result$jscomp$344$$):$f$jscomp$853$$($content$jscomp$243_result$jscomp$344$$)}};
$instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$=function($reduction_type$$,$grammar$jscomp$2$$){var $temp__5823__auto__$jscomp$219$$=$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$($reduction_type$$):$instaparse$reduction$reduction_types$$($reduction_type$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$219$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function(){return function $instaparse$reduction$iter__75795$$($s__75796$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__75796__$2_temp__5825__auto__$jscomp$333$$=$APP.$cljs$core$seq$$($s__75796$$);if($s__75796__$2_temp__5825__auto__$jscomp$333$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75796__$2_temp__5825__auto__$jscomp$333$$)){var $JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$=$APP.$cljs$core$_chunked_first$$($s__75796__$2_temp__5825__auto__$jscomp$333$$),
$size__5502__auto__$jscomp$40$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$),$b__75798_k$jscomp$673$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$40$$);a:{for(var $i__75797$jscomp$inline_8599$$=0;;)if($i__75797$jscomp$inline_8599$$<$size__5502__auto__$jscomp$40$$){var $b$jscomp$inline_13401_vec__75799$jscomp$inline_8600$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$,
$i__75797$jscomp$inline_8599$$),$k$jscomp$inline_8601_x$jscomp$inline_13402$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13401_vec__75799$jscomp$inline_8600$$,0,null),$v$jscomp$inline_8602$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13401_vec__75799$jscomp$inline_8600$$,1,null);$b$jscomp$inline_13401_vec__75799$jscomp$inline_8600$$=$b__75798_k$jscomp$673$$;$k$jscomp$inline_8601_x$jscomp$inline_13402$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$inline_8602$$))?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8601_x$jscomp$inline_13402$$,$v$jscomp$inline_8602$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8601_x$jscomp$inline_13402$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$inline_8602$$,$APP.$cljs$cst$5446$red$$,$temp__5823__auto__$jscomp$219$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$219$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8601_x$jscomp$inline_13402$$):
$temp__5823__auto__$jscomp$219$$($k$jscomp$inline_8601_x$jscomp$inline_13402$$))],null);$b$jscomp$inline_13401_vec__75799$jscomp$inline_8600$$.add($k$jscomp$inline_8601_x$jscomp$inline_13402$$);$i__75797$jscomp$inline_8599$$+=1}else{$JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$=!0;break a}$JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$=void 0}return $JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75798_k$jscomp$673$$),$instaparse$reduction$iter__75795$$($APP.$cljs$core$_chunked_rest$$($s__75796__$2_temp__5825__auto__$jscomp$333$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75798_k$jscomp$673$$),null)}$JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$=$APP.$cljs$core$first$$($s__75796__$2_temp__5825__auto__$jscomp$333$$);$b__75798_k$jscomp$673$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$,
0,null);$JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$,1,null);return $APP.$cljs$core$cons$$($APP.$cljs$core$truth_$$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$))?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__75798_k$jscomp$673$$,$JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__75798_k$jscomp$673$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1724_c__5501__auto__$jscomp$40_v$jscomp$647_vec__75802$$,$APP.$cljs$cst$5446$red$$,$temp__5823__auto__$jscomp$219$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$219$$.$cljs$core$IFn$_invoke$arity$1$($b__75798_k$jscomp$673$$):$temp__5823__auto__$jscomp$219$$($b__75798_k$jscomp$673$$))],null),$instaparse$reduction$iter__75795$$($APP.$cljs$core$rest$$($s__75796__$2_temp__5825__auto__$jscomp$333$$)))}return null}},null,null)}($grammar$jscomp$2$$)}()):$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid output format ",$reduction_type$$,
". Use :enlive or :hiccup."]))};$instaparse$combinators_source$opt$$=function($parser$jscomp$22$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$22$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$22$$],null)};
$instaparse$combinators_source$plus$$=function($parser$jscomp$23$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$23$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$23$$],null)};
$instaparse$combinators_source$star$$=function($parser$jscomp$24$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$24$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5456$star$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$24$$],null)};
$instaparse$combinators_source$rep$$=function($m$jscomp$222$$,$n$jscomp$299$$,$parser$jscomp$25$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$25$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5457$rep$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$25$$,$APP.$cljs$cst$338$min$$,$m$jscomp$222$$,$APP.$cljs$cst$339$max$$,$n$jscomp$299$$],null)};
$instaparse$combinators_source$string$$=function($s$jscomp$566$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$566$$,"")?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,$s$jscomp$566$$],null)};
$instaparse$combinators_source$string_ci$$=function($s$jscomp$567$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$567$$,"")?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5458$string_ci$$,$APP.$cljs$cst$198$string$$,$s$jscomp$567$$],null)};
$instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$=function($lo$jscomp$6$$,$hi$jscomp$8$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,$cljs$cst$5439$lo$$,$lo$jscomp$6$$,$cljs$cst$5440$hi$$,$hi$jscomp$8$$],null)};
$instaparse$combinators_source$regexp$$=function($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$,"")?$JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$=$instaparse$combinators_source$Epsilon$$:($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$=
$APP.$cljs$core$re_pattern$$($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$),$JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$=$APP.$cljs$core$regexp_QMARK_$$($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$)?new RegExp(["^",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$.source)].join(""),
$instaparse$util$regexp_flags$$($JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$)):$JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$,$JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5444$regexp$$,$cljs$cst$5444$regexp$$,$JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$],
null));return $JSCompiler_inline_result$jscomp$1728_JSCompiler_temp$jscomp$1726_r$jscomp$126_r$jscomp$inline_8607$$};$instaparse$combinators_source$nt$$=function($s$jscomp$568$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$s$jscomp$568$$],null)};
$instaparse$combinators_source$look$$=function($parser$jscomp$26$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5461$look$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$26$$],null)};$instaparse$combinators_source$neg$$=function($parser$jscomp$27$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5462$neg$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$27$$],null)};
$instaparse$combinators_source$hide$$=function($parser$jscomp$28$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$28$$,$APP.$cljs$cst$2345$hide$$,!0)};$instaparse$combinators_source$hide_tag$$=function($parser$jscomp$29$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$29$$,$APP.$cljs$cst$5446$red$$,$instaparse$reduction$raw_non_terminal_reduction$$)};
$instaparse$combinators_source$unhide_all_content$$=function($grammar$jscomp$3$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $instaparse$combinators_source$unhide_all_content_$_iter__75836$$($s__75837$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__75837__$2_temp__5825__auto__$jscomp$334$$=$APP.$cljs$core$seq$$($s__75837$$);if($s__75837__$2_temp__5825__auto__$jscomp$334$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75837__$2_temp__5825__auto__$jscomp$334$$)){var $JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$=
$APP.$cljs$core$_chunked_first$$($s__75837__$2_temp__5825__auto__$jscomp$334$$),$size__5502__auto__$jscomp$41$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$),$b__75839_k$jscomp$675$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$41$$);a:{for(var $i__75838$jscomp$inline_8609$$=0;;)if($i__75838$jscomp$inline_8609$$<$size__5502__auto__$jscomp$41$$){var $b$jscomp$inline_13404_vec__75841$jscomp$inline_8610$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$,
$i__75838$jscomp$inline_8609$$),$k$jscomp$inline_8611_x$jscomp$inline_13405$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13404_vec__75841$jscomp$inline_8610$$,0,null),$v$jscomp$inline_8612$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13404_vec__75841$jscomp$inline_8610$$,1,null);$b$jscomp$inline_13404_vec__75841$jscomp$inline_8610$$=$b__75839_k$jscomp$675$$;$k$jscomp$inline_8611_x$jscomp$inline_13405$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8611_x$jscomp$inline_13405$$,$instaparse$combinators_source$unhide_content$$($v$jscomp$inline_8612$$)],null);$b$jscomp$inline_13404_vec__75841$jscomp$inline_8610$$.add($k$jscomp$inline_8611_x$jscomp$inline_13405$$);$i__75838$jscomp$inline_8609$$+=1}else{$JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$=!0;break a}$JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$=
void 0}return $JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75839_k$jscomp$675$$),$instaparse$combinators_source$unhide_all_content_$_iter__75836$$($APP.$cljs$core$_chunked_rest$$($s__75837__$2_temp__5825__auto__$jscomp$334$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75839_k$jscomp$675$$),null)}$JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$=
$APP.$cljs$core$first$$($s__75837__$2_temp__5825__auto__$jscomp$334$$);$b__75839_k$jscomp$675$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$,0,null);$JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__75839_k$jscomp$675$$,$instaparse$combinators_source$unhide_content$$($JSCompiler_inline_result$jscomp$1729_c__5501__auto__$jscomp$41_v$jscomp$649_vec__75845$$)],null),$instaparse$combinators_source$unhide_all_content_$_iter__75836$$($APP.$cljs$core$rest$$($s__75837__$2_temp__5825__auto__$jscomp$334$$)))}return null}},null,null)}($grammar$jscomp$3$$)}())};
$instaparse$combinators_source$unhide_tags$$=function($reduction_type$jscomp$1$$,$grammar$jscomp$4$$){var $temp__5823__auto__$jscomp$220$$=$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$($reduction_type$jscomp$1$$):$instaparse$reduction$reduction_types$$($reduction_type$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$220$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function(){return function $instaparse$combinators_source$unhide_tags_$_iter__75848$$($s__75849$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__75849__$2_temp__5825__auto__$jscomp$335$$=$APP.$cljs$core$seq$$($s__75849$$);if($s__75849__$2_temp__5825__auto__$jscomp$335$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75849__$2_temp__5825__auto__$jscomp$335$$)){var $JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$=$APP.$cljs$core$_chunked_first$$($s__75849__$2_temp__5825__auto__$jscomp$335$$),
$size__5502__auto__$jscomp$42$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$),$b__75851_k$jscomp$677$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$42$$);a:{for(var $i__75850$jscomp$inline_8614$$=0;;)if($i__75850$jscomp$inline_8614$$<$size__5502__auto__$jscomp$42$$){var $b$jscomp$inline_13407_vec__75852$jscomp$inline_8615$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$,
$i__75850$jscomp$inline_8614$$),$k$jscomp$inline_8616_x$jscomp$inline_13408$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13407_vec__75852$jscomp$inline_8615$$,0,null),$v$jscomp$inline_8617$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13407_vec__75852$jscomp$inline_8615$$,1,null);$b$jscomp$inline_13407_vec__75852$jscomp$inline_8615$$=$b__75851_k$jscomp$677$$;$k$jscomp$inline_8616_x$jscomp$inline_13408$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8616_x$jscomp$inline_13408$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$inline_8617$$,$APP.$cljs$cst$5446$red$$,$temp__5823__auto__$jscomp$220$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$220$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8616_x$jscomp$inline_13408$$):$temp__5823__auto__$jscomp$220$$($k$jscomp$inline_8616_x$jscomp$inline_13408$$))],null);$b$jscomp$inline_13407_vec__75852$jscomp$inline_8615$$.add($k$jscomp$inline_8616_x$jscomp$inline_13408$$);
$i__75850$jscomp$inline_8614$$+=1}else{$JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$=!0;break a}$JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$=void 0}return $JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75851_k$jscomp$677$$),$instaparse$combinators_source$unhide_tags_$_iter__75848$$($APP.$cljs$core$_chunked_rest$$($s__75849__$2_temp__5825__auto__$jscomp$335$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75851_k$jscomp$677$$),null)}$JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$=$APP.$cljs$core$first$$($s__75849__$2_temp__5825__auto__$jscomp$335$$);$b__75851_k$jscomp$677$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$,0,null);$JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__75851_k$jscomp$677$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1730_c__5501__auto__$jscomp$42_v$jscomp$651_vec__75855$$,$APP.$cljs$cst$5446$red$$,$temp__5823__auto__$jscomp$220$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$220$$.$cljs$core$IFn$_invoke$arity$1$($b__75851_k$jscomp$677$$):$temp__5823__auto__$jscomp$220$$($b__75851_k$jscomp$677$$))],null),$instaparse$combinators_source$unhide_tags_$_iter__75848$$($APP.$cljs$core$rest$$($s__75849__$2_temp__5825__auto__$jscomp$335$$)))}return null}},null,null)}($grammar$jscomp$4$$)}()):$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid output format ",
$reduction_type$jscomp$1$$,". Use :enlive or :hiccup."]))};
$instaparse$combinators_source$unhide_all$$=function($reduction_type$jscomp$2$$,$grammar$jscomp$5$$){var $temp__5823__auto__$jscomp$221$$=$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$($reduction_type$jscomp$2$$):$instaparse$reduction$reduction_types$$($reduction_type$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$221$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function(){return function $instaparse$combinators_source$unhide_all_$_iter__75858$$($s__75859$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__75859__$2_temp__5825__auto__$jscomp$336$$=$APP.$cljs$core$seq$$($s__75859$$);if($s__75859__$2_temp__5825__auto__$jscomp$336$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75859__$2_temp__5825__auto__$jscomp$336$$)){var $JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$=$APP.$cljs$core$_chunked_first$$($s__75859__$2_temp__5825__auto__$jscomp$336$$),
$size__5502__auto__$jscomp$43$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$),$b__75861_k$jscomp$679$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$43$$);a:{for(var $i__75860$jscomp$inline_8619$$=0;;)if($i__75860$jscomp$inline_8619$$<$size__5502__auto__$jscomp$43$$){var $b$jscomp$inline_13410_vec__75862$jscomp$inline_8620$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$,
$i__75860$jscomp$inline_8619$$),$k$jscomp$inline_8621_x$jscomp$inline_13411$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13410_vec__75862$jscomp$inline_8620$$,0,null),$v$jscomp$inline_8622$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13410_vec__75862$jscomp$inline_8620$$,1,null);$b$jscomp$inline_13410_vec__75862$jscomp$inline_8620$$=$b__75861_k$jscomp$679$$;$k$jscomp$inline_8621_x$jscomp$inline_13411$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8621_x$jscomp$inline_13411$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$unhide_content$$($v$jscomp$inline_8622$$),$APP.$cljs$cst$5446$red$$,$temp__5823__auto__$jscomp$221$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$221$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8621_x$jscomp$inline_13411$$):$temp__5823__auto__$jscomp$221$$($k$jscomp$inline_8621_x$jscomp$inline_13411$$))],
null);$b$jscomp$inline_13410_vec__75862$jscomp$inline_8620$$.add($k$jscomp$inline_8621_x$jscomp$inline_13411$$);$i__75860$jscomp$inline_8619$$+=1}else{$JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$=!0;break a}$JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$=void 0}return $JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75861_k$jscomp$679$$),
$instaparse$combinators_source$unhide_all_$_iter__75858$$($APP.$cljs$core$_chunked_rest$$($s__75859__$2_temp__5825__auto__$jscomp$336$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75861_k$jscomp$679$$),null)}$JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$=$APP.$cljs$core$first$$($s__75859__$2_temp__5825__auto__$jscomp$336$$);$b__75861_k$jscomp$679$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$,
0,null);$JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__75861_k$jscomp$679$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$unhide_content$$($JSCompiler_inline_result$jscomp$1731_c__5501__auto__$jscomp$43_v$jscomp$653_vec__75865$$),
$APP.$cljs$cst$5446$red$$,$temp__5823__auto__$jscomp$221$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$221$$.$cljs$core$IFn$_invoke$arity$1$($b__75861_k$jscomp$679$$):$temp__5823__auto__$jscomp$221$$($b__75861_k$jscomp$679$$))],null),$instaparse$combinators_source$unhide_all_$_iter__75858$$($APP.$cljs$core$rest$$($s__75859__$2_temp__5825__auto__$jscomp$336$$)))}return null}},null,null)}($grammar$jscomp$5$$)}()):$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid output format ",
$reduction_type$jscomp$2$$,". Use :enlive or :hiccup."]))};
$instaparse$combinators_source$auto_whitespace$$=function($grammar$jscomp$6$$,$final_grammar_start$jscomp$234$$,$grammar_ws_grammar_ws__$1$$,$modified_grammar_start_ws$$){var $ws_parser$jscomp$1$$=$instaparse$combinators_source$hide$$($instaparse$combinators_source$opt$$($instaparse$combinators_source$nt$$($modified_grammar_start_ws$$)));$grammar_ws_grammar_ws__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($grammar_ws_grammar_ws__$1$$,$modified_grammar_start_ws$$,$instaparse$combinators_source$hide_tag$$($grammar_ws_grammar_ws__$1$$.$cljs$core$IFn$_invoke$arity$1$?
$grammar_ws_grammar_ws__$1$$.$cljs$core$IFn$_invoke$arity$1$($modified_grammar_start_ws$$):$grammar_ws_grammar_ws__$1$$($modified_grammar_start_ws$$)));$modified_grammar_start_ws$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $instaparse$combinators_source$auto_whitespace_$_iter__75874$$($s__75875$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__75875__$2_temp__5825__auto__$jscomp$337$$=$APP.$cljs$core$seq$$($s__75875$$);
if($s__75875__$2_temp__5825__auto__$jscomp$337$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75875__$2_temp__5825__auto__$jscomp$337$$)){var $JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$=$APP.$cljs$core$_chunked_first$$($s__75875__$2_temp__5825__auto__$jscomp$337$$),$size__5502__auto__$jscomp$44$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$),$b__75877_nt$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$44$$);
a:{for(var $i__75876$jscomp$inline_8624$$=0;;)if($i__75876$jscomp$inline_8624$$<$size__5502__auto__$jscomp$44$$){var $b$jscomp$inline_13413_vec__75878$jscomp$inline_8625$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$,$i__75876$jscomp$inline_8624$$),$nt$jscomp$inline_8626_x$jscomp$inline_13414$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13413_vec__75878$jscomp$inline_8625$$,0,null),$parser$jscomp$inline_8627$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13413_vec__75878$jscomp$inline_8625$$,1,null);$b$jscomp$inline_13413_vec__75878$jscomp$inline_8625$$=$b__75877_nt$$;$nt$jscomp$inline_8626_x$jscomp$inline_13414$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$nt$jscomp$inline_8626_x$jscomp$inline_13414$$,$instaparse$combinators_source$auto_whitespace_parser$$($parser$jscomp$inline_8627$$,$ws_parser$jscomp$1$$)],null);$b$jscomp$inline_13413_vec__75878$jscomp$inline_8625$$.add($nt$jscomp$inline_8626_x$jscomp$inline_13414$$);
$i__75876$jscomp$inline_8624$$+=1}else{$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$=!0;break a}$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$=void 0}return $JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75877_nt$$),$instaparse$combinators_source$auto_whitespace_$_iter__75874$$($APP.$cljs$core$_chunked_rest$$($s__75875__$2_temp__5825__auto__$jscomp$337$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75877_nt$$),null)}$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$=$APP.$cljs$core$first$$($s__75875__$2_temp__5825__auto__$jscomp$337$$);$b__75877_nt$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$,0,null);$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__75877_nt$$,$instaparse$combinators_source$auto_whitespace_parser$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__75881$$,$ws_parser$jscomp$1$$)],null),$instaparse$combinators_source$auto_whitespace_$_iter__75874$$($APP.$cljs$core$rest$$($s__75875__$2_temp__5825__auto__$jscomp$337$$)))}return null}},
null,null)}($grammar$jscomp$6$$)}());$final_grammar_start$jscomp$234$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($modified_grammar_start_ws$$,$final_grammar_start$jscomp$234$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$?
$modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$($final_grammar_start$jscomp$234$$):$modified_grammar_start_ws$$($final_grammar_start$jscomp$234$$),$APP.$cljs$cst$5446$red$$),$ws_parser$jscomp$1$$])),$APP.$cljs$cst$5446$red$$,$APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$?$modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$($final_grammar_start$jscomp$234$$):$modified_grammar_start_ws$$($final_grammar_start$jscomp$234$$))));
return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$final_grammar_start$jscomp$234$$,$grammar_ws_grammar_ws__$1$$]))};
$goog$i18n$uChar$fromCharCode$$=function($code$jscomp$58$$){if($code$jscomp$58$$==null||!($code$jscomp$58$$>=0&&$code$jscomp$58$$<=1114111))return null;if($code$jscomp$58$$>=65536&&$code$jscomp$58$$<=1114111){const $trailCodePoint$$=($code$jscomp$58$$&1023)+56320;return String.fromCharCode(($code$jscomp$58$$>>10)+55232)+String.fromCharCode($trailCodePoint$$)}return String.fromCharCode($code$jscomp$58$$)};
$goog$i18n$uChar$getCodePointAround$$=function($lead$jscomp$1_string$jscomp$21_trail$$,$index$jscomp$413$$){const $charCode$jscomp$1$$=$lead$jscomp$1_string$jscomp$21_trail$$.charCodeAt($index$jscomp$413$$);if($charCode$jscomp$1$$>=55296&&$charCode$jscomp$1$$<=56319&&$index$jscomp$413$$+1<$lead$jscomp$1_string$jscomp$21_trail$$.length){if($lead$jscomp$1_string$jscomp$21_trail$$=$lead$jscomp$1_string$jscomp$21_trail$$.charCodeAt($index$jscomp$413$$+1),$lead$jscomp$1_string$jscomp$21_trail$$>=56320&&
$lead$jscomp$1_string$jscomp$21_trail$$<=57343)return $charCode$jscomp$1$$>=55296&&$charCode$jscomp$1$$<=56319&&$lead$jscomp$1_string$jscomp$21_trail$$>=56320&&$lead$jscomp$1_string$jscomp$21_trail$$<=57343?($charCode$jscomp$1$$<<10)-56623104+($lead$jscomp$1_string$jscomp$21_trail$$-56320+65536):null}else if($charCode$jscomp$1$$>=56320&&$charCode$jscomp$1$$<=57343&&$index$jscomp$413$$>0&&($lead$jscomp$1_string$jscomp$21_trail$$=$lead$jscomp$1_string$jscomp$21_trail$$.charCodeAt($index$jscomp$413$$-
1),$lead$jscomp$1_string$jscomp$21_trail$$>=55296&&$lead$jscomp$1_string$jscomp$21_trail$$<=56319))return-($lead$jscomp$1_string$jscomp$21_trail$$>=55296&&$lead$jscomp$1_string$jscomp$21_trail$$<=56319&&$charCode$jscomp$1$$>=56320&&$charCode$jscomp$1$$<=57343?($lead$jscomp$1_string$jscomp$21_trail$$<<10)-56623104+($charCode$jscomp$1$$-56320+65536):0);return $charCode$jscomp$1$$};
$instaparse$gll$_parse$$=function($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$){var $G__76704_G__76704__$1$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$35$$);$G__76704_G__76704__$1$$=$G__76704_G__76704__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76704_G__76704__$1$$.$fqn$:null;switch($G__76704_G__76704__$1$$){case "nt":return $instaparse$gll$non_terminal_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$non_terminal_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,
$index$jscomp$414$$,$tramp$$):$instaparse$gll$non_terminal_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "alt":return $instaparse$gll$alt_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$alt_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$alt_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "cat":return $instaparse$gll$cat_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$cat_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,
$index$jscomp$414$$,$tramp$$):$instaparse$gll$cat_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "string":return $instaparse$gll$string_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$string_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "string-ci":return $instaparse$gll$string_case_insensitive_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_case_insensitive_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,
$index$jscomp$414$$,$tramp$$):$instaparse$gll$string_case_insensitive_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "char":return $instaparse$gll$char_range_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$char_range_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$char_range_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "epsilon":return $instaparse$gll$epsilon_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$epsilon_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$epsilon_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "opt":return $instaparse$gll$opt_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$opt_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$opt_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "plus":return $instaparse$gll$plus_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$plus_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$plus_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "rep":return $instaparse$gll$rep_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$rep_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$rep_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "star":return $instaparse$gll$star_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$star_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$star_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "regexp":return $instaparse$gll$regexp_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$regexp_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$regexp_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "look":return $instaparse$gll$lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$lookahead_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);case "neg":return $instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$negative_lookahead_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,
$tramp$$);case "ord":return $instaparse$gll$ordered_alt_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$ordered_alt_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$):$instaparse$gll$ordered_alt_parse$$($parser$jscomp$35$$,$index$jscomp$414$$,$tramp$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76704_G__76704__$1$$)].join(""));}};
$instaparse$gll$_full_parse$$=function($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$){var $G__76710_G__76710__$1$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$36$$);$G__76710_G__76710__$1$$=$G__76710_G__76710__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76710_G__76710__$1$$.$fqn$:null;switch($G__76710_G__76710__$1$$){case "nt":return $instaparse$gll$non_terminal_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$non_terminal_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,
$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$non_terminal_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "alt":return $instaparse$gll$alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$alt_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "cat":return $instaparse$gll$cat_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$cat_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$cat_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "string":return $instaparse$gll$string_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$string_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,
$tramp$jscomp$1$$);case "string-ci":return $instaparse$gll$string_case_insensitive_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_case_insensitive_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$string_case_insensitive_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "char":return $instaparse$gll$char_range_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$char_range_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,
$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$char_range_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "epsilon":return $instaparse$gll$epsilon_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$epsilon_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$epsilon_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "opt":return $instaparse$gll$opt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$opt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$opt_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "plus":return $instaparse$gll$plus_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$plus_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$plus_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);
case "rep":return $instaparse$gll$rep_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$rep_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$rep_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "star":return $instaparse$gll$star_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$star_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):
$instaparse$gll$star_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "regexp":return $instaparse$gll$regexp_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$regexp_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$regexp_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "look":return $instaparse$gll$lookahead_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$lookahead_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,
$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$lookahead_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "neg":return $instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$negative_lookahead_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);case "ord":return $instaparse$gll$ordered_alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$ordered_alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$):$instaparse$gll$ordered_alt_full_parse$$($parser$jscomp$36$$,$index$jscomp$415$$,$tramp$jscomp$1$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76710_G__76710__$1$$)].join(""));}};
$instaparse$gll$Failure$$=function($index$jscomp$416$$,$reason$jscomp$27$$,$__meta$jscomp$35$$,$__extmap$jscomp$35$$,$__hash$jscomp$94$$){this.index=$index$jscomp$416$$;this.reason=$reason$jscomp$27$$;this.$__meta$=$__meta$jscomp$35$$;this.$__extmap$=$__extmap$jscomp$35$$;this.$__hash$=$__hash$jscomp$94$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$instaparse$gll$Tramp$$=function($grammar$jscomp$8$$,$text$jscomp$85$$,$segment$jscomp$46$$,$fail_index$$,$node_builder$$,$stack$jscomp$34$$,$next_stack$jscomp$2$$,$generation$$,$negative_listeners$$,$msg_cache$$,$nodes$jscomp$37$$,$success$jscomp$7$$,$failure$jscomp$1$$,$trace_QMARK_$$,$__meta$jscomp$36$$,$__extmap$jscomp$36$$,$__hash$jscomp$95$$){this.$grammar$=$grammar$jscomp$8$$;this.text=$text$jscomp$85$$;this.segment=$segment$jscomp$46$$;this.$fail_index$=$fail_index$$;this.$node_builder$=$node_builder$$;
this.stack=$stack$jscomp$34$$;this.$next_stack$=$next_stack$jscomp$2$$;this.$generation$=$generation$$;this.$negative_listeners$=$negative_listeners$$;this.$msg_cache$=$msg_cache$$;this.$nodes$=$nodes$jscomp$37$$;this.$success$=$success$jscomp$7$$;this.$failure$=$failure$jscomp$1$$;this.$trace_QMARK_$=$trace_QMARK_$$;this.$__meta$=$__meta$jscomp$36$$;this.$__extmap$=$__extmap$jscomp$36$$;this.$__hash$=$__hash$jscomp$95$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$=function($grammar$jscomp$13$$,$text$jscomp$90$$,$segment$jscomp$49$$,$fail_index$jscomp$3$$,$node_builder$jscomp$3$$){return new $instaparse$gll$Tramp$$($grammar$jscomp$13$$,$text$jscomp$90$$,$segment$jscomp$49$$,$fail_index$jscomp$3$$,$node_builder$jscomp$3$$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0),
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$sorted_map_by$$($APP.$cljs$core$_GT_$$)),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $instaparse$gll$Failure$$(0,$APP.$cljs$core$PersistentVector$EMPTY$$,
null,null,null)),!1,null,null,null)};$instaparse$gll$make_success$$=function($result$jscomp$345$$,$index$jscomp$418$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$828$result$$,$result$jscomp$345$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$418$$],null)};
$instaparse$gll$total_success_QMARK_$$=function($tramp$jscomp$2$$,$s$jscomp$569$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$2$$)),$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$569$$))};
$instaparse$gll$Node$$=function($listeners$jscomp$1$$,$full_listeners$$,$results$jscomp$2$$,$full_results$$,$__meta$jscomp$37$$,$__extmap$jscomp$37$$,$__hash$jscomp$96$$){this.$listeners$=$listeners$jscomp$1$$;this.$full_listeners$=$full_listeners$$;this.results=$results$jscomp$2$$;this.$full_results$=$full_results$$;this.$__meta$=$__meta$jscomp$37$$;this.$__extmap$=$__extmap$jscomp$37$$;this.$__hash$=$__hash$jscomp$96$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};$instaparse$gll$push_stack$$=function($tramp$jscomp$3$$,$item$jscomp$121$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$3685$stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$3$$),$APP.$cljs$core$conj$$,$item$jscomp$121$$)};
$instaparse$gll$push_message$$=function($tramp$jscomp$4$$,$listener$jscomp$103$$,$result$jscomp$346$$){function $f$jscomp$854$$(){return $listener$jscomp$103$$.$cljs$core$IFn$_invoke$arity$1$?$listener$jscomp$103$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$346$$):$listener$jscomp$103$$($result$jscomp$346$$)}var $cache$jscomp$106$$=$cljs$cst$5469$msg_cache$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$),$i$jscomp$519_k$jscomp$681$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$346$$);
$i$jscomp$519_k$jscomp$681$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$listener$jscomp$103$$,$i$jscomp$519_k$jscomp$681$$],null);var $c$jscomp$303$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($cache$jscomp$106$$),$i$jscomp$519_k$jscomp$681$$,0);$c$jscomp$303$$>$APP.$cljs$core$deref$$($cljs$cst$5467$generation$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$5466$next_stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$),
$APP.$cljs$core$conj$$,$f$jscomp$854$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$3685$stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$),$APP.$cljs$core$conj$$,$f$jscomp$854$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cache$jscomp$106$$,$APP.$cljs$core$assoc$$,$i$jscomp$519_k$jscomp$681$$,$c$jscomp$303$$+1)};
$instaparse$gll$listener_exists_QMARK_$$=function($fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$,$node_key_temp__5825__auto__$jscomp$338$$){$fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$=$cljs$cst$5470$nodes$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$);$fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$=$APP.$cljs$core$_deref$$($fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$);
$node_key_temp__5825__auto__$jscomp$338$$=$fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($node_key_temp__5825__auto__$jscomp$338$$):$fexpr__76774$jscomp$inline_8629_nodes$jscomp$39_tramp$jscomp$5$$($node_key_temp__5825__auto__$jscomp$338$$);return $APP.$cljs$core$truth_$$($node_key_temp__5825__auto__$jscomp$338$$)?$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5483$listeners$$.$cljs$core$IFn$_invoke$arity$1$($node_key_temp__5825__auto__$jscomp$338$$)))>
0:null};
$instaparse$gll$full_listener_exists_QMARK_$$=function($fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$,$node_key$jscomp$1_temp__5825__auto__$jscomp$339$$){$fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$=$cljs$cst$5470$nodes$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$);$fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$=$APP.$cljs$core$_deref$$($fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$);$node_key$jscomp$1_temp__5825__auto__$jscomp$339$$=
$fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$1_temp__5825__auto__$jscomp$339$$):$fexpr__76775$jscomp$inline_8631_nodes$jscomp$40_tramp$jscomp$6$$($node_key$jscomp$1_temp__5825__auto__$jscomp$339$$);return $APP.$cljs$core$truth_$$($node_key$jscomp$1_temp__5825__auto__$jscomp$339$$)?$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5484$full_listeners$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$1_temp__5825__auto__$jscomp$339$$)))>
0||$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5483$listeners$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$1_temp__5825__auto__$jscomp$339$$)))>0:null};
$instaparse$gll$result_exists_QMARK_$$=function($fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$,$node_key$jscomp$2_temp__5825__auto__$jscomp$340$$){$fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$=$cljs$cst$5470$nodes$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$);$fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$=$APP.$cljs$core$_deref$$($fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$);
$node_key$jscomp$2_temp__5825__auto__$jscomp$340$$=$fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$2_temp__5825__auto__$jscomp$340$$):$fexpr__76776$jscomp$inline_8633_nodes$jscomp$41_tramp$jscomp$7$$($node_key$jscomp$2_temp__5825__auto__$jscomp$340$$);return $APP.$cljs$core$truth_$$($node_key$jscomp$2_temp__5825__auto__$jscomp$340$$)?
$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5486$full_results$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$2_temp__5825__auto__$jscomp$340$$)))>0||$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5485$results$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$2_temp__5825__auto__$jscomp$340$$)))>0:null};
$instaparse$gll$node_get$$=function($nodes$jscomp$43_tramp$jscomp$9$$,$node_key$jscomp$4$$){$nodes$jscomp$43_tramp$jscomp$9$$=$cljs$cst$5470$nodes$$.$cljs$core$IFn$_invoke$arity$1$($nodes$jscomp$43_tramp$jscomp$9$$);var $fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$=$APP.$cljs$core$_deref$$($nodes$jscomp$43_tramp$jscomp$9$$);$fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$=$fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$4$$):$fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$($node_key$jscomp$4$$);$APP.$cljs$core$truth_$$($fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$)||($fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$=new $instaparse$gll$Node$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),null,null,null),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($nodes$jscomp$43_tramp$jscomp$9$$,$APP.$cljs$core$assoc$$,$node_key$jscomp$4$$,$fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$));
return $fexpr__76778$jscomp$inline_8635_node$jscomp$393_temp__5823__auto__$jscomp$222$$};
$instaparse$gll$safe_with_meta$$=function($obj$jscomp$215$$,$metamap$jscomp$2$$){return($obj$jscomp$215$$!=null?$obj$jscomp$215$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$215$$.$cljs$core$IWithMeta$$||($obj$jscomp$215$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$215$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$215$$))?$APP.$cljs$core$with_meta$$($obj$jscomp$215$$,
$metamap$jscomp$2$$):$obj$jscomp$215$$};
$instaparse$gll$push_result$$=function($tramp$jscomp$10$$,$node_key$jscomp$5$$,$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$){var $c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$=$instaparse$gll$node_get$$($tramp$jscomp$10$$,$node_key$jscomp$5$$),$parser$jscomp$37$$=$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$(1):$node_key$jscomp$5$$(1),$result__$1$jscomp$41$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$37$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$,$APP.$cljs$cst$828$result$$,null):$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$,$result__$2$jscomp$9$$=function(){var $temp__5823__auto__$jscomp$223$$=$APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$37$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$223$$)?$instaparse$gll$make_success$$($instaparse$gll$safe_with_meta$$($instaparse$reduction$apply_reduction$$($temp__5823__auto__$jscomp$223$$,
$APP.$cljs$cst$828$result$$.$cljs$core$IFn$_invoke$arity$1$($result__$1$jscomp$41$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$,$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$(0):$node_key$jscomp$5$$(0),$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($result__$1$jscomp$41$$)],null)),$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($result__$1$jscomp$41$$)):
$result__$1$jscomp$41$$}(),$results$jscomp$4$$=($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$=$instaparse$gll$total_success_QMARK_$$($tramp$jscomp$10$$,$result__$2$jscomp$9$$))?$cljs$cst$5486$full_results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$):$cljs$cst$5485$results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$);if($APP.$cljs$core$not$$(function(){var $fexpr__76780$$=
$APP.$cljs$core$_deref$$($results$jscomp$4$$);return $fexpr__76780$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__76780$$.$cljs$core$IFn$_invoke$arity$1$($result__$2$jscomp$9$$):$fexpr__76780$$($result__$2$jscomp$9$$)}())){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($results$jscomp$4$$,$APP.$cljs$core$conj$$,$result__$2$jscomp$9$$);for(var $G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5483$listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$))),
$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=null,$G__77003_count__76783_76991_i__76788$$=0,$G__77001_i__76784_76992$$=0;;)if($G__77001_i__76784_76992$$<$G__77003_count__76783_76991_i__76788$$){var $listener_76993$$=$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77001_i__76784_76992$$);$instaparse$gll$push_message$$($tramp$jscomp$10$$,$listener_76993$$,$result__$2$jscomp$9$$);$G__77001_i__76784_76992$$+=
1}else if($G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$seq$$($G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$))$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$)?
($G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$_chunked_first$$($G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$),$G__77001_i__76784_76992$$=$APP.$cljs$core$_chunked_rest$$($G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$),$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$,
$G__77003_count__76783_76991_i__76788$$=$APP.$cljs$core$count$$($G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$),$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$G__77001_i__76784_76992$$):($G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$first$$($G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$),
$instaparse$gll$push_message$$($tramp$jscomp$10$$,$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$,$result__$2$jscomp$9$$),$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$next$$($G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$),$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=null,$G__77003_count__76783_76991_i__76788$$=
0),$G__77001_i__76784_76992$$=0;else break;if($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$)for($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5484$full_listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$))),$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$=null,$G__77003_count__76783_76991_i__76788$$=
$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=0;;)if($G__77003_count__76783_76991_i__76788$$<$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$)$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77003_count__76783_76991_i__76788$$),$instaparse$gll$push_message$$($tramp$jscomp$10$$,
$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$,$result__$2$jscomp$9$$),$G__77003_count__76783_76991_i__76788$$+=1;else if($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$))$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$=$c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$)?($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$=$APP.$cljs$core$_chunked_first$$($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$),$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=$APP.$cljs$core$_chunked_rest$$($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$),$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$=
$c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$,$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$),$c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$=$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$,$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=
$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$):($G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$=$APP.$cljs$core$first$$($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$),$instaparse$gll$push_message$$($tramp$jscomp$10$$,$G__77020_c__5548__auto___77000_listener$jscomp$104_listener_77005_seq__76781_76989_temp__5825__auto___76998$$,$result__$2$jscomp$9$$),
$c__5548__auto__$jscomp$38_node$jscomp$394_seq__76785_temp__5825__auto__$jscomp$342$$=$APP.$cljs$core$next$$($G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$),$G__77019_chunk__76786_result$jscomp$347_seq__76785__$1_total_QMARK_$$=null,$G__77002_G__77018_chunk__76782_76990_count__76787_seq__76781_76999__$1$$=0),$G__77003_count__76783_76991_i__76788$$=0;else return null;else return null}else return null};
$instaparse$gll$push_listener$$=function($tramp$jscomp$11$$,$node_key$jscomp$6$$,$listener$jscomp$105$$){var $listener_already_exists_QMARK_$$=$instaparse$gll$listener_exists_QMARK_$$($tramp$jscomp$11$$,$node_key$jscomp$6$$),$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$instaparse$gll$node_get$$($tramp$jscomp$11$$,$node_key$jscomp$6$$),$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=
$cljs$cst$5483$listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$,$APP.$cljs$core$conj$$,$listener$jscomp$105$$);$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5485$results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$)));for(var $G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=null,$G__77045_G__77064_count__76791_77031_i__76796_77055$$=0,$G__77043_i__76792_77032_result_77056$$=0;;)if($G__77043_i__76792_77032_result_77056$$<$G__77045_G__77064_count__76791_77031_i__76796_77055$$){var $result_77035$$=
$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77043_i__76792_77032_result_77056$$);$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,$result_77035$$);$G__77043_i__76792_77032_result_77056$$+=1}else if($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=$APP.$cljs$core$seq$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$))$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=
$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$)?($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=$APP.$cljs$core$_chunked_first$$($G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$),
$G__77043_i__76792_77032_result_77056$$=$APP.$cljs$core$_chunked_rest$$($G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$),$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$,$G__77045_G__77064_count__76791_77031_i__76796_77055$$=$APP.$cljs$core$count$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$),
$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=$G__77043_i__76792_77032_result_77056$$):($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=$APP.$cljs$core$first$$($G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$),$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,
$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$),$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=$APP.$cljs$core$next$$($G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$),$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=null,$G__77045_G__77064_count__76791_77031_i__76796_77055$$=
0),$G__77043_i__76792_77032_result_77056$$=0;else break;$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5486$full_results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$)));$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=
null;for($G__77045_G__77064_count__76791_77031_i__76796_77055$$=$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=0;;)if($G__77045_G__77064_count__76791_77031_i__76796_77055$$<$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$)$G__77043_i__76792_77032_result_77056$$=$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__77045_G__77064_count__76791_77031_i__76796_77055$$),$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,$G__77043_i__76792_77032_result_77056$$),$G__77045_G__77064_count__76791_77031_i__76796_77055$$+=1;else if($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$APP.$cljs$core$seq$$($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$))$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=
$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$)?($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$APP.$cljs$core$_chunked_first$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$),
$G__77045_G__77064_count__76791_77031_i__76796_77055$$=$APP.$cljs$core$_chunked_rest$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$),$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$,$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=
$APP.$cljs$core$count$$($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$),$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$G__77045_G__77064_count__76791_77031_i__76796_77055$$):($c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$APP.$cljs$core$first$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$),
$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$),$c__5548__auto___77063_node$jscomp$395_result_77069_seq__76793_77052_temp__5825__auto___77061$$=$APP.$cljs$core$next$$($G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$),$G__77065_c__5548__auto___77042_chunk__76794_77053_listeners$jscomp$3_result_77047_seq__76789_77027_seq__76793_77062__$1_temp__5825__auto___77040$$=
null,$G__77044_G__77066_chunk__76790_77029_count__76795_77054_seq__76789_77041__$1$$=0),$G__77045_G__77064_count__76791_77031_i__76796_77055$$=0;else break;return $APP.$cljs$core$not$$($listener_already_exists_QMARK_$$)?$instaparse$gll$push_stack$$($tramp$jscomp$11$$,function(){return $instaparse$gll$_parse$$($node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$(1):$node_key$jscomp$6$$(1),$node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$(0):
$node_key$jscomp$6$$(0),$tramp$jscomp$11$$)}):null};
$instaparse$gll$push_full_listener$$=function($tramp$jscomp$12$$,$node_key$jscomp$7$$,$listener$jscomp$106$$){var $full_listener_already_exists_QMARK_$$=$instaparse$gll$full_listener_exists_QMARK_$$($tramp$jscomp$12$$,$node_key$jscomp$7$$),$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=$instaparse$gll$node_get$$($tramp$jscomp$12$$,$node_key$jscomp$7$$),$G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$=$cljs$cst$5484$full_listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$,$APP.$cljs$core$conj$$,$listener$jscomp$106$$);$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5486$full_results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$)));$G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$=
null;for(var $G__77088_count__76799_77076$$=0,$G__77086_i__76800_77077$$=0;;)if($G__77086_i__76800_77077$$<$G__77088_count__76799_77076$$){var $result_77078$$=$G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77086_i__76800_77077$$);$instaparse$gll$push_message$$($tramp$jscomp$12$$,$listener$jscomp$106$$,$result_77078$$);$G__77086_i__76800_77077$$+=1}else if($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=
$APP.$cljs$core$seq$$($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$))$G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$=$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$)?($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=$APP.$cljs$core$_chunked_first$$($G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$),
$G__77086_i__76800_77077$$=$APP.$cljs$core$_chunked_rest$$($G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$),$G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$=$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$,$G__77088_count__76799_77076$$=$APP.$cljs$core$count$$($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$),$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=
$G__77086_i__76800_77077$$):($c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=$APP.$cljs$core$first$$($G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$),$instaparse$gll$push_message$$($tramp$jscomp$12$$,$listener$jscomp$106$$,$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$),$c__5548__auto___77085_node$jscomp$396_result_77090_seq__76797_77074_temp__5825__auto___77083$$=$APP.$cljs$core$next$$($G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$),
$G__77087_chunk__76798_77075_listeners$jscomp$4_seq__76797_77084__$1$$=null,$G__77088_count__76799_77076$$=0),$G__77086_i__76800_77077$$=0;else break;return $APP.$cljs$core$not$$($full_listener_already_exists_QMARK_$$)?$instaparse$gll$push_stack$$($tramp$jscomp$12$$,function(){return $instaparse$gll$_full_parse$$($node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$(1):$node_key$jscomp$7$$(1),$node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?
$node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$(0):$node_key$jscomp$7$$(0),$tramp$jscomp$12$$)}):null};
$instaparse$gll$push_negative_listener$$=function($tramp$jscomp$13$$,$creator$$,$negative_listener$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$5468$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$13$$),$instaparse$gll$merge_negative_listeners$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$creator$$.$cljs$core$IFn$_invoke$arity$1$?$creator$$.$cljs$core$IFn$_invoke$arity$1$(0):$creator$$(0),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$negative_listener$$],null)]))};
$instaparse$gll$fail$$=function($tramp$jscomp$14$$,$node_key$jscomp$8$$,$index$jscomp$419$$,$reason$jscomp$29$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$847$failure$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$),function($failure$jscomp$3$$){var $G__76801_current_index$jscomp$6$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($failure$jscomp$3$$);$G__76801_current_index$jscomp$6$$=$APP.$cljs$core$compare$$($index$jscomp$419$$,$G__76801_current_index$jscomp$6$$);
switch($G__76801_current_index$jscomp$6$$){case 1:return new $instaparse$gll$Failure$$($index$jscomp$419$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$reason$jscomp$29$$],null),null,null,null);case 0:return new $instaparse$gll$Failure$$($index$jscomp$419$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$984$reason$$.$cljs$core$IFn$_invoke$arity$1$($failure$jscomp$3$$),$reason$jscomp$29$$),null,null,null);case -1:return $failure$jscomp$3$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76801_current_index$jscomp$6$$)].join(""));}});return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$419$$,$cljs$cst$5464$fail_index$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$))?$instaparse$gll$push_result$$($tramp$jscomp$14$$,$node_key$jscomp$8$$,$instaparse$gll$make_success$$(function(){var $G__76802$$=$cljs$cst$5465$node_builder$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$);
var $G__76804_G__76807$jscomp$inline_8637$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$);$G__76804_G__76807$jscomp$inline_8637$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($G__76804_G__76807$jscomp$inline_8637$$,$index$jscomp$419$$):$APP.$cljs$core$subs$$($G__76804_G__76807$jscomp$inline_8637$$,$index$jscomp$419$$);var $G__76806$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$));
return $instaparse$gll$build_node_with_meta$$.$cljs$core$IFn$_invoke$arity$5$?$instaparse$gll$build_node_with_meta$$.$cljs$core$IFn$_invoke$arity$5$($G__76802$$,$cljs$cst$5493$instaparse_SLASH_failure$$,$G__76804_G__76807$jscomp$inline_8637$$,$index$jscomp$419$$,$G__76806$$):$instaparse$gll$build_node_with_meta$$($G__76802$$,$cljs$cst$5493$instaparse_SLASH_failure$$,$G__76804_G__76807$jscomp$inline_8637$$,$index$jscomp$419$$,$G__76806$$)}(),$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$)))):
null};$instaparse$gll$step$$=function($stack$jscomp$36$$){var $top$jscomp$10$$=$APP.$cljs$core$peek$$($APP.$cljs$core$_deref$$($stack$jscomp$36$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($stack$jscomp$36$$,$APP.$cljs$core$pop$$);$top$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$?$top$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$():$top$jscomp$10$$()};
$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$=function($tramp$jscomp$16$$,$found_result_QMARK__next_stack$jscomp$4$$){for(;;){var $index$jscomp$420_stack$jscomp$37$$=$APP.$cljs$cst$3685$stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$deref$$($APP.$cljs$cst$2344$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$))))return $APP.$cljs$core$cons$$($APP.$cljs$cst$828$result$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$cst$2344$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$))),
new $APP.$cljs$core$LazySeq$$(null,function($tramp$jscomp$17$$){return function(){$APP.$cljs$core$reset_BANG_$$($APP.$cljs$cst$2344$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$17$$),null);return $instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($tramp$jscomp$17$$,!0)}}($tramp$jscomp$16$$,$found_result_QMARK__next_stack$jscomp$4$$,$index$jscomp$420_stack$jscomp$37$$),null,null));if($APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($index$jscomp$420_stack$jscomp$37$$))>0)$instaparse$gll$step$$($index$jscomp$420_stack$jscomp$37$$);
else if($APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5468$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$)))>0){var $listeners$jscomp$5_vec__76811$$=$APP.$cljs$core$first$$($APP.$cljs$core$deref$$($cljs$cst$5468$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$)));$index$jscomp$420_stack$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($listeners$jscomp$5_vec__76811$$,0,null);$listeners$jscomp$5_vec__76811$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($listeners$jscomp$5_vec__76811$$,
1,null);var $listener$jscomp$107$$=$APP.$cljs$core$peek$$($listeners$jscomp$5_vec__76811$$);$listener$jscomp$107$$.$cljs$core$IFn$_invoke$arity$0$?$listener$jscomp$107$$.$cljs$core$IFn$_invoke$arity$0$():$listener$jscomp$107$$();$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($listeners$jscomp$5_vec__76811$$),1)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$5468$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),$APP.$cljs$core$dissoc$$,
$index$jscomp$420_stack$jscomp$37$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$5468$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$420_stack$jscomp$37$$],null),$APP.$cljs$core$pop$$)}else if($APP.$cljs$core$truth_$$($found_result_QMARK__next_stack$jscomp$4$$))$found_result_QMARK__next_stack$jscomp$4$$=$cljs$cst$5466$next_stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),
$APP.$cljs$core$reset_BANG_$$($index$jscomp$420_stack$jscomp$37$$,$APP.$cljs$core$_deref$$($found_result_QMARK__next_stack$jscomp$4$$)),$APP.$cljs$core$reset_BANG_$$($found_result_QMARK__next_stack$jscomp$4$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5467$generation$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),$APP.$cljs$core$inc$$),$found_result_QMARK__next_stack$jscomp$4$$=null;else return null}};
$instaparse$gll$NodeListener$$=function($node_key$jscomp$9$$,$tramp$jscomp$18$$){return function($result$jscomp$348$$){return $instaparse$gll$push_result$$($tramp$jscomp$18$$,$node_key$jscomp$9$$,$result$jscomp$348$$)}};
$instaparse$gll$LookListener$$=function($node_key$jscomp$10$$,$tramp$jscomp$19$$){return function(){return $instaparse$gll$push_result$$($tramp$jscomp$19$$,$node_key$jscomp$10$$,$instaparse$gll$make_success$$(null,$node_key$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$(0):$node_key$jscomp$10$$(0)))}};
$instaparse$gll$TopListener$$=function($tramp$jscomp$26$$){return function($result$jscomp$356$$){return $APP.$cljs$core$reset_BANG_$$($APP.$cljs$cst$2344$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$26$$),$result$jscomp$356$$)}};
$instaparse$gll$string_parse$$=function($this$$jscomp$770$$,$index$jscomp$421$$,$tramp$jscomp$27$$){var $string$jscomp$22$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$770$$),$head$jscomp$24_text$jscomp$91$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$27$$);var $end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$=$APP.$cljs$core$count$$($head$jscomp$24_text$jscomp$91$$);var $y__5114__auto__$jscomp$inline_8642$$=$index$jscomp$421$$+$APP.$cljs$core$count$$($string$jscomp$22$$);
$end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$=$end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$<$y__5114__auto__$jscomp$inline_8642$$?$end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$:$y__5114__auto__$jscomp$inline_8642$$;$head$jscomp$24_text$jscomp$91$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$24_text$jscomp$91$$,$index$jscomp$421$$,$end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$):$APP.$cljs$core$subs$$($head$jscomp$24_text$jscomp$91$$,
$index$jscomp$421$$,$end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$22$$,$head$jscomp$24_text$jscomp$91$$)?$instaparse$gll$push_result$$($tramp$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$421$$,$this$$jscomp$770$$],null),$instaparse$gll$make_success$$($string$jscomp$22$$,$end$jscomp$96_x__5113__auto__$jscomp$inline_8641$$)):$instaparse$gll$fail$$($tramp$jscomp$27$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$421$$,$this$$jscomp$770$$],null),$index$jscomp$421$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$cljs$cst$5451$expecting$$,$string$jscomp$22$$],null))};
$instaparse$gll$string_full_parse$$=function($this$$jscomp$771$$,$index$jscomp$422$$,$tramp$jscomp$28$$){var $string$jscomp$23$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$771$$),$text$jscomp$92$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$28$$);var $end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$=$APP.$cljs$core$count$$($text$jscomp$92$$);var $head$jscomp$25_y__5114__auto__$jscomp$inline_8645$$=$index$jscomp$422$$+$APP.$cljs$core$count$$($string$jscomp$23$$);
$end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$=$end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$<$head$jscomp$25_y__5114__auto__$jscomp$inline_8645$$?$end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$:$head$jscomp$25_y__5114__auto__$jscomp$inline_8645$$;$head$jscomp$25_y__5114__auto__$jscomp$inline_8645$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($text$jscomp$92$$,$index$jscomp$422$$,$end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$):
$APP.$cljs$core$subs$$($text$jscomp$92$$,$index$jscomp$422$$,$end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$,$APP.$cljs$core$count$$($text$jscomp$92$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$23$$,$head$jscomp$25_y__5114__auto__$jscomp$inline_8645$$)?$instaparse$gll$push_result$$($tramp$jscomp$28$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$422$$,$this$$jscomp$771$$],null),$instaparse$gll$make_success$$($string$jscomp$23$$,$end$jscomp$97_x__5113__auto__$jscomp$inline_8644$$)):$instaparse$gll$fail$$($tramp$jscomp$28$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$422$$,$this$$jscomp$771$$],null),$index$jscomp$422$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$cljs$cst$5451$expecting$$,$string$jscomp$23$$,
$APP.$cljs$cst$1273$full$$,!0],null))};
$instaparse$gll$string_case_insensitive_parse$$=function($this$$jscomp$772$$,$index$jscomp$423$$,$tramp$jscomp$29$$){var $string$jscomp$24$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$772$$),$head$jscomp$26_text$jscomp$93$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$29$$);var $end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$=$APP.$cljs$core$count$$($head$jscomp$26_text$jscomp$93$$);var $y__5114__auto__$jscomp$inline_8648$$=$index$jscomp$423$$+
$APP.$cljs$core$count$$($string$jscomp$24$$);$end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$=$end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$<$y__5114__auto__$jscomp$inline_8648$$?$end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$:$y__5114__auto__$jscomp$inline_8648$$;$head$jscomp$26_text$jscomp$93$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$26_text$jscomp$93$$,$index$jscomp$423$$,$end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$):
$APP.$cljs$core$subs$$($head$jscomp$26_text$jscomp$93$$,$index$jscomp$423$$,$end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$24$$.toUpperCase(),$head$jscomp$26_text$jscomp$93$$.toUpperCase())?$instaparse$gll$push_result$$($tramp$jscomp$29$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$423$$,$this$$jscomp$772$$],null),$instaparse$gll$make_success$$($string$jscomp$24$$,
$end$jscomp$98_x__5113__auto__$jscomp$inline_8647$$)):$instaparse$gll$fail$$($tramp$jscomp$29$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$423$$,$this$$jscomp$772$$],null),$index$jscomp$423$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$cljs$cst$5451$expecting$$,$string$jscomp$24$$],null))};
$instaparse$gll$string_case_insensitive_full_parse$$=function($this$$jscomp$773$$,$index$jscomp$424$$,$tramp$jscomp$30$$){var $string$jscomp$25$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$773$$),$text$jscomp$94$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$30$$);var $end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$=$APP.$cljs$core$count$$($text$jscomp$94$$);var $head$jscomp$27_y__5114__auto__$jscomp$inline_8651$$=$index$jscomp$424$$+$APP.$cljs$core$count$$($string$jscomp$25$$);
$end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$=$end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$<$head$jscomp$27_y__5114__auto__$jscomp$inline_8651$$?$end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$:$head$jscomp$27_y__5114__auto__$jscomp$inline_8651$$;$head$jscomp$27_y__5114__auto__$jscomp$inline_8651$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($text$jscomp$94$$,$index$jscomp$424$$,$end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$):
$APP.$cljs$core$subs$$($text$jscomp$94$$,$index$jscomp$424$$,$end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$,$APP.$cljs$core$count$$($text$jscomp$94$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$25$$.toUpperCase(),$head$jscomp$27_y__5114__auto__$jscomp$inline_8651$$.toUpperCase())?$instaparse$gll$push_result$$($tramp$jscomp$30$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$424$$,$this$$jscomp$773$$],null),$instaparse$gll$make_success$$($string$jscomp$25$$,$end$jscomp$99_x__5113__auto__$jscomp$inline_8650$$)):$instaparse$gll$fail$$($tramp$jscomp$30$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$424$$,$this$$jscomp$773$$],null),$index$jscomp$424$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,
$cljs$cst$5451$expecting$$,$string$jscomp$25$$,$APP.$cljs$cst$1273$full$$,!0],null))};
$instaparse$gll$char_range_parse$$=function($this$$jscomp$774$$,$index$jscomp$427$$,$tramp$jscomp$31$$){var $lo$jscomp$7$$=$cljs$cst$5439$lo$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$774$$),$hi$jscomp$9$$=$cljs$cst$5440$hi$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$774$$),$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$31$$);if($index$jscomp$427$$>=$APP.$cljs$core$count$$($code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$))return $instaparse$gll$fail$$($tramp$jscomp$31$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$427$$,$this$$jscomp$774$$],null),$index$jscomp$427$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5450$char_range$$,!0,$cljs$cst$5439$lo$$,$lo$jscomp$7$$,$cljs$cst$5440$hi$$,$hi$jscomp$9$$],null)],null));if($hi$jscomp$9$$<=65535)return $code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$=
$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$.charCodeAt($index$jscomp$427$$),$lo$jscomp$7$$<=$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$&&$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$<=$hi$jscomp$9$$?$instaparse$gll$push_result$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$427$$,$this$$jscomp$774$$],null),$instaparse$gll$make_success$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$char$0$$($code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$)),
$index$jscomp$427$$+1)):$instaparse$gll$fail$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$427$$,$this$$jscomp$774$$],null),$index$jscomp$427$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5450$char_range$$,!0,$cljs$cst$5439$lo$$,$lo$jscomp$7$$,$cljs$cst$5440$hi$$,$hi$jscomp$9$$],
null)],null));$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$=$goog$i18n$uChar$getCodePointAround$$($code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$,$index$jscomp$427$$|0);var $char_string$$=$goog$i18n$uChar$fromCharCode$$($code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$);return $lo$jscomp$7$$<=$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$&&$code$jscomp$59_code_point$jscomp$2_text$jscomp$97$$<=$hi$jscomp$9$$?$instaparse$gll$push_result$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$427$$,$this$$jscomp$774$$],null),$instaparse$gll$make_success$$($char_string$$,$index$jscomp$427$$+$APP.$cljs$core$count$$($char_string$$))):$instaparse$gll$fail$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$427$$,$this$$jscomp$774$$],null),$index$jscomp$427$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,
$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5450$char_range$$,!0,$cljs$cst$5439$lo$$,$lo$jscomp$7$$,$cljs$cst$5440$hi$$,$hi$jscomp$9$$],null)],null))};
$instaparse$gll$char_range_full_parse$$=function($this$$jscomp$775$$,$index$jscomp$428$$,$tramp$jscomp$32$$){var $lo$jscomp$8$$=$cljs$cst$5439$lo$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$775$$),$hi$jscomp$10$$=$cljs$cst$5440$hi$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$775$$),$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$32$$),$end$jscomp$100$$=$APP.$cljs$core$count$$($code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$);
if($index$jscomp$428$$>=$APP.$cljs$core$count$$($code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$))return $instaparse$gll$fail$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$775$$],null),$index$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5450$char_range$$,
!0,$cljs$cst$5439$lo$$,$lo$jscomp$8$$,$cljs$cst$5440$hi$$,$hi$jscomp$10$$],null)],null));if($hi$jscomp$10$$<=65535)return $code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$=$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$.charCodeAt($index$jscomp$428$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$428$$+1,$end$jscomp$100$$)&&$lo$jscomp$8$$<=$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$&&$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$<=$hi$jscomp$10$$?$instaparse$gll$push_result$$($tramp$jscomp$32$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$775$$],null),$instaparse$gll$make_success$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$char$0$$($code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$)),$end$jscomp$100$$)):$instaparse$gll$fail$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$775$$],
null),$index$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5450$char_range$$,!0,$cljs$cst$5439$lo$$,$lo$jscomp$8$$,$cljs$cst$5440$hi$$,$hi$jscomp$10$$],null)],null));$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$=$goog$i18n$uChar$getCodePointAround$$($code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$,$index$jscomp$428$$|0);var $char_string$jscomp$1$$=
$goog$i18n$uChar$fromCharCode$$($code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$428$$+$APP.$cljs$core$count$$($char_string$jscomp$1$$),$end$jscomp$100$$)&&$lo$jscomp$8$$<=$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$&&$code$jscomp$60_code_point$jscomp$3_text$jscomp$98$$<=$hi$jscomp$10$$?$instaparse$gll$push_result$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$428$$,$this$$jscomp$775$$],null),$instaparse$gll$make_success$$($char_string$jscomp$1$$,$end$jscomp$100$$)):$instaparse$gll$fail$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$775$$],null),$index$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5459$char$$,$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5450$char_range$$,
!0,$cljs$cst$5439$lo$$,$lo$jscomp$8$$,$cljs$cst$5440$hi$$,$hi$jscomp$10$$],null),$APP.$cljs$cst$1273$full$$,!0],null))};
$instaparse$gll$re_match_at_front$$=function($m$jscomp$225_regexp$jscomp$3$$,$text$jscomp$99$$){$m$jscomp$225_regexp$jscomp$3$$=(new RegExp($m$jscomp$225_regexp$jscomp$3$$.source,["g",$instaparse$util$regexp_flags$$($m$jscomp$225_regexp$jscomp$3$$)].join(""))).exec($text$jscomp$99$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($m$jscomp$225_regexp$jscomp$3$$)?$m$jscomp$225_regexp$jscomp$3$$.index===0:$m$jscomp$225_regexp$jscomp$3$$)?$APP.$cljs$core$first$$($m$jscomp$225_regexp$jscomp$3$$):
null};
$instaparse$gll$regexp_parse$$=function($this$$jscomp$776$$,$index$jscomp$429$$,$tramp$jscomp$33$$){var $regexp$jscomp$4$$=$cljs$cst$5444$regexp$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$776$$),$match$jscomp$56_substring_text$jscomp$100$$=$APP.$cljs$cst$1861$segment$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$33$$);$match$jscomp$56_substring_text$jscomp$100$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($match$jscomp$56_substring_text$jscomp$100$$,$index$jscomp$429$$):
$APP.$cljs$core$subs$$($match$jscomp$56_substring_text$jscomp$100$$,$index$jscomp$429$$);$match$jscomp$56_substring_text$jscomp$100$$=$instaparse$gll$re_match_at_front$$($regexp$jscomp$4$$,$match$jscomp$56_substring_text$jscomp$100$$);return $APP.$cljs$core$truth_$$($match$jscomp$56_substring_text$jscomp$100$$)?$instaparse$gll$push_result$$($tramp$jscomp$33$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$429$$,$this$$jscomp$776$$],null),
$instaparse$gll$make_success$$($match$jscomp$56_substring_text$jscomp$100$$,$index$jscomp$429$$+$APP.$cljs$core$count$$($match$jscomp$56_substring_text$jscomp$100$$))):$instaparse$gll$fail$$($tramp$jscomp$33$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$429$$,$this$$jscomp$776$$],null),$index$jscomp$429$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5444$regexp$$,$cljs$cst$5451$expecting$$,$regexp$jscomp$4$$],
null))};
$instaparse$gll$regexp_full_parse$$=function($this$$jscomp$777$$,$index$jscomp$430$$,$tramp$jscomp$34$$){var $regexp$jscomp$5$$=$cljs$cst$5444$regexp$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$777$$),$text$jscomp$101$$=$APP.$cljs$cst$1861$segment$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$34$$),$match$jscomp$57_substring$jscomp$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($text$jscomp$101$$,$index$jscomp$430$$):$APP.$cljs$core$subs$$($text$jscomp$101$$,
$index$jscomp$430$$);$match$jscomp$57_substring$jscomp$1$$=$instaparse$gll$re_match_at_front$$($regexp$jscomp$5$$,$match$jscomp$57_substring$jscomp$1$$);var $desired_length$$=$APP.$cljs$core$count$$($text$jscomp$101$$)-$index$jscomp$430$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($match$jscomp$57_substring$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($match$jscomp$57_substring$jscomp$1$$),$desired_length$$):$match$jscomp$57_substring$jscomp$1$$)?
$instaparse$gll$push_result$$($tramp$jscomp$34$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$430$$,$this$$jscomp$777$$],null),$instaparse$gll$make_success$$($match$jscomp$57_substring$jscomp$1$$,$APP.$cljs$core$count$$($text$jscomp$101$$))):$instaparse$gll$fail$$($tramp$jscomp$34$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$430$$,$this$$jscomp$777$$],null),$index$jscomp$430$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5444$regexp$$,$cljs$cst$5451$expecting$$,$regexp$jscomp$5$$,$APP.$cljs$cst$1273$full$$,!0],null))};
$instaparse$gll$cat_parse$$=function($this$$jscomp$778$$,$index$jscomp$431$$,$tramp$jscomp$35$$){var $parsers$jscomp$10$$=$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$778$$);return $instaparse$gll$push_listener$$($tramp$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$431$$,$APP.$cljs$core$first$$($parsers$jscomp$10$$)],null),$instaparse$gll$CatListener$$($instaparse$auto_flatten_seq$EMPTY$$,$APP.$cljs$core$next$$($parsers$jscomp$10$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$431$$,$this$$jscomp$778$$],null),$tramp$jscomp$35$$))};
$instaparse$gll$cat_full_parse$$=function($this$$jscomp$779$$,$index$jscomp$432$$,$tramp$jscomp$36$$){var $parsers$jscomp$11$$=$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$779$$);return $instaparse$gll$push_listener$$($tramp$jscomp$36$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$432$$,$APP.$cljs$core$first$$($parsers$jscomp$11$$)],null),$instaparse$gll$CatFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,
$APP.$cljs$core$next$$($parsers$jscomp$11$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$432$$,$this$$jscomp$779$$],null),$tramp$jscomp$36$$))};
$instaparse$gll$plus_parse$$=function($this$$jscomp$780$$,$index$jscomp$433$$,$tramp$jscomp$37$$){var $parser$jscomp$42$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$780$$);return $instaparse$gll$push_listener$$($tramp$jscomp$37$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$433$$,$parser$jscomp$42$$],null),$instaparse$gll$PlusListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$42$$,$index$jscomp$433$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$433$$,$this$$jscomp$780$$],null),$tramp$jscomp$37$$))};
$instaparse$gll$plus_full_parse$$=function($this$$jscomp$781$$,$index$jscomp$434$$,$tramp$jscomp$38$$){var $parser$jscomp$43$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$781$$);return $instaparse$gll$push_listener$$($tramp$jscomp$38$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$434$$,$parser$jscomp$43$$],null),$instaparse$gll$PlusFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$43$$,$index$jscomp$434$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$434$$,$this$$jscomp$781$$],null),$tramp$jscomp$38$$))};
$instaparse$gll$rep_parse$$=function($this$$jscomp$782$$,$index$jscomp$435$$,$tramp$jscomp$39$$){var $parser$jscomp$44$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$782$$),$m$jscomp$226$$=$APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$782$$),$n$jscomp$302$$=$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$782$$);return $m$jscomp$226$$===0?($instaparse$gll$push_result$$($tramp$jscomp$39$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$this$$jscomp$782$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$435$$)),$n$jscomp$302$$>=1?$instaparse$gll$push_listener$$($tramp$jscomp$39$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$parser$jscomp$44$$],null),$instaparse$gll$RepListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$44$$,1,$n$jscomp$302$$,$index$jscomp$435$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$this$$jscomp$782$$],null),$tramp$jscomp$39$$)):null):$instaparse$gll$push_listener$$($tramp$jscomp$39$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$parser$jscomp$44$$],null),$instaparse$gll$RepListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$44$$,$m$jscomp$226$$,$n$jscomp$302$$,$index$jscomp$435$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$this$$jscomp$782$$],null),$tramp$jscomp$39$$))};
$instaparse$gll$rep_full_parse$$=function($this$$jscomp$783$$,$index$jscomp$436$$,$tramp$jscomp$40$$){var $parser$jscomp$45$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$783$$),$m$jscomp$227$$=$APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$783$$),$n$jscomp$303$$=$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$783$$);return $m$jscomp$227$$===0?($instaparse$gll$push_result$$($tramp$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$this$$jscomp$783$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$436$$)),$n$jscomp$303$$>=1?$instaparse$gll$push_listener$$($tramp$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$parser$jscomp$45$$],null),$instaparse$gll$RepFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$45$$,1,$n$jscomp$303$$,$index$jscomp$436$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$this$$jscomp$783$$],null),$tramp$jscomp$40$$)):null):$instaparse$gll$push_listener$$($tramp$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$parser$jscomp$45$$],null),$instaparse$gll$RepFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$45$$,$m$jscomp$227$$,$n$jscomp$303$$,$index$jscomp$436$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$this$$jscomp$783$$],null),$tramp$jscomp$40$$))};
$instaparse$gll$star_parse$$=function($this$$jscomp$784$$,$index$jscomp$437$$,$tramp$jscomp$41$$){var $parser$jscomp$46$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$784$$);$instaparse$gll$push_listener$$($tramp$jscomp$41$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$parser$jscomp$46$$],null),$instaparse$gll$PlusListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$46$$,$index$jscomp$437$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$this$$jscomp$784$$],null),$tramp$jscomp$41$$));return $instaparse$gll$push_result$$($tramp$jscomp$41$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$this$$jscomp$784$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$437$$))};
$instaparse$gll$star_full_parse$$=function($this$$jscomp$785$$,$index$jscomp$438$$,$tramp$jscomp$42$$){var $parser$jscomp$47$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$785$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$438$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$42$$)))?$instaparse$gll$push_result$$($tramp$jscomp$42$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$438$$,$this$$jscomp$785$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$438$$)):$instaparse$gll$push_listener$$($tramp$jscomp$42$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$438$$,$parser$jscomp$47$$],null),$instaparse$gll$PlusFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$47$$,$index$jscomp$438$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$438$$,$this$$jscomp$785$$],null),$tramp$jscomp$42$$))};
$instaparse$gll$alt_parse$$=function($this$$jscomp$786$$,$index$jscomp$439$$,$tramp$jscomp$43$$){var $c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$=$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$786$$);$c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$);for(var $G__77243_chunk__76833_seq__76832__$1$$=
null,$G__77242_count__76834$$=0,$i__76835$$=0;;)if($i__76835$$<$G__77242_count__76834$$){var $G__77244_parser$jscomp$48$$=$G__77243_chunk__76833_seq__76832__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__76835$$);$instaparse$gll$push_listener$$($tramp$jscomp$43$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$439$$,$G__77244_parser$jscomp$48$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$439$$,$this$$jscomp$786$$],null),$tramp$jscomp$43$$));$i__76835$$+=1}else if($c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$))$G__77243_chunk__76833_seq__76832__$1$$=$c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77243_chunk__76833_seq__76832__$1$$)?($c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$=
$APP.$cljs$core$_chunked_first$$($G__77243_chunk__76833_seq__76832__$1$$),$G__77242_count__76834$$=$APP.$cljs$core$_chunked_rest$$($G__77243_chunk__76833_seq__76832__$1$$),$G__77243_chunk__76833_seq__76832__$1$$=$c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$,$G__77244_parser$jscomp$48$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$),$c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$=
$G__77242_count__76834$$,$G__77242_count__76834$$=$G__77244_parser$jscomp$48$$):($G__77244_parser$jscomp$48$$=$APP.$cljs$core$first$$($G__77243_chunk__76833_seq__76832__$1$$),$instaparse$gll$push_listener$$($tramp$jscomp$43$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$439$$,$G__77244_parser$jscomp$48$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$439$$,$this$$jscomp$786$$],null),$tramp$jscomp$43$$)),$c__5548__auto__$jscomp$39_parsers$jscomp$12_seq__76832_temp__5825__auto__$jscomp$343$$=$APP.$cljs$core$next$$($G__77243_chunk__76833_seq__76832__$1$$),$G__77243_chunk__76833_seq__76832__$1$$=null,$G__77242_count__76834$$=0),$i__76835$$=0;else return null};
$instaparse$gll$alt_full_parse$$=function($this$$jscomp$787$$,$index$jscomp$440$$,$tramp$jscomp$44$$){var $c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$=$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$787$$);$c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$);for(var $G__77255_chunk__76837_seq__76836__$1$$=
null,$G__77254_count__76838$$=0,$i__76839$$=0;;)if($i__76839$$<$G__77254_count__76838$$){var $G__77256_parser$jscomp$49$$=$G__77255_chunk__76837_seq__76836__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__76839$$);$instaparse$gll$push_full_listener$$($tramp$jscomp$44$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$440$$,$G__77256_parser$jscomp$49$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$440$$,$this$$jscomp$787$$],null),$tramp$jscomp$44$$));$i__76839$$+=1}else if($c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$))$G__77255_chunk__76837_seq__76836__$1$$=$c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77255_chunk__76837_seq__76836__$1$$)?($c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$=
$APP.$cljs$core$_chunked_first$$($G__77255_chunk__76837_seq__76836__$1$$),$G__77254_count__76838$$=$APP.$cljs$core$_chunked_rest$$($G__77255_chunk__76837_seq__76836__$1$$),$G__77255_chunk__76837_seq__76836__$1$$=$c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$,$G__77256_parser$jscomp$49$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$),$c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$=
$G__77254_count__76838$$,$G__77254_count__76838$$=$G__77256_parser$jscomp$49$$):($G__77256_parser$jscomp$49$$=$APP.$cljs$core$first$$($G__77255_chunk__76837_seq__76836__$1$$),$instaparse$gll$push_full_listener$$($tramp$jscomp$44$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$440$$,$G__77256_parser$jscomp$49$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$440$$,$this$$jscomp$787$$],null),$tramp$jscomp$44$$)),$c__5548__auto__$jscomp$40_parsers$jscomp$13_seq__76836_temp__5825__auto__$jscomp$344$$=$APP.$cljs$core$next$$($G__77255_chunk__76837_seq__76836__$1$$),$G__77255_chunk__76837_seq__76836__$1$$=null,$G__77254_count__76838$$=0),$i__76839$$=0;else return null};
$instaparse$gll$ordered_alt_parse$$=function($this$$jscomp$788$$,$index$jscomp$441$$,$tramp$jscomp$45$$){var $node_key_parser1_parser1$jscomp$3$$=$cljs$cst$5441$parser1$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$788$$),$parser2$jscomp$2$$=$cljs$cst$5442$parser2$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$788$$);$node_key_parser1_parser1$jscomp$3$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$441$$,$node_key_parser1_parser1$jscomp$3$$],
null);var $node_key_parser2$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$441$$,$parser2$jscomp$2$$],null),$listener$jscomp$108$$=$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$441$$,$this$$jscomp$788$$],null),$tramp$jscomp$45$$);$instaparse$gll$push_listener$$($tramp$jscomp$45$$,$node_key_parser1_parser1$jscomp$3$$,$listener$jscomp$108$$);return $instaparse$gll$push_negative_listener$$($tramp$jscomp$45$$,
$node_key_parser1_parser1$jscomp$3$$,function(){return $instaparse$gll$push_listener$$($tramp$jscomp$45$$,$node_key_parser2$$,$listener$jscomp$108$$)})};
$instaparse$gll$ordered_alt_full_parse$$=function($this$$jscomp$789$$,$index$jscomp$442$$,$tramp$jscomp$46$$){var $node_key_parser1$jscomp$1_parser1$jscomp$4$$=$cljs$cst$5441$parser1$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$789$$),$parser2$jscomp$3$$=$cljs$cst$5442$parser2$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$789$$);$node_key_parser1$jscomp$1_parser1$jscomp$4$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$442$$,$node_key_parser1$jscomp$1_parser1$jscomp$4$$],
null);var $node_key_parser2$jscomp$1$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$442$$,$parser2$jscomp$3$$],null),$listener$jscomp$109$$=$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$442$$,$this$$jscomp$789$$],null),$tramp$jscomp$46$$);$instaparse$gll$push_full_listener$$($tramp$jscomp$46$$,$node_key_parser1$jscomp$1_parser1$jscomp$4$$,$listener$jscomp$109$$);
return $instaparse$gll$push_negative_listener$$($tramp$jscomp$46$$,$node_key_parser1$jscomp$1_parser1$jscomp$4$$,function(){return $instaparse$gll$push_full_listener$$($tramp$jscomp$46$$,$node_key_parser2$jscomp$1$$,$listener$jscomp$109$$)})};
$instaparse$gll$opt_parse$$=function($this$$jscomp$790$$,$index$jscomp$443$$,$tramp$jscomp$47$$){var $parser$jscomp$50$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$790$$);$instaparse$gll$push_listener$$($tramp$jscomp$47$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$443$$,$parser$jscomp$50$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$443$$,$this$$jscomp$790$$],null),$tramp$jscomp$47$$));return $instaparse$gll$push_result$$($tramp$jscomp$47$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$443$$,$this$$jscomp$790$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$443$$))};
$instaparse$gll$opt_full_parse$$=function($this$$jscomp$791$$,$index$jscomp$444$$,$tramp$jscomp$48$$){var $parser$jscomp$51$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$791$$);$instaparse$gll$push_full_listener$$($tramp$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$444$$,$parser$jscomp$51$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$444$$,$this$$jscomp$791$$],null),$tramp$jscomp$48$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$444$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$48$$)))?$instaparse$gll$push_result$$($tramp$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$444$$,$this$$jscomp$791$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$444$$)):
$instaparse$gll$fail$$($tramp$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$444$$,$this$$jscomp$791$$],null),$index$jscomp$444$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$450$optional$$,$cljs$cst$5451$expecting$$,$cljs$cst$5494$end_of_string$$],null))};
$instaparse$gll$non_terminal_parse$$=function($this$$jscomp$792$$,$index$jscomp$445$$,$tramp$jscomp$49$$){var $grammar$jscomp$inline_8653_parser$jscomp$52$$=$cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$49$$);var $p$jscomp$inline_8654$$=$APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$792$$);$grammar$jscomp$inline_8653_parser$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($grammar$jscomp$inline_8653_parser$jscomp$52$$,$p$jscomp$inline_8654$$,
$p$jscomp$inline_8654$$);return $instaparse$gll$push_listener$$($tramp$jscomp$49$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$445$$,$grammar$jscomp$inline_8653_parser$jscomp$52$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$445$$,$this$$jscomp$792$$],null),$tramp$jscomp$49$$))};
$instaparse$gll$non_terminal_full_parse$$=function($this$$jscomp$793$$,$index$jscomp$446$$,$tramp$jscomp$50$$){var $grammar$jscomp$inline_8656_parser$jscomp$53$$=$cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$50$$);var $p$jscomp$inline_8657$$=$APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$793$$);$grammar$jscomp$inline_8656_parser$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($grammar$jscomp$inline_8656_parser$jscomp$53$$,$p$jscomp$inline_8657$$,
$p$jscomp$inline_8657$$);return $instaparse$gll$push_full_listener$$($tramp$jscomp$50$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$446$$,$grammar$jscomp$inline_8656_parser$jscomp$53$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$446$$,$this$$jscomp$793$$],null),$tramp$jscomp$50$$))};
$instaparse$gll$lookahead_parse$$=function($this$$jscomp$794$$,$index$jscomp$447$$,$tramp$jscomp$51$$){var $parser$jscomp$54$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$794$$);return $instaparse$gll$push_listener$$($tramp$jscomp$51$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$447$$,$parser$jscomp$54$$],null),$instaparse$gll$LookListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$447$$,$this$$jscomp$794$$],null),$tramp$jscomp$51$$))};
$instaparse$gll$lookahead_full_parse$$=function($this$$jscomp$795$$,$index$jscomp$448$$,$tramp$jscomp$52$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$448$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$52$$)))?$instaparse$gll$lookahead_parse$$($this$$jscomp$795$$,$index$jscomp$448$$,$tramp$jscomp$52$$):$instaparse$gll$fail$$($tramp$jscomp$52$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$448$$,$this$$jscomp$795$$],null),$index$jscomp$448$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5495$lookahead$$,$cljs$cst$5451$expecting$$,$cljs$cst$5494$end_of_string$$],null))};
$instaparse$gll$negative_lookahead_parse$$=function($this$$jscomp$796$$,$index$jscomp$449$$,$tramp$jscomp$53$$){var $parser$jscomp$55$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$796$$),$node_key$jscomp$17$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$449$$,$parser$jscomp$55$$],null);if($APP.$cljs$core$truth_$$($instaparse$gll$result_exists_QMARK_$$($tramp$jscomp$53$$,$node_key$jscomp$17$$)))return $instaparse$gll$fail$$($tramp$jscomp$53$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$449$$,$this$$jscomp$796$$],null),$index$jscomp$449$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5496$negative_lookahead$$],null));$instaparse$gll$push_listener$$($tramp$jscomp$53$$,$node_key$jscomp$17$$,function(){var $fail_send$$=new $APP.$cljs$core$Delay$$(function(){return $instaparse$gll$fail$$($tramp$jscomp$53$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$449$$,$this$$jscomp$796$$],null),$index$jscomp$449$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5496$negative_lookahead$$,$cljs$cst$5451$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5449$NOT$$,$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$55$$,!1)],null)],null))});return function(){return $APP.$cljs$core$force$$($fail_send$$)}}());
return $instaparse$gll$push_negative_listener$$($tramp$jscomp$53$$,$node_key$jscomp$17$$,function(){return $APP.$cljs$core$not$$($instaparse$gll$result_exists_QMARK_$$($tramp$jscomp$53$$,$node_key$jscomp$17$$))?$instaparse$gll$push_result$$($tramp$jscomp$53$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$449$$,$this$$jscomp$796$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$449$$)):null})};
$instaparse$gll$epsilon_parse$$=function($this$$jscomp$797$$,$index$jscomp$450$$,$tramp$jscomp$54$$){return $instaparse$gll$push_result$$($tramp$jscomp$54$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$450$$,$this$$jscomp$797$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$450$$))};
$instaparse$gll$epsilon_full_parse$$=function($this$$jscomp$798$$,$index$jscomp$451$$,$tramp$jscomp$55$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$451$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$55$$)))?$instaparse$gll$push_result$$($tramp$jscomp$55$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$451$$,$this$$jscomp$798$$],null),$instaparse$gll$make_success$$(null,
$index$jscomp$451$$)):$instaparse$gll$fail$$($tramp$jscomp$55$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$451$$,$this$$jscomp$798$$],null),$index$jscomp$451$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5497$Epsilon$$,$cljs$cst$5451$expecting$$,$cljs$cst$5494$end_of_string$$],null))};
$instaparse$gll$start_parser$$=function($tramp$jscomp$56$$,$parser$jscomp$56$$,$partial_QMARK_$$){$APP.$cljs$core$truth_$$($partial_QMARK_$$)?$instaparse$gll$push_listener$$($tramp$jscomp$56$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,$parser$jscomp$56$$],null),$instaparse$gll$TopListener$$($tramp$jscomp$56$$)):$instaparse$gll$push_full_listener$$($tramp$jscomp$56$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0,$parser$jscomp$56$$],null),$instaparse$gll$TopListener$$($tramp$jscomp$56$$))};
$instaparse$gll$parse$$=function($JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$,$JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$,$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$,$index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$){$JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$=$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$($JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$,
$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$,$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$,-1,null);$instaparse$gll$start_parser$$($JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$,$instaparse$combinators_source$nt$$($JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$),
$index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$);$JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$=$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$,null);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$))$JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$=
$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$);else{$JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$=$APP.$cljs$core$deref$$($APP.$cljs$cst$847$failure$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$));a:{$index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$=
$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$);for(var $G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$=$JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$=1,$G__75740$jscomp$inline_13421_G__75743$jscomp$inline_13422_counter$jscomp$inline_13420$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$,
$G__75740$jscomp$inline_13421_G__75743$jscomp$inline_13422_counter$jscomp$inline_13420$$)){$index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$209$line$$,$JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$,$APP.$cljs$cst$216$column$$,$G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$],null);
break a}$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$,$G__75740$jscomp$inline_13421_G__75743$jscomp$inline_13422_counter$jscomp$inline_13420$$))?($G__75740$jscomp$inline_13421_G__75743$jscomp$inline_13422_counter$jscomp$inline_13420$$+=1,$JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$+=
1,$G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$=1):($G__75740$jscomp$inline_13421_G__75743$jscomp$inline_13422_counter$jscomp$inline_13420$$+=1,$G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$+=1)}$index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$=void 0}$JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;a:{$G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$=$APP.$cljs$cst$209$line$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$);for($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$=$APP.$cljs$core$seq$$($APP.$clojure$string$replace$$($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$,
"\r\n","\n"));;){if($APP.$cljs$core$empty_QMARK_$$($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$)){$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$="";break a}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$,
1)){$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$complement$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,["\n",null],null),null)),$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$));
break a}$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$first$$($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$))?($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$=$APP.$cljs$core$next$$($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$),
--$G__75745$jscomp$inline_13429_G__75747$jscomp$inline_13431_col$jscomp$inline_13419_n$jscomp$inline_13424_n__$1$jscomp$inline_13427$$):$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$=$APP.$cljs$core$next$$($G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$)}$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$=
void 0}$JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$=$JSCompiler_temp_const$jscomp$11011_grammar$jscomp$15_line$jscomp$inline_13418_tramp$jscomp$58$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$,$index$jscomp$inline_13416_lc$jscomp$inline_8661_partial_QMARK_$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1588$text$$,$G__75744$jscomp$inline_13428_G__75746$jscomp$inline_13430_JSCompiler_inline_result$jscomp$11013_chars$jscomp$inline_13426_text$jscomp$103$$],null)]))}return $JSCompiler_temp$jscomp$1723_failure$jscomp$inline_8659_start$jscomp$236_temp__5823__auto__$jscomp$225$$};
$instaparse$gll$build_node_with_meta$$=function($node_builder$jscomp$4$$,$tag$jscomp$92$$,$content$jscomp$244$$,$start$jscomp$237$$,$end$jscomp$101$$){return $APP.$cljs$core$with_meta$$($node_builder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$node_builder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$92$$,$content$jscomp$244$$):$node_builder$jscomp$4$$($tag$jscomp$92$$,$content$jscomp$244$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$,
$start$jscomp$237$$,$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$,$end$jscomp$101$$],null))};
$instaparse$cfg$string_PLUS_$$=function($s$jscomp$570$$,$ci_by_default_QMARK_$$){var $G__76845$$=$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!0,$G__76845$$))return $instaparse$combinators_source$string_ci$$($s$jscomp$570$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$G__76845$$))return $instaparse$combinators_source$string$$($s$jscomp$570$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,
$G__76845$$))return $APP.$cljs$core$truth_$$($ci_by_default_QMARK_$$)?$instaparse$combinators_source$string_ci$$($s$jscomp$570$$):$instaparse$combinators_source$string$$($s$jscomp$570$$);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76845$$)].join(""));};
$instaparse$cfg$make_cfg$$=function($allow_namespaced_nts_QMARK_$$){return $instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5452$hiccup$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5462$neg$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5438$ord$$,$cljs$cst$5499$rule_separator$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5461$look$$,$cljs$cst$5500$rule$$,$cljs$cst$5460$nt$$,$cljs$cst$5501$hide_nt$$,$cljs$cst$5502$inside_comment$$,$cljs$cst$5456$star$$,$APP.$cljs$cst$198$string$$,
$APP.$cljs$cst$5503$rules$$,$APP.$cljs$cst$2345$hide$$,$cljs$cst$5504$paren$$,$cljs$cst$5505$alt_or_ord$$,$cljs$cst$5444$regexp$$,$cljs$cst$5506$factor$$,$APP.$cljs$cst$3432$comment$$,$cljs$cst$5455$plus$$,$cljs$cst$5454$epsilon$$,$cljs$cst$5498$opt_whitespace$$,$cljs$cst$5507$rules_or_parser$$,$APP.$cljs$cst$993$opt$$],[$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("!")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5506$factor$$)])),$instaparse$combinators_source$plus$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5506$factor$$),
$instaparse$combinators_source$nt$$($cljs$cst$5461$look$$),$instaparse$combinators_source$nt$$($cljs$cst$5462$neg$$)])),$instaparse$cfg$opt_whitespace$$]))),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$),$instaparse$combinators_source$plus$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,
$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("/")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$)])))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(":"),$instaparse$combinators_source$string$$(":\x3d"),$instaparse$combinators_source$string$$("::\x3d"),$instaparse$combinators_source$string$$("\x3d")])),
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("|")),$instaparse$cfg$opt_whitespace$$,
$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$)])))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x26")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5506$factor$$)])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5460$nt$$),
$instaparse$combinators_source$nt$$($cljs$cst$5501$hide_nt$$)])),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$nt$$($cljs$cst$5499$rule_separator$$)),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5505$alt_or_ord$$),$instaparse$combinators_source$hide$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5498$opt_whitespace$$),
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5498$opt_whitespace$$),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(";"),$instaparse$combinators_source$string$$(".")])),$instaparse$combinators_source$nt$$($cljs$cst$5498$opt_whitespace$$)]))])))])),
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$neg$$($instaparse$combinators_source$nt$$($cljs$cst$5454$epsilon$$)),$instaparse$combinators_source$regexp$$($APP.$cljs$core$truth_$$($allow_namespaced_nts_QMARK_$$)?$instaparse$cfg$non_terminal_namespace_allowed$$:$instaparse$cfg$non_terminal$$)])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3c")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5460$nt$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3e"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$inside_comment$$),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$3432$comment$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$inside_comment$$)])))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("{")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5505$alt_or_ord$$),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("}"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5506$factor$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("*"))]))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$single_quoted_string$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$double_quoted_string$$)])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$plus$$($instaparse$combinators_source$nt$$($cljs$cst$5500$rule$$))]))),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3c")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5505$alt_or_ord$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3e"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("(")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5505$alt_or_ord$$),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$(")"))])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$717$alt$$),$instaparse$combinators_source$nt$$($cljs$cst$5438$ord$$)]))),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$single_quoted_regexp$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$double_quoted_regexp$$)])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5460$nt$$),$instaparse$combinators_source$nt$$($APP.$cljs$cst$198$string$$),$instaparse$combinators_source$nt$$($cljs$cst$5444$regexp$$),$instaparse$combinators_source$nt$$($APP.$cljs$cst$993$opt$$),
$instaparse$combinators_source$nt$$($cljs$cst$5456$star$$),$instaparse$combinators_source$nt$$($cljs$cst$5455$plus$$),$instaparse$combinators_source$nt$$($cljs$cst$5504$paren$$),$instaparse$combinators_source$nt$$($APP.$cljs$cst$2345$hide$$),$instaparse$combinators_source$nt$$($cljs$cst$5454$epsilon$$)]))),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$("(*"),$instaparse$combinators_source$nt$$($cljs$cst$5502$inside_comment$$),
$instaparse$combinators_source$string$$("*)")])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5506$factor$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("+"))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$("Epsilon"),
$instaparse$combinators_source$string$$("epsilon"),$instaparse$combinators_source$string$$("EPSILON"),$instaparse$combinators_source$string$$("eps"),$instaparse$combinators_source$string$$("ε")])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$ws$$),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$3432$comment$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$ws$$)])))])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$5503$rules$$),$instaparse$combinators_source$nt$$($cljs$cst$5505$alt_or_ord$$)]))),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("[")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5505$alt_or_ord$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("]"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5506$factor$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("?"))]))]))]))};
$instaparse$cfg$escape$$=function($s$jscomp$571$$){for(var $G__77130_G__77132_G__77134_G__77139_sq$$=$APP.$cljs$core$seq$$($s$jscomp$571$$),$G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $c$jscomp$304_temp__5823__auto__$jscomp$228$$=$APP.$cljs$core$first$$($G__77130_G__77132_G__77134_G__77139_sq$$);if($APP.$cljs$core$truth_$$($c$jscomp$304_temp__5823__auto__$jscomp$228$$))switch($c$jscomp$304_temp__5823__auto__$jscomp$228$$){case "\\":var $c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$=
$APP.$cljs$core$second$$($G__77130_G__77132_G__77134_G__77139_sq$$);if($APP.$cljs$core$truth_$$($c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$)){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$,"'")?($G__77130_G__77132_G__77134_G__77139_sq$$=$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$G__77130_G__77132_G__77134_G__77139_sq$$),$G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$,
$c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$)):($G__77130_G__77132_G__77134_G__77139_sq$$=$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$G__77130_G__77132_G__77134_G__77139_sq$$),$G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$,$c$jscomp$304_temp__5823__auto__$jscomp$228$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$])));
continue}else return $instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Encountered backslash character at end of string: ",$s$jscomp$571$$]));break;case '"':$G__77130_G__77132_G__77134_G__77139_sq$$=$APP.$cljs$core$next$$($G__77130_G__77132_G__77134_G__77139_sq$$);$G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$,
"\\",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['"']));continue;default:$G__77130_G__77132_G__77134_G__77139_sq$$=$APP.$cljs$core$next$$($G__77130_G__77132_G__77134_G__77139_sq$$);$G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$,$c$jscomp$304_temp__5823__auto__$jscomp$228$$);continue}else return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$G__77131_G__77133_G__77135_G__77140_v$jscomp$655$$);break}};
$instaparse$cfg$process_string$$=function($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$){$G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$,1,$APP.$cljs$core$count$$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$)-1);
$G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$=$instaparse$cfg$escape$$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$);$G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$),'"'].join("");
$G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$=new $APP.$cljs$tools$reader$reader_types$PushbackReader$$(new $APP.$cljs$tools$reader$reader_types$StringReader$$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$,$APP.$cljs$core$count$$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$)));return $read_string_STAR__77141$$.$cljs$core$IFn$_invoke$arity$4$?
$read_string_STAR__77141$$.$cljs$core$IFn$_invoke$arity$4$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$,null,null,null):$read_string_STAR__77141$$($G__76928$jscomp$inline_8676_remove_escaped_single_quotes_s$jscomp$573_s$jscomp$inline_8675_stripped$$,null,null,null)};
$instaparse$cfg$process_regexp$$=function($remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$){$remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$,2,$APP.$cljs$core$count$$($remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$)-1);$remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$=$instaparse$cfg$escape$$($remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$);
return $APP.$cljs$core$re_pattern$$($remove_escaped_single_quotes$jscomp$1_s$jscomp$574_stripped$jscomp$1$$)};
$instaparse$cfg$check_grammar$$=function($grammar_map$$){for(var $valid_nts_77168$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($grammar_map$$)),$c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$=$APP.$cljs$core$seq$$($APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($grammar_map$$)])))),
$G__77197_chunk__76956_77171_seq__76955_77190__$1$$=null,$G__77198_count__76957_77172$$=0,$G__77196_i__76958_77173$$=0;;)if($G__77196_i__76958_77173$$<$G__77198_count__76957_77172$$){var $nt_77180$$=$G__77197_chunk__76956_77171_seq__76955_77190__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77196_i__76958_77173$$);$APP.$cljs$core$truth_$$($valid_nts_77168$$.$cljs$core$IFn$_invoke$arity$1$?$valid_nts_77168$$.$cljs$core$IFn$_invoke$arity$1$($nt_77180$$):$valid_nts_77168$$($nt_77180$$))||$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($nt_77180$$),
1)," occurs on the right-hand side of your grammar, but not on the left"]));$G__77196_i__76958_77173$$+=1}else if($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$=$APP.$cljs$core$seq$$($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$))$G__77197_chunk__76956_77171_seq__76955_77190__$1$$=$c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77197_chunk__76956_77171_seq__76955_77190__$1$$)?
($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$=$APP.$cljs$core$_chunked_first$$($G__77197_chunk__76956_77171_seq__76955_77190__$1$$),$G__77196_i__76958_77173$$=$APP.$cljs$core$_chunked_rest$$($G__77197_chunk__76956_77171_seq__76955_77190__$1$$),$G__77197_chunk__76956_77171_seq__76955_77190__$1$$=$c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$,$G__77198_count__76957_77172$$=$APP.$cljs$core$count$$($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$),
$c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$=$G__77196_i__76958_77173$$):($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$=$APP.$cljs$core$first$$($G__77197_chunk__76956_77171_seq__76955_77190__$1$$),$APP.$cljs$core$truth_$$($valid_nts_77168$$.$cljs$core$IFn$_invoke$arity$1$?$valid_nts_77168$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$):$valid_nts_77168$$($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$))||
$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$),1)," occurs on the right-hand side of your grammar, but not on the left"])),$c__5548__auto___77191_nt_77201_seq__76955_77170_temp__5825__auto___77189$$=$APP.$cljs$core$next$$($G__77197_chunk__76956_77171_seq__76955_77190__$1$$),
$G__77197_chunk__76956_77171_seq__76955_77190__$1$$=null,$G__77198_count__76957_77172$$=0),$G__77196_i__76958_77173$$=0;else break;return $grammar_map$$};
$instaparse$cfg$build_parser$cljs$0core$0IFn$0_invoke$0arity$03$$=function($productions_spec$jscomp$47$$,$output_format$jscomp$1$$,$allow_namespaced_nts_QMARK_$jscomp$1_start_production$$){var $rules$$=$instaparse$gll$parse$$($APP.$cljs$core$truth_$$($allow_namespaced_nts_QMARK_$jscomp$1_start_production$$)?$instaparse$cfg$cfg_allow_namespaced_nts$$:$instaparse$cfg$cfg$$,$APP.$cljs$cst$5503$rules$$,$productions_spec$jscomp$47$$,!1);if($rules$$ instanceof $instaparse$gll$Failure$$)return $instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Error parsing grammar specification:\n",
function(){var $sb__5670__auto__$jscomp$10$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__76978_77210$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__76979_77211$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$11$$){return $sb__5670__auto__$jscomp$10$$.append($x__5671__auto__$jscomp$11$$)};try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$rules$$]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__76979_77211$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__76978_77210$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$10$$)}()]));$productions_spec$jscomp$47$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,$rules$$);$allow_namespaced_nts_QMARK_$jscomp$1_start_production$$=$APP.$cljs$core$first$$($APP.$cljs$core$first$$($productions_spec$jscomp$47$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5447$grammar$$,$instaparse$cfg$check_grammar$$($instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($output_format$jscomp$1$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$productions_spec$jscomp$47$$))),$cljs$cst$5448$start_production$$,$allow_namespaced_nts_QMARK_$jscomp$1_start_production$$,$cljs$cst$5513$output_format$$,$output_format$jscomp$1$$],null)};
$instaparse$cfg$build_parser_from_combinators$$=function($grammar_map$jscomp$1$$,$output_format$jscomp$2$$,$start_production$jscomp$1$$){return $start_production$jscomp$1$$==null?$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["When you build a parser from a map of parser combinators, you must provide a start production using the :start keyword argument."])):new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5447$grammar$$,$instaparse$cfg$check_grammar$$($instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($output_format$jscomp$2$$,$grammar_map$jscomp$1$$)),$cljs$cst$5448$start_production$$,$start_production$jscomp$1$$,$cljs$cst$5513$output_format$$,$output_format$jscomp$2$$],null)};
$instaparse$transform$merge_meta$$=function($obj$jscomp$217$$,$metamap$jscomp$4$$){return($obj$jscomp$217$$!=null?$obj$jscomp$217$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$217$$.$cljs$core$IWithMeta$$||($obj$jscomp$217$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$217$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$217$$))?$APP.$cljs$core$with_meta$$($obj$jscomp$217$$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$metamap$jscomp$4$$,$APP.$cljs$core$meta$$($obj$jscomp$217$$)]))):$obj$jscomp$217$$};
$instaparse$abnf$project$$=function($m$jscomp$228$$,$ks$jscomp$63$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $instaparse$abnf$project_$_iter__77534$$($s__77535$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$=$s__77535$$;;)if($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$=$APP.$cljs$core$seq$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$)){var $JSCompiler_inline_result$jscomp$1742_c__5501__auto__$jscomp$46$$=
$APP.$cljs$core$_chunked_first$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$),$size__5502__auto__$jscomp$46$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1742_c__5501__auto__$jscomp$46$$),$b__77537_k$jscomp$682$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$46$$);a:{for(var $i__77536$jscomp$inline_8687$$=0;;)if($i__77536$jscomp$inline_8687$$<$size__5502__auto__$jscomp$46$$){var $k$jscomp$inline_8688_x$jscomp$inline_13445$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1742_c__5501__auto__$jscomp$46$$,
$i__77536$jscomp$inline_8687$$);if($APP.$cljs$core$contains_QMARK_$$($m$jscomp$228$$,$k$jscomp$inline_8688_x$jscomp$inline_13445$$)){var $b$jscomp$inline_13444$$=$b__77537_k$jscomp$682$$;$k$jscomp$inline_8688_x$jscomp$inline_13445$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8688_x$jscomp$inline_13445$$,$m$jscomp$228$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$228$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8688_x$jscomp$inline_13445$$):
$m$jscomp$228$$($k$jscomp$inline_8688_x$jscomp$inline_13445$$)],null);$b$jscomp$inline_13444$$.add($k$jscomp$inline_8688_x$jscomp$inline_13445$$)}$i__77536$jscomp$inline_8687$$+=1}else{$JSCompiler_inline_result$jscomp$1742_c__5501__auto__$jscomp$46$$=!0;break a}$JSCompiler_inline_result$jscomp$1742_c__5501__auto__$jscomp$46$$=void 0}return $JSCompiler_inline_result$jscomp$1742_c__5501__auto__$jscomp$46$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77537_k$jscomp$682$$),$instaparse$abnf$project_$_iter__77534$$($APP.$cljs$core$_chunked_rest$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77537_k$jscomp$682$$),null)}$b__77537_k$jscomp$682$$=$APP.$cljs$core$first$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$);if($APP.$cljs$core$contains_QMARK_$$($m$jscomp$228$$,$b__77537_k$jscomp$682$$))return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__77537_k$jscomp$682$$,$m$jscomp$228$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$228$$.$cljs$core$IFn$_invoke$arity$1$($b__77537_k$jscomp$682$$):
$m$jscomp$228$$($b__77537_k$jscomp$682$$)],null),$instaparse$abnf$project_$_iter__77534$$($APP.$cljs$core$rest$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$)));$s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$=$APP.$cljs$core$rest$$($s__77535__$1_s__77535__$2_temp__5825__auto__$jscomp$346$$)}else return null},null,null)}($ks$jscomp$63$$)}())};
$instaparse$abnf$merge_core$$=function($grammar_map$jscomp$2$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$abnf$project$$($instaparse$abnf$abnf_core$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($grammar_map$jscomp$2$$)])))),
$grammar_map$jscomp$2$$]))};
$instaparse$abnf$alt_preserving_hide_tag$$=function($p1$jscomp$82$$,$p2$jscomp$63$$){var $hide_tag_p1_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$82$$),$instaparse$reduction$raw_non_terminal_reduction$$),$hide_tag_p2_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$63$$),$instaparse$reduction$raw_non_terminal_reduction$$);return $hide_tag_p1_QMARK_$$&&
$hide_tag_p2_QMARK_$$?$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$82$$,$APP.$cljs$cst$5446$red$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$63$$,$APP.$cljs$cst$5446$red$$)]))):$hide_tag_p1_QMARK_$$?$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$82$$,
$APP.$cljs$cst$5446$red$$),$p2$jscomp$63$$]))):$hide_tag_p2_QMARK_$$?$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1$jscomp$82$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$63$$,$APP.$cljs$cst$5446$red$$)]))):$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1$jscomp$82$$,
$p2$jscomp$63$$]))};
$instaparse$abnf$build_parser$$=function($grammar_map$jscomp$3_spec$jscomp$50$$,$output_format$jscomp$3$$){var $rule_tree$$=$instaparse$gll$parse$$($instaparse$abnf$abnf_parser$$,$cljs$cst$5549$rulelist$$,$grammar_map$jscomp$3_spec$jscomp$50$$,!1);if($rule_tree$$ instanceof $instaparse$gll$Failure$$)return $instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Error parsing grammar specification:\n",function(){var $sb__5670__auto__$jscomp$13$$=
new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__77571_77659$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__77572_77660$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$14$$){return $sb__5670__auto__$jscomp$13$$.append($x__5671__auto__$jscomp$14$$)};try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$rule_tree$$]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__77572_77660$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__77571_77659$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$13$$)}()]));var $rules$jscomp$3_start_production$jscomp$2$$=$instaparse$transform$transform$$($instaparse$abnf$abnf_transformer$$,$rule_tree$$);$grammar_map$jscomp$3_spec$jscomp$50$$=$instaparse$abnf$merge_core$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge_with$$,
$instaparse$abnf$alt_preserving_hide_tag$$,$rules$jscomp$3_start_production$jscomp$2$$));$rules$jscomp$3_start_production$jscomp$2$$=$APP.$cljs$core$first$$($APP.$cljs$core$first$$($APP.$cljs$core$first$$($rules$jscomp$3_start_production$jscomp$2$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5447$grammar$$,$instaparse$cfg$check_grammar$$($instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($output_format$jscomp$3$$,$grammar_map$jscomp$3_spec$jscomp$50$$)),
$cljs$cst$5448$start_production$$,$rules$jscomp$3_start_production$jscomp$2$$,$cljs$cst$5513$output_format$$,$output_format$jscomp$3$$],null)};
$instaparse$viz$span$$=function($s$jscomp$575_tree$jscomp$22$$){var $e$jscomp$342_m$jscomp$229$$=$APP.$cljs$core$meta$$($s$jscomp$575_tree$jscomp$22$$);$s$jscomp$575_tree$jscomp$22$$=$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$342_m$jscomp$229$$);$e$jscomp$342_m$jscomp$229$$=$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$342_m$jscomp$229$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($s$jscomp$575_tree$jscomp$22$$)?
$e$jscomp$342_m$jscomp$229$$:$s$jscomp$575_tree$jscomp$22$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$575_tree$jscomp$22$$,$e$jscomp$342_m$jscomp$229$$],null):null};
$instaparse$repeat$empty_result_QMARK_$$=function($result$jscomp$359$$){return $APP.$cljs$core$vector_QMARK_$$($result$jscomp$359$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($result$jscomp$359$$),1)||$APP.$cljs$core$map_QMARK_$$($result$jscomp$359$$)&&$APP.$cljs$core$contains_QMARK_$$($result$jscomp$359$$,$APP.$cljs$cst$78$tag$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$359$$,$APP.$cljs$cst$1637$content$$))||
$APP.$cljs$core$empty_QMARK_$$($result$jscomp$359$$)};
$instaparse$repeat$parse_from_index$$=function($grammar$jscomp$20_tramp$jscomp$61$$,$initial_parser$$,$text$jscomp$109$$,$segment$jscomp$50$$,$index$jscomp$453$$){$grammar$jscomp$20_tramp$jscomp$61$$=$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$20_tramp$jscomp$61$$,$text$jscomp$109$$,$segment$jscomp$50$$,-1,null);$instaparse$gll$push_listener$$($grammar$jscomp$20_tramp$jscomp$61$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$453$$,$initial_parser$$],null),$instaparse$gll$TopListener$$($grammar$jscomp$20_tramp$jscomp$61$$));return $instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($grammar$jscomp$20_tramp$jscomp$61$$,null)};
$instaparse$repeat$select_parse$$=function($grammar$jscomp$21$$,$initial_parser$jscomp$1$$,$text$jscomp$110$$,$segment$jscomp$51$$,$index$jscomp$454$$,$parses_parses__$1$$){var $length$jscomp$54$$=$APP.$cljs$core$count$$($text$jscomp$110$$);for($parses_parses__$1$$=$APP.$cljs$core$seq$$($parses_parses__$1$$);;)if($parses_parses__$1$$){var $parse$jscomp$7$$=$APP.$cljs$core$first$$($parses_parses__$1$$),$end$jscomp$104_end__$1_vec__76858$$=$instaparse$viz$span$$($parse$jscomp$7$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$104_end__$1_vec__76858$$,
0,null);$end$jscomp$104_end__$1_vec__76858$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$104_end__$1_vec__76858$$,1,null);$end$jscomp$104_end__$1_vec__76858$$=$APP.$cljs$core$truth_$$($end$jscomp$104_end__$1_vec__76858$$)?$end$jscomp$104_end__$1_vec__76858$$:$index$jscomp$454$$+$APP.$cljs$core$count$$($parse$jscomp$7$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$104_end__$1_vec__76858$$,$length$jscomp$54$$))return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parse$jscomp$7$$,$end$jscomp$104_end__$1_vec__76858$$,null],null);var $temp__5823__auto__$jscomp$230$$=$APP.$cljs$core$seq$$($instaparse$repeat$parse_from_index$$($grammar$jscomp$21$$,$initial_parser$jscomp$1$$,$text$jscomp$110$$,$segment$jscomp$51$$,$end$jscomp$104_end__$1_vec__76858$$));if($temp__5823__auto__$jscomp$230$$)return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parse$jscomp$7$$,$end$jscomp$104_end__$1_vec__76858$$,
$temp__5823__auto__$jscomp$230$$],null);$parses_parses__$1$$=$APP.$cljs$core$next$$($parses_parses__$1$$)}else return null};
$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$=function($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$116$$,$segment$jscomp$57$$,$G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$){var $length$jscomp$57$$=$APP.$cljs$core$count$$($text$jscomp$116$$),$G__76972_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$=$instaparse$repeat$parse_from_index$$($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$116$$,
$segment$jscomp$57$$,$G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$);$G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$=$APP.$cljs$core$fix$$($G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$);var $G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$=$instaparse$repeat$select_parse$$($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$116$$,$segment$jscomp$57$$,$G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$,
$G__76972_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$,2,null);$G__76972_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$=$G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$;
for($G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$=$instaparse$auto_flatten_seq$EMPTY$$;;){var $vec__76918$$=$G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$,$parse__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__76918$$,0,null);$G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__76918$$,1,null);var $follow_ups__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__76918$$,
2,null);if($vec__76918$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__76972_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$,$G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$))return $instaparse$repeat$failure_signal$$;if($follow_ups__$1$jscomp$2$$==null)return $instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$conj_flat$$($G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$,$parse__$1$jscomp$2$$),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5554$optimize$$,$cljs$cst$5555$memory$$,$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$57$$],null));$G__76972_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$=$APP.$cljs$core$fix$$($G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$);$G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$=$instaparse$auto_flatten_seq$conj_flat$$($G__76973_index$jscomp$457_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$,
$parse__$1$jscomp$2$$);$G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$=$instaparse$repeat$select_parse$$($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$116$$,$segment$jscomp$57$$,$G__76910_G__76910__$1_G__76974_end__$1$jscomp$3$$,$follow_ups__$1$jscomp$2$$)}};
$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$=function($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$,$G__76961$jscomp$inline_13466_index__$2$jscomp$inline_13457_index__$3$jscomp$inline_13460_root_tag$jscomp$4$$,$text$jscomp$118$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$,
$cljs$cst$5452$hiccup$$))a:{$length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$=$APP.$cljs$core$count$$($text$jscomp$118$$);var $G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$=$instaparse$repeat$parse_from_index$$($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,
$text$jscomp$118$$,$text$jscomp$118$$,0),$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$=$APP.$cljs$core$fix$$(0),$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=
$instaparse$auto_flatten_seq$auto_flatten_seq$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__76961$jscomp$inline_13466_index__$2$jscomp$inline_13457_index__$3$jscomp$inline_13460_root_tag$jscomp$4$$],null));$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,
$initial_parser$jscomp$9$$,$text$jscomp$118$$,$text$jscomp$118$$,$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$,$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$);
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,2,null);$G__76961$jscomp$inline_13466_index__$2$jscomp$inline_13457_index__$3$jscomp$inline_13460_root_tag$jscomp$4$$=$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$;
$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$=$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$;for($G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=
$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$;;){var $parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$=$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$,
$follow_ups__$1$jscomp$inline_13487_parse__$1$jscomp$inline_13463$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$,0,null);$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$,
1,null);$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$,2,null);if($parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__76961$jscomp$inline_13466_index__$2$jscomp$inline_13457_index__$3$jscomp$inline_13460_root_tag$jscomp$4$$,
$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$)){$JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=$instaparse$repeat$failure_signal$$;break a}if($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$==
null){$JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=$instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$convert_afs_to_vec$$($instaparse$auto_flatten_seq$conj_flat$$($G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$,$follow_ups__$1$jscomp$inline_13487_parse__$1$jscomp$inline_13463$$)),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5554$optimize$$,$cljs$cst$5555$memory$$,$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$],null));break a}$G__76961$jscomp$inline_13466_index__$2$jscomp$inline_13457_index__$3$jscomp$inline_13460_root_tag$jscomp$4$$=$APP.$cljs$core$fix$$($G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$);
$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$=$instaparse$auto_flatten_seq$conj_flat$$($G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$,
$follow_ups__$1$jscomp$inline_13487_parse__$1$jscomp$inline_13463$$);$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$118$$,$text$jscomp$118$$,$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$,
$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$)}$JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=void 0}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$,$cljs$cst$5453$enlive$$))a:{$length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$=
$APP.$cljs$core$count$$($text$jscomp$118$$);$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=$instaparse$repeat$parse_from_index$$($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$118$$,$text$jscomp$118$$,0);$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$=
$APP.$cljs$core$fix$$(0);$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$118$$,$text$jscomp$118$$,$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$,
$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,
2,null);for($G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=$instaparse$auto_flatten_seq$EMPTY$$;;){var $vec__76896$jscomp$inline_13484$$=$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$;
$parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__76896$jscomp$inline_13484$$,0,null);$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__76896$jscomp$inline_13484$$,1,null);$follow_ups__$1$jscomp$inline_13487_parse__$1$jscomp$inline_13463$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__76896$jscomp$inline_13484$$,2,null);if($vec__76896$jscomp$inline_13484$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$,$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$)){$JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=
$instaparse$repeat$failure_signal$$;break a}if($follow_ups__$1$jscomp$inline_13487_parse__$1$jscomp$inline_13463$$==null){$JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=$instaparse$gll$safe_with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$G__76961$jscomp$inline_13466_index__$2$jscomp$inline_13457_index__$3$jscomp$inline_13460_root_tag$jscomp$4$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$seq$$($instaparse$auto_flatten_seq$conj_flat$$($G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$,
$parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$))],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5554$optimize$$,$cljs$cst$5555$memory$$,$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$inline_13452_length$jscomp$inline_13475_output_format$jscomp$5$$],null));break a}$G__76962$jscomp$inline_13467_G__76966$jscomp$inline_13488_index__$1$jscomp$inline_13454_index__$1$jscomp$inline_13477_index__$2$jscomp$inline_13479_index__$3$jscomp$inline_13482_parses__$1$jscomp$inline_13458_parses__$2$jscomp$inline_13461$$=
$APP.$cljs$core$fix$$($G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$);$G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$=$instaparse$auto_flatten_seq$conj_flat$$($G__76867__$1$jscomp$inline_13459_G__76963$jscomp$inline_13468_G__76967$jscomp$inline_13489_end__$1$jscomp$inline_13464_first_result$jscomp$inline_13476_parses$jscomp$inline_13455_parses__$1$jscomp$inline_13480_parses__$2$jscomp$inline_13483$$,
$parse__$1$jscomp$inline_13485_vec__76875$jscomp$inline_13462$$);$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$118$$,$text$jscomp$118$$,$G__76867$jscomp$inline_13456_G__76887$jscomp$inline_13478_G__76887__$1$jscomp$inline_13481_G__76968$jscomp$inline_13490_end__$1$jscomp$inline_13486_first_result$jscomp$inline_13453_follow_ups__$1$jscomp$inline_13465$$,
$follow_ups__$1$jscomp$inline_13487_parse__$1$jscomp$inline_13463$$)}$JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=void 0}else $JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$=null;return $JSCompiler_temp$jscomp$11019_JSCompiler_temp$jscomp$11020_grammar$jscomp$29$$};
$instaparse$repeat$repeat_parse_with_header$$=function($grammar$jscomp$30_repeat_result$$,$JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$,$repeating_parser$$,$output_format$jscomp$6$$,$root_tag$jscomp$5$$,$text$jscomp$119$$){var $length$jscomp$58_span_meta$$=$APP.$cljs$core$count$$($text$jscomp$119$$),$header_result_header_results$$=$instaparse$repeat$parse_from_index$$($grammar$jscomp$30_repeat_result$$,$JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$,$text$jscomp$119$$,
$text$jscomp$119$$,0),$or__5025__auto__$jscomp$inline_8690$$=$APP.$cljs$core$empty_QMARK_$$($header_result_header_results$$);$JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$=$or__5025__auto__$jscomp$inline_8690$$?$or__5025__auto__$jscomp$inline_8690$$:$APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$))return $instaparse$repeat$failure_signal$$;
$header_result_header_results$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$max_key$$,$instaparse$repeat$get_end$$,$header_result_header_results$$);$JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$=$instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$1$($header_result_header_results$$);$grammar$jscomp$30_repeat_result$$=$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$30_repeat_result$$,$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$$),
$text$jscomp$119$$,$text$jscomp$119$$,$JSCompiler_inline_result$jscomp$1744_end$jscomp$108_header_parser$$);$length$jscomp$58_span_meta$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5554$optimize$$,$cljs$cst$5555$memory$$,$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$58_span_meta$$],null);if($grammar$jscomp$30_repeat_result$$ instanceof $instaparse$gll$Failure$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$$),
$cljs$cst$5456$star$$)&&$instaparse$repeat$empty_result_QMARK_$$($grammar$jscomp$30_repeat_result$$))return $instaparse$repeat$failure_signal$$;switch($output_format$jscomp$6$$ instanceof $APP.$cljs$core$Keyword$$?$output_format$jscomp$6$$.$fqn$:null){case "enlive":return $instaparse$gll$safe_with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$root_tag$jscomp$5$$,$APP.$cljs$cst$1637$content$$,$instaparse$auto_flatten_seq$conj_flat$$($instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,
$header_result_header_results$$),$grammar$jscomp$30_repeat_result$$)],null),$length$jscomp$58_span_meta$$);case "hiccup":return $instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$convert_afs_to_vec$$($instaparse$auto_flatten_seq$conj_flat$$($instaparse$auto_flatten_seq$auto_flatten_seq$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$root_tag$jscomp$5$$],null)).$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$header_result_header_results$$),
$grammar$jscomp$30_repeat_result$$)),$length$jscomp$58_span_meta$$);default:return $instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$conj_flat$$($instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$header_result_header_results$$),$grammar$jscomp$30_repeat_result$$),$length$jscomp$58_span_meta$$)}};
$instaparse$repeat$try_repeating_parse_strategy_with_header$$=function($grammar$jscomp$31$$,$text$jscomp$120$$,$start_production$jscomp$3$$,$start_rule$$,$output_format$jscomp$7$$){var $header_parser$jscomp$1_parsers$jscomp$14$$=$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$$),$repeating_parser$jscomp$1$$=$APP.$cljs$core$last$$($header_parser$jscomp$1_parsers$jscomp$14$$),$G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$;
if($G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$$),$APP.$cljs$cst$594$cat$$)){$G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$jscomp$1$$);
var $fexpr__76938$jscomp$inline_13495$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5456$star$$,null,$cljs$cst$5455$plus$$,null],null),null);$G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$=$fexpr__76938$jscomp$inline_13495$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__76938$jscomp$inline_13495$$.$cljs$core$IFn$_invoke$arity$1$($G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$):
$fexpr__76938$jscomp$inline_13495$$($G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$);$G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$=$APP.$cljs$core$truth_$$($G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$)?
$APP.$cljs$core$not$$($APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$jscomp$1$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$jscomp$1$$))):$G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$}if($APP.$cljs$core$not$$($G__76939$jscomp$inline_13494_JSCompiler_inline_result$jscomp$11021_and__5023__auto__$jscomp$inline_13492_and__5023__auto____$1$jscomp$inline_13493$$))return $instaparse$repeat$failure_signal$$;
$header_parser$jscomp$1_parsers$jscomp$14$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$cat$$,$APP.$cljs$core$butlast$$($header_parser$jscomp$1_parsers$jscomp$14$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$$),$instaparse$reduction$raw_non_terminal_reduction$$)?$instaparse$repeat$repeat_parse_with_header$$($grammar$jscomp$31$$,$header_parser$jscomp$1_parsers$jscomp$14$$,
$repeating_parser$jscomp$1$$,null,$start_production$jscomp$3$$,$text$jscomp$120$$):$instaparse$repeat$repeat_parse_with_header$$($grammar$jscomp$31$$,$header_parser$jscomp$1_parsers$jscomp$14$$,$repeating_parser$jscomp$1$$,$output_format$jscomp$7$$,$start_production$jscomp$3$$,$text$jscomp$120$$)};
$instaparse$repeat$try_repeating_parse_strategy$$=function($output_format$jscomp$8_parser$jscomp$62$$,$result$jscomp$360_text$jscomp$121$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$){var $grammar$jscomp$32$$=$cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($output_format$jscomp$8_parser$jscomp$62$$);$output_format$jscomp$8_parser$jscomp$62$$=$cljs$cst$5513$output_format$$.$cljs$core$IFn$_invoke$arity$1$($output_format$jscomp$8_parser$jscomp$62$$);
var $start_rule$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grammar$jscomp$32$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),!0)?$instaparse$repeat$failure_signal$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),
$instaparse$reduction$raw_non_terminal_reduction$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5456$star$$)?($initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$,
$result$jscomp$360_text$jscomp$121$$,$result$jscomp$360_text$jscomp$121$$,0)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5455$plus$$)?($initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$result$jscomp$360_text$jscomp$121$$=$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,
$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$,$result$jscomp$360_text$jscomp$121$$,$result$jscomp$360_text$jscomp$121$$,0),$instaparse$repeat$empty_result_QMARK_$$($result$jscomp$360_text$jscomp$121$$)?$instaparse$repeat$failure_signal$$:$result$jscomp$360_text$jscomp$121$$):$instaparse$repeat$try_repeating_parse_strategy_with_header$$($grammar$jscomp$32$$,$result$jscomp$360_text$jscomp$121$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$,
$start_rule$jscomp$1$$,$output_format$jscomp$8_parser$jscomp$62$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5456$star$$)?$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$output_format$jscomp$8_parser$jscomp$62$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$,
$result$jscomp$360_text$jscomp$121$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5455$plus$$)?($result$jscomp$360_text$jscomp$121$$=$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$output_format$jscomp$8_parser$jscomp$62$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$,
$result$jscomp$360_text$jscomp$121$$),$instaparse$repeat$empty_result_QMARK_$$($result$jscomp$360_text$jscomp$121$$)?$instaparse$repeat$failure_signal$$:$result$jscomp$360_text$jscomp$121$$):$instaparse$repeat$try_repeating_parse_strategy_with_header$$($grammar$jscomp$32$$,$result$jscomp$360_text$jscomp$121$$,$initial_parser$jscomp$inline_8696_initial_parser$jscomp$inline_8700_start_production$jscomp$4$$,$start_rule$jscomp$1$$,$output_format$jscomp$8_parser$jscomp$62$$)};
$instaparse$core$unhide_parser$$=function($parser$jscomp$63$$,$unhide$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$unhide$$))return $parser$jscomp$63$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$,$unhide$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$63$$,$cljs$cst$5447$grammar$$,$instaparse$combinators_source$unhide_all_content$$($cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$)));
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3142$tags$$,$unhide$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$63$$,$cljs$cst$5447$grammar$$,$instaparse$combinators_source$unhide_tags$$($cljs$cst$5513$output_format$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$),$cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2124$all$$,$unhide$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$63$$,
$cljs$cst$5447$grammar$$,$instaparse$combinators_source$unhide_all$$($cljs$cst$5513$output_format$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$),$cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$)));throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($unhide$$)].join(""));};
$instaparse$core$Parser$$=function($grammar$jscomp$33$$,$start_production$jscomp$7$$,$output_format$jscomp$9$$,$__meta$jscomp$39$$,$__extmap$jscomp$39$$,$__hash$jscomp$98$$){this.$grammar$=$grammar$jscomp$33$$;this.$start_production$=$start_production$jscomp$7$$;this.$output_format$=$output_format$jscomp$9$$;this.$__meta$=$__meta$jscomp$39$$;this.$__extmap$=$__extmap$jscomp$39$$;this.$__hash$=$__hash$jscomp$98$$;this.$cljs$lang$protocol_mask$partition0$$=2230716171;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$instaparse$core$map__GT_Parser$$=function($G__77950$$){var $G__77990$jscomp$inline_8703_extmap__5365__auto__$jscomp$39$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__77950$$,$cljs$cst$5447$grammar$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5448$start_production$$,$cljs$cst$5513$output_format$$]));$G__77990$jscomp$inline_8703_extmap__5365__auto__$jscomp$39$$=$APP.$cljs$core$record_QMARK_$$($G__77950$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__77990$jscomp$inline_8703_extmap__5365__auto__$jscomp$39$$):
$G__77990$jscomp$inline_8703_extmap__5365__auto__$jscomp$39$$;return new $instaparse$core$Parser$$($cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__77950$$),$cljs$cst$5448$start_production$$.$cljs$core$IFn$_invoke$arity$1$($G__77950$$),$cljs$cst$5513$output_format$$.$cljs$core$IFn$_invoke$arity$1$($G__77950$$),null,$APP.$cljs$core$not_empty$$($G__77990$jscomp$inline_8703_extmap__5365__auto__$jscomp$39$$),null)};
$instaparse$core$parser$$=function($var_args$jscomp$1446$$){for(var $args__5755__auto__$jscomp$253$$=[],$len__5749__auto___78042$$=arguments.length,$i__5750__auto___78043$$=0;;)if($i__5750__auto___78043$$<$len__5749__auto___78042$$)$args__5755__auto__$jscomp$253$$.push(arguments[$i__5750__auto___78043$$]),$i__5750__auto___78043$$+=1;else break;return $instaparse$core$parser$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$253$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$253$$.slice(1),
0,null):null)};
$instaparse$core$parser$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($grammar_specification$$,$built_parser_p__77995$$){var $options$jscomp$605$$=$APP.$cljs$core$__destructure_map$$($built_parser_p__77995$$),$input_format$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$605$$,$cljs$cst$5565$input_format$$,$cljs$cst$5561$ebnf$$),$output_format$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$605$$,$cljs$cst$5513$output_format$$,$cljs$cst$5452$hiccup$$),
$start$jscomp$246$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$605$$,$APP.$cljs$cst$1292$start$$,null);$built_parser_p__77995$$=typeof $grammar_specification$$==="string"?function(){a:{var $_STAR_case_insensitive_literals_STAR__orig_val__77998$jscomp$inline_8707$$=$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$;$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$=$cljs$cst$5458$string_ci$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$605$$,$APP.$cljs$cst$205$default$$);
try{var $G__78000__$1$jscomp$inline_8708$$=$input_format$$ instanceof $APP.$cljs$core$Keyword$$?$input_format$$.$fqn$:null;switch($G__78000__$1$jscomp$inline_8708$$){case "abnf":var $parser$jscomp$78$$=$instaparse$abnf$build_parser$$($grammar_specification$$,$output_format$jscomp$11$$);break a;case "ebnf":$parser$jscomp$78$$=$instaparse$cfg$build_parser$cljs$0core$0IFn$0_invoke$0arity$03$$($grammar_specification$$,$output_format$jscomp$11$$,$cljs$cst$5566$allow_namespaced_nts$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$605$$,
!1));break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78000__$1$jscomp$inline_8708$$)].join(""));}}finally{$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$=$_STAR_case_insensitive_literals_STAR__orig_val__77998$jscomp$inline_8707$$}$parser$jscomp$78$$=void 0}return $APP.$cljs$core$truth_$$($start$jscomp$246$$)?$instaparse$core$map__GT_Parser$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$78$$,$cljs$cst$5448$start_production$$,
$start$jscomp$246$$)):$instaparse$core$map__GT_Parser$$($parser$jscomp$78$$)}():$APP.$cljs$core$map_QMARK_$$($grammar_specification$$)?function(){var $parser$jscomp$79$$=$instaparse$cfg$build_parser_from_combinators$$($grammar_specification$$,$output_format$jscomp$11$$,$start$jscomp$246$$);return $instaparse$core$map__GT_Parser$$($parser$jscomp$79$$)}():$APP.$cljs$core$vector_QMARK_$$($grammar_specification$$)?function(){var $parser$jscomp$80_start__$1$jscomp$14$$=$APP.$cljs$core$truth_$$($start$jscomp$246$$)?
$start$jscomp$246$$:$grammar_specification$$.$cljs$core$IFn$_invoke$arity$1$?$grammar_specification$$.$cljs$core$IFn$_invoke$arity$1$(0):$grammar_specification$$(0);$parser$jscomp$80_start__$1$jscomp$14$$=$instaparse$cfg$build_parser_from_combinators$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$hash_map$$,$grammar_specification$$),$output_format$jscomp$11$$,$parser$jscomp$80_start__$1$jscomp$14$$);return $instaparse$core$map__GT_Parser$$($parser$jscomp$80_start__$1$jscomp$14$$)}():
$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Expected string, map, or vector as grammar specification, got ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$grammar_specification$$]))]));var $auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$605$$,
$cljs$cst$5567$auto_whitespace$$);$auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$=$auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$core$standard_whitespace_parsers$$,$auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$):$auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$;if($APP.$cljs$core$truth_$$($auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$)){var $map__78003__$1_ws_start$$=
$APP.$cljs$core$__destructure_map$$($auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$);$auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78003__$1_ws_start$$,$cljs$cst$5447$grammar$$);$map__78003__$1_ws_start$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78003__$1_ws_start$$,$cljs$cst$5448$start_production$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($built_parser_p__77995$$,$cljs$cst$5447$grammar$$,
$instaparse$combinators_source$auto_whitespace$$($built_parser_p__77995$$.$grammar$,$built_parser_p__77995$$.$start_production$,$auto_whitespace_temp__5823__auto__$jscomp$231_ws_grammar$$,$map__78003__$1_ws_start$$))}return $built_parser_p__77995$$};$instaparse$core$failure_QMARK_$$=function($result$jscomp$362$$){return $result$jscomp$362$$ instanceof $instaparse$gll$failure_type$$||$APP.$cljs$core$meta$$($result$jscomp$362$$)instanceof $instaparse$gll$failure_type$$};
$app$util$simple_math$expr_eval$$=function($expr$jscomp$5_text$jscomp$139$$,$index$jscomp$461_init_value$jscomp$1_init_value__$1$$){$APP.$cljs$core$truth_$$(!1)&&$APP.$cljs$core$truth_$$($APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return!1},$cljs$cst$5570$cljs_DOT_spec_DOT_alpha_SLASH__STAR_runtime_asserts_STAR_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1478$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,
$APP.$cljs$cst$216$column$$,$cljs$cst$5571$dynamic$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1479$arglists$$,$APP.$cljs$cst$1480$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$5572$cljs_DOT_spec_DOT_alpha$$,$cljs$cst$5573$_STAR_runtime_asserts_STAR_$$,"cljs/spec/alpha.cljs",20,1,!0,1480,1482,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$(!1)?(!1).$cljs$lang$test$:null]))))&&$cljs$spec$alpha$assert_STAR_$$($APP.$cljs$core$string_QMARK_$$,$expr$jscomp$5_text$jscomp$139$$);
var $expecting_result$jscomp$364$$=$app$util$simple_math$parser$$.$cljs$core$IFn$_invoke$arity$1$?$app$util$simple_math$parser$$.$cljs$core$IFn$_invoke$arity$1$($expr$jscomp$5_text$jscomp$139$$):$app$util$simple_math$parser$$($expr$jscomp$5_text$jscomp$139$$);$index$jscomp$461_init_value$jscomp$1_init_value__$1$$=$APP.$cljs$core$truth_$$($index$jscomp$461_init_value$jscomp$1_init_value__$1$$)?$index$jscomp$461_init_value$jscomp$1_init_value__$1$$:0;$APP.$cljs$core$truth_$$(!1)&&$APP.$cljs$core$truth_$$($APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return!1},
$cljs$cst$5570$cljs_DOT_spec_DOT_alpha_SLASH__STAR_runtime_asserts_STAR_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1478$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$216$column$$,$cljs$cst$5571$dynamic$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1479$arglists$$,$APP.$cljs$cst$1480$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$5572$cljs_DOT_spec_DOT_alpha$$,$cljs$cst$5573$_STAR_runtime_asserts_STAR_$$,
"cljs/spec/alpha.cljs",20,1,!0,1480,1482,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$(!1)?(!1).$cljs$lang$test$:null]))))&&$cljs$spec$alpha$assert_STAR_$$($APP.$cljs$core$number_QMARK_$$,$index$jscomp$461_init_value$jscomp$1_init_value__$1$$);if($instaparse$core$failure_QMARK_$$($expecting_result$jscomp$364$$))return $expr$jscomp$5_text$jscomp$139$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$364$$),$index$jscomp$461_init_value$jscomp$1_init_value__$1$$=
$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$364$$),$expecting_result$jscomp$364$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5451$expecting$$,$APP.$cljs$cst$984$reason$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$364$$))),console.debug(["Invalid value '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr$jscomp$5_text$jscomp$139$$),
"' at index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$461_init_value$jscomp$1_init_value__$1$$),". Expected one of ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$364$$),"."].join("")),null;try{var $value$jscomp$787$$=$app$util$simple_math$interpret$$($expecting_result$jscomp$364$$,$index$jscomp$461_init_value$jscomp$1_init_value__$1$$);return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1064$$=Number.isFinite($value$jscomp$787$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1064$$)?$or__5025__auto__$jscomp$1064$$:$value$jscomp$787$$==null}())?$value$jscomp$787$$:null}catch($e78066$$){return console.debug(["Expression evaluation error: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_message$$($e78066$$))].join(""),["Expression: '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr$jscomp$5_text$jscomp$139$$),"'"].join("")),null}};
$app$main$ui$components$reorder_handler$reorder_handler_STAR_$$=function($props_76698$$){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{ref:$props_76698$$.ref,className:"main_ui_components_reorder_handler__reorder",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"reorder",className:"main_ui_components_reorder_handler__reorder-icon","aria-hidden":!0})}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_components_reorder_handler__reorder-separator-top"}),
(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_components_reorder_handler__reorder-separator-bottom"})]})};
$app$main$ui$workspace$tokens$management$forms$controls$utils$token__GT_dropdown_option$$=function($token$jscomp$121$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$121$$,$APP.$cljs$cst$266$id$$)),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1136$token$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$121$$,
$APP.$cljs$cst$260$value$$),$APP.$cljs$cst$4605$resolved_value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$121$$,$APP.$cljs$cst$4605$resolved_value$$),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$121$$,$APP.$cljs$cst$725$name$$)],null)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$generate_dropdown_options$$=function($non_empty_groups_tokens$jscomp$39$$,$no_sets$$){$non_empty_groups_tokens$jscomp$39$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($items$jscomp$56_p__76700$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$56_p__76700$$,0,null);$items$jscomp$56_p__76700$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$56_p__76700$$,1,null);return $APP.$cljs$core$seq$$($items$jscomp$56_p__76700$$)},
$non_empty_groups_tokens$jscomp$39$$);return $APP.$cljs$core$empty_QMARK_$$($non_empty_groups_tokens$jscomp$39$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$489$empty$$,$APP.$cljs$cst$2287$label$$,$APP.$cljs$core$truth_$$($no_sets$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.no-applicable-tokens"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.no-matches")],
null)],null):$APP.$cljs$core$not_empty$$($APP.$cljs$core$vec$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1472$separator$$,!0,$APP.$cljs$cst$266$id$$,"separator",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1472$separator$$],null)],null),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($items$jscomp$57_p__76705$$){var $type$jscomp$609$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$57_p__76705$$,0,null);$items$jscomp$57_p__76705$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$57_p__76705$$,1,null);return $APP.$cljs$core$seq_QMARK_$$($items$jscomp$57_p__76705$$)?$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1608$group$$,!0,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$266$id$$,"group-"+($APP.$cljs$core$name$$($type$jscomp$609$$)??
""),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$name$$($type$jscomp$609$$)],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$forms$controls$utils$token__GT_dropdown_option$$,$items$jscomp$57_p__76705$$)):null},$non_empty_groups_tokens$jscomp$39$$)))))};
$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_token_groups_by_name$$=function($tokens$jscomp$40$$,$filter_text$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($filtered$jscomp$2_p__76712_tokens__$1$$){var $group$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filtered$jscomp$2_p__76712_tokens__$1$$,0,null);$filtered$jscomp$2_p__76712_tokens__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filtered$jscomp$2_p__76712_tokens__$1$$,1,null);$filtered$jscomp$2_p__76712_tokens__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__76711_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__76711_SHARP_$$),$filter_text$$)},$filtered$jscomp$2_p__76712_tokens__$1$$);return $APP.$cljs$core$seq$$($filtered$jscomp$2_p__76712_tokens__$1$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$48$$,$filtered$jscomp$2_p__76712_tokens__$1$$],null):null}),$tokens$jscomp$40$$)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$sort_groups_and_tokens$$=function($groups__GT_tokens$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$155$$,$p__76721_tokens$jscomp$41$$){var $group$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76721_tokens$jscomp$41$$,0,null);$p__76721_tokens$jscomp$41$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76721_tokens$jscomp$41$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$155$$,
$group$jscomp$49$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$p__76721_tokens$jscomp$41$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$groups__GT_tokens$$)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$=function($tokens$jscomp$42$$,$filter_term$jscomp$1$$){return new $APP.$cljs$core$Delay$$(function(){var $no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$=$APP.$cljs$core$delay_QMARK_$$($tokens$jscomp$42$$)?$APP.$cljs$core$_deref$$($tokens$jscomp$42$$):$tokens$jscomp$42$$;$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$=$app$main$ui$workspace$tokens$management$forms$controls$utils$sort_groups_and_tokens$$($no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$);
var $options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($filter_term$jscomp$1$$,"{");$APP.$cljs$core$truth_$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$)?($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($filter_term$jscomp$1$$,
$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$+1),$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$=$APP.$cljs$core$seq$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$)&&$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$.length>0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("}",
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$,$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$.length-1))?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$,0,$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$.length-
1):$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$):$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$=null;$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$=$APP.$cljs$core$seq$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$)?$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_token_groups_by_name$$($no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$,
$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$):$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$;$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$=$APP.$cljs$core$empty_QMARK_$$($no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$);return $app$main$ui$workspace$tokens$management$forms$controls$utils$generate_dropdown_options$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8712_temp__5825__auto__$jscomp$inline_8711$$,
$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$)})};
$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$=function($raw_tokens$$,$input_type$jscomp$1$$){return new $APP.$cljs$core$Delay$$(function(){var $raw_tokens__$1$$=$APP.$cljs$core$_deref$$($raw_tokens$$);a:switch($input_type$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$input_type$jscomp$1$$.$fqn$:null){case "color-selection":var $key_order$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$tokens_by_input$$,$APP.$cljs$cst$1403$fill$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$tokens_by_input$$,$APP.$cljs$cst$1739$stroke_color$$));break a;default:$key_order$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$tokens_by_input$$,$input_type$jscomp$1$$)}return $APP.$cljs$core$not_empty$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$156$$,$k$jscomp$689$$){return $APP.$cljs$core$contains_QMARK_$$($raw_tokens__$1$$,$k$jscomp$689$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$156$$,$k$jscomp$689$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($raw_tokens__$1$$,$k$jscomp$689$$)):$acc$jscomp$156$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$key_order$$))})};
$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$=function($options$jscomp$607$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__76731_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__76731_SHARP_$$),$APP.$cljs$cst$1136$token$$)},$options$jscomp$607$$)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$=function($error$jscomp$143$$,$token_name$jscomp$15_translated_string$$){$token_name$jscomp$15_translated_string$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.name-collision",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_name$jscomp$15_translated_string$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$143$$,$token_name$jscomp$15_translated_string$$)};
$app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$=function($JSCompiler_temp_const$jscomp$1745_props_78113$$){var $children$jscomp$294$$=$JSCompiler_temp_const$jscomp$1745_props_78113$$.children,$JSCompiler_temp$jscomp$1746_select_on_focus$jscomp$1$$=$JSCompiler_temp_const$jscomp$1745_props_78113$$.selectOnFocus,$JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$=$JSCompiler_temp_const$jscomp$1745_props_78113$$.color,$on_focus$jscomp$6$$=
$JSCompiler_temp_const$jscomp$1745_props_78113$$.onFocus,$on_blur$jscomp$9$$=$JSCompiler_temp_const$jscomp$1745_props_78113$$.onBlur,$on_opacity_change$$=$JSCompiler_temp_const$jscomp$1745_props_78113$$.onOpacityChange,$JSCompiler_temp_const$jscomp$1747_opacity$jscomp$43$$=$JSCompiler_temp_const$jscomp$1745_props_78113$$.opacity;$JSCompiler_temp_const$jscomp$1745_props_78113$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:$JSCompiler_temp_const$jscomp$1745_props_78113$$.className,children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_color_row__color-bullet-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$,onClick:$JSCompiler_temp_const$jscomp$1745_props_78113$$.handleClickColor,size:"small"})}),$children$jscomp$294$$]});$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1747_opacity$jscomp$43$$)?($JSCompiler_temp_const$jscomp$1747_opacity$jscomp$43$$=
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_color_row__icon-text",children:"%"}),$JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$),$JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$,
$APP.$cljs$cst$1616$multiple$$)?"":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$coalesce$$($JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$)*100)),$JSCompiler_temp$jscomp$1746_select_on_focus$jscomp$1$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper",children:[$JSCompiler_temp_const$jscomp$1747_opacity$jscomp$43$$,
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_opacity_change$$,className:"main_ui_workspace_sidebar_options_rows_color_row__opacity-input",placeholder:"--",selectOnFocus:$JSCompiler_temp$jscomp$1746_select_on_focus$jscomp$1$$,max:100,"data-testid":"opacity-input",value:$JSCompiler_inline_result$jscomp$1748_color$jscomp$136_opacity$jscomp$inline_8715$$,onFocus:$on_focus$jscomp$6$$,onBlur:$on_blur$jscomp$9$$,"default":100})]})):$JSCompiler_temp$jscomp$1746_select_on_focus$jscomp$1$$=
null;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-info",children:[$JSCompiler_temp_const$jscomp$1745_props_78113$$,$JSCompiler_temp$jscomp$1746_select_on_focus$jscomp$1$$]})};
$app$main$ui$workspace$sidebar$options$rows$color_row$color_token_row_STAR_$$=function($active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$){var $detach_token$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$.detachToken,$color$jscomp$137$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$.color,$applied_token_name$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$.appliedTokenName,$on_swatch_click_token$$=
$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$.onSwatchClickToken,$open_modal_from_token$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$.openModalFromToken;$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$.activeTokens;var $active_tokens__$1_not_active$$=$APP.$cljs$core$delay_QMARK_$$($active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$)?
$APP.$cljs$core$_deref$$($active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$):$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$;$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens__$1_not_active$$);var $token$jscomp$122$$=$APP.$cljs$core$some$$(function($p1__78114_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78114_SHARP_$$),
$applied_token_name$$)?$p1__78114_SHARP_$$:null},$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$);$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($detach_token$$),$APP.$rumext$v2$adapt$$($token$jscomp$122$$),$APP.$rumext$v2$adapt$$($applied_token_name$$)],function(){var $or__5025__auto__$jscomp$inline_8717_token_name$jscomp$17$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$122$$);
$or__5025__auto__$jscomp$inline_8717_token_name$jscomp$17$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8717_token_name$jscomp$17$$)?$or__5025__auto__$jscomp$inline_8717_token_name$jscomp$17$$:$applied_token_name$$;return $detach_token$$.$cljs$core$IFn$_invoke$arity$1$?$detach_token$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_8717_token_name$jscomp$17$$):$detach_token$$($or__5025__auto__$jscomp$inline_8717_token_name$jscomp$17$$)});var $has_errors$jscomp$1$$=$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$122$$)!=
null,$token_name$jscomp$16$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$122$$),$resolved$jscomp$5_swatch_tooltip_content$$=$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$122$$);$active_tokens__$1_not_active$$=$APP.$cljs$core$empty_QMARK_$$($active_tokens__$1_not_active$$)||$token$jscomp$122$$==null;var $id$jscomp$925$$=""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$122$$)??"")+"-name",$token_name_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);
$resolved$jscomp$5_swatch_tooltip_content$$=$active_tokens__$1_not_active$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-active-token.no-name"):$has_errors$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("options.deleted-token"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$5_swatch_tooltip_content$$]));var $name_tooltip_content$$=
$active_tokens__$1_not_active$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-active-token.no-name"):$has_errors$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("options.deleted-token"):function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")??"")+": "}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_color_row__token-name-tooltip",
children:$applied_token_name$$})]})};return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-info",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__token-color-wrapper "+($has_errors$jscomp$1$$?"main_ui_workspace_sidebar_options_rows_color_row__token-color-with-errors":"")+" "+($active_tokens__$1_not_active$$?"main_ui_workspace_sidebar_options_rows_color_row__token-color-not-active":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_color_row__color-bullet-wrapper",children:[$has_errors$jscomp$1$$||$active_tokens__$1_not_active$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__error-dot"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color$jscomp$137$$,tooltipContent:$resolved$jscomp$5_swatch_tooltip_content$$,onClick:$on_swatch_click_token$$,hasErrors:$has_errors$jscomp$1$$||$active_tokens__$1_not_active$$,
size:"small"})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$name_tooltip_content$$,id:$id$jscomp$925$$,"aria-label":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_name$$)].join(""),triggerRef:$token_name_ref$$,className:"main_ui_workspace_sidebar_options_rows_color_row__token-tooltip",children:(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$token_name_ref$$,"aria-labelledby":$id$jscomp$925$$,className:"main_ui_workspace_sidebar_options_rows_color_row__token-name",children:$APP.$cljs$core$truth_$$($token_name$jscomp$16$$)?$token_name$jscomp$16$$:$applied_token_name$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__token-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("token-actions.detach-token"),
onClick:$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78115$$,icon:"detach"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),onClick:$open_modal_from_token$$,icon:"tokens"})]})]})})};
$app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$=function($props_78125_token_color$$){var $on_change$jscomp$37$$=$props_78125_token_color$$.onChange,$on_remove$$=$props_78125_token_color$$.onRemove,$on_open$$=$props_78125_token_color$$.onOpen,$on_detach_token$jscomp$1$$=$props_78125_token_color$$.onDetachToken,$disable_picker$$=$props_78125_token_color$$.disablePicker,$disable_gradient$$=$props_78125_token_color$$.disableGradient,$disable_opacity$jscomp$1$$=$props_78125_token_color$$.disableOpacity,
$on_token_change$jscomp$2$$=$props_78125_token_color$$.onTokenChange,$select_on_focus$jscomp$2$$=$props_78125_token_color$$.selectOnFocus,$select_only$jscomp$1$$=$props_78125_token_color$$.selectOnly,$index$jscomp$462$$=$props_78125_token_color$$.index,$color$jscomp$138$$=$props_78125_token_color$$.color,$disable_image$$=$props_78125_token_color$$.disableImage,$on_close$jscomp$15$$=$props_78125_token_color$$.onClose,$disable_drag$jscomp$1_dprops$jscomp$1$$=$props_78125_token_color$$.disableDrag,$on_focus$jscomp$7$$=
$props_78125_token_color$$.onFocus,$on_blur$jscomp$10$$=$props_78125_token_color$$.onBlur,$applied_token$jscomp$2$$=$props_78125_token_color$$.appliedToken,$on_reorder$$=$props_78125_token_color$$.onReorder,$class$$jscomp$60$$=$props_78125_token_color$$.className,$hidden$jscomp$10_row_class$$=$props_78125_token_color$$.hidden,$on_detach$$=$props_78125_token_color$$.onDetach,$origin$jscomp$59$$=$props_78125_token_color$$.origin;$props_78125_token_color$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1213$token_color$$);var $gradient_color_QMARK__libraries$jscomp$135_src_colors$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$color_without_hash$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$)],function(){return $app$common$types$color$remove_hash$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$))}),$file_id$jscomp$368_image_color_QMARK_$$=function(){var $or__5025__auto__$jscomp$1073$$=
$APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1073$$)?$or__5025__auto__$jscomp$1073$$:$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$)}(),$color_id$jscomp$8_library_color_QMARK_$$=function(){var $or__5025__auto__$jscomp$1074$$=$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1074$$)?
$or__5025__auto__$jscomp$1074$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$)}();$gradient_color_QMARK__libraries$jscomp$135_src_colors$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_color_QMARK__libraries$jscomp$135_src_colors$$,$file_id$jscomp$368_image_color_QMARK_$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2212$colors$$);var $color_name$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_color_QMARK__libraries$jscomp$135_src_colors$$,$color_id$jscomp$8_library_color_QMARK_$$),$APP.$cljs$cst$725$name$$),$has_multiple_colors$$=$APP.$app$util$color$multiple_QMARK_$$($color$jscomp$138$$);$color_id$jscomp$8_library_color_QMARK_$$=function(){var $and__5023__auto__$jscomp$709_or__5025__auto__$jscomp$inline_8719$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);
$and__5023__auto__$jscomp$709_or__5025__auto__$jscomp$inline_8719$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$709_or__5025__auto__$jscomp$inline_8719$$)?$and__5023__auto__$jscomp$709_or__5025__auto__$jscomp$inline_8719$$:$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$709_or__5025__auto__$jscomp$inline_8719$$)?$APP.$cljs$core$truth_$$($color_name$$)?!$has_multiple_colors$$:$color_name$$:$and__5023__auto__$jscomp$709_or__5025__auto__$jscomp$inline_8719$$}();
$gradient_color_QMARK__libraries$jscomp$135_src_colors$$=function(){var $and__5023__auto__$jscomp$710_and__5023__auto____$1$jscomp$122$$=!$has_multiple_colors$$;return $and__5023__auto__$jscomp$710_and__5023__auto____$1$jscomp$122$$?($and__5023__auto__$jscomp$710_and__5023__auto____$1$jscomp$122$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$710_and__5023__auto____$1$jscomp$122$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$138$$,
$APP.$cljs$cst$1724$gradient$$),$APP.$cljs$cst$139$type$$):$and__5023__auto__$jscomp$710_and__5023__auto____$1$jscomp$122$$):$and__5023__auto__$jscomp$710_and__5023__auto____$1$jscomp$122$$}();$file_id$jscomp$368_image_color_QMARK_$$=function(){var $and__5023__auto__$jscomp$711$$=!$has_multiple_colors$$;return $and__5023__auto__$jscomp$711$$?$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$):$and__5023__auto__$jscomp$711$$}();var $editing_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$is_editing_text$$=$APP.$cljs$core$_deref$$($editing_text_STAR_$$),$active_tokens_STAR_$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$),$tokens$jscomp$43$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens_STAR_$$),$APP.$rumext$v2$adapt$$($origin$jscomp$59$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($active_tokens_STAR_$$,$origin$jscomp$59$$)}),$on_focus_SINGLEQUOTE_$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$7$$)],function(){$APP.$cljs$core$reset_BANG_$$($editing_text_STAR_$$,!0);return $APP.$cljs$core$truth_$$($on_focus$jscomp$7$$)?$on_focus$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?$on_focus$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus$jscomp$7$$():null}),$on_blur_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_blur$jscomp$10$$)],function(){$APP.$cljs$core$reset_BANG_$$($editing_text_STAR_$$,
!1);return $APP.$cljs$core$truth_$$($on_blur$jscomp$10$$)?$on_blur$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$10$$():null}),$parse_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($color__$1$jscomp$19$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$19$$,$APP.$cljs$cst$1298$color$$,function($p1__78122_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__78122_SHARP_$$)?
$p1__78122_SHARP_$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$19$$)})}),$detach_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach$$),$APP.$rumext$v2$adapt$$($index$jscomp$462$$),$APP.$rumext$v2$adapt$$($color$jscomp$138$$)],function(){return $APP.$cljs$core$truth_$$($on_detach$$)?$on_detach$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$462$$,$color$jscomp$138$$):
$on_detach$$($index$jscomp$462$$,$color$jscomp$138$$):null}),$handle_select$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($select_only$jscomp$1$$),$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($applied_token$jscomp$2$$)],function(){var $color__$1$jscomp$20$$=$APP.$cljs$core$truth_$$($applied_token$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$138$$,$APP.$cljs$cst$4185$has_token_applied$$,
!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4186$token_name$$,$applied_token$jscomp$2$$])):$color$jscomp$138$$;return $select_only$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$select_only$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$20$$):$select_only$jscomp$1$$($color__$1$jscomp$20$$)}),$on_color_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($index$jscomp$462$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$37$$)],function($color__$1$jscomp$21_value$jscomp$790$$){$color__$1$jscomp$21_value$jscomp$790$$=$APP.$cljs$core$select_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$138$$,$APP.$cljs$cst$1298$color$$,$color__$1$jscomp$21_value$jscomp$790$$),$APP.$cljs$cst$1724$gradient$$),$APP.$app$common$types$color$color_attrs$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($color__$1$jscomp$21_value$jscomp$790$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$2$($color__$1$jscomp$21_value$jscomp$790$$,$index$jscomp$462$$):$on_change$jscomp$37$$($color__$1$jscomp$21_value$jscomp$790$$,$index$jscomp$462$$)]))}),$on_opacity_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($index$jscomp$462$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$37$$)],function($color__$1$jscomp$22_value$jscomp$791$$){$color__$1$jscomp$22_value$jscomp$791$$=$APP.$cljs$core$select_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$138$$,$APP.$cljs$cst$1734$opacity$$,$color__$1$jscomp$22_value$jscomp$791$$/100),$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1736$ref_file$$])),
$APP.$app$common$types$color$color_attrs$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($color__$1$jscomp$22_value$jscomp$791$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$2$($color__$1$jscomp$22_value$jscomp$791$$,$index$jscomp$462$$):$on_change$jscomp$37$$($color__$1$jscomp$22_value$jscomp$791$$,
$index$jscomp$462$$)]))}),$open_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disable_gradient$$),$APP.$rumext$v2$adapt$$($disable_opacity$jscomp$1$$),$APP.$rumext$v2$adapt$$($disable_image$$),$APP.$rumext$v2$adapt$$($disable_picker$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$37$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$15$$),$APP.$rumext$v2$adapt$$($on_open$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$43$$),$APP.$rumext$v2$adapt$$($index$jscomp$462$$),
$APP.$rumext$v2$adapt$$($applied_token$jscomp$2$$)],function($color__$1$jscomp$23_color__$2$jscomp$1$$,$pos$jscomp$132_props$jscomp$316$$,$tab$jscomp$6$$){$color__$1$jscomp$23_color__$2$jscomp$1$$=$has_multiple_colors$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#B1B2B5",$APP.$cljs$cst$1734$opacity$$,1],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$23_color__$2$jscomp$1$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$23_color__$2$jscomp$1$$,$APP.$cljs$cst$1734$opacity$$,1):$color__$1$jscomp$23_color__$2$jscomp$1$$;$pos$jscomp$132_props$jscomp$316$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$4156$disable_gradient$$,$cljs$cst$5574$on_token_change$$,$APP.$cljs$cst$4155$disable_opacity$$,$cljs$cst$5575$disable_image$$,$APP.$cljs$cst$4994$on_close$$,$cljs$cst$5576$applied_token$$,$cljs$cst$5577$active_tokens$$,
$cljs$cst$5578$color_origin$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$4157$on_change$$,$APP.$cljs$cst$5344$tab$$,$APP.$cljs$cst$142$data$$],[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$132_props$jscomp$316$$),$disable_gradient$$,$on_token_change$jscomp$2$$,$disable_opacity$jscomp$1$$,$disable_image$$,function($value$jscomp$792$$,$opacity$jscomp$44$$,$id$jscomp$926$$,$file_id__$1$jscomp$10$$){return $APP.$cljs$core$truth_$$($on_close$jscomp$15$$)?
$on_close$jscomp$15$$.$cljs$core$IFn$_invoke$arity$4$?$on_close$jscomp$15$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$792$$,$opacity$jscomp$44$$,$id$jscomp$926$$,$file_id__$1$jscomp$10$$):$on_close$jscomp$15$$($value$jscomp$792$$,$opacity$jscomp$44$$,$id$jscomp$926$$,$file_id__$1$jscomp$10$$):null},$applied_token$jscomp$2$$,$tokens$jscomp$43$$,$origin$jscomp$59$$,$cljs$cst$5579$sidebar$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$132_props$jscomp$316$$),function($p1__78123_SHARP_$$){return $on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$2$($p1__78123_SHARP_$$,$index$jscomp$462$$):$on_change$jscomp$37$$($p1__78123_SHARP_$$,$index$jscomp$462$$)},$tab$jscomp$6$$,$color__$1$jscomp$23_color__$2$jscomp$1$$]);$APP.$cljs$core$fn_QMARK_$$($on_open$$)&&($on_open$$.$cljs$core$IFn$_invoke$arity$1$?$on_open$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$23_color__$2$jscomp$1$$):$on_open$$($color__$1$jscomp$23_color__$2$jscomp$1$$));return $APP.$cljs$core$truth_$$($disable_picker$$)?null:
$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2239$colorpicker$$,$pos$jscomp$132_props$jscomp$316$$)}),$handle_click_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_modal$$)],function($color__$1$jscomp$24$$,$cpos$jscomp$1_event$jscomp$302$$){$cpos$jscomp$1_event$jscomp$302$$=$APP.$app$util$dom$get_client_position$$($cpos$jscomp$1_event$jscomp$302$$);return $open_modal$$.$cljs$core$IFn$_invoke$arity$3$?
$open_modal$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$24$$,$cpos$jscomp$1_event$jscomp$302$$,null):$open_modal$$($color__$1$jscomp$24$$,$cpos$jscomp$1_event$jscomp$302$$,null)}),$open_modal_from_token$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_modal$$),$APP.$rumext$v2$adapt$$($color$jscomp$138$$)],function($event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$){var $cpos$jscomp$2_y$jscomp$466$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$);
$event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cpos$jscomp$2_y$jscomp$466$$);$cpos$jscomp$2_y$jscomp$466$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cpos$jscomp$2_y$jscomp$466$$);$event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$-215,$APP.$cljs$cst$1511$y$$,$cpos$jscomp$2_y$jscomp$466$$],null);return $open_modal$$.$cljs$core$IFn$_invoke$arity$3$?
$open_modal$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$138$$,$event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$,$APP.$cljs$cst$1213$token_color$$):$open_modal$$($color$jscomp$138$$,$event$jscomp$303_pos$jscomp$133_x$jscomp$1244$$,$APP.$cljs$cst$1213$token_color$$)}),$on_swatch_click_token$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_modal$$)],function($color__$1$jscomp$25$$,$cpos$jscomp$3_event$jscomp$304$$){$cpos$jscomp$3_event$jscomp$304$$=
$APP.$app$util$dom$get_client_position$$($cpos$jscomp$3_event$jscomp$304$$);return $open_modal$$.$cljs$core$IFn$_invoke$arity$3$?$open_modal$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$25$$,$cpos$jscomp$3_event$jscomp$304$$,$APP.$cljs$cst$1213$token_color$$):$open_modal$$($color__$1$jscomp$25$$,$cpos$jscomp$3_event$jscomp$304$$,$APP.$cljs$cst$1213$token_color$$)}),$detach_token$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$1$$)],
function($token$jscomp$123$$){return $APP.$cljs$core$truth_$$($on_detach_token$jscomp$1$$)?$on_detach_token$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_detach_token$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$123$$):$on_detach_token$jscomp$1$$($token$jscomp$123$$):null}),$on_remove_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$462$$),$APP.$rumext$v2$adapt$$($on_remove$$)],function(){return $APP.$cljs$core$truth_$$($on_remove$$)?
$on_remove$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$462$$):$on_remove$$($index$jscomp$462$$):null}),$prev_color$jscomp$2$$=$APP.$app$main$ui$hooks$use_previous$$($color$jscomp$138$$),$dref$jscomp$1_on_drop$jscomp$3_vec__78126$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reorder$$),$APP.$rumext$v2$adapt$$($index$jscomp$462$$)],function($relative_pos_to_space_between_pos$jscomp$10$$,$data$jscomp$468_from_pos$jscomp$10$$){$data$jscomp$468_from_pos$jscomp$10$$=
$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$468_from_pos$jscomp$10$$);$relative_pos_to_space_between_pos$jscomp$10$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos_to_space_between_pos$jscomp$10$$,$APP.$cljs$cst$2952$bot$$)?$index$jscomp$462$$+1:$index$jscomp$462$$;return $on_reorder$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$468_from_pos$jscomp$10$$,$relative_pos_to_space_between_pos$jscomp$10$$):
$on_reorder$$($data$jscomp$468_from_pos$jscomp$10$$,$relative_pos_to_space_between_pos$jscomp$10$$)});$dref$jscomp$1_on_drop$jscomp$3_vec__78126$$=$on_reorder$$!=null?$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/color-row",$APP.$cljs$cst$2955$on_drop$$,$dref$jscomp$1_on_drop$jscomp$3_vec__78126$$,$APP.$cljs$cst$2948$disabled$$,$disable_drag$jscomp$1_dprops$jscomp$1$$,
$APP.$cljs$cst$2958$detect_center_QMARK_$$,!1,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$462$$],null)])):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null);$disable_drag$jscomp$1_dprops$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$1_on_drop$jscomp$3_vec__78126$$,0,null);$dref$jscomp$1_on_drop$jscomp$3_vec__78126$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$1_on_drop$jscomp$3_vec__78126$$,
1,null);$hidden$jscomp$10_row_class$$="main_ui_workspace_sidebar_options_rows_color_row__color-data "+($APP.$cljs$core$truth_$$($hidden$jscomp$10_row_class$$)?"main_ui_workspace_sidebar_options_rows_color_row__hidden":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($disable_drag$jscomp$1_dprops$jscomp$1$$),$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_sidebar_options_rows_color_row__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($disable_drag$jscomp$1_dprops$jscomp$1$$),
$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_options_rows_color_row__dnd-over-bot":"");$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($prev_color$jscomp$2$$),$APP.$rumext$v2$adapt$$($disable_picker$$)],function(){if($APP.$cljs$core$not$$($disable_picker$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_color$jscomp$2$$,$color$jscomp$138$$)){var $JSCompiler_temp$jscomp$1578_props$jscomp$inline_8722$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,$parse_color$$.$cljs$core$IFn$_invoke$arity$1$?$parse_color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$):$parse_color$$($color$jscomp$138$$)],null);$JSCompiler_temp$jscomp$1578_props$jscomp$inline_8722$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$modal$update_props$$($JSCompiler_temp$jscomp$1578_props$jscomp$inline_8722$$))}else $JSCompiler_temp$jscomp$1578_props$jscomp$inline_8722$$=
null;return $JSCompiler_temp$jscomp$1578_props$jscomp$inline_8722$$});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token$jscomp$2$$),$APP.$rumext$v2$adapt$$($disable_picker$$)],function(){return $APP.$cljs$core$not$$($disable_picker$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$modal$update_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5576$applied_token$$,$applied_token$jscomp$2$$],null))):
null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:($class$$jscomp$60$$??"")+" "+($hidden$jscomp$10_row_class$$??""),children:[$on_reorder$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$1_on_drop$jscomp$3_vec__78126$$}):null,$APP.$cljs$core$truth_$$($props_78125_token_color$$?$applied_token$jscomp$2$$:$props_78125_token_color$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_token_row_STAR_$$,
{activeTokens:$tokens$jscomp$43$$,appliedTokenName:$applied_token$jscomp$2$$,color:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$138$$,$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1736$ref_file$$])),onSwatchClickToken:$on_swatch_click_token$jscomp$1$$,detachToken:$detach_token$jscomp$1$$,openModalFromToken:$open_modal_from_token$jscomp$1$$}):$APP.$cljs$core$truth_$$($color_id$jscomp$8_library_color_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper main_ui_workspace_sidebar_options_rows_color_row__library-name-wrapper",handleClickColor:$handle_click_color$jscomp$1$$,opacity:!1,color:$color$jscomp$138$$,children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color_name$$),
className:"main_ui_workspace_sidebar_options_rows_color_row__color-name",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color_name$$)}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_options_rows_color_row__detach-btn","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.detach"),onClick:$detach_value$$,icon:"detach"})]})}):$APP.$cljs$core$truth_$$($gradient_color_QMARK__libraries$jscomp$135_src_colors$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper "+($disable_opacity$jscomp$1$$?"main_ui_workspace_sidebar_options_rows_color_row__no-opacity":"")+" main_ui_workspace_sidebar_options_rows_color_row__gradient-name-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name",children:$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$138$$,
$APP.$cljs$cst$1724$gradient$$),$APP.$cljs$cst$139$type$$))}),selectOnFocus:$select_on_focus$jscomp$2$$,onFocus:$on_focus_SINGLEQUOTE_$$,onOpacityChange:$on_opacity_change$jscomp$1$$,onBlur:$on_blur_SINGLEQUOTE_$$,handleClickColor:$handle_click_color$jscomp$1$$,color:$color$jscomp$138$$,opacity:!$disable_opacity$jscomp$1$$}):$APP.$cljs$core$truth_$$($file_id$jscomp$368_image_color_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,
{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper "+($disable_opacity$jscomp$1$$?"main_ui_workspace_sidebar_options_rows_color_row__no-opacity":""),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")}),selectOnFocus:$select_on_focus$jscomp$2$$,onFocus:$on_focus_SINGLEQUOTE_$$,onOpacityChange:$on_opacity_change$jscomp$1$$,onBlur:$on_blur_SINGLEQUOTE_$$,
handleClickColor:$handle_click_color$jscomp$1$$,color:$color$jscomp$138$$,opacity:!$disable_opacity$jscomp$1$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper "+($disable_opacity$jscomp$1$$||$has_multiple_colors$$?"main_ui_workspace_sidebar_options_rows_color_row__no-opacity":"")+" "+($APP.$cljs$core$truth_$$($is_editing_text$$)?"main_ui_workspace_sidebar_options_rows_color_row__editing":
""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-input-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$color_input$color_input_STAR_$$,{value:$has_multiple_colors$$?"":$color_without_hash$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),"data-index":$index$jscomp$462$$,className:"main_ui_workspace_sidebar_options_rows_color_row__color-input",onFocus:$on_focus_SINGLEQUOTE_$$,
onBlur:$on_blur_SINGLEQUOTE_$$,onChange:$on_color_change$$})}),selectOnFocus:$select_on_focus$jscomp$2$$,onFocus:$on_focus_SINGLEQUOTE_$$,onOpacityChange:$on_opacity_change$jscomp$1$$,onBlur:$on_blur_SINGLEQUOTE_$$,handleClickColor:$handle_click_color$jscomp$1$$,color:$color$jscomp$138$$,opacity:!($disable_opacity$jscomp$1$$||$has_multiple_colors$$)}),$on_remove$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.remove-color"),
onClick:$on_remove_SINGLEQUOTE_$$,icon:"remove"}):null,$APP.$cljs$core$truth_$$($select_only$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.select-this-color"),onClick:$handle_select$jscomp$1$$,tooltipPosition:"top-left",icon:"move"}):null]})};
$app$main$ui$workspace$colorpicker$gradients$format_rgb$$=function($p__78135_r$jscomp$129$$){var $map__78136__$1_offset$jscomp$198$$=$APP.$cljs$core$__destructure_map$$($p__78135_r$jscomp$129$$);$p__78135_r$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78136__$1_offset$jscomp$198$$,$APP.$cljs$cst$1743$r$$);var $g$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78136__$1_offset$jscomp$198$$,$APP.$cljs$cst$1744$g$$),$b$jscomp$350$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78136__$1_offset$jscomp$198$$,
$APP.$cljs$cst$1520$b$$);$map__78136__$1_offset$jscomp$198$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78136__$1_offset$jscomp$198$$,$APP.$cljs$cst$195$offset$$);return"rgb("+($p__78135_r$jscomp$129$$??"")+", "+($g$jscomp$151$$??"")+", "+($b$jscomp$350$$??"")+") "+$map__78136__$1_offset$jscomp$198$$*100+"%"};
$app$main$ui$workspace$colorpicker$gradients$gradient__GT_string$$=function($stops$jscomp$16$$){return"linear-gradient(90deg, "+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$colorpicker$gradients$format_rgb$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($opacity$jscomp$46_p__78138$$){var $map__78139__$1_offset$jscomp$199$$=$APP.$cljs$core$__destructure_map$$($opacity$jscomp$46_p__78138$$),
$color$jscomp$139_r$jscomp$130$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78139__$1_offset$jscomp$199$$,$APP.$cljs$cst$1298$color$$);$opacity$jscomp$46_p__78138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78139__$1_offset$jscomp$199$$,$APP.$cljs$cst$1734$opacity$$);$map__78139__$1_offset$jscomp$199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78139__$1_offset$jscomp$199$$,$APP.$cljs$cst$195$offset$$);var $b$jscomp$351_vec__78141$$=$APP.$app$common$types$color$hex__GT_rgb$$($color$jscomp$139_r$jscomp$130$$);
$color$jscomp$139_r$jscomp$130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$351_vec__78141$$,0,null);var $g$jscomp$152$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$351_vec__78141$$,1,null);$b$jscomp$351_vec__78141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$351_vec__78141$$,2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1743$r$$,$color$jscomp$139_r$jscomp$130$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$152$$,
$APP.$cljs$cst$1520$b$$,$b$jscomp$351_vec__78141$$,$APP.$cljs$cst$746$alpha$$,$opacity$jscomp$46_p__78138$$,$APP.$cljs$cst$195$offset$$,$map__78139__$1_offset$jscomp$199$$],null)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$16$$))))??"")+")"};
$app$main$ui$workspace$colorpicker$gradients$stop_input_row_STAR_$$=function($offset$jscomp$200_props_78144$$){var $on_blur_stop_offset$$=$offset$jscomp$200_props_78144$$.onBlurStopOffset,$on_select_stop$$=$offset$jscomp$200_props_78144$$.onSelectStop,$on_remove_stop$$=$offset$jscomp$200_props_78144$$.onRemoveStop,$index$jscomp$463$$=$offset$jscomp$200_props_78144$$.index,$on_blur_stop_color$$=$offset$jscomp$200_props_78144$$.onBlurStopColor,$on_reorder_stops$$=$offset$jscomp$200_props_78144$$.onReorderStops,
$is_selected$jscomp$4$$=$offset$jscomp$200_props_78144$$.isSelected,$on_focus_stop_color$$=$offset$jscomp$200_props_78144$$.onFocusStopColor,$on_focus_stop_offset$$=$offset$jscomp$200_props_78144$$.onFocusStopOffset,$stop$jscomp$8$$=$offset$jscomp$200_props_78144$$.stop,$on_change_stop$$=$offset$jscomp$200_props_78144$$.onChangeStop;$offset$jscomp$200_props_78144$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stop$jscomp$8$$,$APP.$cljs$cst$195$offset$$);var $handle_change_stop_color$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_stop$$),
$APP.$rumext$v2$adapt$$($stop$jscomp$8$$)],function($G__78149_value$jscomp$793$$){$G__78149_value$jscomp$793$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$stop$jscomp$8$$,$G__78149_value$jscomp$793$$]));return $on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$($stop$jscomp$8$$,$G__78149_value$jscomp$793$$):$on_change_stop$$($stop$jscomp$8$$,$G__78149_value$jscomp$793$$)}),
$handle_change_offset$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_stop$$),$APP.$rumext$v2$adapt$$($stop$jscomp$8$$)],function($G__78151_value$jscomp$794$$){$G__78151_value$jscomp$794$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($stop$jscomp$8$$,$APP.$cljs$cst$195$offset$$,$APP.$app$common$math$precision$$($G__78151_value$jscomp$794$$/100,2));return $on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$($stop$jscomp$8$$,
$G__78151_value$jscomp$794$$):$on_change_stop$$($stop$jscomp$8$$,$G__78151_value$jscomp$794$$)}),$handle_remove_stop$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_remove_stop$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$)],function(){return $APP.$cljs$core$truth_$$($on_remove_stop$$)?$on_remove_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$463$$):$on_remove_stop$$($index$jscomp$463$$):null}),
$handle_focus_stop_offset$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_focus_stop_offset$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$463$$):$on_select_stop$$($index$jscomp$463$$);return $APP.$cljs$core$truth_$$($on_focus_stop_offset$$)?$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$?
$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus_stop_offset$$():null}),$handle_blur_stop_offset$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_blur_stop_offset$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$463$$):$on_select_stop$$($index$jscomp$463$$);return $APP.$cljs$core$truth_$$($on_blur_stop_offset$$)?
$on_blur_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur_stop_offset$$():null}),$handle_focus_stop_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_focus_stop_offset$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$463$$):
$on_select_stop$$($index$jscomp$463$$);return $APP.$cljs$core$truth_$$($on_focus_stop_color$$)?$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$?$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus_stop_offset$$():null}),$handle_blur_stop_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_blur_stop_color$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?
$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$463$$):$on_select_stop$$($index$jscomp$463$$);return $APP.$cljs$core$truth_$$($on_blur_stop_color$$)?$on_blur_stop_color$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur_stop_color$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur_stop_color$$():null}),$dprops$jscomp$2_on_drop$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$463$$),$APP.$rumext$v2$adapt$$($on_reorder_stops$$)],function($position$jscomp$192_to_index$jscomp$17$$,
$data$jscomp$469_from_index$jscomp$10$$){$data$jscomp$469_from_index$jscomp$10$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$469_from_index$jscomp$10$$);$position$jscomp$192_to_index$jscomp$17$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$192_to_index$jscomp$17$$,$APP.$cljs$cst$2952$bot$$)?$index$jscomp$463$$+1:$index$jscomp$463$$;return $APP.$cljs$core$truth_$$($on_reorder_stops$$)?$on_reorder_stops$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder_stops$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$469_from_index$jscomp$10$$,
$position$jscomp$192_to_index$jscomp$17$$):$on_reorder_stops$$($data$jscomp$469_from_index$jscomp$10$$,$position$jscomp$192_to_index$jscomp$17$$):null}),$dref$jscomp$2_vec__78145$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/stops",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$2_on_drop$jscomp$4$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$463$$],null),$APP.$cljs$cst$2959$draggable_QMARK_$$,!0]));$dprops$jscomp$2_on_drop$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$2_vec__78145$$,0,null);$dref$jscomp$2_vec__78145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$2_vec__78145$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-stops-entry "+($APP.$cljs$core$truth_$$($is_selected$jscomp$4$$)?
"main_ui_workspace_colorpicker_gradients__is-selected":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$2_on_drop$jscomp$4$$),$APP.$cljs$cst$1667$center$$)?"main_ui_workspace_colorpicker_gradients__dnd-over":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$2_on_drop$jscomp$4$$),$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_colorpicker_gradients__dnd-over-top":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$2_on_drop$jscomp$4$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_colorpicker_gradients__dnd-over-bot":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$2_vec__78145$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__offset-input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_colorpicker_gradients__icon-text",children:"%"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$coalesce$$($offset$jscomp$200_props_78144$$)*100)),onChange:$handle_change_offset$$,"default":100,min:0,max:100,onFocus:$handle_focus_stop_offset$$,onBlur:$handle_blur_stop_offset$$})]}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{onRemove:$handle_remove_stop$$,origin:$APP.$cljs$cst$1724$gradient$$,index:$index$jscomp$463$$,onChange:$handle_change_stop_color$$,onFocus:$handle_focus_stop_color$$,disableGradient:!0,onBlur:$handle_blur_stop_color$$,color:$APP.$cljs$core$select_keys$$($stop$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1734$opacity$$],
null)),disablePicker:!0})]})};
$app$main$ui$workspace$colorpicker$gradients$gradients_STAR_$$=function($handle_change_type_props_78153$$){var $on_reverse_stops$$=$handle_change_type_props_78153$$.onReverseStops,$on_change_type$$=$handle_change_type_props_78153$$.onChangeType,$on_stop_edit_start$$=$handle_change_type_props_78153$$.onStopEditStart,$on_select_stop$jscomp$1$$=$handle_change_type_props_78153$$.onSelectStop,$on_rotate_stops$$=$handle_change_type_props_78153$$.onRotateStops,$on_add_stop_preview$$=$handle_change_type_props_78153$$.onAddStopPreview,
$stops$jscomp$17$$=$handle_change_type_props_78153$$.stops,$on_remove_stop$jscomp$1$$=$handle_change_type_props_78153$$.onRemoveStop,$on_add_stop_auto$$=$handle_change_type_props_78153$$.onAddStopAuto,$on_stop_edit_finish$$=$handle_change_type_props_78153$$.onStopEditFinish,$on_reorder_stops$jscomp$1$$=$handle_change_type_props_78153$$.onReorderStops,$type$jscomp$610$$=$handle_change_type_props_78153$$.type,$on_change_stop$jscomp$1$$=$handle_change_type_props_78153$$.onChangeStop,$editing_stop$jscomp$3$$=
$handle_change_type_props_78153$$.editingStop,$preview_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5580$hover_QMARK_$$,!1,$APP.$cljs$cst$195$offset$$,.5],null)}),$dragging_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$start_offset$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$background_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handle_select_stop$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$jscomp$1$$)],function($event$jscomp$306_index$jscomp$464$$){return $APP.$cljs$core$truth_$$($on_select_stop$jscomp$1$$)?($event$jscomp$306_index$jscomp$464$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$306_index$jscomp$464$$),"index")),$on_select_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$306_index$jscomp$464$$):
$on_select_stop$jscomp$1$$($event$jscomp$306_index$jscomp$464$$)):null});$handle_change_type_props_78153$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_type$$)],function($event$jscomp$307$$){return $APP.$cljs$core$truth_$$($on_change_type$$)?$on_change_type$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_type$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$307$$):$on_change_type$$($event$jscomp$307$$):null});var $handle_add_stop$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_add_stop_auto$$)],
function(){return $APP.$cljs$core$truth_$$($on_add_stop_auto$$)?$on_add_stop_auto$$.$cljs$core$IFn$_invoke$arity$0$?$on_add_stop_auto$$.$cljs$core$IFn$_invoke$arity$0$():$on_add_stop_auto$$():null}),$handle_preview_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($preview_state$$,$APP.$cljs$core$assoc$$,$cljs$cst$5580$hover_QMARK_$$,!0)}),$handle_preview_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($preview_state$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5580$hover_QMARK_$$,!1)}),$handle_preview_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$350_offset$jscomp$201$$){$e$jscomp$350_offset$jscomp$201$$=$APP.$app$common$math$precision$$($e$jscomp$350_offset$jscomp$201$$.nativeEvent.offsetX/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($e$jscomp$350_offset$jscomp$201$$))),2);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($preview_state$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,$e$jscomp$350_offset$jscomp$201$$)}),$handle_preview_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_add_stop_preview$$)],function($e$jscomp$351_offset$jscomp$202$$){$e$jscomp$351_offset$jscomp$202$$=$APP.$app$common$math$precision$$($e$jscomp$351_offset$jscomp$202$$.nativeEvent.offsetX/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($e$jscomp$351_offset$jscomp$202$$))),
2);return $APP.$cljs$core$truth_$$($on_add_stop_preview$$)?$on_add_stop_preview$$.$cljs$core$IFn$_invoke$arity$1$?$on_add_stop_preview$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$351_offset$jscomp$202$$):$on_add_stop_preview$$($e$jscomp$351_offset$jscomp$202$$):null}),$handle_stop_marker_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_stop_edit_start$$),$APP.$rumext$v2$adapt$$($handle_select_stop$$),$APP.$rumext$v2$adapt$$($stops$jscomp$17$$)],
function($event$jscomp$308$$){var $index$jscomp$465_stop$jscomp$9$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$308$$),"index"));$index$jscomp$465_stop$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$17$$,$index$jscomp$465_stop$jscomp$9$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$308$$);$handle_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$handle_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$308$$):
$handle_select_stop$$($event$jscomp$308$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$2$$,!0);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$2$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$308$$));$APP.$rumext$v2$set_ref_val_BANG_$$($start_offset$jscomp$1$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$465_stop$jscomp$9$$));return $on_stop_edit_start$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit_start$$.$cljs$core$IFn$_invoke$arity$0$():
$on_stop_edit_start$$()}),$handle_stop_marker_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_stop$jscomp$1$$),$APP.$rumext$v2$adapt$$($stops$jscomp$17$$)],function($background_width_current_pt$jscomp$1_event$jscomp$309$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$2$$))){var $delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$=$APP.$rumext$v2$ref_val$$($start_ref$jscomp$2$$),$G__78157_new_offset$jscomp$2_start_offset__$1$$=
$APP.$rumext$v2$ref_val$$($start_offset$jscomp$1$$),$index$jscomp$466_stop$jscomp$10$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($background_width_current_pt$jscomp$1_event$jscomp$309$$),"index"));$background_width_current_pt$jscomp$1_event$jscomp$309$$=$APP.$app$util$dom$get_client_position$$($background_width_current_pt$jscomp$1_event$jscomp$309$$);$delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($background_width_current_pt$jscomp$1_event$jscomp$309$$)-
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$);$background_width_current_pt$jscomp$1_event$jscomp$309$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$rumext$v2$ref_val$$($background_ref$$)));$delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$/=$background_width_current_pt$jscomp$1_event$jscomp$309$$;$index$jscomp$466_stop$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$17$$,
$index$jscomp$466_stop$jscomp$10$$);$G__78157_new_offset$jscomp$2_start_offset__$1$$=$APP.$app$common$math$precision$$($APP.$app$common$math$clamp$$($G__78157_new_offset$jscomp$2_start_offset__$1$$+$delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$,0,1),2);$G__78157_new_offset$jscomp$2_start_offset__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$466_stop$jscomp$10$$,$APP.$cljs$cst$195$offset$$,$G__78157_new_offset$jscomp$2_start_offset__$1$$);return $on_change_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$466_stop$jscomp$10$$,$G__78157_new_offset$jscomp$2_start_offset__$1$$):$on_change_stop$jscomp$1$$($index$jscomp$466_stop$jscomp$10$$,$G__78157_new_offset$jscomp$2_start_offset__$1$$)}return null}),$handle_stop_marker_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_stop_edit_finish$$)],function($event$jscomp$310$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$310$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$2$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$2$$,null);return $on_stop_edit_finish$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit_finish$$.$cljs$core$IFn$_invoke$arity$0$():$on_stop_edit_finish$$()}),$handle_rotate_gradient$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_rotate_stops$$)],function(){return $APP.$cljs$core$truth_$$($on_rotate_stops$$)?$on_rotate_stops$$.$cljs$core$IFn$_invoke$arity$0$?
$on_rotate_stops$$.$cljs$core$IFn$_invoke$arity$0$():$on_rotate_stops$$():null}),$handle_reverse_gradient$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reverse_stops$$)],function(){return $APP.$cljs$core$truth_$$($on_reverse_stops$$)?$on_reverse_stops$$.$cljs$core$IFn$_invoke$arity$0$?$on_reverse_stops$$.$cljs$core$IFn$_invoke$arity$0$():$on_reverse_stops$$():null}),$add_stop_disabled_QMARK_$$=$app$main$features$use_feature$$("render-wasm/v1")?$APP.$cljs$core$count$$($stops$jscomp$17$$)>=
16:null;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-panel",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-preview",children:[(0,$APP.$rumext$v2$jsx$$)("div",{ref:$background_ref$$,style:{background:$app$main$ui$workspace$colorpicker$gradients$gradient__GT_string$$($stops$jscomp$17$$)},onPointerEnter:$handle_preview_enter$$,onPointerLeave:$handle_preview_leave$$,onPointerMove:$handle_preview_move$$,
onPointerDown:$handle_preview_down$$,className:"main_ui_workspace_colorpicker_gradients__gradient-background",children:$APP.$cljs$core$not$$($add_stop_disabled_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{display:$APP.$cljs$core$truth_$$($cljs$cst$5580$hover_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($preview_state$$)))?"block":"none","--preview-position":""+100*$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($preview_state$$))+"%"},
className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-preview"}):null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-wrapper",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$116$$,$color$jscomp$140_map__78162_p__78158$$){var $index$jscomp$467$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color$jscomp$140_map__78162_p__78158$$,0,null);$color$jscomp$140_map__78162_p__78158$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color$jscomp$140_map__78162_p__78158$$,1,null);var $alpha$jscomp$15_map__78162__$1$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$140_map__78162_p__78158$$);$color$jscomp$140_map__78162_p__78158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78162__$1$$,$APP.$cljs$cst$1298$color$$);var $offset$jscomp$203$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78162__$1$$,$APP.$cljs$cst$195$offset$$),
$r$jscomp$131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78162__$1$$,$APP.$cljs$cst$1743$r$$),$g$jscomp$153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78162__$1$$,$APP.$cljs$cst$1744$g$$),$b$jscomp$352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78162__$1$$,$APP.$cljs$cst$1520$b$$);$alpha$jscomp$15_map__78162__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78162__$1$$,
$APP.$cljs$cst$746$alpha$$);$out_arr__44124__auto__$jscomp$116$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--color-solid":$color$jscomp$140_map__78162_p__78158$$,"--color-alpha":"rgba("+($r$jscomp$131$$??"")+", "+($g$jscomp$153$$??"")+", "+($b$jscomp$352$$??"")+", "+($alpha$jscomp$15_map__78162__$1$$??"")+")","--position":""+$offset$jscomp$203$$*100+"%"},"data-index":$index$jscomp$467$$,onPointerDown:$handle_stop_marker_pointer_down$$,
onPointerMove:$handle_stop_marker_pointer_move$$,onLostPointerCapture:$handle_stop_marker_lost_pointer_capture$$,className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop$jscomp$3$$,$index$jscomp$467$$)?"main_ui_workspace_colorpicker_gradients__is-selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:"none"},className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-color"}),
(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:"none"},className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-alpha"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--position":""+$offset$jscomp$203$$*100+"%"},className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-decoration"})]},"preview-stop-"+($index$jscomp$467$$??"")));return $out_arr__44124__auto__$jscomp$116$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($stops$jscomp$17$$))})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$type$jscomp$610$$,options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$4163$linear_gradient$$,$APP.$cljs$cst$2287$label$$,"Linear"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$4165$radial_gradient$$,$APP.$cljs$cst$2287$label$$,"Radial"],null)],null),"on-change":$handle_change_type_props_78153$$,"class":"main_ui_workspace_colorpicker_gradients__gradient-options-select"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-options-buttons",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":"Rotate gradient",onClick:$handle_rotate_gradient$$,
iconClass:"main_ui_workspace_colorpicker_gradients__rotate-icon",icon:"reload"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":"Reverse gradient",onClick:$handle_reverse_gradient$$,icon:"switch"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":"Add stop",disabled:$add_stop_disabled_QMARK_$$,onClick:$handle_add_stop$$,icon:"add"})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_colorpicker_gradients__gradient-stops-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$117$$,$p__78163_stop$jscomp$11$$){var $index$jscomp$468$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78163_stop$jscomp$11$$,0,null);$p__78163_stop$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78163_stop$jscomp$11$$,
1,null);$out_arr__44124__auto__$jscomp$117$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$gradients$stop_input_row_STAR_$$,{stop:$p__78163_stop$jscomp$11$$,onSelectStop:$on_select_stop$jscomp$1$$,index:$index$jscomp$468$$,onFocusStopOffset:$on_stop_edit_start$$,onBlurStopColor:$on_stop_edit_finish$$,onChangeStop:$on_change_stop$jscomp$1$$,onFocusStopColor:$on_stop_edit_start$$,onBlurStopOffset:$on_stop_edit_finish$$,onReorderStops:$on_reorder_stops$jscomp$1$$,isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop$jscomp$3$$,
$index$jscomp$468$$),onRemoveStop:$on_remove_stop$jscomp$1$$},$index$jscomp$468$$));return $out_arr__44124__auto__$jscomp$117$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($stops$jscomp$17$$))})}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_workspace_colorpicker_gradients__gradient-separator"})]})};
$app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$=function($handle_start_drag_props_76841$$){function $calculate_pos$$($ev$jscomp$8_map__76843_x$jscomp$1245$$){if($APP.$cljs$core$truth_$$($on_change$jscomp$38$$)){var $left$jscomp$29_map__76842_value__$1$jscomp$39$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($ev$jscomp$8_map__76843_x$jscomp$1245$$)),$bottom$jscomp$5_map__76842__$1$$=$APP.$cljs$core$__destructure_map$$($left$jscomp$29_map__76842_value__$1$jscomp$39$$);
$left$jscomp$29_map__76842_value__$1$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__76842__$1$$,$APP.$cljs$cst$257$left$$);var $h_size_right$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__76842__$1$$,$APP.$cljs$cst$258$right$$),$top$jscomp$11_v_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__76842__$1$$,$APP.$cljs$cst$1562$top$$);$bottom$jscomp$5_map__76842__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__76842__$1$$,
$APP.$cljs$cst$1563$bottom$$);$ev$jscomp$8_map__76843_x$jscomp$1245$$=$APP.$app$util$dom$get_client_position$$($ev$jscomp$8_map__76843_x$jscomp$1245$$);var $map__76843__$1_y$jscomp$467$$=$APP.$cljs$core$__destructure_map$$($ev$jscomp$8_map__76843_x$jscomp$1245$$);$ev$jscomp$8_map__76843_x$jscomp$1245$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76843__$1_y$jscomp$467$$,$APP.$cljs$cst$1510$x$$);$map__76843__$1_y$jscomp$467$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76843__$1_y$jscomp$467$$,
$APP.$cljs$cst$1511$y$$);$h_size_right$jscomp$23$$-=$left$jscomp$29_map__76842_value__$1$jscomp$39$$;$top$jscomp$11_v_size$$=$bottom$jscomp$5_map__76842__$1$$-$top$jscomp$11_v_size$$;$left$jscomp$29_map__76842_value__$1$jscomp$39$$=$min_value__$1$jscomp$1$$+($APP.$cljs$core$truth_$$($is_vertical$$)?$top$jscomp$11_v_size$$>0?$APP.$app$common$math$clamp$$(($bottom$jscomp$5_map__76842__$1$$-$map__76843__$1_y$jscomp$467$$)/$top$jscomp$11_v_size$$,0,1):0:$h_size_right$jscomp$23$$>0?$APP.$app$common$math$clamp$$(($ev$jscomp$8_map__76843_x$jscomp$1245$$-
$left$jscomp$29_map__76842_value__$1$jscomp$39$$)/$h_size_right$jscomp$23$$,0,1):0)*($max_value__$1$jscomp$1$$-$min_value__$1$jscomp$1$$);return $on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$29_map__76842_value__$1$jscomp$39$$):$on_change$jscomp$38$$($left$jscomp$29_map__76842_value__$1$jscomp$39$$)}return null}var $on_change$jscomp$38$$=$handle_start_drag_props_76841$$.onChange,$on_start_drag$$=$handle_start_drag_props_76841$$.onStartDrag,
$value$jscomp$795$$=$handle_start_drag_props_76841$$.value,$is_vertical$$=$handle_start_drag_props_76841$$.isVertical,$type$jscomp$611$$=$handle_start_drag_props_76841$$.type,$handle_stop_drag_min_value$jscomp$2$$=$handle_start_drag_props_76841$$.minValue,$max_value$jscomp$4$$=$handle_start_drag_props_76841$$.maxValue,$class$$jscomp$61$$=$handle_start_drag_props_76841$$.className,$on_finish_drag$$=$handle_start_drag_props_76841$$.onFinishDrag,$min_value__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($handle_stop_drag_min_value$jscomp$2$$)?
$handle_stop_drag_min_value$jscomp$2$$:0,$max_value__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($max_value$jscomp$4$$)?$max_value$jscomp$4$$:1,$dragging_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$handle_start_drag_props_76841$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_drag$$)],function($event$jscomp$311$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$311$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$$,
!0);return $APP.$cljs$core$truth_$$($on_start_drag$$)?$on_start_drag$$.$cljs$core$IFn$_invoke$arity$0$?$on_start_drag$$.$cljs$core$IFn$_invoke$arity$0$():$on_start_drag$$():null});$handle_stop_drag_min_value$jscomp$2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_drag$$)],function($event$jscomp$312$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$312$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$$,!1);return $APP.$cljs$core$truth_$$($on_finish_drag$$)?
$on_finish_drag$$.$cljs$core$IFn$_invoke$arity$0$?$on_finish_drag$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_drag$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$611$$,$APP.$cljs$cst$1734$opacity$$)?"slider-opacity":null,onPointerDown:$handle_start_drag_props_76841$$,onPointerUp:$handle_stop_drag_min_value$jscomp$2$$,onLostPointerCapture:$handle_stop_drag_min_value$jscomp$2$$,onClick:$calculate_pos$$,onPointerMove:function($p1__76840_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($dragging_QMARK_$$))?
$calculate_pos$$($p1__76840_SHARP_$$):null},className:""+($class$$jscomp$61$$??"")+(($APP.$cljs$core$truth_$$($is_vertical$$)?"main_ui_workspace_colorpicker_slider_selector__vertical":"")+" main_ui_workspace_colorpicker_slider_selector__slider-selector "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$611$$,$APP.$cljs$cst$2018$hue$$)?"main_ui_workspace_colorpicker_slider_selector__hue":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$611$$,$APP.$cljs$cst$1734$opacity$$)?
"main_ui_workspace_colorpicker_slider_selector__opacity":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$611$$,$APP.$cljs$cst$260$value$$)?"main_ui_workspace_colorpicker_slider_selector__value":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$611$$,$cljs$cst$5581$hsl_saturation$$)?"main_ui_workspace_colorpicker_slider_selector__hsl-saturation":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$611$$,$APP.$cljs$cst$5582$lightness$$)?
"main_ui_workspace_colorpicker_slider_selector__lightness":"")),children:function(){var $style_vertical_value_percent_str$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(($value$jscomp$795$$-$min_value__$1$jscomp$1$$)/($max_value__$1$jscomp$1$$-$min_value__$1$jscomp$1$$)*100),"%"].join(""),$style_common$$={pointerEvents:"none"},$style_horizontal$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({left:$style_vertical_value_percent_str$$},$style_common$$);$style_vertical_value_percent_str$$=
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({bottom:$style_vertical_value_percent_str$$},$style_common$$);return(0,$APP.$rumext$v2$jsx$$)("div",{style:$APP.$cljs$core$truth_$$($is_vertical$$)?$style_vertical_value_percent_str$$:$style_horizontal$$,className:"main_ui_workspace_colorpicker_slider_selector__handler"})}()})};
$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$=function($hue$jscomp$2_hue_rad$$,$saturation$jscomp$1$$){$hue$jscomp$2_hue_rad$$=$APP.$goog$math$toRadians$$(-$hue$jscomp$2_hue_rad$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(96+$saturation$jscomp$1$$*Math.cos($hue$jscomp$2_hue_rad$$)*96,96+$saturation$jscomp$1$$*Math.sin($hue$jscomp$2_hue_rad$$)*96)};
$app$main$ui$workspace$colorpicker$harmony$harmony_selector_STAR_$$=function($alpha$jscomp$16_map__77108__$1_props_77103$$){function $on_change_opacity$$($G__77143_new_alpha$$){$G__77143_new_alpha$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$746$alpha$$,$G__77143_new_alpha$$],null);return $on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($G__77143_new_alpha$$):$on_change$jscomp$39$$($G__77143_new_alpha$$)}function $calculate_pos$jscomp$1$$($ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$){var $G__77124_map__77119_new_hue_top$jscomp$12$$=
$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$)),$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$=$APP.$cljs$core$__destructure_map$$($G__77124_map__77119_new_hue_top$jscomp$12$$),$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,
$APP.$cljs$cst$257$left$$),$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,$APP.$cljs$cst$258$right$$);$G__77124_map__77119_new_hue_top$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,$APP.$cljs$cst$1562$top$$);
$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,$APP.$cljs$cst$1563$bottom$$);$ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$=$APP.$app$util$dom$get_client_position$$($ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$);var $b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$=
$APP.$cljs$core$__destructure_map$$($ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$);$ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$,$APP.$cljs$cst$1510$x$$);$b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$,$APP.$cljs$cst$1511$y$$);
$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$=2*$APP.$app$common$math$clamp$$(($ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$-$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$)/($hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$-$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$),0,1)-
1;$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$=2*$APP.$app$common$math$clamp$$(($b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$-$G__77124_map__77119_new_hue_top$jscomp$12$$)/($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$-$G__77124_map__77119_new_hue_top$jscomp$12$$),0,1)-1;$G__77124_map__77119_new_hue_top$jscomp$12$$=$APP.$cljs$core$mod$$(Math.atan2($JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$,
$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$)*180/Math.PI-90,360);$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$,$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$],null);$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0],null);$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,0,null);$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,
1,null);$ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$,0,null);$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$,1,null);$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$=
$APP.$app$common$math$precision$$($APP.$app$common$math$hypot$$($JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$-$ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$,$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$-$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$),2);$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$=
$APP.$app$common$math$clamp$$($JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$,0,1);$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77124_map__77119_new_hue_top$jscomp$12$$,$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$,
$value$jscomp$796$$],null));$b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$);$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$,0,null);$ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$,1,null);$b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$,2,null);$G__77124_map__77119_new_hue_top$jscomp$12$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2687$hex$$,$hex$jscomp$10_p__24269$jscomp$inline_8728_py__$1_right$jscomp$24_y2$jscomp$inline_8732$$,
$APP.$cljs$cst$1743$r$$,$bottom$jscomp$6_map__77119__$1_p__24268$jscomp$inline_8727_r$jscomp$132_y1$jscomp$inline_8730$$,$APP.$cljs$cst$1744$g$$,$ev$jscomp$9_g$jscomp$154_map__77120_x$jscomp$1247_x2$jscomp$inline_8731$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$353_map__77120__$1_vec__77121_y$jscomp$469$$,$APP.$cljs$cst$1899$h$$,$G__77124_map__77119_new_hue_top$jscomp$12$$,$APP.$cljs$cst$4168$s$$,$JSCompiler_inline_result$jscomp$1522_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8729$$],null);return $on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($G__77124_map__77119_new_hue_top$jscomp$12$$):$on_change$jscomp$39$$($G__77124_map__77119_new_hue_top$jscomp$12$$)}var $on_change$jscomp$39$$=$alpha$jscomp$16_map__77108__$1_props_77103$$.onChange,$disable_opacity$jscomp$2$$=$alpha$jscomp$16_map__77108__$1_props_77103$$.disableOpacity,$color$jscomp$141_pos_current$$=$alpha$jscomp$16_map__77108__$1_props_77103$$.color,$on_start_drag$jscomp$1$$=$alpha$jscomp$16_map__77108__$1_props_77103$$.onStartDrag,
$on_finish_drag$jscomp$1$$=$alpha$jscomp$16_map__77108__$1_props_77103$$.onFinishDrag,$canvas_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null);$alpha$jscomp$16_map__77108__$1_props_77103$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$141_pos_current$$);var $hue$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77108__$1_props_77103$$,$APP.$cljs$cst$1899$h$$),$saturation$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77108__$1_props_77103$$,
$APP.$cljs$cst$4168$s$$),$value$jscomp$796$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77108__$1_props_77103$$,$APP.$cljs$cst$3670$v$$);$alpha$jscomp$16_map__77108__$1_props_77103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77108__$1_props_77103$$,$APP.$cljs$cst$746$alpha$$);$color$jscomp$141_pos_current$$=$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$($hue$jscomp$3$$,$saturation$jscomp$2$$);var $pos_complement$$=$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$($APP.$cljs$core$mod$$($hue$jscomp$3$$+
180,360),$saturation$jscomp$2$$),$dragging_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$handle_start_drag$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_drag$jscomp$1$$)],function($event$jscomp$313$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$313$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$1$$,!0);return $APP.$cljs$core$truth_$$($on_start_drag$jscomp$1$$)?$on_start_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$on_start_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_start_drag$jscomp$1$$():null}),$handle_stop_drag$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_drag$jscomp$1$$)],function($event$jscomp$314$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$314$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$1$$,!1);return $APP.$cljs$core$truth_$$($on_finish_drag$jscomp$1$$)?$on_finish_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$on_finish_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_drag$jscomp$1$$():null}),$l1$jscomp$3_vec__77109$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$3$$,$saturation$jscomp$2$$,0],null))),$h1$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$3_vec__77109$$,0,null),$s1$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$3_vec__77109$$,
1,null);$l1$jscomp$3_vec__77109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$3_vec__77109$$,2,null);var $l2$jscomp$2_vec__77112$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$3$$,$saturation$jscomp$2$$,255],null))),$h2$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l2$jscomp$2_vec__77112$$,0,null),$s2$jscomp$17$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l2$jscomp$2_vec__77112$$,1,null);$l2$jscomp$2_vec__77112$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l2$jscomp$2_vec__77112$$,2,null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($canvas_ref$jscomp$1$$)],function(){if($APP.$cljs$core$truth_$$($canvas_ref$jscomp$1$$)){var $G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$=
$APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$1$$);var $JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$=$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$.getContext("2d");var $G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$,
"width"),$radius$jscomp$inline_8737$$=$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$/2,$cx$jscomp$inline_8738$$=$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$/2,$cy$jscomp$inline_8739$$=$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$/2;$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.clearRect(0,
0,$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$,"height"));$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,360,.2));$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$=null;for(var $G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$=0,$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$=0;;)if($degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$<
$G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$){var $degrees_77158$jscomp$inline_8744$$=$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$.$cljs$core$IIndexed$_nth$arity$2$(null,$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$),$degrees_rad_77160$jscomp$inline_8745_y_77162$jscomp$inline_8747$$=
$APP.$goog$math$toRadians$$($degrees_77158$jscomp$inline_8744$$),$x_77161$jscomp$inline_8746$$=$radius$jscomp$inline_8737$$*Math.cos(-$degrees_rad_77160$jscomp$inline_8745_y_77162$jscomp$inline_8747$$);$degrees_rad_77160$jscomp$inline_8745_y_77162$jscomp$inline_8747$$=$radius$jscomp$inline_8737$$*Math.sin(-$degrees_rad_77160$jscomp$inline_8745_y_77162$jscomp$inline_8747$$);$APP.$app$util$object$set_BANG_$$($JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$,"strokeStyle",$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("hsl(%s, 100%, 50%)",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$degrees_77158$jscomp$inline_8744$$])));$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.beginPath();$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.moveTo($cx$jscomp$inline_8738$$,$cy$jscomp$inline_8739$$);$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.lineTo($cx$jscomp$inline_8738$$+$x_77161$jscomp$inline_8746$$,$cy$jscomp$inline_8739$$+$degrees_rad_77160$jscomp$inline_8745_y_77162$jscomp$inline_8747$$);$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.stroke();
$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$+=1}else if($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$=$APP.$cljs$core$seq$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$)?
($G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$=$APP.$cljs$core$_chunked_first$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$),$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$=
$APP.$cljs$core$_chunked_rest$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$),$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$=$G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$,
$G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$=$APP.$cljs$core$count$$($G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$)):($G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$=$APP.$cljs$core$first$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$),
$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$=$APP.$goog$math$toRadians$$($G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$),$G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$=$radius$jscomp$inline_8737$$*Math.cos(-$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$),
$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$=$radius$jscomp$inline_8737$$*Math.sin(-$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$),$APP.$app$util$object$set_BANG_$$($JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$,"strokeStyle",$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("hsl(%s, 100%, 50%)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$]))),
$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.beginPath(),$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.moveTo($cx$jscomp$inline_8738$$,$cy$jscomp$inline_8739$$),$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.lineTo($cx$jscomp$inline_8738$$+$G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$,$cy$jscomp$inline_8739$$+$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$),
$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.stroke(),$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$=$APP.$cljs$core$next$$($G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$),$G__77177$jscomp$inline_8752_chunk__76984_77155$jscomp$inline_8741_degrees_77181$jscomp$inline_8754_width$jscomp$inline_8736$$=
null,$G__77178$jscomp$inline_8753_c__5548__auto___77175$jscomp$inline_8750_count__76985_77156$jscomp$inline_8742_x_77183$jscomp$inline_8756$$=0),$degrees_rad_77182$jscomp$inline_8755_i__76986_77157$jscomp$inline_8743_y_77184$jscomp$inline_8757$$=0;else break;$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$=$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.createRadialGradient($cx$jscomp$inline_8738$$,
$cy$jscomp$inline_8739$$,0,$cx$jscomp$inline_8738$$,$cx$jscomp$inline_8738$$,$radius$jscomp$inline_8737$$);$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$.addColorStop(0,"rgba(255, 255, 255, 1)");$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$.addColorStop(1,
"rgba(255, 255, 255, 0)");$APP.$app$util$object$set_BANG_$$($JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$,"fillStyle",$G__77176$jscomp$inline_8751_canvas_node$jscomp$inline_8734_grd$jscomp$inline_8758_seq__76983_77154$jscomp$inline_8740_seq__76983_77174__$1$jscomp$inline_8749_temp__5825__auto___77169$jscomp$inline_8748$$);$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.beginPath();$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.arc($cx$jscomp$inline_8738$$,$cy$jscomp$inline_8739$$,
$radius$jscomp$inline_8737$$,0,2*$APP.$app$common$math$PI$$,!0);$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.closePath();$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$=$JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$.fill()}else $JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$=null;return $JSCompiler_temp$jscomp$1749_ctx$jscomp$inline_8735$$});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--hue-from":"hsl("+($h1$jscomp$30$$??"")+", "+$s1$jscomp$20$$*100+"%, "+$l1$jscomp$3_vec__77109$$*
100+"%)","--hue-to":"hsl("+($h2$jscomp$24$$??"")+", "+$s2$jscomp$17$$*100+"%, "+$l2$jscomp$2_vec__77112$$*100+"%)"},className:"main_ui_workspace_colorpicker_harmony__harmony-selector",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_harmony__handlers-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{type:$APP.$cljs$cst$260$value$$,isVertical:!0,value:$value$jscomp$796$$,maxValue:255,onChange:function($G__77129_new_value$jscomp$17$$){var $hex$jscomp$11$$=
$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$3$$,$saturation$jscomp$2$$,$G__77129_new_value$jscomp$17$$],null)),$b$jscomp$354_vec__77125$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$11$$),$r$jscomp$133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$354_vec__77125$$,0,null),$g$jscomp$155$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$354_vec__77125$$,
1,null);$b$jscomp$354_vec__77125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$354_vec__77125$$,2,null);$G__77129_new_value$jscomp$17$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2687$hex$$,$hex$jscomp$11$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$133$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$155$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$354_vec__77125$$,$APP.$cljs$cst$3670$v$$,$G__77129_new_value$jscomp$17$$],null);return $on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($G__77129_new_value$jscomp$17$$):$on_change$jscomp$39$$($G__77129_new_value$jscomp$17$$)},onStartDrag:$on_start_drag$jscomp$1$$,onFinishDrag:$on_finish_drag$jscomp$1$$}),$APP.$cljs$core$not$$($disable_opacity$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{type:$APP.$cljs$cst$1734$opacity$$,isVertical:!0,value:$alpha$jscomp$16_map__77108__$1_props_77103$$,maxValue:1,onChange:$on_change_opacity$$,
onStartDrag:$on_start_drag$jscomp$1$$,onFinishDrag:$on_finish_drag$jscomp$1$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_harmony__hue-wheel-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("canvas",{width:192,height:192,className:"main_ui_workspace_colorpicker_harmony__hue-wheel",onPointerUp:$handle_stop_drag$jscomp$1$$,onLostPointerCapture:$handle_stop_drag$jscomp$1$$,onClick:$calculate_pos$jscomp$1$$,onPointerMove:function($p1__77101_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$1$$))?
$calculate_pos$jscomp$1$$($p1__77101_SHARP_$$):null},ref:$canvas_ref$jscomp$1$$,onPointerDown:$handle_start_drag$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:"none",left:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$141_pos_current$$),top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$141_pos_current$$)},className:"main_ui_workspace_colorpicker_harmony__handler"}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{left:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($pos_complement$$),
top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($pos_complement$$),cursor:"pointer"},onClick:function(){var $G__77142_new_hue$jscomp$1$$=$APP.$cljs$core$mod$$($hue$jscomp$3$$+180,360),$hex$jscomp$12$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77142_new_hue$jscomp$1$$,$saturation$jscomp$2$$,$value$jscomp$796$$],null)),$b$jscomp$355_vec__77136$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$12$$),
$r$jscomp$134$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$355_vec__77136$$,0,null),$g$jscomp$156$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$355_vec__77136$$,1,null);$b$jscomp$355_vec__77136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$355_vec__77136$$,2,null);$G__77142_new_hue$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2687$hex$$,$hex$jscomp$12$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$134$$,$APP.$cljs$cst$1744$g$$,
$g$jscomp$156$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$355_vec__77136$$,$APP.$cljs$cst$1899$h$$,$G__77142_new_hue$jscomp$1$$,$APP.$cljs$cst$4168$s$$,$saturation$jscomp$2$$],null);return $on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($G__77142_new_hue$jscomp$1$$):$on_change$jscomp$39$$($G__77142_new_hue$jscomp$1$$)},className:"main_ui_workspace_colorpicker_harmony__handler main_ui_workspace_colorpicker_harmony__complement"})]})]})};
$app$main$ui$workspace$colorpicker$hsva$hsva_selector_STAR_$$=function($on_finish_drag$jscomp$2_props_77409$$){function $on_change_opacity$jscomp$1$$($G__77441_new_alpha$jscomp$1$$){$G__77441_new_alpha$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$746$alpha$$,$G__77441_new_alpha$jscomp$1$$],null);return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77441_new_alpha$jscomp$1$$):$on_change$jscomp$40$$($G__77441_new_alpha$jscomp$1$$)}
function $handle_change_hsl$$($key$jscomp$409$$){return function($g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$){var $G__77440_new_s$jscomp$1_r$jscomp$136$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$409$$,$cljs$cst$5423$hsl_s$$)?$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$:$hsl_s$jscomp$1$$;$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$409$$,$cljs$cst$5422$hsl_l$$)?$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$:
$hsl_l$jscomp$1$$;var $b$jscomp$357_vec__77428$$=$app$common$types$color$hsl__GT_rgb$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$4$$,$G__77440_new_s$jscomp$1_r$jscomp$136$$,$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$],null));$G__77440_new_s$jscomp$1_r$jscomp$136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$357_vec__77428$$,0,null);$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$357_vec__77428$$,
1,null);$b$jscomp$357_vec__77428$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$357_vec__77428$$,2,null);var $hex$jscomp$14$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77440_new_s$jscomp$1_r$jscomp$136$$,$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$,$b$jscomp$357_vec__77428$$],null)),$v$jscomp$657_vec__77431$$=$app$common$types$color$hex__GT_hsv$$($hex$jscomp$14$$),$h$jscomp$178$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$657_vec__77431$$,0,null),$s$jscomp$579$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$657_vec__77431$$,1,null);$v$jscomp$657_vec__77431$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$657_vec__77431$$,2,null);$G__77440_new_s$jscomp$1_r$jscomp$136$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2687$hex$$,$hex$jscomp$14$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$178$$,$APP.$cljs$cst$4168$s$$,
$s$jscomp$579$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$657_vec__77431$$,$APP.$cljs$cst$1743$r$$,$G__77440_new_s$jscomp$1_r$jscomp$136$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$357_vec__77428$$],null);return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77440_new_s$jscomp$1_r$jscomp$136$$):$on_change$jscomp$40$$($G__77440_new_s$jscomp$1_r$jscomp$136$$)}}function $handle_change_hsv$$($key$jscomp$408$$){return function($G__77427_change$jscomp$33_new_value$jscomp$18$$){$G__77427_change$jscomp$33_new_value$jscomp$18$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$key$jscomp$408$$],[$G__77427_change$jscomp$33_new_value$jscomp$18$$]);var $h$jscomp$177_hex$jscomp$13_map__77422$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$color$jscomp$142$$,$G__77427_change$jscomp$33_new_value$jscomp$18$$])),$g$jscomp$157_map__77422__$1_v$jscomp$656$$=$APP.$cljs$core$__destructure_map$$($h$jscomp$177_hex$jscomp$13_map__77422$$);$h$jscomp$177_hex$jscomp$13_map__77422$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$157_map__77422__$1_v$jscomp$656$$,$APP.$cljs$cst$1899$h$$);var $r$jscomp$135_s$jscomp$578$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$157_map__77422__$1_v$jscomp$656$$,$APP.$cljs$cst$4168$s$$);$g$jscomp$157_map__77422__$1_v$jscomp$656$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$157_map__77422__$1_v$jscomp$656$$,$APP.$cljs$cst$3670$v$$);$h$jscomp$177_hex$jscomp$13_map__77422$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$177_hex$jscomp$13_map__77422$$,$r$jscomp$135_s$jscomp$578$$,$g$jscomp$157_map__77422__$1_v$jscomp$656$$],null));var $b$jscomp$356_vec__77423$$=$APP.$app$common$types$color$hex__GT_rgb$$($h$jscomp$177_hex$jscomp$13_map__77422$$);$r$jscomp$135_s$jscomp$578$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$356_vec__77423$$,0,null);$g$jscomp$157_map__77422__$1_v$jscomp$656$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$356_vec__77423$$,
1,null);$b$jscomp$356_vec__77423$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$356_vec__77423$$,2,null);$G__77427_change$jscomp$33_new_value$jscomp$18$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__77427_change$jscomp$33_new_value$jscomp$18$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2687$hex$$,$h$jscomp$177_hex$jscomp$13_map__77422$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$135_s$jscomp$578$$,
$APP.$cljs$cst$1744$g$$,$g$jscomp$157_map__77422__$1_v$jscomp$656$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$356_vec__77423$$],null)]));return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77427_change$jscomp$33_new_value$jscomp$18$$):$on_change$jscomp$40$$($G__77427_change$jscomp$33_new_value$jscomp$18$$)}}var $on_change$jscomp$40$$=$on_finish_drag$jscomp$2_props_77409$$.onChange,$disable_opacity$jscomp$3$$=$on_finish_drag$jscomp$2_props_77409$$.disableOpacity,
$color$jscomp$142$$=$on_finish_drag$jscomp$2_props_77409$$.color,$on_start_drag$jscomp$2$$=$on_finish_drag$jscomp$2_props_77409$$.onStartDrag,$hsl_mode_QMARK__mode$jscomp$48$$=$on_finish_drag$jscomp$2_props_77409$$.mode;$on_finish_drag$jscomp$2_props_77409$$=$on_finish_drag$jscomp$2_props_77409$$.onFinishDrag;var $b_val_map__77416__$1$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$142$$),$hue$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$1899$h$$),
$saturation$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$4168$s$$),$value$jscomp$797$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$3670$v$$),$alpha$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$746$alpha$$),$r_val_vec__77417$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$1743$r$$),$g_val$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$1744$g$$);$b_val_map__77416__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77416__$1$$,$APP.$cljs$cst$1520$b$$);$hsl_mode_QMARK__mode$jscomp$48$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsl_mode_QMARK__mode$jscomp$48$$,$cljs$cst$5425$hsl$$);$r_val_vec__77417$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($r_val_vec__77417$$)?$APP.$cljs$core$truth_$$($g_val$$)?
$b_val_map__77416__$1$$:$g_val$$:$r_val_vec__77417$$)?$APP.$app$common$types$color$rgb__GT_hsl$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r_val_vec__77417$$,$g_val$$,$b_val_map__77416__$1$$],null)):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0],null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r_val_vec__77417$$,0,null);var $hsl_s$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r_val_vec__77417$$,
1,null),$hsl_l$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r_val_vec__77417$$,2,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:"H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,
{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$APP.$cljs$cst$2018$hue$$,maxValue:360,value:$hue$jscomp$4$$,onChange:$handle_change_hsv$$($APP.$cljs$cst$1899$h$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77409$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:"S"}),$hsl_mode_QMARK__mode$jscomp$48$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$cljs$cst$5581$hsl_saturation$$,maxValue:1,value:$hsl_s$jscomp$1$$,onChange:$handle_change_hsl$$($cljs$cst$5423$hsl_s$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77409$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",
type:$APP.$cljs$cst$2021$saturation$$,maxValue:1,value:$saturation$jscomp$3$$,onChange:$handle_change_hsv$$($APP.$cljs$cst$4168$s$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77409$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:$hsl_mode_QMARK__mode$jscomp$48$$?"L":"B(V)"}),$hsl_mode_QMARK__mode$jscomp$48$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$APP.$cljs$cst$5582$lightness$$,maxValue:1,value:$hsl_l$jscomp$1$$,onChange:$handle_change_hsl$$($cljs$cst$5422$hsl_l$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77409$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",
type:$APP.$cljs$cst$260$value$$,maxValue:255,value:$value$jscomp$797$$,onChange:$handle_change_hsv$$($APP.$cljs$cst$3670$v$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77409$$})]}),$APP.$cljs$core$not$$($disable_opacity$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:"A"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,
{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$APP.$cljs$cst$1734$opacity$$,maxValue:1,value:$alpha$jscomp$17$$,onChange:$on_change_opacity$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77409$$})]}):null]})};
$app$main$ui$workspace$colorpicker$libraries$libraries_STAR_$$=function($current_colors_props_77412$$){var $disable_gradient$jscomp$1$$=$current_colors_props_77412$$.disableGradient,$on_add_library_color$$=$current_colors_props_77412$$.onAddLibraryColor,$disable_opacity$jscomp$4$$=$current_colors_props_77412$$.disableOpacity,$disable_image$jscomp$1$$=$current_colors_props_77412$$.disableImage,$state$jscomp$1166$$=$current_colors_props_77412$$.state,$on_select_color$$=$current_colors_props_77412$$.onSelectColor,
$selected_STAR_$jscomp$1$$=$app$main$ui$hooks$use_shared_state$$($APP.$cljs$cst$4126$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpicker_selected$$),$selected$jscomp$140$$=$APP.$cljs$core$_deref$$($selected_STAR_$jscomp$1$$),$file_id$jscomp$369$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$current_colors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$);$current_colors_props_77412$$=$APP.$cljs$core$_deref$$($current_colors_STAR_$$);
var $libraries$jscomp$136$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$recent_colors$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_colors$$),$recent_colors__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($recent_colors$jscomp$1$$)],function(){return $APP.$cljs$core$filterv$$($APP.$app$common$types$color$valid_color_QMARK_$$,$recent_colors$jscomp$1$$)}),$library_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"recent",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.recent-colors")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"file",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.file-library")],
null)],null)}),$options$jscomp$608$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($library_options$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$136$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$369$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($library_options$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($lib$jscomp$12$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$app$common$data$name$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$12$$)),$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$12$$)],null)})),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$136$$,$file_id$jscomp$369$$))}),$on_library_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$315$$){return $APP.$cljs$core$reset_BANG_$$($selected_STAR_$jscomp$1$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$315$$,"recent")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$315$$,"file")?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$315$$):$APP.$app$common$uuid$parse$$($event$jscomp$315$$))}),$valid_color_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disable_gradient$jscomp$1$$),$APP.$rumext$v2$adapt$$($disable_opacity$jscomp$4$$),$APP.$rumext$v2$adapt$$($disable_image$jscomp$1$$)],
function($color$jscomp$143$$){return($APP.$cljs$core$not$$($disable_gradient$jscomp$1$$)||$APP.$cljs$core$not$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$143$$)))&&($APP.$cljs$core$not$$($disable_opacity$jscomp$4$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$143$$)))&&($APP.$cljs$core$not$$($disable_image$jscomp$1$$)||$APP.$cljs$core$not$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$143$$)))}),
$toggle_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$140$$)],function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1563$bottom$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),"fade-out-down");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3740$textpalette$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$data$workspace$colors$show_palette$$($selected$jscomp$140$$),
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-colorpicker")]))}),$on_color_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1166$$),$APP.$rumext$v2$adapt$$($selected$jscomp$140$$),$APP.$rumext$v2$adapt$$($on_select_color$$)],function($event$jscomp$316$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5583$recent$$,$selected$jscomp$140$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-color",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"colorpicker",$APP.$cljs$cst$3933$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$208$file$$,$selected$jscomp$140$$)],null)));return $on_select_color$$.$cljs$core$IFn$_invoke$arity$2$?$on_select_color$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1166$$,$event$jscomp$316$$):$on_select_color$$($state$jscomp$1166$$,
$event$jscomp$316$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$140$$),$APP.$rumext$v2$adapt$$($recent_colors__$1$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$136$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$369$$),$APP.$rumext$v2$adapt$$($valid_color_QMARK_$$)],function(){var $file_id__$1$jscomp$11$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$140$$,$APP.$cljs$cst$208$file$$)?$file_id$jscomp$369$$:$selected$jscomp$140$$,
$colors$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$140$$,$cljs$cst$5583$recent$$)?$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$color$sort_colors$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$469$$,$color$jscomp$144_color__$1$jscomp$26$$){$color$jscomp$144_color__$1$jscomp$26$$=$APP.$cljs$core$map_QMARK_$$($color$jscomp$144_color__$1$jscomp$26$$)?$color$jscomp$144_color__$1$jscomp$26$$:
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1298$color$$,$color$jscomp$144_color__$1$jscomp$26$$],null);return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($color$jscomp$144_color__$1$jscomp$26$$,$cljs$cst$5584$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$,""+($index$jscomp$469$$??""))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($valid_color_QMARK_$$,$APP.$cljs$core$reverse$$($recent_colors__$1$$)))):$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$470$$,
$color$jscomp$145$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($color$jscomp$145$$,$cljs$cst$5584$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$,""+($index$jscomp$470$$??""))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77408_SHARP_$$){return $app$common$types$color$library_color__GT_color$$($p1__77408_SHARP_$$,$file_id__$1$jscomp$11$$)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($valid_color_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$136$$,$file_id__$1$jscomp$11$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2212$colors$$))))));return $APP.$cljs$core$reset_BANG_$$($current_colors_STAR_$$,$colors$jscomp$9$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_libraries__libraries",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_libraries__select-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_colorpicker_libraries__shadow-type-select","data-direction":"up","default-value":function(){var $or__5025__auto__$jscomp$1079$$=$APP.$app$common$data$name$$($selected$jscomp$140$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1079$$)?$or__5025__auto__$jscomp$1079$$:"recent"}(),
options:$options$jscomp$608$$,"on-change":$on_library_change$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_libraries__selected-colors",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$140$$,$APP.$cljs$cst$208$file$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_add_library_color$$,className:"main_ui_workspace_colorpicker_libraries__add-color-btn",children:$APP.$app$main$ui$icons$add$$}):null,(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$toggle_palette$$,className:"main_ui_workspace_colorpicker_libraries__palette-btn",children:$APP.$app$main$ui$icons$swatches$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$118$$,$color$jscomp$146$$){$out_arr__44124__auto__$jscomp$118$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{color:$color$jscomp$146$$,"on-click":$on_color_click$$},$cljs$cst$5584$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($color$jscomp$146$$))));
return $out_arr__44124__auto__$jscomp$118$$},[],$current_colors_props_77412$$)]})]})};
$app$main$ui$workspace$colorpicker$ramp$value_saturation_selector_STAR_$$=function($handle_start_drag$jscomp$2_props_77407$$){function $calculate_pos$jscomp$2$$($ev$jscomp$10_map__77421_x$jscomp$1248$$){var $map__77420_py$jscomp$11_top$jscomp$13$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($ev$jscomp$10_map__77421_x$jscomp$1248$$)),$bottom$jscomp$7_map__77420__$1$$=$APP.$cljs$core$__destructure_map$$($map__77420_py$jscomp$11_top$jscomp$13$$),$left$jscomp$31_px$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77420__$1$$,$APP.$cljs$cst$257$left$$),$right$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77420__$1$$,$APP.$cljs$cst$258$right$$);$map__77420_py$jscomp$11_top$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77420__$1$$,$APP.$cljs$cst$1562$top$$);$bottom$jscomp$7_map__77420__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77420__$1$$,
$APP.$cljs$cst$1563$bottom$$);$ev$jscomp$10_map__77421_x$jscomp$1248$$=$APP.$app$util$dom$get_client_position$$($ev$jscomp$10_map__77421_x$jscomp$1248$$);var $map__77421__$1_y$jscomp$470$$=$APP.$cljs$core$__destructure_map$$($ev$jscomp$10_map__77421_x$jscomp$1248$$);$ev$jscomp$10_map__77421_x$jscomp$1248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77421__$1_y$jscomp$470$$,$APP.$cljs$cst$1510$x$$);$map__77421__$1_y$jscomp$470$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77421__$1_y$jscomp$470$$,
$APP.$cljs$cst$1511$y$$);$left$jscomp$31_px$jscomp$12$$=$APP.$app$common$math$clamp$$(($ev$jscomp$10_map__77421_x$jscomp$1248$$-$left$jscomp$31_px$jscomp$12$$)/($right$jscomp$25$$-$left$jscomp$31_px$jscomp$12$$),0,1);$map__77420_py$jscomp$11_top$jscomp$13$$=255*(1-$APP.$app$common$math$clamp$$(($map__77421__$1_y$jscomp$470$$-$map__77420_py$jscomp$11_top$jscomp$13$$)/($bottom$jscomp$7_map__77420__$1$$-$map__77420_py$jscomp$11_top$jscomp$13$$),0,1));return $on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$31_px$jscomp$12$$,$map__77420_py$jscomp$11_top$jscomp$13$$):$on_change$jscomp$41$$($left$jscomp$31_px$jscomp$12$$,$map__77420_py$jscomp$11_top$jscomp$13$$)}var $on_change$jscomp$41$$=$handle_start_drag$jscomp$2_props_77407$$.onChange,$saturation$jscomp$4$$=$handle_start_drag$jscomp$2_props_77407$$.saturation,$on_start_drag$jscomp$3$$=$handle_start_drag$jscomp$2_props_77407$$.onStartDrag,$value$jscomp$798$$=$handle_start_drag$jscomp$2_props_77407$$.value,
$on_finish_drag$jscomp$3$$=$handle_start_drag$jscomp$2_props_77407$$.onFinishDrag,$dragging_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$2$$=$APP.$cljs$core$_deref$$($dragging_QMARK__STAR_$$);$handle_start_drag$jscomp$2_props_77407$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_drag$jscomp$3$$)],function($event$jscomp$317$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$317$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK__STAR_$$,
!0);return $on_start_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_start_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_start_drag$jscomp$3$$()});var $handle_stop_drag$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_drag$jscomp$3$$)],function($event$jscomp$318$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$318$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK__STAR_$$,!1);return $on_finish_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$on_finish_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_drag$jscomp$3$$()}),$handle_change_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_pos$jscomp$2$$),$APP.$rumext$v2$adapt$$($dragging_QMARK_$jscomp$2$$)],function($event$jscomp$319$$){return $APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$2$$)?$calculate_pos$jscomp$2$$($event$jscomp$319$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"value-saturation-selector",
onPointerDown:$handle_start_drag$jscomp$2_props_77407$$,onPointerUp:$handle_stop_drag$jscomp$2$$,onClick:$calculate_pos$jscomp$2$$,onPointerMove:$handle_change_pointer_move$$,className:"main_ui_workspace_colorpicker_ramp__value-saturation-selector",children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"ramp-handler",style:{pointerEvents:"none",left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(100*$saturation$jscomp$4$$),"%"].join(""),top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(100*
(1-$value$jscomp$798$$/255)),"%"].join("")},className:"main_ui_workspace_colorpicker_ramp__handler"})})};
$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$=function($map__77435__$1_p__77434$$){$map__77435__$1_p__77434$$=$APP.$cljs$core$__destructure_map$$($map__77435__$1_p__77434$$);var $h$jscomp$179_h__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77435__$1_p__77434$$,$APP.$cljs$cst$1899$h$$),$s$jscomp$580_s__$1$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77435__$1_p__77434$$,$APP.$cljs$cst$4168$s$$),$v$jscomp$658_v__$1$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77435__$1_p__77434$$,
$APP.$cljs$cst$3670$v$$);$h$jscomp$179_h__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$179_h__$1$jscomp$2$$,0);$s$jscomp$580_s__$1$jscomp$50$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$580_s__$1$jscomp$50$$,0);$v$jscomp$658_v__$1$jscomp$32$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$658_v__$1$jscomp$32$$,0);var $hsv$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$h$jscomp$179_h__$1$jscomp$2$$,$s$jscomp$580_s__$1$jscomp$50$$,$v$jscomp$658_v__$1$jscomp$32$$],null),$b$jscomp$358_vec__77437$$=$app$common$types$color$hsv__GT_rgb$$($hsv$jscomp$2$$),$r$jscomp$137$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$358_vec__77437$$,0,null),$g$jscomp$159$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$358_vec__77437$$,1,null);$b$jscomp$358_vec__77437$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$358_vec__77437$$,
2,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__77435__$1_p__77434$$,$APP.$cljs$cst$2687$hex$$,$app$common$types$color$hsv__GT_hex$$($hsv$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1899$h$$,$h$jscomp$179_h__$1$jscomp$2$$,$APP.$cljs$cst$4168$s$$,$s$jscomp$580_s__$1$jscomp$50$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$658_v__$1$jscomp$32$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$137$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$159$$,$APP.$cljs$cst$1520$b$$,
$b$jscomp$358_vec__77437$$]))};
$app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$=function($on_finish_drag$jscomp$4_props_77442$$){var $on_change$jscomp$42$$=$on_finish_drag$jscomp$4_props_77442$$.onChange,$disable_opacity$jscomp$5$$=$on_finish_drag$jscomp$4_props_77442$$.disableOpacity,$color$jscomp$148$$=$on_finish_drag$jscomp$4_props_77442$$.color,$on_start_drag$jscomp$4$$=$on_finish_drag$jscomp$4_props_77442$$.onStartDrag;$on_finish_drag$jscomp$4_props_77442$$=$on_finish_drag$jscomp$4_props_77442$$.onFinishDrag;var $internal_color_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($color$jscomp$148$$)}),$internal_color$$=$APP.$cljs$core$_deref$$($internal_color_STAR_$$),$h$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$1899$h$$),$s$jscomp$581$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$4168$s$$),$v$jscomp$659$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,
$APP.$cljs$cst$3670$v$$),$hex$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$2687$hex$$),$alpha$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$746$alpha$$),$bullet_color$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hex$jscomp$15$$),$APP.$rumext$v2$adapt$$($alpha$jscomp$18$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,
$hex$jscomp$15$$,$APP.$cljs$cst$1734$opacity$$,$alpha$jscomp$18$$],null)}),$on_change_value_saturation$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_color$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$42$$)],function($color__$1$jscomp$27_saturation$jscomp$5$$,$value$jscomp$799$$){$color__$1$jscomp$27_saturation$jscomp$5$$=$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($internal_color$$,
$APP.$cljs$cst$4168$s$$,$color__$1$jscomp$27_saturation$jscomp$5$$),$APP.$cljs$cst$3670$v$$,$value$jscomp$799$$));$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,$color__$1$jscomp$27_saturation$jscomp$5$$);return $on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$27_saturation$jscomp$5$$):$on_change$jscomp$42$$($color__$1$jscomp$27_saturation$jscomp$5$$)}),$on_change_hue$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_color$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$42$$)],function($color__$1$jscomp$28_hue$jscomp$5$$){$color__$1$jscomp$28_hue$jscomp$5$$=$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($internal_color$$,$APP.$cljs$cst$1899$h$$,$color__$1$jscomp$28_hue$jscomp$5$$));$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,$color__$1$jscomp$28_hue$jscomp$5$$);return $on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$28_hue$jscomp$5$$):
$on_change$jscomp$42$$($color__$1$jscomp$28_hue$jscomp$5$$)}),$on_change_opacity$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_color$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$42$$)],function($color__$1$jscomp$29_opacity$jscomp$47$$){$color__$1$jscomp$29_opacity$jscomp$47$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($internal_color$$,$APP.$cljs$cst$746$alpha$$,$color__$1$jscomp$29_opacity$jscomp$47$$);$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,
$color__$1$jscomp$29_opacity$jscomp$47$$);return $on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$29_opacity$jscomp$47$$):$on_change$jscomp$42$$($color__$1$jscomp$29_opacity$jscomp$47$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$148$$)],function(){return $APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($color$jscomp$148$$))});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$ramp$value_saturation_selector_STAR_$$,{hue:$h$jscomp$180$$,saturation:$s$jscomp$581$$,value:$v$jscomp$659$$,onChange:$on_change_value_saturation$$,onStartDrag:$on_start_drag$jscomp$4$$,onFinishDrag:$on_finish_drag$jscomp$4_props_77442$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--bullet-size":"52px"},className:"main_ui_workspace_colorpicker_ramp__shade-selector",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,
{color:$bullet_color$$,area:!0}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_ramp__sliders-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{type:$APP.$cljs$cst$2018$hue$$,maxValue:360,value:$h$jscomp$180$$,onChange:$on_change_hue$$,onStartDrag:$on_start_drag$jscomp$4$$,onFinishDrag:$on_finish_drag$jscomp$4_props_77442$$}),$APP.$cljs$core$not$$($disable_opacity$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,
{type:$APP.$cljs$cst$1734$opacity$$,maxValue:1,value:$alpha$jscomp$18$$,onChange:$on_change_opacity$jscomp$2$$,onStartDrag:$on_start_drag$jscomp$4$$,onFinishDrag:$on_finish_drag$jscomp$4_props_77442$$}):null]})]})]})};
$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$=function($node_ref$jscomp$3$$,$current_color$jscomp$2$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_color$jscomp$2$$)],function(){function $format_hsl$$($G__78190_l$jscomp$109_p__78183$$){var $h__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78190_l$jscomp$109_p__78183$$,0,null),$G__78189_s$jscomp$582$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78190_l$jscomp$109_p__78183$$,
1,null);$G__78190_l$jscomp$109_p__78183$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78190_l$jscomp$109_p__78183$$,2,null);$G__78189_s$jscomp$582$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78189_s$jscomp$582$$*100),"%"].join("");$G__78190_l$jscomp$109_p__78183$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78190_l$jscomp$109_p__78183$$*100),"%"].join("");return $APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$4$("hsl(%s, %s, %s)",
$h__$1$jscomp$3$$,$G__78189_s$jscomp$582$$,$G__78190_l$jscomp$109_p__78183$$):$APP.$cuerdas$core$format$$("hsl(%s, %s, %s)",$h__$1$jscomp$3$$,$G__78189_s$jscomp$582$$,$G__78190_l$jscomp$109_p__78183$$)}var $node$jscomp$405$$=$APP.$rumext$v2$ref_val$$($node_ref$jscomp$3$$),$hsl_to_map__78179__$1_v$jscomp$660$$=$APP.$cljs$core$__destructure_map$$($current_color$jscomp$2$$),$r$jscomp$138_rgb$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78179__$1_v$jscomp$660$$,$APP.$cljs$cst$1743$r$$),
$g$jscomp$160_hue_rgb$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78179__$1_v$jscomp$660$$,$APP.$cljs$cst$1744$g$$),$b$jscomp$359_hsl_from$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78179__$1_v$jscomp$660$$,$APP.$cljs$cst$1520$b$$),$h$jscomp$181_lightness_mid$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78179__$1_v$jscomp$660$$,$APP.$cljs$cst$1899$h$$);$hsl_to_map__78179__$1_v$jscomp$660$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78179__$1_v$jscomp$660$$,
$APP.$cljs$cst$3670$v$$);$r$jscomp$138_rgb$jscomp$6$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$138_rgb$jscomp$6$$,$g$jscomp$160_hue_rgb$$,$b$jscomp$359_hsl_from$$],null);$g$jscomp$160_hue_rgb$$=$app$common$types$color$hsv__GT_rgb$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,1,255],null));$b$jscomp$359_hsl_from$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,0,$hsl_to_map__78179__$1_v$jscomp$660$$],null)));$hsl_to_map__78179__$1_v$jscomp$660$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,1,$hsl_to_map__78179__$1_v$jscomp$660$$],null)));var $hsl_sat_from_vec__78180$$=$APP.$app$common$types$color$rgb__GT_hsl$$($r$jscomp$138_rgb$jscomp$6$$);
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hsl_sat_from_vec__78180$$,0,null);var $cur_hsl_s$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hsl_sat_from_vec__78180$$,1,null),$cur_hsl_l_hsl_sat_to$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hsl_sat_from_vec__78180$$,2,null);$hsl_sat_from_vec__78180$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,0,$cur_hsl_l_hsl_sat_to$$],null);
$cur_hsl_l_hsl_sat_to$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,1,$cur_hsl_l_hsl_sat_to$$],null);$h$jscomp$181_lightness_mid$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,$cur_hsl_s$$,.5],null);$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--color",$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$r$jscomp$138_rgb$jscomp$6$$));
$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--hue-rgb",$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$g$jscomp$160_hue_rgb$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--saturation-grad-from",$format_hsl$$($b$jscomp$359_hsl_from$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--saturation-grad-to",$format_hsl$$($hsl_to_map__78179__$1_v$jscomp$660$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--hsl-saturation-grad-from",
$format_hsl$$($hsl_sat_from_vec__78180$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--hsl-saturation-grad-to",$format_hsl$$($cur_hsl_l_hsl_sat_to$$));return $APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$405$$,"--lightness-grad-mid",$format_hsl$$($h$jscomp$181_lightness_mid$$))})};
$app$main$ui$workspace$colorpicker$colorpicker_STAR_$$=function($origin$jscomp$60_props_78197$$){var $tab$jscomp$7_toggle_token_color$$=$origin$jscomp$60_props_78197$$.tab,$on_change$jscomp$43$$=$origin$jscomp$60_props_78197$$.onChange,$data$jscomp$470$$=$origin$jscomp$60_props_78197$$.data,$disable_gradient$jscomp$2$$=$origin$jscomp$60_props_78197$$.disableGradient,$disable_opacity$jscomp$6$$=$origin$jscomp$60_props_78197$$.disableOpacity,$on_token_change$jscomp$3$$=$origin$jscomp$60_props_78197$$.onTokenChange,
$combined_tokens$jscomp$3$$=$origin$jscomp$60_props_78197$$.combinedTokens,$disable_image$jscomp$2$$=$origin$jscomp$60_props_78197$$.disableImage,$applied_token$jscomp$3$$=$origin$jscomp$60_props_78197$$.appliedToken,$on_accept$jscomp$9$$=$origin$jscomp$60_props_78197$$.onAccept,$color_origin$jscomp$2$$=$origin$jscomp$60_props_78197$$.colorOrigin;$origin$jscomp$60_props_78197$$=$origin$jscomp$60_props_78197$$.origin;var $state$jscomp$1167$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$colorpicker$$),
$node_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(),$should_update_QMARK_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$token_color$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1213$token_color$$),$color_style_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$7_toggle_token_color$$,$cljs$cst$5586$direct_color$$)),$color_style$jscomp$1$$=$APP.$cljs$core$_deref$$($color_style_STAR_$$);
$tab$jscomp$7_toggle_token_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_style$jscomp$1$$)],function(){var $new_style$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5586$direct_color$$,$color_style$jscomp$1$$)?$APP.$cljs$cst$1213$token_color$$:$cljs$cst$5586$direct_color$$;return $APP.$cljs$core$reset_BANG_$$($color_style_STAR_$$,$new_style$jscomp$1$$)});var $picking_color_QMARK_$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$picking_color_QMARK_$$),
$picked_color$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$picked_color$$),$picked_color_select$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$picked_color_select$$),$current_color$jscomp$3$$=$APP.$cljs$cst$4164$current_color$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$),$active_fill_tab$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$470$$))?$APP.$cljs$cst$1612$image$$:function(){var $G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$=
$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$470$$);if($APP.$cljs$core$truth_$$($G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$))switch($G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$),$G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$=$G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$ instanceof $APP.$cljs$core$Keyword$$?$G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$.$fqn$:
null,$G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$){case "linear":return $APP.$cljs$cst$4163$linear_gradient$$;case "radial":return $APP.$cljs$cst$4165$radial_gradient$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78199_G__78199__$1_temp__5823__auto__$jscomp$232$$)].join(""));}else return $APP.$cljs$cst$1298$color$$}(),$active_color_tab_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5587$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_color_tab$$,
"ramp"),$active_color_tab$$=$APP.$cljs$core$_deref$$($active_color_tab_STAR_$$),$hsb_mode_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5588$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_hsb_mode$$,$cljs$cst$5421$hsb$$),$hsb_mode$jscomp$1$$=$APP.$cljs$core$_deref$$($hsb_mode_STAR_$$),$drag_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$drag_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($drag_QMARK__STAR_$$),$type$jscomp$612$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_color_tab$$,
"hsva")?$cljs$cst$5421$hsb$$:$cljs$cst$5424$rgb$$,$fill_image_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$color_type$jscomp$2_selected_mode$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1167$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1298$color$$);switch($color_type$jscomp$2_selected_mode$$ instanceof $APP.$cljs$core$Keyword$$?$color_type$jscomp$2_selected_mode$$.$fqn$:null){case "linear-gradient":case "radial-gradient":$color_type$jscomp$2_selected_mode$$=$APP.$cljs$cst$1724$gradient$$}var $disabled_color_accept_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,$APP.$cljs$cst$1612$image$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$)),$on_fill_image_success$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($image$jscomp$36$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1612$image$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$select_keys$$($image$jscomp$36$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1726$mtype$$,$APP.$cljs$cst$725$name$$],null)),$APP.$cljs$cst$1727$keep_aspect_ratio$$,!0)],null),$APP.$cljs$core$not$$($drag_QMARK_$jscomp$1$$)))}),$on_fill_image_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($fill_image_ref$$))}),
$on_fill_image_selected$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file$jscomp$158$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$upload_fill_image$$($file$jscomp$158$$,$on_fill_image_success$$))}),$handle_change_keep_aspect_ratio$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_color$jscomp$3$$)],function(){var $keep_aspect_ratio_QMARK_$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1727$keep_aspect_ratio$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$))),
$image$jscomp$37$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$),$APP.$cljs$cst$1727$keep_aspect_ratio$$,$keep_aspect_ratio_QMARK_$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$update_colorpicker_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1612$image$$,$image$jscomp$37$$],null),!0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"toggle-image-aspect-ratio",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:colorpicker",$cljs$cst$5589$checked$$,$keep_aspect_ratio_QMARK_$$],null))]))}),$on_change_tab$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78191_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($active_color_tab_STAR_$$,$p1__78191_SHARP_$$)}),$handle_change_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$800$$){switch($value$jscomp$800$$ instanceof
$APP.$cljs$core$Keyword$$?$value$jscomp$800$$.$fqn$:null){case "color":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_color$$());case "gradient":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_gradient$$($APP.$cljs$cst$4163$linear_gradient$$));case "image":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_image$$());
default:return null}}),$handle_change_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_color$jscomp$3$$),$APP.$rumext$v2$adapt$$($drag_QMARK_$jscomp$1$$)],function($color$jscomp$149_color__$1$jscomp$30_color__$2$jscomp$2$$){$color$jscomp$149_color__$1$jscomp$30_color__$2$jscomp$2$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$current_color$jscomp$3$$,$color$jscomp$149_color__$1$jscomp$30_color__$2$jscomp$2$$]));
$color$jscomp$149_color__$1$jscomp$30_color__$2$jscomp$2$$=$app$main$data$workspace$colors$materialize_color_components$$($color$jscomp$149_color__$1$jscomp$30_color__$2$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_color$$($color$jscomp$149_color__$1$jscomp$30_color__$2$jscomp$2$$,$APP.$cljs$core$not$$($drag_QMARK_$jscomp$1$$)))}),$handle_click_picker$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($picking_color_QMARK_$$)],
function(){if($APP.$cljs$core$truth_$$($picking_color_QMARK_$$))return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$(),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$stop_picker$$());$app$main$data$modal$allow_click_outside_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$start_picker$$())}),$on_select_library_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$470$$),
$APP.$rumext$v2$adapt$$($handle_change_color$jscomp$1$$)],function($G__78203__$jscomp$2973_color__$1$jscomp$31$$,$color$jscomp$150$$){if($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$150$$)!=null&&$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$470$$)!=null)return $G__78203__$jscomp$2973_color__$1$jscomp$31$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2687$hex$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$150$$),
$APP.$cljs$cst$746$alpha$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$150$$)],null),$handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78203__$jscomp$2973_color__$1$jscomp$31$$):$handle_change_color$jscomp$1$$($G__78203__$jscomp$2973_color__$1$jscomp$31$$);$G__78203__$jscomp$2973_color__$1$jscomp$31$$=$APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($color$jscomp$150$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($G__78203__$jscomp$2973_color__$1$jscomp$31$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$apply_color_from_colorpicker$$($G__78203__$jscomp$2973_color__$1$jscomp$31$$)]));return $on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$($G__78203__$jscomp$2973_color__$1$jscomp$31$$):
$on_change$jscomp$43$$($G__78203__$jscomp$2973_color__$1$jscomp$31$$)}),$on_add_library_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1167$$)],function(){var $JSCompiler_temp_const$jscomp$1674$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1676_color$jscomp$inline_8761$$=$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($state$jscomp$1167$$);$JSCompiler_inline_result$jscomp$1676_color$jscomp$inline_8761$$=
$APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1676_color$jscomp$inline_8761$$,null);return $JSCompiler_temp_const$jscomp$1674$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1676_color$jscomp$inline_8761$$)}),$on_start_drag$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drag_QMARK__STAR_$$),$APP.$rumext$v2$adapt$$($node_ref$jscomp$4$$)],function(){$APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,
!1);$APP.$cljs$core$reset_BANG_$$($drag_QMARK__STAR_$$,!0);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($APP.$rumext$v2$ref_val$$($node_ref$jscomp$4$$)))}),$on_finish_drag$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drag_QMARK__STAR_$$),$APP.$rumext$v2$adapt$$($node_ref$jscomp$4$$)],function(){$APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,!0);$APP.$cljs$core$reset_BANG_$$($drag_QMARK__STAR_$$,
!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($APP.$rumext$v2$ref_val$$($node_ref$jscomp$4$$)))}),$on_color_accept$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1167$$)],function(){var $G__78204_78252$$=$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($state$jscomp$1167$$);$on_accept$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($G__78204_78252$$):
$on_accept$jscomp$9$$($G__78204_78252$$);return $APP.$app$main$data$modal$hide_BANG_$$()}),$options$jscomp$609$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_type$jscomp$2_selected_mode$$),$APP.$rumext$v2$adapt$$($disable_gradient$jscomp$2$$),$APP.$rumext$v2$adapt$$($disable_image$jscomp$2$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.solid")],null)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$not$$($disable_gradient$jscomp$2$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.gradient")],null)],null):null,$APP.$cljs$core$not$$($disable_image$jscomp$2$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")],
null)],null):null]))}),$handle_change_gradient_selected_stop$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$471$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$select_colorpicker_gradient_stop$$($index$jscomp$471$$))}),$handle_change_gradient_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($type__$1$jscomp$14$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_gradient$$($type__$1$jscomp$14$$))}),
$handle_gradient_change_stop$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1167$$)],function($prev_stop$$,$new_stop$jscomp$2$$){var $stops$jscomp$18$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78192_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__78192_SHARP_$$,$prev_stop$$)?$new_stop$jscomp$2$$:$p1__78192_SHARP_$$},$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($stops$jscomp$18$$))}),$handle_gradient_add_stop_auto$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_add_auto$$())}),$handle_gradient_add_stop_preview$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($offset$jscomp$204$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_add_stop$$($offset$jscomp$204$$))}),
$handle_gradient_remove_stop$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$472$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$($index$jscomp$472$$))}),$handle_stop_edit_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,!1)}),$handle_stop_edit_finish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,
!0);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$sort_colorpicker_stops$$())})}),$handle_rotate_stops$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1167$$)],function(){var $end_p$jscomp$2_gradient$jscomp$27$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$),$mtx$jscomp$8$$=
$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$(90,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(.5,.5)),$start_p$jscomp$9$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1729$start_x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$27$$),$APP.$cljs$cst$1730$start_y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$27$$)),$mtx$jscomp$8$$);
$end_p$jscomp$2_gradient$jscomp$27$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1731$end_x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$27$$),$APP.$cljs$cst$1732$end_y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$27$$)),$mtx$jscomp$8$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_gradient$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1729$start_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$9$$),$APP.$cljs$cst$1730$start_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$9$$),$APP.$cljs$cst$1731$end_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$27$$),$APP.$cljs$cst$1732$end_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$27$$)],null)))}),$handle_reverse_stops$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$))],
function(){var $stops$jscomp$19$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($it$jscomp$275$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$275$$,$APP.$cljs$cst$195$offset$$,function($p1__78193_SHARP_$$){return 1+-1*$p1__78193_SHARP_$$})},$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$))));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($stops$jscomp$19$$))}),$handle_reorder_stops$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$))],function($from_index$jscomp$11_new_stops$jscomp$1$$,$to_index$jscomp$18$$){var $stops$jscomp$20_stops__$1$jscomp$7$$=$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$);
$from_index$jscomp$11_new_stops$jscomp$1$$=$APP.$app$common$data$insert_at_index$$($stops$jscomp$20_stops__$1$jscomp$7$$,$to_index$jscomp$18$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$20_stops__$1$jscomp$7$$,$from_index$jscomp$11_new_stops$jscomp$1$$)],null));$stops$jscomp$20_stops__$1$jscomp$7$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__78195_SHARP_$$,
$p2__78194_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p2__78194_SHARP_$$,$APP.$cljs$cst$195$offset$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($p1__78195_SHARP_$$))},$stops$jscomp$20_stops__$1$jscomp$7$$,$from_index$jscomp$11_new_stops$jscomp$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($stops$jscomp$20_stops__$1$jscomp$7$$))}),$render_wasm_QMARK_$$=$app$main$features$use_feature$$("render-wasm/v1"),
$tabs$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4564$aria_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.rgba"),$APP.$cljs$cst$1721$icon$$,"rgba",$APP.$cljs$cst$266$id$$,"ramp"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4564$aria_label$$,
"Harmony",$APP.$cljs$cst$1721$icon$$,"rgba-complementary",$APP.$cljs$cst$266$id$$,"harmony"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4564$aria_label$$,"HSBA",$APP.$cljs$cst$1721$icon$$,"hsva",$APP.$cljs$cst$266$id$$,"hsva"],null)],null)}),$show_tokens_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5590$color_selection$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1403$fill$$,
null],null),null),$color_origin$jscomp$2$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$initialize_colorpicker$$($on_change$jscomp$43$$,$active_fill_tab$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$stop_picker$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$finalize_colorpicker$$()]))}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$470$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($should_update_QMARK_$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker$$($data$jscomp$470$$)):null});$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$($node_ref$jscomp$4$$,$current_color$jscomp$3$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($picking_color_QMARK_$$),
$APP.$rumext$v2$adapt$$($picked_color$$),$APP.$rumext$v2$adapt$$($picked_color_select$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($picking_color_QMARK_$$)?$APP.$cljs$core$truth_$$($picked_color$$)?$picked_color_select$$:$picked_color$$:$picking_color_QMARK_$$)){var $G__78213_r$jscomp$139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,0,null),$g$jscomp$161$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,1,null),$b$jscomp$360$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,2,null),$alpha$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,3,null),$hex$jscomp$16$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__78213_r$jscomp$139$$,$g$jscomp$161$$,$b$jscomp$360$$],null)),$v$jscomp$661_vec__78210$$=$app$common$types$color$hex__GT_hsv$$($hex$jscomp$16$$),$h$jscomp$182$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$661_vec__78210$$,
0,null),$s$jscomp$583$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$661_vec__78210$$,1,null);$v$jscomp$661_vec__78210$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$661_vec__78210$$,2,null);$G__78213_r$jscomp$139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$2687$hex$$,$hex$jscomp$16$$,$APP.$cljs$cst$1743$r$$,$G__78213_r$jscomp$139$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$161$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$360$$,$APP.$cljs$cst$1899$h$$,
$h$jscomp$182$$,$APP.$cljs$cst$4168$s$$,$s$jscomp$583$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$661_vec__78210$$,$APP.$cljs$cst$746$alpha$$,$alpha$jscomp$19$$/255],null);return $handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78213_r$jscomp$139$$):$handle_change_color$jscomp$1$$($G__78213_r$jscomp$139$$)}return null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{ref:$node_ref$jscomp$4$$,style:{touchAction:"none"},className:"main_ui_workspace_colorpicker__colorpicker",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__top-actions",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__top-actions-right",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$cljs$cst$5586$direct_color$$)&&($APP.$cljs$core$not$$($disable_gradient$jscomp$2$$)||$APP.$cljs$core$not$$($disable_image$jscomp$2$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$color_type$jscomp$2_selected_mode$$,options:$options$jscomp$609$$,"on-change":$handle_change_mode$$})}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$60_props_78197$$,$cljs$cst$5579$sidebar$$)&&$show_tokens_QMARK_$$&&$token_color$jscomp$1$$?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,
{selected:$color_style$jscomp$1$$,"on-change":$tab$jscomp$7_toggle_token_color$$,name:"color-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"swatches",value:$cljs$cst$5586$direct_color$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.color"),id:"opt-color"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"tokens",value:$APP.$cljs$cst$1213$token_color$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.colorpicker.color-tokens"),
id:"opt-token-color"})]}):null]}),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,$APP.$cljs$cst$1612$image$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$cljs$cst$5586$direct_color$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_click_picker$$,className:"main_ui_workspace_colorpicker__picker-btn "+($APP.$cljs$core$truth_$$($picking_color_QMARK_$$)?"main_ui_workspace_colorpicker__selected":""),children:$APP.$app$main$ui$icons$picker$$}):
null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$APP.$cljs$cst$1213$token_color$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__token-color-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.colorpicker.color-tokens")}):null]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$cljs$cst$5586$direct_color$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,
$APP.$cljs$cst$1724$gradient$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$gradients$gradients_STAR_$$,{stops:$render_wasm_QMARK_$$?$APP.$cljs$core$vec$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(16,$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$))):$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$),onSelectStop:$handle_change_gradient_selected_stop$$,onStopEditStart:$handle_stop_edit_start$$,onReverseStops:$handle_reverse_stops$$,
onAddStopPreview:$handle_gradient_add_stop_preview$$,onChangeStop:$handle_gradient_change_stop$$,onStopEditFinish:$handle_stop_edit_finish$$,editingStop:$APP.$cljs$cst$4162$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$),onChangeType:$handle_change_gradient_type$$,onReorderStops:$handle_reorder_stops$$,type:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1167$$),onRemoveStop:$handle_gradient_remove_stop$$,onAddStopAuto:$handle_gradient_add_stop_auto$$,
onRotateStops:$handle_rotate_stops$$}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,$APP.$cljs$cst$1612$image$$)?function(){var $uri$jscomp$112$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$)),$keep_aspect_ratio_QMARK_$jscomp$1$$=$APP.$cljs$cst$1727$keep_aspect_ratio$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$));
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__select-image",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__content",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$))?(0,$APP.$rumext$v2$jsx$$)("img",{src:$uri$jscomp$112$$}):null}),$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$)!=null?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_colorpicker__checkbox-option",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"keep-aspect-ratio",className:$APP.$cljs$core$truth_$$($keep_aspect_ratio_QMARK_$jscomp$1$$)?"checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$truth_$$($keep_aspect_ratio_QMARK_$jscomp$1$$)?"checked":"",children:$APP.$cljs$core$truth_$$($keep_aspect_ratio_QMARK_$jscomp$1$$)?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.keep-aspect-ratio"),
(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"keep-aspect-ratio",checked:$keep_aspect_ratio_QMARK_$jscomp$1$$,onChange:$handle_change_keep_aspect_ratio$$})]})}):null,(0,$APP.$rumext$v2$jsxs$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.choose-image"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.choose-image"),onClick:$on_fill_image_click$$,className:"main_ui_workspace_colorpicker__choose-image",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.choose-image"),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{"input-id":"fill-image-upload",accept:"image/jpeg,image/png",multi:!1,ref:$fill_image_ref$$,"on-selected":$on_fill_image_selected$$})]})]})}():(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__colorpicker-tabs",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$3$$,
selected:$active_color_tab$$,onChange:$on_change_tab$$,children:$APP.$cljs$core$truth_$$($picking_color_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__picker-detail-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__center-circle"}),(0,$APP.$rumext$v2$jsx$$)("canvas",{id:"picker-detail",width:256,height:140,className:"main_ui_workspace_colorpicker__picker-detail"})]}):function(){switch($active_color_tab$$){case "ramp":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$,
{color:$current_color$jscomp$3$$,disableOpacity:$disable_opacity$jscomp$6$$,onChange:$handle_change_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$5$$,onFinishDrag:$on_finish_drag$jscomp$5$$});case "harmony":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$harmony$harmony_selector_STAR_$$,{color:$current_color$jscomp$3$$,disableOpacity:$disable_opacity$jscomp$6$$,onChange:$handle_change_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$5$$,onFinishDrag:$on_finish_drag$jscomp$5$$});
case "hsva":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$hsva$hsva_selector_STAR_$$,{color:$current_color$jscomp$3$$,disableOpacity:$disable_opacity$jscomp$6$$,mode:$hsb_mode$jscomp$1$$,onChange:$handle_change_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$5$$,onFinishDrag:$on_finish_drag$jscomp$5$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($active_color_tab$$)].join(""));}}()})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_inputs$color_inputs_STAR_$$,
{type:$type$jscomp$612$$,disableOpacity:$disable_opacity$jscomp$6$$,mode:$hsb_mode$jscomp$1$$,onModeChange:function($p1__78196_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($hsb_mode_STAR_$$,$p1__78196_SHARP_$$)},color:$current_color$jscomp$3$$,onChange:$handle_change_color$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$libraries$libraries_STAR_$$,{state:$state$jscomp$1167$$,currentColor:$current_color$jscomp$3$$,disableGradient:$disable_gradient$jscomp$2$$,disableOpacity:$disable_opacity$jscomp$6$$,
disableImage:$disable_image$jscomp$2$$,onSelectColor:$on_select_library_color$$,onAddLibraryColor:$on_add_library_color$jscomp$1$$})]})]}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$token_section_STAR_$$,{combinedTokens:$combined_tokens$jscomp$3$$,onTokenChange:$on_token_change$jscomp$3$$,appliedToken:$applied_token$jscomp$3$$,colorOrigin:$color_origin$jscomp$2$$})]}),$APP.$cljs$core$fn_QMARK_$$($on_accept$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__actions",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_color_accept$$,disabled:$disabled_color_accept_QMARK_$$,className:"main_ui_workspace_colorpicker__accept-color "+($disabled_color_accept_QMARK_$$?"main_ui_workspace_colorpicker__btn-disabled":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.save-color")})}):null]})};
$app$main$ui$workspace$colorpicker$calculate_position$$=function($left_offset_map__78222__$1_p__78221_rulers_QMARK_$$,$position$jscomp$193$$,$x$jscomp$1249$$,$y$jscomp$471$$,$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$){$left_offset_map__78222__$1_p__78221_rulers_QMARK_$$=$APP.$cljs$core$__destructure_map$$($left_offset_map__78222__$1_p__78221_rulers_QMARK_$$);$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($left_offset_map__78222__$1_p__78221_rulers_QMARK_$$,
$APP.$cljs$cst$1522$height$$)-($APP.$cljs$core$truth_$$($gradient_QMARK_$jscomp$1_max_y$jscomp$2$$)?820:510);$left_offset_map__78222__$1_p__78221_rulers_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$);$left_offset_map__78222__$1_p__78221_rulers_QMARK_$$=$APP.$cljs$core$truth_$$($left_offset_map__78222__$1_p__78221_rulers_QMARK_$$)?40:18;var $top_offset$$=""+($y$jscomp$471$$-70)+"px",$max_height_top$$=["calc(100vh - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($top_offset$$)].join("");
return $x$jscomp$1249$$==null||$y$jscomp$471$$==null?{left:"auto",right:"16rem",top:"4rem",maxHeight:"calc(100vh - 4rem)"}:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$193$$,$APP.$cljs$cst$257$left$$)?$y$jscomp$471$$>$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$?{left:""+($x$jscomp$1249$$-324)+"px",bottom:"1rem",maxHeight:"calc(100vh -1rem"}:{left:""+($x$jscomp$1249$$-324)+"px",top:$top_offset$$,maxHeight:$max_height_top$$}:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$193$$,
$APP.$cljs$cst$258$right$$)?$y$jscomp$471$$>$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$?{left:""+($x$jscomp$1249$$+80??"")+"px",bottom:"1rem",maxHeight:"calc(100vh -1rem"}:{left:""+($x$jscomp$1249$$+80??"")+"px",top:$top_offset$$,maxHeight:$max_height_top$$}:$y$jscomp$471$$>$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$?{left:""+($x$jscomp$1249$$+$left_offset_map__78222__$1_p__78221_rulers_QMARK_$$??"")+"px",bottom:"1rem",maxHeight:"calc(100vh -1rem"}:{left:""+($x$jscomp$1249$$+$left_offset_map__78222__$1_p__78221_rulers_QMARK_$$??
"")+"px",top:$top_offset$$,maxHeight:$max_height_top$$}};
$app$main$ui$workspace$colorpicker$group_sets$$=function($sets$jscomp$16$$){return $APP.$cljs$core$flatten$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($grouped_sets_p__78223$$){var $group$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grouped_sets_p__78223$$,0,null);$grouped_sets_p__78223$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grouped_sets_p__78223$$,1,null);return $APP.$cljs$core$truth_$$($group$jscomp$50$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1608$group$$,$group$jscomp$50$$,$APP.$cljs$cst$2108$sets$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$927_p__78227$$){var $map__78228__$1_set$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$927_p__78227$$);$id$jscomp$927_p__78227$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78228__$1_set$jscomp$16$$,$APP.$cljs$cst$266$id$$);$map__78228__$1_set$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78228__$1_set$jscomp$16$$,
$APP.$cljs$cst$203$set$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$id$jscomp$927_p__78227$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$last$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78228__$1_set$jscomp$16$$,/\//))],null)},$grouped_sets_p__78223$$),$APP.$cljs$cst$2100$tokens$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2100$tokens$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$grouped_sets_p__78223$$]))))],null):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$928_p__78229$$){var $map__78230__$1_tokens$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$928_p__78229$$);$id$jscomp$928_p__78229$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78230__$1_tokens$jscomp$44$$,$APP.$cljs$cst$266$id$$);var $set$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78230__$1_tokens$jscomp$44$$,
$APP.$cljs$cst$203$set$$);$map__78230__$1_tokens$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78230__$1_tokens$jscomp$44$$,$APP.$cljs$cst$2100$tokens$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$2108$sets$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$id$jscomp$928_p__78229$$,$APP.$cljs$cst$725$name$$,
$set$jscomp$17$$],null)],null),$APP.$cljs$cst$2100$tokens$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$map__78230__$1_tokens$jscomp$44$$)],null)},$grouped_sets_p__78223$$)},$APP.$cljs$core$group_by$$(function($map__78232__$1_p__78231_set$jscomp$18$$){$map__78232__$1_p__78231_set$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($map__78232__$1_p__78231_set$jscomp$18$$);$map__78232__$1_p__78231_set$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78232__$1_p__78231_set$jscomp$18$$,
$APP.$cljs$cst$203$set$$);return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($map__78232__$1_p__78231_set$jscomp$18$$,"/"))?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("/",$APP.$cljs$core$butlast$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78232__$1_p__78231_set$jscomp$18$$,/\//))):null},$sets$jscomp$16$$)))};
$app$main$ui$workspace$colorpicker$combine_groups_with_resolved$$=function($groups$jscomp$3$$,$resolved_tokens$jscomp$24$$){var $token_map$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$identity$$),$resolved_tokens$jscomp$24$$));return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($group$jscomp$51_p__78235$$){var $map__78236__$1_tokens$jscomp$45$$=
$APP.$cljs$core$__destructure_map$$($group$jscomp$51_p__78235$$);$group$jscomp$51_p__78235$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78236__$1_tokens$jscomp$45$$,$APP.$cljs$cst$1608$group$$);var $sets$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78236__$1_tokens$jscomp$45$$,$APP.$cljs$cst$2108$sets$$);$map__78236__$1_tokens$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78236__$1_tokens$jscomp$45$$,$APP.$cljs$cst$2100$tokens$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1608$group$$,$group$jscomp$51_p__78235$$,$APP.$cljs$cst$2108$sets$$,$sets$jscomp$17$$,$APP.$cljs$cst$2100$tokens$$,$APP.$cljs$core$vec$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78234_SHARP_$$){var $or__5025__auto__$jscomp$1080_or__5025__auto____$1$jscomp$117$$=$p1__78234_SHARP_$$==null;if($or__5025__auto__$jscomp$1080_or__5025__auto____$1$jscomp$117$$)return $or__5025__auto__$jscomp$1080_or__5025__auto____$1$jscomp$117$$;
$or__5025__auto__$jscomp$1080_or__5025__auto____$1$jscomp$117$$=$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($p1__78234_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1080_or__5025__auto____$1$jscomp$117$$)?$or__5025__auto__$jscomp$1080_or__5025__auto____$1$jscomp$117$$:$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($p1__78234_SHARP_$$)==null},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78233_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token_map$jscomp$1$$,
$p1__78233_SHARP_$$)},$map__78236__$1_tokens$jscomp$45$$)))],null)},$groups$jscomp$3$$)};
$app$main$ui$workspace$colorpicker$filter_non_empty_sets$$=function($sets$jscomp$18$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__78239__$1_p__78238_tokens$jscomp$46$$){$map__78239__$1_p__78238_tokens$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($map__78239__$1_p__78238_tokens$jscomp$46$$);$map__78239__$1_p__78238_tokens$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78239__$1_p__78238_tokens$jscomp$46$$,$APP.$cljs$cst$2100$tokens$$);
return $APP.$cljs$core$some$$(function($p1__78237_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78237_SHARP_$$),$APP.$cljs$cst$1298$color$$)},$map__78239__$1_p__78238_tokens$jscomp$46$$)},$sets$jscomp$18$$)};
$app$main$ui$workspace$colorpicker$add_tokens_to_sets$$=function($sets$jscomp$19$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($s$jscomp$584$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$203$set$$,$APP.$app$common$types$tokens_lib$get_name$$($s$jscomp$584$$),$APP.$cljs$cst$266$id$$,$APP.$app$common$types$tokens_lib$get_id$$($s$jscomp$584$$),$APP.$cljs$cst$2100$tokens$$,$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens_$$($s$jscomp$584$$))],
null)},$sets$jscomp$19$$)};$app$main$ui$workspace$colorpicker$filter_active_sets$$=function($sets$jscomp$20$$,$active_set_names$jscomp$5$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78240_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($active_set_names$jscomp$5$$,$APP.$cljs$cst$203$set$$.$cljs$core$IFn$_invoke$arity$1$($p1__78240_SHARP_$$))},$sets$jscomp$20$$)};
$app$main$ui$workspace$colorpicker$colorpicker_modal$$=function($props_78241_vport$jscomp$8$$){var $style$jscomp$71_x$jscomp$1250$$=$props_78241_vport$jscomp$8$$.x,$tab$jscomp$8$$=$props_78241_vport$jscomp$8$$.tab,$on_change$jscomp$44$$=$props_78241_vport$jscomp$8$$["on-change"],$data$jscomp$471$$=$props_78241_vport$jscomp$8$$.data,$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$=$props_78241_vport$jscomp$8$$.y,$disable_gradient$jscomp$3$$=$props_78241_vport$jscomp$8$$["disable-gradient"],
$disable_opacity$jscomp$7$$=$props_78241_vport$jscomp$8$$["disable-opacity"],$on_token_change$jscomp$4$$=$props_78241_vport$jscomp$8$$["on-token-change"],$disable_image$jscomp$3$$=$props_78241_vport$jscomp$8$$["disable-image"],$on_close$jscomp$16$$=$props_78241_vport$jscomp$8$$["on-close"],$applied_token$jscomp$4$$=$props_78241_vport$jscomp$8$$["applied-token"],$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$=$props_78241_vport$jscomp$8$$["active-tokens"],$on_accept$jscomp$10$$=$props_78241_vport$jscomp$8$$["on-accept"],
$color_origin$jscomp$3$$=$props_78241_vport$jscomp$8$$["color-origin"],$origin$jscomp$61$$=$props_78241_vport$jscomp$8$$.origin,$position$jscomp$194_position__$1$jscomp$8$$=$props_78241_vport$jscomp$8$$.position;$props_78241_vport$jscomp$8$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$viewport$$);var $dirty_QMARK_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$last_change$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$position$jscomp$194_position__$1$jscomp$8$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$194_position__$1$jscomp$8$$,$APP.$cljs$cst$257$left$$);$style$jscomp$71_x$jscomp$1250$$=$app$main$ui$workspace$colorpicker$calculate_position$$($props_78241_vport$jscomp$8$$,$position$jscomp$194_position__$1$jscomp$8$$,$style$jscomp$71_x$jscomp$1250$$,$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$,$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$471$$)!=null);
$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$=$APP.$cljs$core$object_QMARK_$$($active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$)?$APP.$rumext$v2$util$bean$$($active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$):$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$;$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$44$$)],function($new_data$jscomp$3$$){$APP.$cljs$core$reset_BANG_$$($dirty_QMARK_$$,
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$471$$,$new_data$jscomp$3$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_data$jscomp$3$$,$APP.$cljs$core$_deref$$($last_change$$))?($APP.$cljs$core$reset_BANG_$$($last_change$$,$new_data$jscomp$3$$),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$44$$)?$on_change$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$($new_data$jscomp$3$$):$on_change$jscomp$44$$($new_data$jscomp$3$$):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker$$($new_data$jscomp$3$$))):null});var $tokens_lib$jscomp$35$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$active_sets_names$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$35$$)],function(){return $tokens_lib$jscomp$35$$==null?null:$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$35$$)});
$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$=$APP.$cljs$core$delay_QMARK_$$($active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$)?$APP.$cljs$core$_deref$$($active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$):$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$;var $color_tokens$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$);
$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$35$$),$APP.$rumext$v2$adapt$$($active_sets_names$$),$APP.$rumext$v2$adapt$$($color_tokens$$)],function(){var $G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$=$tokens_lib$jscomp$35$$==null?null:$APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$35$$);$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$=
$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$==null?null:$app$main$ui$workspace$colorpicker$add_tokens_to_sets$$($G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$);$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$=$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$==null?null:$app$main$ui$workspace$colorpicker$filter_active_sets$$($G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$,$active_sets_names$$);$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$=
$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$==null?null:$app$main$ui$workspace$colorpicker$filter_non_empty_sets$$($G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$);$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$=$G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$==null?null:$app$main$ui$workspace$colorpicker$group_sets$$($G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$);return $G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$==
null?null:$app$main$ui$workspace$colorpicker$combine_groups_with_resolved$$($G__78243__$1_G__78243__$2_G__78243__$3_G__78243__$4_G__78243__$5$$,$color_tokens$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$5591$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_colorpicker$$,
$app$main$ui$workspace$colorpicker$shortcuts$shortcuts$$)));return function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$5591$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_colorpicker$$));var $G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$=$APP.$cljs$core$_deref$$($dirty_QMARK_$$);$APP.$cljs$core$truth_$$($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$)&&
($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$=$APP.$cljs$core$_deref$$($last_change$$),$G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$=$APP.$cljs$core$truth_$$($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$)?$on_close$jscomp$16$$:$G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$);
return $APP.$cljs$core$truth_$$($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$)?($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$=$APP.$cljs$core$_deref$$($last_change$$),$on_close$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$on_close$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$):
$on_close$jscomp$16$$($G__78244_JSCompiler_inline_result$jscomp$1750_and__5023__auto__$jscomp$inline_8763_and__5023__auto____$1$jscomp$inline_8764$$)):null}});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"colorpicker",style:$style$jscomp$71_x$jscomp$1250$$,className:"main_ui_workspace_colorpicker__colorpicker-tooltip",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$colorpicker_STAR_$$,{tab:$tab$jscomp$8$$,origin:$origin$jscomp$61$$,onChange:$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$,
disableOpacity:$disable_opacity$jscomp$7$$,colorOrigin:$color_origin$jscomp$3$$,onTokenChange:$on_token_change$jscomp$4$$,appliedToken:$applied_token$jscomp$4$$,disableGradient:$disable_gradient$jscomp$3$$,disableImage:$disable_image$jscomp$3$$,onAccept:$on_accept$jscomp$10$$,data:$data$jscomp$471$$,combinedTokens:$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$472$$})})};
$app$main$ui$workspace$sidebar$assets$common$apply_filters$$=function($G__77413__$1_G__77413__$2_coll$jscomp$1101$$,$map__77411__$1_p__77410$$){$map__77411__$1_p__77410$$=$APP.$cljs$core$__destructure_map$$($map__77411__$1_p__77410$$);var $ordering$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77411__$1_p__77410$$,$cljs$cst$5592$ordering$$),$term$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77411__$1_p__77410$$,$APP.$cljs$cst$2513$term$$),$reverse_QMARK_$jscomp$9$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2698$desc$$,$ordering$$);$G__77413__$1_G__77413__$2_coll$jscomp$1101$$=$APP.$cuerdas$core$empty_QMARK_$$($term$jscomp$7$$)?$G__77413__$1_G__77413__$2_coll$jscomp$1101$$:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$122$$){var $or__5025__auto__$jscomp$1081_or__5025__auto____$1$jscomp$118$$=$app$util$strings$matches_search$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$122$$,
"!$!"),$term$jscomp$7$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1081_or__5025__auto____$1$jscomp$118$$))return $or__5025__auto__$jscomp$1081_or__5025__auto____$1$jscomp$118$$;$or__5025__auto__$jscomp$1081_or__5025__auto____$1$jscomp$118$$=$app$util$strings$matches_search$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$122$$,"!$!"),$term$jscomp$7$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1081_or__5025__auto____$1$jscomp$118$$)?$or__5025__auto__$jscomp$1081_or__5025__auto____$1$jscomp$118$$:
$app$util$strings$matches_search$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$122$$,"!$!"),$term$jscomp$7$$)},$G__77413__$1_G__77413__$2_coll$jscomp$1101$$);$G__77413__$1_G__77413__$2_coll$jscomp$1101$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$(function($p__77414_path$jscomp$258_path__$1$jscomp$8$$){var $map__77415__$1_name$jscomp$439$$=$APP.$cljs$core$__destructure_map$$($p__77414_path$jscomp$258_path__$1$jscomp$8$$);$p__77414_path$jscomp$258_path__$1$jscomp$8$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77415__$1_name$jscomp$439$$,$APP.$cljs$cst$296$path$$);$map__77415__$1_name$jscomp$439$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77415__$1_name$jscomp$439$$,$APP.$cljs$cst$725$name$$);$p__77414_path$jscomp$258_path__$1$jscomp$8$$=$APP.$cuerdas$core$empty_QMARK_$$($p__77414_path$jscomp$258_path__$1$jscomp$8$$)?$reverse_QMARK_$jscomp$9$$?"z":"a":$p__77414_path$jscomp$258_path__$1$jscomp$8$$;return $APP.$cuerdas$core$lower$$($APP.$app$common$path_names$merge_path_item$$($p__77414_path$jscomp$258_path__$1$jscomp$8$$,
$map__77415__$1_name$jscomp$439$$))},$reverse_QMARK_$jscomp$9$$?$APP.$cljs$core$_GT_$$:$APP.$cljs$core$_LT_$$,$G__77413__$1_G__77413__$2_coll$jscomp$1101$$);return $APP.$cljs$core$vec$$($G__77413__$1_G__77413__$2_coll$jscomp$1101$$)};
$app$main$ui$workspace$sidebar$assets$common$add_group$$=function($asset$jscomp$4$$,$group_name$$){return $APP.$app$common$path_names$merge_path_item$$($APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$4$$),$group_name$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$4$$))};
$app$main$ui$workspace$sidebar$assets$common$rename_group$$=function($asset$jscomp$5$$,$path$jscomp$259$$,$last_path$$){return $APP.$app$common$path_names$merge_path_item$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$path_names$join_path$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($APP.$cljs$core$butlast$$($APP.$app$common$path_names$split_path$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$5$$),0,
$APP.$cljs$core$count$$($path$jscomp$259$$))))),$last_path$$))),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$5$$),$APP.$cljs$core$count$$($path$jscomp$259$$)))].join(""),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$5$$))};
$app$main$ui$workspace$sidebar$assets$common$ungroup$$=function($asset$jscomp$6$$,$path$jscomp$260$$){return $APP.$app$common$path_names$merge_path_item$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$path_names$join_path$$($APP.$cljs$core$butlast$$($APP.$app$common$path_names$split_path$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$6$$),0,$APP.$cljs$core$count$$($path$jscomp$260$$)))))),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$6$$),$APP.$cljs$core$count$$($path$jscomp$260$$)))].join(""),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$6$$))};
$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$=function($state$jscomp$1168$$,$left$jscomp$32_pos$jscomp$134$$){var $top$jscomp$14$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$32_pos$jscomp$134$$);$left$jscomp$32_pos$jscomp$134$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$32_pos$jscomp$134$$)+10;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1168$$,$APP.$cljs$cst$4533$open_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1562$top$$,
$top$jscomp$14$$,$APP.$cljs$cst$257$left$$,$left$jscomp$32_pos$jscomp$134$$]))};$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$=function($state$jscomp$1169$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1169$$,$APP.$cljs$cst$4533$open_QMARK_$$,!1)};
$app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$=function($props_77426_state$jscomp$1170$$){var $options$jscomp$610$$=$props_77426_state$jscomp$1170$$.options,$on_close$jscomp$17$$=$props_77426_state$jscomp$1170$$.onClose;$props_77426_state$jscomp$1170$$=$props_77426_state$jscomp$1170$$.state;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,{show:$APP.$cljs$cst$4533$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($props_77426_state$jscomp$1170$$),
fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($props_77426_state$jscomp$1170$$),0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($props_77426_state$jscomp$1170$$),0),onClose:$on_close$jscomp$17$$,top:$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($props_77426_state$jscomp$1170$$),left:$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($props_77426_state$jscomp$1170$$),
options:$options$jscomp$610$$})};$app$main$ui$workspace$sidebar$assets$common$section_icon$$=function($section$jscomp$25$$){switch($section$jscomp$25$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$25$$.$fqn$:null){case "colors":return"drop";case "components":return"component";case "typographies":return"text-palette";default:return"add"}};
$app$main$ui$workspace$sidebar$assets$common$should_display_asset_count_QMARK_$$=function($section$jscomp$26$$,$assets_count$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$26$$,$APP.$cljs$cst$2100$tokens$$)||0<$assets_count$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$26$$,$APP.$cljs$cst$2100$tokens$$)};
$app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$=function($buttons_props_77445$$){var $is_open$jscomp$3$$=$buttons_props_77445$$.isOpen,$assets_count$jscomp$1$$=$buttons_props_77445$$.assetsCount,$file_id$jscomp$370$$=$buttons_props_77445$$.fileId,$section$jscomp$27$$=$buttons_props_77445$$.section,$icon$jscomp$19_title__$1$jscomp$1$$=$buttons_props_77445$$.icon,$title$jscomp$32$$=$buttons_props_77445$$.title,$on_click$jscomp$37$$=$buttons_props_77445$$.onClick,$children__$1$jscomp$36_content$jscomp$245$$=
$app$util$array$without_nils$$($app$util$array$normalize_to_array$$($buttons_props_77445$$.children));$buttons_props_77445$$=$app$util$array$filter$$(function($p1__77443_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5593$title_button$$,$p1__77443_SHARP_$$.props.role)},$children__$1$jscomp$36_content$jscomp$245$$);$children__$1$jscomp$36_content$jscomp$245$$=$app$util$array$filter$$(function($p1__77444_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$,
$p1__77444_SHARP_$$.props.role)},$children__$1$jscomp$36_content$jscomp$245$$);var $on_collapsed$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$370$$),$APP.$rumext$v2$adapt$$($section$jscomp$27$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$3$$),$APP.$rumext$v2$adapt$$($assets_count$jscomp$1$$)],function(){return 0<$assets_count$jscomp$1$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$370$$,
$section$jscomp$27$$,$APP.$cljs$core$not$$($is_open$jscomp$3$$))):null});$icon$jscomp$19_title__$1$jscomp$1$$=(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_assets_common__title-name "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$27$$,$APP.$cljs$cst$2100$tokens$$)?"main_ui_workspace_sidebar_assets_common__title-tokens":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$27$$,$APP.$cljs$cst$2100$tokens$$)&&0<$assets_count$jscomp$1$$?
"main_ui_workspace_sidebar_assets_common__title-tokens-active":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_common__section-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($icon$jscomp$19_title__$1$jscomp$1$$)?$icon$jscomp$19_title__$1$jscomp$1$$:$app$main$ui$workspace$sidebar$assets$common$section_icon$$($section$jscomp$27$$),size:"s"})}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_assets_common__section-name",children:$title$jscomp$32$$}),$app$main$ui$workspace$sidebar$assets$common$should_display_asset_count_QMARK_$$($section$jscomp$27$$,$assets_count$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_common__num-assets",children:$assets_count$jscomp$1$$}):null]});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_click$jscomp$37$$,className:"main_ui_workspace_sidebar_assets_common__asset-section "+
($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$716$$=0<$assets_count$jscomp$1$$;return $and__5023__auto__$jscomp$716$$?$is_open$jscomp$3$$:$and__5023__auto__$jscomp$716$$}())?"main_ui_workspace_sidebar_assets_common__opened":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:0<$assets_count$jscomp$1$$,collapsed:$APP.$cljs$core$not$$($is_open$jscomp$3$$),onCollapsed:$on_collapsed$jscomp$1$$,addIconGap:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$assets_count$jscomp$1$$),title:$icon$jscomp$19_title__$1$jscomp$1$$,children:$buttons_props_77445$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$717$$=0<$assets_count$jscomp$1$$;return $and__5023__auto__$jscomp$717$$?$is_open$jscomp$3$$:$and__5023__auto__$jscomp$717$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:$APP.$cljs$core$truth_$$($is_open$jscomp$3$$)?"main_ui_workspace_sidebar_assets_common__title-spacing":"",children:$children__$1$jscomp$36_content$jscomp$245$$}):
null]})};$app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$=function($props_77446$$){return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$props_77446$$.children})};
$app$main$ui$workspace$sidebar$assets$common$create_assets_group$$=function($rename$jscomp$1$$,$components_to_group$$,$group_name$jscomp$1$$){var $undo_id$jscomp$90$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$90$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($G__77449_p1__77447_SHARP_$$){var $G__77448$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__77449_p1__77447_SHARP_$$);
$G__77449_p1__77447_SHARP_$$=$app$main$ui$workspace$sidebar$assets$common$add_group$$($G__77449_p1__77447_SHARP_$$,$group_name$jscomp$1$$);return $rename$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$rename$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__77448$$,$G__77449_p1__77447_SHARP_$$):$rename$jscomp$1$$($G__77448$$,$G__77449_p1__77447_SHARP_$$)},$components_to_group$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$90$$))};
$app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$=function($map__77452__$1_p__77451$$){$map__77452__$1_p__77451$$=$APP.$cljs$core$__destructure_map$$($map__77452__$1_p__77451$$);var $assets$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77452__$1_p__77451$$,$APP.$cljs$cst$3718$assets$$),$on_clear_selection$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77452__$1_p__77451$$,$cljs$cst$5594$on_clear_selection$$),$delete_events$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77452__$1_p__77451$$,
$cljs$cst$5595$delete_events$$),$path_filter$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__77452__$1_p__77451$$,$cljs$cst$5596$path_filter$$,$APP.$cuerdas$core$starts_with_QMARK_$$);return function($path$jscomp$261$$){function $do_delete$$(){$on_clear_selection$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$91$$));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$delete_events$$.$cljs$core$IFn$_invoke$arity$1$?$delete_events$$.$cljs$core$IFn$_invoke$arity$1$($matching$$):$delete_events$$($matching$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$91$$))}var $matching$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__77453_p1__77450_SHARP_$$){$G__77453_p1__77450_SHARP_$$=
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($G__77453_p1__77450_SHARP_$$);return $path_filter$$.$cljs$core$IFn$_invoke$arity$2$?$path_filter$$.$cljs$core$IFn$_invoke$arity$2$($G__77453_p1__77450_SHARP_$$,$path$jscomp$261$$):$path_filter$$($G__77453_p1__77450_SHARP_$$,$path$jscomp$261$$)},$assets$jscomp$1$$),$undo_id$jscomp$91$$=Symbol();return $APP.$cljs$core$seq$$($matching$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-asset-group.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-asset-group.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($matching$$))])),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
$APP.$cljs$cst$2479$on_accept$$,$do_delete$$],null))):null}};
$app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$=function($components_to_group$jscomp$1_event$jscomp$320$$,$asset$jscomp$7$$,$dragging_STAR_$$,$selected$jscomp$141$$,$selected_full$$,$selected_paths$$,$create_typed_assets_group_rename$jscomp$2$$){$create_typed_assets_group_rename$jscomp$2$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$assets$common$create_assets_group$$,$create_typed_assets_group_rename$jscomp$2$$);return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($components_to_group$jscomp$1_event$jscomp$320$$))&&
($APP.$cljs$core$reset_BANG_$$($dragging_STAR_$$,!1),!$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$141$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$7$$))&&$APP.$cljs$core$every_QMARK_$$(function($p1__77455_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77455_SHARP_$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$7$$))},$selected_paths$$))?($components_to_group$jscomp$1_event$jscomp$320$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($selected_full$$,
$asset$jscomp$7$$),$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($create_typed_assets_group_rename$jscomp$2$$,$components_to_group$jscomp$1_event$jscomp$320$$)],null))):null};
$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$=function($event$jscomp$321$$,$asset$jscomp$8$$,$dragging_STAR_$jscomp$1$$,$selected$jscomp$142$$,$selected_paths$jscomp$1$$){return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$321$$))&&$APP.$cljs$core$every_QMARK_$$(function($p1__77456_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77456_SHARP_$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$8$$))},
$selected_paths$jscomp$1$$)&&!$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$142$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$8$$))?$APP.$cljs$core$reset_BANG_$$($dragging_STAR_$jscomp$1$$,!0):null};
$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$=function($event$jscomp$322$$,$dragging_STAR_$jscomp$2$$){return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$322$$))?$APP.$cljs$core$reset_BANG_$$($dragging_STAR_$jscomp$2$$,!1):null};
$app$main$ui$workspace$sidebar$assets$common$create_counter_element$$=function($asset_count$$){var $counter_el$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("div");$APP.$app$util$dom$set_property_BANG_$$($counter_el$$,"class","main_ui_workspace_sidebar_assets_common__drag-counter");$APP.$app$util$dom$set_text_BANG_$$($counter_el$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.assets.sidebar.components",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($asset_count$$)])));
return $counter_el$$};
$app$main$ui$workspace$sidebar$assets$common$set_drag_image$$=function($event$jscomp$323$$,$item_ref$jscomp$1$$,$num_selected$$){var $offset$jscomp$205$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$323$$.nativeEvent),$item_el$$=$APP.$rumext$v2$ref_val$$($item_ref$jscomp$1$$),$counter_el$jscomp$1$$=$app$main$ui$workspace$sidebar$assets$common$create_counter_element$$($num_selected$$);$APP.$app$util$dom$append_child_BANG_$$($item_el$$,$counter_el$jscomp$1$$);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($event$jscomp$323$$,$item_el$$,
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$205$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$205$$));return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$child_QMARK_$$($counter_el$jscomp$1$$,$item_el$$))){$item_el$$!=null&&$item_el$$.removeChild($counter_el$jscomp$1$$);var $JSCompiler_temp$jscomp$660$$=$item_el$$}else $JSCompiler_temp$jscomp$660$$=null;return $JSCompiler_temp$jscomp$660$$})};
$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$=function($event$jscomp$324$$,$file_id$jscomp$371$$,$asset$jscomp$9$$,$selected$jscomp$143$$,$item_ref$jscomp$2$$,$asset_type$jscomp$12$$,$on_drag_start$jscomp$1$$){var $id_asset$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$9$$),$num_selected$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$143$$,$id_asset$$)?$APP.$cljs$core$count$$($selected$jscomp$143$$):1;$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$143$$,
$id_asset$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$($file_id$jscomp$371$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$toggle_selected_assets$$($file_id$jscomp$371$$,$id_asset$$,$asset_type$jscomp$12$$)]));$on_drag_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($asset$jscomp$9$$,
$event$jscomp$324$$):$on_drag_start$jscomp$1$$($asset$jscomp$9$$,$event$jscomp$324$$);return $num_selected$jscomp$1$$>1?$app$main$ui$workspace$sidebar$assets$common$set_drag_image$$($event$jscomp$324$$,$item_ref$jscomp$2$$,$num_selected$jscomp$1$$):null};
$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$=function($event$jscomp$325$$,$dragging_STAR_$jscomp$3$$,$prefix$jscomp$66$$,$selected_paths$jscomp$2$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$325$$);return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$325$$))&&!$APP.$cljs$core$every_QMARK_$$(function($p1__77457_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77457_SHARP_$$,$prefix$jscomp$66$$)},$selected_paths$jscomp$2$$)?
$APP.$cljs$core$reset_BANG_$$($dragging_STAR_$jscomp$3$$,!0):null};
$app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$=function($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$,$G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$,$prefix$jscomp$67$$,$G__77491_count__77461_selected_paths$jscomp$3$$,$G__77489_i__77462_selected_full$jscomp$1$$,$rename$jscomp$3$$){$APP.$app$util$dom$stop_propagation$$($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$);if($APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$))){$APP.$cljs$core$reset_BANG_$$($G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$,
!1);if($APP.$cljs$core$every_QMARK_$$(function($p1__77458_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77458_SHARP_$$,$prefix$jscomp$67$$)},$G__77491_count__77461_selected_paths$jscomp$3$$))return null;$c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$=$APP.$cljs$core$seq$$($G__77489_i__77462_selected_full$jscomp$1$$);$G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$=null;for($G__77489_i__77462_selected_full$jscomp$1$$=
$G__77491_count__77461_selected_paths$jscomp$3$$=0;;)if($G__77489_i__77462_selected_full$jscomp$1$$<$G__77491_count__77461_selected_paths$jscomp$3$$){var $target_asset$$=$G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77489_i__77462_selected_full$jscomp$1$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $G__77467$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$),$G__77468$$=$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$67$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$));return $rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($G__77467$$,$G__77468$$):$rename$jscomp$3$$($G__77467$$,$G__77468$$)}());$G__77489_i__77462_selected_full$jscomp$1$$+=1}else if($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$))$G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$=
$c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$)?($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$=$APP.$cljs$core$_chunked_first$$($G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$),$G__77489_i__77462_selected_full$jscomp$1$$=$APP.$cljs$core$_chunked_rest$$($G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$),
$G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$=$c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$,$G__77491_count__77461_selected_paths$jscomp$3$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$),$c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$=$G__77489_i__77462_selected_full$jscomp$1$$):($target_asset$$=$APP.$cljs$core$first$$($G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $G__77469$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$),$G__77470$$=$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$67$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$));return $rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($G__77469$$,$G__77470$$):$rename$jscomp$3$$($G__77469$$,$G__77470$$)}()),
$c__5548__auto__$jscomp$41_event$jscomp$326_seq__77459_temp__5825__auto__$jscomp$355$$=$APP.$cljs$core$next$$($G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$),$G__77490_chunk__77460_dragging_STAR_$jscomp$4_seq__77459__$1$$=null,$G__77491_count__77461_selected_paths$jscomp$3$$=0),$G__77489_i__77462_selected_full$jscomp$1$$=0;else return null}else return null};
$app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$=function($on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$){var $file_id$jscomp$372$$=$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.fileId,$root_shape$jscomp$8$$=$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.rootShape,$component$jscomp$121$$=$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.component,
$class$$jscomp$62$$=$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.className,$container$jscomp$82$$=$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.container,$is_hidden$jscomp$2$$=$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.isHidden,$page_id$jscomp$417$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$121$$),$root_id$jscomp$9$$=
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$121$$),$retry$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$wasm_QMARK_$jscomp$1$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1"),$current_page_id$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$current_page_id$$),$thumbnail_requested_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$object_id$jscomp$30$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$372$$),
$APP.$rumext$v2$adapt$$($page_id$jscomp$417$$),$APP.$rumext$v2$adapt$$($root_id$jscomp$9$$)],function(){return $APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$372$$,$page_id$jscomp$417$$,$root_id$jscomp$9$$,"component")});$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($object_id$jscomp$30$$)],function(){return $APP.$app$main$refs$workspace_thumbnail_by_id$$($object_id$jscomp$30$$)});
var $thumbnail_uri$jscomp$2$$=$APP.$rumext$v2$deref$$($on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$);$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($object_id$jscomp$30$$)],function(){return $app$main$refs$workspace_thumbnail_rendered_at$$($object_id$jscomp$30$$)});$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=
$APP.$rumext$v2$deref$$($on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$);var $modified_at$jscomp$14$$=function(){var $G__77472$$=$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$121$$);return $G__77472$$==null?null:$G__77472$$.getTime()}(),$stale_QMARK_$$=$thumbnail_uri$jscomp$2$$!=null&&($on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$==null||$modified_at$jscomp$14$$!=null&&
$modified_at$jscomp$14$$>$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$);$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($retry$$))],function(){return $APP.$cljs$core$_deref$$($retry$$)<3?$retry$$+1:null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_hidden$jscomp$2$$),
$APP.$rumext$v2$adapt$$($thumbnail_uri$jscomp$2$$),$APP.$rumext$v2$adapt$$($stale_QMARK_$$),$APP.$rumext$v2$adapt$$($wasm_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($current_page_id$jscomp$2$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$372$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$417$$)],function(){return $thumbnail_uri$jscomp$2$$==null||$stale_QMARK_$$?$wasm_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($is_hidden$jscomp$2$$)&&$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($thumbnail_requested_QMARK_$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$417$$,$current_page_id$jscomp$2$$)?($APP.$rumext$v2$set_ref_val_BANG_$$($thumbnail_requested_QMARK_$$,!0),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$thumbnails_wasm$render_thumbnail$$($file_id$jscomp$372$$,$page_id$jscomp$417$$,$root_id$jscomp$9$$))):null:$APP.$rumext$v2$set_ref_val_BANG_$$($thumbnail_requested_QMARK_$$,!1)});return $thumbnail_uri$jscomp$2$$==null||$stale_QMARK_$$||
!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1237$component_thumbnails$$)&&!$wasm_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg$$,{"root-shape":$root_shape$jscomp$8$$,"class":$class$$jscomp$62$$,objects:$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$82$$),"show-grids?":!0,"is-hidden":$is_hidden$jscomp$2$$}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg_thumbnail$$,{"thumbnail-uri":$thumbnail_uri$jscomp$2$$,
"class":$class$$jscomp$62$$,"on-error":$on_error$jscomp$71_props_77471_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$,"root-shape":$root_shape$jscomp$8$$,objects:$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$82$$),"show-grids?":!0})};
$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$$=function($var_args$jscomp$1447$$){for(var $args__5755__auto__$jscomp$254$$=[],$len__5749__auto___77497$$=arguments.length,$i__5750__auto___77498$$=0;;)if($i__5750__auto___77498$$<$len__5749__auto___77497$$)$args__5755__auto__$jscomp$254$$.push(arguments[$i__5750__auto___77498$$]),$i__5750__auto___77498$$+=1;else break;return $app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
1<$args__5755__auto__$jscomp$254$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$254$$.slice(1),0,null):null)};
$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$,$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$){function $do_restore_component$$(){var $comps_to_restore$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($id_file_map$$,$component_id__$1$jscomp$1_p__77482$$){var $component_file$jscomp$7_map__77483__$1$$=$APP.$cljs$core$__destructure_map$$($component_id__$1$jscomp$1_p__77482$$);
$component_id__$1$jscomp$1_p__77482$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_file$jscomp$7_map__77483__$1$$,$APP.$cljs$cst$1627$component_id$$);$component_file$jscomp$7_map__77483__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_file$jscomp$7_map__77483__$1$$,$APP.$cljs$cst$1643$component_file$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($id_file_map$$,$component_id__$1$jscomp$1_p__77482$$,$component_file$jscomp$7_map__77483__$1$$)},
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$restorable_copies$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$restore_components$$($comps_to_restore$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($comps_to_restore$$))?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $do_show_component$$(null,!0)}):null}function $do_show_component$$($_$jscomp$2976_temp__5825__auto__$jscomp$inline_8773$$,
$JSCompiler_temp$jscomp$1752_update_layout_QMARK_$jscomp$5$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$hide_context_menu$$);$local_component_QMARK_$$?$JSCompiler_temp$jscomp$1752_update_layout_QMARK_$jscomp$5$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
$component_id$jscomp$91$$]))):($_$jscomp$2976_temp__5825__auto__$jscomp$inline_8773$$=$find_component$$($shape$jscomp$981$$,!0),$JSCompiler_temp$jscomp$1752_update_layout_QMARK_$jscomp$5$$=$APP.$cljs$core$truth_$$($_$jscomp$2976_temp__5825__auto__$jscomp$inline_8773$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($library_id$jscomp$52$$,$_$jscomp$2976_temp__5825__auto__$jscomp$inline_8773$$,$JSCompiler_temp$jscomp$1752_update_layout_QMARK_$jscomp$5$$)):
null);return $JSCompiler_temp$jscomp$1752_update_layout_QMARK_$jscomp$5$$}function $do_add_new_property$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-property",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:design-tab-menu-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($variant_id$jscomp$48$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3520$property_value$$,"Value 1",$APP.$cljs$cst$3518$editing_QMARK_$$,!0],null)]))]))}function $do_add_variant$$(){return $APP.$app$common$types$component$is_variant_QMARK_$$($shape$jscomp$981$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$core$truth_$$($for_design_tab_QMARK_$$)?"workspace:design-tab-menu-variant":"workspace:context-menu-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$158$$)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"transform-in-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$core$truth_$$($for_design_tab_QMARK_$$)?"workspace:design-tab-menu":"workspace:context-menu"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id$jscomp$158$$)]))}function $do_create_annotation$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$($shape_id$jscomp$158$$))}
function $do_update_component$$(){return $local_component_QMARK_$$?$do_update_component_sync$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$141$message$$,"",$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.message"),$APP.$cljs$cst$275$hint$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.hint"),$APP.$cljs$cst$2474$cancel_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.cancel"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.accept"),$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$2478$primary$$,$APP.$cljs$cst$2479$on_accept$$,$do_update_component_sync$$],null)))}function $do_update_component_sync$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_id$jscomp$158$$,
$library_id$jscomp$52$$))}function $do_reset_component$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$reset_components$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$touched_not_dangling$$)))}function $do_detach_component$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$detach_components$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$copies$jscomp$2$$)))}function $find_component$$($shape$jscomp$982$$,$include_deleted_QMARK_$jscomp$10$$){return $APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$982$$,$current_file$$,$libraries$jscomp$137$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$10$$],null)]))}$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$=
$APP.$cljs$core$__destructure_map$$($can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$);var $for_design_tab_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$,$cljs$cst$5598$for_design_tab_QMARK_$$),$multi$jscomp$5$$=$APP.$cljs$core$count$$($menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$)>1,$copies$jscomp$2$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$in_component_copy_QMARK_$$,
$menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$),$current_file_id$jscomp$12$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$);var $libraries$jscomp$137$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),$current_file$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$137$$,$current_file_id$jscomp$12$$),
$objects$jscomp$763$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($current_file$$),$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$),$APP.$cljs$cst$1631$objects$$),$restorable_copies$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($library_id$jscomp$inline_8770_p1__77474_SHARP_$$){$library_id$jscomp$inline_8770_p1__77474_SHARP_$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($library_id$jscomp$inline_8770_p1__77474_SHARP_$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($library_id$jscomp$inline_8770_p1__77474_SHARP_$$,$current_file_id$jscomp$12$$)||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$137$$,$library_id$jscomp$inline_8770_p1__77474_SHARP_$$)!=null},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77473_SHARP_$$){return $find_component$$($p1__77473_SHARP_$$,!1)==null},$copies$jscomp$2$$)),$touched_not_dangling$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77475_SHARP_$$){var $and__5023__auto__$jscomp$718$$=
$app$common$files$helpers$component_touched_QMARK_$$($objects$jscomp$763$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77475_SHARP_$$));return $and__5023__auto__$jscomp$718$$?$find_component$$($p1__77475_SHARP_$$,!1):$and__5023__auto__$jscomp$718$$},$copies$jscomp$2$$);$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$=$APP.$cljs$core$seq$$($touched_not_dangling$$);var $shape$jscomp$981$$=$APP.$cljs$core$first$$($menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$),
$shape_id$jscomp$158$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$981$$),$main_instance_QMARK_$jscomp$3$$=$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$981$$),$variant_container_QMARK_$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$981$$),$component_id$jscomp$91$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$981$$),$variant_id$jscomp$48$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$981$$),
$library_id$jscomp$52$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$981$$),$local_component_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($library_id$jscomp$52$$,$current_file_id$jscomp$12$$),$can_show_component_QMARK__component$jscomp$122$$=$find_component$$($shape$jscomp$981$$,!1),$lacks_annotation_QMARK_$$=$APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($can_show_component_QMARK__component$jscomp$122$$)==null,$can_update_main_QMARK__is_dangling_QMARK_$$=
$can_show_component_QMARK__component$jscomp$122$$==null;$can_show_component_QMARK__component$jscomp$122$$=!$multi$jscomp$5$$&&!$main_instance_QMARK_$jscomp$3$$&&!$can_update_main_QMARK__is_dangling_QMARK_$$;$can_update_main_QMARK__is_dangling_QMARK_$$=!$multi$jscomp$5$$&&!$can_update_main_QMARK__is_dangling_QMARK_$$&&!$main_instance_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$763$$,$shape$jscomp$981$$))&&$app$common$files$helpers$component_touched_QMARK_$$($objects$jscomp$763$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$981$$));var $can_detach_QMARK_$jscomp$1$$=$APP.$cljs$core$seq$$($copies$jscomp$2$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__77476_SHARP_$$){return $APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$763$$,$p1__77476_SHARP_$$))},$copies$jscomp$2$$),$same_variant_QMARK_$$=$app$common$types$variant$same_variant_QMARK_$$($menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$);
$menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$=$APP.$cljs$core$every_QMARK_$$(function($and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$){var $and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$=$find_component$$($and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$,!0),$main$jscomp$4_parent$jscomp$297$$=$APP.$app$common$types$component$get_deleted_component_root$$($and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$);$and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$137$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$)),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1630$pages_index$$),
$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$)),$APP.$cljs$cst$1631$objects$$);$main$jscomp$4_parent$jscomp$297$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$4_parent$jscomp$297$$));$and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$=
$APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$)?($and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$=$APP.$app$common$types$component$is_variant_QMARK_$$($and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$))?$main$jscomp$4_parent$jscomp$297$$:$and__5023__auto____$1$jscomp$126_component__$1$jscomp$6$$:$and__5023__auto__$jscomp$719_objects__$1$jscomp$38_shape__$1$jscomp$104$$},
$restorable_copies$$);var $do_show_in_assets$$=function(){var $component_id__$1$$=$APP.$cljs$core$truth_$$($variant_container_QMARK_$$)?$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77477_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$763$$,$p1__77477_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$981$$)))):
$component_id$jscomp$91$$;return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_component_in_assets$$($component_id__$1$$))}}();$menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$inline_8775_or__5025__auto__$jscomp$1083$$=($and__5023__auto__$jscomp$inline_8775_or__5025__auto__$jscomp$1083$$=
!$multi$jscomp$5$$)?$APP.$cljs$core$truth_$$($variant_container_QMARK_$$)?$variant_container_QMARK_$$:$main_instance_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$inline_8775_or__5025__auto__$jscomp$1083$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8775_or__5025__auto__$jscomp$1083$$)?$and__5023__auto__$jscomp$inline_8775_or__5025__auto__$jscomp$1083$$:$multi$jscomp$5$$?$same_variant_QMARK_$$:$multi$jscomp$5$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-in-assets"),$APP.$cljs$cst$2683$action$$,$do_show_in_assets$$],null):null,!$multi$jscomp$5$$&&$main_instance_QMARK_$jscomp$3$$&&$local_component_QMARK_$$&&$lacks_annotation_QMARK_$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-annotation"),$APP.$cljs$cst$2683$action$$,$do_create_annotation$$],null):
null,$can_detach_QMARK_$jscomp$1$$?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$cljs$core$count$$($copies$jscomp$2$$)>1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.detach-instances-in-bulk"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.detach-instance"),$APP.$cljs$cst$2683$action$$,$do_detach_component$$,$cljs$cst$5599$shortcut$$,$APP.$cljs$cst$4870$detach_component$$],null):null,$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77481__$1_p__77480$$?
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.reset-overrides"),$APP.$cljs$cst$2683$action$$,$do_reset_component$$],null):null,$APP.$cljs$core$seq$$($restorable_copies$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.restore-variant"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.restore-main"),$APP.$cljs$cst$2683$action$$,$do_restore_component$$],null):null,$can_show_component_QMARK__component$jscomp$122$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-main"),$APP.$cljs$cst$2683$action$$,$do_show_component$$],null):null,$can_update_main_QMARK__is_dangling_QMARK_$$?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.update-main"),$APP.$cljs$cst$2683$action$$,$do_update_component$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$722_or__5025__auto__$jscomp$inline_8777$$=($and__5023__auto__$jscomp$722_or__5025__auto__$jscomp$inline_8777$$=!$multi$jscomp$5$$)?$and__5023__auto__$jscomp$722_or__5025__auto__$jscomp$inline_8777$$:$same_variant_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$722_or__5025__auto__$jscomp$inline_8777$$)?
$main_instance_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$722_or__5025__auto__$jscomp$inline_8777$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),$cljs$cst$5599$shortcut$$,$APP.$cljs$cst$4869$create_component_variant$$,$APP.$cljs$cst$2683$action$$,$do_add_variant$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($same_variant_QMARK_$$)?$main_instance_QMARK_$jscomp$3$$?
$APP.$cljs$core$truth_$$($variant_id$jscomp$48$$)?$for_design_tab_QMARK_$$:$variant_id$jscomp$48$$:$main_instance_QMARK_$jscomp$3$$:$same_variant_QMARK_$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),$APP.$cljs$cst$2683$action$$,$do_add_new_property$$],null):null],null);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$($APP.$cljs$core$nil_QMARK_$$),
$menu_entries_restorable_variants_QMARK__shapes$jscomp$185$$)};$app$main$ui$workspace$context_menu$prevent_default$$=function($event$jscomp$327$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$327$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$327$$)};
$app$main$ui$workspace$context_menu$menu_entry_STAR_$$=function($on_unmount_props_77501$$){var $children$jscomp$297$$=$on_unmount_props_77501$$.children,$on_pointer_leave$jscomp$4$$=$on_unmount_props_77501$$.onPointerLeave,$disabled$jscomp$13$$=$on_unmount_props_77501$$.disabled,$is_selected$jscomp$5$$=$on_unmount_props_77501$$.isSelected,$on_pointer_enter$jscomp$4$$=$on_unmount_props_77501$$.onPointerEnter,$value$jscomp$801$$=$on_unmount_props_77501$$.value,$icon$jscomp$20$$=$on_unmount_props_77501$$.icon,
$title$jscomp$33$$=$on_unmount_props_77501$$.title,$shortcut$jscomp$7$$=$on_unmount_props_77501$$.shortcut,$on_click$jscomp$38$$=$on_unmount_props_77501$$.onClick;$on_unmount_props_77501$$=$on_unmount_props_77501$$.onUnmount;var $submenu_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$hovering_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_click_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$38$$)],function($event$jscomp$328$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$hide_context_menu$$);
return $APP.$cljs$core$truth_$$($on_click$jscomp$38$$)?$on_click$jscomp$38$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$38$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$328$$):$on_click$jscomp$38$$($event$jscomp$328$$):null}),$on_pointer_enter__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$$,!0);var $submenu_node_77650$$=$APP.$rumext$v2$ref_val$$($submenu_ref$$);$submenu_node_77650$$!=null&&$APP.$app$util$dom$set_css_property_BANG_$$($submenu_node_77650$$,
"display","block");return $APP.$cljs$core$truth_$$($on_pointer_enter$jscomp$4$$)?$on_pointer_enter$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_pointer_enter$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_pointer_enter$jscomp$4$$():null}),$on_pointer_leave__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$$,!1);var $submenu_node_77651$$=$APP.$rumext$v2$ref_val$$($submenu_ref$$);$submenu_node_77651$$!=null&&$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(200,
function(){return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($hovering_QMARK_$$))?null:$APP.$app$util$dom$set_css_property_BANG_$$($submenu_node_77651$$,"display","none")});return $APP.$cljs$core$truth_$$($on_pointer_leave$jscomp$4$$)?$on_pointer_leave$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_pointer_leave$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_pointer_leave$jscomp$4$$():null}),$set_dom_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($dom$jscomp$1$$){var $submenu_node$$=
$APP.$rumext$v2$ref_val$$($submenu_ref$$);return $dom$jscomp$1$$!=null&&$submenu_node$$!=null?$APP.$app$util$dom$set_css_property_BANG_$$($submenu_node$$,"top",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dom$jscomp$1$$.offsetTop),"px"].join("")):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_unmount_props_77501$$)],$APP.$cljs$core$constantly$$($on_unmount_props_77501$$));return $APP.$cljs$core$truth_$$($icon$jscomp$20$$)?(0,$APP.$rumext$v2$jsxs$$)("li",
{disabled:$disabled$jscomp$13$$,"data-value":$value$jscomp$801$$,ref:$set_dom_node$$,onClick:$on_click_SINGLEQUOTE_$$,onPointerEnter:$on_pointer_enter__$1$$,onPointerLeave:$on_pointer_leave__$1$$,className:"main_ui_workspace_context_menu__icon-menu-item",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_context_menu__icon-wrapper",children:[$APP.$cljs$core$truth_$$($is_selected$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__selected-icon",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s"})}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__selected-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__shape-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$20$$,size:"s"})})]}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__title",
children:$title$jscomp$33$$})]}):(0,$APP.$rumext$v2$jsxs$$)("li",{disabled:$disabled$jscomp$13$$,ref:$set_dom_node$$,"data-value":$value$jscomp$801$$,onClick:$on_click_SINGLEQUOTE_$$,onPointerEnter:$on_pointer_enter__$1$$,onPointerLeave:$on_pointer_leave__$1$$,className:"main_ui_workspace_context_menu__context-menu-item",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__title",children:$title$jscomp$33$$}),$APP.$cljs$core$truth_$$($shortcut$jscomp$7$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_context_menu__shortcut",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$119$$,$p__77502_sc$jscomp$9$$){var $idx$jscomp$115$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77502_sc$jscomp$9$$,0,null);$p__77502_sc$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77502_sc$jscomp$9$$,1,null);$out_arr__44124__auto__$jscomp$119$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__shortcut-key",
children:$p__77502_sc$jscomp$9$$},""+($shortcut$jscomp$7$$??"")+"-"+($idx$jscomp$115$$??"")));return $out_arr__44124__auto__$jscomp$119$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$main$data$shortcuts$split_sc$$($shortcut$jscomp$7$$)))}):null,$APP.$cljs$core$count$$($children$jscomp$297$$)>1?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__submenu-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow",size:"s"})}):null,$APP.$cljs$core$count$$($children$jscomp$297$$)>1?(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$submenu_ref$$,style:{display:"none",left:250},onContextMenu:$app$main$ui$workspace$context_menu$prevent_default$$,className:"main_ui_workspace_context_menu__workspace-context-submenu",children:$children$jscomp$297$$}):null]})};$app$main$ui$workspace$context_menu$menu_separator_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_context_menu__separator"})};
$app$main$ui$workspace$context_menu$context_menu_edit_STAR_$$=function($props_77508_shapes$jscomp$186$$){$props_77508_shapes$jscomp$186$$=$props_77508_shapes$jscomp$186$$.shapes;var $multiple_QMARK_$jscomp$2$$=$APP.$cljs$core$count$$($props_77508_shapes$jscomp$186$$)>1,$enabled_paste_props_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$handle_copy_css$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_css$$())}),
$handle_copy_css_nested$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_css_nested$$())}),$handle_copy_props$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_selected_props$$())}),$handle_paste_props$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$paste_selected_props$$())}),$handle_copy_svg$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_svg$$())}),$handle_copy_text$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_text$$())}),
$handle_copy_as_image$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_as_image$$())}),$handle_hover_copy_paste$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($data$jscomp$472$$){try{var $pdata$jscomp$12$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$472$$),
$and__5023__auto__$jscomp$inline_8779$$=(0,$APP.$app$main$data$workspace$clipboard$paste_data_valid_QMARK_$$)($pdata$jscomp$12$$);var $JSCompiler_inline_result$jscomp$1753$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8779$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4111$copied_props$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($pdata$jscomp$12$$)):$and__5023__auto__$jscomp$inline_8779$$;return $APP.$cljs$core$reset_BANG_$$($enabled_paste_props_STAR_$$,
$JSCompiler_inline_result$jscomp$1753$$)}catch($e77509$$){return $APP.$cljs$core$reset_BANG_$$($enabled_paste_props_STAR_$$,!1)}},function(){return $APP.$cljs$core$reset_BANG_$$($enabled_paste_props_STAR_$$,!1)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($p1__77507_SHARP_$$){return $p1__77507_SHARP_$$.text()},$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$clipboard$default_options$$))))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4798$copy$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_selected$$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-link"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4837$copy_link$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_link_to_clipboard$$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.cut"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4881$cut$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$clipboard$copy_selected$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$delete_selected$$()]))}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.paste"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4833$paste$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$0$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.duplicate"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4791$duplicate$$),
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$duplicate_or_add_variant$$())}}),(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-paste-as"),onPointerEnter:$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$chrome$$)?$handle_hover_copy_paste$$:null,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-css"),onClick:$handle_copy_css$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-css-nested"),onClick:$handle_copy_css_nested$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-svg"),
onClick:$handle_copy_svg$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$props_77508_shapes$jscomp$186$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-as-image"),disabled:$multiple_QMARK_$jscomp$2$$,onClick:$handle_copy_as_image$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-text"),onClick:$handle_copy_text$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-props"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4831$copy_props$$),disabled:$multiple_QMARK_$jscomp$2$$,
onClick:$handle_copy_props$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.paste-props"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4872$paste_props$$),disabled:$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$chrome$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($enabled_paste_props_STAR_$$)),onClick:$handle_paste_props$$})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{})]})};
$app$main$ui$workspace$context_menu$context_menu_layer_position_STAR_$$=function($do_bring_forward_props_77511$$){function $on_unmount$jscomp$1$$($id$jscomp$932$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$highlight$dehighlight_shape$$($id$jscomp$932$$))}}function $on_pointer_leave$jscomp$5$$($id$jscomp$931$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$highlight$dehighlight_shape$$($id$jscomp$931$$))}}function $on_pointer_enter$jscomp$5$$($id$jscomp$930$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$highlight$highlight_shape$$($id$jscomp$930$$))}}
function $select_shapes$$($id$jscomp$929$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$929$$))}}var $shapes$jscomp$187$$=$do_bring_forward_props_77511$$.shapes;$do_bring_forward_props_77511$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1954$up$$))});
var $do_bring_to_front$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1562$top$$))}),$do_send_backward$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1953$down$$))}),
$do_send_to_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1563$bottom$$))}),$hover_ids_hover_objs$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$current_hover_ids$$),$objects$jscomp$764$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);$hover_ids_hover_objs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$764$$)),$hover_ids_hover_objs$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$count$$($hover_ids_hover_objs$$)>1?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.select-layer"),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$120$$,
$object$jscomp$39$$){$out_arr__44124__auto__$jscomp$120$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$),isSelected:$APP.$cljs$core$some$$(function($p1__77510_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($object$jscomp$39$$,$p1__77510_SHARP_$$)},$shapes$jscomp$187$$),onClick:$select_shapes$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),
onPointerEnter:$on_pointer_enter$jscomp$5$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),onPointerLeave:$on_pointer_leave$jscomp$5$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),onUnmount:$on_unmount$jscomp$1$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),icon:$APP.$app$util$shape_icon$get_shape_icon$$($object$jscomp$39$$)},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)??
"")));return $out_arr__44124__auto__$jscomp$120$$},[],$hover_ids_hover_objs$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.forward"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4828$bring_forward$$),onClick:$do_bring_forward_props_77511$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.front"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4820$bring_front$$),onClick:$do_bring_to_front$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.backward"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4855$bring_backward$$),onClick:$do_send_backward$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.back"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4880$bring_back$$),onClick:$do_send_to_back$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{})]})};
$app$main$ui$workspace$context_menu$context_menu_flip_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flip-vertical"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4840$flip_vertical$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$0$())}}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flip-horizontal"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4829$flip_horizontal$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$0$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{})]})};
$app$main$ui$workspace$context_menu$context_menu_thumbnail_STAR_$$=function($props_77513_shapes$jscomp$188$$){function $do_toggle_thumbnail$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$toggle_file_thumbnail_selected$$())}$props_77513_shapes$jscomp$188$$=$props_77513_shapes$jscomp$188$$.shapes;var $single_QMARK_$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77513_shapes$jscomp$188$$),1),
$has_frame_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$props_77513_shapes$jscomp$188$$);return $APP.$cljs$core$truth_$$($single_QMARK_$jscomp$6$$?$has_frame_QMARK_$$:$single_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$2964$use_for_thumbnail$$,$props_77513_shapes$jscomp$188$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.thumbnail-remove"),
onClick:$do_toggle_thumbnail$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.thumbnail-set"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4876$thumbnail_set$$),onClick:$do_toggle_thumbnail$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{})]}):null};
$app$main$ui$workspace$context_menu$context_menu_rename_STAR_$$=function($props_77514$$){function $do_rename$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_rename_selected$$())}return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77514$$.shapes),1)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.rename"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4835$rename$$),onClick:$do_rename$$})]}):null};
$app$main$ui$workspace$context_menu$context_menu_group_STAR_$$=function($props_77518_shapes$jscomp$190$$){function $do_create_artboard_from_selection$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$05$$(null,null,null,null))}function $do_unmask_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$unmask_group$$.$cljs$core$IFn$_invoke$arity$0$())}
function $do_mask_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$mask_group$$.$cljs$core$IFn$_invoke$arity$0$())}function $do_remove_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$groups$ungroup_selected$$())}function $do_create_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$groups$group_selected$$())}
$props_77518_shapes$jscomp$190$$=$props_77518_shapes$jscomp$190$$.shapes;var $multiple_QMARK_$jscomp$3$$=$APP.$cljs$core$count$$($props_77518_shapes$jscomp$190$$)>1,$single_QMARK_$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77518_shapes$jscomp$190$$),1),$objects$jscomp$765$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$any_in_copy_QMARK_$$=$APP.$cljs$core$some$$(function($p1__77515_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$765$$,
$p1__77515_SHARP_$$)},$props_77518_shapes$jscomp$190$$),$any_is_variant_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$props_77518_shapes$jscomp$190$$),$has_frame_QMARK_$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77516_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__77516_SHARP_$$)&&!$APP.$app$common$types$component$instance_head_QMARK_$$($p1__77516_SHARP_$$)&&
$APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__77516_SHARP_$$))},$props_77518_shapes$jscomp$190$$),$has_group_QMARK_$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77517_SHARP_$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__77517_SHARP_$$)&&!$APP.$app$common$types$component$instance_head_QMARK_$$($p1__77517_SHARP_$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__77517_SHARP_$$))},
$props_77518_shapes$jscomp$190$$),$has_bool_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$bool_shape_QMARK_$$,$props_77518_shapes$jscomp$190$$),$has_mask_QMARK_$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1609$masked_group$$,$props_77518_shapes$jscomp$190$$),$is_group_QMARK_$jscomp$1$$=$single_QMARK_$jscomp$7$$?$has_group_QMARK_$jscomp$1$$:$single_QMARK_$jscomp$7$$,$is_bool_QMARK_$$=$single_QMARK_$jscomp$7$$?
$has_bool_QMARK_$$:$single_QMARK_$jscomp$7$$;return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($any_in_copy_QMARK_$$)?$any_in_copy_QMARK_$$:$any_is_variant_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_bool_QMARK_$$)?$has_bool_QMARK_$$:$APP.$cljs$core$truth_$$($has_group_QMARK_$jscomp$1$$)?$has_group_QMARK_$jscomp$1$$:$APP.$cljs$core$truth_$$($has_mask_QMARK_$jscomp$1$$)?
$has_mask_QMARK_$jscomp$1$$:$has_frame_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.ungroup"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4861$ungroup$$),onClick:$do_remove_group$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.group"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$1608$group$$),onClick:$do_create_group$$}),$APP.$cljs$core$truth_$$(function(){if($multiple_QMARK_$jscomp$3$$)return $multiple_QMARK_$jscomp$3$$;var $or__5025__auto____$1$jscomp$120$$=$APP.$cljs$core$truth_$$($is_group_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($has_mask_QMARK_$jscomp$1$$):$is_group_QMARK_$jscomp$1$$;return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$120$$)?$or__5025__auto____$1$jscomp$120$$:$is_bool_QMARK_$$}())?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.mask"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$2689$mask$$),onClick:$do_mask_group$$}):null,$APP.$cljs$core$truth_$$($has_mask_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unmask"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4866$unmask$$),onClick:$do_unmask_group$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-artboard-from-selection"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4862$artboard_selection$$),onClick:$do_create_artboard_from_selection$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{})]}):null})};
$app$main$ui$workspace$context_menu$context_focus_mode_menu_STAR_$$=function(){var $focus$jscomp$15$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$cljs$core$empty_QMARK_$$($focus$jscomp$15$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-on"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-off"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4839$toggle_focus_mode$$),
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())}})};
$app$main$ui$workspace$context_menu$context_menu_path_STAR_$$=function($has_path_QMARK_$jscomp$1_props_77522$$){function $make_do_bool$$($bool_type$jscomp$9$$){return function(){if($multiple_QMARK_$jscomp$4$$)var $JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$create_bool$$)($bool_type$jscomp$9$$));
else if($APP.$cljs$core$truth_$$($is_group_QMARK_$jscomp$2$$)){$JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$191$$));
$JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$=$app$main$data$workspace$bool$group_to_bool$$($JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$,$bool_type$jscomp$9$$);$JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$=$JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$.call($APP.$app$main$store$emit_BANG_$$,
$JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$)}else $APP.$cljs$core$truth_$$($is_bool_QMARK_$jscomp$1$$)?($JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$,$JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$191$$)),$JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$=$app$main$data$workspace$bool$change_bool_type$$($JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$,$bool_type$jscomp$9$$),$JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$=
$JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1690_JSCompiler_inline_result$jscomp$1693_param72231$jscomp$inline_8781_param72234$jscomp$inline_8784$$)):$JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$=null;return $JSCompiler_temp$jscomp$1685_JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp_const$jscomp$1688_JSCompiler_temp_const$jscomp$1691$$}}
function $do_strokes_to_path$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$convert_selected_strokes_to_path$$.$cljs$core$IFn$_invoke$arity$0$())}function $do_transform_to_path$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$convert_selected_to_path$$.$cljs$core$IFn$_invoke$arity$0$())}function $do_start_editing$$(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_editing_selected$$())})}
var $shapes$jscomp$191$$=$has_path_QMARK_$jscomp$1_props_77522$$.shapes,$objects$jscomp$766$$=$has_path_QMARK_$jscomp$1_props_77522$$.objects,$disable_flatten$$=$has_path_QMARK_$jscomp$1_props_77522$$.disableFlatten,$disable_booleans$$=$has_path_QMARK_$jscomp$1_props_77522$$.disableBooleans,$multiple_QMARK_$jscomp$4$$=$APP.$cljs$core$count$$($shapes$jscomp$191$$)>1,$single_QMARK_$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$191$$),1),$has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$group_shape_QMARK_$$,$shapes$jscomp$191$$),$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$bool_shape_QMARK_$$,$shapes$jscomp$191$$),$has_frame_QMARK_$jscomp$2$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$shapes$jscomp$191$$);$has_path_QMARK_$jscomp$1_props_77522$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$path_shape_QMARK_$$,$shapes$jscomp$191$$);var $is_group_QMARK_$jscomp$2$$=$single_QMARK_$jscomp$8$$?$has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$:$single_QMARK_$jscomp$8$$,$is_bool_QMARK_$jscomp$1$$=$single_QMARK_$jscomp$8$$?$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$:$single_QMARK_$jscomp$8$$;$has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$=$single_QMARK_$jscomp$8$$?$has_frame_QMARK_$jscomp$2$$:
$single_QMARK_$jscomp$8$$;$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$=function(){var $or__5025__auto__$jscomp$1089$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77520_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($p1__77520_SHARP_$$))},$shapes$jscomp$191$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1089$$)?$or__5025__auto__$jscomp$1089$$:$APP.$cljs$core$truth_$$($objects$jscomp$766$$)?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($shape$jscomp$984$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77521_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$766$$,
$p1__77521_SHARP_$$)))},$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$766$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$984$$)))},$shapes$jscomp$191$$):null}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$single_QMARK_$jscomp$8$$&&$APP.$cljs$core$not$$($has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.edit"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4859$start_editing$$),onClick:$do_start_editing$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($disable_flatten$$)?$disable_flatten$$:$APP.$cljs$core$truth_$$($has_frame_QMARK_$jscomp$2$$)?$has_frame_QMARK_$jscomp$2$$:$has_path_QMARK_$jscomp$1_props_77522$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flatten"),
onClick:$do_transform_to_path$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$)?$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1193$stroke_path$$):$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.stroke-to-path"),
onClick:$do_strokes_to_path$$}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$733_and__5023__auto____$1$jscomp$128$$=$APP.$cljs$core$not$$($has_frame_QMARK_$jscomp$2$$);return $and__5023__auto__$jscomp$733_and__5023__auto____$1$jscomp$128$$?($and__5023__auto__$jscomp$733_and__5023__auto____$1$jscomp$128$$=$APP.$cljs$core$not$$($disable_booleans$$))?$multiple_QMARK_$jscomp$4$$?$multiple_QMARK_$jscomp$4$$:$single_QMARK_$jscomp$8$$?$APP.$cljs$core$truth_$$($is_group_QMARK_$jscomp$2$$)?
$is_group_QMARK_$jscomp$2$$:$is_bool_QMARK_$jscomp$1$$:$single_QMARK_$jscomp$8$$:$and__5023__auto__$jscomp$733_and__5023__auto____$1$jscomp$128$$:$and__5023__auto__$jscomp$733_and__5023__auto____$1$jscomp$128$$}())?(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.path"),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.union"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4830$bool_union$$),onClick:$make_do_bool$$($APP.$cljs$cst$736$union$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.difference"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4832$bool_difference$$),onClick:$make_do_bool$$($APP.$cljs$cst$2025$difference$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.intersection"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4795$bool_intersection$$),onClick:$make_do_bool$$($APP.$cljs$cst$2034$intersection$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.exclude"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4851$bool_exclude$$),
onClick:$make_do_bool$$($APP.$cljs$cst$2033$exclude$$)}),$APP.$cljs$core$truth_$$($single_QMARK_$jscomp$8$$?$APP.$cljs$core$truth_$$($is_bool_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($disable_flatten$$):$is_bool_QMARK_$jscomp$1$$:$single_QMARK_$jscomp$8$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flatten"),
onClick:$do_transform_to_path$$})]}):null]}):null]})};
$app$main$ui$workspace$context_menu$context_menu_layer_options_STAR_$$=function($props_77524_shapes$jscomp$192$$){function $do_unlock_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$272$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1623$blocked$$,!1],null)))}function $do_lock_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$272$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1623$blocked$$,!0],null)))}function $do_hide_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$272$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1620$hidden$$,!0],null)))}function $do_show_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$272$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1620$hidden$$,!1],null)))}$props_77524_shapes$jscomp$192$$=$props_77524_shapes$jscomp$192$$.shapes;var $ids$jscomp$272$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$props_77524_shapes$jscomp$192$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$1620$hidden$$,$props_77524_shapes$jscomp$192$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4847$toggle_visibility$$),onClick:$do_show_shape$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4847$toggle_visibility$$),onClick:$do_hide_shape$$}),$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$1623$blocked$$,$props_77524_shapes$jscomp$192$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4868$toggle_lock$$),onClick:$do_unlock_shape$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4868$toggle_lock$$),
onClick:$do_lock_shape$$})]})};
$app$main$ui$workspace$context_menu$context_menu_prototype_STAR_$$=function($props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$){function $do_add_flow$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$add_flow_selected_frame$$())}$props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$=$props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$.shapes;var $flows$jscomp$8$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_flows$$),$options_mode_prototype_QMARK_$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$options_mode_global$$);$options_mode_prototype_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode_prototype_QMARK_$$,$APP.$cljs$cst$3731$prototype$$);var $single_QMARK_$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$),1),$has_frame_QMARK_$jscomp$3$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,
$props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$);return $APP.$cljs$core$truth_$$($options_mode_prototype_QMARK_$$?$single_QMARK_$jscomp$9$$?$has_frame_QMARK_$jscomp$3$$:$single_QMARK_$jscomp$9$$:$options_mode_prototype_QMARK_$$)?($props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$=$APP.$app$common$types$page$get_frame_flow$$($flows$jscomp$8$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$))),
$APP.$cljs$core$truth_$$($props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete-flow-start"),onClick:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_77533_shapes$jscomp$193_temp__5823__auto__$jscomp$233$$)))}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flow-start"),onClick:$do_add_flow$$})):null};
$app$main$ui$workspace$context_menu$context_menu_layout_STAR_$$=function($props_77539_single_QMARK_$jscomp$10$$){var $shapes$jscomp$194$$=$props_77539_single_QMARK_$jscomp$10$$.shapes;$props_77539_single_QMARK_$jscomp$10$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$194$$),1);var $objects$jscomp$767$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$any_in_copy_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$cljs$core$true_QMARK_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77538_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$767$$,$p1__77538_SHARP_$$)},$shapes$jscomp$194$$)),$has_flex_QMARK_$$=$props_77539_single_QMARK_$jscomp$10$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$shapes$jscomp$194$$),$has_grid_QMARK_$$=$props_77539_single_QMARK_$jscomp$10$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,
$shapes$jscomp$194$$),$any_is_variant_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$shapes$jscomp$194$$),$on_add_layout$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$329_type$jscomp$613$$){$event$jscomp$329_type$jscomp$613$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$329_type$jscomp$613$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$shape_layout$create_layout$$($event$jscomp$329_type$jscomp$613$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:context-menu"],null)))}),$on_remove_layout$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$194$$)],function(){var $ids$jscomp$273$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$194$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($ids$jscomp$273$$))});
return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$not$$($any_in_copy_QMARK_$jscomp$1$$)?$has_flex_QMARK_$$||$has_grid_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),$has_flex_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-flex"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4804$toggle_layout_flex$$),
onClick:$on_remove_layout$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-grid"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4823$toggle_layout_grid$$),onClick:$on_remove_layout$$})]}):$props_77539_single_QMARK_$jscomp$10$$||$APP.$cljs$core$not$$($any_is_variant_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-flex"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4804$toggle_layout_flex$$),value:"flex",onClick:$on_add_layout$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-grid"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4823$toggle_layout_grid$$),
value:"grid",onClick:$on_add_layout$$})]}):null:null})};
$app$main$ui$workspace$context_menu$context_menu_component_STAR_$$=function($props_77542_single_QMARK_$jscomp$11$$){var $shapes$jscomp$195$$=$props_77542_single_QMARK_$jscomp$11$$.shapes;$props_77542_single_QMARK_$jscomp$11$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$195$$),1);var $objects$jscomp$768$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$can_make_component$jscomp$2$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77540_SHARP_$$){return $APP.$app$common$types$container$valid_shape_for_component_QMARK_$$($objects$jscomp$768$$,$p1__77540_SHARP_$$)},$shapes$jscomp$195$$)),$components_menu_entries$$=$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$$($shapes$jscomp$195$$),$variant_container_QMARK_$jscomp$1$$=$props_77542_single_QMARK_$jscomp$11$$?$APP.$app$common$types$component$is_variant_container_QMARK_$$($APP.$cljs$core$first$$($shapes$jscomp$195$$)):
$props_77542_single_QMARK_$jscomp$11$$,$all_main_QMARK_$jscomp$3$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$main_instance_QMARK_$$,$shapes$jscomp$195$$),$any_variant_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$shapes$jscomp$195$$),$do_add_component$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$add_component$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
null))}),$do_add_multiple_components$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$add_multiple_components$$())}),$do_combine_as_variants$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$combine_selected_as_variants$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$4424$trigger$$,"workspace:context-menu-component"],null)))}),$do_add_variant$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$195$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:context-menu-component"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$195$$)))]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$can_make_component$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-component"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4869$create_component_variant$$),onClick:$do_add_component$$}),$props_77542_single_QMARK_$jscomp$11$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-multiple-components"),
onClick:$do_add_multiple_components$$})]}):null,$APP.$cljs$core$seq$$($components_menu_entries$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$121$$,$entry$jscomp$70$$){$out_arr__44124__auto__$jscomp$121$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$70$$),shortcut:$APP.$cljs$core$contains_QMARK_$$($entry$jscomp$70$$,$cljs$cst$5599$shortcut$$)?$app$main$data$workspace$shortcuts$get_tooltip$$($cljs$cst$5599$shortcut$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$70$$)):null,onClick:$APP.$cljs$cst$2683$action$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$70$$)},$APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$70$$)));return $out_arr__44124__auto__$jscomp$121$$},
[],$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$components_menu_entries$$))]}):null,$APP.$cljs$core$truth_$$($variant_container_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4869$create_component_variant$$),onClick:$do_add_variant$jscomp$1$$})]}):null,!$props_77542_single_QMARK_$jscomp$11$$&&$all_main_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($any_variant_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants"),onClick:$do_combine_as_variants$$})]}):null]})};
$app$main$ui$workspace$context_menu$context_menu_guides_STAR_$$=function($do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$){$do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$=$do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$.shapes;var $frame_ids$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$frame_shape_QMARK_$$),
$APP.$app$common$data$xf_COLON_map_id$$),$do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$);$do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_guides$$);var $has_guides_QMARK_$$=$APP.$cljs$core$some$$(function($p1__77551_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_ids$jscomp$7$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77551_SHARP_$$))},$APP.$cljs$core$vals$$($do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$));
$do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_ids$jscomp$7$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$remove_frame_guides$$($frame_ids$jscomp$7$$))});return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$738$$=$APP.$cljs$core$seq$$($frame_ids$jscomp$7$$);return $and__5023__auto__$jscomp$738$$?
$has_guides_QMARK_$$:$and__5023__auto__$jscomp$738$$}())?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.clear-guides"),onClick:$do_remove_guides_guides$jscomp$9_props_77552_shapes$jscomp$196$$})]}):null};
$app$main$ui$workspace$context_menu$context_menu_delete_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4834$delete$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$delete_selected$$())}})]})};
$app$main$ui$workspace$context_menu$page_item_context_menu_STAR_$$=function($page$jscomp$162_props_77570$$){function $do_delete$jscomp$2$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.title"),$APP.$cljs$cst$141$message$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.body"),$APP.$cljs$cst$2479$on_accept$$,$delete_fn$jscomp$2$$],null)))}function $delete_fn$jscomp$2$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$pages$delete_page$$($id$jscomp$933$$))}var $deletable_QMARK__mdata$jscomp$15$$=$page$jscomp$162_props_77570$$.mdata;$page$jscomp$162_props_77570$$=$APP.$cljs$cst$1624$page$$.$cljs$core$IFn$_invoke$arity$1$($deletable_QMARK__mdata$jscomp$15$$);
$deletable_QMARK__mdata$jscomp$15$$=$cljs$cst$5602$deletable_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($deletable_QMARK__mdata$jscomp$15$$);var $id$jscomp$933$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$162_props_77570$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($deletable_QMARK__mdata$jscomp$15$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),
onClick:$do_delete$jscomp$2$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$start_rename_page_item$$($id$jscomp$933$$))}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$pages$duplicate_page$$($id$jscomp$933$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"duplicate-page"],null))]))}})]})};
$app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$=function(){function $do_toggle_focus_mode$jscomp$1$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())}function $do_paste$jscomp$1$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$0$())}var $focus$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),
$read_only_QMARK_$jscomp$8$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$read_only_QMARK_$jscomp$8$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.paste"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4833$paste$$),onClick:$do_paste$jscomp$1$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide-ui"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4825$hide_ui$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$4825$hide_ui$$),
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-context-menu"))}}),$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$16$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-off"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4839$toggle_focus_mode$$),onClick:$do_toggle_focus_mode$jscomp$1$$}):null]})};
$app$main$ui$workspace$context_menu$grid_track_context_menu_STAR_$$=function($do_delete_track_map__77578__$1_props_77577$$){$do_delete_track_map__77578__$1_props_77577$$=$APP.$cljs$core$__destructure_map$$($do_delete_track_map__77578__$1_props_77577$$.mdata);var $type$jscomp$614$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_delete_track_map__77578__$1_props_77577$$,$APP.$cljs$cst$139$type$$),$index$jscomp$473$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_delete_track_map__77578__$1_props_77577$$,
$APP.$cljs$cst$1795$index$$),$grid_id$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_delete_track_map__77578__$1_props_77577$$,$APP.$cljs$cst$4420$grid_id$$);$do_delete_track_map__77578__$1_props_77577$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$614$$),$APP.$rumext$v2$adapt$$($index$jscomp$473$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$614$$,$index$jscomp$473$$))});var $do_add_track_before$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$614$$),$APP.$rumext$v2$adapt$$($index$jscomp$473$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$614$$,$APP.$app$common$types$shape$layout$default_track_value$$,$index$jscomp$473$$))}),$do_add_track_after$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$614$$),$APP.$rumext$v2$adapt$$($index$jscomp$473$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$614$$,$APP.$app$common$types$shape$layout$default_track_value$$,$index$jscomp$473$$+1))}),$do_duplicate_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$614$$),$APP.$rumext$v2$adapt$$($index$jscomp$473$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$duplicate_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$614$$,$index$jscomp$473$$))}),$do_delete_track_shapes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$614$$),$APP.$rumext$v2$adapt$$($index$jscomp$473$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$614$$,$index$jscomp$473$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4404$with_shapes_QMARK_$$,!0],null)])))});return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$APP.$cljs$cst$216$column$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.duplicate"),onClick:$do_duplicate_track$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.add-before"),onClick:$do_add_track_before$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.add-after"),
onClick:$do_add_track_after$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.delete"),onClick:$do_delete_track_map__77578__$1_props_77577$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.delete-shapes"),onClick:$do_delete_track_shapes$$})]}):
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.duplicate"),onClick:$do_duplicate_track$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.add-before"),onClick:$do_add_track_before$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.add-after"),onClick:$do_add_track_after$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.delete"),onClick:$do_delete_track_map__77578__$1_props_77577$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.delete-shapes"),onClick:$do_delete_track_shapes$$})]})};
$app$main$ui$workspace$context_menu$grid_cells_context_menu_STAR_$$=function($map__77582__$1_props_77581_single_QMARK_$jscomp$12$$){$map__77582__$1_props_77581_single_QMARK_$jscomp$12$$=$APP.$cljs$core$__destructure_map$$($map__77582__$1_props_77581_single_QMARK_$jscomp$12$$.mdata);var $grid$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77582__$1_props_77581_single_QMARK_$jscomp$12$$,$APP.$cljs$cst$1659$grid$$),$cells$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77582__$1_props_77581_single_QMARK_$jscomp$12$$,
$APP.$cljs$cst$4512$cells$$),$grid_id$jscomp$28$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$10$$);$map__77582__$1_props_77581_single_QMARK_$jscomp$12$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($cells$jscomp$29$$),1);var $can_merge_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){return $app$common$types$shape$layout$valid_area_cells_QMARK_$$($cells$jscomp$29$$)}),
$can_copy_rows_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$10$$),$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){var $first_column$jscomp$inline_8791_map__71287$jscomp$inline_8789$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$29$$),$last_column$jscomp$inline_8792_map__71287__$1$jscomp$inline_8790$$=$APP.$cljs$core$__destructure_map$$($first_column$jscomp$inline_8791_map__71287$jscomp$inline_8789$$);
$first_column$jscomp$inline_8791_map__71287$jscomp$inline_8789$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$inline_8792_map__71287__$1$jscomp$inline_8790$$,$APP.$cljs$cst$1716$first_column$$);$last_column$jscomp$inline_8792_map__71287__$1$jscomp$inline_8790$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$inline_8792_map__71287__$1$jscomp$inline_8790$$,$APP.$cljs$cst$1718$last_column$$);var $num_columns$jscomp$inline_8793$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$10$$));
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first_column$jscomp$inline_8791_map__71287$jscomp$inline_8789$$,1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$inline_8792_map__71287__$1$jscomp$inline_8790$$,$num_columns$jscomp$inline_8793$$)}),$can_copy_columns_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$10$$),$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){var $first_row$jscomp$inline_8799_map__71288$jscomp$inline_8797$$=
$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$29$$),$last_row$jscomp$inline_8800_map__71288__$1$jscomp$inline_8798$$=$APP.$cljs$core$__destructure_map$$($first_row$jscomp$inline_8799_map__71288$jscomp$inline_8797$$);$first_row$jscomp$inline_8799_map__71288$jscomp$inline_8797$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_row$jscomp$inline_8800_map__71288__$1$jscomp$inline_8798$$,$APP.$cljs$cst$1715$first_row$$);$last_row$jscomp$inline_8800_map__71288__$1$jscomp$inline_8798$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_row$jscomp$inline_8800_map__71288__$1$jscomp$inline_8798$$,$APP.$cljs$cst$1717$last_row$$);var $num_rows$jscomp$inline_8801$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$10$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first_row$jscomp$inline_8799_map__71288$jscomp$inline_8797$$,1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_row$jscomp$inline_8800_map__71288__$1$jscomp$inline_8798$$,
$num_rows$jscomp$inline_8801$$)}),$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $app$main$refs$workspace_grid_edition_id$$($grid_id$jscomp$28$$)});$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$=$APP.$rumext$v2$deref$$($grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$);$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$=$APP.$cljs$cst$4418$copied_tracks$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$)!=
null;var $do_merge_cells$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$),$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$merge_cells$$($grid_id$jscomp$28$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cells$jscomp$29$$)))}),$do_create_board$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$),
$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$create_cell_board$$($grid_id$jscomp$28$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cells$jscomp$29$$)))}),$do_copy_rows$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$copy_grid_tracks$$($grid_id$jscomp$28$$,
$APP.$cljs$cst$1656$row$$))}),$do_copy_columns$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$copy_grid_tracks$$($grid_id$jscomp$28$$,$APP.$cljs$cst$216$column$$))}),$do_paste_tracks$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$paste_grid_tracks$$($grid_id$jscomp$28$$))});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$map__77582__$1_props_77581_single_QMARK_$jscomp$12$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.merge"),onClick:$do_merge_cells$$,disabled:$APP.$cljs$core$not$$($can_merge_QMARK_$$)}),$map__77582__$1_props_77581_single_QMARK_$jscomp$12$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.area"),onClick:$do_merge_cells$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.create-board"),onClick:$do_create_board$$,disabled:!$map__77582__$1_props_77581_single_QMARK_$jscomp$12$$&&$APP.$cljs$core$not$$($can_merge_QMARK_$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.copy-rows"),onClick:$do_copy_rows$$,disabled:$APP.$cljs$core$not$$($can_copy_rows_QMARK_$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.copy-columns"),onClick:$do_copy_columns$$,disabled:$APP.$cljs$core$not$$($can_copy_columns_QMARK_$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.paste-tracks"),onClick:$do_paste_tracks$$,disabled:!$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$})]})};
$app$main$ui$workspace$context_menu$guide_color_context_menu_STAR_$$=function($do_remove_guide_map__77590__$1_props_77587$$){$do_remove_guide_map__77590__$1_props_77587$$=$APP.$cljs$core$__destructure_map$$($do_remove_guide_map__77590__$1_props_77587$$.mdata);var $guide$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_remove_guide_map__77590__$1_props_77587$$,$APP.$cljs$cst$3848$guide$$),$guide_id$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$11$$),
$current_color$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1092$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$11$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1092$$)?$or__5025__auto__$jscomp$1092$$:$APP.$cljs$core$first$$($app$main$ui$workspace$context_menu$guide_color_presets$$)}(),$do_set_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guide_id$jscomp$4$$)],function($color$jscomp$151_event$jscomp$330$$){$color$jscomp$151_event$jscomp$330$$=
$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($color$jscomp$151_event$jscomp$330$$),"color");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$hide_context_menu$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$guides$update_guide_color$$($guide_id$jscomp$4$$,$color$jscomp$151_event$jscomp$330$$)]))});$do_remove_guide_map__77590__$1_props_77587$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guide$jscomp$11$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$hide_context_menu$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$11$$)]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_context_menu__context-menu-item main_ui_workspace_context_menu__guide-color-label",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_context_menu__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.guides.change-color")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_context_menu__guide-color-swatches",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$122$$,$color$jscomp$152$$){$out_arr__44124__auto__$jscomp$122$$.push((0,$APP.$rumext$v2$jsx$$)("span",{"data-color":$color$jscomp$152$$,
onClick:$do_set_color$$,title:$color$jscomp$152$$,style:{backgroundColor:$color$jscomp$152$$},className:"main_ui_workspace_context_menu__guide-color-swatch "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$152$$,$current_color$jscomp$4$$)?"main_ui_workspace_context_menu__selected":"")},$color$jscomp$152$$));return $out_arr__44124__auto__$jscomp$122$$},[],$app$main$ui$workspace$context_menu$guide_color_presets$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.guides.remove"),onClick:$do_remove_guide_map__77590__$1_props_77587$$})]})};
$app$main$ui$workspace$context_menu$context_menu_STAR_$$=function(){var $mdata$jscomp$19$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$context_menu$menu_ref$$),$top$jscomp$15$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$19$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1511$y$$],null))-20,$left$jscomp$33$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$19$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1510$x$$],null)),$dropdown_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$read_only_QMARK_$jscomp$9$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$19$$)],function(){var $temp__5825__auto__$jscomp$357$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$357$$)){var $bounding_rect$jscomp$1$$=$APP.$app$util$dom$get_bounding_rect$$($temp__5825__auto__$jscomp$357$$),$window_size$jscomp$4$$=$APP.$app$util$dom$get_window_size$$(),$delta_x$jscomp$3$$=function(){var $x__5110__auto__$jscomp$135$$=$APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($bounding_rect$jscomp$1$$)+250-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($window_size$jscomp$4$$);return $x__5110__auto__$jscomp$135$$>
0?$x__5110__auto__$jscomp$135$$:0}(),$delta_y$jscomp$2$$=function(){var $x__5110__auto__$jscomp$136$$=$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($bounding_rect$jscomp$1$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($window_size$jscomp$4$$);return $x__5110__auto__$jscomp$136$$>0?$x__5110__auto__$jscomp$136$$:0}(),$new_style$jscomp$2$$=["top: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($top$jscomp$15$$-$delta_y$jscomp$2$$),"px; left: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$33$$-
$delta_x$jscomp$3$$),"px;"].join("");return $delta_x$jscomp$3$$>0||$delta_y$jscomp$2$$>0?$temp__5825__auto__$jscomp$357$$.setAttribute("style",$new_style$jscomp$2$$):null}return null});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$boolean$0$$($mdata$jscomp$19$$),"on-close":function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$hide_context_menu$$)},children:(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$dropdown_ref$$,style:{top:$top$jscomp$15$$,left:$left$jscomp$33$$},"data-testid":"context-menu",onContextMenu:$app$main$ui$workspace$context_menu$prevent_default$$,className:"main_ui_workspace_context_menu__workspace-context-menu",children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_context_menu__context-list",children:$read_only_QMARK_$jscomp$9$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$}):function(){var $G__77609$$=
$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($mdata$jscomp$19$$);switch($G__77609$$ instanceof $APP.$cljs$core$Keyword$$?$G__77609$$.$fqn$:null){case "shape":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$shape_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});case "page":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$page_item_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});case "grid-track":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$grid_track_context_menu_STAR_$$,
{mdata:$mdata$jscomp$19$$});case "grid-cells":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$grid_cells_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});case "guide":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$guide_color_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});default:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$})}}()})})})};
$app$main$ui$workspace$coordinates$coordinates_STAR_$$=function($is_colorpalette_props_77500$$){$is_colorpalette_props_77500$$=$is_colorpalette_props_77500$$.isColorpalette;var $coords$jscomp$3$$=$app$main$ui$hooks$use_rxsub$$();return(0,$APP.$rumext$v2$jsxs$$)("div",{className:($APP.$cljs$core$truth_$$($is_colorpalette_props_77500$$)?"main_ui_workspace_coordinates__container-color-palette-open":"")+" main_ui_workspace_coordinates__container",children:[(0,$APP.$rumext$v2$jsx$$)("span",{alt:"x",className:"main_ui_workspace_coordinates__coordinate",
children:["X: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$($coords$jscomp$3$$,"-"))].join("")}),(0,$APP.$rumext$v2$jsx$$)("span",{alt:"y",className:"main_ui_workspace_coordinates__coordinate",children:["Y: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$($coords$jscomp$3$$,"-"))].join("")})]})};
$app$main$ui$workspace$tokens$import_from_library$import_modal_library_STAR_$$=function($cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$){$cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0]));$cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$=
$APP.$cljs$core$__destructure_map$$($cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$);var $file_id$jscomp$373$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$,$APP.$cljs$cst$1644$file_id$$),$library_id$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$,$APP.$cljs$cst$3966$library_id$$);$cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($library_id$jscomp$54$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1171$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1171$$,$APP.$cljs$cst$1916$files$$),$library_id$jscomp$54$$),$APP.$cljs$cst$142$data$$)},$APP.$app$main$store$state$$)});
var $library_data$jscomp$36$$=$APP.$rumext$v2$deref$$($cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$),$show_libraries_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$373$$)],function(){$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3971$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,
$file_id$jscomp$373$$],null))});$cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$?$show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$():$show_libraries_dialog$$()});var $import$$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$373$$),$APP.$rumext$v2$adapt$$($library_id$jscomp$54$$),
$APP.$rumext$v2$adapt$$($library_data$jscomp$36$$)],function(){var $tokens_lib_77575$$=$APP.$cljs$cst$2139$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$36$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$import_tokens_lib$$($tokens_lib_77575$$));return $show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$?$show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$():$show_libraries_dialog$$()});return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_tokens_import_from_library__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_import_from_library__close-btn",onClick:$cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-header",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,id:"modal-title",typography:"headline-large",className:"main_ui_workspace_tokens_import_from_library__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.import-library-tokens.title")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-content",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.import-library-tokens.description")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{type:$APP.$cljs$cst$2312$context$$,appearance:"neutral",level:"default",isHtml:!0,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-warning")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_from_library__action-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$cancel$jscomp$2_library_file_ref_map__77565_map__77565__$1_props_77559$$,type:"button",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$import$$$,type:"button",variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.import-library-tokens.import")})]})})]})})};
$app$main$ui$workspace$libraries$get_library_summary$$=function($data$jscomp$473$$){var $colors$jscomp$10$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$473$$)),$typographies$jscomp$1$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$473$$)),$components$jscomp$8$$=$APP.$cljs$core$count$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77919_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__77919_SHARP_$$,
$data$jscomp$473$$)},$APP.$app$common$types$components_list$components_seq$$($data$jscomp$473$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5604$is_empty$$,$components$jscomp$8$$===0&&$colors$jscomp$10$$===0&&$typographies$jscomp$1$$===0,$APP.$cljs$cst$2212$colors$$,$colors$jscomp$10$$,$APP.$cljs$cst$2472$graphics$$,0,$APP.$cljs$cst$2215$typographies$$,$typographies$jscomp$1$$,$APP.$cljs$cst$1638$components$$,$components$jscomp$8$$],null)};
$app$main$ui$workspace$libraries$adapt_backend_summary$$=function($summary$jscomp$2$$){var $components$jscomp$9$$=function(){var $or__5025__auto__$jscomp$1093$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$2$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1093$$)?$or__5025__auto__$jscomp$1093$$:0}(),$graphics$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1094$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1639$media$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$2$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1094$$)?$or__5025__auto__$jscomp$1094$$:0}(),$typographies$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1095$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$2$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1095$$)?$or__5025__auto__$jscomp$1095$$:0}(),$colors$jscomp$11$$=function(){var $or__5025__auto__$jscomp$1096$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$2$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1096$$)?$or__5025__auto__$jscomp$1096$$:0}();return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5604$is_empty$$,$components$jscomp$9$$===0&&$graphics$jscomp$1$$===0&&$colors$jscomp$11$$===0&&$typographies$jscomp$2$$===0,$APP.$cljs$cst$1638$components$$,$components$jscomp$9$$,$APP.$cljs$cst$2472$graphics$$,$graphics$jscomp$1$$,$APP.$cljs$cst$2215$typographies$$,$typographies$jscomp$2$$,$APP.$cljs$cst$2212$colors$$,$colors$jscomp$11$$],
null)};
$app$main$ui$workspace$libraries$describe_library$$=function($G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$,$G__77937__$3$jscomp$inline_8806_colors_count$$,$JSCompiler_inline_result$jscomp$1758_typography_count$$){var $all_zero_QMARK_$$=$G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$===0&&$G__77937__$3$jscomp$inline_8806_colors_count$$===0&&$JSCompiler_inline_result$jscomp$1758_typography_count$$===0,$JSCompiler_temp_const$jscomp$1757$$=$APP.$cljs$core$str$$,
$JSCompiler_temp_const$jscomp$1756$$=$JSCompiler_temp_const$jscomp$1757$$.$cljs$core$IFn$_invoke$arity$1$,$JSCompiler_temp_const$jscomp$1754$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$,$G__77937$jscomp$inline_8803$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$=$all_zero_QMARK_$$||$G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$>0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77937$jscomp$inline_8803$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.components",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$)]))):$G__77937$jscomp$inline_8803$$;$G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$=$all_zero_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.graphics",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$(0)]))):$G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$;$G__77937__$3$jscomp$inline_8806_colors_count$$=$all_zero_QMARK_$$||$G__77937__$3$jscomp$inline_8806_colors_count$$>0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.colors",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($G__77937__$3$jscomp$inline_8806_colors_count$$)]))):$G__77937__$1$jscomp$inline_8804_G__77937__$2$jscomp$inline_8805_components_count$$;$JSCompiler_inline_result$jscomp$1758_typography_count$$=$all_zero_QMARK_$$||$JSCompiler_inline_result$jscomp$1758_typography_count$$>0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77937__$3$jscomp$inline_8806_colors_count$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.typography",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($JSCompiler_inline_result$jscomp$1758_typography_count$$)]))):$G__77937__$3$jscomp$inline_8806_colors_count$$;return[$JSCompiler_temp_const$jscomp$1756$$.call($JSCompiler_temp_const$jscomp$1757$$,$JSCompiler_temp_const$jscomp$1754$$.call($APP.$cuerdas$core$join$$," · ",$JSCompiler_inline_result$jscomp$1758_typography_count$$)),
" "].join("")};
$app$main$ui$workspace$libraries$library_description_STAR_$$=function($components_count$jscomp$1_props_77941$$){var $colors_count$jscomp$1_summary$jscomp$3$$=$components_count$jscomp$1_props_77941$$.summary;$components_count$jscomp$1_props_77941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$3$$,$APP.$cljs$cst$1638$components$$);var $graphics_count$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$3$$,$APP.$cljs$cst$2472$graphics$$),
$typography_count$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$3$$,$APP.$cljs$cst$2215$typographies$$);$colors_count$jscomp$1_summary$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$3$$,$APP.$cljs$cst$2212$colors$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$components_count$jscomp$1_props_77941$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.components",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($components_count$jscomp$1_props_77941$$)]))}):null,$graphics_count$jscomp$1$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.graphics",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($graphics_count$jscomp$1$$)]))}):
null,$colors_count$jscomp$1_summary$jscomp$3$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.colors",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($colors_count$jscomp$1_summary$jscomp$3$$)]))}):null,$typography_count$jscomp$1$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.typography",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($typography_count$jscomp$1$$)]))}):null]})};
$app$main$ui$workspace$libraries$sample_library_entry_STAR_$$=function($library$jscomp$32_props_77944$$){var $importing$$=$library$jscomp$32_props_77944$$.importing;$library$jscomp$32_props_77944$$=$library$jscomp$32_props_77944$$.library;var $id$jscomp$934$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$32_props_77944$$),$importing_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($importing$$),$team_id$jscomp$144$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$),
$on_error$jscomp$72$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($importing$$,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.import-error")))}),$on_success$jscomp$57$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$144$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$144$$))}),
$import_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success$jscomp$57$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$72$$)],function(){$APP.$cljs$core$reset_BANG_$$($importing$$,$id$jscomp$934$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$clone_template$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4966$template_id$$,$id$jscomp$934$$],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$57$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$72$$],null))))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__sample-library-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__sample-library-item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$32_props_77944$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"secondary",disabled:$importing_QMARK_$jscomp$1$$!=null,onClick:$import_library$$,className:"main_ui_workspace_libraries__sample-library-button",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($importing_QMARK_$jscomp$1$$,$id$jscomp$934$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.adding"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.add")})]},""+($id$jscomp$934$$??""))};
$app$main$ui$workspace$libraries$libraries_tab_STAR_$$=function($is_shared$jscomp$5_props_77977$$){var $shared_libraries$$=$is_shared$jscomp$5_props_77977$$.sharedLibraries,$linked_libraries$$=$is_shared$jscomp$5_props_77977$$.linkedLibraries;$is_shared$jscomp$5_props_77977$$=$is_shared$jscomp$5_props_77977$$.isShared;var $file_id$jscomp$374$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$search_term_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),
$search_term$jscomp$3$$=$APP.$cljs$core$_deref$$($search_term_STAR_$$),$local_library_summary$jscomp$5$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_data$$);$local_library_summary$jscomp$5$$=$app$main$ui$workspace$libraries$get_library_summary$$($local_library_summary$jscomp$5$$);var $empty_library_QMARK_$$=$APP.$cljs$core$boolean$0$$($cljs$cst$5604$is_empty$$.$cljs$core$IFn$_invoke$arity$1$($local_library_summary$jscomp$5$$)),$selected$jscomp$144$$=$app$main$ui$hooks$use_shared_state$$($APP.$cljs$cst$4127$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$),
$dependencies$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shared_libraries$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$cljs$cst$5605$library_file_ids$$),$APP.$cljs$core$vals$$($shared_libraries$$)))}),$library_names$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shared_libraries$$)],
function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$935_p__77983$$){var $map__77984__$1_name$jscomp$440$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$935_p__77983$$);$id$jscomp$935_p__77983$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77984__$1_name$jscomp$440$$,$APP.$cljs$cst$266$id$$);$map__77984__$1_name$jscomp$440$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77984__$1_name$jscomp$440$$,
$APP.$cljs$cst$725$name$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$935_p__77983$$,$map__77984__$1_name$jscomp$440$$],null)},$APP.$cljs$core$vals$$($shared_libraries$$)))}),$find_connected_to$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dependencies$$)],function($library_id$jscomp$55$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__77985_v$jscomp$662$$){var $k$jscomp$690$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77985_v$jscomp$662$$,0,null);$p__77985_v$jscomp$662$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77985_v$jscomp$662$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($p__77985_v$jscomp$662$$,$library_id$jscomp$55$$)?$k$jscomp$690$$:null},$dependencies$$)}),$shared_libraries__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shared_libraries$$),$APP.$rumext$v2$adapt$$($linked_libraries$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$),$APP.$rumext$v2$adapt$$($search_term$jscomp$3$$)],function(){return $APP.$cljs$core$truth_$$($shared_libraries$$)?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$,$APP.$cljs$cst$725$name$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77968_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__77968_SHARP_$$,$cljs$cst$5606$connected_to_names$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($library_names$$,$cljs$cst$5607$connected_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__77968_SHARP_$$)))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77967_SHARP_$$){var $JSCompiler_temp_const$jscomp$1759$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__77991$jscomp$inline_8808_JSCompiler_inline_result$jscomp$1761$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77967_SHARP_$$);$G__77991$jscomp$inline_8808_JSCompiler_inline_result$jscomp$1761$$=
$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$?$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$($G__77991$jscomp$inline_8808_JSCompiler_inline_result$jscomp$1761$$):$find_connected_to$$($G__77991$jscomp$inline_8808_JSCompiler_inline_result$jscomp$1761$$);return $JSCompiler_temp_const$jscomp$1759$$.call($APP.$cljs$core$assoc$$,$p1__77967_SHARP_$$,$cljs$cst$5607$connected_to$$,$G__77991$jscomp$inline_8808_JSCompiler_inline_result$jscomp$1761$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77966_SHARP_$$){return $app$util$strings$matches_search$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__77966_SHARP_$$),
$search_term$jscomp$3$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77965_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($linked_libraries$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77965_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77964_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77964_SHARP_$$),$file_id$jscomp$374$$)},
$APP.$cljs$core$vals$$($shared_libraries$$))))))):null}),$linked_libraries__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($linked_libraries$$),$APP.$rumext$v2$adapt$$($find_connected_to$$),$APP.$rumext$v2$adapt$$($library_names$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$,$APP.$cljs$cst$725$name$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77970_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__77970_SHARP_$$,
$cljs$cst$5606$connected_to_names$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($library_names$$,$cljs$cst$5607$connected_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__77970_SHARP_$$)))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77969_SHARP_$$){var $JSCompiler_temp_const$jscomp$1762$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__77994$jscomp$inline_8810_JSCompiler_inline_result$jscomp$1764$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77969_SHARP_$$);
$G__77994$jscomp$inline_8810_JSCompiler_inline_result$jscomp$1764$$=$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$?$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$($G__77994$jscomp$inline_8810_JSCompiler_inline_result$jscomp$1764$$):$find_connected_to$$($G__77994$jscomp$inline_8810_JSCompiler_inline_result$jscomp$1764$$);return $JSCompiler_temp_const$jscomp$1762$$.call($APP.$cljs$core$assoc$$,$p1__77969_SHARP_$$,$cljs$cst$5607$connected_to$$,$G__77994$jscomp$inline_8810_JSCompiler_inline_result$jscomp$1764$$)},
$APP.$cljs$core$vals$$($linked_libraries$$))))}),$linked_libraries_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($linked_libraries__$1$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,$linked_libraries__$1$$)}),$importing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$sample_libraries$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"penpot-design-system",$APP.$cljs$cst$725$name$$,"Design system example"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"wireframing-kit",$APP.$cljs$cst$725$name$$,"Wireframe library"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"whiteboarding-kit",
$APP.$cljs$cst$725$name$$,"Whiteboarding Kit"],null)],null)}),$change_search_term$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$331$$){return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$$,$event$jscomp$331$$)}),$link_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],function($G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$){$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$=
$APP.$app$util$dom$get_current_target$$($G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$);$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$=$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$==null?null:$APP.$app$util$dom$get_data$$($G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$,"library-id");$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$=
$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$==null?null:$APP.$app$common$uuid$parse$$($G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$);$APP.$cljs$core$reset_BANG_$$($selected$jscomp$144$$,$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$link_file_to_library$$($file_id$jscomp$374$$,
$G__77996$jscomp$inline_8812_G__77996__$1$jscomp$inline_8813_event$jscomp$332_library_id$jscomp$56$$))}),$unlink_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],function($G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$){$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$=$APP.$app$util$dom$get_current_target$$($G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$);
$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$=$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$==null?null:$APP.$app$util$dom$get_data$$($G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$,"library-id");$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$=$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$==
null?null:$APP.$app$common$uuid$parse$$($G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$,$APP.$cljs$core$_deref$$($selected$jscomp$144$$))&&$APP.$cljs$core$reset_BANG_$$($selected$jscomp$144$$,$APP.$cljs$cst$208$file$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$unlink_file_from_library$$($file_id$jscomp$374$$,
$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$374$$,$G__78001$jscomp$inline_8815_G__78001__$1$jscomp$inline_8816_event$jscomp$333_library_id$jscomp$57$$,null,null)]))}),$import_tokens$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],
function($G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$){$G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$=$APP.$app$util$dom$get_current_target$$($G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$);$G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$=$G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$==
null?null:$APP.$app$util$dom$get_data$$($G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$,"library-id");$G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$=$G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$==null?null:$APP.$app$common$uuid$parse$$($G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5603$tokens_SLASH_import_from_library$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$374$$,$APP.$cljs$cst$3966$library_id$$,$G__78002$jscomp$inline_8818_G__78002__$1$jscomp$inline_8819_event$jscomp$334_library_id$jscomp$58$$],null)))}),$on_delete_accept$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$374$$,
!1),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3971$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$374$$],null))]))}),$on_delete_cancel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3971$libraries_dialog$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$374$$],null)))}),$publish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],function($event$jscomp$335_input_node$jscomp$6$$){function $cancel_publish$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3971$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$374$$],null)))}function $publish_library$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$374$$,!0))}$event$jscomp$335_input_node$jscomp$6$$=$APP.$app$util$dom$get_target$$($event$jscomp$335_input_node$jscomp$6$$);$empty_library_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.publish-empty-library.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.publish-empty-library.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.publish-empty-library.accept"),$APP.$cljs$cst$2479$on_accept$$,$publish_library$$,$APP.$cljs$cst$5608$on_cancel$$,
$cancel_publish$$],null))):$publish_library$$();return $APP.$app$util$dom$blur_BANG_$$($event$jscomp$335_input_node$jscomp$6$$)}),$unpublish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5609$delete_shared_libraries$$,
$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$file_id$jscomp$374$$]),$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$5610$unpublish$$,$APP.$cljs$cst$2479$on_accept$$,$on_delete_accept$$,$APP.$cljs$cst$5608$on_cancel$$,$on_delete_cancel$$,$APP.$cljs$cst$5611$count_libraries$$,1],null)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__libraries-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__lib-section",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.in-this-file"),className:"main_ui_workspace_libraries__title-spacing-lib"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__section-list",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__section-list-item",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__item-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.file-library")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$library_description_STAR_$$,{summary:$local_library_summary$jscomp$5$$})})]}),$is_shared$jscomp$5_props_77977$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"secondary",type:"button",onClick:$unpublish$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.unpublish")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:$publish$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.publish")})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$123$$,$p__78004$$){var $map__78005__$1$$=$APP.$cljs$core$__destructure_map$$($p__78004$$),
$id$jscomp$936$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78005__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$441$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78005__$1$$,$APP.$cljs$cst$725$name$$),$data$jscomp$475$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78005__$1$$,$APP.$cljs$cst$142$data$$),$connected_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78005__$1$$,$cljs$cst$5607$connected_to$$),$connected_to_names$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78005__$1$$,
$cljs$cst$5606$connected_to_names$$);$out_arr__44124__auto__$jscomp$123$$.push(function(){var $disabled_QMARK_$jscomp$6$$=$APP.$cljs$core$some$$(function($p1__77975_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($linked_libraries_ids$$,$p1__77975_SHARP_$$)},$connected_to$$),$has_tokens_QMARK_$$=function(){var $and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$=$APP.$cljs$core$__destructure_map$$($map__78005__$1$$);$and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$,$APP.$cljs$cst$142$data$$);$and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$,
$APP.$cljs$cst$2139$tokens_lib$$);$and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$)?$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$empty_lib_QMARK_$$($and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$)):
null;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1214$token_import_from_library$$):$and__5023__auto__$jscomp$739_data$jscomp$inline_8823_map__77963__$1$jscomp$inline_8822_temp__5825__auto__$jscomp$inline_8824$$}();return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"library-item",className:"main_ui_workspace_libraries__section-list-item",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__item-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-name "+($APP.$cljs$core$truth_$$($has_tokens_QMARK_$$)?"main_ui_workspace_libraries__item-name-short":""),children:$name$jscomp$441$$}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:function(){var $summary__$1$$=$app$main$ui$workspace$libraries$get_library_summary$$($data$jscomp$475$$);
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$library_description_STAR_$$,{summary:$summary__$1$$}),$APP.$cljs$core$seq$$($connected_to$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__connected-to-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{children:["(",$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.connected-to")," "]}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_libraries__connected-to-values",children:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$connected_to_names$$)}),(0,$APP.$rumext$v2$jsx$$)("span",{children:")"})]}):null]})}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__library-actions",children:[$has_tokens_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-tokens"),
icon:"import-export","data-library-id":""+($id$jscomp$936$$??""),variant:"secondary",onClick:$import_tokens$$}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.unlink-library-btn"),icon:"detach","data-library-id":""+($id$jscomp$936$$??""),variant:"secondary",disabled:$disabled_QMARK_$jscomp$6$$,onClick:$unlink_library$$})]})]},""+($id$jscomp$936$$??
""))}());return $out_arr__44124__auto__$jscomp$123$$},[],$linked_libraries__$1$$)]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__shared-section",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.shared-libraries"),className:"main_ui_workspace_libraries__title-spacing-lib"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,
{onChange:$change_search_term$$,value:$search_term$jscomp$3$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.search-shared-libraries"),iconId:"search"}),$APP.$cljs$core$seq$$($shared_libraries__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list-shared",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$124$$,$id$jscomp$937_p__78012$$){var $JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$937_p__78012$$);$id$jscomp$937_p__78012$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$,$APP.$cljs$cst$266$id$$);var $JSCompiler_temp_const$jscomp$1765_name$jscomp$442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$,$APP.$cljs$cst$725$name$$),$JSCompiler_temp_const$jscomp$1766$$=
$out_arr__44124__auto__$jscomp$124$$.push;$JSCompiler_temp_const$jscomp$1765_name$jscomp$442$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-name",children:$JSCompiler_temp_const$jscomp$1765_name$jscomp$442$$});$JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$=$app$main$ui$workspace$libraries$adapt_backend_summary$$($APP.$cljs$cst$3982$library_summary$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$));
$JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$library_description_STAR_$$,{summary:$JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$});$JSCompiler_temp_const$jscomp$1766$$.call($out_arr__44124__auto__$jscomp$124$$,(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"library-item",className:"main_ui_workspace_libraries__section-list-item",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__item-content",children:[$JSCompiler_temp_const$jscomp$1765_name$jscomp$442$$,(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:$JSCompiler_inline_result$jscomp$1768_map__78013__$1_summary__$1$jscomp$inline_8826$$})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_libraries__item-button-shared",variant:"secondary","data-library-id":""+($id$jscomp$937_p__78012$$??
""),icon:"add","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.shared-library-btn"),onClick:$link_library$$})]},""+($id$jscomp$937_p__78012$$??"")));return $out_arr__44124__auto__$jscomp$124$$},[],$shared_libraries__$1$$)}):$APP.$cljs$core$empty_QMARK_$$($shared_libraries__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list-empty",children:$shared_libraries__$1$$==null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.loading"):
$APP.$cuerdas$core$empty_QMARK_$$($search_term$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__sample-libraries-info",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.empty.no-libraries"),(0,$APP.$rumext$v2$jsx$$)("a",{target:"_blank",href:"https://penpot.app/libraries-templates",className:"main_ui_workspace_libraries__sample-libraries-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.empty.some-templates")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__sample-libraries-container",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.empty.add-some"),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$125$$,$library$jscomp$35$$){$out_arr__44124__auto__$jscomp$125$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$sample_library_entry_STAR_$$,{library:$library$jscomp$35$$,importing:$importing_STAR_$$},
""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$35$$)??"")));return $out_arr__44124__auto__$jscomp$125$$},[],$sample_libraries$$)]})]}):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.no-matches-for",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$search_term$jscomp$3$$]))}):null]})]})};
$app$main$ui$workspace$libraries$extract_assets$$=function($color_ids_colors$jscomp$12_file_data$jscomp$114$$,$library$jscomp$36$$,$summary_QMARK_$$){function $truncate$jscomp$14$$($asset_type$jscomp$13$$,$items$jscomp$58$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($summary_QMARK_$$)?$APP.$cljs$core$count$$($items$jscomp$58$$)>5:$summary_QMARK_$$)?($exceeded$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($exceeded$$.$cljs$core$IDeref$_deref$arity$1$(null),
$asset_type$jscomp$13$$,!0)),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(5,$items$jscomp$58$$)):$items$jscomp$58$$}var $exceeded$$=$APP.$cljs$core$volatile_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1638$components$$,!1,$APP.$cljs$cst$2212$colors$$,!1,$APP.$cljs$cst$2215$typographies$$,!1],null)),$assets$jscomp$2_typographies$jscomp$3_typography_ids$$=$APP.$app$main$data$workspace$libraries$assets_need_sync$cljs$0core$0IFn$0_invoke$0arity$03$$($library$jscomp$36$$,
$color_ids_colors$jscomp$12_file_data$jscomp$114$$,null),$component_ids$jscomp$8_components$jscomp$10$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2544$asset_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78015_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2545$asset_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78015_SHARP_$$),
$APP.$cljs$cst$1625$component$$)},$assets$jscomp$2_typographies$jscomp$3_typography_ids$$)));$color_ids_colors$jscomp$12_file_data$jscomp$114$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2544$asset_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78016_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2545$asset_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78016_SHARP_$$),
$APP.$cljs$cst$1298$color$$)},$assets$jscomp$2_typographies$jscomp$3_typography_ids$$)));$assets$jscomp$2_typographies$jscomp$3_typography_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2544$asset_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78017_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2545$asset_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78017_SHARP_$$),
$APP.$cljs$cst$1981$typography$$)},$assets$jscomp$2_typographies$jscomp$3_typography_ids$$)));$component_ids$jscomp$8_components$jscomp$10$$=$truncate$jscomp$14$$($APP.$cljs$cst$1638$components$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78019_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78019_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78018_SHARP_$$){return $APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$36$$),
$p1__78018_SHARP_$$)},$component_ids$jscomp$8_components$jscomp$10$$)));$color_ids_colors$jscomp$12_file_data$jscomp$114$$=$truncate$jscomp$14$$($APP.$cljs$cst$2212$colors$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78021_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78021_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78020_SHARP_$$){return $APP.$app$common$types$library$get_color$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$36$$),
$p1__78020_SHARP_$$)},$color_ids_colors$jscomp$12_file_data$jscomp$114$$)));$assets$jscomp$2_typographies$jscomp$3_typography_ids$$=$truncate$jscomp$14$$($APP.$cljs$cst$2215$typographies$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78023_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78023_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78022_SHARP_$$){return $APP.$app$common$types$typographies_list$get_typography$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$36$$),
$p1__78022_SHARP_$$)},$assets$jscomp$2_typographies$jscomp$3_typography_ids$$)));return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$library$jscomp$36$$,$APP.$cljs$core$_deref$$($exceeded$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1638$components$$,$component_ids$jscomp$8_components$jscomp$10$$,$APP.$cljs$cst$2212$colors$$,$color_ids_colors$jscomp$12_file_data$jscomp$114$$,$APP.$cljs$cst$2215$typographies$$,$assets$jscomp$2_typographies$jscomp$3_typography_ids$$],
null)],null)};
$app$main$ui$workspace$libraries$updates_tab_STAR_$$=function($libs_assets_props_78041$$){var $file_id$jscomp$375$$=$libs_assets_props_78041$$.fileId,$libraries$jscomp$138$$=$libs_assets_props_78041$$.libraries,$summary_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$summary_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($summary_QMARK__STAR_$$),$updating_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$updating_library$$),$file_data$jscomp$115$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_data$$),
$see_all_assets$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($summary_QMARK__STAR_$$,!1)});$libs_assets_props_78041$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_data$jscomp$115$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$138$$),$APP.$rumext$v2$adapt$$($summary_QMARK__STAR_$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($components$jscomp$11_map__78061_p__78057$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$11_map__78061_p__78057$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$11_map__78061_p__78057$$,1,null);$components$jscomp$11_map__78061_p__78057$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$11_map__78061_p__78057$$,2,null);var $map__78061__$1_typographies$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($components$jscomp$11_map__78061_p__78057$$);$components$jscomp$11_map__78061_p__78057$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78061__$1_typographies$jscomp$4$$,
$APP.$cljs$cst$1638$components$$);var $colors$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78061__$1_typographies$jscomp$4$$,$APP.$cljs$cst$2212$colors$$);$map__78061__$1_typographies$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78061__$1_typographies$jscomp$4$$,$APP.$cljs$cst$2215$typographies$$);return $APP.$cljs$core$seq$$($components$jscomp$11_map__78061_p__78057$$)||$APP.$cljs$core$seq$$($colors$jscomp$13$$)||$APP.$cljs$core$seq$$($map__78061__$1_typographies$jscomp$4$$)},
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78029_SHARP_$$){return $app$main$ui$workspace$libraries$extract_assets$$($file_data$jscomp$115$$,$p1__78029_SHARP_$$,$summary_QMARK_$jscomp$1$$)},$APP.$cljs$core$vals$$($libraries$jscomp$138$$)))});var $update$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$375$$)],function($G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$){if($APP.$cljs$core$truth_$$($updating_QMARK_$jscomp$2$$))return null;
$G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$=$APP.$app$util$dom$get_current_target$$($G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$);$G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$=$G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$==null?null:$APP.$app$util$dom$get_data$$($G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$,
"library-id");$G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$=$G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$==null?null:$APP.$app$common$uuid$parse$$($G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$);return $APP.$cljs$core$truth_$$($G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$libraries$set_updating_library$$(!0),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$375$$,$G__78064$jscomp$inline_8828_G__78064__$1$jscomp$inline_8829_event$jscomp$336_library_id$jscomp$59$$,null,null)])):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__updates-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__update-section",children:$APP.$cljs$core$empty_QMARK_$$($libs_assets_props_78041$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"library",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.no-libraries-need-sync")})}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.library-updates")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$126$$,$components$jscomp$12_map__78072_p__78067$$){var $id$jscomp$938_map__78071$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$12_map__78072_p__78067$$,0,null),$map__78071__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$938_map__78071$$);$id$jscomp$938_map__78071$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78071__$1$$,
$APP.$cljs$cst$266$id$$);var $name$jscomp$443$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78071__$1$$,$APP.$cljs$cst$725$name$$),$exceeded$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$12_map__78072_p__78067$$,1,null);$components$jscomp$12_map__78072_p__78067$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$12_map__78072_p__78067$$,2,null);var $map__78072__$1_typographies$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($components$jscomp$12_map__78072_p__78067$$);
$components$jscomp$12_map__78072_p__78067$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78072__$1_typographies$jscomp$5$$,$APP.$cljs$cst$1638$components$$);var $colors$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78072__$1_typographies$jscomp$5$$,$APP.$cljs$cst$2212$colors$$);$map__78072__$1_typographies$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78072__$1_typographies$jscomp$5$$,$APP.$cljs$cst$2215$typographies$$);$out_arr__44124__auto__$jscomp$126$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__section-list-item",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__item-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-name-long",children:$name$jscomp$443$$}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:$app$main$ui$workspace$libraries$describe_library$$($APP.$cljs$core$count$$($components$jscomp$12_map__78072_p__78067$$),
$APP.$cljs$core$count$$($colors$jscomp$14$$),$APP.$cljs$core$count$$($map__78072__$1_typographies$jscomp$5$$))})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_workspace_libraries__item-update",disabled:$updating_QMARK_$jscomp$2$$,variant:"primary","data-library-id":""+($id$jscomp$938_map__78071$$??""),onClick:$update$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.update")}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__libraries-updates",children:[$APP.$cljs$core$empty_QMARK_$$($components$jscomp$12_map__78072_p__78067$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-column",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$15$$,$component$jscomp$123$$){var $JSCompiler_temp_const$jscomp$1769$$=$out_arr__44124__auto____$1$jscomp$15$$.push;var $JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$=
$APP.$app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__78071__$1$$),$component$jscomp$123$$);var $root_shape$jscomp$inline_8832$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__78071__$1$$),$JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$);$JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg$$,{"root-shape":$root_shape$jscomp$inline_8832$$,"class":"main_ui_workspace_libraries__component-svg",objects:$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$),
className:"main_ui_workspace_libraries__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$)})})]});$JSCompiler_temp_const$jscomp$1769$$.call($out_arr__44124__auto____$1$jscomp$15$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:$JSCompiler_inline_result$jscomp$1771_component__$1$jscomp$inline_8831$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$123$$)??
"")));return $out_arr__44124__auto____$1$jscomp$15$$},[],$components$jscomp$12_map__78072_p__78067$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block main_ui_workspace_libraries__ellipsis",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_libraries__item-name",
children:"(...)"})})},$APP.$app$common$uuid$next$$()):null]}),$APP.$cljs$core$empty_QMARK_$$($colors$jscomp$14$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--bullet-size":"24px"},className:"main_ui_workspace_libraries__libraries-updates-column",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$16$$,$JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$){var $JSCompiler_temp_const$jscomp$1772$$=$out_arr__44124__auto____$1$jscomp$16$$.push,
$default_name$jscomp$inline_8834$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$))?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$139$type$$],null))):
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$))?$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$):$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$);$JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",
children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{color:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$),$APP.$cljs$cst$1734$opacity$$,
$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$)],null)}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__name-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$),className:"main_ui_workspace_libraries__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$)}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$),$default_name$jscomp$inline_8834$$)?null:(0,$APP.$rumext$v2$jsx$$)("span",{className:"color-value",children:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$)})]})]})},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$)??
""));$JSCompiler_temp_const$jscomp$1772$$.call($out_arr__44124__auto____$1$jscomp$16$$,$JSCompiler_inline_result$jscomp$1774_color$jscomp$153$$);return $out_arr__44124__auto____$1$jscomp$16$$},[],$colors$jscomp$14$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block.ellipsis",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_libraries__item-name",children:"(...)"})})},$APP.$app$common$uuid$next$$()):null]}),$APP.$cljs$core$empty_QMARK_$$($map__78072__$1_typographies$jscomp$5$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-column",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$17$$,$typography$jscomp$30$$){$out_arr__44124__auto____$1$jscomp$17$$.push((0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$)},children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$),className:"main_ui_workspace_libraries__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$)})})]})},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$)??"")));return $out_arr__44124__auto____$1$jscomp$17$$},
[],$map__78072__$1_typographies$jscomp$5$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block.ellipsis",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_libraries__item-name",children:"(...)"})})},$APP.$app$common$uuid$next$$()):
null]})]}),$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$)>0||$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$)>0||$APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$)>0?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link_button$link_button$$,{"on-click":$see_all_assets$$,"class":"main_ui_workspace_libraries__libraries-updates-see-all",value:["(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.update.see-all-changes")),
")"].join("")}):null]},""+($id$jscomp$938_map__78071$$??"")));return $out_arr__44124__auto__$jscomp$126$$},[],$libs_assets_props_78041$$)})]})})})};
$app$main$ui$workspace$libraries$libraries_dialog$$=function($close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$){$close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$=$APP.$rumext$v2$util$wrap_props$$($close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$);$close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$=$APP.$cljs$core$__destructure_map$$($close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$);
var $starting_tab$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$,$APP.$cljs$cst$3972$starting_tab$$),$file_id$jscomp$376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$,$APP.$cljs$cst$1644$file_id$$),$files$jscomp$26$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$);$close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$26$$,$file_id$jscomp$376$$);var $JSCompiler_inline_result$jscomp$1777_shared_QMARK_$jscomp$4$$=$APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$),$linked_libraries$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$26$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function(){return $APP.$app$main$refs$select_libraries$$($files$jscomp$26$$,
$file_id$jscomp$376$$)}),$linked_libraries__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($linked_libraries$jscomp$1$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function(){return $APP.$app$common$data$removem$$(function($lib$jscomp$13_p__78095$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lib$jscomp$13_p__78095$$,0,null);$lib$jscomp$13_p__78095$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lib$jscomp$13_p__78095$$,
1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$13_p__78095$$),$file_id$jscomp$376$$)},$linked_libraries$jscomp$1$$)}),$shared_libraries$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$shared_files$$);$close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$337$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_target$$($event$jscomp$337$$),
$APP.$app$util$dom$get_current_target$$($event$jscomp$337$$))?$APP.$app$main$data$modal$hide_BANG_$$():null});var $JSCompiler_temp_const$jscomp$1776_close_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),$selected_tab_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($starting_tab$$,"libraries")}),$selected_tab$$=$APP.$cljs$core$_deref$$($selected_tab_STAR_$$),
$on_change_tab$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78092_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected_tab_STAR_$$,$p1__78092_SHARP_$$)}),$tabs$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.libraries"),
$APP.$cljs$cst$266$id$$,"libraries"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.updates"),$APP.$cljs$cst$266$id$$,"updates"],null)],null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});$JSCompiler_temp_const$jscomp$1776_close_dialog$$=
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_libraries__close-btn",onClick:$JSCompiler_temp_const$jscomp$1776_close_dialog$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),variant:"ghost",icon:"close"});var $JSCompiler_temp_const$jscomp$1775$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.libraries")});
a:switch($selected_tab$$){case "libraries":$JSCompiler_inline_result$jscomp$1777_shared_QMARK_$jscomp$4$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$libraries_tab_STAR_$$,{isShared:$JSCompiler_inline_result$jscomp$1777_shared_QMARK_$jscomp$4$$,linkedLibraries:$linked_libraries__$1$jscomp$1$$,sharedLibraries:$shared_libraries$jscomp$1$$});break a;case "updates":$JSCompiler_inline_result$jscomp$1777_shared_QMARK_$jscomp$4$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$updates_tab_STAR_$$,
{fileId:$file_id$jscomp$376$$,libraries:$linked_libraries__$1$jscomp$1$$});break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($selected_tab$$)].join(""));}return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$close_dialog_outside_file$jscomp$159_map__78094_map__78094__$1_props_78093$$,"data-testid":"libraries-modal",className:"main_ui_workspace_libraries__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__modal-dialog",
children:[$JSCompiler_temp_const$jscomp$1776_close_dialog$$,$JSCompiler_temp_const$jscomp$1775$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$4$$,selected:$selected_tab$$,onChange:$on_change_tab$jscomp$1$$,children:$JSCompiler_inline_result$jscomp$1777_shared_QMARK_$jscomp$4$$})]})})};
$app$main$ui$workspace$libraries$v2_info_dialog$$=function(){var $handle_gotit_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5612$v2_info_shown$$,!0],null)))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__modal-overlay",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__modal-dialog main_ui_workspace_libraries__modal-v2-info",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__modal-v2-title",children:"IMPORTANT INFORMATION ABOUT NEW COMPONENTS"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__info-block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"One physical source of truth"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block-content",children:["Main components are now found at the design space. They act as a single source ",
"of truth and can be worked on with their copies. This ensures consistency and ","allows better control and synchronization."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_2$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"Swap components"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__info-block-content",children:["Now, you can replace one component copy with another within your libraries. ","The swap components functionality streamlines making changes, testing ","variations, or updating elements without extensive manual adjustments."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_3$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"Graphic assets no longer exist"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block-content",children:["Graphic assets now disappear, so that all graphic assets become components. ","This way, swapping between them is possible, and we avoid confusion about ","what should go in each typology."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_4$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"Main components page"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block-content",children:["You might find that a new page called 'Main components' has appeared in ","your file. On that page, you'll find all the main components that were ",
"created in your files previously to this new version."]})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-bottom",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_workspace_libraries__primary-button",variant:"primary",onClick:$handle_gotit_click$$,children:"I GOT IT"})})]})]})})};
$app$main$ui$workspace$nudge$on_keydown$$=function($event$jscomp$338$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$338$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$338$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$338$$),$APP.$app$main$data$modal$hide_BANG_$$()):null};
$app$main$ui$workspace$nudge$nudge_modal$$=function(){var $profile$jscomp$66$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$nudge$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1097$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$66$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3875$nudge$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1097$$)?$or__5025__auto__$jscomp$1097$$:
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3876$big$$,10,$APP.$cljs$cst$3877$small$$,1],null)}(),$update_big$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78109_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_nudge$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3876$big$$,$p1__78109_SHARP_$$],null)))}),$update_small$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78110_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_nudge$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3877$small$$,$p1__78110_SHARP_$$],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$APP.$goog$events$listen$$(document,"keydown",$app$main$ui$workspace$nudge$on_keydown$$))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_nudge__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__modal-container",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_workspace_nudge__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.nudge-title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_nudge__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"nudge-small",className:"main_ui_workspace_nudge__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.small-nudge")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,id:"nudge-small",value:$APP.$cljs$cst$3877$small$$.$cljs$core$IFn$_invoke$arity$1$($nudge$jscomp$3$$),onChange:$update_small$$})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"nudge-big",className:"main_ui_workspace_nudge__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.big-nudge")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,id:"nudge-big",value:$APP.$cljs$cst$3876$big$$.$cljs$core$IFn$_invoke$arity$1$($nudge$jscomp$3$$),onChange:$update_big$$})]})]})]})})};
$app$main$ui$workspace$color_palette$recent_colors_palette_STAR_$$=function($props_77976$$){var $libraries$jscomp$139$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$colors$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_colors$$),$colors__$1$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$16$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$139$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__77979__$1_p__77978$$){$map__77979__$1_p__77978$$=
$APP.$cljs$core$__destructure_map$$($map__77979__$1_p__77978$$);var $G__77980$jscomp$inline_13511_ref_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77979__$1_p__77978$$,$APP.$cljs$cst$1735$ref_id$$),$or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77979__$1_p__77978$$,$APP.$cljs$cst$1736$ref_file$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__77980$jscomp$inline_13511_ref_id$jscomp$12$$)?$or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$:
$G__77980$jscomp$inline_13511_ref_id$jscomp$12$$)){var $fdata$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$139$$,$or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$),$APP.$cljs$cst$142$data$$);$G__77980$jscomp$inline_13511_ref_id$jscomp$12$$=$APP.$app$common$types$library$get_color$$($fdata$jscomp$22$$,$G__77980$jscomp$inline_13511_ref_id$jscomp$12$$);$or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$=$G__77980$jscomp$inline_13511_ref_id$jscomp$12$$==
null?null:$app$common$types$color$library_color__GT_color$$($G__77980$jscomp$inline_13511_ref_id$jscomp$12$$,$or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$)?$or__5025__auto__$jscomp$1099_ref_file$jscomp$12$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__77979__$1_p__77978$$,$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1736$ref_file$$]))}return $map__77979__$1_p__77978$$},
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$valid_color_QMARK_$$,$APP.$cljs$core$reverse$$($colors$jscomp$16$$))))});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$palette_STAR_$$,{...$props_77976$$,colors:$colors__$1$jscomp$3$$})};
$app$main$ui$workspace$color_palette$make_library_colors_ref$$=function($file_id$jscomp$377$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($files$jscomp$27$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$27$$,$file_id$jscomp$377$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2212$colors$$)},$APP.$app$main$refs$files$$)};
$app$main$ui$workspace$color_palette$file_color_palette_STAR_$$=function($props_77982$$){var $file_id$jscomp$378$$=$props_77982$$.fileId,$colors__$1$jscomp$4_colors_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$378$$)],function(){return $app$main$ui$workspace$color_palette$make_library_colors_ref$$($file_id$jscomp$378$$)}),$colors$jscomp$17$$=$APP.$rumext$v2$deref$$($colors__$1$jscomp$4_colors_ref$$);$colors__$1$jscomp$4_colors_ref$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$17$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$378$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77981_SHARP_$$){return $app$common$types$color$library_color__GT_color$$($p1__77981_SHARP_$$,$file_id$jscomp$378$$)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$valid_library_color_QMARK_$$,
$APP.$cljs$core$vals$$($colors$jscomp$17$$)))))});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$palette_STAR_$$,{...$props_77982$$,colors:$colors__$1$jscomp$4_colors_ref$$})};
$app$main$ui$workspace$color_palette_ctx_menu$extract_colors$$=function($map__77922__$1_p__77921$$){$map__77922__$1_p__77921$$=$APP.$cljs$core$__destructure_map$$($map__77922__$1_p__77921$$);var $colors$jscomp$18_data$jscomp$476$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77922__$1_p__77921$$,$APP.$cljs$cst$142$data$$);$colors$jscomp$18_data$jscomp$476$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$color_palette_ctx_menu$xf_COLON_sample_colors$$,
$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$18_data$jscomp$476$$));return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__77922__$1_p__77921$$,$APP.$cljs$cst$2212$colors$$,$colors$jscomp$18_data$jscomp$476$$),$APP.$cljs$cst$142$data$$)};
$app$main$ui$workspace$color_palette_ctx_menu$color_palette_ctx_menu_STAR_$$=function($local_colors_props_77924$$){var $show$jscomp$7$$=$local_colors_props_77924$$.show,$selected$jscomp$148$$=$local_colors_props_77924$$.selected,$on_close$jscomp$18$$=$local_colors_props_77924$$.onClose,$on_select$$=$local_colors_props_77924$$.onSelect,$recent_colors$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_colors$$),$libraries$jscomp$140$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),
$file_id$jscomp$380$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);$local_colors_props_77924$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$140$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$380$$)],function(){var $colors$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$140$$,
$file_id$jscomp$380$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2212$colors$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$color_palette_ctx_menu$xf_COLON_sample_colors$$,$colors$jscomp$19$$)});var $libraries__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$140$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$380$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$color_palette_ctx_menu$extract_colors$$,
$APP.$cljs$core$vals$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$140$$,$file_id$jscomp$380$$)))}),$recent_colors__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($recent_colors$jscomp$2$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$474$$,$color$jscomp$156$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$156$$,
$cljs$cst$5616$app_DOT_main_DOT_ui_DOT_workspace_DOT_color_palette_ctx_menu_SLASH_id$$,""+($index$jscomp$474$$??""))},$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(7,$APP.$cljs$core$reverse$$($recent_colors$jscomp$2$$))))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show$jscomp$7$$,"on-close":$on_close$jscomp$18$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_color_palette_ctx_menu__palette-menu",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$128$$,
$map__77936__$1_p__77935$$){$map__77936__$1_p__77935$$=$APP.$cljs$core$__destructure_map$$($map__77936__$1_p__77935$$);var $id$jscomp$939$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77936__$1_p__77935$$,$APP.$cljs$cst$266$id$$),$colors$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77936__$1_p__77935$$,$APP.$cljs$cst$2212$colors$$);$out_arr__44124__auto__$jscomp$128$$.push((0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_select$$,"data-palette":""+($id$jscomp$939$$??
""),className:"main_ui_workspace_color_palette_ctx_menu__palette-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$148$$,$id$jscomp$939$$)?"main_ui_workspace_color_palette_ctx_menu__selected":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__option-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name",children:""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__77936__$1_p__77935$$)??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($colors$jscomp$20$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$148$$,$id$jscomp$939$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_color_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"20px"},className:"main_ui_workspace_color_palette_ctx_menu__color-sample",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$18$$,$color$jscomp$157$$){$out_arr__44124__auto____$1$jscomp$18$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,
{mini:!0,color:$color$jscomp$157$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$157$$)??"")));return $out_arr__44124__auto____$1$jscomp$18$$},[],$colors$jscomp$20$$)})]})},"library-"+($id$jscomp$939$$??"")));return $out_arr__44124__auto__$jscomp$128$$},[],$libraries__$1$$),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_select$$,"data-palette":"file",className:"main_ui_workspace_color_palette_ctx_menu__file-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$148$$,
$APP.$cljs$cst$208$file$$)?"main_ui_workspace_color_palette_ctx_menu__selected":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__option-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name",
children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.file-library")??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($local_colors_props_77924$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$148$$,$APP.$cljs$cst$208$file$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__icon-wrapper",
children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"20px"},className:"main_ui_workspace_color_palette_ctx_menu__color-sample",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$129$$,$color$jscomp$158$$){$out_arr__44124__auto__$jscomp$129$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{mini:!0,color:$color$jscomp$158$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$158$$)??
"")));return $out_arr__44124__auto__$jscomp$129$$},[],$local_colors_props_77924$$)})]})}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_select$$,"data-palette":"recent",className:"main_ui_workspace_color_palette_ctx_menu__recent-colors main_ui_workspace_color_palette_ctx_menu__selected",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__option-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__library-name",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name",children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.recent-colors")??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($recent_colors__$1$jscomp$1$$)??
"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$148$$,$cljs$cst$5583$recent$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"20px"},className:"main_ui_workspace_color_palette_ctx_menu__color-sample",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$130$$,
$color$jscomp$159$$){$out_arr__44124__auto__$jscomp$130$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{mini:!0,color:$color$jscomp$159$$},""+($cljs$cst$5616$app_DOT_main_DOT_ui_DOT_workspace_DOT_color_palette_ctx_menu_SLASH_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$159$$)??"")));return $out_arr__44124__auto__$jscomp$130$$},[],$recent_colors__$1$jscomp$1$$)})]})})]})})};
$app$main$ui$workspace$text_palette$typography_item_STAR_$$=function($font_data$jscomp$11_props_78039$$){var $file_id$jscomp$381$$=$font_data$jscomp$11_props_78039$$.fileId,$size$jscomp$144$$=$font_data$jscomp$11_props_78039$$.size,$selected_ids$jscomp$7$$=$font_data$jscomp$11_props_78039$$.selectedIds,$current_file_id$jscomp$13$$=$font_data$jscomp$11_props_78039$$.currentFileId,$typography$jscomp$31$$=$font_data$jscomp$11_props_78039$$.typography;$font_data$jscomp$11_props_78039$$=$APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$));
var $font_variant_id$jscomp$17$$=$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),$variant_data$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78035_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78035_SHARP_$$),$font_variant_id$jscomp$17$$)},$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$11_props_78039$$)),
$handle_click$jscomp$3$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$31$$),$APP.$rumext$v2$adapt$$($selected_ids$jscomp$7$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$381$$),$APP.$rumext$v2$adapt$$($current_file_id$jscomp$13$$)],function(){var $attrs$jscomp$173$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1642$typography_ref_file$$,$file_id$jscomp$381$$,$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)],null),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($typography$jscomp$31$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]))]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-typography",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"text-palette",$APP.$cljs$cst$3933$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$381$$,$current_file_id$jscomp$13$$)],null)));return $APP.$cljs$core$run_BANG_$$(function($p1__78036_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_text_attrs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,$p1__78036_SHARP_$$,$APP.$cljs$cst$1594$editor$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_editor_state$$),$p1__78036_SHARP_$$),$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$173$$],null)))},$selected_ids$jscomp$7$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$handle_click$jscomp$3$$,className:"main_ui_workspace_text_palette__typography-item "+($size$jscomp$144$$<=72?"main_ui_workspace_text_palette__mid-item":
"")+" "+($size$jscomp$144$$<=64?"main_ui_workspace_text_palette__small-item":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)},
className:"main_ui_workspace_text_palette__typography-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_text_palette__typography-font",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$11_props_78039$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_text_palette__typography-data",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)),
"px | ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $or__5025__auto__$jscomp$1100$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant_data$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1100$$)?$or__5025__auto__$jscomp$1100$$:"--"}())].join("")})]})};
$app$main$ui$workspace$text_palette$palette_STAR_$$=function($props_78062_width__$1$jscomp$9$$){var $file_typographies$$=$props_78062_width__$1$jscomp$9$$.fileTypographies,$selected$jscomp$149$$=$props_78062_width__$1$jscomp$9$$.selected,$libraries$jscomp$141$$=$props_78062_width__$1$jscomp$9$$.libraries,$show_arrows_QMARK_$jscomp$1_width$jscomp$190$$=$props_78062_width__$1$jscomp$9$$.width,$size$jscomp$145$$=$props_78062_width__$1$jscomp$9$$.size,$selected_ids$jscomp$8$$=$props_78062_width__$1$jscomp$9$$.selectedIds,
$current_file_id$jscomp$14$$=$props_78062_width__$1$jscomp$9$$.currentFileId,$file_id$jscomp$382$$=function(){switch($selected$jscomp$149$$ instanceof $APP.$cljs$core$Keyword$$?$selected$jscomp$149$$.$fqn$:null){case "recent":return null;case "file":return $current_file_id$jscomp$14$$;default:return $selected$jscomp$149$$}}(),$current_typographies$$=function(){switch($selected$jscomp$149$$ instanceof $APP.$cljs$core$Keyword$$?$selected$jscomp$149$$.$fqn$:null){case "recent":return $APP.$cljs$core$PersistentVector$EMPTY$$;
case "file":return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78055_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78055_SHARP_$$))},$APP.$cljs$core$vals$$($file_typographies$$));default:return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78056_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78056_SHARP_$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$141$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selected$jscomp$149$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$],null))))}}(),$state$jscomp$1173$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$195$offset$$,0],null));$props_78062_width__$1$jscomp$9$$=$show_arrows_QMARK_$jscomp$1_width$jscomp$190$$-($size$jscomp$145$$<=64?164:$size$jscomp$145$$<=72?164:
132);var $on_wheel_visible$jscomp$2$$=$props_78062_width__$1$jscomp$9$$/144|0;$show_arrows_QMARK_$jscomp$1_width$jscomp$190$$=$APP.$cljs$core$count$$($current_typographies$$)>$on_wheel_visible$jscomp$2$$;var $offset$jscomp$207$$=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($state$jscomp$1173$$),0),$max_offset$jscomp$3$$=$APP.$cljs$core$count$$($current_typographies$$)-$on_wheel_visible$jscomp$2$$,$container$jscomp$84$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_left_arrow_click$jscomp$1$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_wheel_visible$jscomp$2$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1173$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$24_x__5110__auto__$jscomp$138$$){return $offset__$1$jscomp$24_x__5110__auto__$jscomp$138$$>0?(--$offset__$1$jscomp$24_x__5110__auto__$jscomp$138$$,$offset__$1$jscomp$24_x__5110__auto__$jscomp$138$$>
0?$offset__$1$jscomp$24_x__5110__auto__$jscomp$138$$:0):$offset__$1$jscomp$24_x__5110__auto__$jscomp$138$$})}),$on_right_arrow_click$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_wheel_visible$jscomp$2$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1173$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$25_y__5114__auto__$jscomp$77$$){return $offset__$1$jscomp$25_y__5114__auto__$jscomp$77$$<
$max_offset$jscomp$3$$?($offset__$1$jscomp$25_y__5114__auto__$jscomp$77$$+=1,$max_offset$jscomp$3$$<$offset__$1$jscomp$25_y__5114__auto__$jscomp$77$$?$max_offset$jscomp$3$$:$offset__$1$jscomp$25_y__5114__auto__$jscomp$77$$):$offset__$1$jscomp$25_y__5114__auto__$jscomp$77$$})});$on_wheel_visible$jscomp$2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$3$$)],function($event$jscomp$341_event__$1$jscomp$5$$){$event$jscomp$341_event__$1$jscomp$5$$=
$event$jscomp$341_event__$1$jscomp$5$$.nativeEvent;return $event$jscomp$341_event__$1$jscomp$5$$.deltaY+$event$jscomp$341_event__$1$jscomp$5$$.deltaX>0?$on_right_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_right_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$341_event__$1$jscomp$5$$):$on_right_arrow_click$jscomp$1$$($event$jscomp$341_event__$1$jscomp$5$$):$on_left_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_left_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$341_event__$1$jscomp$5$$):
$on_left_arrow_click$jscomp$1$$($event$jscomp$341_event__$1$jscomp$5$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_typographies$$)],function(){var $fonts$jscomp$29$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1757$font_id$$),$current_typographies$$);return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,
$fonts$jscomp$29$$)});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1173$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$84$$),"clientWidth"))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($props_78062_width__$1$jscomp$9$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$149$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1173$$)))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1173$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,0):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--height":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$145$$),
"px"].join("")},className:"main_ui_workspace_text_palette__text-palette",children:[$show_arrows_QMARK_$jscomp$1_width$jscomp$190$$?(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$207$$,0),onClick:$on_left_arrow_click$jscomp$1$$,className:"main_ui_workspace_text_palette__left-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",{ref:$container$jscomp$84$$,onWheel:$on_wheel_visible$jscomp$2$$,className:"main_ui_workspace_text_palette__text-palette-content",
children:$APP.$cljs$core$empty_QMARK_$$($current_typographies$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"absolute",left:"50%",top:"50%",transform:"translate(-50%, -50%)"},className:"main_ui_workspace_text_palette__text-palette-empty",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-typography-palette")}):(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"relative",maxWidth:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($props_78062_width__$1$jscomp$9$$),
"px"].join(""),right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(144*$offset$jscomp$207$$),"px"].join("")},className:"main_ui_workspace_text_palette__text-palette-inside",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$131$$,$item$jscomp$125_p__78075$$){var $idx$jscomp$117$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$125_p__78075$$,0,null);$item$jscomp$125_p__78075$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$125_p__78075$$,
1,null);$out_arr__44124__auto__$jscomp$131$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette$typography_item_STAR_$$,{fileId:$file_id$jscomp$382$$,currentFileId:$current_file_id$jscomp$14$$,selectedIds:$selected_ids$jscomp$8$$,typography:$item$jscomp$125_p__78075$$,size:$size$jscomp$145$$},$idx$jscomp$117$$));return $out_arr__44124__auto__$jscomp$131$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$current_typographies$$))})}),$show_arrows_QMARK_$jscomp$1_width$jscomp$190$$?
(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$207$$,$max_offset$jscomp$3$$),onClick:$on_right_arrow_click$jscomp$1$$,className:"main_ui_workspace_text_palette__right-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null]})};
$app$main$ui$workspace$text_palette_ctx_menu$text_palette_ctx_menu_STAR_$$=function($props_78116_show_menu$$){var $close_menu$$=$props_78116_show_menu$$.closeMenu,$selected$jscomp$151$$=$props_78116_show_menu$$.selected,$on_select_palette$$=$props_78116_show_menu$$.onSelectPalette;$props_78116_show_menu$$=$props_78116_show_menu$$.showMenu;var $typographies$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$libraries$jscomp$143$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$);
return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$props_78116_show_menu$$,"on-close":$close_menu$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_text_palette_ctx_menu__text-context-menu",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$132$$,$p__78117$$){var $idx$jscomp$118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78117$$,0,null),$cur_library$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78117$$,
1,null);$out_arr__44124__auto__$jscomp$132$$.push(function(){var $typographies__$1$$=$APP.$cljs$core$vals$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_library$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$],null)));return(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:function(){return $on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$):
$on_select_palette$$($cur_library$$)},className:"main_ui_workspace_text_palette_ctx_menu__palette-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$151$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$))?"main_ui_workspace_text_palette_ctx_menu__selected":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_text_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-name",
children:""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$)??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($typographies__$1$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$151$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__icon-wrapper",
children:$APP.$app$main$ui$icons$tick$$}):null]},["library-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($idx$jscomp$118$$)].join(""))}());return $out_arr__44124__auto__$jscomp$132$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$core$vals$$($libraries$jscomp$143$$))),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:function(){return $on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$208$file$$):
$on_select_palette$$($APP.$cljs$cst$208$file$$)},className:"main_ui_workspace_text_palette_ctx_menu__file-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$151$$,$APP.$cljs$cst$208$file$$)?"main_ui_workspace_text_palette_ctx_menu__selected":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_text_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.file-library")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($typographies$jscomp$6$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$151$$,$APP.$cljs$cst$208$file$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):null]})]})})};
$app$main$ui$workspace$palette$calculate_palette_style$$=function($rulers_QMARK_$jscomp$1$$){var $left_sidebar$jscomp$1_left_sidebar_size$$=$APP.$goog$dom$getElement$$("left-sidebar-aside");$left_sidebar$jscomp$1_left_sidebar_size$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($left_sidebar$jscomp$1_left_sidebar_size$$,"width"));return{paddingLeft:""+(($APP.$cljs$core$truth_$$($rulers_QMARK_$jscomp$1$$)?22:0)+($APP.$cljs$core$truth_$$($left_sidebar$jscomp$1_left_sidebar_size$$)?
$left_sidebar$jscomp$1_left_sidebar_size$$:318)+4+1??"")+"px",paddingRight:"322px"}};
$app$main$ui$workspace$palette$palette_STAR_$$=function($color_palette_QMARK__props_78130$$){var $map__78132_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$=$color_palette_QMARK__props_78130$$.onChangeSize,$hide_palettes_QMARK__layout$jscomp$15$$=$color_palette_QMARK__props_78130$$.layout;$color_palette_QMARK__props_78130$$=$APP.$cljs$cst$3715$colorpalette$$.$cljs$core$IFn$_invoke$arity$1$($hide_palettes_QMARK__layout$jscomp$15$$);var $text_palette_QMARK_$$=$APP.$cljs$cst$3740$textpalette$$.$cljs$core$IFn$_invoke$arity$1$($hide_palettes_QMARK__layout$jscomp$15$$);
$hide_palettes_QMARK__layout$jscomp$15$$=$APP.$cljs$cst$3726$hide_palettes$$.$cljs$core$IFn$_invoke$arity$1$($hide_palettes_QMARK__layout$jscomp$15$$);var $read_only_QMARK_$jscomp$10$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$container$jscomp$85$$=(0,$APP.$rumext$v2$use_ref$$)(null),$state_STAR_$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5615$show_menu$$,
!1],null)}),$show_menu_QMARK__state$jscomp$1174$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$9$$);$show_menu_QMARK__state$jscomp$1174$$=$cljs$cst$5615$show_menu$$.$cljs$core$IFn$_invoke$arity$1$($show_menu_QMARK__state$jscomp$1174$$);var $selected$jscomp$152$$=$app$main$ui$hooks$use_shared_state$$($APP.$cljs$cst$4127$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$),$selected_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$208$file$$),
$selected_text$$=$APP.$cljs$core$_deref$$($selected_text_STAR_$$),$on_select$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78129_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected$jscomp$152$$,$p1__78129_SHARP_$$)}),$rulers_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$),$vport$jscomp$9_vport_width$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$palette$ref_COLON_viewport$$);$vport$jscomp$9_vport_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$9_vport_width$$,
$APP.$cljs$cst$290$width$$);$map__78132_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$4751$palette$$,72,54,80,$APP.$cljs$cst$1511$y$$,!0,$APP.$cljs$cst$1563$bottom$$,$map__78132_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$);var $map__78132__$1_size$jscomp$147$$=$APP.$cljs$core$__destructure_map$$($map__78132_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$);$map__78132_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78132__$1_size$jscomp$147$$,$APP.$cljs$cst$4542$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78132__$1_size$jscomp$147$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78132__$1_size$jscomp$147$$,$APP.$cljs$cst$4544$on_pointer_move$$),$parent_ref$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78132__$1_size$jscomp$147$$,
$APP.$cljs$cst$4545$parent_ref$$);$map__78132__$1_size$jscomp$147$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78132__$1_size$jscomp$147$$,$APP.$cljs$cst$874$size$$);var $on_resize$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$85$$),
"clientWidth"))}),$on_close_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$assoc$$,$cljs$cst$5615$show_menu$$,!1)}),$on_select_palette$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select$jscomp$1$$)],function($G__78133_event$jscomp$342_value$jscomp$802$$){$G__78133_event$jscomp$342_value$jscomp$802$$=$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_current_target$$($G__78133_event$jscomp$342_value$jscomp$802$$),
"data-palette");$G__78133_event$jscomp$342_value$jscomp$802$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("file",$G__78133_event$jscomp$342_value$jscomp$802$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("recent",$G__78133_event$jscomp$342_value$jscomp$802$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__78133_event$jscomp$342_value$jscomp$802$$):$APP.$app$common$uuid$parse$$($G__78133_event$jscomp$342_value$jscomp$802$$);return $on_select$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_select$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78133_event$jscomp$342_value$jscomp$802$$):$on_select$jscomp$1$$($G__78133_event$jscomp$342_value$jscomp$802$$)}),$on_select_text_palette_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select$jscomp$1$$)],function($lib$jscomp$14$$){return $lib$jscomp$14$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$208$file$$,$lib$jscomp$14$$)?$APP.$cljs$core$reset_BANG_$$($selected_text_STAR_$$,
$APP.$cljs$cst$208$file$$):$APP.$cljs$core$reset_BANG_$$($selected_text_STAR_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$14$$))}),$toggle_palettes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1562$top$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),"fade-out-down");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3726$hide_palettes$$),
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar"))}),$on_select_color_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$343_node$jscomp$407$$){$event$jscomp$343_node$jscomp$407$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$343_node$jscomp$407$$);$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1562$top$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),
"fade-out-down");$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(300,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3726$hide_palettes$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3740$textpalette$$),$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3715$colorpalette$$),
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar")]))});return $APP.$app$util$dom$blur_BANG_$$($event$jscomp$343_node$jscomp$407$$)}),$on_select_text_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$344_node$jscomp$408$$){$event$jscomp$344_node$jscomp$408$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$344_node$jscomp$408$$);$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1562$top$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),
"fade-out-down");$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(300,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3726$hide_palettes$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3715$colorpalette$$),$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3740$textpalette$$),
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar")]))});return $APP.$app$util$dom$blur_BANG_$$($event$jscomp$344_node$jscomp$408$$)}),$any_palette_QMARK_$$=$APP.$cljs$core$truth_$$($color_palette_QMARK__props_78130$$)?$color_palette_QMARK__props_78130$$:$text_palette_QMARK_$$,$size_classname$$=$map__78132__$1_size$jscomp$147$$<=64?"main_ui_workspace_palette__small-palette":$map__78132__$1_size$jscomp$147$$<=72?"main_ui_workspace_palette__mid-palette":$map__78132__$1_size$jscomp$147$$<=
80?"main_ui_workspace_palette__big-palette":null;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$7$$=$APP.$goog$events$listen$$(window,"resize",$on_resize$$);return function(){return $APP.$goog$events$unlistenByKey$$($key1$jscomp$7$$)}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($parent_ref$jscomp$2$$),"clientWidth"))});return(0,$APP.$rumext$v2$jsx$$)("div",{id:"palette-wrapper",style:$app$main$ui$workspace$palette$calculate_palette_style$$($rulers_QMARK_$jscomp$2$$),"data-testid":"palette",className:"main_ui_workspace_palette__palette-wrapper",children:$read_only_QMARK_$jscomp$10$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$parent_ref$jscomp$2$$,style:{"--height":""+($map__78132__$1_size$jscomp$147$$??
"")+"px"},className:""+($size_classname$$??"")+" main_ui_workspace_palette__palettes "+(($APP.$cljs$core$truth_$$($any_palette_QMARK_$$)?"main_ui_workspace_palette__wide":"")+" "+($APP.$cljs$core$truth_$$($hide_palettes_QMARK__layout$jscomp$15$$)?"main_ui_workspace_palette__hidden-bts":"")),children:[(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__78132_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$1$$,onPointerMove:$on_pointer_move$jscomp$2$$,
className:"main_ui_workspace_palette__resize-area"}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:""+($size_classname$$??"")+" main_ui_workspace_palette__palette-btn-list "+($APP.$cljs$core$truth_$$($hide_palettes_QMARK__layout$jscomp$15$$)?"main_ui_workspace_palette__hidden-bts":""),children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_palette__palette-item",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.color-palette",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4808$toggle_colorpalette$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.color-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4808$toggle_colorpalette$$)])),onClick:$on_select_color_palette$$,className:"main_ui_workspace_palette__palette-btn "+
($APP.$cljs$core$truth_$$($color_palette_QMARK__props_78130$$)?"main_ui_workspace_palette__selected":""),children:$APP.$app$main$ui$icons$drop_icon$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_palette__palette-item",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4853$toggle_textpalette$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4853$toggle_textpalette$$)])),onClick:$on_select_text_palette$$,className:"main_ui_workspace_palette__palette-btn "+($APP.$cljs$core$truth_$$($text_palette_QMARK_$$)?"main_ui_workspace_palette__selected":""),children:$APP.$app$main$ui$icons$text_palette$$})})]}),$APP.$cljs$core$truth_$$($any_palette_QMARK_$$)?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$update$$,$cljs$cst$5615$show_menu$$,$APP.$cljs$core$not$$)},className:"main_ui_workspace_palette__palette-actions",children:$APP.$app$main$ui$icons$menu$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$container$jscomp$85$$,className:"main_ui_workspace_palette__palette",children:[$APP.$cljs$core$truth_$$($text_palette_QMARK_$$)?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette_ctx_menu$text_palette_ctx_menu_STAR_$$,{showMenu:$show_menu_QMARK__state$jscomp$1174$$,closeMenu:$on_close_menu$$,onSelectPalette:$on_select_text_palette_menu$$,selected:$selected_text$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette$text_palette_STAR_$$,{size:$map__78132__$1_size$jscomp$147$$,selected:$selected_text$$,width:$vport$jscomp$9_vport_width$$})]}):
null,$APP.$cljs$core$truth_$$($color_palette_QMARK__props_78130$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$color_palette_ctx_menu$color_palette_ctx_menu_STAR_$$,{show:$show_menu_QMARK__state$jscomp$1174$$,onClose:$on_close_menu$$,onSelect:$on_select_palette$jscomp$1$$,selected:$APP.$cljs$core$_deref$$($selected$jscomp$152$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$color_palette$color_palette_STAR_$$,{size:$map__78132__$1_size$jscomp$147$$,
selected:$APP.$cljs$core$_deref$$($selected$jscomp$152$$),width:$vport$jscomp$9_vport_width$$})]}):null]})]}):(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$toggle_palettes$$,"data-testid":"toggle-palettes-visibility",className:"main_ui_workspace_palette__handler",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_palette__handler-btn"})})]})})};
$app$main$ui$workspace$main_menu$shortcuts_STAR_$$=function($props_78124$$){return(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__shortcut",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$133$$,$sc$jscomp$10$$){$out_arr__44124__auto__$jscomp$133$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__shortcut-key",children:$sc$jscomp$10$$},$sc$jscomp$10$$));return $out_arr__44124__auto__$jscomp$133$$},
[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$workspace$shortcuts$get_tooltip$$($props_78124$$.id)))})};
$app$main$ui$workspace$main_menu$file_menu_STAR_$$=function($props_78155_shared_QMARK_$jscomp$5$$){var $on_close$jscomp$23$$=$props_78155_shared_QMARK_$jscomp$5$$.onClose,$file$jscomp$161$$=$props_78155_shared_QMARK_$jscomp$5$$.file,$file_id$jscomp$383$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$161$$);$props_78155_shared_QMARK_$jscomp$5$$=$APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$161$$);var $all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$153$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);$all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$=$APP.$cljs$core$filterv$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$,$APP.$app$common$uuid$zero$$));var $on_remove_shared_key_down_selected_frames$$=
$APP.$cljs$core$filterv$$(function($p1__78154_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected$jscomp$153$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78154_SHARP_$$))},$all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$),$frames$jscomp$26$$=$APP.$cljs$core$seq$$($on_remove_shared_key_down_selected_frames$$)?$on_remove_shared_key_down_selected_frames$$:$all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$;$all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);$all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$);var $on_remove_shared$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$383$$)],function($event$jscomp$376$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$376$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$376$$);
return $app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5609$delete_shared_libraries$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$5610$unpublish$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$file_id$jscomp$383$$]),$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$383$$,
!1))},$APP.$cljs$cst$5611$count_libraries$$,1],null))});$on_remove_shared_key_down_selected_frames$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_remove_shared$$)],function($event$jscomp$377$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$377$$))?$on_remove_shared$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove_shared$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$377$$):$on_remove_shared$$($event$jscomp$377$$):
null});var $on_add_shared$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$383$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$show_shared_dialog$$($file_id$jscomp$383$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$383$$,!0))}))}),$on_add_shared_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_add_shared$$)],
function($event$jscomp$378$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$378$$))?$on_add_shared$$.$cljs$core$IFn$_invoke$arity$1$?$on_add_shared$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$378$$):$on_add_shared$$($event$jscomp$378$$):null}),$on_show_version_history$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$383$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3719$document_history$$))}),
$on_show_version_history_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_show_version_history$$)],function($event$jscomp$379$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$379$$))?$on_show_version_history$$.$cljs$core$IFn$_invoke$arity$1$?$on_show_version_history$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$379$$):$on_show_version_history$$($event$jscomp$379$$):null}),$on_pin_version$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$create_version$$())}),
$on_pin_version_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_pin_version$$)],function($event$jscomp$380$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$380$$))?$on_pin_version$$.$cljs$core$IFn$_invoke$arity$1$?$on_pin_version$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$380$$):$on_pin_version$$($event$jscomp$380$$):null}),$on_export_shapes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$exports$assets$show_workspace_export_dialog$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1786$origin$$,"workspace:menu"],null)))}),$on_export_shapes_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_export_shapes$$)],function($event$jscomp$381$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$381$$))?$on_export_shapes$$.$cljs$core$IFn$_invoke$arity$1$?$on_export_shapes$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$381$$):$on_export_shapes$$($event$jscomp$381$$):null}),$on_export_file$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$161$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$exports$files$open_export_dialog$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$161$$],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:menu"],null)))}),$on_export_file_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_export_file$$)],function($event$jscomp$382$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$382$$))?$on_export_file$$.$cljs$core$IFn$_invoke$arity$1$?$on_export_file$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$382$$):$on_export_file$$($event$jscomp$382$$):null}),$on_export_frames$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frames$jscomp$26$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$exports$assets$show_workspace_export_frames_dialog$$($APP.$cljs$core$reverse$$($frames$jscomp$26$$)))}),$on_export_frames_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_export_frames$$)],function($event$jscomp$383$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$383$$))?$on_export_frames$$.$cljs$core$IFn$_invoke$arity$1$?
$on_export_frames$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$383$$):$on_export_frames$$($event$jscomp$383$$):null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-1",onClose:$on_close$jscomp$23$$,children:[$props_78155_shared_QMARK_$jscomp$5$$?$APP.$cljs$core$truth_$$($all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_remove_shared$$,onKeyDown:$on_remove_shared_key_down_selected_frames$$,id:"file-menu-remove-shared",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.unpublish-shared")})}):null:
$APP.$cljs$core$truth_$$($all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_add_shared$$,onKeyDown:$on_add_shared_key_down$$,id:"file-menu-add-shared",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.add-shared")})}):
null,$APP.$cljs$core$truth_$$($all_frames_can_edit$jscomp$4_objects$jscomp$770_perms$jscomp$2$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_pin_version$$,onKeyDown:$on_pin_version_key_down$$,
id:"file-menu-create-version",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.create-version-menu")})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_show_version_history$$,onKeyDown:$on_show_version_history_key_down$$,id:"file-menu-show-version-history",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.show-version-history")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4845$toggle_history$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"})]}):null,$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_export_shapes$$,onKeyDown:$on_export_shapes_key_down$$,id:"file-menu-export-shapes",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-shapes")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4125$export_shapes$$})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_export_file$$,onKeyDown:$on_export_file_key_down$$,"data-format":"binfile-v3",id:"file-menu-binary-file",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.download-binary-file")})}),
$APP.$cljs$core$seq$$($frames$jscomp$26$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_export_frames$$,onKeyDown:$on_export_frames_key_down$$,id:"file-menu-export-frames",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-frames")})}):
null]})};
$app$main$ui$workspace$main_menu$mcp_menu_STAR_$$=function($on_close$jscomp$25_props_78174$$){$on_close$jscomp$25_props_78174$$=$on_close$jscomp$25_props_78174$$.onClose;var $plugins_QMARK_$jscomp$1$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime"),$mcp_enabled_QMARK_$jscomp$1_on_nav_to_integrations_key_down_profile$jscomp$68$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$mcp_mcp_connection_show_enabled_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$mcp$$),
$tokens$jscomp$47$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$access_tokens$$),$expired_QMARK_$jscomp$2_expires_at$$=function(){var $G__78175__$1$$=$tokens$jscomp$47$$==null?null:$APP.$cljs$core$some$$(function($p1__78173_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78173_SHARP_$$),"mcp")?$p1__78173_SHARP_$$:null},$tokens$jscomp$47$$);return $G__78175__$1$$==null?null:$APP.$cljs$cst$5618$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($G__78175__$1$$)}();
$expired_QMARK_$jscomp$2_expires_at$$=$expired_QMARK_$jscomp$2_expires_at$$!=null&&$APP.$app$common$time$now$$()>$expired_QMARK_$jscomp$2_expires_at$$;$mcp_enabled_QMARK_$jscomp$1_on_nav_to_integrations_key_down_profile$jscomp$68$$=$APP.$cljs$cst$4335$mcp_enabled$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($mcp_enabled_QMARK_$jscomp$1_on_nav_to_integrations_key_down_profile$jscomp$68$$))===!0;$mcp_mcp_connection_show_enabled_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mcp_mcp_connection_show_enabled_QMARK_$$,
$APP.$cljs$cst$4327$connection_status$$);var $mcp_connected_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mcp_mcp_connection_show_enabled_QMARK_$$,"connected");$mcp_mcp_connection_show_enabled_QMARK_$$=$mcp_enabled_QMARK_$jscomp$1_on_nav_to_integrations_key_down_profile$jscomp$68$$&&$expired_QMARK_$jscomp$2_expires_at$$===!1;var $on_nav_to_integrations$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"manage-mpc-option",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("/#/settings/integrations")});$mcp_enabled_QMARK_$jscomp$1_on_nav_to_integrations_key_down_profile$jscomp$68$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$387$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$387$$))?
$on_nav_to_integrations$$.$cljs$core$IFn$_invoke$arity$0$?$on_nav_to_integrations$$.$cljs$core$IFn$_invoke$arity$0$():$on_nav_to_integrations$$():null});var $on_toggle_mcp_plugin$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $mcp_connected_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$mcp$user_disconnect_mcp$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"disconnect-mcp-plugin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null))])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$mcp$connect_mcp$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"connect-mcp-plugin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null))]))}),$on_toggle_mcp_plugin_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$388$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$388$$))?$on_toggle_mcp_plugin$$.$cljs$core$IFn$_invoke$arity$0$?$on_toggle_mcp_plugin$$.$cljs$core$IFn$_invoke$arity$0$():$on_toggle_mcp_plugin$$():null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu "+($plugins_QMARK_$jscomp$1$$?"":"main_ui_workspace_main_menu__pos-5")+" "+($plugins_QMARK_$jscomp$1$$?"main_ui_workspace_main_menu__pos-6":""),onClose:$on_close$jscomp$25_props_78174$$,children:[$mcp_mcp_connection_show_enabled_QMARK_$$&&!$expired_QMARK_$jscomp$2_expires_at$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{id:"mcp-menu-toggle-mcp-plugin",className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$on_toggle_mcp_plugin$$,onKeyDown:$on_toggle_mcp_plugin_key_down$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$mcp_connected_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.plugin.status.disconnect"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.plugin.status.connect")})}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{id:"mcp-menu-nav-to-integrations",className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_nav_to_integrations$$,onKeyDown:$mcp_enabled_QMARK_$jscomp$1_on_nav_to_integrations_key_down_profile$jscomp$68$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$mcp_mcp_connection_show_enabled_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.server.status.enabled"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.server.status.disabled")})})]})};
$app$main$ui$workspace$main_menu$menu_STAR_$$=function($props_78178_toggle_menu$$){var $layout$jscomp$19$$=$props_78178_toggle_menu$$.layout,$file$jscomp$162$$=$props_78178_toggle_menu$$.file,$profile$jscomp$69$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$mcp$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$mcp$$),$show_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_menu_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_menu_STAR_$$),$selected_sub_menu_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected_sub_menu$$=$APP.$cljs$core$_deref$$($selected_sub_menu_STAR_$$);$props_78178_toggle_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$389$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$389$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_menu_STAR_$$,$APP.$cljs$core$not$$);return $APP.$cljs$core$not$$($show_menu_QMARK_$jscomp$1$$)?$APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,
null):null});var $close_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$390$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$390$$);return $APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1)}),$close_sub_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$391$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$391$$);return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null)}),$close_all_menus$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null)}),$on_menu_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$392_menu$jscomp$1$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$392_menu$jscomp$1$$);$event$jscomp$392_menu$jscomp$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$392_menu$jscomp$1$$),
"testid"));return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,$event$jscomp$392_menu$jscomp$1$$)}),$on_power_up_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-pricing-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/pricing")}),$toggle_flag$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$393_flag$jscomp$13$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$393_flag$jscomp$13$$);$event$jscomp$393_flag$jscomp$13$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$393_flag$jscomp$13$$),
"testid"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($event$jscomp$393_flag$jscomp$13$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"));$APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null)}),$toggle_theme$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$394$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$394$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$toggle_theme$$())}),$toggle_render$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$69$$)],function($event$jscomp$395_next_renderer_renderer$jscomp$2$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$395_next_renderer_renderer$jscomp$2$$);$event$jscomp$395_next_renderer_renderer$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1106$$=
$APP.$cljs$cst$3105$renderer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$69$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1106$$)?$or__5025__auto__$jscomp$1106$$:$APP.$cljs$cst$1538$svg$$}();$event$jscomp$395_next_renderer_renderer$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$395_next_renderer_renderer$jscomp$2$$,$APP.$cljs$cst$3104$wasm$$)?$APP.$cljs$cst$1538$svg$$:$APP.$cljs$cst$3104$wasm$$;
var $ev_name$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$395_next_renderer_renderer$jscomp$2$$,$APP.$cljs$cst$3104$wasm$$)?"enable-webgl-rendering":"disable-webgl-rendering";return $APP.$cljs$core$truth_$$($APP.$app$config$external_feature_flag$$("renderer-hard-reload"))?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
$ev_name$jscomp$1$$,$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null))),$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){return $APP.$app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$1$(!0)},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3196$update_profile_props$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3105$renderer$$,$event$jscomp$395_next_renderer_renderer$jscomp$2$$],null)],null)))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$ev_name$jscomp$1$$,$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:menu"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3105$renderer$$,$event$jscomp$395_next_renderer_renderer$jscomp$2$$],null)),$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$395_next_renderer_renderer$jscomp$2$$,
$APP.$cljs$cst$3104$wasm$$)?"webgl.toast.webgl-render-enabled":"webgl.toast.webgl-render-disabled"))]))}),$open_plugins_manager$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$396$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$396$$);$APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1);$APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-plugins-manager",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4894$plugin_management$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}),$subscription$jscomp$10_subscription_type$jscomp$9$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$69$$));
$subscription$jscomp$10_subscription_type$jscomp$9$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($subscription$jscomp$10_subscription_type$jscomp$9$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $disposable$jscomp$7$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($close_all_menus$$,$APP.$beicon$v2$core$filter$$(function($p1__78176_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2169$interrupt$$,
$p1__78176_SHARP_$$)},$APP.$app$main$store$stream$$));return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$dispose_BANG_$$,$disposable$jscomp$7$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-pressed":$show_menu_QMARK_$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-subsection.main-menu"),
onClick:$props_78178_toggle_menu$$,icon:"menu"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:$show_menu_QMARK_$jscomp$1$$,id:"workspace:menu",onClose:$close_menu$jscomp$1$$,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__menu",children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",
onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$397$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$397$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$397$$):$on_menu_click$jscomp$2$$($event$jscomp$397$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"file",id:"file-menu-file",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.file")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$398$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$398$$))?
$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$398$$):$on_menu_click$jscomp$2$$($event$jscomp$398$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"edit",id:"file-menu-edit",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.edit")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$399$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$399$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$399$$):
$on_menu_click$jscomp$2$$($event$jscomp$399$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"view",id:"file-menu-view",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.view")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$400$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$400$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$400$$):$on_menu_click$jscomp$2$$($event$jscomp$400$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"preferences",
id:"file-menu-preferences",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.preferences")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")?
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$401$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$401$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$401$$):$on_menu_click$jscomp$2$$($event$jscomp$401$$):
null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"plugins",id:"file-menu-plugins",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.menu.title")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1236$mcp$$)?function(){var $tokens$jscomp$48$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$access_tokens$$),$expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$=function(){var $G__78198__$1$$=$tokens$jscomp$48$$==null?null:$APP.$cljs$core$some$$(function($p1__78177_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78177_SHARP_$$),"mcp")?$p1__78177_SHARP_$$:null},$tokens$jscomp$48$$);return $G__78198__$1$$==
null?null:$APP.$cljs$cst$5618$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($G__78198__$1$$)}();$expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$=$expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$!=null&&$APP.$app$common$time$now$$()>$expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$;var $mcp_enabled_QMARK_$jscomp$2$$=$APP.$cljs$cst$4335$mcp_enabled$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$69$$))===!0,
$mcp_connection$jscomp$1_mcp_error_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mcp$jscomp$1$$,$APP.$cljs$cst$4327$connection_status$$),$active_QMARK_$jscomp$4_mcp_connected_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mcp_connection$jscomp$1_mcp_error_QMARK_$$,"connected");$mcp_connection$jscomp$1_mcp_error_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mcp_connection$jscomp$1_mcp_error_QMARK_$$,"error");$active_QMARK_$jscomp$4_mcp_connected_QMARK_$jscomp$1$$=
$mcp_enabled_QMARK_$jscomp$2$$&&$active_QMARK_$jscomp$4_mcp_connected_QMARK_$jscomp$1$$;$expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$=$mcp_enabled_QMARK_$jscomp$2$$&&$mcp_connection$jscomp$1_mcp_error_QMARK_$$||$expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$===!0;return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,
onKeyDown:function($event$jscomp$402$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$402$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$402$$):$on_menu_click$jscomp$2$$($event$jscomp$402$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"mcp",id:"file-menu-mcp",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.mcp")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-indicator "+($active_QMARK_$jscomp$4_mcp_connected_QMARK_$jscomp$1$$?"main_ui_workspace_main_menu__active":"")+" "+($expired_QMARK_$jscomp$3_expires_at$jscomp$1_failed_QMARK_$$?"main_ui_workspace_main_menu__failed":"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",
className:"main_ui_workspace_main_menu__item-arrow"})]})}():null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$403$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$403$$))?
$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$403$$):$on_menu_click$jscomp$2$$($event$jscomp$403$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"help-info",id:"file-menu-help-info",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.help-info")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$subscription$jscomp$10_subscription_type$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$main_menu_power_up_STAR_$$,{closeSubMenu:$close_sub_menu$jscomp$2$$}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1186$subscriptions_old$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_power_up_click$jscomp$1$$,onKeyDown:function($event$jscomp$404$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$404$$))?$on_power_up_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_power_up_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_power_up_click$jscomp$1$$():
null},onPointerEnter:$close_sub_menu$jscomp$2$$,id:"file-menu-power-up",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.workspace.header.menu.option.power-up")})}):null]}),function(){switch($selected_sub_menu$$ instanceof $APP.$cljs$core$Keyword$$?$selected_sub_menu$$.$fqn$:null){case "file":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$file_menu_STAR_$$,
{file:$file$jscomp$162$$,onClose:$close_sub_menu$jscomp$2$$});case "edit":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$edit_menu_STAR_$$,{onClose:$close_sub_menu$jscomp$2$$});case "view":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$view_menu_STAR_$$,{layout:$layout$jscomp$19$$,toggleFlag:$toggle_flag$jscomp$2$$,onClose:$close_sub_menu$jscomp$2$$});case "preferences":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$preferences_menu_STAR_$$,{layout:$layout$jscomp$19$$,
profile:$profile$jscomp$69$$,toggleFlag:$toggle_flag$jscomp$2$$,toggleTheme:$toggle_theme$jscomp$1$$,toggleRender:$toggle_render$jscomp$1$$,onClose:$close_sub_menu$jscomp$2$$});case "plugins":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$plugins_menu_STAR_$$,{openPlugins:$open_plugins_manager$$,onClose:$close_sub_menu$jscomp$2$$});case "mcp":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$mcp_menu_STAR_$$,{onClose:$close_sub_menu$jscomp$2$$});case "help-info":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$help_info_menu_STAR_$$,
{layout:$layout$jscomp$19$$,onClose:$close_sub_menu$jscomp$2$$});default:return null}}()]})};
$app$main$ui$workspace$left_header$left_header_STAR_$$=function($class$$jscomp$63_props_78205$$){var $layout$jscomp$20$$=$class$$jscomp$63_props_78205$$.layout,$file$jscomp$163$$=$class$$jscomp$63_props_78205$$.file,$project$jscomp$21$$=$class$$jscomp$63_props_78205$$.project;$class$$jscomp$63_props_78205$$=$class$$jscomp$63_props_78205$$.className;var $file_id$jscomp$384$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$163$$),$file_name$jscomp$8$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$163$$),
$project_id$jscomp$35$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$21$$),$shared_QMARK_$jscomp$6$$=$APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$163$$),$handle_name_keydown_persistence$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$persistence$$),$persistence_status$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_name_keydown_persistence$jscomp$1$$,$APP.$cljs$cst$109$status$$),$editing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$editing_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($editing_STAR_$$),$input_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handle_blur$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$384$$)],function(){var $value$jscomp$803$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$6$$)));$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$803$$,
"")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$rename_file$$($file_id$jscomp$384$$,$value$jscomp$803$$));return $APP.$cljs$core$reset_BANG_$$($editing_STAR_$$,!1)});$handle_name_keydown_persistence$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_blur$jscomp$3$$)],function($event$jscomp$405$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$405$$))?$handle_blur$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_blur$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$405$$):$handle_blur$jscomp$3$$($event$jscomp$405$$):null});var $start_editing_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$406$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$406$$);return $APP.$cljs$core$reset_BANG_$$($editing_STAR_$$,!0)}),$close_modals$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$stop_picker$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}),$go_back$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$close_modals$$.$cljs$core$IFn$_invoke$arity$0$?$close_modals$$.$cljs$core$IFn$_invoke$arity$0$():$close_modals$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$set_options_mode$$($APP.$cljs$cst$3732$design$$),
$APP.$app$main$data$common$go_to_dashboard_recent$$()]))}),$nav_to_project$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$35$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,
!0,$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$35$$]))]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$3$$)],function(){return $editing_QMARK_$jscomp$3$$?$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$6$$)):null});return(0,$APP.$rumext$v2$jsxs$$)("header",{className:""+($class$$jscomp$63_props_78205$$??"")+" main_ui_workspace_left_header__workspace-header-left",children:[(0,$APP.$rumext$v2$jsx$$)("a",
{onClick:$go_back$jscomp$1$$,className:"main_ui_workspace_left_header__main-icon",children:$APP.$app$main$ui$icons$logo_icon$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sitemap"),className:"main_ui_workspace_left_header__project-tree",children:[(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$nav_to_project$$,className:"main_ui_workspace_left_header__project-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$21$$)}),
$editing_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$input_ref$jscomp$6$$,onBlur:$handle_blur$jscomp$3$$,onKeyDown:$handle_name_keydown_persistence$jscomp$1$$,autoFocus:!0,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$163$$,""),className:"main_ui_workspace_left_header__file-name-input"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$file_name$jscomp$8$$,onDoubleClick:$start_editing_name$$,className:"main_ui_workspace_left_header__file-name",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:function(){switch($persistence_status$$ instanceof $APP.$cljs$core$Keyword$$?$persistence_status$$.$fqn$:null){case "pending":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.saving");case "saving":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.saving");case "saved":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.saved");case "error":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.save-error");
default:return null}}(),className:function(){switch($persistence_status$$ instanceof $APP.$cljs$core$Keyword$$?$persistence_status$$.$fqn$:null){case "pending":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__pending-status";case "saving":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__saving-status";case "saved":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__saved-status";case "error":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__error-status";
default:return"main_ui_workspace_left_header__status-notification"}}(),children:function(){switch($persistence_status$$ instanceof $APP.$cljs$core$Keyword$$?$persistence_status$$.$fqn$:null){case "pending":return $APP.$app$main$ui$icons$status_alert$$;case "saving":return $APP.$app$main$ui$icons$status_alert$$;case "saved":return $APP.$app$main$ui$icons$status_tick$$;case "error":return $APP.$app$main$ui$icons$status_wrong$$;default:return null}}()}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_left_header__file-name-label",
children:$file_name$jscomp$8$$})]})]}),$shared_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_left_header__shared-badge",children:$APP.$app$main$ui$icons$library$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_left_header__menu-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$menu_STAR_$$,{layout:$layout$jscomp$20$$,file:$file$jscomp$163$$})})]})};
$app$main$data$workspace$history$initialize_history$$=function(){typeof $app$main$data$workspace$history$initialize_history_78249$$==="undefined"&&($app$main$data$workspace$history$initialize_history_78249$$=function($meta78250$$){this.$meta78250$=$meta78250$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$history$initialize_history_78249$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$history$initialize_history_78249$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5619$app_DOT_main_DOT_data_DOT_workspace_DOT_history_SLASH_initialize_history$$},$app$main$data$workspace$history$initialize_history_78249$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_78251$$,$meta78250__$1$$){return new $app$main$data$workspace$history$initialize_history_78249$$($meta78250__$1$$)},$app$main$data$workspace$history$initialize_history_78249$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta78250$},$app$main$data$workspace$history$initialize_history_78249$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$history$initialize_history_78249$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3001$$,$___$1$jscomp$2074$$,$stream$jscomp$105$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$layout$toggle_layout_flag$$($APP.$cljs$cst$3719$document_history$$)),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3719$document_history$$)},
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$common$interrupt_QMARK_$$,$stream$jscomp$105$$))))});return new $app$main$data$workspace$history$initialize_history_78249$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$right_header$right_header_STAR_$$=function($props_78262_zoom$jscomp$66$$){var $file_id$jscomp$385$$=$props_78262_zoom$jscomp$66$$.fileId,$layout$jscomp$21$$=$props_78262_zoom$jscomp$66$$.layout,$page_id$jscomp$418$$=$props_78262_zoom$jscomp$66$$.pageId,$threads_map$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$);$props_78262_zoom$jscomp$66$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$);var $read_only_QMARK_$jscomp$12$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),
$selected_drawtool$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_drawing_tool$$),$on_increase$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}),$on_decrease$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}),
$on_zoom_reset$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}),$on_zoom_fit$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}),$on_zoom_selected$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)}),
$editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$editing_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$),$input_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(null),$team$jscomp$55$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$permissions$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$55$$,$APP.$cljs$cst$1722$permissions$$);$editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($threads_map$jscomp$6$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$385$$)],function(){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($p1__78261_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78261_SHARP_$$),$file_id$jscomp$385$$)&&$APP.$cljs$cst$3428$count_unread_comments$$.$cljs$core$IFn$_invoke$arity$1$($p1__78261_SHARP_$$)>
0},$APP.$cljs$core$vals$$($threads_map$jscomp$6$$)))});var $display_share_button_QMARK_$$=function(){var $and__5023__auto__$jscomp$742_or__5025__auto__$jscomp$1107$$=$APP.$cljs$core$not$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$55$$));return $and__5023__auto__$jscomp$742_or__5025__auto__$jscomp$1107$$?($and__5023__auto__$jscomp$742_or__5025__auto__$jscomp$1107$$=$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$33$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$742_or__5025__auto__$jscomp$1107$$)?
$and__5023__auto__$jscomp$742_or__5025__auto__$jscomp$1107$$:$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$33$$)):$and__5023__auto__$jscomp$742_or__5025__auto__$jscomp$1107$$}(),$nav_to_viewer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$385$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$418$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$418$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$385$$,$APP.$cljs$cst$1366$section$$,"interactions"],null)])))}),$active_comments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$21$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$(),
$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3719$document_history$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-header"),$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$3436$comments$$)]))}),$toggle_comments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_drawtool$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_drawtool$$,
$APP.$cljs$cst$3436$comments$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$common$clear_drawing$$()):$active_comments$$.$cljs$core$IFn$_invoke$arity$0$?$active_comments$$.$cljs$core$IFn$_invoke$arity$0$():$active_comments$$()}),$toggle_history$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_drawtool$$)],function(){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3436$comments$$,
$selected_drawtool$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$data$workspace$history$initialize_history$$(),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace-header"))}),$open_share_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$55$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5127$invite_members$$,$APP.$cljs$cst$2492$team$$,$team$jscomp$55$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$2532$workspace$$],
null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$4$$)],function(){return $editing_QMARK_$jscomp$4$$?$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$7$$)):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_right_header__workspace-header-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__users-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$presence$active_sessions_STAR_$$,
{})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$exports$assets$progress_widget$$,{}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__separator"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__zoom-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$right_header$zoom_widget_workspace$$,{zoom:$props_78262_zoom$jscomp$66$$,"on-increase":$on_increase$jscomp$2$$,"on-decrease":$on_decrease$jscomp$2$$,"on-zoom-reset":$on_zoom_reset$jscomp$2$$,
"on-zoom-fit":$on_zoom_fit$jscomp$2$$,"on-zoom-selected":$on_zoom_selected$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__comments-section",children:(0,$APP.$rumext$v2$jsxs$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.comments",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4805$add_comment$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.comments",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4805$add_comment$$)])),onClick:$toggle_comments$$,"data-tool":"comments",style:{position:"relative"},className:"main_ui_workspace_right_header__comments-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_drawtool$$,$APP.$cljs$cst$3436$comments$$)?"main_ui_workspace_right_header__selected":""),children:[$APP.$app$main$ui$icons$comments$$,$editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__unread"}):null]})}),$read_only_QMARK_$jscomp$12$$?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__history-section",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.history"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.history"),onClick:$toggle_history$$,className:($APP.$cljs$core$contains_QMARK_$$($layout$jscomp$21$$,
$APP.$cljs$cst$3719$document_history$$)?"main_ui_workspace_right_header__selected":"")+" main_ui_workspace_right_header__history-button",children:$APP.$app$main$ui$icons$history$$})}),$APP.$cljs$core$truth_$$($display_share_button_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("a",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.share"),onClick:$open_share_dialog$jscomp$1$$,className:"main_ui_workspace_right_header__viewer-btn",children:$APP.$app$main$ui$icons$share$$}):null,
(0,$APP.$rumext$v2$jsx$$)("a",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.header.viewer",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4842$open_viewer$$)])),onClick:$nav_to_viewer$$,className:"main_ui_workspace_right_header__viewer-btn",children:$APP.$app$main$ui$icons$play$$})]})};
$app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$=function($other_path$jscomp$1_props_78264$$){var $on_group_combine_variants$$=$other_path$jscomp$1_props_78264$$.onGroupCombineVariants,$path$jscomp$262$$=$other_path$jscomp$1_props_78264$$.path,$is_group_open$$=$other_path$jscomp$1_props_78264$$.isGroupOpen,$is_can_combine$$=$other_path$jscomp$1_props_78264$$.isCanCombine,$file_id$jscomp$386$$=$other_path$jscomp$1_props_78264$$.fileId,$section$jscomp$28$$=$other_path$jscomp$1_props_78264$$.section,
$on_ungroup$$=$other_path$jscomp$1_props_78264$$.onUngroup,$on_rename$$=$other_path$jscomp$1_props_78264$$.onRename,$on_add$$=$other_path$jscomp$1_props_78264$$.onAdd,$on_delete_group$$=$other_path$jscomp$1_props_78264$$.onDeleteGroup;if($APP.$cljs$core$empty_QMARK_$$($path$jscomp$262$$))return null;var $truncated_vec__78265$$=$app$common$path_names$compact_path$$($path$jscomp$262$$);$other_path$jscomp$1_props_78264$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($truncated_vec__78265$$,
0,null);var $last_path$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($truncated_vec__78265$$,1,null);$truncated_vec__78265$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($truncated_vec__78265$$,2,null);var $menu_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$on_fold_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$386$$),
$APP.$rumext$v2$adapt$$($section$jscomp$28$$),$APP.$rumext$v2$adapt$$($path$jscomp$262$$),$APP.$rumext$v2$adapt$$($is_group_open$$)],function($event$jscomp$411$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$411$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_group_open$$($file_id$jscomp$386$$,$section$jscomp$28$$,$path$jscomp$262$$,$APP.$cljs$core$not$$($is_group_open$$)))}),$on_context_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$412_pos$jscomp$135$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$412_pos$jscomp$135$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$412_pos$jscomp$135$$);$event$jscomp$412_pos$jscomp$135$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$412_pos$jscomp$135$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,$event$jscomp$412_pos$jscomp$135$$)}),$on_close_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$$,
$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__group-title-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onContextMenu:$on_context_menu$jscomp$2$$,className:"main_ui_workspace_sidebar_assets_groups__group-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($is_group_open$$),onCollapsed:$on_fold_group$$,
title:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$empty_QMARK_$$($other_path$jscomp$1_props_78264$$)?null:(0,$APP.$rumext$v2$jsxs$$)("span",{title:$APP.$cljs$core$truth_$$($truncated_vec__78265$$)?$path$jscomp$262$$:null,className:"main_ui_workspace_sidebar_assets_groups__pre-path",children:[$other_path$jscomp$1_props_78264$$," • "]}),(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$core$truth_$$($truncated_vec__78265$$)?$path$jscomp$262$$:null,className:"main_ui_workspace_sidebar_assets_groups__path",
children:$last_path$jscomp$1$$})]})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$1$$,state:$APP.$cljs$core$_deref$$($menu_state$$),options:function(){var $G__78268_G__78268__$1$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),
$APP.$cljs$cst$266$id$$,"assets-rename-group",$APP.$cljs$cst$2402$handler$$,function($p1__78263_SHARP_$$){return $on_rename$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename$$.$cljs$core$IFn$_invoke$arity$3$($p1__78263_SHARP_$$,$path$jscomp$262$$,$last_path$jscomp$1$$):$on_rename$$($p1__78263_SHARP_$$,$path$jscomp$262$$,$last_path$jscomp$1$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.ungroup"),
$APP.$cljs$cst$266$id$$,"assets-ungroup-group",$APP.$cljs$cst$2402$handler$$,function(){return $on_ungroup$$.$cljs$core$IFn$_invoke$arity$1$?$on_ungroup$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$262$$):$on_ungroup$$($path$jscomp$262$$)}],null)],null);$G__78268_G__78268__$1$$=$APP.$cljs$core$truth_$$($on_delete_group$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78268_G__78268__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete-group"),
$APP.$cljs$cst$266$id$$,"assets-delete-group",$APP.$cljs$cst$2402$handler$$,function(){return $on_delete_group$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete_group$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$262$$):$on_delete_group$$($path$jscomp$262$$)}],null)):$G__78268_G__78268__$1$$;return $APP.$cljs$core$truth_$$($is_can_combine$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78268_G__78268__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants"),
$APP.$cljs$cst$266$id$$,"assets-combine-as-variants",$APP.$cljs$cst$2402$handler$$,function(){return $on_group_combine_variants$$.$cljs$core$IFn$_invoke$arity$1$?$on_group_combine_variants$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$262$$):$on_group_combine_variants$$($path$jscomp$262$$)}],null)):$G__78268_G__78268__$1$$}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__title-menu",children:[$APP.$cljs$core$truth_$$($on_add$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.add-typography"),onClick:$on_add$$,icon:"add"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.component-group-options"),onClick:$on_context_menu$jscomp$2$$,icon:"menu"})]})]})};
$app$main$ui$workspace$sidebar$assets$groups$sort_groups$$=function($groups$jscomp$4$$,$reverse_sort_QMARK_$$){var $cmp$$=$APP.$cljs$core$truth_$$($reverse_sort_QMARK_$$)?function($p1__78270_SHARP_$$,$p2__78269_SHARP_$$){return $APP.$cljs$core$compare$$($p2__78269_SHARP_$$,$p1__78270_SHARP_$$)}:$APP.$cljs$core$compare$$;return function $app$main$ui$workspace$sidebar$assets$groups$sort_groups_$_sort_tree$$($m$jscomp$236$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$sorted_map_by$$($cmp$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__78271_v$jscomp$663$$){var $k$jscomp$691$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78271_v$jscomp$663$$,0,null);$p__78271_v$jscomp$663$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78271_v$jscomp$663$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$691$$,$APP.$cljs$core$map_QMARK_$$($p__78271_v$jscomp$663$$)?$app$main$ui$workspace$sidebar$assets$groups$sort_groups_$_sort_tree$$($p__78271_v$jscomp$663$$):
$p__78271_v$jscomp$663$$],null)}),$m$jscomp$236$$)}($groups$jscomp$4$$)};
$app$main$ui$workspace$sidebar$assets$groups$group_assets$$=function($assets$jscomp$3$$,$reverse_sort_QMARK_$jscomp$1$$){return $APP.$cljs$core$empty_QMARK_$$($assets$jscomp$3$$)?null:$app$main$ui$workspace$sidebar$assets$groups$sort_groups$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($groups$jscomp$5$$,$p__78275_path$jscomp$263_path__$1$jscomp$9$$){var $map__78276__$1$$=$APP.$cljs$core$__destructure_map$$($p__78275_path$jscomp$263_path__$1$jscomp$9$$);$p__78275_path$jscomp$263_path__$1$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78276__$1$$,$APP.$cljs$cst$296$path$$);$p__78275_path$jscomp$263_path__$1$jscomp$9$$=$APP.$app$common$path_names$split_path$$($APP.$cljs$core$truth_$$($p__78275_path$jscomp$263_path__$1$jscomp$9$$)?$p__78275_path$jscomp$263_path__$1$jscomp$9$$:"");return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$5$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__78275_path$jscomp$263_path__$1$jscomp$9$$,""),function($group$jscomp$52$$){return $APP.$cljs$core$truth_$$($group$jscomp$52$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$52$$,$map__78276__$1$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__78276__$1$$],null)})},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$assets$jscomp$3$$),$reverse_sort_QMARK_$jscomp$1$$)};
$app$main$ui$workspace$sidebar$assets$groups$name_group_dialog$$=function($initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$){$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$=$APP.$rumext$v2$util$wrap_props$$($initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$);$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$=$APP.$cljs$core$__destructure_map$$($initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$);
var $path$jscomp$264$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$,$APP.$cljs$cst$296$path$$,""),$last_path$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$,$cljs$cst$5623$last_path$$,""),$accept$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$,
$APP.$cljs$cst$924$accept$$);$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($last_path$jscomp$2$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5624$asset_name$$,$last_path$jscomp$2$$],null)});var $form$jscomp$188$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,
$app$main$ui$workspace$sidebar$assets$groups$schema_COLON_group_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$workspace$sidebar$assets$groups$schema_COLON_group_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$),$create_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($path$jscomp$264$$);$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$188$$)],function(){var $asset_name$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$188$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$725$name$$],null));$create_QMARK_$$?$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($asset_name$$):
$accept$jscomp$11$$($asset_name$$):$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$?$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$264$$,$asset_name$$):$accept$jscomp$11$$($path$jscomp$264$$,$asset_name$$);return $APP.$app$main$data$modal$hide_BANG_$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_assets_groups__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_workspace_sidebar_assets_groups__modal-title",children:$create_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.create-group"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename-group")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_sidebar_assets_groups__modal-close-btn",
children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$188$$,"on-submit":$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$APP.$cljs$cst$725$name$$,"class":"main_ui_workspace_sidebar_assets_groups__input-wrapper",
"auto-focus?":!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group-name"),hint:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.create-group-hint")})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),
onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_sidebar_assets_groups__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$188$$))),value:$create_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),onClick:$initial$jscomp$36_map__78278_map__78278__$1_on_accept$jscomp$12_props_78277$$,
className:"main_ui_workspace_sidebar_assets_groups__accept-btn "+($APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$188$$)))?"disabled":"")})]})})]})})};
$app$main$ui$workspace$sidebar$assets$colors$color_item$$=function($dragging_QMARK_$jscomp$3_props_78279$$){var $selected_paths$jscomp$4$$=$dragging_QMARK_$jscomp$3_props_78279$$["selected-paths"],$on_asset_click$$=$dragging_QMARK_$jscomp$3_props_78279$$["on-asset-click"],$selected_full$jscomp$2$$=$dragging_QMARK_$jscomp$3_props_78279$$["selected-full"],$on_assets_delete$$=$dragging_QMARK_$jscomp$3_props_78279$$["on-assets-delete"],$selected$jscomp$154$$=$dragging_QMARK_$jscomp$3_props_78279$$.selected,
$file_id$jscomp$387$$=$dragging_QMARK_$jscomp$3_props_78279$$["file-id"],$color$jscomp$161$$=$dragging_QMARK_$jscomp$3_props_78279$$.color,$multi_assets_QMARK_$$=$dragging_QMARK_$jscomp$3_props_78279$$["multi-assets?"],$local_QMARK_$jscomp$5$$=$dragging_QMARK_$jscomp$3_props_78279$$["local?"],$move_color$$=$dragging_QMARK_$jscomp$3_props_78279$$["move-color"],$on_clear_selection$jscomp$1$$=$dragging_QMARK_$jscomp$3_props_78279$$["on-clear-selection"],$on_group$$=$dragging_QMARK_$jscomp$3_props_78279$$["on-group"],
$multi_colors_QMARK_$$=$dragging_QMARK_$jscomp$3_props_78279$$["multi-colors?"],$color__$1$jscomp$32$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$161$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$)],function(){var $G__78280__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$161$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$161$$,$APP.$cljs$cst$1298$color$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$161$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1734$opacity$$,1])):$color$jscomp$161$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$161$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__78280__$1$$,$APP.$cljs$cst$260$value$$):$G__78280__$1$$}),$color_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),
$item_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(),$dragging_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$dragging_QMARK_$jscomp$3_props_78279$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$5$$);var $default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3904$color_for_rename$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_local$$)),
$color_id$jscomp$9$$),$input_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(),$editing_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$),$editing_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$2$$),$menu_state$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$read_only_QMARK_$jscomp$13$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);var $alpha_suffix_display_name$$=typeof $default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$==="number"&&$default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$<1?" "+($APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$*
100)??"")+"%":null;$default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$))?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color__$1$jscomp$32$$,$APP.$cljs$cst$1724$gradient$$),$APP.$cljs$cst$139$type$$)):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$))?
$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$):$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);$alpha_suffix_display_name$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($alpha_suffix_display_name$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)):$alpha_suffix_display_name$$)?""+($default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$??"")+($alpha_suffix_display_name$$??
""):$default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$;var $rename_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$),$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$)],function($name$jscomp$445$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$rename_color$$($file_id$jscomp$387$$,$color_id$jscomp$9$$,$name$jscomp$445$$))}),$edit_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$)],function($attrs$jscomp$174_color__$2$jscomp$3$$){var $name$jscomp$446$$=$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$));$attrs$jscomp$174_color__$2$jscomp$3$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$174_color__$2$jscomp$3$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)),$APP.$cljs$cst$725$name$$,$name$jscomp$446$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_color$$($attrs$jscomp$174_color__$2$jscomp$3$$,$file_id$jscomp$387$$))}),$delete_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($multi_colors_QMARK_$$),$APP.$rumext$v2$adapt$$($multi_assets_QMARK_$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$),$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($multi_colors_QMARK_$$)?$multi_colors_QMARK_$$:$multi_assets_QMARK_$$))return $on_assets_delete$$.$cljs$core$IFn$_invoke$arity$0$?$on_assets_delete$$.$cljs$core$IFn$_invoke$arity$0$():$on_assets_delete$$();var $undo_id$jscomp$92$$=Symbol();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$92$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$delete_color$$($color__$1$jscomp$32$$),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$387$$,$file_id$jscomp$387$$,$APP.$cljs$cst$2212$colors$$,$color_id$jscomp$9$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$92$$)]))}),$duplicate_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$),
$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_color$$($file_id$jscomp$387$$,$color_id$jscomp$9$$))}),$rename_color_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$),$APP.$rumext$v2$adapt$$($local_QMARK_$jscomp$5$$)],function($event$jscomp$413$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($local_QMARK_$jscomp$5$$)?
$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$13$$):$local_QMARK_$jscomp$5$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$413$$),$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$2$$,!0)):null}),$input_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($rename_color$$)],function($event$jscomp$414_name$jscomp$447$$){$event$jscomp$414_name$jscomp$447$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$414_name$jscomp$447$$);$rename_color$$.$cljs$core$IFn$_invoke$arity$1$?
$rename_color$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$414_name$jscomp$447$$):$rename_color$$($event$jscomp$414_name$jscomp$447$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$clear_color_for_rename$$);return $APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$2$$,!1)}),$input_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($input_blur$$)],function($event$jscomp$415$$){$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$415$$))&&
($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$clear_color_for_rename$$),$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$2$$,!1));return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$415$$))?$input_blur$$.$cljs$core$IFn$_invoke$arity$1$?$input_blur$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$415$$):$input_blur$$($event$jscomp$415$$):null}),$edit_color_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edit_color$$),
$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$)],function($event$jscomp$416$$){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2239$colorpicker$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1510$x$$,$event$jscomp$416$$.clientX,$APP.$cljs$cst$1511$y$$,$event$jscomp$416$$.clientY,$APP.$cljs$cst$2479$on_accept$$,$edit_color$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$3718$assets$$,$APP.$cljs$cst$142$data$$,$color__$1$jscomp$32$$,$APP.$cljs$cst$1676$position$$,
$APP.$cljs$cst$258$right$$],null))}),$on_context_menu$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected$jscomp$154$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$1$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$)],function($event$jscomp$417_pos$jscomp$136$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$417_pos$jscomp$136$$);$event$jscomp$417_pos$jscomp$136$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$417_pos$jscomp$136$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($local_QMARK_$jscomp$5$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$13$$):$local_QMARK_$jscomp$5$$)?($APP.$cljs$core$contains_QMARK_$$($selected$jscomp$154$$,$color_id$jscomp$9$$)||($on_clear_selection$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$1$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$jscomp$1$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,
$event$jscomp$417_pos$jscomp$136$$)):null}),$on_close_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$jscomp$1$$,$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)}),$on_drop$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected$jscomp$154$$),
$APP.$rumext$v2$adapt$$($selected_full$jscomp$2$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$4$$),$APP.$rumext$v2$adapt$$($move_color$$)],function($event$jscomp$418$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$($event$jscomp$418$$,$color__$1$jscomp$32$$,$dragging_STAR_$jscomp$5$$,$selected$jscomp$154$$,$selected_full$jscomp$2$$,$selected_paths$jscomp$4$$,$move_color$$)}),$on_drag_enter$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),
$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected$jscomp$154$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$4$$)],function($event$jscomp$419$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$($event$jscomp$419$$,$color__$1$jscomp$32$$,$dragging_STAR_$jscomp$5$$,$selected$jscomp$154$$,$selected_paths$jscomp$4$$)}),$on_drag_leave$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$5$$)],
function($event$jscomp$420$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$420$$,$dragging_STAR_$jscomp$5$$)}),$on_color_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$),$APP.$rumext$v2$adapt$$($selected$jscomp$154$$),$APP.$rumext$v2$adapt$$($item_ref$jscomp$3$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$),$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$5$$)],
function($event$jscomp$421$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$13$$)?$read_only_QMARK_$jscomp$13$$:$editing_QMARK_$jscomp$5$$)?$APP.$app$util$dom$prevent_default$$($event$jscomp$421$$):$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$($event$jscomp$421$$,$file_id$jscomp$387$$,$color__$1$jscomp$32$$,$selected$jscomp$154$$,$item_ref$jscomp$3$$,$APP.$cljs$cst$2212$colors$$,$APP.$cljs$core$identity$$)}),$on_click$jscomp$40$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),
$APP.$rumext$v2$adapt$$($on_asset_click$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$)],function($event$jscomp$422$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$13$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-color",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"sidebar",$APP.$cljs$cst$3933$external_library$$,$APP.$cljs$core$not$$($local_QMARK_$jscomp$5$$)],null)));var $G__78282$jscomp$inline_8839_JSCompiler_inline_result$jscomp$1779$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);$G__78282$jscomp$inline_8839_JSCompiler_inline_result$jscomp$1779$$=$on_asset_click$$.$cljs$core$IFn$_invoke$arity$2$?$on_asset_click$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$422$$,$G__78282$jscomp$inline_8839_JSCompiler_inline_result$jscomp$1779$$):
$on_asset_click$$($event$jscomp$422$$,$G__78282$jscomp$inline_8839_JSCompiler_inline_result$jscomp$1779$$);return $APP.$cljs$core$truth_$$($G__78282$jscomp$inline_8839_JSCompiler_inline_result$jscomp$1779$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$apply_color_from_assets$$($file_id$jscomp$387$$,$color__$1$jscomp$32$$,$event$jscomp$422$$.altKey))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$5$$)],
function(){$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$5$$)&&$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$8$$));return null});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$2$$,onDragLeave:$on_drag_leave$jscomp$2$$,className:"main_ui_workspace_sidebar_assets_colors__asset-list-item "+($APP.$cljs$core$contains_QMARK_$$($selected$jscomp$154$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$))?"main_ui_workspace_sidebar_assets_colors__selected":
"")+" "+($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_assets_colors__editing":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__bullet-block",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{color:$color__$1$jscomp$32$$,mini:!0})}),$editing_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$input_ref$jscomp$8$$,onBlur:$input_blur$$,onKeyDown:$input_key_down$$,
autoFocus:!0,maxLength:255,defaultValue:$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)),className:"main_ui_workspace_sidebar_assets_colors__element-name"}):(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$)?
$alpha_suffix_display_name$$:""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)??"")+" ("+($alpha_suffix_display_name$$??"")+")",onDoubleClick:$rename_color_clicked$$,className:"main_ui_workspace_sidebar_assets_colors__name-block",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$default_name$jscomp$1_opacity$jscomp$49_rename_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_assets_colors__default-name",children:$alpha_suffix_display_name$$}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_colors__default-name main_ui_workspace_sidebar_assets_colors__default-name-with-color",children:$alpha_suffix_display_name$$})]})}),$APP.$cljs$core$truth_$$($local_QMARK_$jscomp$5$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$2$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$1$$),options:new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($multi_colors_QMARK_$$)?$multi_colors_QMARK_$$:$multi_assets_QMARK_$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),
$APP.$cljs$cst$266$id$$,"assets-rename-color",$APP.$cljs$cst$2402$handler$$,$rename_color_clicked$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($multi_colors_QMARK_$$)?$multi_colors_QMARK_$$:$multi_assets_QMARK_$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.edit"),$APP.$cljs$cst$266$id$$,"assets-edit-color",$APP.$cljs$cst$2402$handler$$,$edit_color_clicked$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($multi_colors_QMARK_$$)?
$multi_colors_QMARK_$$:$multi_assets_QMARK_$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),$APP.$cljs$cst$266$id$$,"assets-duplicate-color",$APP.$cljs$cst$2402$handler$$,$duplicate_color$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),$APP.$cljs$cst$266$id$$,
"assets-delete-color",$APP.$cljs$cst$2402$handler$$,$delete_color$$],null),$APP.$cljs$core$truth_$$($multi_assets_QMARK_$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group"),$APP.$cljs$cst$266$id$$,"assets-group-color",$APP.$cljs$cst$2402$handler$$,function(){var $G__78283$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);return $on_group$$.$cljs$core$IFn$_invoke$arity$1$?
$on_group$$.$cljs$core$IFn$_invoke$arity$1$($G__78283$$):$on_group$$($G__78283$$)}()],null)],null)}):null,$dragging_QMARK_$jscomp$3_props_78279$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__dragging"}):null],onContextMenu:$on_context_menu$jscomp$3$$,onDrop:$on_drop$jscomp$5$$,style:{"--bullet-size":"16px"},onDragOver:$APP.$app$util$dom$prevent_default$$,draggable:$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$13$$)&&$APP.$cljs$core$not$$($editing_QMARK_$jscomp$5$$),
onClick:$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$5$$)?null:$on_click$jscomp$40$$,ref:$item_ref$jscomp$3$$,onDragStart:$on_color_drag_start$$})};
$app$main$ui$workspace$sidebar$assets$colors$colors_section_STAR_$$=function($props_78299_selected_full$jscomp$4$$){var $on_asset_click$jscomp$2_on_asset_click__$1$$=$props_78299_selected_full$jscomp$4$$.onAssetClick,$is_open$jscomp$4$$=$props_78299_selected_full$jscomp$4$$.isOpen,$open_status_ref$$=$props_78299_selected_full$jscomp$4$$.openStatusRef,$on_assets_delete$jscomp$2$$=$props_78299_selected_full$jscomp$4$$.onAssetsDelete,$file_id$jscomp$389$$=$props_78299_selected_full$jscomp$4$$.fileId,
$is_force_open$$=$props_78299_selected_full$jscomp$4$$.isForceOpen,$colors$jscomp$22$$=$props_78299_selected_full$jscomp$4$$.colors,$is_local$jscomp$1$$=$props_78299_selected_full$jscomp$4$$.isLocal,$on_clear_selection$jscomp$3$$=$props_78299_selected_full$jscomp$4$$.onClearSelection,$is_reverse_sort$$=$props_78299_selected_full$jscomp$4$$.isReverseSort,$selected__$1$jscomp$15$$=$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($props_78299_selected_full$jscomp$4$$.selected);$props_78299_selected_full$jscomp$4$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$15$$),$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78291_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$15$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78291_SHARP_$$))}),
$colors$jscomp$22$$)});var $open_groups$jscomp$1_open_groups_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_status_ref$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4382$groups$$,$APP.$cljs$cst$2212$colors$$],null)),$open_status_ref$$)});$open_groups$jscomp$1_open_groups_ref$$=
$APP.$rumext$v2$deref$$($open_groups$jscomp$1_open_groups_ref$$);var $multi_colors_QMARK_$jscomp$2$$=$APP.$cljs$core$count$$($selected__$1$jscomp$15$$)>1,$multi_assets_QMARK_$jscomp$2$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$15$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2472$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$15$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$15$$)),
$groups$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($is_reverse_sort$$)],function(){return $app$main$ui$workspace$sidebar$assets$groups$group_assets$$($colors$jscomp$22$$,$is_reverse_sort$$)}),$read_only_QMARK_$jscomp$14$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$add_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$804$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$804$$,
null))}),$add_color_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$389$$)],function($event$jscomp$426_x_position$$){var $bounds$jscomp$81_y_position$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($event$jscomp$426_x_position$$));$event$jscomp$426_x_position$$=$APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$81_y_position$$);$bounds$jscomp$81_y_position$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$81_y_position$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$389$$,$APP.$cljs$cst$2212$colors$$,!0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-asset-to-library",$APP.$cljs$cst$2545$asset_type$$,"color"],null)),$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2239$colorpicker$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1510$x$$,$event$jscomp$426_x_position$$,$APP.$cljs$cst$1511$y$$,$bounds$jscomp$81_y_position$$,$APP.$cljs$cst$2479$on_accept$$,$add_color$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$3718$assets$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#406280",$APP.$cljs$cst$1734$opacity$$,1],null),$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$258$right$$],null))]))}),$create_group$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$15$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$3$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$389$$)],function($color_id$jscomp$10$$){return function($group_name$jscomp$2$$){$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$3$$();var $undo_id$jscomp$93$$=
Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$93$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78293_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_color$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78293_SHARP_$$,$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$add_group$$($p1__78293_SHARP_$$,
$group_name$jscomp$2$$)),$file_id$jscomp$389$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78292_SHARP_$$){return $multi_colors_QMARK_$jscomp$2$$?$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$15$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78292_SHARP_$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_id$jscomp$10$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78292_SHARP_$$))},$colors$jscomp$22$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$93$$))}}),
$rename_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],function($path$jscomp$265$$,$last_path$jscomp$3$$){$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$3$$();var $undo_id$jscomp$94$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$94$$));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78295_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_color$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78295_SHARP_$$,$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$rename_group$$($p1__78295_SHARP_$$,$path$jscomp$265$$,$last_path$jscomp$3$$)),$file_id$jscomp$389$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78294_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78294_SHARP_$$),
$path$jscomp$265$$)},$colors$jscomp$22$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$94$$))}),$on_group$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$15$$)],function($color_id$jscomp$11$$){return function($event$jscomp$427$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$427$$);
return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,$create_group$$.$cljs$core$IFn$_invoke$arity$1$?$create_group$$.$cljs$core$IFn$_invoke$arity$1$($color_id$jscomp$11$$):$create_group$$($color_id$jscomp$11$$)],null))}}),$on_rename_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],function($event$jscomp$428$$,
$path$jscomp$266$$,$last_path$jscomp$4$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$428$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,$path$jscomp$266$$,$cljs$cst$5623$last_path$$,$last_path$jscomp$4$$,$APP.$cljs$cst$924$accept$$,$rename_group$$],null))}),$on_ungroup$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],
function($path$jscomp$267$$){$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$3$$();var $undo_id$jscomp$95$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$95$$));$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78297_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_color$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78297_SHARP_$$,
$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$ungroup$$($p1__78297_SHARP_$$,$path$jscomp$267$$)),$file_id$jscomp$389$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78296_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78296_SHARP_$$),$path$jscomp$267$$)},$colors$jscomp$22$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$95$$))}),
$on_delete_group$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$3$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3718$assets$$,$colors$jscomp$22$$,$cljs$cst$5594$on_clear_selection$$,$on_clear_selection$jscomp$3$$,$cljs$cst$5595$delete_events$$,function($p1__78298_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($c$jscomp$312$$){return $APP.$app$main$data$workspace$libraries$delete_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$312$$)],null))},$p1__78298_SHARP_$$)}],null))});$on_asset_click$jscomp$2_on_asset_click__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$7$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$2_on_asset_click__$1$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$2_on_asset_click__$1$$,$groups$jscomp$7$$));return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,
{fileId:$file_id$jscomp$389$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),section:$APP.$cljs$cst$2212$colors$$,assetsCount:$APP.$cljs$core$count$$($colors$jscomp$22$$),isOpen:$is_open$jscomp$4$$,children:[$APP.$cljs$core$truth_$$($is_local$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$cljs$cst$5593$title_button$$,children:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$14$$)?null:
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors.add-color"),onClick:$add_color_clicked$$,icon:"add"})}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$APP.$cljs$cst$1637$content$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$colors_group$$,{"selected-full":$props_78299_selected_full$jscomp$4$$,
"on-assets-delete":$on_assets_delete$jscomp$2$$,"force-open?":$is_force_open$$,selected:$selected__$1$jscomp$15$$,"file-id":$file_id$jscomp$389$$,"multi-assets?":$multi_assets_QMARK_$jscomp$2$$,"on-ungroup":$on_ungroup$jscomp$2$$,"local?":$is_local$jscomp$1$$,colors:$colors$jscomp$22$$,"open-groups":$open_groups$jscomp$1_open_groups_ref$$,prefix:"","on-group":$on_group$jscomp$2$$,"on-clear-selection":$on_clear_selection$jscomp$3$$,"multi-colors?":$multi_colors_QMARK_$jscomp$2$$,"on-delete-group":$on_delete_group$jscomp$2$$,
groups:$groups$jscomp$7$$,"on-asset-click":$on_asset_click$jscomp$2_on_asset_click__$1$$,"on-rename-group":$on_rename_group$jscomp$1$$})})]})};
$app$main$ui$components$editable_label$editable_label_STAR_$$=function($display_value_props_78286$$){var $on_change$jscomp$45$$=$display_value_props_78286$$.onChange,$on_cancel$jscomp$7$$=$display_value_props_78286$$.onCancel,$tooltip$$=$display_value_props_78286$$.tooltip,$class_label$$=$display_value_props_78286$$.classLabel,$value$jscomp$805$$=$display_value_props_78286$$.value,$class_input$$=$display_value_props_78286$$.classInput,$is_editing$$=$display_value_props_78286$$.isEditing;$display_value_props_78286$$=
$display_value_props_78286$$.displayValue;var $input_ref$jscomp$9$$=(0,$APP.$rumext$v2$use_ref$$)(null),$internal_editing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$internal_editing_QMARK_$$=$APP.$cljs$core$_deref$$($internal_editing_STAR_$$),$start_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($internal_editing_STAR_$$,!0);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,
function(){var $temp__5825__auto__$jscomp$359$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$9$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$359$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$359$$):null})}),$stop_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($internal_editing_STAR_$$,!1)}),$accept_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_editing_QMARK_$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$45$$),$APP.$rumext$v2$adapt$$($stop_edition$$)],function(){if($APP.$cljs$core$truth_$$($internal_editing_QMARK_$$)){var $value__$1$jscomp$40$$=$APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$9$$));$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$45$$)&&($on_change$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$40$$):$on_change$jscomp$45$$($value__$1$jscomp$40$$));
return $stop_edition$$.$cljs$core$IFn$_invoke$arity$0$?$stop_edition$$.$cljs$core$IFn$_invoke$arity$0$():$stop_edition$$()}return null}),$cancel_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stop_edition$$),$APP.$rumext$v2$adapt$$($on_cancel$jscomp$7$$)],function(){$stop_edition$$.$cljs$core$IFn$_invoke$arity$0$?$stop_edition$$.$cljs$core$IFn$_invoke$arity$0$():$stop_edition$$();return $APP.$cljs$core$fn_QMARK_$$($on_cancel$jscomp$7$$)?$on_cancel$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?
$on_cancel$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$7$$():null}),$on_key_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cancel_edition$$),$APP.$rumext$v2$adapt$$($accept_edition$$)],function($event$jscomp$429$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$429$$))?$cancel_edition$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_edition$$.$cljs$core$IFn$_invoke$arity$0$():$cancel_edition$$():$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$429$$))?
$accept_edition$$.$cljs$core$IFn$_invoke$arity$0$?$accept_edition$$.$cljs$core$IFn$_invoke$arity$0$():$accept_edition$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$$),$APP.$rumext$v2$adapt$$($internal_editing_QMARK_$$),$APP.$rumext$v2$adapt$$($start_edition$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_editing$$)?$APP.$cljs$core$not$$($internal_editing_QMARK_$$):$is_editing$$)?$start_edition$$.$cljs$core$IFn$_invoke$arity$0$?
$start_edition$$.$cljs$core$IFn$_invoke$arity$0$():$start_edition$$():null});return $internal_editing_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("input",{ref:$input_ref$jscomp$9$$,defaultValue:$value$jscomp$805$$,onKeyUp:$on_key_up$$,maxLength:255,onBlur:$accept_edition$$,className:"main_ui_components_editable_label__editable-label-input "+($class_input$$??"")}):(0,$APP.$rumext$v2$jsx$$)("span",{title:$tooltip$$,className:"main_ui_components_editable_label__editable-label-text "+($class_label$$??""),children:$display_value_props_78286$$})};
$app$main$ui$workspace$sidebar$assets$components$get_component_root_and_container$$=function($file_id$jscomp$390_root_shape$jscomp$10$$,$component$jscomp$124_container$jscomp$86$$){var $data$jscomp$478$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),$file_id$jscomp$390_root_shape$jscomp$10$$),$APP.$cljs$cst$142$data$$);$file_id$jscomp$390_root_shape$jscomp$10$$=$APP.$app$common$types$file$get_component_root$$($data$jscomp$478$$,
$component$jscomp$124_container$jscomp$86$$);$component$jscomp$124_container$jscomp$86$$=$APP.$app$common$types$file$get_component_page$$($data$jscomp$478$$,$component$jscomp$124_container$jscomp$86$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$390_root_shape$jscomp$10$$,$component$jscomp$124_container$jscomp$86$$],null)};
$app$main$ui$workspace$sidebar$assets$components$components_item_STAR_$$=function($dragging_QMARK_$jscomp$5_props_78303$$){var $selected_paths$jscomp$6$$=$dragging_QMARK_$jscomp$5_props_78303$$.selectedPaths,$on_asset_click$jscomp$3$$=$dragging_QMARK_$jscomp$5_props_78303$$.onAssetClick,$selected_full$jscomp$5$$=$dragging_QMARK_$jscomp$5_props_78303$$.selectedFull,$selected$jscomp$157$$=$dragging_QMARK_$jscomp$5_props_78303$$.selected,$file_id$jscomp$391$$=$dragging_QMARK_$jscomp$5_props_78303$$.fileId,
$cancel_rename$$=$dragging_QMARK_$jscomp$5_props_78303$$.cancelRename,$is_listing_thumbs$$=$dragging_QMARK_$jscomp$5_props_78303$$.isListingThumbs,$num_variants$$=$dragging_QMARK_$jscomp$5_props_78303$$.numVariants,$on_context_menu$jscomp$4_on_context_menu__$1$$=$dragging_QMARK_$jscomp$5_props_78303$$.onContextMenu,$renaming_root_shape$jscomp$11$$=$dragging_QMARK_$jscomp$5_props_78303$$.renaming,$component$jscomp$125$$=$dragging_QMARK_$jscomp$5_props_78303$$.component,$do_rename$jscomp$2$$=$dragging_QMARK_$jscomp$5_props_78303$$.doRename,
$is_local$jscomp$2$$=$dragging_QMARK_$jscomp$5_props_78303$$.isLocal,$on_drag_start$jscomp$2$$=$dragging_QMARK_$jscomp$5_props_78303$$.onDragStart,$item_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(),$dragging_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$dragging_QMARK_$jscomp$5_props_78303$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$7$$);var $read_only_QMARK_$jscomp$15$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),
$component_id$jscomp$92$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),$visible_QMARK_$$=$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($item_ref$jscomp$4$$),$renaming_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($renaming_root_shape$jscomp$11$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)),$container$jscomp$87_vec__78305$$=$app$main$ui$workspace$sidebar$assets$components$get_component_root_and_container$$($file_id$jscomp$391$$,
$component$jscomp$125$$);$renaming_root_shape$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($container$jscomp$87_vec__78305$$,0,null);$container$jscomp$87_vec__78305$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($container$jscomp$87_vec__78305$$,1,null);var $on_component_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_id$jscomp$92$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$3$$)],function($event$jscomp$430$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$430$$);
return $APP.$cljs$core$truth_$$($on_asset_click$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$on_asset_click$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$430$$,$component_id$jscomp$92$$):$on_asset_click$jscomp$3$$($event$jscomp$430$$,$component_id$jscomp$92$$))?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),$on_component_double_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$391$$),
$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$2$$),$APP.$rumext$v2$adapt$$($renaming_QMARK_$$)],function($event$jscomp$431$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$431$$);return $renaming_QMARK_$$?null:$APP.$cljs$core$truth_$$($is_local$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
$component_id$jscomp$92$$]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($file_id$jscomp$391$$,$component$jscomp$125$$,!1))}),$on_drop$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected$jscomp$157$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$6$$),
$APP.$rumext$v2$adapt$$($is_local$jscomp$2$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$432$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$2$$)?$APP.$cljs$cst$2574$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$2$$)?$app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$($event$jscomp$432$$,
$component$jscomp$125$$,$dragging_STAR_$jscomp$7$$,$selected$jscomp$157$$,$selected_full$jscomp$5$$,$selected_paths$jscomp$6$$,$APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$):null}),$on_drag_enter$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected$jscomp$157$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$6$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$2$$),
$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$433$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$2$$)?$APP.$cljs$cst$2574$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$2$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$($event$jscomp$433$$,$component$jscomp$125$$,$dragging_STAR_$jscomp$7$$,
$selected$jscomp$157$$,$selected_paths$jscomp$6$$):null}),$on_drag_leave$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$7$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$2$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$434$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$2$$)?$APP.$cljs$cst$2574$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):
$is_local$jscomp$2$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$434$$,$dragging_STAR_$jscomp$7$$):null}),$on_component_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$391$$),$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($selected$jscomp$157$$),$APP.$rumext$v2$adapt$$($item_ref$jscomp$4$$),$APP.$rumext$v2$adapt$$($on_drag_start$jscomp$2$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$15$$),
$APP.$rumext$v2$adapt$$($renaming_QMARK_$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$2$$)],function($event$jscomp$435$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$15$$)?$read_only_QMARK_$jscomp$15$$:$renaming_QMARK_$$)?$APP.$app$util$dom$prevent_default$$($event$jscomp$435$$):$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$($event$jscomp$435$$,$file_id$jscomp$391$$,$component$jscomp$125$$,$selected$jscomp$157$$,$item_ref$jscomp$4$$,$APP.$cljs$cst$1638$components$$,
$on_drag_start$jscomp$2$$)});$on_context_menu$jscomp$4_on_context_menu__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_context_menu$jscomp$4_on_context_menu__$1$$),$APP.$rumext$v2$adapt$$($component_id$jscomp$92$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_context_menu$jscomp$4_on_context_menu__$1$$,$component_id$jscomp$92$$));return(0,$APP.$rumext$v2$jsx$$)("div",{onDoubleClick:$on_component_double_click$$,onDragEnter:$on_drag_enter$jscomp$4$$,
onDragLeave:$on_drag_leave$jscomp$4$$,className:"main_ui_workspace_sidebar_assets_components__component-item "+($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list":"")+" "+($APP.$cljs$core$contains_QMARK_$$($selected$jscomp$157$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$))?"main_ui_workspace_sidebar_assets_components__component-item-selected":
""),children:$renaming_root_shape$jscomp$11$$!=null&&$container$jscomp$87_vec__78305$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid-name":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-name":
"")+" "+($renaming_QMARK_$$?"main_ui_workspace_sidebar_assets_components__component-item-editing":""),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$editable_label$editable_label_STAR_$$,{classInput:($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid-input":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-input":""),classLabel:($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?
"main_ui_workspace_sidebar_assets_components__component-item-grid-label":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-label":""),value:$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)),tooltip:$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)),displayValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),isEditing:$renaming_QMARK_$$,onChange:$do_rename$jscomp$2$$,onCancel:$cancel_rename$$})}),$dragging_QMARK_$jscomp$5_props_78303$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_components__component-item-dragging"}):null]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$,
{fileId:$file_id$jscomp$391$$,className:"main_ui_workspace_sidebar_assets_components__component-item-thumbnail "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-thumbnail":""),rootShape:$renaming_root_shape$jscomp$11$$,component:$component$jscomp$125$$,container:$container$jscomp$87_vec__78305$$,isHidden:$APP.$cljs$core$not$$($visible_QMARK_$$)}),$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$125$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.assets.components.num-variants",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$num_variants$$])),className:"main_ui_workspace_sidebar_assets_components__component-item-variant-mark "+($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid-variant-mark":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"variant",size:"s"})}):null]}):null,id:"component-shape-id-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)??""),onContextMenu:$on_context_menu$jscomp$4_on_context_menu__$1$$,onDrop:$on_drop$jscomp$7$$,onDragOver:$APP.$app$util$dom$prevent_default$$,draggable:$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$15$$)&&!$renaming_QMARK_$$,onClick:$on_component_click$$,ref:$item_ref$jscomp$4$$,onDragStart:$on_component_drag_start$$})};
$app$main$ui$workspace$sidebar$assets$components$components_section_STAR_$$=function($props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$){var $on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.onAssetClick,$is_open$jscomp$5$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.isOpen,$open_status_ref$jscomp$1$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.openStatusRef,$on_assets_delete$jscomp$3$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.onAssetsDelete,
$any_variant_QMARK_$jscomp$2_selected$jscomp$159$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.selected,$file_id$jscomp$393$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.fileId,$is_listing_thumbs$jscomp$2$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.isListingThumbs,$count_variants$jscomp$1$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.countVariants,$is_force_open$jscomp$2$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.isForceOpen,
$is_local$jscomp$4$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.isLocal,$on_clear_selection$jscomp$4$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.onClearSelection,$components$jscomp$14$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.components,$is_reverse_sort$jscomp$1$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.isReverseSort,$delete_component$$=$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$.deleteComponent,$input_ref$jscomp$10$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$state_STAR_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$10$$);var $current_component_id$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$);$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$=$cljs$cst$5636$renaming$$.$cljs$core$IFn$_invoke$arity$1$($props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$);
var $open_groups$jscomp$3_open_groups_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_status_ref$jscomp$1$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4382$groups$$,$APP.$cljs$cst$1638$components$$],null)),$open_status_ref$jscomp$1$$)});$open_groups$jscomp$3_open_groups_ref$jscomp$1$$=
$APP.$rumext$v2$deref$$($open_groups$jscomp$3_open_groups_ref$jscomp$1$$);var $menu_state$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$read_only_QMARK_$jscomp$16$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$toggle_list_style$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$workspace$sidebar$assets$common$assets_toggle_list_style$$),$selected__$1$jscomp$16$$=
$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($any_variant_QMARK_$jscomp$2_selected$jscomp$159$$),$selected_full$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78326_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$16$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78326_SHARP_$$))}),$components$jscomp$14$$),$multi_components_QMARK_$$=
$APP.$cljs$core$count$$($selected__$1$jscomp$16$$)>1,$multi_assets_QMARK_$jscomp$3$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$2472$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$16$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$16$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$16$$)),$selected_and_current$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),
$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($current_component_id$$)],function(){return $APP.$cljs$core$set$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($selected__$1$jscomp$16$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$current_component_id$$))}),$selected_and_current_full$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78327_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected_and_current$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78327_SHARP_$$))},$components$jscomp$14$$)});$any_variant_QMARK_$jscomp$2_selected$jscomp$159$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current$$)],function(){return $APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$selected_and_current_full$$)});var $all_same_page_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current$$)],
function(){var $page$jscomp$163$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_and_current_full$$));return $APP.$cljs$core$every_QMARK_$$(function($p1__78328_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$163$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($p1__78328_SHARP_$$))},$selected_and_current_full$$)}),$groups$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),
$APP.$rumext$v2$adapt$$($is_reverse_sort$jscomp$1$$)],function(){return $app$main$ui$workspace$sidebar$assets$groups$group_assets$$($components$jscomp$14$$,$is_reverse_sort$jscomp$1$$)}),$add_component$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$393$$,$APP.$cljs$cst$1638$components$$,!0));return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$10$$))}),
$on_file_selected$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$393$$)],function($blobs$jscomp$2_params$jscomp$418$$){$blobs$jscomp$2_params$jscomp$418$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$393$$,$APP.$cljs$cst$3698$blobs$$,$APP.$cljs$core$seq$$($blobs$jscomp$2_params$jscomp$418$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$media$upload_media_components$$($blobs$jscomp$2_params$jscomp$418$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-asset-to-library",$APP.$cljs$cst$2545$asset_type$$,"components"],null))]))}),$on_duplicate$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$)],function(){if($APP.$cljs$core$empty_QMARK_$$($selected__$1$jscomp$16$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$393$$,
$current_component_id$$));var $undo_id$jscomp$96$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$96$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$libraries$duplicate_component$$,$file_id$jscomp$393$$),$selected__$1$jscomp$16$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$96$$))}),
$on_delete$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$393$$),$APP.$rumext$v2$adapt$$($multi_components_QMARK_$$),$APP.$rumext$v2$adapt$$($multi_assets_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_assets_delete$jscomp$3$$)],function(){var $undo_id$jscomp$97$$=Symbol();return $multi_components_QMARK_$$||$multi_assets_QMARK_$jscomp$3$$?$on_assets_delete$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$on_assets_delete$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_assets_delete$jscomp$3$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$97$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$delete_component$$.$cljs$core$IFn$_invoke$arity$1$?$delete_component$$.$cljs$core$IFn$_invoke$arity$1$($current_component_id$$):$delete_component$$($current_component_id$$),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$393$$,
$file_id$jscomp$393$$,$APP.$cljs$cst$1638$components$$,$current_component_id$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$97$$)]))}),$on_close_menu$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$jscomp$2$$,$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)}),$on_rename$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$10$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5636$renaming$$,!0)}),$cancel_rename$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state_STAR_$jscomp$10$$,$APP.$cljs$core$dissoc$$,$cljs$cst$5636$renaming$$)}),$do_rename$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$)],function($new_name$jscomp$36$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state_STAR_$jscomp$10$$,
$APP.$cljs$core$dissoc$$,$cljs$cst$5636$renaming$$);return $APP.$cuerdas$core$blank_QMARK_$$($new_name$jscomp$36$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($current_component_id$$,$new_name$jscomp$36$$))}),$on_context_menu$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$),
$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$16$$)],function($component_id$jscomp$93$$,$event$jscomp$439_pos$jscomp$137$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$439_pos$jscomp$137$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$439_pos$jscomp$137$$);$event$jscomp$439_pos$jscomp$137$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$439_pos$jscomp$137$$);return $APP.$cljs$core$not$$($read_only_QMARK_$jscomp$16$$)?($APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$16$$,
$component_id$jscomp$93$$)||($on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$10$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1627$component_id$$,$component_id$jscomp$93$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$jscomp$2$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,
$event$jscomp$439_pos$jscomp$137$$)):null}),$create_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($group_name$jscomp$3$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$();
var $undo_id$jscomp$98$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$98$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78330_SHARP_$$){return $APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78330_SHARP_$$),$app$main$ui$workspace$sidebar$assets$common$add_group$$($p1__78330_SHARP_$$,
$group_name$jscomp$3$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78329_SHARP_$$){return $multi_components_QMARK_$$?$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$16$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78329_SHARP_$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78329_SHARP_$$))},$components$jscomp$14$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$98$$))}),
$rename_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($path$jscomp$268$$,$last_path$jscomp$5$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$();var $undo_id$jscomp$99$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$99$$));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78332_SHARP_$$){return $APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78332_SHARP_$$),$app$main$ui$workspace$sidebar$assets$common$rename_group$$($p1__78332_SHARP_$$,$path$jscomp$268$$,$last_path$jscomp$5$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78331_SHARP_$$){return $app$common$path_names$inside_path_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78331_SHARP_$$),
$path$jscomp$268$$)},$components$jscomp$14$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$99$$))}),$on_group$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),$APP.$rumext$v2$adapt$$($create_group$jscomp$1$$)],function($event$jscomp$440$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$440$$);
return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,$create_group$jscomp$1$$],null))}),$on_rename_group$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$)],function($event$jscomp$441$$,$path$jscomp$269$$,$last_path$jscomp$6$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$441$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,$path$jscomp$269$$,$cljs$cst$5623$last_path$$,$last_path$jscomp$6$$,$APP.$cljs$cst$924$accept$$,$rename_group$jscomp$1$$],null))}),$on_ungroup$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($path$jscomp$270$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$on_clear_selection$jscomp$4$$();var $undo_id$jscomp$100$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$100$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78334_SHARP_$$){return $APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78334_SHARP_$$),
$app$main$ui$workspace$sidebar$assets$common$ungroup$$($p1__78334_SHARP_$$,$path$jscomp$270$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78333_SHARP_$$){return $app$common$path_names$inside_path_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78333_SHARP_$$),$path$jscomp$270$$)},$components$jscomp$14$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$100$$))}),
$on_delete_group$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3718$assets$$,$components$jscomp$14$$,$cljs$cst$5594$on_clear_selection$$,$on_clear_selection$jscomp$4$$,$cljs$cst$5596$path_filter$$,$app$common$path_names$inside_path_QMARK_$$,
$cljs$cst$5595$delete_events$$,function($map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$){$map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$=$APP.$cljs$core$group_by$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$boolean$0$$,$APP.$app$common$types$component$is_variant_QMARK_$$),$map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$);var $map__78364__$1_non_variants$$=$APP.$cljs$core$__destructure_map$$($map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$);
$map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78364__$1_non_variants$$,!0);$map__78364__$1_non_variants$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78364__$1_non_variants$$,!1);$map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($comps_p__78365$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($comps_p__78365$$,
0,null);$comps_p__78365$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($comps_p__78365$$,1,null);return $APP.$cljs$core$first$$($comps_p__78365$$)},$APP.$cljs$core$group_by$$($APP.$cljs$cst$2000$variant_id$$,$map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$));return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78335_SHARP_$$){return $app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($p1__78335_SHARP_$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78335_SHARP_$$)]))},$map__78364_matching$jscomp$1_variant_containers_variants$jscomp$9$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78336_SHARP_$$){return $APP.$app$main$data$workspace$libraries$delete_component$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78336_SHARP_$$)],
null))},$map__78364__$1_non_variants$$))}],null))}),$on_group_combine_variants$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($path$jscomp$271$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$();var $comps$jscomp$1_page_id$jscomp$419$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78337_SHARP_$$){return $app$common$path_names$inside_path_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78337_SHARP_$$),
$path$jscomp$271$$)},$components$jscomp$14$$),$ids$jscomp$274$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$,$comps$jscomp$1_page_id$jscomp$419$$));$comps$jscomp$1_page_id$jscomp$419$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($comps$jscomp$1_page_id$jscomp$419$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids$jscomp$274$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,$comps$jscomp$1_page_id$jscomp$419$$,$APP.$cljs$cst$4424$trigger$$,"workspace:context-menu-assets-group"],null)))}),$on_drag_start$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$393$$)],function($component$jscomp$127$$,$event$jscomp$442$$){var $file_data$jscomp$116_shape_main$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),
$file_id$jscomp$393$$),$APP.$cljs$cst$142$data$$);$file_data$jscomp$116_shape_main$jscomp$12$$=$APP.$app$common$types$file$get_component_root$$($file_data$jscomp$116_shape_main$jscomp$12$$,$component$jscomp$127$$);$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$393$$,$APP.$cljs$cst$1625$component$$,$component$jscomp$127$$,$APP.$cljs$cst$1811$shape$$,$file_data$jscomp$116_shape_main$jscomp$12$$,
$APP.$cljs$cst$2574$is_local$$,$is_local$jscomp$4$$],null));$APP.$app$util$dom$dnd$set_data_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$442$$,"penpot/component",!0);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$442$$);return $APP.$app$util$dom$dnd$set_allowed_effect_BANG_$$($event$jscomp$442$$)}),$on_show_main$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$393$$),
$APP.$rumext$v2$adapt$$($is_local$jscomp$4$$)],function($component$jscomp$128_event$jscomp$443$$){$APP.$app$util$dom$stop_propagation$$($component$jscomp$128_event$jscomp$443$$);if($APP.$cljs$core$truth_$$($is_local$jscomp$4$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,$current_component_id$$])));
$component$jscomp$128_event$jscomp$443$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78338_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78338_SHARP_$$),$current_component_id$$)},$components$jscomp$14$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($file_id$jscomp$393$$,$component$jscomp$128_event$jscomp$443$$,
!1))});$on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$9$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$,$groups$jscomp$9$$));var $on_combine_as_variants$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current_full$$)],
function($event$jscomp$444_page_id$jscomp$420$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$444_page_id$jscomp$420$$);$event$jscomp$444_page_id$jscomp$420$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_and_current_full$$));var $ids$jscomp$275$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$,
$selected_full$jscomp$7$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids$jscomp$275$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,$event$jscomp$444_page_id$jscomp$420$$,$APP.$cljs$cst$4424$trigger$$,"workspace:context-menu-assets"],null)))});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,{fileId:$file_id$jscomp$393$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components"),section:$APP.$cljs$cst$1638$components$$,assetsCount:$APP.$cljs$core$count$$($components$jscomp$14$$),isOpen:$is_open$jscomp$5$$,children:[(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$cljs$cst$5593$title_button$$,children:[$is_open$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,
{selected:$APP.$cljs$core$truth_$$($is_listing_thumbs$jscomp$2$$)?"grid":"list","on-change":$toggle_list_style$jscomp$1$$,name:"listing-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"view-as-list",value:"list",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.list-view"),id:"opt-list"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"flex-grid",value:"grid",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.grid-view"),
id:"opt-grid"})]})}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$755$$=$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$16$$);return $and__5023__auto__$jscomp$755$$?$is_local$jscomp$4$$:$and__5023__auto__$jscomp$755$$}())?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components.add-component"),onClick:$add_component$jscomp$1$$,icon:"add",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{accept:$APP.$app$main$data$workspace$media$accept_image_types$$,multi:!0,ref:$input_ref$jscomp$10$$,"on-selected":$on_file_selected$jscomp$2$$})}):null]}),(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$APP.$cljs$cst$1637$content$$,children:[$is_open$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$,
{isLocal:$is_local$jscomp$4$$,selected:$selected__$1$jscomp$16$$,onRenameGroup:$on_rename_group$jscomp$3$$,onGroup:$on_group$jscomp$4$$,onAssetClick:$on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$,prefix:"",isForceOpen:$is_force_open$jscomp$2$$,doRename:$do_rename$jscomp$4$$,countVariants:$count_variants$jscomp$1$$,cancelRename:$cancel_rename$jscomp$2$$,onContextMenu:$on_context_menu$jscomp$6$$,isListingThumbs:$is_listing_thumbs$jscomp$2$$,onUngroup:$on_ungroup$jscomp$4$$,onGroupCombineVariants:$on_group_combine_variants$jscomp$2$$,
openGroups:$open_groups$jscomp$3_open_groups_ref$jscomp$1$$,onDeleteGroup:$on_delete_group$jscomp$4$$,renaming:$props_78346_renaming_QMARK_$jscomp$1_state$jscomp$1175$$?$current_component_id$$:null,onDragStart:$on_drag_start$jscomp$4$$,fileId:$file_id$jscomp$393$$,groups:$groups$jscomp$9$$,selectedFull:$selected_full$jscomp$7$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$3$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$2$$),
options:new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$APP.$cljs$core$not$$($multi_components_QMARK_$$?$multi_components_QMARK_$$:$multi_assets_QMARK_$jscomp$3$$?$multi_assets_QMARK_$jscomp$3$$:$read_only_QMARK_$jscomp$16$$):$is_local$jscomp$4$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),
$APP.$cljs$cst$266$id$$,"assets-rename-component",$APP.$cljs$cst$2402$handler$$,$on_rename$jscomp$1$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$APP.$cljs$core$not$$($multi_assets_QMARK_$jscomp$3$$?$multi_assets_QMARK_$jscomp$3$$:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$16$$)?$read_only_QMARK_$jscomp$16$$:$any_variant_QMARK_$jscomp$2_selected$jscomp$159$$):$is_local$jscomp$4$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate-main"),$APP.$cljs$cst$266$id$$,"assets-duplicate-component",$APP.$cljs$cst$2402$handler$$,$on_duplicate$jscomp$1$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$APP.$cljs$core$not$$($multi_assets_QMARK_$jscomp$3$$?$multi_assets_QMARK_$jscomp$3$$:$read_only_QMARK_$jscomp$16$$):$is_local$jscomp$4$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group"),
$APP.$cljs$cst$266$id$$,"assets-group-component",$APP.$cljs$cst$2402$handler$$,$on_group$jscomp$4$$],null):null,$multi_assets_QMARK_$jscomp$3$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-main"),$APP.$cljs$cst$266$id$$,"assets-show-main-component",$APP.$cljs$cst$2402$handler$$,$on_show_main$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$multi_components_QMARK_$$&&
$APP.$cljs$core$not$$($any_variant_QMARK_$jscomp$2_selected$jscomp$159$$):$is_local$jscomp$4$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants"),$APP.$cljs$cst$266$id$$,"assets-combine-as-variants",$APP.$cljs$cst$939$title$$,$APP.$cljs$core$truth_$$($all_same_page_QMARK_$$)?null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants-error"),
$APP.$cljs$cst$2948$disabled$$,$APP.$cljs$core$not$$($all_same_page_QMARK_$$),$APP.$cljs$cst$2402$handler$$,$on_combine_as_variants$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$16$$):$is_local$jscomp$4$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),$APP.$cljs$cst$266$id$$,"assets-delete-component",
$APP.$cljs$cst$2402$handler$$,$on_delete$jscomp$9$$],null):null],null)})]})]})};
$app$main$ui$components$editable_select$editable_select$$=function($aria_label$jscomp$9_map__78304_props_78302$$){function $handle_change_input$$($event$jscomp$447_value__$1$jscomp$44$$){$event$jscomp$447_value__$1$jscomp$44$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$447_value__$1$jscomp$44$$));var $or__5025__auto__$jscomp$inline_8845$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$447_value__$1$jscomp$44$$);return $set_value$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8845$$)?
$or__5025__auto__$jscomp$inline_8845$$:$event$jscomp$447_value__$1$jscomp$44$$)}function $set_value$$($value__$1$jscomp$43$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4563$current_value$$,$value__$1$jscomp$43$$);return $APP.$cljs$core$truth_$$($on_change$jscomp$46$$)?$on_change$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$43$$):$on_change$jscomp$46$$($value__$1$jscomp$43$$):
null}function $as_key_value$$($item$jscomp$126$$){return $APP.$cljs$core$map_QMARK_$$($item$jscomp$126$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$126$$),$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$126$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$126$$,$item$jscomp$126$$],
null)}$aria_label$jscomp$9_map__78304_props_78302$$=$APP.$rumext$v2$util$wrap_props$$($aria_label$jscomp$9_map__78304_props_78302$$);var $map__78304__$1_toggle_dropdown$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($aria_label$jscomp$9_map__78304_props_78302$$),$options$jscomp$611$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$873$options$$);$aria_label$jscomp$9_map__78304_props_78302$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,
$APP.$cljs$cst$4564$aria_label$$);var $on_change$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$4157$on_change$$),$placeholder$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$5082$placeholder$$),$value$jscomp$806$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$260$value$$),$on_blur$jscomp$11$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$5090$on_blur$$),$type$jscomp$615$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$139$type$$),$input_class$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$cljs$cst$5637$input_class$$),$class$$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,
$APP.$cljs$cst$1291$class$$),$state_STAR_$jscomp$11$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$4561$is_open_QMARK_$$,!1,$APP.$cljs$cst$4563$current_value$$,$value$jscomp$806$$,$APP.$cljs$cst$1562$top$$,null,$APP.$cljs$cst$257$left$$,null,$APP.$cljs$cst$1563$bottom$$,null],null)),$handle_key_down$jscomp$7_state$jscomp$1176$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$11$$),
$is_open_QMARK_$jscomp$1$$=$APP.$cljs$cst$4561$is_open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($handle_key_down$jscomp$7_state$jscomp$1176$$),$current_value$jscomp$6$$=$APP.$cljs$cst$4563$current_value$$.$cljs$core$IFn$_invoke$arity$1$($handle_key_down$jscomp$7_state$jscomp$1176$$),$element_id$jscomp$3$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($handle_key_down$jscomp$7_state$jscomp$1176$$),$min_val$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,
$APP.$cljs$cst$338$min$$),$max_val$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78304__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$339$max$$),$emit_blur_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$font_size_wrapper_ref$$=(0,$APP.$rumext$v2$use_ref$$)();$map__78304__$1_toggle_dropdown$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_key_down$jscomp$7_state$jscomp$1176$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,$APP.$cljs$core$not$$)});var $select_item$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$46$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$11$$)],function($event$jscomp$446_value__$1$jscomp$41$$){$event$jscomp$446_value__$1$jscomp$41$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$446_value__$1$jscomp$41$$),
"value"));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4563$current_value$$,$event$jscomp$446_value__$1$jscomp$41$$);$APP.$cljs$core$truth_$$($on_change$jscomp$46$$)&&($on_change$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$446_value__$1$jscomp$41$$):$on_change$jscomp$46$$($event$jscomp$446_value__$1$jscomp$41$$));return $APP.$cljs$core$truth_$$($on_blur$jscomp$11$$)?
$on_blur$jscomp$11$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$11$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$11$$():null}),$labels_map$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($as_key_value$$),$options$jscomp$611$$);$handle_key_down$jscomp$7_state$jscomp$1176$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_value$$)],function($event$jscomp$448$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$615$$,
"number")){var $up_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$448$$),$down_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$448$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?$up_QMARK_$jscomp$3$$:$down_QMARK_$jscomp$3$$)){$APP.$app$util$dom$prevent_default$$($event$jscomp$448$$);var $value__$1$jscomp$45$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$448$$)),$new_value$jscomp$20$$=
function(){var $or__5025__auto__$jscomp$1122$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$45$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1122$$)?$or__5025__auto__$jscomp$1122$$:$value__$1$jscomp$45$$}()+($event$jscomp$448$$.shiftKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?10:-10:$event$jscomp$448$$.altKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?.1:-.1:$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?1:-1);return $set_value$$($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$761$$=
$APP.$app$common$math$finite_QMARK_$$($min_val$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$761$$)?$new_value$jscomp$20$$<$min_val$jscomp$2$$:$and__5023__auto__$jscomp$761$$}())?$min_val$jscomp$2$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$762$$=$APP.$app$common$math$finite_QMARK_$$($max_val$jscomp$3$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$762$$)?$new_value$jscomp$20$$>$max_val$jscomp$3$$:$and__5023__auto__$jscomp$762$$}())?$max_val$jscomp$3$$:
$new_value$jscomp$20$$)}}return null});var $handle_focus$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($emit_blur_QMARK_$$,!1)}),$handle_blur$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($emit_blur_QMARK_$$,!0);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(200,function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($on_blur$jscomp$11$$)?
$APP.$rumext$v2$ref_val$$($emit_blur_QMARK_$$):$on_blur$jscomp$11$$)?$on_blur$jscomp$11$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$11$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$11$$():null})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$806$$),$APP.$rumext$v2$adapt$$($current_value$jscomp$6$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$806$$),
$current_value$jscomp$6$$)?$APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$11$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4563$current_value$$,$value$jscomp$806$$],null)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$1$$)],function(){var $nodes_78341_wrapper_node_78339$$=$APP.$rumext$v2$ref_val$$($font_size_wrapper_ref$$),$G__78310_78345__$1_node_78340$$=$APP.$goog$dom$getElementByClass$$("checked-element is-selected",
$nodes_78341_wrapper_node_78339$$);$nodes_78341_wrapper_node_78339$$=$goog$dom$getElementsByClass$$("checked-element-value",$nodes_78341_wrapper_node_78339$$);var $closest_value_78343$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(function($a$jscomp$427$$,$b$jscomp$361$$){return $APP.$cljs$core$first$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78300_SHARP_$$){return $APP.$app$common$math$abs$$($p1__78300_SHARP_$$-$b$jscomp$361$$)},$a$jscomp$427$$))}($options$jscomp$611$$,
$value$jscomp$806$$));$APP.$cljs$core$truth_$$($is_open_QMARK_$jscomp$1$$)&&($G__78310_78345__$1_node_78340$$!=null?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78310_78345__$1_node_78340$$,!1):($G__78310_78345__$1_node_78340$$=$nodes_78341_wrapper_node_78339$$==null?null:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78301_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($closest_value_78343$$,$p1__78301_SHARP_$$!=
null?$p1__78301_SHARP_$$.innerText:null)},$nodes_78341_wrapper_node_78339$$),$G__78310_78345__$1_node_78340$$!=null&&$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78310_78345__$1_node_78340$$,!1)));return $APP.$rumext$v2$set_ref_val_BANG_$$($emit_blur_QMARK_$$,$APP.$cljs$core$not$$($is_open_QMARK_$jscomp$1$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:function($node$jscomp$410$$){return $APP.$cljs$core$truth_$$($node$jscomp$410$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $left$jscomp$34_temp__5825__auto__$jscomp$360$$=
$APP.$cljs$core$truth_$$($node$jscomp$410$$)?$APP.$app$util$dom$get_bounding_rect$$($node$jscomp$410$$):null;if($APP.$cljs$core$truth_$$($left$jscomp$34_temp__5825__auto__$jscomp$360$$)){var $map__78308__$1_window_height$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$dom$get_window_size$$());$map__78308__$1_window_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78308__$1_window_height$jscomp$2$$,$APP.$cljs$cst$1522$height$$);var $height$jscomp$164_map__78309__$1$$=
$APP.$cljs$core$__destructure_map$$($left$jscomp$34_temp__5825__auto__$jscomp$360$$);$left$jscomp$34_temp__5825__auto__$jscomp$360$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$164_map__78309__$1$$,$APP.$cljs$cst$257$left$$);var $top$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$164_map__78309__$1$$,$APP.$cljs$cst$1562$top$$);$height$jscomp$164_map__78309__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$164_map__78309__$1$$,
$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$257$left$$,$left$jscomp$34_temp__5825__auto__$jscomp$360$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1562$top$$,$map__78308__$1_window_height$jscomp$2$$-$top$jscomp$16$$>=300?$top$jscomp$16$$+$height$jscomp$164_map__78309__$1$$:null,$APP.$cljs$cst$1563$bottom$$,$map__78308__$1_window_height$jscomp$2$$-
$top$jscomp$16$$<300?$map__78308__$1_window_height$jscomp$2$$-$top$jscomp$16$$:null]))}return null}):null},className:""+($class$$jscomp$64$$??"")+" main_ui_components_editable_select__editable-select",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$615$$,"number")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:function(){var $or__5025__auto__$jscomp$1123$$=$current_value$jscomp$6$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($labels_map$$,
$current_value$jscomp$6$$,$current_value$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1123$$)?$or__5025__auto__$jscomp$1123$$:""}(),className:$input_class$$,onChange:$set_value$$,onFocus:$handle_focus$jscomp$3$$,onBlur:$handle_blur$jscomp$4$$,"aria-label":$aria_label$jscomp$9_map__78304_props_78302$$,placeholder:$placeholder$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$handle_change_input$$,"aria-label":$aria_label$jscomp$9_map__78304_props_78302$$,className:$input_class$$,
placeholder:$placeholder$jscomp$4$$,value:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$806$$,$APP.$cljs$cst$1616$multiple$$)?null:function(){var $or__5025__auto__$jscomp$1124$$=$current_value$jscomp$6$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($labels_map$$,$current_value$jscomp$6$$,$current_value$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1124$$)?$or__5025__auto__$jscomp$1124$$:""}(),onFocus:$handle_focus$jscomp$3$$,onBlur:$handle_blur$jscomp$4$$,
type:$type$jscomp$615$$,onKeyDown:$handle_key_down$jscomp$7_state$jscomp$1176$$}),(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$map__78304__$1_toggle_dropdown$jscomp$3$$,className:"main_ui_components_editable_select__dropdown-button",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$truth_$$($is_open_QMARK_$jscomp$1$$)?$is_open_QMARK_$jscomp$1$$:!1,"on-close":function($event$jscomp$445$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$445$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!1)},children:(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$font_size_wrapper_ref$$,className:"main_ui_components_editable_select__custom-select-dropdown",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$143$$,$JSCompiler_temp_const$jscomp$1783_p__78314$$){var $JSCompiler_temp$jscomp$1785_index$jscomp$477$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1783_p__78314$$,0,null),$item$jscomp$127_value__$1$jscomp$inline_8848$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1783_p__78314$$,1,null);$JSCompiler_temp_const$jscomp$1783_p__78314$$=$out_arr__44124__auto__$jscomp$143$$.push;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1472$separator$$,$item$jscomp$127_value__$1$jscomp$inline_8848$$))$JSCompiler_temp$jscomp$1785_index$jscomp$477$$=
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_components_editable_select__separator"},""+($element_id$jscomp$3$$??"")+"-"+($JSCompiler_temp$jscomp$1785_index$jscomp$477$$??""));else{var $label$jscomp$inline_8849_vec__78318$jscomp$inline_8847$$=$as_key_value$$($item$jscomp$127_value__$1$jscomp$inline_8848$$);$item$jscomp$127_value__$1$jscomp$inline_8848$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($label$jscomp$inline_8849_vec__78318$jscomp$inline_8847$$,0,null);$label$jscomp$inline_8849_vec__78318$jscomp$inline_8847$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($label$jscomp$inline_8849_vec__78318$jscomp$inline_8847$$,1,null);$JSCompiler_temp$jscomp$1785_index$jscomp$477$$=(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":$item$jscomp$127_value__$1$jscomp$inline_8848$$,onClick:$select_item$jscomp$1$$,className:"main_ui_components_editable_select__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(""+($item$jscomp$127_value__$1$jscomp$inline_8848$$??""),$current_value$jscomp$6$$)?
"main_ui_components_editable_select__is-selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_editable_select__label",children:$label$jscomp$inline_8849_vec__78318$jscomp$inline_8847$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_editable_select__check-icon",children:$APP.$app$main$ui$icons$tick$$})]},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($element_id$jscomp$3$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1785_index$jscomp$477$$)].join(""))}$JSCompiler_temp_const$jscomp$1783_p__78314$$.call($out_arr__44124__auto__$jscomp$143$$,
$JSCompiler_temp$jscomp$1785_index$jscomp$477$$);return $out_arr__44124__auto__$jscomp$143$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$options$jscomp$611$$))})})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$=function($value$jscomp$807$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$807$$,$APP.$cljs$cst$1616$multiple$$)?"":$APP.$app$util$strings$format_precision$$($value$jscomp$807$$,2)};
$app$main$ui$workspace$sidebar$options$menus$typography$get_next_font$$=function($index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$,$fonts$jscomp$30$$){$index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$);var $id$jscomp$941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$,$APP.$cljs$cst$266$id$$);if($APP.$cljs$core$seq$$($fonts$jscomp$30$$)){$index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$=
$APP.$app$common$data$index_of_pred$$($fonts$jscomp$30$$,function($p1__78347_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78347_SHARP_$$),$id$jscomp$941$$)});$index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$=$APP.$cljs$core$truth_$$($index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$)?$index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$:-1;try{var $or__5025__auto__$jscomp$1126$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts$jscomp$30$$,$index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$+1)}catch($e78350$jscomp$inline_8851$$){$or__5025__auto__$jscomp$1126$$=null}return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1126$$)?$or__5025__auto__$jscomp$1126$$:$APP.$cljs$core$first$$($fonts$jscomp$30$$)}return $index$jscomp$478_index__$1$jscomp$23_map__78349__$1_p__78348$$};
$app$main$ui$workspace$sidebar$options$menus$typography$get_prev_font$$=function($index$jscomp$479_map__78353__$1_p__78352$$,$fonts$jscomp$31$$){$index$jscomp$479_map__78353__$1_p__78352$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$479_map__78353__$1_p__78352$$);var $id$jscomp$942$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$479_map__78353__$1_p__78352$$,$APP.$cljs$cst$266$id$$);if($APP.$cljs$core$seq$$($fonts$jscomp$31$$)){$index$jscomp$479_map__78353__$1_p__78352$$=
$APP.$app$common$data$index_of_pred$$($fonts$jscomp$31$$,function($p1__78351_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78351_SHARP_$$),$id$jscomp$942$$)});try{var $or__5025__auto__$jscomp$1128$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts$jscomp$31$$,$index$jscomp$479_map__78353__$1_p__78352$$-1)}catch($e78354$jscomp$inline_8853$$){$or__5025__auto__$jscomp$1128$$=null}return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1128$$)?
$or__5025__auto__$jscomp$1128$$:$APP.$cljs$core$peek$$($fonts$jscomp$31$$)}return $index$jscomp$479_map__78353__$1_p__78352$$};
$app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$=function($map__78359__$1_p__78358_xform$jscomp$40$$,$fonts$jscomp$32$$){$map__78359__$1_p__78358_xform$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($map__78359__$1_p__78358_xform$jscomp$40$$);var $term$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78359__$1_p__78358_xform$jscomp$40$$,$APP.$cljs$cst$2513$term$$),$backends$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78359__$1_p__78358_xform$jscomp$40$$,
$cljs$cst$5638$backends$$),$term__$1$jscomp$1$$=$APP.$cuerdas$core$lower$$($term$jscomp$8$$);$map__78359__$1_p__78358_xform$jscomp$40$$=function(){var $G__78360_G__78360__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$identity$$);$G__78360_G__78360__$1$$=$APP.$cljs$core$seq$$($term__$1$jscomp$1$$)?$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($G__78360_G__78360__$1$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78356_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78356_SHARP_$$)),
$term__$1$jscomp$1$$)})):$G__78360_G__78360__$1$$;return $APP.$cljs$core$seq$$($backends$$)?$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($G__78360_G__78360__$1$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78357_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($backends$$,$APP.$cljs$cst$2584$backend$$.$cljs$core$IFn$_invoke$arity$1$($p1__78357_SHARP_$$))})):$G__78360_G__78360__$1$$}();return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$map__78359__$1_p__78358_xform$jscomp$40$$,$fonts$jscomp$32$$)};
$app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$=function($props_78363_recent_fonts__$1$$){var $current_font$jscomp$1$$=$props_78363_recent_fonts__$1$$.currentFont,$on_close$jscomp$27$$=$props_78363_recent_fonts__$1$$.onClose,$show_recent$$=$props_78363_recent_fonts__$1$$.showRecent,$full_size_full_size_QMARK_$$=$props_78363_recent_fonts__$1$$.fullSize,$on_select$jscomp$2$$=$props_78363_recent_fonts__$1$$.onSelect,$selected$jscomp$160$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($current_font$jscomp$1$$),
$state_STAR_$jscomp$12$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2513$term$$,"",$cljs$cst$5638$backends$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null)}),$state$jscomp$1177$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$12$$),$flist$$=(0,$APP.$rumext$v2$use_ref$$)(),$input$jscomp$71$$=(0,$APP.$rumext$v2$use_ref$$)(),$fonts$jscomp$33$$=$APP.$rumext$v2$deref$$($APP.$app$main$fonts$fonts$$),$fonts__$1$jscomp$3$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1177$$),$APP.$rumext$v2$adapt$$($fonts$jscomp$33$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$($state$jscomp$1177$$,$fonts$jscomp$33$$)}),$recent_fonts$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_fonts$$);$props_78363_recent_fonts__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1177$$),
$APP.$rumext$v2$adapt$$($recent_fonts$jscomp$1$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$($state$jscomp$1177$$,$recent_fonts$jscomp$1$$)});$full_size_full_size_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$truth_$$($full_size_full_size_QMARK_$$)?$show_recent$$:$full_size_full_size_QMARK_$$);var $select_next$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function($event$jscomp$449$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$449$$);
$APP.$app$util$dom$prevent_default$$($event$jscomp$449$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$160$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_next_font$$,$fonts__$1$jscomp$3$$)}),$select_prev$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function($event$jscomp$450$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$450$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$450$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$160$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_prev_font$$,$fonts__$1$jscomp$3$$)}),$on_key_down$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function($event$jscomp$451$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$451$$))?$select_prev$$.$cljs$core$IFn$_invoke$arity$1$?$select_prev$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$451$$):
$select_prev$$($event$jscomp$451$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$451$$))?$select_next$$.$cljs$core$IFn$_invoke$arity$1$?$select_next$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$451$$):$select_next$$($event$jscomp$451$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$451$$))?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$27$$():
$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$451$$))?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$27$$():$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($input$jscomp$71$$))}),$on_filter_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$452$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$12$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2513$term$$,$event$jscomp$452$$)}),$on_select_and_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$27$$)],function($font$jscomp$45$$){$on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$45$$):$on_select$jscomp$2$$($font$jscomp$45$$);return $on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?
$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$27$$()});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function(){var $key$jscomp$410$$=$APP.$goog$events$listen$$(document,"keydown",$on_key_down$jscomp$13$$);return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$410$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($selected$jscomp$160$$))],
function(){var $temp__5825__auto__$jscomp$361$$=$APP.$rumext$v2$ref_val$$($flist$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$361$$)){var $temp__5825__auto____$1$jscomp$21$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($selected$jscomp$160$$));return $APP.$cljs$core$truth_$$($temp__5825__auto____$1$jscomp$21$$)?$temp__5825__auto__$jscomp$361$$.scrollToRow($temp__5825__auto____$1$jscomp$21$$):null}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($selected$jscomp$160$$))],
function(){var $G__78369$$=$APP.$cljs$core$_deref$$($selected$jscomp$160$$);return $on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78369$$):$on_select$jscomp$2$$($G__78369$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($APP.$cljs$cst$1981$typography$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$));
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($APP.$cljs$cst$1981$typography$$))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $index$jscomp$481$$=$APP.$app$common$data$index_of_pred$$($fonts__$1$jscomp$3$$,function($p1__78361_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78361_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_font$jscomp$1$$))}),$inst$jscomp$6$$=$APP.$rumext$v2$ref_val$$($flist$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $offset$jscomp$208$$=$inst$jscomp$6$$.getOffsetForRow({alignment:"center",index:$index$jscomp$481$$});return $inst$jscomp$6$$.scrollToPosition($offset$jscomp$208$$)})});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-selector",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown "+($full_size_full_size_QMARK_$$?"main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown-full-size":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__header",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_filter_change$$,value:$APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1177$$),
autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.search-font")}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_78363_recent_fonts__$1$$)?$show_recent$$:$props_78363_recent_fonts__$1$$)?(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_workspace_sidebar_options_menus_typography__show-recent",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_sidebar_options_menus_typography__header-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.recent-fonts")}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$144$$,$font$jscomp$46_p__78370$$){var $idx$jscomp$120$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$46_p__78370$$,0,null);$font$jscomp$46_p__78370$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$46_p__78370$$,1,null);$out_arr__44124__auto__$jscomp$144$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_item_STAR_$$,
{font:$font$jscomp$46_p__78370$$,style:{},onClick:$on_select_and_close$$,isCurrent:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$46_p__78370$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($selected$jscomp$160$$)))},"font-"+($idx$jscomp$120$$??"")));return $out_arr__44124__auto__$jscomp$144$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($props_78363_recent_fonts__$1$$))]}):
null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__fonts-list "+($full_size_full_size_QMARK_$$?"main_ui_workspace_sidebar_options_menus_typography__fonts-list-full-size":""),children:(0,$APP.$rumext$v2$jsx$$)($shadow$js$shim$module$0react_virtualized$$.AutoSizer,{children:function($props$jscomp$322$$){return(0,$APP.$rumext$v2$create_element$$)($shadow$js$shim$module$0react_virtualized$$.List,{height:$props$jscomp$322$$.height,ref:$flist$$,width:$props$jscomp$322$$.width,
rowCount:$APP.$cljs$core$count$$($fonts__$1$jscomp$3$$),rowHeight:36,rowRenderer:function($p1__78362_SHARP_$$){var $G__78375$$=$APP.$cljs$core$_deref$$($selected$jscomp$160$$);return $app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$.$cljs$core$IFn$_invoke$arity$4$?$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$.$cljs$core$IFn$_invoke$arity$4$($fonts__$1$jscomp$3$$,$G__78375$$,$on_select_and_close$$,$p1__78362_SHARP_$$):$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$($fonts__$1$jscomp$3$$,
$G__78375$$,$on_select_and_close$$,$p1__78362_SHARP_$$)}})}})})]})})};
$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$=function($font$jscomp$47_fonts$jscomp$34$$,$selected$jscomp$161$$,$on_select$jscomp$3$$,$props$jscomp$323$$){var $key$jscomp$411$$=$props$jscomp$323$$.key,$style$jscomp$73$$=$props$jscomp$323$$.style;$font$jscomp$47_fonts$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($font$jscomp$47_fonts$jscomp$34$$,$props$jscomp$323$$.index);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_item_STAR_$$,{font:$font$jscomp$47_fonts$jscomp$34$$,
style:$style$jscomp$73$$,onClick:$on_select$jscomp$3$$,isCurrent:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$47_fonts$jscomp$34$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$161$$))},$key$jscomp$411$$)};
$app$main$ui$workspace$sidebar$options$menus$typography$font_options$$=function($font_size$jscomp$12_on_font_select_props_78379$$){var $on_change$jscomp$47$$=$font_size$jscomp$12_on_font_select_props_78379$$["on-change"],$full_size_selector$$=$font_size$jscomp$12_on_font_select_props_78379$$["full-size-selector"],$on_blur$jscomp$12$$=$font_size$jscomp$12_on_font_select_props_78379$$["on-blur"],$show_recent$jscomp$1$$=$font_size$jscomp$12_on_font_select_props_78379$$["show-recent"],$font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$=
$APP.$cljs$core$__destructure_map$$($font_size$jscomp$12_on_font_select_props_78379$$.values),$font_id$jscomp$36_font_id__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$,$APP.$cljs$cst$1757$font_id$$);$font_size$jscomp$12_on_font_select_props_78379$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$,$APP.$cljs$cst$1760$font_size$$);$font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$,$APP.$cljs$cst$1759$font_variant_id$$);$font_id$jscomp$36_font_id__$1$$=$APP.$cljs$core$truth_$$($font_id$jscomp$36_font_id__$1$$)?$font_id$jscomp$36_font_id__$1$$:$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);var $font_size__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($font_size$jscomp$12_on_font_select_props_78379$$)?
$font_size$jscomp$12_on_font_select_props_78379$$:$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$),$font_variant_id__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$)?$font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$:$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$),$fonts$jscomp$35$$=$APP.$rumext$v2$deref$$($APP.$app$main$fonts$fontsdb$$),
$font$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$35$$,$font_id$jscomp$36_font_id__$1$$),$last_font$$=(0,$APP.$rumext$v2$use_ref$$)(null),$open_selector_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$change_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$47$$),$APP.$rumext$v2$adapt$$($fonts$jscomp$35$$)],function($G__78383_78404_new_font_id$$){var $map__78381_map__78381__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$35$$,$G__78383_78404_new_font_id$$);$map__78381_map__78381__$1$$=$APP.$cljs$core$__destructure_map$$($map__78381_map__78381__$1$$);var $family$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78381_map__78381__$1$$,$APP.$cljs$cst$2675$family$$),$id$jscomp$943_map__78382$$=$APP.$app$main$fonts$get_default_variant$$($map__78381_map__78381__$1$$),$map__78382__$1_style$jscomp$74$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$943_map__78382$$);
$id$jscomp$943_map__78382$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78382__$1_style$jscomp$74$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$448$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78382__$1_style$jscomp$74$$,$APP.$cljs$cst$725$name$$),$weight$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78382__$1_style$jscomp$74$$,$APP.$cljs$cst$1996$weight$$);$map__78382__$1_style$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78382__$1_style$jscomp$74$$,
$APP.$cljs$cst$1904$style$$);$G__78383_78404_new_font_id$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,$G__78383_78404_new_font_id$$,$APP.$cljs$cst$1758$font_family$$,$family$jscomp$7$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$core$truth_$$($id$jscomp$943_map__78382$$)?$id$jscomp$943_map__78382$$:$name$jscomp$448$$,$APP.$cljs$cst$1761$font_weight$$,$weight$jscomp$9$$,$APP.$cljs$cst$1762$font_style$$,$map__78382__$1_style$jscomp$74$$],null);$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($G__78383_78404_new_font_id$$):$on_change$jscomp$47$$($G__78383_78404_new_font_id$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($last_font$$,$map__78381_map__78381__$1$$)}),$on_font_size_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$47$$)],function($G__78384_new_font_size$$){if($APP.$cuerdas$core$empty_QMARK_$$($G__78384_new_font_size$$))return null;$G__78384_new_font_size$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78384_new_font_size$$)],null);return $on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($G__78384_new_font_size$$):$on_change$jscomp$47$$($G__78384_new_font_size$$)}),$on_font_variant_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$48$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$47$$)],function($new_variant_id$jscomp$2$$){var $G__78385_78405_variant$jscomp$23$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78378_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_variant_id$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78378_SHARP_$$))},$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$));$G__78385_78405_variant$jscomp$23$$!=null&&($G__78385_78405_variant$jscomp$23$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$),$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$2675$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$),$APP.$cljs$cst$1759$font_variant_id$$,$new_variant_id$jscomp$2$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($G__78385_78405_variant$jscomp$23$$),$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($G__78385_78405_variant$jscomp$23$$)],
null),$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($G__78385_78405_variant$jscomp$23$$):$on_change$jscomp$47$$($G__78385_78405_variant$jscomp$23$$));return $on_blur$jscomp$12$$!=null?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$12$$():null});$font_size$jscomp$12_on_font_select_props_78379$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_font$$)],
function($G__78386_78406_font_STAR_$$){$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$48$$,$G__78386_78406_font_STAR_$$)&&($G__78386_78406_font_STAR_$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__78386_78406_font_STAR_$$),$change_font$$.$cljs$core$IFn$_invoke$arity$1$?$change_font$$.$cljs$core$IFn$_invoke$arity$1$($G__78386_78406_font_STAR_$$):$change_font$$($G__78386_78406_font_STAR_$$));return $on_blur$jscomp$12$$!=null?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?
$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$12$$():null});$font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($open_selector_QMARK_$$,!1);$on_blur$jscomp$12$$!=null&&($on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$12$$());return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($last_font$$))?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$add_recent_font$$($APP.$rumext$v2$ref_val$$($last_font$$))):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($open_selector_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,{currentFont:$font$jscomp$48$$,onClose:$font_variant_id$jscomp$18_map__78380__$1_on_font_selector_close$$,
onSelect:$font_size$jscomp$12_on_font_select_props_78379$$,fullSize:$full_size_selector$$,showRecent:$show_recent$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-family"),onClick:function(){return $APP.$cljs$core$reset_BANG_$$($open_selector_QMARK_$$,!0)},className:"main_ui_workspace_sidebar_options_menus_typography__font-option",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$font_id$jscomp$36_font_id__$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("mixed",$font_id$jscomp$36_font_id__$1$$)?"--":$font$jscomp$48$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__font-option-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-down",className:"main_ui_workspace_sidebar_options_menus_typography__dropdown-icon",size:"s"})]}):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.deleted-placeholder")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-modifiers",children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-size"),className:"main_ui_workspace_sidebar_options_menus_typography__font-size-options",
children:function(){var $size_options$jscomp$1_size_options__$1$$=new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[8,9,10,11,12,14,16,18,24,36,48,72],null);$size_options$jscomp$1_size_options__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_size__$1$jscomp$1$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[""],null),$size_options$jscomp$1_size_options__$1$$):$size_options$jscomp$1_size_options__$1$$;return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$editable_select$editable_select$$,{min:3,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),value:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_size__$1$jscomp$1$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$cst$1616$multiple$$:$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($font_size__$1$jscomp$1$$),
"on-blur":$on_blur$jscomp$12$$,type:"number","input-class":"main_ui_workspace_sidebar_options_menus_typography__numeric-input",max:1E3,"class":"main_ui_workspace_sidebar_options_menus_typography__font-size-select",options:$size_options$jscomp$1_size_options__$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-size"),"on-change":$on_font_size_change$$})}()}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-style"),
className:"main_ui_workspace_sidebar_options_menus_typography__font-variant-options",children:function(){var $basic_variant_options_variant_options$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($variant$jscomp$24$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$24$$),$APP.$cljs$cst$302$key$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$variant$jscomp$24$$])),
$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$24$$)],null)},$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$));$basic_variant_options_variant_options$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id__$1$jscomp$1$$,$APP.$cljs$cst$1616$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id__$1$jscomp$1$$,"mixed")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($basic_variant_options_variant_options$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$302$key$$,$cljs$cst$5639$multiple_variants$$,$APP.$cljs$cst$2287$label$$,"--"],null)):$basic_variant_options_variant_options$$;var $font_variant_value_font_variant_value__$1$$=$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($font_variant_id__$1$jscomp$1$$);$font_variant_value_font_variant_value__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_value_font_variant_value__$1$$,
"mixed")?"":$font_variant_value_font_variant_value__$1$$;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_typography__font-variant-select","default-value":$font_variant_value_font_variant_value__$1$$,options:$basic_variant_options_variant_options$$,"on-change":$on_font_variant_change$$,"on-blur":$on_blur$jscomp$12$$})}()})]})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$spacing_options$$=function($line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$){function $handle_change$jscomp$4$$($G__78391_value$jscomp$808$$,$attr$jscomp$62$$){$G__78391_value$jscomp$808$$=$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$attr$jscomp$62$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78391_value$jscomp$808$$)]);return $on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($G__78391_value$jscomp$808$$):
$on_change$jscomp$48$$($G__78391_value$jscomp$808$$)}var $on_change$jscomp$48$$=$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$["on-change"],$on_blur$jscomp$13$$=$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$["on-blur"],$letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$=$APP.$cljs$core$__destructure_map$$($line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$.values);$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$,
$APP.$cljs$cst$1765$line_height$$);$letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$,$APP.$cljs$cst$1766$letter_spacing$$);$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$=$APP.$cljs$core$truth_$$($line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$)?$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$:"1.2";$letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$=
$APP.$cljs$core$truth_$$($letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$)?$letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$:"0";return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__spacing-options",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.line-height"),className:"main_ui_workspace_sidebar_options_menus_typography__line-height",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.line-height"),className:"main_ui_workspace_sidebar_options_menus_typography__icon",children:$APP.$app$main$ui$icons$text_lineheight$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:-200,onChange:function($p1__78387_SHARP_$$){return $handle_change$jscomp$4$$($p1__78387_SHARP_$$,$APP.$cljs$cst$1765$line_height$$)},"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.line-height"),
className:"main_ui_workspace_sidebar_options_menus_typography__line-height-input",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",max:200,value:$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$),onBlur:$on_blur$jscomp$13$$,
nillable:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$line_height$jscomp$20_line_height__$1$jscomp$5_props_78389$$),defaultValue:"1.2",step:.1})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.letter-spacing"),className:"main_ui_workspace_sidebar_options_menus_typography__letter-spacing",children:[(0,$APP.$rumext$v2$jsx$$)("span",{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.letter-spacing"),
className:"main_ui_workspace_sidebar_options_menus_typography__icon",children:$APP.$app$main$ui$icons$text_letterspacing$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:-200,onChange:function($p1__78388_SHARP_$$){return $handle_change$jscomp$4$$($p1__78388_SHARP_$$,$APP.$cljs$cst$1766$letter_spacing$$)},"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.letter-spacing"),className:"main_ui_workspace_sidebar_options_menus_typography__letter-spacing-input",
placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",max:200,value:$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$),onBlur:$on_blur$jscomp$13$$,nillable:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$letter_spacing$jscomp$7_letter_spacing__$1_map__78390__$1$$),defaultValue:"0",step:.1})]})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$text_transform_options$$=function($props_78392$$){var $on_change$jscomp$49$$=$props_78392$$["on-change"],$on_blur$jscomp$14$$=$props_78392$$["on-blur"],$values$jscomp$77$$=$props_78392$$.values,$text_transform$jscomp$7$$=function(){var $or__5025__auto__$jscomp$1135$$=$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$77$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1135$$)?$or__5025__auto__$jscomp$1135$$:
"none"}(),$unset_value$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?"none":"unset";return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__text-transform",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$text_transform$jscomp$7$$,"on-change":function($G__78393_78408_G__78394_78409_type$jscomp$616$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($text_transform$jscomp$7$$,
$G__78393_78408_G__78394_78409_type$jscomp$616$$)?($G__78393_78408_G__78394_78409_type$jscomp$616$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1769$text_transform$$,$unset_value$$],null),$on_change$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__78393_78408_G__78394_78409_type$jscomp$616$$):$on_change$jscomp$49$$($G__78393_78408_G__78394_78409_type$jscomp$616$$)):($G__78393_78408_G__78394_78409_type$jscomp$616$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1769$text_transform$$,$G__78393_78408_G__78394_78409_type$jscomp$616$$],null),$on_change$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__78393_78408_G__78394_78409_type$jscomp$616$$):$on_change$jscomp$49$$($G__78393_78408_G__78394_78409_type$jscomp$616$$));return $on_blur$jscomp$14$$!=null?$on_blur$jscomp$14$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$14$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$14$$():null},
name:"text-transform",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"text-uppercase",type:"checkbox",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform.uppercase"),value:"uppercase",id:"text-transform-uppercase"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"text-mixed",type:"checkbox",value:"capitalize",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform.capitalize"),
id:"text-transform-capitalize"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"text-lowercase",type:"checkbox",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform.lowercase"),value:"lowercase",id:"text-transform-lowercase"})]})})};
$app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$=function($full_size_selector_QMARK__props_78395$$){var $on_change$jscomp$50_opts$jscomp$311$$=$full_size_selector_QMARK__props_78395$$.onChange,$on_blur$jscomp$15$$=$full_size_selector_QMARK__props_78395$$.onBlur,$show_recent$jscomp$2$$=$full_size_selector_QMARK__props_78395$$.showRecent,$ids$jscomp$276$$=$full_size_selector_QMARK__props_78395$$.ids,$values$jscomp$78$$=$full_size_selector_QMARK__props_78395$$.values,$editor$jscomp$7$$=
$full_size_selector_QMARK__props_78395$$.editor;$full_size_selector_QMARK__props_78395$$=$APP.$cljs$core$truth_$$($show_recent$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$((0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$sidebar$$),$APP.$cljs$cst$258$right$$):$show_recent$jscomp$2$$;$on_change$jscomp$50_opts$jscomp$311$$={editor:$editor$jscomp$7$$,ids:$ids$jscomp$276$$,values:$values$jscomp$78$$,"on-change":$on_change$jscomp$50_opts$jscomp$311$$,"on-blur":$on_blur$jscomp$15$$,
"show-recent":$show_recent$jscomp$2$$,"full-size-selector":$full_size_selector_QMARK__props_78395$$};return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__text-options "+($APP.$cljs$core$truth_$$($full_size_selector_QMARK__props_78395$$)?"main_ui_workspace_sidebar_options_menus_typography__text-options-full-size":""),children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_options$$,$on_change$jscomp$50_opts$jscomp$311$$),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-variations",children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$spacing_options$$,$on_change$jscomp$50_opts$jscomp$311$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$text_transform_options$$,$on_change$jscomp$50_opts$jscomp$311$$)]})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$typography_entry$$=function($on_detach$jscomp$1_props_78399$$){var $on_change$jscomp$52$$=$on_detach$jscomp$1_props_78399$$["on-change"],$selected_QMARK_$jscomp$2$$=$on_detach$jscomp$1_props_78399$$["selected?"],$is_asset_QMARK_$jscomp$1$$=$on_detach$jscomp$1_props_78399$$["is-asset?"],$editing_QMARK_$jscomp$6$$=$on_detach$jscomp$1_props_78399$$["editing?"],$focus_name_QMARK_$$=$on_detach$jscomp$1_props_78399$$["focus-name?"],$file_id$jscomp$395$$=
$on_detach$jscomp$1_props_78399$$["file-id"],$external_open_STAR_$$=$on_detach$jscomp$1_props_78399$$["external-open*"],$renaming_QMARK_$jscomp$2$$=$on_detach$jscomp$1_props_78399$$["renaming?"],$local_QMARK_$jscomp$8$$=$on_detach$jscomp$1_props_78399$$["local?"],$on_context_menu$jscomp$7$$=$on_detach$jscomp$1_props_78399$$["on-context-menu"],$on_click$jscomp$42$$=$on_detach$jscomp$1_props_78399$$["on-click"],$typography$jscomp$33$$=$on_detach$jscomp$1_props_78399$$.typography;$on_detach$jscomp$1_props_78399$$=
$on_detach$jscomp$1_props_78399$$["on-detach"];var $name_input_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(),$editable_QMARK_$jscomp$9_read_only_QMARK_$jscomp$17$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$editable_QMARK_$jscomp$9_read_only_QMARK_$jscomp$17$$=$APP.$cljs$core$truth_$$($local_QMARK_$jscomp$8$$)?$APP.$cljs$core$not$$($editable_QMARK_$jscomp$9_read_only_QMARK_$jscomp$17$$):$local_QMARK_$jscomp$8$$;var $open_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($editing_QMARK_$jscomp$6$$),
$open_QMARK_$jscomp$11$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$4$$),$font_data$jscomp$13$$=$APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)),$name_only_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$13$$)),$on_name_blur$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$52$$)],
function($G__78400_78413_event$jscomp$453_name$jscomp$449$$){$G__78400_78413_event$jscomp$453_name$jscomp$449$$=(0,$APP.$app$util$dom$get_target_val$$)($G__78400_78413_event$jscomp$453_name$jscomp$449$$);if($APP.$cuerdas$core$blank_QMARK_$$($G__78400_78413_event$jscomp$453_name$jscomp$449$$))return null;$G__78400_78413_event$jscomp$453_name$jscomp$449$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$G__78400_78413_event$jscomp$453_name$jscomp$449$$],null);$on_change$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$($G__78400_78413_event$jscomp$453_name$jscomp$449$$):$on_change$jscomp$52$$($G__78400_78413_event$jscomp$453_name$jscomp$449$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78398_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__78398_SHARP_$$,$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$dissoc$$,$cljs$cst$5647$rename_typography$$)})}),$on_open$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$4$$,
!0)}),$on_close$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$4$$,!1)}),$navigate_to_library$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$395$$)],function(){return $APP.$cljs$core$truth_$$($file_id$jscomp$395$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,
$file_id$jscomp$395$$]))):null}),$on_key_down$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$454_input_node$jscomp$7$$){var $enter_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$454_input_node$jscomp$7$$),$esc_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$454_input_node$jscomp$7$$);$event$jscomp$454_input_node$jscomp$7$$=$APP.$app$util$dom$get_target$$($event$jscomp$454_input_node$jscomp$7$$);$enter_QMARK_$jscomp$2$$&&
$APP.$app$util$dom$blur_BANG_$$($event$jscomp$454_input_node$jscomp$7$$);return $esc_QMARK_$jscomp$3$$?$APP.$app$util$dom$blur_BANG_$$($event$jscomp$454_input_node$jscomp$7$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$6$$)],function(){return $APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$6$$)?$APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$4$$,$editing_QMARK_$jscomp$6$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_QMARK_$jscomp$11$$)],
function(){return $external_open_STAR_$$!=null?$APP.$cljs$core$reset_BANG_$$($external_open_STAR_$$,$open_QMARK_$jscomp$11$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus_name_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($focus_name_QMARK_$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$363$$=$APP.$rumext$v2$ref_val$$($name_input_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$363$$)?
($APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$363$$),$APP.$app$util$dom$select_text_BANG_$$($temp__5825__auto__$jscomp$363$$)):null}):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{style:{display:$open_QMARK_$jscomp$11$$?"none":null},className:"main_ui_workspace_sidebar_options_menus_typography__typography-entry "+($selected_QMARK_$jscomp$2$$?"main_ui_workspace_sidebar_options_menus_typography__selected":""),children:[$APP.$cljs$core$truth_$$($renaming_QMARK_$jscomp$2$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)},className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample-input",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$name_input_ref$jscomp$1$$,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),maxLength:255,onKeyDown:$on_key_down$jscomp$15$$,onBlur:$on_name_blur$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_typography__adv-typography-name"})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_click$jscomp$42$$,
onContextMenu:$on_context_menu$jscomp$7$$,className:"main_ui_workspace_sidebar_options_menus_typography__typography-selection-wrapper "+($on_click$jscomp$42$$?"main_ui_workspace_sidebar_options_menus_typography__is-selectable":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)},
className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),className:"main_ui_workspace_sidebar_options_menus_typography__typography-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)}),$name_only_QMARK_$$?
null:(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$13$$),className:"main_ui_workspace_sidebar_options_menus_typography__typography-font",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$13$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__element-set-actions",children:[$on_detach$jscomp$1_props_78399$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.detach"),onClick:$on_detach$jscomp$1_props_78399$$,icon:"detach"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.open"),onClick:$on_open$jscomp$2$$,icon:"menu"})]})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$typography_advanced_options$$,
{"is-asset?":$is_asset_QMARK_$jscomp$1$$,"navigate-to-library":$navigate_to_library$jscomp$1$$,"visible?":$open_QMARK_$jscomp$11$$,"on-name-blur":$on_name_blur$jscomp$1$$,"file-id":$file_id$jscomp$395$$,"on-close":$on_close$jscomp$29$$,"local?":$local_QMARK_$jscomp$8$$,"editable?":$editable_QMARK_$jscomp$9_read_only_QMARK_$jscomp$17$$,typography:$typography$jscomp$33$$,"name-input-ref":$name_input_ref$jscomp$1$$,"on-change":$on_change$jscomp$52$$,"on-key-down":$on_key_down$jscomp$15$$})]})};
$app$main$ui$workspace$sidebar$assets$typographies$typography_item$$=function($props_78407_typography_id$jscomp$9$$){var $selected_paths$jscomp$8$$=$props_78407_typography_id$jscomp$9$$["selected-paths"],$move_typography$$=$props_78407_typography_id$jscomp$9$$["move-typography"],$on_asset_click$jscomp$6$$=$props_78407_typography_id$jscomp$9$$["on-asset-click"],$selected_full$jscomp$8$$=$props_78407_typography_id$jscomp$9$$["selected-full"],$handle_change$jscomp$6_handle_change__$1$$=$props_78407_typography_id$jscomp$9$$["handle-change"],
$selected$jscomp$162$$=$props_78407_typography_id$jscomp$9$$.selected,$rename_QMARK_$jscomp$3$$=$props_78407_typography_id$jscomp$9$$["rename?"],$file_id$jscomp$396$$=$props_78407_typography_id$jscomp$9$$["file-id"],$local_QMARK_$jscomp$9$$=$props_78407_typography_id$jscomp$9$$["local?"],$on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$=$props_78407_typography_id$jscomp$9$$["on-context-menu"],$editing_QMARK_$jscomp$7_editing_id$jscomp$1$$=$props_78407_typography_id$jscomp$9$$["editing-id"],
$typography$jscomp$34$$=$props_78407_typography_id$jscomp$9$$.typography,$open_STAR_$jscomp$5_renaming_id$$=$props_78407_typography_id$jscomp$9$$["renaming-id"],$item_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)();$props_78407_typography_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$);var $dragging_STAR_$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$7$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$9$$),
$read_only_QMARK_$jscomp$18$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$editing_QMARK_$jscomp$7_editing_id$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_QMARK_$jscomp$7_editing_id$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$));var $renaming_QMARK_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$5_renaming_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$));
$open_STAR_$jscomp$5_renaming_id$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($editing_QMARK_$jscomp$7_editing_id$jscomp$1$$);var $open_QMARK_$jscomp$12$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$5_renaming_id$$),$on_drop$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected$jscomp$162$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$8$$),
$APP.$rumext$v2$adapt$$($selected_paths$jscomp$8$$),$APP.$rumext$v2$adapt$$($move_typography$$)],function($event$jscomp$455$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$($event$jscomp$455$$,$typography$jscomp$34$$,$dragging_STAR_$jscomp$9$$,$selected$jscomp$162$$,$selected_full$jscomp$8$$,$selected_paths$jscomp$8$$,$move_typography$$)}),$on_drag_enter$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$9$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$162$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$8$$)],function($event$jscomp$456$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$($event$jscomp$456$$,$typography$jscomp$34$$,$dragging_STAR_$jscomp$9$$,$selected$jscomp$162$$,$selected_paths$jscomp$8$$)}),$on_drag_leave$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$9$$)],function($event$jscomp$457$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$457$$,
$dragging_STAR_$jscomp$9$$)}),$on_typography_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$396$$),$APP.$rumext$v2$adapt$$($selected$jscomp$162$$),$APP.$rumext$v2$adapt$$($item_ref$jscomp$6$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$18$$),$APP.$rumext$v2$adapt$$($renaming_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($open_QMARK_$jscomp$12$$)],function($event$jscomp$458$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$18$$)?
$read_only_QMARK_$jscomp$18$$:$renaming_QMARK_$jscomp$3$$?$renaming_QMARK_$jscomp$3$$:$open_QMARK_$jscomp$12$$)?$APP.$app$util$dom$prevent_default$$($event$jscomp$458$$):$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$($event$jscomp$458$$,$file_id$jscomp$396$$,$typography$jscomp$34$$,$selected$jscomp$162$$,$item_ref$jscomp$6$$,$APP.$cljs$cst$2215$typographies$$,$APP.$cljs$core$identity$$)});$on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$),
$APP.$rumext$v2$adapt$$($props_78407_typography_id$jscomp$9$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$,$props_78407_typography_id$jscomp$9$$));$handle_change$jscomp$6_handle_change__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_change$jscomp$6_handle_change__$1$$,$typography$jscomp$34$$));
var $on_asset_click__$1$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$6$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$18$$),$APP.$rumext$v2$adapt$$($local_QMARK_$jscomp$9$$)],function($JSCompiler_inline_result$jscomp$1786_event$jscomp$459$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$18$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-typography",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"sidebar",$APP.$cljs$cst$3933$external_library$$,$APP.$cljs$core$not$$($local_QMARK_$jscomp$9$$)],null)));var $G__78411$jscomp$inline_8855$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$);$JSCompiler_inline_result$jscomp$1786_event$jscomp$459$$=$on_asset_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_asset_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1786_event$jscomp$459$$,
$G__78411$jscomp$inline_8855$$):$on_asset_click$jscomp$6$$($JSCompiler_inline_result$jscomp$1786_event$jscomp$459$$,$G__78411$jscomp$inline_8855$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1786_event$jscomp$459$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$(null,$typography$jscomp$34$$,$file_id$jscomp$396$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$6$$,
onDragLeave:$on_drag_leave$jscomp$6$$,className:"main_ui_workspace_sidebar_assets_typographies__typography-item",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$typography_entry$$,{"editing?":$editing_QMARK_$jscomp$7_editing_id$jscomp$1$$,"is-asset?":!0,"focus-name?":$rename_QMARK_$jscomp$3$$,"external-open*":$open_STAR_$jscomp$5_renaming_id$$,"file-id":$file_id$jscomp$396$$,"renaming?":$renaming_QMARK_$jscomp$3$$,"local?":$local_QMARK_$jscomp$9$$,"on-context-menu":$on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$,
"on-click":$on_asset_click__$1$jscomp$2$$,typography:$typography$jscomp$34$$,"on-change":$handle_change$jscomp$6_handle_change__$1$$,"selected?":$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$162$$,$props_78407_typography_id$jscomp$9$$)}),$dragging_QMARK_$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_typographies__dragging"}):null],onDrop:$on_drop$jscomp$9$$,onDragOver:$APP.$app$util$dom$prevent_default$$,draggable:$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$18$$)&&
$APP.$cljs$core$not$$($open_QMARK_$jscomp$12$$),ref:$item_ref$jscomp$6$$,onDragStart:$on_typography_drag_start$$})};
$app$main$ui$workspace$sidebar$assets$typographies$typographies_section_STAR_$$=function($groups$jscomp$11_props_78431$$){function $handle_edit_typography_clicked$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78429_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__78429_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$3915$edit_typography$$],null),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$)))})}function $handle_rename_typography_clicked$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78428_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__78428_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$cljs$cst$5647$rename_typography$$],null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$)))})}
var $on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$=$groups$jscomp$11_props_78431$$.onAssetClick,$is_open$jscomp$6$$=$groups$jscomp$11_props_78431$$.isOpen,$open_status_ref$jscomp$2$$=$groups$jscomp$11_props_78431$$.openStatusRef,$on_assets_delete$jscomp$4$$=$groups$jscomp$11_props_78431$$.onAssetsDelete,$selected$jscomp$164_selected_full$jscomp$10$$=$groups$jscomp$11_props_78431$$.selected,$file_id$jscomp$398$$=$groups$jscomp$11_props_78431$$.fileId,$is_force_open$jscomp$3$$=$groups$jscomp$11_props_78431$$.isForceOpen,
$file$jscomp$165$$=$groups$jscomp$11_props_78431$$.file,$typographies$jscomp$8$$=$groups$jscomp$11_props_78431$$.typographies,$is_local$jscomp$5$$=$groups$jscomp$11_props_78431$$.isLocal,$on_clear_selection$jscomp$5$$=$groups$jscomp$11_props_78431$$.onClearSelection,$is_reverse_sort$jscomp$2$$=$groups$jscomp$11_props_78431$$.isReverseSort,$state$jscomp$1178$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5648$detail_open_QMARK_$$,
!1,$APP.$cljs$cst$266$id$$,null],null)),$local_data$jscomp$1$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$assets$typographies$lens_COLON_typography_section_state$$),$read_only_QMARK_$jscomp$19$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$menu_state$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$typographies__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies$jscomp$8$$)],
function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$libraries$extract_path_if_missing$$,$typographies$jscomp$8$$)});$groups$jscomp$11_props_78431$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($is_reverse_sort$jscomp$2$$)],function(){return $app$main$ui$workspace$sidebar$assets$groups$group_assets$$($typographies__$1$jscomp$1$$,$is_reverse_sort$jscomp$2$$)});
var $selected__$1$jscomp$17$$=$APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$164_selected_full$jscomp$10$$);$selected$jscomp$164_selected_full$jscomp$10$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78420_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$17$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78420_SHARP_$$))}),$typographies__$1$jscomp$1$$)});var $multi_typographies_QMARK_$$=$APP.$cljs$core$count$$($selected__$1$jscomp$17$$)>1,$multi_assets_QMARK_$jscomp$4$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$17$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2472$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$17$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$17$$)),
$open_groups$jscomp$5_open_groups_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_status_ref$jscomp$2$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4382$groups$$,$APP.$cljs$cst$2215$typographies$$],null)),$open_status_ref$jscomp$2$$)});$open_groups$jscomp$5_open_groups_ref$jscomp$2$$=
$APP.$rumext$v2$deref$$($open_groups$jscomp$5_open_groups_ref$jscomp$2$$);var $add_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$398$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$398$$,$APP.$cljs$cst$2215$typographies$$,!0));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$398$$,
null))}),$handle_change$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$398$$)],function($typography$jscomp$36$$,$changes$jscomp$328$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$typography$jscomp$36$$,$changes$jscomp$328$$])),
$file_id$jscomp$398$$))}),$create_group$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$5$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$398$$),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$)))],function($group_name$jscomp$4$$){$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?
$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$();var $undo_id$jscomp$102$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$102$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78422_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78422_SHARP_$$,
$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$add_group$$($p1__78422_SHARP_$$,$group_name$jscomp$4$$)),$file_id$jscomp$398$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78421_SHARP_$$){return $multi_typographies_QMARK_$$?$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$17$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78421_SHARP_$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$)),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78421_SHARP_$$))},$typographies__$1$jscomp$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$102$$))}),$rename_group$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function($path$jscomp$272$$,$last_path$jscomp$7$$){$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?
$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$();var $undo_id$jscomp$103$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$103$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78424_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78424_SHARP_$$,
$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$rename_group$$($p1__78424_SHARP_$$,$path$jscomp$272$$,$last_path$jscomp$7$$)),$file_id$jscomp$398$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78423_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78423_SHARP_$$),$path$jscomp$272$$)},$typographies__$1$jscomp$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$103$$))}),
$on_group$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($create_group$jscomp$2$$)],function($event$jscomp$463$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$463$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,
$create_group$jscomp$2$$],null))}),$on_rename_group$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function($event$jscomp$464$$,$path$jscomp$273$$,$last_path$jscomp$8$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$464$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5597$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,$path$jscomp$273$$,
$cljs$cst$5623$last_path$$,$last_path$jscomp$8$$,$APP.$cljs$cst$924$accept$$,$rename_group$jscomp$2$$],null))}),$on_ungroup$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function($path$jscomp$274$$){$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$();var $undo_id$jscomp$104$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$104$$));
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78426_SHARP_$$){return $APP.$app$main$data$workspace$libraries$rename_typography$$($file_id$jscomp$398$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78426_SHARP_$$),$app$main$ui$workspace$sidebar$assets$common$ungroup$$($p1__78426_SHARP_$$,$path$jscomp$274$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78425_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78425_SHARP_$$),
$path$jscomp$274$$)},$typographies__$1$jscomp$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$104$$))}),$on_delete_group$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$5$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3718$assets$$,$typographies__$1$jscomp$1$$,$cljs$cst$5594$on_clear_selection$$,$on_clear_selection$jscomp$5$$,$cljs$cst$5595$delete_events$$,function($p1__78427_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($t$jscomp$99$$){return $APP.$app$main$data$workspace$libraries$delete_typography$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($t$jscomp$99$$))},$p1__78427_SHARP_$$)}],null))}),$on_context_menu$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),
$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$5$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$19$$)],function($id$jscomp$945$$,$event$jscomp$465_pos$jscomp$138$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$465_pos$jscomp$138$$);$event$jscomp$465_pos$jscomp$138$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$465_pos$jscomp$138$$);return $APP.$cljs$core$not$$($read_only_QMARK_$jscomp$19$$)?($APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$17$$,$id$jscomp$945$$)||($on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?
$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1178$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$,$id$jscomp$945$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$jscomp$3$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,$event$jscomp$465_pos$jscomp$138$$)):null}),$on_close_menu$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$jscomp$3$$,
$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)}),$handle_delete_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($state$jscomp$1178$$)),$APP.$rumext$v2$adapt$$($multi_typographies_QMARK_$$),$APP.$rumext$v2$adapt$$($multi_assets_QMARK_$jscomp$4$$)],function(){var $undo_id$jscomp$105$$=Symbol();return $multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$4$$?$on_assets_delete$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$on_assets_delete$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_assets_delete$jscomp$4$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$105$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$delete_typography$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$))),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$398$$,
$file_id$jscomp$398$$,$APP.$cljs$cst$2215$typographies$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$))),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$105$$)]))}),$handle_duplicate_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$398$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($state$jscomp$1178$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_typography$$($file_id$jscomp$398$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1178$$))))}),$editing_id$jscomp$3$$=$APP.$cljs$cst$3915$edit_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$jscomp$1$$),$renaming_id$jscomp$2$$=$cljs$cst$5647$rename_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$jscomp$1$$);$on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$11_props_78431$$),
$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$,$groups$jscomp$11_props_78431$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($local_data$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$3915$edit_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$jscomp$1$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78430_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__78430_SHARP_$$,
$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3915$edit_typography$$)}):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,{fileId:$file_id$jscomp$398$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography"),section:$APP.$cljs$cst$2215$typographies$$,assetsCount:$APP.$cljs$core$count$$($typographies__$1$jscomp$1$$),
isOpen:$is_open$jscomp$6$$,children:[$APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$cljs$cst$5593$title_button$$,children:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$19$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.add-typography"),
onClick:$add_typography$$,icon:"add"})}):null,(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$APP.$cljs$cst$1637$content$$,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$,{"selected-full":$selected$jscomp$164_selected_full$jscomp$10$$,"force-open?":$is_force_open$jscomp$3$$,"handle-change":$handle_change$jscomp$8$$,selected:$selected__$1$jscomp$17$$,"file-id":$file_id$jscomp$398$$,
"is-read-only":$read_only_QMARK_$jscomp$19$$,"on-ungroup":$on_ungroup$jscomp$6$$,file:$file$jscomp$165$$,"local?":$is_local$jscomp$5$$,"on-context-menu":$on_context_menu$jscomp$10$$,state:$state$jscomp$1178$$,"local-data":$local_data$jscomp$1$$,"open-groups":$open_groups$jscomp$5_open_groups_ref$jscomp$2$$,prefix:"","editing-id":$editing_id$jscomp$3$$,"renaming-id":$renaming_id$jscomp$2$$,"on-delete-group":$on_delete_group$jscomp$6$$,groups:$groups$jscomp$11_props_78431$$,"on-asset-click":$on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$,
"on-rename-group":$on_rename_group$jscomp$5$$}),$APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$4$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$3$$),options:new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$4$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),$APP.$cljs$cst$266$id$$,"assets-rename-typography",$APP.$cljs$cst$2402$handler$$,$handle_rename_typography_clicked$$],null),$multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$4$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.edit"),$APP.$cljs$cst$266$id$$,"assets-edit-typography",
$APP.$cljs$cst$2402$handler$$,$handle_edit_typography_clicked$$],null),$multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$4$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),$APP.$cljs$cst$266$id$$,"assets-duplicate-typography",$APP.$cljs$cst$2402$handler$$,$handle_duplicate_typography$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),
$APP.$cljs$cst$266$id$$,"assets-delete-typography",$APP.$cljs$cst$2402$handler$$,$handle_delete_typography$$],null),$multi_assets_QMARK_$jscomp$4$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group"),$APP.$cljs$cst$266$id$$,"assets-group-typography",$APP.$cljs$cst$2402$handler$$,$on_group$jscomp$5$$],null)],null)}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,
{onClose:$on_close_menu$jscomp$4$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$3$$),options:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"show info",$APP.$cljs$cst$266$id$$,"assets-rename-typography",$APP.$cljs$cst$2402$handler$$,$handle_edit_typography_clicked$$],null)],null)})]})]})})};
$app$main$ui$workspace$sidebar$assets$file_library$create_file_ref$$=function($library_id$jscomp$60$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1179$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1179$$,$APP.$cljs$cst$1916$files$$),$library_id$jscomp$60$$),$APP.$cljs$cst$142$data$$)},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$sidebar$assets$file_library$use_library_ref$$=function($file_id$jscomp$399$$){var $library_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$399$$)],function(){return $app$main$ui$workspace$sidebar$assets$file_library$create_file_ref$$($file_id$jscomp$399$$)});return $APP.$rumext$v2$deref$$($library_ref$$)};
$app$main$ui$workspace$sidebar$assets$file_library$use_selected$$=function($file_id$jscomp$400$$){var $selected_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$400$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($file_id$jscomp$400$$),$app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_selected$$)});return $APP.$rumext$v2$deref$$($selected_ref$$)};
$app$main$ui$workspace$sidebar$assets$file_library$file_library_title_STAR_$$=function($file_name$jscomp$9_props_78449$$){var $is_open$jscomp$7$$=$file_name$jscomp$9_props_78449$$.isOpen,$file_id$jscomp$401$$=$file_name$jscomp$9_props_78449$$.fileId,$is_local$jscomp$6$$=$file_name$jscomp$9_props_78449$$.isLocal,$page_id$jscomp$421_url$jscomp$101$$=$file_name$jscomp$9_props_78449$$.pageId;$file_name$jscomp$9_props_78449$$=$file_name$jscomp$9_props_78449$$.fileName;var $router$jscomp$7_toggle_open$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$router$$),$on_click$jscomp$43_team_id$jscomp$145$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$);$page_id$jscomp$421_url$jscomp$101$$=$APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$($router$jscomp$7_toggle_open$$,$APP.$cljs$cst$2532$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1927$team_id$$,$on_click$jscomp$43_team_id$jscomp$145$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$401$$,
$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$421_url$jscomp$101$$],null));$router$jscomp$7_toggle_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$401$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$7$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$401$$,$APP.$cljs$cst$3532$library$$,$APP.$cljs$core$not$$($is_open$jscomp$7$$)))});$on_click$jscomp$43_team_id$jscomp$145$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($ev$jscomp$11$$){$APP.$app$util$dom$stop_propagation$$($ev$jscomp$11$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"navigate-to-library-file"],null)))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__library-title "+
($APP.$cljs$core$truth_$$($is_open$jscomp$7$$)?"main_ui_workspace_sidebar_assets_file_library__open":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($is_open$jscomp$7$$),onCollapsed:$router$jscomp$7_toggle_open$$,title:$APP.$cljs$core$truth_$$($is_local$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__special-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.local-library")}):
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__special-title",children:$file_name$jscomp$9_props_78449$$}),children:$is_local$jscomp$6$$?null:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.open-library"),children:(0,$APP.$rumext$v2$jsx$$)("a",{href:["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$421_url$jscomp$101$$)].join(""),target:"_blank",onClick:$on_click$jscomp$43_team_id$jscomp$145$$,
className:"main_ui_workspace_sidebar_assets_file_library__file-link",children:$APP.$app$main$ui$icons$open_link$$})})})})};
$app$main$ui$workspace$sidebar$assets$file_library$extend_selected$$=function($first_index_ids$jscomp$277_selected$jscomp$165$$,$type$jscomp$617$$,$asset_groups_click_index$$,$asset_id$jscomp$16$$,$file_id$jscomp$402$$){var $selected_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_index_ids$jscomp$277_selected$jscomp$165$$,$type$jscomp$617$$);if($APP.$cljs$core$count$$($selected_SINGLEQUOTE_$jscomp$1$$)===0)$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$select_single_asset$$($file_id$jscomp$402$$,
$asset_id$jscomp$16$$,$type$jscomp$617$$));else{var $all_assets$$=function $app$main$ui$workspace$sidebar$assets$file_library$extend_selected_$_flatten_groups$$($groups$jscomp$12$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$concat$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$12$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$ui$workspace$sidebar$assets$file_library$extend_selected_$_flatten_groups$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78454_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$first$$($p1__78454_SHARP_$$))},$groups$jscomp$12$$))])))],null))}($asset_groups_click_index$$);
$asset_groups_click_index$$=$APP.$app$common$data$index_of_pred$$($all_assets$$,function($p1__78455_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78455_SHARP_$$),$asset_id$jscomp$16$$)});$first_index_ids$jscomp$277_selected$jscomp$165$$=$APP.$cljs$core$first$$($cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($asset$jscomp$11$$){return $APP.$app$common$data$index_of_pred$$($all_assets$$,
function($p1__78456_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78456_SHARP_$$),$asset$jscomp$11$$)})},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_index_ids$jscomp$277_selected$jscomp$165$$,$type$jscomp$617$$))));var $min_index$$=$first_index_ids$jscomp$277_selected$jscomp$165$$<$asset_groups_click_index$$?$first_index_ids$jscomp$277_selected$jscomp$165$$:$asset_groups_click_index$$,$max_index$jscomp$1$$=
$first_index_ids$jscomp$277_selected$jscomp$165$$>$asset_groups_click_index$$?$first_index_ids$jscomp$277_selected$jscomp$165$$:$asset_groups_click_index$$;$first_index_ids$jscomp$277_selected$jscomp$165$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78457_SHARP_$$){return $min_index$$<=$APP.$cljs$core$first$$($p1__78457_SHARP_$$)&&
$APP.$cljs$core$first$$($p1__78457_SHARP_$$)<=$max_index$jscomp$1$$}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$second$$))),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($all_assets$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$select_assets$$($file_id$jscomp$402$$,$first_index_ids$jscomp$277_selected$jscomp$165$$,$type$jscomp$617$$))}};
$app$main$ui$workspace$sidebar$assets$file_library$file_library_content_STAR_$$=function($open_status_props_78467$$){var $open_status_ref$jscomp$3$$=$open_status_props_78467$$.openStatusRef,$filters$jscomp$7_listing_thumbs_QMARK_$$=$open_status_props_78467$$.filters,$count_variants$jscomp$2$$=$open_status_props_78467$$.countVariants,$file$jscomp$166$$=$open_status_props_78467$$.file,$colors$jscomp$23$$=$open_status_props_78467$$.colors,$is_loaded$$=$open_status_props_78467$$.isLoaded,$typographies$jscomp$9$$=
$open_status_props_78467$$.typographies,$is_local$jscomp$7$$=$open_status_props_78467$$.isLocal,$on_clear_selection$jscomp$6$$=$open_status_props_78467$$.onClearSelection,$components$jscomp$15$$=$open_status_props_78467$$.components;$open_status_props_78467$$=$APP.$rumext$v2$deref$$($open_status_ref$jscomp$3$$);var $file_id$jscomp$403$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$166$$),$filters_section_show_typography_QMARK_$$=$APP.$cljs$cst$1366$section$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$),
$force_open_typographies_QMARK__has_filters_term_QMARK_$$=!$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$)),$reverse_sort_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2698$desc$$,$cljs$cst$5592$ordering$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$));$filters$jscomp$7_listing_thumbs_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5622$thumbs$$,
$APP.$cljs$cst$5649$list_style$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$));var $selected$jscomp$166$$=$app$main$ui$workspace$sidebar$assets$file_library$use_selected$$($file_id$jscomp$403$$),$show_components_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"all")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"components"))&&($APP.$cljs$core$count$$($components$jscomp$15$$)>
0||!$force_open_typographies_QMARK__has_filters_term_QMARK_$$),$show_colors_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"all")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"colors"))&&($APP.$cljs$core$count$$($colors$jscomp$23$$)>0||!$force_open_typographies_QMARK__has_filters_term_QMARK_$$);$filters_section_show_typography_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,
"all")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"typographies"))&&($APP.$cljs$core$count$$($typographies$jscomp$9$$)>0||!$force_open_typographies_QMARK__has_filters_term_QMARK_$$);var $force_open_components_QMARK_$$=$force_open_typographies_QMARK__has_filters_term_QMARK_$$?60>$APP.$cljs$core$count$$($components$jscomp$15$$):null,$force_open_colors_QMARK_$$=$force_open_typographies_QMARK__has_filters_term_QMARK_$$?60>$APP.$cljs$core$count$$($colors$jscomp$23$$):
null;$force_open_typographies_QMARK__has_filters_term_QMARK_$$=$force_open_typographies_QMARK__has_filters_term_QMARK_$$?60>$APP.$cljs$core$count$$($typographies$jscomp$9$$):null;var $on_asset_click$jscomp$9_on_typography_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$403$$),$APP.$rumext$v2$adapt$$($selected$jscomp$166$$)],function($asset_type$jscomp$14$$,$asset_groups$jscomp$1$$,$event$jscomp$466$$,$asset_id$jscomp$17$$){return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$466$$)?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$466$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$toggle_selected_assets$$($file_id$jscomp$403$$,$asset_id$jscomp$17$$,$asset_type$jscomp$14$$)),!0):$event$jscomp$466$$.shiftKey?($APP.$app$util$dom$stop_propagation$$($event$jscomp$466$$),$app$main$ui$workspace$sidebar$assets$file_library$extend_selected$$($selected$jscomp$166$$,$asset_type$jscomp$14$$,$asset_groups$jscomp$1$$,$asset_id$jscomp$17$$,
$file_id$jscomp$403$$),!0):null}),$on_component_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$9_on_typography_click$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$9_on_typography_click$$,$APP.$cljs$cst$1638$components$$)),$on_colors_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$9_on_typography_click$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$9_on_typography_click$$,
$APP.$cljs$cst$2212$colors$$));$on_asset_click$jscomp$9_on_typography_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$9_on_typography_click$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$9_on_typography_click$$,$APP.$cljs$cst$2215$typographies$$));var $delete_component$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$15$$)],
function($component_id$jscomp$94$$){var $component$jscomp$129$$=$APP.$cljs$core$some$$(function($p1__78463_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78463_SHARP_$$),$component_id$jscomp$94$$)?$p1__78463_SHARP_$$:null},$components$jscomp$15$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$129$$)?$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$129$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$129$$)])):$APP.$app$main$data$workspace$libraries$delete_component$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$component_id$jscomp$94$$],null))}),$on_assets_delete$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$166$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$403$$)],
function(){var $undo_id$jscomp$106$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$106$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($delete_component$jscomp$1$$,$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$)));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78464_SHARP_$$){return $app$main$data$workspace$libraries$delete_media$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$p1__78464_SHARP_$$],null))},$APP.$cljs$cst$2472$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$)));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78465_SHARP_$$){return $APP.$app$main$data$workspace$libraries$delete_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$p1__78465_SHARP_$$],null))},$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$)));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78466_SHARP_$$){return $APP.$app$main$data$workspace$libraries$delete_typography$$($p1__78466_SHARP_$$)},$APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$)));($APP.$cljs$core$seq$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$))||
$APP.$cljs$core$seq$$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166$$)))&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$403$$,$file_id$jscomp$403$$,null,null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$106$$))});return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_assets_file_library__library-content",children:$APP.$cljs$core$not$$($is_loaded$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_file_library__loading",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$show_components_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_section_STAR_$$,
{isLocal:$is_local$jscomp$7$$,selected:$selected$jscomp$166$$,onAssetClick:$on_component_click$jscomp$1$$,onAssetsDelete:$on_assets_delete$jscomp$5$$,isForceOpen:$force_open_components_QMARK_$$,countVariants:$count_variants$jscomp$2$$,deleteComponent:$delete_component$jscomp$1$$,isListingThumbs:$filters$jscomp$7_listing_thumbs_QMARK_$$,onClearSelection:$on_clear_selection$jscomp$6$$,components:$components$jscomp$15$$,isOpen:$force_open_components_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_status_props_78467$$,
$APP.$cljs$cst$1638$components$$,!1),fileId:$file_id$jscomp$403$$,isReverseSort:$reverse_sort_QMARK_$jscomp$2$$,openStatusRef:$open_status_ref$jscomp$3$$}):null,$show_colors_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$colors_section_STAR_$$,{isLocal:$is_local$jscomp$7$$,selected:$selected$jscomp$166$$,onAssetClick:$on_colors_click$$,onAssetsDelete:$on_assets_delete$jscomp$5$$,isForceOpen:$force_open_colors_QMARK_$$,onClearSelection:$on_clear_selection$jscomp$6$$,
isOpen:$force_open_colors_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_status_props_78467$$,$APP.$cljs$cst$2212$colors$$,!1),colors:$colors$jscomp$23$$,fileId:$file_id$jscomp$403$$,isReverseSort:$reverse_sort_QMARK_$jscomp$2$$,openStatusRef:$open_status_ref$jscomp$3$$}):null,$filters_section_show_typography_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typographies_section_STAR_$$,{isLocal:$is_local$jscomp$7$$,selected:$selected$jscomp$166$$,
onAssetClick:$on_asset_click$jscomp$9_on_typography_click$$,onAssetsDelete:$on_assets_delete$jscomp$5$$,isForceOpen:$force_open_typographies_QMARK__has_filters_term_QMARK_$$,onClearSelection:$on_clear_selection$jscomp$6$$,typographies:$typographies$jscomp$9$$,file:$file$jscomp$166$$,isOpen:$force_open_typographies_QMARK__has_filters_term_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_status_props_78467$$,$APP.$cljs$cst$2215$typographies$$,!1),fileId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$166$$),
isReverseSort:$reverse_sort_QMARK_$jscomp$2$$,openStatusRef:$open_status_ref$jscomp$3$$}):null,$show_components_QMARK_$$||$show_colors_QMARK_$$||$filters_section_show_typography_QMARK_$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_file_library__no-found-icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_file_library__no-found-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.not-found")})]})]})})};
$app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$=function($is_local$jscomp$8_props_78484$$){var $is_default_open_open_QMARK_$jscomp$13$$=$is_local$jscomp$8_props_78484$$.isDefaultOpen,$filters$jscomp$8$$=$is_local$jscomp$8_props_78484$$.filters,$file$jscomp$167$$=$is_local$jscomp$8_props_78484$$.file;$is_local$jscomp$8_props_78484$$=$is_local$jscomp$8_props_78484$$.isLocal;var $file_id$jscomp$404$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$167$$),
$file_name$jscomp$10$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$167$$),$page_id$jscomp$422$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$167$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2228$pages$$),0),$library$jscomp$39$$=$app$main$ui$workspace$sidebar$assets$file_library$use_library_ref$$($file_id$jscomp$404$$),$colors$jscomp$24$$=$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$39$$),
$typographies$jscomp$10$$=$APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$39$$),$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$=$APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$8$$),$is_loaded$jscomp$1$$=$library$jscomp$39$$!=null,$filtered_colors$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filters$jscomp$8$$),$APP.$rumext$v2$adapt$$($colors$jscomp$24$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$apply_filters$$($APP.$cljs$core$vals$$($colors$jscomp$24$$),
$filters$jscomp$8$$)}),$filtered_components$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filters$jscomp$8$$),$APP.$rumext$v2$adapt$$($library$jscomp$39$$)],function(){var $$$jscomp$31_$__$1$jscomp$24$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$common$types$components_list$components_seq$$($library$jscomp$39$$));$$$jscomp$31_$__$1$jscomp$24$$=$app$main$ui$workspace$sidebar$assets$common$apply_filters$$($$$jscomp$31_$__$1$jscomp$24$$,
$filters$jscomp$8$$);return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78483_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__78483_SHARP_$$,$library$jscomp$39$$)},$$$jscomp$31_$__$1$jscomp$24$$)}),$filtered_typographies$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filters$jscomp$8$$),$APP.$rumext$v2$adapt$$($typographies$jscomp$10$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$apply_filters$$($APP.$cljs$core$vals$$($typographies$jscomp$10$$),
$filters$jscomp$8$$)}),$open_status_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$404$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($file_id$jscomp$404$$),$app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_open_status$$)}),$open_status$jscomp$1_unselect_all$$=$APP.$rumext$v2$deref$$($open_status_ref$jscomp$4$$);$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$=
!$APP.$cuerdas$core$blank_QMARK_$$($count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$)&&(60>$APP.$cljs$core$count$$($filtered_colors$jscomp$1$$)||60>$APP.$cljs$core$count$$($filtered_components$$)||60>$APP.$cljs$core$count$$($filtered_typographies$$));$is_default_open_open_QMARK_$jscomp$13$$=$APP.$cljs$cst$3532$library$$.$cljs$core$IFn$_invoke$arity$1$($open_status$jscomp$1_unselect_all$$)===!1?!1:$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$?$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$:
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3532$library$$.$cljs$core$IFn$_invoke$arity$1$($open_status$jscomp$1_unselect_all$$),$is_default_open_open_QMARK_$jscomp$13$$);$open_status$jscomp$1_unselect_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$404$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$($file_id$jscomp$404$$))});
var $variants_counter$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($library$jscomp$39$$)],function(){return $APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$2000$variant_id$$,$APP.$app$common$types$components_list$components_seq$$($library$jscomp$39$$)),$APP.$cljs$core$count$$)});$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants_counter$$)],
function($variant_id$jscomp$49$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_counter$$,$variant_id$jscomp$49$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onContextMenu:$APP.$app$util$dom$prevent_default$$,onClick:$open_status$jscomp$1_unselect_all$$,className:"main_ui_workspace_sidebar_assets_file_library__tool-window",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_title_STAR_$$,{fileId:$file_id$jscomp$404$$,pageId:$page_id$jscomp$422$$,
fileName:$file_name$jscomp$10$$,isOpen:$is_default_open_open_QMARK_$jscomp$13$$,isLocal:$is_local$jscomp$8_props_78484$$}),$is_default_open_open_QMARK_$jscomp$13$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_content_STAR_$$,{isLocal:$is_local$jscomp$8_props_78484$$,isLoaded:$is_loaded$jscomp$1$$,countVariants:$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$,filters:$filters$jscomp$8$$,onClearSelection:$open_status$jscomp$1_unselect_all$$,
typographies:$filtered_typographies$$,file:$file$jscomp$167$$,components:$filtered_components$$,colors:$filtered_colors$jscomp$1$$,openStatusRef:$open_status_ref$jscomp$4$$}):null]})};
$app$main$ui$workspace$sidebar$assets$assets_local_library_STAR_$$=function($filters$jscomp$10_props_78527$$){$filters$jscomp$10_props_78527$$=$filters$jscomp$10_props_78527$$.filters;var $file$jscomp$171$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$assets$ref_COLON_local_library$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$,{file:$file$jscomp$171$$,isLocal:!0,isDefaultOpen:!0,filters:$filters$jscomp$10_props_78527$$})};
$app$main$ui$workspace$sidebar$debug$debug_panel_STAR_$$=function($class$$jscomp$65_props_78403$$){$class$$jscomp$65_props_78403$$=$class$$jscomp$65_props_78403$$.className;var $on_toggle_enabled$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$469$$,$option$jscomp$16$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$469$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$469$$);$APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$16$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$debug$state$$,
$APP.$cljs$core$disj$$,$option$jscomp$16$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$debug$state$$,$APP.$cljs$core$conj$$,$option$jscomp$16$$);return $APP.$app$main$reinit$$(!0)}),$handle_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($cljs$cst$5652$debug_panel$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:""+($class$$jscomp$65_props_78403$$??"")+" main_ui_workspace_sidebar_debug__debug-panel",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,{className:"main_ui_workspace_sidebar_debug__debug-panel-title",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.debug.title"),onClose:$handle_close$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug__debug-panel-inner",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$148$$,
$option$jscomp$17$$){$out_arr__44124__auto__$jscomp$148$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug__checkbox-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{onClick:function($p1__78401_SHARP_$$){return $on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__78401_SHARP_$$,$option$jscomp$17$$):$on_toggle_enabled$jscomp$1$$($p1__78401_SHARP_$$,$option$jscomp$17$$)},className:"main_ui_workspace_sidebar_debug__checkbox-icon "+
($APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$17$$)?"checked":""),children:$APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$17$$)?$APP.$app$main$ui$icons$status_tick$$:null}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:$APP.$app$common$data$name$$($option$jscomp$17$$),onChange:function($p1__78402_SHARP_$$){return $on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__78402_SHARP_$$,$option$jscomp$17$$):
$on_toggle_enabled$jscomp$1$$($p1__78402_SHARP_$$,$option$jscomp$17$$)},checked:$APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$17$$)},$APP.$app$common$data$name$$($option$jscomp$17$$)),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:$APP.$app$common$data$name$$($option$jscomp$17$$),children:$APP.$app$common$data$name$$($option$jscomp$17$$)})]},$APP.$app$common$data$name$$($option$jscomp$17$$)));return $out_arr__44124__auto__$jscomp$148$$},[],$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$,
$APP.$app$util$debug$options$$))})]})};
$app$main$ui$workspace$sidebar$debug_shape_info$get_attrs$$=function($shape$jscomp$985$$){var $shape_attrs$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$debug_shape_info$remove_attrs$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($app$main$ui$workspace$sidebar$debug_shape_info$display_attrs$$),$APP.$cljs$core$keys$$($shape$jscomp$985$$)))),$$__$1$jscomp$25$$=
$APP.$app$common$data$removev$$(function($p1__78432_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$985$$,$p1__78432_SHARP_$$)==null},$app$main$ui$workspace$sidebar$debug_shape_info$display_attrs$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($$__$1$jscomp$25$$,$shape_attrs$$)};
$app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$=function($map__78434_map__78434__$1_objects$jscomp$771_props_78433$$){$map__78434_map__78434__$1_objects$jscomp$771_props_78433$$=$APP.$rumext$v2$util$wrap_props$$($map__78434_map__78434__$1_objects$jscomp$771_props_78433$$);$map__78434_map__78434__$1_objects$jscomp$771_props_78433$$=$APP.$cljs$core$__destructure_map$$($map__78434_map__78434__$1_objects$jscomp$771_props_78433$$);var $id$jscomp$946$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78434_map__78434__$1_objects$jscomp$771_props_78433$$,
$APP.$cljs$cst$266$id$$);$map__78434_map__78434__$1_objects$jscomp$771_props_78433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78434_map__78434__$1_objects$jscomp$771_props_78433$$,$APP.$cljs$cst$1631$objects$$);return(0,$APP.$rumext$v2$jsx$$)("a",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$946$$))},className:"main_ui_workspace_sidebar_debug_shape_info__shape-link",
children:""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78434_map__78434__$1_objects$jscomp$771_props_78433$$,$id$jscomp$946$$),$APP.$cljs$cst$725$name$$)??"")+" #"+($id$jscomp$946$$??"")})};
$app$main$ui$workspace$sidebar$debug_shape_info$cells_render$$=function($map__78436_map__78436__$1_props_78435$$){$map__78436_map__78436__$1_props_78435$$=$APP.$rumext$v2$util$wrap_props$$($map__78436_map__78436__$1_props_78435$$);$map__78436_map__78436__$1_props_78435$$=$APP.$cljs$core$__destructure_map$$($map__78436_map__78436__$1_props_78435$$);var $cells$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78436_map__78436__$1_props_78435$$,$APP.$cljs$cst$4512$cells$$),$objects$jscomp$772$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78436_map__78436__$1_props_78435$$,$APP.$cljs$cst$1631$objects$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cells-render",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$149$$,$cell$jscomp$45_p__78437$$){var $id$jscomp$947$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$45_p__78437$$,0,null);$cell$jscomp$45_p__78437$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$45_p__78437$$,1,null);$out_arr__44124__auto__$jscomp$149$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cell-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cell-position",children:"("+($APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)??"")+", "+($APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)??
"")+") -\x3e ("+($APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)+($APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)-1)??"")+", "+($APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)+($APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)-1)??"")+")"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cell-shape",
children:$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$))?(0,$APP.$rumext$v2$jsx$$)("div",{children:"\x3cempty\x3e"}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,{id:$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78437$$)),objects:$objects$jscomp$772$$})})]},"cell-"+($id$jscomp$947$$??"")));return $out_arr__44124__auto__$jscomp$149$$},
[],$cells$jscomp$30$$)})};
$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_attr$$=function($map__78442_props_78441_value$jscomp$810$$){$map__78442_props_78441_value$jscomp$810$$=$APP.$rumext$v2$util$wrap_props$$($map__78442_props_78441_value$jscomp$810$$);var $G__78443_map__78442__$1$$=$APP.$cljs$core$__destructure_map$$($map__78442_props_78441_value$jscomp$810$$),$attr$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78443_map__78442__$1$$,$APP.$cljs$cst$2599$attr$$);$map__78442_props_78441_value$jscomp$810$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78443_map__78442__$1$$,$APP.$cljs$cst$260$value$$);var $objects$jscomp$773$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78443_map__78442__$1$$,$APP.$cljs$cst$1631$objects$$);$G__78443_map__78442__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$debug_shape_info$custom_renderer$$,$attr$jscomp$63$$);switch($G__78443_map__78442__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__78443_map__78442__$1$$.$fqn$:
null){case "shape-link":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,{id:$map__78442_props_78441_value$jscomp$810$$,objects:$objects$jscomp$773$$});case "shape-list":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$150$$,$id$jscomp$948$$){$out_arr__44124__auto__$jscomp$150$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,
{id:$id$jscomp$948$$,objects:$objects$jscomp$773$$},"child-"+($id$jscomp$948$$??"")));return $out_arr__44124__auto__$jscomp$150$$},[],$map__78442_props_78441_value$jscomp$810$$)});case "matrix-render":return(0,$APP.$rumext$v2$jsx$$)("div",{children:""+($APP.$app$common$geom$matrix$format_precision$$($map__78442_props_78441_value$jscomp$810$$,2)??"")});case "rect-render":return(0,$APP.$rumext$v2$jsx$$)("div",{children:"X:"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($map__78442_props_78441_value$jscomp$810$$)??
"")+" Y:"+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__78442_props_78441_value$jscomp$810$$)??"")+" W:"+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__78442_props_78441_value$jscomp$810$$)??"")+" H:"+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__78442_props_78441_value$jscomp$810$$)??"")});case "points-render":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__point-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$151$$,
$p__78444_point$jscomp$79$$){var $idx$jscomp$121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78444_point$jscomp$79$$,0,null);$p__78444_point$jscomp$79$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78444_point$jscomp$79$$,1,null);$out_arr__44124__auto__$jscomp$151$$.push((0,$APP.$rumext$v2$jsx$$)("div",{children:"("+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p__78444_point$jscomp$79$$)??"")+", "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p__78444_point$jscomp$79$$)??
"")+")"},"point-"+($idx$jscomp$121$$??"")));return $out_arr__44124__auto__$jscomp$151$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78442_props_78441_value$jscomp$810$$))});case "cells-render":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$cells_render$$,{cells:$map__78442_props_78441_value$jscomp$810$$,objects:$objects$jscomp$773$$});default:return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container-value",
children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__78442_props_78441_value$jscomp$810$$)})}};
$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_info_STAR_$$=function(){var $objects$jscomp$774$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$167$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$774$$),$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-info",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,
{className:"main_ui_workspace_sidebar_debug_shape_info__shape-info-title",text:"Debug",onClose:function(){return $APP.$debug$disable_BANG_$$($APP.$cljs$cst$3075$shape_panel$$)}}),$APP.$cljs$core$empty_QMARK_$$($selected$jscomp$167$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container",children:"No shapes selected"}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$152$$,$p__78450$$){var $idx$jscomp$122$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78450$$,0,null),$current$jscomp$57$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78450$$,1,null);$out_arr__44124__auto__$jscomp$152$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-name",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$57$$)}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$debug$dump_object$$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$57$$)??""))},children:"object"}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$2$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$57$$)??""),!0)},
children:"tree"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-attrs",children:function(){var $attrs$jscomp$175$$=$app$main$ui$workspace$sidebar$debug_shape_info$get_attrs$$($current$jscomp$57$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$19$$,$JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$){var $JSCompiler_temp_const$jscomp$1790$$=$out_arr__44124__auto____$1$jscomp$19$$.push,
$temp__5825__auto__$jscomp$inline_8871$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$57$$,$JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$);$JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_8871$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container-attr "+($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$)?
"main_ui_workspace_sidebar_debug_shape_info__vertical-layout":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container-name",children:$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_attr$$,{attr:$JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$,value:$temp__5825__auto__$jscomp$inline_8871$$,objects:$objects$jscomp$774$$})]},
"att-"+($idx$jscomp$122$$??"")+"-"+($JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$??"")):null;$JSCompiler_temp_const$jscomp$1790$$.call($out_arr__44124__auto____$1$jscomp$19$$,$JSCompiler_inline_result$jscomp$1792_attr$jscomp$64$$);return $out_arr__44124__auto____$1$jscomp$19$$},[],$attrs$jscomp$175$$)}()})]},"shape"+($idx$jscomp$122$$??"")));return $out_arr__44124__auto__$jscomp$152$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$167$$))]})};
$app$main$ui$workspace$sidebar$history$get_object$$=function($id$jscomp$949$$,$entries$jscomp$36$$,$objects$jscomp$775_or__5025__auto__$jscomp$1140$$){function $search_deleted_shape$$($id__$1$jscomp$18$$,$entries__$1$jscomp$4_map__78459_map__78459__$1$$){function $search_delete_entry$$($or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$){var $map__78461__$1_redo_changes$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$);$or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78461__$1_redo_changes$jscomp$15$$,$APP.$cljs$cst$3137$undo_changes$$);$map__78461__$1_redo_changes$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78461__$1_redo_changes$jscomp$15$$,$APP.$cljs$cst$3133$redo_changes$$);$or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($search_obj$$,$or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$)?$or__5025__auto__$jscomp$1141_p__78460_undo_changes$jscomp$10$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($search_obj$$,$map__78461__$1_redo_changes$jscomp$15$$)}function $search_obj$$($obj$jscomp$219$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$219$$),$APP.$cljs$cst$2610$add_obj$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$219$$),
$id__$1$jscomp$18$$)}$entries__$1$jscomp$4_map__78459_map__78459__$1$$=$search_delete_entry$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($search_delete_entry$$,$entries__$1$jscomp$4_map__78459_map__78459__$1$$));$entries__$1$jscomp$4_map__78459_map__78459__$1$$=$APP.$cljs$core$__destructure_map$$($entries__$1$jscomp$4_map__78459_map__78459__$1$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($entries__$1$jscomp$4_map__78459_map__78459__$1$$,$APP.$cljs$cst$2611$obj$$)}
$objects$jscomp$775_or__5025__auto__$jscomp$1140$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$775_or__5025__auto__$jscomp$1140$$,$id$jscomp$949$$);return $APP.$cljs$core$truth_$$($objects$jscomp$775_or__5025__auto__$jscomp$1140$$)?$objects$jscomp$775_or__5025__auto__$jscomp$1140$$:$search_deleted_shape$$($id$jscomp$949$$,$entries$jscomp$36$$)};
$app$main$ui$workspace$sidebar$history$extract_operation$$=function($G__78462_change$jscomp$34$$){$G__78462_change$jscomp$34$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78462_change$jscomp$34$$);switch($G__78462_change$jscomp$34$$ instanceof $APP.$cljs$core$Keyword$$?$G__78462_change$jscomp$34$$.$fqn$:null){case "add-obj":case "add-page":case "add-color":case "add-media":case "add-component":case "add-typography":return $APP.$cljs$cst$4001$new$$;case "mod-obj":case "mod-page":case "mod-color":case "mod-media":case "mod-component":case "mod-typography":return $cljs$cst$5659$modify$$;
case "del-obj":case "del-page":case "del-color":case "del-media":case "del-component":case "del-typography":return $APP.$cljs$cst$4834$delete$$;case "mov-objects":return $APP.$cljs$cst$1798$move$$;default:return null}};
$app$main$ui$workspace$sidebar$history$parse_change$$=function($change$jscomp$35$$){function $r$jscomp$140$$($type$jscomp$618$$,$id$jscomp$950$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$type$jscomp$618$$,$cljs$cst$5660$operation$$,$app$main$ui$workspace$sidebar$history$extract_operation$$($change$jscomp$35$$),$APP.$cljs$cst$5338$detail$$,$APP.$cljs$cst$2613$operations$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$coll_QMARK_$$($id$jscomp$950$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($id$jscomp$950$$))?$APP.$cljs$core$first$$($id$jscomp$950$$):$APP.$cljs$core$coll_QMARK_$$($id$jscomp$950$$)?$APP.$cljs$cst$1616$multiple$$:$id$jscomp$950$$],null)}var $G__78468$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$);switch($G__78468$$ instanceof $APP.$cljs$core$Keyword$$?$G__78468$$.$fqn$:null){case "set-option":return $r$jscomp$140$$($APP.$cljs$cst$1624$page$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));
case "add-obj":case "mod-obj":case "del-obj":return $r$jscomp$140$$($APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "reg-objects":return null;case "mov-objects":return $r$jscomp$140$$($APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "add-page":case "mod-page":case "del-page":case "mov-page":return $r$jscomp$140$$($APP.$cljs$cst$1624$page$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));
case "add-color":case "mod-color":return $r$jscomp$140$$($APP.$cljs$cst$1298$color$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($change$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$266$id$$],null)));case "del-color":return $r$jscomp$140$$($APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "add-recent-color":return null;case "add-media":case "mod-media":return $r$jscomp$140$$($APP.$cljs$cst$1639$media$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($change$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2198$object$$,$APP.$cljs$cst$266$id$$],null)));case "del-media":return $r$jscomp$140$$($APP.$cljs$cst$1639$media$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "add-component":case "mod-component":case "del-component":return $r$jscomp$140$$($APP.$cljs$cst$1625$component$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));
case "add-typography":case "mod-typography":return $r$jscomp$140$$($APP.$cljs$cst$1981$typography$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($change$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1981$typography$$,$APP.$cljs$cst$266$id$$],null)));case "del-typography":return $r$jscomp$140$$($APP.$cljs$cst$1981$typography$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));default:return null}};
$app$main$ui$workspace$sidebar$history$resolve_shape_types$$=function($entries$jscomp$37$$,$objects$jscomp$776$$){function $map_fn$$($JSCompiler_temp$jscomp$1793_entry$jscomp$71$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1793_entry$jscomp$71$$),$APP.$cljs$cst$1811$shape$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1793_entry$jscomp$71$$),
$APP.$cljs$cst$1616$multiple$$)){var $JSCompiler_temp_const$jscomp$1795$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1794$$=$APP.$cljs$cst$139$type$$,$id$jscomp$inline_8876_map__78470__$1$jscomp$inline_8874$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1793_entry$jscomp$71$$);var $JSCompiler_inline_result$jscomp$1797_type$jscomp$inline_8875$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_8876_map__78470__$1$jscomp$inline_8874$$,
$APP.$cljs$cst$139$type$$);$id$jscomp$inline_8876_map__78470__$1$jscomp$inline_8874$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_8876_map__78470__$1$jscomp$inline_8874$$,$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$1797_type$jscomp$inline_8875$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1797_type$jscomp$inline_8875$$,$APP.$cljs$cst$1811$shape$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_8876_map__78470__$1$jscomp$inline_8874$$,
$APP.$cljs$cst$1616$multiple$$)?$JSCompiler_inline_result$jscomp$1797_type$jscomp$inline_8875$$:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($id$jscomp$inline_8876_map__78470__$1$jscomp$inline_8874$$,$entries$jscomp$37$$,$objects$jscomp$776$$));$JSCompiler_temp$jscomp$1793_entry$jscomp$71$$=$JSCompiler_temp_const$jscomp$1795$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$1793_entry$jscomp$71$$,$JSCompiler_temp_const$jscomp$1794$$,
$JSCompiler_inline_result$jscomp$1797_type$jscomp$inline_8875$$)}return $JSCompiler_temp$jscomp$1793_entry$jscomp$71$$}return function($entries__$1$jscomp$5$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($map_fn$$,$entries__$1$jscomp$5$$)}};
$app$main$ui$workspace$sidebar$history$entry__GT_message$$=function($G__78471_entry$jscomp$72$$){var $attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78471_entry$jscomp$72$$);var $arity$jscomp$inline_13531_multiple_QMARK_$jscomp$inline_13530$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__78471_entry$jscomp$72$$));
$arity$jscomp$inline_13531_multiple_QMARK_$jscomp$inline_13530$$=$APP.$cljs$core$truth_$$($arity$jscomp$inline_13531_multiple_QMARK_$jscomp$inline_13530$$)?"multiple":"single";$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$=$APP.$cljs$core$name$$($APP.$cljs$core$truth_$$($attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$)?$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$:$APP.$cljs$cst$1616$multiple$$);$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.%s.%s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$arity$jscomp$inline_13531_multiple_QMARK_$jscomp$inline_13530$$,$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$])));$G__78471_entry$jscomp$72$$=$cljs$cst$5660$operation$$.$cljs$core$IFn$_invoke$arity$1$($G__78471_entry$jscomp$72$$);switch($G__78471_entry$jscomp$72$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78471_entry$jscomp$72$$.$fqn$:null){case "new":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.new",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$]));case "modify":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.modify",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$]));
case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.delete",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$]));case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.move",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$]));
default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.unknown",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13532_type$jscomp$inline_13529_value$jscomp$812$$]))}};
$app$main$ui$workspace$sidebar$history$entry__GT_icon$$=function($G__78474_map__78473__$1_p__78472$$){$G__78474_map__78473__$1_p__78472$$=$APP.$cljs$core$__destructure_map$$($G__78474_map__78473__$1_p__78472$$);$G__78474_map__78473__$1_p__78472$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78474_map__78473__$1_p__78472$$,$APP.$cljs$cst$139$type$$);switch($G__78474_map__78473__$1_p__78472$$ instanceof $APP.$cljs$core$Keyword$$?$G__78474_map__78473__$1_p__78472$$.$fqn$:null){case "page":return $APP.$app$main$ui$icons$document$$;
case "shape":return $APP.$app$main$ui$icons$svg$$;case "rect":return $APP.$app$main$ui$icons$rectangle$$;case "circle":return $APP.$app$main$ui$icons$elipse$$;case "text":return $APP.$app$main$ui$icons$text$$;case "path":return $APP.$app$main$ui$icons$path$$;case "frame":return $APP.$app$main$ui$icons$board$$;case "group":return $APP.$app$main$ui$icons$group$$;case "color":return $APP.$app$main$ui$icons$drop_icon$$;case "typography":return $APP.$app$main$ui$icons$text_palette$$;case "component":return $APP.$app$main$ui$icons$component$$;
case "media":return $APP.$app$main$ui$icons$img$$;case "image":return $APP.$app$main$ui$icons$img$$;default:return $APP.$app$main$ui$icons$svg$$}};
$app$main$ui$workspace$sidebar$history$is_shape_QMARK_$$=function($type$jscomp$622$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1606$frame$$,null,$APP.$cljs$cst$1417$circle$$,null,$APP.$cljs$cst$1811$shape$$,null,$APP.$cljs$cst$1611$rect$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$type$jscomp$622$$)};
$app$main$ui$workspace$sidebar$history$parse_entry$$=function($map__78476__$1_p__78475_redo_changes$jscomp$16$$){$map__78476__$1_p__78475_redo_changes$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($map__78476__$1_p__78475_redo_changes$jscomp$16$$);$map__78476__$1_p__78475_redo_changes$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78476__$1_p__78475_redo_changes$jscomp$16$$,$APP.$cljs$cst$3133$redo_changes$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$parse_change$$,
$map__78476__$1_p__78475_redo_changes$jscomp$16$$)};$app$main$ui$workspace$sidebar$history$safe_name$$=function($maybe_keyword$jscomp$1$$){return $maybe_keyword$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($maybe_keyword$jscomp$1$$):$maybe_keyword$jscomp$1$$};
$app$main$ui$workspace$sidebar$history$select_entry$$=function($candidates$jscomp$1$$){function $single_QMARK_$jscomp$13$$($coll$jscomp$1102$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($coll$jscomp$1102$$),1)}var $detail$jscomp$9_entries$jscomp$38$$=$APP.$cljs$core$group_by$$(function($p1__78477_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78477_SHARP_$$),
$cljs$cst$5660$operation$$.$cljs$core$IFn$_invoke$arity$1$($p1__78477_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78477_SHARP_$$)],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$candidates$jscomp$1$$)),$types$jscomp$13$$=$APP.$cljs$core$group_by$$($APP.$cljs$core$first$$,$APP.$cljs$core$keys$$($detail$jscomp$9_entries$jscomp$38$$)),$operations$jscomp$11$$=$APP.$cljs$core$group_by$$($APP.$cljs$core$second$$,$APP.$cljs$core$keys$$($detail$jscomp$9_entries$jscomp$38$$)),
$selected_entry$$=$single_QMARK_$jscomp$13$$($detail$jscomp$9_entries$jscomp$38$$)?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$38$$,$APP.$cljs$core$first$$($APP.$cljs$core$keys$$($detail$jscomp$9_entries$jscomp$38$$)))):$single_QMARK_$jscomp$13$$($APP.$cljs$cst$4001$new$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$))?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$38$$,
$APP.$cljs$core$first$$($APP.$cljs$cst$4001$new$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$)))):$single_QMARK_$jscomp$13$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78478_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$core$first$$($p1__78478_SHARP_$$))},$APP.$cljs$cst$4834$delete$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$)))?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$38$$,
$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78479_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$core$first$$($p1__78479_SHARP_$$))},$APP.$cljs$cst$4834$delete$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$))))):$single_QMARK_$jscomp$13$$($APP.$cljs$cst$1798$move$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$))?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$38$$,
$APP.$cljs$core$first$$($APP.$cljs$cst$1798$move$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$)))):$single_QMARK_$jscomp$13$$($operations$jscomp$11$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$core$every_QMARK_$$($app$main$ui$workspace$sidebar$history$is_shape_QMARK_$$,$APP.$cljs$core$keys$$($types$jscomp$13$$))?$APP.$cljs$cst$1811$shape$$:$APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1616$multiple$$,$cljs$cst$5660$operation$$,
$APP.$cljs$core$first$$($APP.$cljs$core$keys$$($operations$jscomp$11$$))],null):new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1616$multiple$$,$cljs$cst$5660$operation$$,$APP.$cljs$cst$1616$multiple$$],null);$detail$jscomp$9_entries$jscomp$38$$=function(){var $G__78485$$=$cljs$cst$5660$operation$$.$cljs$core$IFn$_invoke$arity$1$($selected_entry$$);switch($G__78485$$ instanceof $APP.$cljs$core$Keyword$$?
$G__78485$$.$fqn$:null){case "new":return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected_entry$$);case "modify":return $APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($_$jscomp$3009$$,$v$jscomp$666$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$safe_name$$,
$APP.$cljs$cst$2599$attr$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$5338$detail$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v$jscomp$666$$])))))},$APP.$cljs$core$group_by$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78480_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5659$modify$$,$cljs$cst$5660$operation$$.$cljs$core$IFn$_invoke$arity$1$($p1__78480_SHARP_$$))},
$candidates$jscomp$1$$)));case "delete":return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78481_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4834$delete$$,$cljs$cst$5660$operation$$.$cljs$core$IFn$_invoke$arity$1$($p1__78481_SHARP_$$))},$candidates$jscomp$1$$));default:return $candidates$jscomp$1$$}}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($selected_entry$$,
$APP.$cljs$cst$5338$detail$$,$detail$jscomp$9_entries$jscomp$38$$)};
$app$main$ui$workspace$sidebar$history$history_entry_details_STAR_$$=function($map__78489_map__78489__$1_props_78488$$){var $entry$jscomp$73$$=$map__78489_map__78489__$1_props_78488$$.entry;$map__78489_map__78489__$1_props_78488$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$history$workspace_undo$$);$map__78489_map__78489__$1_props_78488$$=$APP.$cljs$core$__destructure_map$$($map__78489_map__78489__$1_props_78488$$);var $entries$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78489_map__78489__$1_props_78488$$,
$APP.$cljs$cst$1838$items$$),$objects$jscomp$778$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-detail",children:function(){var $G__78490$$=$cljs$cst$5660$operation$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$73$$);switch($G__78490$$ instanceof $APP.$cljs$core$Keyword$$?$G__78490$$.$fqn$:null){case "new":return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$73$$),
$entries$jscomp$40$$,$objects$jscomp$778$$));case "delete":return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_history__history-entry-details-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$153$$,$JSCompiler_inline_result$jscomp$1800_id$jscomp$952$$){var $JSCompiler_temp_const$jscomp$1798$$=$out_arr__44124__auto__$jscomp$153$$.push,$shape_name$jscomp$inline_8878$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($JSCompiler_inline_result$jscomp$1800_id$jscomp$952$$,
$entries$jscomp$40$$,$objects$jscomp$778$$));$JSCompiler_inline_result$jscomp$1800_id$jscomp$952$$=(0,$APP.$rumext$v2$jsx$$)("li",{children:$shape_name$jscomp$inline_8878$$},$JSCompiler_inline_result$jscomp$1800_id$jscomp$952$$);$JSCompiler_temp_const$jscomp$1798$$.call($out_arr__44124__auto__$jscomp$153$$,$JSCompiler_inline_result$jscomp$1800_id$jscomp$952$$);return $out_arr__44124__auto__$jscomp$153$$},[],$APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$73$$))});case "modify":return(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_workspace_sidebar_history__history-entry-details-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$154$$,$JSCompiler_temp_const$jscomp$1801_p__78491$$){var $JSCompiler_inline_result$jscomp$1803_id$jscomp$953$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1801_p__78491$$,0,null),$attributes$jscomp$76$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1801_p__78491$$,
1,null);$JSCompiler_temp_const$jscomp$1801_p__78491$$=$out_arr__44124__auto__$jscomp$154$$.push;var $shape_name$jscomp$inline_8880$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($JSCompiler_inline_result$jscomp$1803_id$jscomp$953$$,$entries$jscomp$40$$,$objects$jscomp$778$$));$JSCompiler_inline_result$jscomp$1803_id$jscomp$953$$=(0,$APP.$rumext$v2$jsxs$$)("li",{children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$shape_name$jscomp$inline_8880$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$attributes$jscomp$76$$)})]},$JSCompiler_inline_result$jscomp$1803_id$jscomp$953$$);$JSCompiler_temp_const$jscomp$1801_p__78491$$.call($out_arr__44124__auto__$jscomp$154$$,$JSCompiler_inline_result$jscomp$1803_id$jscomp$953$$);return $out_arr__44124__auto__$jscomp$154$$},[],$APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$73$$))});default:return null}}()})};
$app$main$ui$workspace$sidebar$history$history_entry$$=function($entry$jscomp$74_props_78495$$){var $disabled_QMARK_$jscomp$7$$=$entry$jscomp$74_props_78495$$["disabled?"],$current_QMARK_$$=$entry$jscomp$74_props_78495$$["current?"],$idx_entry$$=$entry$jscomp$74_props_78495$$["idx-entry"];$entry$jscomp$74_props_78495$$=$entry$jscomp$74_props_78495$$.entry;var $hover_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_detail_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$toggle_show_detail$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$470$$){var $has_entry_QMARK_$$=$APP.$cljs$core$parse_boolean$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$470$$),"has-entry"));$APP.$app$util$dom$stop_propagation$$($event$jscomp$470$$);return $APP.$cljs$core$truth_$$($has_entry_QMARK_$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_detail_QMARK_$$,$APP.$cljs$core$not$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",
{onPointerEnter:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$6$$,!0)},onPointerLeave:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$6$$,!1)},onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$undo_to_index$$($idx_entry$$))},className:"main_ui_workspace_sidebar_history__history-entry "+($APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$7$$)?"main_ui_workspace_sidebar_history__disabled":
"")+" "+($APP.$cljs$core$truth_$$($current_QMARK_$$)?"main_ui_workspace_sidebar_history__current":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover_QMARK_$jscomp$6$$))?"main_ui_workspace_sidebar_history__hover":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_detail_QMARK_$$))?"main_ui_workspace_sidebar_history__show-detail":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-summary",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_history__history-entry-summary-icon",children:$app$main$ui$workspace$sidebar$history$entry__GT_icon$$($entry$jscomp$74_props_78495$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-summary-text",children:$app$main$ui$workspace$sidebar$history$entry__GT_message$$($entry$jscomp$74_props_78495$$)}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$74_props_78495$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$toggle_show_detail$$,"data-has-entry":""+($APP.$cljs$cst$5338$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$74_props_78495$$)!=null),className:"main_ui_workspace_sidebar_history__history-entry-summary-button "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_detail_QMARK_$$))?"main_ui_workspace_sidebar_history__button-opened":""),children:$APP.$app$main$ui$icons$arrow$$}):null]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_detail_QMARK_$$))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_entry_details_STAR_$$,{entry:$entry$jscomp$74_props_78495$$}):null]})};
$app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$=function(){var $entries$jscomp$41_objects$jscomp$779$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$map__78500_map__78500__$1$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$history$workspace_undo$$);$map__78500_map__78500__$1$$=$APP.$cljs$core$__destructure_map$$($map__78500_map__78500__$1$$);var $items$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78500_map__78500__$1$$,$APP.$cljs$cst$1838$items$$),
$index$jscomp$483$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78500_map__78500__$1$$,$APP.$cljs$cst$1795$index$$);$entries$jscomp$41_objects$jscomp$779$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$select_entry$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$resolve_shape_types$$($items$jscomp$59$$,$entries$jscomp$41_objects$jscomp$779$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$parse_entry$$,
$items$jscomp$59$$)));return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-toolbox",children:$APP.$cljs$core$empty_QMARK_$$($entries$jscomp$41_objects$jscomp$779$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"history",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.undo.empty")})}):
(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_history__history-entries",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$155$$,$entry$jscomp$75_p__78505$$){var $idx_entry$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry$jscomp$75_p__78505$$,0,null);$entry$jscomp$75_p__78505$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry$jscomp$75_p__78505$$,1,null);$out_arr__44124__auto__$jscomp$155$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_entry$$,
{entry:$entry$jscomp$75_p__78505$$,"idx-entry":$idx_entry$jscomp$1$$,"current?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx_entry$jscomp$1$$,$index$jscomp$483$$),"disabled?":$idx_entry$jscomp$1$$>$index$jscomp$483$$},["entry-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($idx_entry$jscomp$1$$)].join("")));return $out_arr__44124__auto__$jscomp$155$$},[],$APP.$cljs$core$reverse$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$entries$jscomp$41_objects$jscomp$779$$)))})})};
$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$=function(){var $selected$jscomp$168$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);return $APP.$app$main$ui$hooks$use_equal_memo$$($selected$jscomp$168$$)};
$app$main$ui$workspace$sidebar$layers$frame_wrapper_STAR_$$=function($props_78482_props__$1$jscomp$76$$){var $selected$jscomp$169$$=$props_78482_props__$1$jscomp$76$$.selected,$pending_selected_ref$$=(0,$APP.$rumext$v2$use_ref$$)($selected$jscomp$169$$),$current_selected$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($selected$jscomp$169$$);$props_78482_props__$1$jscomp$76$$={...$props_78482_props__$1$jscomp$76$$,selected:$APP.$cljs$core$_deref$$($current_selected$$)};var $set_selected$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$rxops$throttle_fn$$(function(){var $temp__5825__auto__$jscomp$365$$=$APP.$rumext$v2$ref_val$$($pending_selected_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$365$$)?$APP.$cljs$core$reset_BANG_$$($current_selected$$,$temp__5825__auto__$jscomp$365$$):null})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$169$$),$APP.$rumext$v2$adapt$$($set_selected$$)],
function(){$APP.$rumext$v2$set_ref_val_BANG_$$($pending_selected_ref$$,$selected$jscomp$169$$);$set_selected$$();return function(){$APP.$rumext$v2$set_ref_val_BANG_$$($pending_selected_ref$$,null);return $APP.$beicon$v2$core$_dispose$$($set_selected$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,$props_78482_props__$1$jscomp$76$$)};
$app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$=function($props_78496_props__$1$jscomp$77$$){var $objects$jscomp$781$$=$props_78496_props__$1$jscomp$77$$.objects,$state_tmp$$=(0,$APP.$rumext$v2$useState$$)($objects$jscomp$781$$),$objects_SINGLEQUOTE_$jscomp$2$$=$state_tmp$$[0],$set_objects$$=$state_tmp$$[1],$subject_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$subject$$()}),$changes_s$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($subject_s$$)],
function(){return $APP.$beicon$v2$core$debounce$$(500,$subject_s$$)});$props_78496_props__$1$jscomp$77$$={...$props_78496_props__$1$jscomp$77$$,objects:$objects_SINGLEQUOTE_$jscomp$2$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$781$$),$APP.$rumext$v2$adapt$$($subject_s$$)],function(){return $subject_s$$.next($objects$jscomp$781$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($changes_s$jscomp$1$$)],
function(){var $sub$jscomp$23$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($changes_s$jscomp$1$$,$set_objects$$);return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$23$$)}});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$layers$layers_tree_STAR_$$,$props_78496_props__$1$jscomp$77$$)};
$app$main$ui$workspace$sidebar$layers$calc_reparented_objects$$=function($objects$jscomp$783_reparented_objects$$){$objects$jscomp$783_reparented_objects$$=$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($_$jscomp$3010$$,$val$jscomp$203$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($val$jscomp$203$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,
null]))},$objects$jscomp$783_reparented_objects$$);var $reparented_shapes$$=$APP.$cljs$core$vec$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78509_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$p1__78509_SHARP_$$)},$APP.$cljs$core$keys$$($objects$jscomp$783_reparented_objects$$)));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($objects$jscomp$783_reparented_objects$$,$APP.$app$common$uuid$zero$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1614$shapes$$,$reparented_shapes$$)};
$app$main$ui$workspace$sidebar$layers$match_filters_QMARK_$$=function($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$,$p__78514$$){var $id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78514$$,0,null),$shape$jscomp$986$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78514$$,1,null),$search$jscomp$7$$=
$cljs$cst$5661$search_text$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$),$scope$jscomp$11$$=$cljs$cst$5662$search_scope$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$);$filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$=$cljs$cst$5663$filters$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$);var $filters__$1$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$,
$APP.$cljs$cst$1811$shape$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1417$circle$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1610$bool$$])):$filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$;$filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$=function(){switch($scope$jscomp$11$$ instanceof $APP.$cljs$core$Keyword$$?
$scope$jscomp$11$$.$fqn$:null){case "canvas":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$))&&$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)!=null&&$app$common$types$text$content_has_text_QMARK_$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$),$search$jscomp$7$$);default:var $and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$=
$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)),$APP.$cuerdas$core$lower$$($search$jscomp$7$$));if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$))return $and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$;$and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$=
$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)),$APP.$cuerdas$core$lower$$($search$jscomp$7$$));if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$))return $and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$;$and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$=
$APP.$cljs$core$_STAR_assert_STAR_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$)?$APP.$cuerdas$core$includes_QMARK_$$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)??""),$APP.$cuerdas$core$lower$$($search$jscomp$7$$)):$and__5023__auto__$jscomp$771_or__5025__auto__$jscomp$1144_or__5025__auto____$1$jscomp$127$$}}();return($id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$))?$id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$:$APP.$cljs$core$truth_$$($filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$)?
($id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$empty_QMARK_$$($filters__$1$jscomp$1$$))||($id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,$APP.$cljs$cst$1625$component$$)&&$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$986$$,
$APP.$cljs$cst$1627$component_id$$))||($id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,$APP.$cljs$cst$1612$image$$)&&$APP.$app$common$types$shape$has_images_QMARK_$$($shape$jscomp$986$$)!=null)?$id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$:
($id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$=function(){var $direct_filters$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1606$frame$$,
null,$APP.$cljs$cst$1417$circle$$,null,$APP.$cljs$cst$1610$bool$$,null,$APP.$cljs$cst$1611$rect$$,null,$APP.$cljs$cst$1588$text$$,null],null),null)),$filters__$1$jscomp$1$$);return $APP.$cljs$core$contains_QMARK_$$($direct_filters$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$))}())?$id$jscomp$956_or__5025__auto__$jscomp$1143_or__5025__auto____$1$jscomp$126_or__5025__auto____$2$jscomp$31_or__5025__auto____$3$jscomp$10_or__5025__auto____$4$jscomp$6$$:$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,
$APP.$cljs$cst$1608$group$$)&&$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)&&!$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$986$$,$APP.$cljs$cst$1627$component_id$$)&&(!$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$986$$,$APP.$cljs$cst$1609$masked_group$$)||$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)===!1)||$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,$APP.$cljs$cst$2689$mask$$)&&
$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$986$$)===!0:$filters$jscomp$12_state$jscomp$1180_text_match_QMARK_$$};
$app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$=function($checked_props_78523$$){var $on_change$jscomp$53$$=$checked_props_78523$$.onChange,$text$jscomp$140$$=$checked_props_78523$$.text,$name$jscomp$450$$=$checked_props_78523$$.name;$checked_props_78523$$=$checked_props_78523$$.checked;return(0,$APP.$rumext$v2$jsxs$$)("label",{className:"main_ui_workspace_sidebar_layers__radio-label "+($APP.$cljs$core$truth_$$($checked_props_78523$$)?"main_ui_workspace_sidebar_layers__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_layers__radio-icon "+($APP.$cljs$core$truth_$$($checked_props_78523$$)?"main_ui_workspace_sidebar_layers__checked":"")}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"radio",name:$name$jscomp$450$$,checked:$checked_props_78523$$,onChange:$on_change$jscomp$53$$,className:"main_ui_workspace_sidebar_layers__radio-input"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__radio-text",children:$text$jscomp$140$$})]})};
$app$main$ui$workspace$sidebar$layers$use_search$$=function($page$jscomp$164$$,$objects$jscomp$784$$){var $state_STAR_$jscomp$13$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5663$filters$$,$cljs$cst$5664$show_search$$,$cljs$cst$5665$num_items$$,$cljs$cst$5662$search_scope$$,$cljs$cst$5666$replace_text$$,$cljs$cst$5615$show_menu$$,$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$,$cljs$cst$5661$search_text$$,
$cljs$cst$5667$current_match_idx$$],[$APP.$cljs$core$PersistentHashSet$EMPTY$$,!1,100,$APP.$cljs$cst$3727$layers$$,"",!1,!1,"",0])}),$layers_search$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_layers_search$$),$state$jscomp$1181$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$13$$),$current_filters$$=$cljs$cst$5663$filters$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$current_items$$=$cljs$cst$5665$num_items$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),
$current_search$$=$cljs$cst$5661$search_text$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$replace_text$$=$cljs$cst$5666$replace_text$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$show_menu_QMARK_$jscomp$2$$=$cljs$cst$5615$show_menu$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$show_search_QMARK_$$=$cljs$cst$5664$show_search$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$find_replace_mode_QMARK_$$=$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),
$search_scope$$=$cljs$cst$5662$search_scope$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$current_match_idx_filtered_objects$$=$cljs$cst$5667$current_match_idx$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1181$$),$search_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$clear_search_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5661$search_text$$,
"",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5665$num_items$$,100,$cljs$cst$5667$current_match_idx$$,0]))}),$toggle_filters$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5615$show_menu$$,$APP.$cljs$core$not$$)}),$on_toggle_filters_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$471$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$471$$);
return $toggle_filters$$.$cljs$core$IFn$_invoke$arity$0$?$toggle_filters$$.$cljs$core$IFn$_invoke$arity$0$():$toggle_filters$$()}),$hide_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5615$show_menu$$,!1)}),$on_key_down$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$472$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$472$$))?
$hide_menu$$.$cljs$core$IFn$_invoke$arity$0$?$hide_menu$$.$cljs$core$IFn$_invoke$arity$0$():$hide_menu$$():null}),$update_search_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$813$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5661$search_text$$,$value$jscomp$813$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5665$num_items$$,100,$cljs$cst$5667$current_match_idx$$,
0]))}),$update_replace_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$473_value$jscomp$814$$){$event$jscomp$473_value$jscomp$814$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$473_value$jscomp$814$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5666$replace_text$$,$event$jscomp$473_value$jscomp$814$$)}),$f_key_QMARK_$$=$APP.$app$util$keyboard$is_key_ignore_case_QMARK_$$("f"),
$h_key_QMARK_$$=$APP.$app$util$keyboard$is_key_ignore_case_QMARK_$$("h"),$handle_find_shortcut_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$474$$){if($APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$474$$)){if($APP.$cljs$core$truth_$$($f_key_QMARK_$$($event$jscomp$474$$)))return $APP.$app$util$dom$prevent_default$$($event$jscomp$474$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$474$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4793$find$$,
null));if($APP.$cljs$core$truth_$$($h_key_QMARK_$$($event$jscomp$474$$)))return $APP.$app$util$dom$prevent_default$$($event$jscomp$474$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$474$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4534$find_and_replace$$,null))}return null}),$set_search_scope$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($scope$jscomp$12$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5662$search_scope$$,$scope$jscomp$12$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5665$num_items$$,100,$cljs$cst$5667$current_match_idx$$,0]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_layers_search_scope$$($scope$jscomp$12$$))}),$toggle_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($find_replace_mode_QMARK_$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($find_replace_mode_QMARK_$$)?
$APP.$cljs$cst$4793$find$$:$APP.$cljs$cst$4534$find_and_replace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3734$force_QMARK_$$,!0],null)))}),$toggle_search$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_search_QMARK_$$)],function($event$jscomp$475$$){$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_current_target$$($event$jscomp$475$$));return $APP.$cljs$core$truth_$$($show_search_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$close_layers_search$$):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4793$find$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3734$force_QMARK_$$,!0],null)))}),$remove_filter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$476$$){var $fkey$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$476$$),
"filter"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($state__$1$jscomp$54$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$54$$,$cljs$cst$5663$filters$$,$APP.$cljs$core$disj$$,$fkey$$),$cljs$cst$5665$num_items$$,100)})}),$add_filter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$477$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$477$$);
var $key$jscomp$412$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$477$$),"filter"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($state__$1$jscomp$55$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$55$$,
$cljs$cst$5663$filters$$,$APP.$cljs$core$conj$$,$key$jscomp$412$$),$cljs$cst$5615$show_menu$$,$APP.$cljs$core$not$$),$cljs$cst$5665$num_items$$,100)})}),$active_QMARK_$jscomp$5$$=$show_search_QMARK_$$&&($APP.$app$common$data$not_empty_QMARK_$$($current_search$$)||$APP.$app$common$data$not_empty_QMARK_$$($current_filters$$)),$filtered_objects_all$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_QMARK_$jscomp$5$$),$APP.$rumext$v2$adapt$$($objects$jscomp$784$$),
$APP.$rumext$v2$adapt$$($state$jscomp$1181$$)],function(){return $active_QMARK_$jscomp$5$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$layers$match_filters_QMARK_$$,$state$jscomp$1181$$)),$objects$jscomp$784$$):null}),$filtered_objects_total$$=$APP.$cljs$core$count$$($filtered_objects_all$$),$canvas_match_ids_handle_show_more$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$784$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3083$canvas$$,$search_scope$$)&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$158$$,$id$jscomp$957$$,$shape$jscomp$987$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$987$$))&&$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$987$$)!=null&&$app$common$types$text$content_has_text_QMARK_$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$987$$),$current_search$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$158$$,$id$jscomp$957$$):$acc$jscomp$158$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$784$$):null}),
$layer_match_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$784$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3727$layers$$,$search_scope$$)&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$159$$,$id$jscomp$958$$,$shape$jscomp$988$$){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$988$$)),
$APP.$cuerdas$core$lower$$($current_search$$)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$159$$,$id$jscomp$958$$):$acc$jscomp$159$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$784$$):null}),$text_match_ids$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3083$canvas$$,$search_scope$$)?$canvas_match_ids_handle_show_more$$:$layer_match_ids$$,$text_match_count$$=$APP.$cljs$core$count$$($text_match_ids$$),$safe_match_idx$$=$text_match_count$$>
0?$APP.$cljs$core$mod$$($current_match_idx_filtered_objects$$,$text_match_count$$):0,$navigate_next$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_count$$)],function(){return $text_match_count$$>0?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5667$current_match_idx$$,function($idx$jscomp$123$$){return $APP.$cljs$core$mod$$($idx$jscomp$123$$+1,$text_match_count$$)}):null}),
$navigate_prev$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_count$$)],function(){return $text_match_count$$>0?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5667$current_match_idx$$,function($idx$jscomp$124$$){return $APP.$cljs$core$mod$$($idx$jscomp$124$$-1+$text_match_count$$,$text_match_count$$)}):null}),$handle_replace$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_ids$$),
$APP.$rumext$v2$adapt$$($safe_match_idx$$),$APP.$rumext$v2$adapt$$($replace_text$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){if($text_match_count$$>0&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)){var $id$jscomp$959$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($text_match_ids$$,$safe_match_idx$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3083$canvas$$,$search_scope$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_text_in_shapes$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$959$$],null),$current_search$$,$replace_text$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_layer_names_in_shapes$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$959$$],null),$current_search$$,$replace_text$$))}return null}),$handle_replace_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_ids$$),
$APP.$rumext$v2$adapt$$($replace_text$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){return $text_match_count$$>0&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3083$canvas$$,$search_scope$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_text_in_shapes$$($text_match_ids$$,$current_search$$,$replace_text$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_layer_names_in_shapes$$($text_match_ids$$,$current_search$$,$replace_text$$)):null}),$on_replace_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_replace$$)],function($event$jscomp$478$$){var $JSCompiler_inline_result$jscomp$1807_or__5025__auto__$jscomp$inline_8886$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$478$$);$JSCompiler_inline_result$jscomp$1807_or__5025__auto__$jscomp$inline_8886$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1807_or__5025__auto__$jscomp$inline_8886$$)?$JSCompiler_inline_result$jscomp$1807_or__5025__auto__$jscomp$inline_8886$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$478$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1807_or__5025__auto__$jscomp$inline_8886$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$478$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$478$$),$handle_replace$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_replace$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$478$$):$handle_replace$$($event$jscomp$478$$)):null}),$on_replace_all_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_replace_all$$)],function($event$jscomp$479$$){var $JSCompiler_inline_result$jscomp$1808_or__5025__auto__$jscomp$inline_8888$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$479$$);$JSCompiler_inline_result$jscomp$1808_or__5025__auto__$jscomp$inline_8888$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1808_or__5025__auto__$jscomp$inline_8888$$)?$JSCompiler_inline_result$jscomp$1808_or__5025__auto__$jscomp$inline_8888$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$479$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1808_or__5025__auto__$jscomp$inline_8888$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$479$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$479$$),$handle_replace_all$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_replace_all$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$479$$):$handle_replace_all$$($event$jscomp$479$$)):null});$current_match_idx_filtered_objects$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_QMARK_$jscomp$5$$),$APP.$rumext$v2$adapt$$($filtered_objects_all$$),$APP.$rumext$v2$adapt$$($current_items$$)],function(){return $active_QMARK_$jscomp$5$$?$app$main$ui$workspace$sidebar$layers$calc_reparented_objects$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$($current_items$$),$filtered_objects_all$$)):null});$canvas_match_ids_handle_show_more$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filtered_objects_total$$),$APP.$rumext$v2$adapt$$($current_items$$)],function(){return $current_items$$<=$filtered_objects_total$$?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5665$num_items$$,
$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([100])):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$8$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$on_key_down$jscomp$16$$),$key2$jscomp$6$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"click",$hide_menu$$);return function(){$APP.$goog$events$unlistenByKey$$($key1$jscomp$8$$);return $APP.$goog$events$unlistenByKey$$($key2$jscomp$6$$)}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layers_search$$)],function(){if($APP.$cljs$core$truth_$$($layers_search$$)){var $map__78531__$1$$=$APP.$cljs$core$__destructure_map$$($layers_search$$),$open_QMARK_$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78531__$1$$,$APP.$cljs$cst$4533$open_QMARK_$$),$find_replace_mode_QMARK___$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78531__$1$$,$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$),
$scope$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78531__$1$$,$APP.$cljs$cst$571$scope$$);return $APP.$cljs$core$truth_$$($open_QMARK_$jscomp$14$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($G__78532_s$jscomp$585$$){var $mode_changed_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4535$find_replace_mode_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__78532_s$jscomp$585$$),$find_replace_mode_QMARK___$1$$),
$opening_QMARK_$$=$APP.$cljs$core$not$$($cljs$cst$5664$show_search$$.$cljs$core$IFn$_invoke$arity$1$($G__78532_s$jscomp$585$$));$G__78532_s$jscomp$585$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__78532_s$jscomp$585$$,$cljs$cst$5664$show_search$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$,$find_replace_mode_QMARK___$1$$,$cljs$cst$5662$search_scope$$,$scope$jscomp$13$$]));return $opening_QMARK_$$||$mode_changed_QMARK_$$?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__78532_s$jscomp$585$$,$cljs$cst$5661$search_text$$,"",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5666$replace_text$$,"",$cljs$cst$5667$current_match_idx$$,0])):$G__78532_s$jscomp$585$$}):null}return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($state__$1$jscomp$56$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state__$1$jscomp$56$$,
$cljs$cst$5661$search_text$$,"",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5666$replace_text$$,"",$cljs$cst$5663$filters$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$])),$cljs$cst$5615$show_menu$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$,!1])),$cljs$cst$5662$search_scope$$,$APP.$cljs$cst$3727$layers$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5665$num_items$$,100,$cljs$cst$5667$current_match_idx$$,
0])),$cljs$cst$5664$show_search$$,!1)})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layers_search$$,$APP.$cljs$cst$571$scope$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($layers_search$$)?$APP.$cljs$cst$4533$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layers_search$$):$layers_search$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5662$search_scope$$,$APP.$cljs$cst$571$scope$$.$cljs$core$IFn$_invoke$arity$1$($layers_search$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layers_search$$),$APP.$rumext$v2$adapt$$($show_search_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($layers_search$$)){var $and__5023__auto____$1$jscomp$132$$=$APP.$cljs$cst$4533$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layers_search$$);
return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$132$$)?$show_search_QMARK_$$:$and__5023__auto____$1$jscomp$132$$}return $layers_search$$}())?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $temp__5825__auto__$jscomp$367$$=$APP.$rumext$v2$ref_val$$($search_input_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$367$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$367$$):null}):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($find_replace_mode_QMARK_$$),
$APP.$rumext$v2$adapt$$($show_search_QMARK_$$),$APP.$rumext$v2$adapt$$($safe_match_idx$$),$APP.$rumext$v2$adapt$$($text_match_ids$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($find_replace_mode_QMARK_$$)?$APP.$cljs$core$truth_$$($show_search_QMARK_$$)?$APP.$cljs$core$seq$$($text_match_ids$$):$show_search_QMARK_$$:$find_replace_mode_QMARK_$$)){var $current_id_78558$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($text_match_ids$$,$safe_match_idx$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$highlight$set_search_match_highlight$$($current_id_78558$$,
$text_match_ids$$))}return function(){return $APP.$cljs$core$seq$$($text_match_ids$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$highlight$clear_search_match_highlight$$($text_match_ids$$)):null}});return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_match_idx_filtered_objects$$,$canvas_match_ids_handle_show_more$$,function(){return $APP.$cljs$core$truth_$$($show_search_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__tool-window-bar",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{inputRef:$search_input_ref$$,className:"main_ui_workspace_sidebar_layers__search-item",onChange:$update_search_text$$,value:$current_search$$,onClear:$clear_search_text$$,onKeyDown:$handle_find_shortcut_keydown$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search"),
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_layers__filter-button","aria-pressed":$show_menu_QMARK_$jscomp$2$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.filter"),onClick:$on_toggle_filters_click$$,icon:"filter"})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-pressed":$find_replace_mode_QMARK_$$,
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search-and-replace"),onClick:$toggle_mode$$,icon:"menu"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$toggle_search$$,icon:"close"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-wrapper",children:[$find_replace_mode_QMARK_$$?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-row",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"text",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.replace-placeholder"),onKeyDown:$handle_find_shortcut_keydown$$,onChange:$update_replace_text$$}),$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$text_match_count$$>0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-match-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__replace-match-count",children:""+($safe_match_idx$$+1??"")+" / "+($text_match_count$$??"")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.previous"),onClick:$navigate_prev$$,icon:"arrow-up"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"),onClick:$navigate_next$$,icon:"arrow-down"})]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-match-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.no-matches")}):null]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-scope-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$,
{name:"search-scope",checked:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3083$canvas$$,$search_scope$$),text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search-scope-canvas"),onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($set_search_scope$$,$APP.$cljs$cst$3083$canvas$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$,{name:"search-scope",checked:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3727$layers$$,
$search_scope$$),text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search-scope-layers"),onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($set_search_scope$$,$APP.$cljs$cst$3727$layers$$)})]}),$find_replace_mode_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-actions-row",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_layers__replace-actions-button",
onClick:$handle_replace$$,onKeyDown:$on_replace_keydown$$,disabled:$text_match_count$$===0||$APP.$cuerdas$core$empty_QMARK_$$($current_search$$),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.replace")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_layers__replace-actions-button",onClick:$handle_replace_all$$,onKeyDown:$on_replace_all_keydown$$,disabled:$text_match_count$$===
0||$APP.$cuerdas$core$empty_QMARK_$$($current_search$$),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.replace-all")})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__active-filters",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$158$$,$fkey$jscomp$1$$){$out_arr__44124__auto__$jscomp$158$$.push(function(){var $fname$jscomp$3$$=$APP.$app$common$data$name$$($fkey$jscomp$1$$),
$name$jscomp$451$$=function(){switch($fkey$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$fkey$jscomp$1$$.$fqn$:null){case "frame":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.frames");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.groups");case "mask":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.masks");case "component":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.components");
case "text":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.texts");case "image":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.images");case "shape":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.shapes");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($fkey$jscomp$1$$)}}(),$filter_icon$$=$app$util$shape_icon$get_shape_icon_by_type$$($fkey$jscomp$1$$);
return(0,$APP.$rumext$v2$jsxs$$)("button",{"data-filter":$fname$jscomp$3$$,onClick:$remove_filter$$,className:"main_ui_workspace_sidebar_layers__layer-filter",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$filter_icon$$,size:"s",className:"main_ui_workspace_sidebar_layers__layer-filter-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__layer-filter-name",children:$name$jscomp$451$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"close-small",className:"main_ui_workspace_sidebar_layers__layer-filter-close"})]},$fname$jscomp$3$$)}());return $out_arr__44124__auto__$jscomp$158$$},[],$current_filters$$)}),$show_menu_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_sidebar_layers__filters-container",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"frame",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,
$APP.$cljs$cst$1606$frame$$)?"main_ui_workspace_sidebar_layers__selected":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"board",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.frames")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1606$frame$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"group",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1608$group$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"group",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.groups")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1608$group$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"mask",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$2689$mask$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"mask",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.masks")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$2689$mask$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"component",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1625$component$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"component",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.components")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1625$component$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"text",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1588$text$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"text",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.texts")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1588$text$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"image",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1612$image$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"img",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.images")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1612$image$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"shape",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1811$shape$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"path",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.shapes")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1811$shape$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]})]}):null]})]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__tool-window-bar",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,className:"main_ui_workspace_sidebar_layers__tool-window-bar-title",
title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$164$$),onBtnClick:$toggle_search$$,btnIcon:"search",btnTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.search")})})}],null)};
$app$main$ui$workspace$sidebar$layers$on_scroll$$=function($event$jscomp$480_frames$jscomp$27$$){var $children$jscomp$298_is_children_shown_QMARK_$$=$goog$dom$getElementsByClass$$("sticky-children");if($children$jscomp$298_is_children_shown_QMARK_$$.length>0){var $target_top$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($event$jscomp$480_frames$jscomp$27$$)));$event$jscomp$480_frames$jscomp$27$$=$goog$dom$getElementsByClass$$("root-board");
var $last_hidden_frame$$=$APP.$cljs$core$last$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78534_SHARP_$$){return $APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($p1__78534_SHARP_$$))-$target_top$$<=0},$event$jscomp$480_frames$jscomp$27$$)),$frame_id$jscomp$137_sticky_QMARK_$$=$APP.$app$util$dom$get_attribute$$($last_hidden_frame$$,"id"),$children_frame_id_last_hidden_children$$=$APP.$cljs$core$last$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78535_SHARP_$$){return $APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($p1__78535_SHARP_$$))-
$target_top$$<0},$children$jscomp$298_is_children_shown_QMARK_$$));$children$jscomp$298_is_children_shown_QMARK_$$=$APP.$cljs$core$truth_$$($children_frame_id_last_hidden_children$$)?$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($children_frame_id_last_hidden_children$$))-$target_top$$>0:$children_frame_id_last_hidden_children$$;$children_frame_id_last_hidden_children$$=$APP.$app$util$dom$get_attribute$$($children_frame_id_last_hidden_children$$,
"data-id");$frame_id$jscomp$137_sticky_QMARK_$$=$APP.$cljs$core$truth_$$($last_hidden_frame$$)?$APP.$cljs$core$truth_$$($children$jscomp$298_is_children_shown_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$137_sticky_QMARK_$$,$children_frame_id_last_hidden_children$$):$children$jscomp$298_is_children_shown_QMARK_$$:$last_hidden_frame$$;$APP.$cljs$core$run_BANG_$$(function($p1__78536_SHARP_$$){return $p1__78536_SHARP_$$!=null?$p1__78536_SHARP_$$.classList.remove("sticky"):
null},$event$jscomp$480_frames$jscomp$27$$);return $APP.$cljs$core$truth_$$($frame_id$jscomp$137_sticky_QMARK_$$)?$APP.$app$util$dom$add_class_BANG_$$($last_hidden_frame$$,"sticky"):null}return null};
$app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$=function($props_78487$$){var $children$jscomp$299$$=$props_78487$$.children,$class$$jscomp$66$$=$props_78487$$.className,$is_visible$$=$props_78487$$.isVisible,$ref$jscomp$52$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_visible$$)],function(){var $temp__5825__auto__$jscomp$369$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$52$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$369$$)?
$APP.$cljs$core$truth_$$($is_visible$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$369$$,!1):null:null});return $APP.$cljs$core$truth_$$($is_visible$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$ref$jscomp$52$$,className:($class$$jscomp$66$$??"")+" main_ui_workspace_sidebar_options_common__advanced-options-wrapper",children:$children$jscomp$299$$}):null};
$app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$=function($value$jscomp$815$$,$emit_value_fn$$,$ids$jscomp$278$$,$attrs$jscomp$176$$){return typeof $value$jscomp$815$$==="string"||typeof $value$jscomp$815$$==="number"||$value$jscomp$815$$==null?$emit_value_fn$$.$cljs$core$IFn$_invoke$arity$1$?$emit_value_fn$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$815$$):$emit_value_fn$$($value$jscomp$815$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$815$$),$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$176$$,$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$278$$],null)))};
$app$main$ui$ds$controls$utilities$token_field$token_field_STAR_$$=function($on_token_key_down_props_78524$$){var $is_open$jscomp$8$$=$on_token_key_down_props_78524$$.isOpen,$detach_token$jscomp$2$$=$on_token_key_down_props_78524$$.detachToken,$disabled$jscomp$14$$=$on_token_key_down_props_78524$$.disabled,$property$jscomp$82$$=$on_token_key_down_props_78524$$.property,$on_focus$jscomp$8$$=$on_token_key_down_props_78524$$.onFocus,$value$jscomp$816$$=$on_token_key_down_props_78524$$.value,$token_has_errors$$=
$on_token_key_down_props_78524$$.tokenHasErrors,$tooltip_placement$jscomp$1$$=$on_token_key_down_props_78524$$.tooltipPlacement,$on_blur$jscomp$16$$=$on_token_key_down_props_78524$$.onBlur,$token_detach_btn_ref$$=$on_token_key_down_props_78524$$.tokenDetachBtnRef,$on_click$jscomp$44$$=$on_token_key_down_props_78524$$.onClick,$content$jscomp$249_label$jscomp$40$$=$on_token_key_down_props_78524$$.label,$id$jscomp$960_id__$1$jscomp$19$$=$on_token_key_down_props_78524$$.id,$class$$jscomp$67$$=$on_token_key_down_props_78524$$.className,
$token_wrapper_ref$$=$on_token_key_down_props_78524$$.tokenWrapperRef,$slot_start$jscomp$1$$=$on_token_key_down_props_78524$$.slotStart;$on_token_key_down_props_78524$$=$on_token_key_down_props_78524$$.onTokenKeyDown;var $set_active_QMARK_$$=$id$jscomp$960_id__$1$jscomp$19$$!=null;$content$jscomp$249_label$jscomp$40$$=$APP.$cljs$core$truth_$$($token_has_errors$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.ref-not-valid"):$set_active_QMARK_$$?$content$jscomp$249_label$jscomp$40$$:
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("ds.inputs.token-field.no-active-token-option",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content$jscomp$249_label$jscomp$40$$]));var $default_id$$=(0,$APP.$rumext$v2$use_id$$)();$id$jscomp$960_id__$1$jscomp$19$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$960_id__$1$jscomp$19$$,$default_id$$);var $pill_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$focus_wrapper$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$14$$)],
function($event$jscomp$481$$){if($disabled$jscomp$14$$)return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$481$$);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$$))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$property$jscomp$82$$,className:"main_ui_ds_controls_utilities_token_field__token-field-wrapper",triggerRef:$token_wrapper_ref$$,id:""+($default_id$$??"")+"-input",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{"aria-labelledby":""+($default_id$$??"")+"-input",tabIndex:$APP.$cljs$core$truth_$$($disabled$jscomp$14$$)?-1:0,className:($class$$jscomp$67$$??"")+" main_ui_ds_controls_utilities_token_field__token-field "+(($slot_start$jscomp$1$$!=null?"main_ui_ds_controls_utilities_token_field__with-icon":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$14$$)?"main_ui_ds_controls_utilities_token_field__token-field-disabled":"")),children:[$slot_start$jscomp$1$$!=null?$slot_start$jscomp$1$$:null,(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_ds_controls_utilities_token_field__content-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$content$jscomp$249_label$jscomp$40$$,triggerRef:$pill_ref$$,id:""+($id$jscomp$960_id__$1$jscomp$19$$??"")+"-pill",children:(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_click$jscomp$44$$,ref:$pill_ref$$,disabled:$disabled$jscomp$14$$,"aria-labelledby":""+($id$jscomp$960_id__$1$jscomp$19$$??"")+"-pill",onKeyDown:$on_token_key_down_props_78524$$,
className:"main_ui_ds_controls_utilities_token_field__pill "+($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1148$$=!$set_active_QMARK_$$;return $or__5025__auto__$jscomp$1148$$?$or__5025__auto__$jscomp$1148$$:$token_has_errors$$}())?"main_ui_ds_controls_utilities_token_field__no-set-pill":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$14$$)?"main_ui_ds_controls_utilities_token_field__pill-disabled":""),children:[$value$jscomp$816$$,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1149$$=
!$set_active_QMARK_$$;return $or__5025__auto__$jscomp$1149$$?$or__5025__auto__$jscomp$1149$$:$token_has_errors$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_utilities_token_field__pill-dot"}):null]})})}),$disabled$jscomp$14$$?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_ds_controls_utilities_token_field__invisible-button "+($APP.$cljs$core$truth_$$($is_open$jscomp$8$$)?"main_ui_ds_controls_utilities_token_field__invisible-btn-dropdown-open":
""),tooltipClass:"main_ui_ds_controls_utilities_token_field__button-tooltip",tooltipPlacement:$tooltip_placement$jscomp$1$$,icon:"broken-link",ref:$token_detach_btn_ref$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("token-actions.detach-token"),onClick:$detach_token$jscomp$2$$})],onFocus:$on_focus$jscomp$8$$,onBlur:$on_blur$jscomp$16$$,onClick:$focus_wrapper$$,ref:$token_wrapper_ref$$,onKeyDown:$on_token_key_down_props_78524$$,disabled:$disabled$jscomp$14$$})})};
$app$main$ui$ds$controls$numeric_input$parse_value$$=function($G__78549$jscomp$inline_13534_raw_value$$,$last_value_new_value$jscomp$23$$,$G__78548_min_value$jscomp$3$$,$max_value$jscomp$5$$,$nillable$$){$last_value_new_value$jscomp$23$$=$app$util$simple_math$expr_eval$$($APP.$cuerdas$core$strip_suffix$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78549$jscomp$inline_13534_raw_value$$),"."),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($last_value_new_value$jscomp$23$$));
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable$$)?$G__78549$jscomp$inline_13534_raw_value$$==null:$nillable$$)?null:$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($last_value_new_value$jscomp$23$$))?($G__78549$jscomp$inline_13534_raw_value$$=Math.min(Math.max($last_value_new_value$jscomp$23$$,-1073741824),1.0737418235E9),$G__78548_min_value$jscomp$3$$=$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($G__78548_min_value$jscomp$3$$))?Math.max($G__78549$jscomp$inline_13534_raw_value$$,
$G__78548_min_value$jscomp$3$$):$G__78549$jscomp$inline_13534_raw_value$$,$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($max_value$jscomp$5$$))?Math.min($G__78548_min_value$jscomp$3$$,$max_value$jscomp$5$$):$G__78548_min_value$jscomp$3$$):null};
$app$main$ui$ds$controls$numeric_input$get_option_by_name$$=function($options$jscomp$613_options__$1$jscomp$81$$,$name$jscomp$452$$){$options$jscomp$613_options__$1$jscomp$81$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$613_options__$1$jscomp$81$$)?$APP.$cljs$core$_deref$$($options$jscomp$613_options__$1$jscomp$81$$):$options$jscomp$613_options__$1$jscomp$81$$;return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78550_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1136$token$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__78550_SHARP_$$,$APP.$cljs$cst$139$type$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$452$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__78550_SHARP_$$,$APP.$cljs$cst$725$name$$))},$options$jscomp$613_options__$1$jscomp$81$$)};
$app$main$ui$ds$controls$numeric_input$get_token_op$$=function($tokens$jscomp$49_tokens__$1$jscomp$2$$,$name$jscomp$453$$){$tokens$jscomp$49_tokens__$1$jscomp$2$$=$APP.$cljs$core$delay_QMARK_$$($tokens$jscomp$49_tokens__$1$jscomp$2$$)?$APP.$cljs$core$_deref$$($tokens$jscomp$49_tokens__$1$jscomp$2$$):$tokens$jscomp$49_tokens__$1$jscomp$2$$;var $xform$jscomp$41$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78551_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78551_SHARP_$$),
$name$jscomp$453$$)});return $APP.$cljs$core$reduce_kv$$(function($result$jscomp$366$$,$_$jscomp$3016$$,$tokens__$2$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$366$$,$xform$jscomp$41$$,$tokens__$2$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$tokens$jscomp$49_tokens__$1$jscomp$2$$)};
$app$main$ui$ds$controls$numeric_input$clean_token_name$$=function($G__78552__$1_s$jscomp$586$$){$G__78552__$1_s$jscomp$586$$=$G__78552__$1_s$jscomp$586$$==null?null:$APP.$cuerdas$core$replace$$($G__78552__$1_s$jscomp$586$$,/^\{/,"");return $G__78552__$1_s$jscomp$586$$==null?null:$APP.$cuerdas$core$replace$$($G__78552__$1_s$jscomp$586$$,/\}$/,"")};
$app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$=function($option$jscomp$18$$){var $and__5023__auto__$jscomp$779$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$18$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$779$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$18$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1472$separator$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$18$$)):$and__5023__auto__$jscomp$779$$};$app$main$ui$ds$controls$numeric_input$first_focusable_id$$=function($options$jscomp$614$$){return $APP.$cljs$core$some$$(function($p1__78553_SHARP_$$){return $APP.$cljs$core$truth_$$($app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$($p1__78553_SHARP_$$))?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78553_SHARP_$$):null},$options$jscomp$614$$)};
$app$main$ui$ds$controls$numeric_input$next_focus_index$$=function($indices$jscomp$1_options$jscomp$615$$,$focused_id$jscomp$2$$,$direction$jscomp$25$$){var $options__$1$jscomp$82$$=$APP.$cljs$core$delay_QMARK_$$($indices$jscomp$1_options$jscomp$615$$)?$APP.$cljs$core$_deref$$($indices$jscomp$1_options$jscomp$615$$):$indices$jscomp$1_options$jscomp$615$$,$len$jscomp$78$$=$APP.$cljs$core$count$$($options__$1$jscomp$82$$),$start_index$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1150$$=$APP.$app$common$data$index_of_pred$$($options__$1$jscomp$82$$,
function($p1__78554_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($focused_id$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78554_SHARP_$$))});return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1150$$)?$or__5025__auto__$jscomp$1150$$:-1}();$indices$jscomp$1_options$jscomp$615$$=function(){var $G__78555__$1$$=$direction$jscomp$25$$ instanceof $APP.$cljs$core$Keyword$$?$direction$jscomp$25$$.$fqn$:null;switch($G__78555__$1$$){case "down":return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($start_index$jscomp$4$$+
1,$len$jscomp$78$$+$start_index$jscomp$4$$);case "up":return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$($start_index$jscomp$4$$-1,$start_index$jscomp$4$$-$len$jscomp$78$$,-1);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78555__$1$$)].join(""));}}();return $APP.$cljs$core$some$$(function($i$jscomp$527_j$jscomp$121$$){$i$jscomp$527_j$jscomp$121$$=$APP.$cljs$core$mod$$($i$jscomp$527_j$jscomp$121$$,$len$jscomp$78$$);return $APP.$cljs$core$truth_$$($app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$82$$,
$i$jscomp$527_j$jscomp$121$$)))?$i$jscomp$527_j$jscomp$121$$:null},$indices$jscomp$1_options$jscomp$615$$)};
$app$main$ui$ds$controls$numeric_input$find_token_by_name$$=function($data$jscomp$479$$,$name$jscomp$454$$){return $APP.$cljs$core$some$$(function($tokens_data$$){return $APP.$cljs$core$some$$(function($p1__78556_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78556_SHARP_$$),$name$jscomp$454$$)?$p1__78556_SHARP_$$:null},$tokens_data$$)},$APP.$cljs$core$vals$$($data$jscomp$479$$))};
$app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$=function($props_78560$$){var $on_change$jscomp$54$$=void 0,$step$jscomp$33$$=void 0,$inner_class$$=void 0,$align$jscomp$3$$=void 0,$min$jscomp$68$$=void 0,$max_length$jscomp$6$$=void 0,$on_change_end$$=void 0,$placeholder$jscomp$5$$=void 0,$applied_token_name$jscomp$1$$=void 0,$disabled$jscomp$15$$=void 0,$ref$jscomp$53$$=void 0,$property$jscomp$83$$=void 0,$default$$jscomp$91$$=void 0,$on_change_start$$=void 0,$on_focus$jscomp$9$$=void 0,
$value$jscomp$817$$=void 0,$name$jscomp$455$$=void 0,$tooltip_placement$jscomp$2$$=void 0,$on_blur$jscomp$17$$=void 0,$icon$jscomp$21$$=void 0,$empty_to_end$jscomp$3$$=void 0,$text_icon$$=void 0,$id$jscomp$961$$=void 0,$class$$jscomp$68$$=void 0,$max$jscomp$81$$=void 0,$on_detach$jscomp$2$$=void 0,$tokens$jscomp$50$$=void 0,$nillable$jscomp$1$$=void 0,$is_selected_on_focus$$=void 0,$props$jscomp$327$$=void 0;({onChange:$on_change$jscomp$54$$,step:$step$jscomp$33$$,innerClass:$inner_class$$,align:$align$jscomp$3$$,
min:$min$jscomp$68$$,maxLength:$max_length$jscomp$6$$,onChangeEnd:$on_change_end$$,placeholder:$placeholder$jscomp$5$$,appliedTokenName:$applied_token_name$jscomp$1$$,disabled:$disabled$jscomp$15$$,ref:$ref$jscomp$53$$,property:$property$jscomp$83$$,"default":$default$$jscomp$91$$,onChangeStart:$on_change_start$$,onFocus:$on_focus$jscomp$9$$,value:$value$jscomp$817$$,name:$name$jscomp$455$$,tooltipPlacement:$tooltip_placement$jscomp$2$$,onBlur:$on_blur$jscomp$17$$,icon:$icon$jscomp$21$$,emptyToEnd:$empty_to_end$jscomp$3$$,
textIcon:$text_icon$$,id:$id$jscomp$961$$,className:$class$$jscomp$68$$,max:$max$jscomp$81$$,onDetach:$on_detach$jscomp$2$$,tokens:$tokens$jscomp$50$$,nillable:$nillable$jscomp$1$$,isSelectedOnFocus:$is_selected_on_focus$$,...$props$jscomp$327$$}=$props_78560$$);var $tokens__$1$jscomp$3$$=$APP.$cljs$core$object_QMARK_$$($tokens$jscomp$50$$)?$APP.$rumext$v2$util$bean$$($tokens$jscomp$50$$):$tokens$jscomp$50$$,$value__$1$jscomp$47$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$applied_token_name$jscomp$1$$)?$APP.$cljs$cst$1616$multiple$$:$value$jscomp$817$$,$token_applied$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$1$$)],function(){return $app$main$ui$ds$controls$numeric_input$find_token_by_name$$($tokens__$1$jscomp$3$$,$applied_token_name$jscomp$1$$)}),$token_has_errors_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($token_applied$$))),
$is_multiple_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$value__$1$jscomp$47$$),$value__$2$jscomp$7$$=$is_multiple_QMARK_$$?null:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$780$$=$nillable$jscomp$1$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$780$$)?$value__$1$jscomp$47$$==null:$and__5023__auto__$jscomp$780$$}())?null:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$47$$,
$default$$jscomp$91$$),$nillable__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($nillable$jscomp$1$$,!1),$disabled__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled$jscomp$15$$,!1),$select_on_focus$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($is_selected_on_focus$$,!0),$default$__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default$$jscomp$91$$),$APP.$rumext$v2$adapt$$($nillable__$1$$)],
function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($default$$jscomp$91$$,$APP.$cljs$core$truth_$$($nillable__$1$$)?null:0)}),$step__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($step$jscomp$33$$)],function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($step$jscomp$33$$,1)}),$min__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min$jscomp$68$$)],
function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($min$jscomp$68$$,-2147483648)}),$max__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max$jscomp$81$$)],function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($max$jscomp$81$$,2147483647)}),$max_length__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_length$jscomp$6$$,255),$empty_to_end__$1$jscomp$2$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($empty_to_end$jscomp$3$$,!1),$internal_id$jscomp$3$$=(0,$APP.$rumext$v2$use_id$$)(),$id__$1$jscomp$20$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$961$$,$internal_id$jscomp$3$$),$listbox_id$jscomp$2$$=(0,$APP.$rumext$v2$use_id$$)(),$align__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$3$$,$APP.$cljs$cst$257$left$$),$is_open_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$is_open$jscomp$9$$=$APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$2$$),$token_applied_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($applied_token_name$jscomp$1$$),$token_applied_name$$=$APP.$cljs$core$_deref$$($token_applied_name_STAR_$$),$is_token_applied_QMARK_$$=$token_applied_name$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$token_applied_name$$),$focused_id_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$focused_id$jscomp$3$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$2$$),$filter_id_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$filter_id$jscomp$10$$=$APP.$cljs$core$_deref$$($filter_id_STAR_$jscomp$1$$),$raw_value_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_value_STAR_$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$token_selection_in_progress_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$wrapper_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$nodes_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$options_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$token_wrapper_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$internal_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ref__$1$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1151$$=$ref$jscomp$53$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1151$$)?$or__5025__auto__$jscomp$1151$$:$internal_ref$$}(),$dirty_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$open_dropdown_ref$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$token_detach_btn_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$drag_state_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)($cljs$cst$5679$idle$$),$drag_start_x_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(0),$drag_start_val_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(0),$dropdown_options$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($filter_id$jscomp$10$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$($tokens__$1$jscomp$3$$,
$filter_id$jscomp$10$$)}),$selected_id_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($applied_token_name$jscomp$1$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$ds$controls$numeric_input$get_option_by_name$$($dropdown_options$jscomp$1$$,$applied_token_name$jscomp$1$$)):null}),$selected_id$jscomp$7$$=$APP.$cljs$core$_deref$$($selected_id_STAR_$jscomp$2$$),$set_option_ref$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$416$$){var $state__$1$jscomp$57_state__$2$jscomp$8$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$),{}),$id__$2$jscomp$1$$=$APP.$app$util$dom$get_data$$($node$jscomp$416$$,"id");$state__$1$jscomp$57_state__$2$jscomp$8$$=$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$57_state__$2$jscomp$8$$,$id__$2$jscomp$1$$,$node$jscomp$416$$);$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$3$$,$state__$1$jscomp$57_state__$2$jscomp$8$$);return function(){var $state__$4$jscomp$3_state__$5$jscomp$3$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$),{}),$id__$3$$=$APP.$app$util$dom$get_data$$($node$jscomp$416$$,"id");$state__$4$jscomp$3_state__$5$jscomp$3$$=$APP.$app$util$object$unset_BANG_$$($state__$4$jscomp$3_state__$5$jscomp$3$$,$id__$3$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$3$$,$state__$4$jscomp$3_state__$5$jscomp$3$$)}}),$update_input$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($new_value$jscomp$24$$){var $temp__5825__auto__$jscomp$370$$=
$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$370$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$370$$,$new_value$jscomp$24$$):null}),$apply_value$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$54$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$2$$),$APP.$rumext$v2$adapt$$($value__$2$jscomp$7$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),
$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$)],function($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$){$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$));var $G__78562_78581_temp__5823__auto__$jscomp$236$$=
$app$main$ui$ds$controls$numeric_input$parse_value$$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);if($APP.$cljs$core$truth_$$($G__78562_78581_temp__5823__auto__$jscomp$236$$))return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78562_78581_temp__5823__auto__$jscomp$236$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$))||
($APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,$G__78562_78581_temp__5823__auto__$jscomp$236$$),$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$54$$)&&($on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$($G__78562_78581_temp__5823__auto__$jscomp$236$$):$on_change$jscomp$54$$($G__78562_78581_temp__5823__auto__$jscomp$236$$))),$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,
$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78562_78581_temp__5823__auto__$jscomp$236$$)),$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78562_78581_temp__5823__auto__$jscomp$236$$),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$):
$update_input$jscomp$2$$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable__$1$$)?$APP.$cljs$core$empty_QMARK_$$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$):$nillable__$1$$))return $APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,null),$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,""),$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,
null),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$(""):$update_input$jscomp$2$$(""),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$54$$)?$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$(null):$on_change$jscomp$54$$(null):null;$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$=$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$);
$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$=$APP.$cljs$core$truth_$$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$)?$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$:$default$__$1$jscomp$1$$;$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,
$G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$);$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null);$G__78562_78581_temp__5823__auto__$jscomp$236$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$);$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78562_78581_temp__5823__auto__$jscomp$236$$):
$update_input$jscomp$2$$($G__78562_78581_temp__5823__auto__$jscomp$236$$);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$54$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value__$2$jscomp$7$$))?$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$):
$on_change$jscomp$54$$($G__78561_fallback_value_or__5025__auto__$jscomp$inline_13536_raw_value$jscomp$1_raw_value__$1$$):null}),$apply_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$54$$),$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$)],function($parsed$jscomp$5_value__$3$$,$G__78563_name__$1$jscomp$18$$){$parsed$jscomp$5_value__$3$$=
$app$main$ui$ds$controls$numeric_input$parse_value$$($parsed$jscomp$5_value__$3$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parsed$jscomp$5_value__$3$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$)))return null;$APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,$parsed$jscomp$5_value__$3$$);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$54$$)?
($G__78563_name__$1$jscomp$18$$=$app$main$ui$ds$controls$numeric_input$get_token_op$$($tokens__$1$jscomp$3$$,$G__78563_name__$1$jscomp$18$$),$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$($G__78563_name__$1$jscomp$18$$):$on_change$jscomp$54$$($G__78563_name__$1$jscomp$18$$)):null}),$store_raw_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$482_text$jscomp$141$$){$event$jscomp$482_text$jscomp$141$$=
(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$482_text$jscomp$141$$);$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$event$jscomp$482_text$jscomp$141$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!0);return $APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,$event$jscomp$482_text$jscomp$141$$)}),$on_token_apply$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_token$$)],function($id__$2$jscomp$2$$,$value__$3$jscomp$1$$,
$name__$1$jscomp$19$$){$APP.$rumext$v2$set_ref_val_BANG_$$($token_selection_in_progress_STAR_$$,!0);$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,$id__$2$jscomp$2$$);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$2$$,null);$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1);$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,$name__$1$jscomp$19$$);$apply_token$$.$cljs$core$IFn$_invoke$arity$2$?$apply_token$$.$cljs$core$IFn$_invoke$arity$2$($value__$3$jscomp$1$$,
$name__$1$jscomp$19$$):$apply_token$$($value__$3$jscomp$1$$,$name__$1$jscomp$19$$);return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($token_selection_in_progress_STAR_$$,!1);return $APP.$cljs$core$truth_$$($token_wrapper_ref$jscomp$1$$)?$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$jscomp$1$$)):null})}),$on_option_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_token_apply$$)],
function($event$jscomp$483_id__$2$jscomp$3$$){$event$jscomp$483_id__$2$jscomp$3$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$483_id__$2$jscomp$3$$),"id");var $options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$)?$APP.$cljs$core$_deref$$($options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$):
$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$;var $name__$1$jscomp$20_option$jscomp$19$$=$APP.$app$main$ui$ds$controls$select$get_option$$($options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$,$event$jscomp$483_id__$2$jscomp$3$$);$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$20_option$jscomp$19$$,$APP.$cljs$cst$4605$resolved_value$$);$name__$1$jscomp$20_option$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$20_option$jscomp$19$$,
$APP.$cljs$cst$725$name$$);$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$483_id__$2$jscomp$3$$,$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$,$name__$1$jscomp$20_option$jscomp$19$$):$on_token_apply$$($event$jscomp$483_id__$2$jscomp$3$$,$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$,$name__$1$jscomp$20_option$jscomp$19$$);return $APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,"")}),$on_option_enter$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_token_apply$$)],function(){var $options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$)?$APP.$cljs$core$_deref$$($options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$):
$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$;var $name__$1$jscomp$21_option$jscomp$20$$=$APP.$app$main$ui$ds$controls$select$get_option$$($options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$,$focused_id$jscomp$3$$);$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$21_option$jscomp$20$$,$APP.$cljs$cst$4605$resolved_value$$);$name__$1$jscomp$21_option$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$21_option$jscomp$20$$,
$APP.$cljs$cst$725$name$$);$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$($focused_id$jscomp$3$$,$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$,$name__$1$jscomp$21_option$jscomp$20$$):$on_token_apply$$($focused_id$jscomp$3$$,$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$,$name__$1$jscomp$21_option$jscomp$20$$);return $APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,"")}),$handle_blur$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),
$APP.$rumext$v2$adapt$$($on_blur$jscomp$17$$)],function($event$jscomp$484$$){$APP.$cljs$core$truth_$$($APP.$app$util$dom$is_child_QMARK_$$($APP.$rumext$v2$ref_val$$($wrapper_ref$jscomp$3$$),$event$jscomp$484$$!=null?$event$jscomp$484$$.relatedTarget:null))||($APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,""),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$2$$,null),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1));if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$jscomp$2$$))){var $G__78564_78584$$=
$APP.$rumext$v2$ref_val$$($raw_value_STAR_$$);$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78564_78584$$):$apply_value$jscomp$2$$($G__78564_78584$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1)}$APP.$cljs$core$fn_QMARK_$$($on_blur$jscomp$17$$)&&($on_blur$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$484$$):$on_blur$jscomp$17$$($event$jscomp$484$$));
return $APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$))}),$commit_pending_on_unmount$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$)],function(){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$jscomp$2$$))){var $G__78565_78585$$=$APP.$rumext$v2$ref_val$$($raw_value_STAR_$$);$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78565_78585$$):
$apply_value$jscomp$2$$($G__78565_78585$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1)}return null}),$handle_unmount$jscomp$1$$=$app$main$ui$hooks$use_ref_callback$$($commit_pending_on_unmount$$),$on_key_down$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$),$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$2$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$),$APP.$rumext$v2$adapt$$($focused_id$jscomp$3$$),
$APP.$rumext$v2$adapt$$($APP.$app$main$ui$ds$controls$select$handle_focus_change$$)],function($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!0);var $name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),$down_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),
$enter_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),$esc_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$),$open_tokens$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$.key,
"{"),$close_tokens$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$.key,"}"),$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=$APP.$cljs$core$delay_QMARK_$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$)?
$APP.$cljs$core$_deref$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$):$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$;if($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$!=null&&$open_tokens$$)return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,
!0);if($close_tokens$$)return $eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=$app$main$ui$ds$controls$numeric_input$clean_token_name$$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=$app$main$ui$ds$controls$numeric_input$get_option_by_name$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,
$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$),$APP.$cljs$core$truth_$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$)?($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$),
$apply_token$$.$cljs$core$IFn$_invoke$arity$2$?$apply_token$$.$cljs$core$IFn$_invoke$arity$2$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$):$apply_token$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$),
$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1),$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,""),$handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):$handle_blur$jscomp$5$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$)):($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$=
$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):$apply_value$jscomp$2$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$)),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1);if($APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$3$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$)){$APP.$app$util$dom$prevent_default$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$);
if($APP.$cljs$core$truth_$$($focused_id$jscomp$3$$))return $on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):$on_option_enter$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$);$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=$app$main$ui$ds$controls$numeric_input$first_focusable_id$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$);
$name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$=$APP.$app$main$ui$ds$controls$select$get_option$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$);$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$,
$APP.$cljs$cst$4605$resolved_value$$);$name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$,$APP.$cljs$cst$725$name$$);$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$($eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$,$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,
$name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$):$on_token_apply$$($eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$,$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$);$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,"")}return $handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):
$handle_blur$jscomp$5$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$)}if($APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$4$$))return $G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$)),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):
$update_input$jscomp$2$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1),$APP.$app$util$dom$blur_BANG_$$($eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$)))return $APP.$app$main$ui$ds$controls$select$handle_focus_change$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,
$focused_id_STAR_$jscomp$2$$,0,$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$));if($APP.$cljs$core$truth_$$($name__$1$jscomp$22_option$jscomp$21_up_QMARK_$jscomp$4$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=$app$main$ui$ds$controls$numeric_input$next_focus_index$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$focused_id$jscomp$3$$,
$APP.$cljs$cst$1954$up$$),$APP.$app$util$dom$prevent_default$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$focused_id_STAR_$jscomp$2$$,$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$,$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$));
var $parsed$jscomp$6$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1153$$=$parsed$jscomp$6$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1153$$)?
$or__5025__auto__$jscomp$1153$$:$default$__$1$jscomp$1$$}();$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$.shiftKey?$step__$1$$*10:$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$.altKey?$step__$1$$*.1:$step__$1$$;$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=
$APP.$app$common$math$clamp$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$+$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$);$APP.$app$util$dom$prevent_default$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$);$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$=
$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$);$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):$update_input$jscomp$2$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$);
$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$=""+($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$??"");return $apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):$apply_value$jscomp$2$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$)}if($APP.$cljs$core$truth_$$($down_QMARK_$jscomp$4$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=
$app$main$ui$ds$controls$numeric_input$next_focus_index$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,$focused_id$jscomp$3$$,$APP.$cljs$cst$1953$down$$),$APP.$app$util$dom$prevent_default$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$,
$focused_id_STAR_$jscomp$2$$,$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$,$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$));$parsed$jscomp$6$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=
function(){var $or__5025__auto__$jscomp$1154$$=$parsed$jscomp$6$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1154$$)?$or__5025__auto__$jscomp$1154$$:$default$__$1$jscomp$1$$}();$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$=$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$.shiftKey?$step__$1$$*10:$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$.altKey?$step__$1$$*
.1:$step__$1$$;$G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$=$APP.$app$common$math$clamp$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$-$eff_step_name_78586__$1_new_index$jscomp$9_node$jscomp$419_option_id$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$);$APP.$app$util$dom$prevent_default$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$);
$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$);$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):
$update_input$jscomp$2$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$);$G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$=""+($G__78566_78588_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_78587_value__$3$jscomp$4$$??"");return $apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$):
$apply_value$jscomp$2$$($G__78568_78590_G__78569_78591_G__78570_78592_G__78571_G__78572_78593_G__78573_event$jscomp$485$$)}return null}),$on_focus__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$9$$),$APP.$rumext$v2$adapt$$($select_on_focus$jscomp$3$$)],function($event$jscomp$486_target$jscomp$147$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5680$dragging$$,$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$)))return null;
$APP.$cljs$core$fn_QMARK_$$($on_focus$jscomp$9$$)&&($on_focus$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$486_target$jscomp$147$$):$on_focus$jscomp$9$$($event$jscomp$486_target$jscomp$147$$));$event$jscomp$486_target$jscomp$147$$=$APP.$app$util$dom$get_target$$($event$jscomp$486_target$jscomp$147$$);return $APP.$cljs$core$truth_$$($select_on_focus$jscomp$3$$)?($APP.$app$util$dom$select_text_BANG_$$($event$jscomp$486_target$jscomp$147$$),
$event$jscomp$486_target$jscomp$147$$.addEventListener("mouseup",$APP.$app$util$dom$prevent_default$$,{once:!0})):null}),$on_mouse_wheel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),$APP.$rumext$v2$adapt$$($app$main$ui$ds$controls$numeric_input$parse_value$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$),
$APP.$rumext$v2$adapt$$($default$__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($step__$1$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$)],function($G__78574_event$jscomp$487$$){var $inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);if($APP.$cljs$core$truth_$$($inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$)&&$APP.$cljs$core$truth_$$($app$util$dom$active_QMARK_$$($inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$))){$inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($app$util$dom$get_delta_position$$($G__78574_event$jscomp$487$$))<0;var $current_value$jscomp$8_parsed$jscomp$7$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$current_value$jscomp$8_parsed$jscomp$7$$=$APP.$cljs$core$truth_$$($current_value$jscomp$8_parsed$jscomp$7$$)?
$current_value$jscomp$8_parsed$jscomp$7$$:$default$__$1$jscomp$1$$;$inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$=$inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$?$APP.$app$common$math$clamp$$($current_value$jscomp$8_parsed$jscomp$7$$+$step__$1$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$):$APP.$app$common$math$clamp$$($current_value$jscomp$8_parsed$jscomp$7$$-$step__$1$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$);$APP.$app$util$dom$prevent_default$$($G__78574_event$jscomp$487$$);
$APP.$app$util$dom$stop_propagation$$($G__78574_event$jscomp$487$$);$G__78574_event$jscomp$487$$=""+($inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$371$$??"");return $apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78574_event$jscomp$487$$):$apply_value$jscomp$2$$($G__78574_event$jscomp$487$$)}return null}),$on_scrub_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled__$1$$),
$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$),$APP.$rumext$v2$adapt$$($is_multiple_QMARK_$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($default$__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function($event$jscomp$488$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($disabled__$1$$)?$disabled__$1$$:$APP.$cljs$core$truth_$$($is_open$jscomp$9$$)?
$is_open$jscomp$9$$:$is_multiple_QMARK_$$||$is_token_applied_QMARK_$$))return null;var $client_x_is_focused_node$jscomp$421$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$),$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$=$client_x_is_focused_node$jscomp$421$$!=null;$client_x_is_focused_node$jscomp$421$$=$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$?$app$util$dom$active_QMARK_$$($client_x_is_focused_node$jscomp$421$$):$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$;
$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$=$APP.$cljs$core$_deref$$($token_applied_name_STAR_$$)!=null;if($APP.$cljs$core$truth_$$($client_x_is_focused_node$jscomp$421$$)?$client_x_is_focused_node$jscomp$421$$:$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$)return null;$client_x_is_focused_node$jscomp$421$$=$event$jscomp$488$$.clientX;$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$=
$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$)?$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$:
$APP.$cljs$core$truth_$$($default$__$1$jscomp$1$$)?$default$__$1$jscomp$1$$:0;$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5681$maybe_dragging$$);$APP.$rumext$v2$set_ref_val_BANG_$$($drag_start_x_STAR_$$,$client_x_is_focused_node$jscomp$421$$);$APP.$rumext$v2$set_ref_val_BANG_$$($drag_start_val_STAR_$$,$and__5023__auto__$jscomp$inline_13538_has_token$jscomp$1_parsed$jscomp$8_start_val$$);return $APP.$app$util$dom$capture_pointer$$($event$jscomp$488$$)}),$on_scrub_pointer_move$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$2$$),$APP.$rumext$v2$adapt$$($step__$1$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_change_start$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function($G__78576_event$jscomp$489_new_val$jscomp$8$$){if($is_token_applied_QMARK_$$)return null;var $G__78575_78594_state$jscomp$1183$$=
$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78575_78594_state$jscomp$1183$$,$cljs$cst$5681$maybe_dragging$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78575_78594_state$jscomp$1183$$,$cljs$cst$5680$dragging$$)){var $delta_x$jscomp$4$$=$G__78576_event$jscomp$489_new_val$jscomp$8$$.clientX-$APP.$rumext$v2$ref_val$$($drag_start_x_STAR_$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78575_78594_state$jscomp$1183$$,
$cljs$cst$5681$maybe_dragging$$)&&Math.abs($delta_x$jscomp$4$$)>=3&&($APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5680$dragging$$),$APP.$cljs$core$fn_QMARK_$$($on_change_start$$)&&($on_change_start$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_start$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_start$$()));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($drag_state_STAR_$$),$cljs$cst$5680$dragging$$))return $G__78576_event$jscomp$489_new_val$jscomp$8$$=
$APP.$app$common$math$clamp$$($APP.$rumext$v2$ref_val$$($drag_start_val_STAR_$$)+Math.round($delta_x$jscomp$4$$/1)*($APP.$cljs$core$truth_$$($G__78576_event$jscomp$489_new_val$jscomp$8$$.shiftKey)?$step__$1$$*10:$APP.$cljs$core$truth_$$($G__78576_event$jscomp$489_new_val$jscomp$8$$.ctrlKey)?$step__$1$$*.1:$step__$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$),$G__78575_78594_state$jscomp$1183$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78576_event$jscomp$489_new_val$jscomp$8$$),
$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78575_78594_state$jscomp$1183$$):$update_input$jscomp$2$$($G__78575_78594_state$jscomp$1183$$),$G__78576_event$jscomp$489_new_val$jscomp$8$$=""+($G__78576_event$jscomp$489_new_val$jscomp$8$$??""),$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78576_event$jscomp$489_new_val$jscomp$8$$):$apply_value$jscomp$2$$($G__78576_event$jscomp$489_new_val$jscomp$8$$)}return null}),
$on_scrub_pointer_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_change_end$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function($event$jscomp$490$$){if($is_token_applied_QMARK_$$)return null;var $state$jscomp$1184$$=$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1184$$,$cljs$cst$5681$maybe_dragging$$)){$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,
$cljs$cst$5679$idle$$);$APP.$app$util$dom$release_pointer$$($event$jscomp$490$$);var $temp__5825__auto___78595$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);$APP.$cljs$core$truth_$$($temp__5825__auto___78595$$)&&$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto___78595$$)}return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1184$$,$cljs$cst$5680$dragging$$)?($APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5679$idle$$),$APP.$app$util$dom$release_pointer$$($event$jscomp$490$$),
$APP.$cljs$core$fn_QMARK_$$($on_change_end$$)?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_end$$():null):null}),$on_scrub_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_end$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function(){if($is_token_applied_QMARK_$$)return null;var $was_dragging$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5680$dragging$$,
$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$));$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5679$idle$$);return $was_dragging$$&&$APP.$cljs$core$fn_QMARK_$$($on_change_end$$)?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_end$$():null}),$open_dropdown$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled__$1$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$)],function($event$jscomp$491$$){if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;
$APP.$app$util$dom$prevent_default$$($event$jscomp$491$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$2$$,$APP.$cljs$core$not$$);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$))}),$open_dropdown_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled__$1$$),$APP.$rumext$v2$adapt$$($token_wrapper_ref$jscomp$1$$)],function($event$jscomp$492$$){if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;
$APP.$app$util$dom$prevent_default$$($event$jscomp$492$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$2$$,$APP.$cljs$core$not$$);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$jscomp$1$$))}),$detach_token$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach$jscomp$2$$),$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($disabled__$1$$),$APP.$rumext$v2$adapt$$($token_applied_name$$)],
function($event$jscomp$493$$){if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$493$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$493$$);$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,null);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$2$$,null);$APP.$cljs$core$truth_$$($on_detach$jscomp$2$$)&&($on_detach$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?
$on_detach$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($token_applied_name$$):$on_detach$jscomp$2$$($token_applied_name$$));return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$))})}),$on_token_key_down$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($detach_token$jscomp$3$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$)],function($event$jscomp$494$$){var $esc_QMARK_$jscomp$5_new_index$jscomp$10$$=
(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$494$$),$delete_QMARK_$$=(0,$APP.$app$util$keyboard$delete_QMARK_$$)($event$jscomp$494$$),$backspace_QMARK_$$=(0,$APP.$app$util$keyboard$backspace_QMARK_$$)($event$jscomp$494$$),$enter_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$494$$),$up_QMARK_$jscomp$5$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$494$$),$down_QMARK_$jscomp$5$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$494$$),
$options$jscomp$619_options__$1$jscomp$86$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$options$jscomp$619_options__$1$jscomp$86$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$619_options__$1$jscomp$86$$)?$APP.$cljs$core$_deref$$($options$jscomp$619_options__$1$jscomp$86$$):$options$jscomp$619_options__$1$jscomp$86$$;var $detach_btn$$=$APP.$rumext$v2$ref_val$$($token_detach_btn_ref$jscomp$1$$),$target$jscomp$148$$=$APP.$app$util$dom$get_target$$($event$jscomp$494$$);if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($delete_QMARK_$$)?$delete_QMARK_$$:$backspace_QMARK_$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$494$$),$detach_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$detach_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$494$$):$detach_token$jscomp$3$$($event$jscomp$494$$),$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$));if($APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$4$$))return $APP.$cljs$core$truth_$$($is_open$jscomp$9$$)?
($APP.$app$util$dom$prevent_default$$($event$jscomp$494$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$494$$),$on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$494$$):$on_option_enter$$($event$jscomp$494$$)):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($target$jscomp$148$$,$detach_btn$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$494$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!0)):null;
if($APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$5_new_index$jscomp$10$$))return $APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$jscomp$1$$));if($APP.$cljs$core$truth_$$($up_QMARK_$jscomp$5$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $esc_QMARK_$jscomp$5_new_index$jscomp$10$$=$app$main$ui$ds$controls$numeric_input$next_focus_index$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id$jscomp$3$$,$APP.$cljs$cst$1954$up$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$494$$),
$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id_STAR_$jscomp$2$$,$esc_QMARK_$jscomp$5_new_index$jscomp$10$$,$nodes_ref$jscomp$3$$)}else if($APP.$cljs$core$truth_$$($down_QMARK_$jscomp$5$$)&&$APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $esc_QMARK_$jscomp$5_new_index$jscomp$10$$=$app$main$ui$ds$controls$numeric_input$next_focus_index$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id$jscomp$3$$,$APP.$cljs$cst$1953$down$$),
$APP.$app$util$dom$prevent_default$$($event$jscomp$494$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id_STAR_$jscomp$2$$,$esc_QMARK_$jscomp$5_new_index$jscomp$10$$,$nodes_ref$jscomp$3$$);return null}),$input_props$$={...$props$jscomp$327$$,onChange:$store_raw_value$$,"aria-label":$property$jscomp$83$$,className:$inner_class$$,placeholder:$is_multiple_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.mixed-values"):
$placeholder$jscomp$5$$,id:$id__$1$jscomp$20$$,maxLength:$max_length__$1$jscomp$1$$,slotStart:$APP.$cljs$core$truth_$$($text_icon$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_numeric_input__text-icon",children:$text_icon$$}):null,onFocus:$on_focus__$1$$,onBlur:$handle_blur$jscomp$5$$,type:"text",ref:$ref__$1$jscomp$2$$,slotEnd:$APP.$cljs$core$truth_$$($disabled__$1$$)?null:$tokens__$1$jscomp$3$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",icon:"tokens",tooltipClass:"main_ui_ds_controls_numeric_input__button-tooltip",className:"main_ui_ds_controls_numeric_input__invisible-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),ref:$open_dropdown_ref$$,tooltipPlacement:$tooltip_placement$jscomp$2$$,onClick:$open_dropdown$jscomp$4$$}):null,defaultValue:function(){var $or__5025__auto__$jscomp$1160$$=$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1160$$)?$or__5025__auto__$jscomp$1160$$:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value__$2$jscomp$7$$)}(),onKeyDown:$on_key_down$jscomp$17$$,disabled:$disabled__$1$$,variant:"comfortable",icon:$icon$jscomp$21$$},$token_props$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($token_applied_name$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$token_applied_name$$):
$token_applied_name$$)?function(){var $token$jscomp$124$$=$app$main$ui$ds$controls$numeric_input$get_option_by_name$$($dropdown_options$jscomp$1$$,$token_applied_name$$),$id__$2$jscomp$4$$=function(){var $G__78577_or__5025__auto__$jscomp$1161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$124$$,$APP.$cljs$cst$266$id$$);if($APP.$cljs$core$truth_$$($G__78577_or__5025__auto__$jscomp$1161$$))return $G__78577_or__5025__auto__$jscomp$1161$$;$G__78577_or__5025__auto__$jscomp$1161$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token_applied$$,$APP.$cljs$cst$266$id$$);return $G__78577_or__5025__auto__$jscomp$1161$$==null?null:""+($G__78577_or__5025__auto__$jscomp$1161$$??"")}(),$label$jscomp$41$$=function(){var $or__5025__auto__$jscomp$1162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$124$$,$APP.$cljs$cst$725$name$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1162$$)?$or__5025__auto__$jscomp$1162$$:$applied_token_name$jscomp$1$$}(),
$token_value$jscomp$6_token_value__$1$$=function(){var $or__5025__auto__$jscomp$1163_or__5025__auto____$1$jscomp$130$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$124$$,$APP.$cljs$cst$4605$resolved_value$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1163_or__5025__auto____$1$jscomp$130$$))return $or__5025__auto__$jscomp$1163_or__5025__auto____$1$jscomp$130$$;$or__5025__auto__$jscomp$1163_or__5025__auto____$1$jscomp$130$$=$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1163_or__5025__auto____$1$jscomp$130$$)?$or__5025__auto__$jscomp$1163_or__5025__auto____$1$jscomp$130$$:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value__$2$jscomp$7$$)}();$token_value$jscomp$6_token_value__$1$$=$id__$2$jscomp$4$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$455$$,$APP.$cljs$cst$1734$opacity$$)?100*$token_value$jscomp$6_token_value__$1$$:$token_value$jscomp$6_token_value__$1$$;
return{...$props$jscomp$327$$,onTokenKeyDown:$on_token_key_down$jscomp$1$$,detachToken:$detach_token$jscomp$3$$,tokenDetachBtnRef:$token_detach_btn_ref$jscomp$1$$,tooltipPlacement:$tooltip_placement$jscomp$2$$,className:$inner_class$$,label:$label$jscomp$41$$,id:$id__$2$jscomp$4$$,value:$token_value$jscomp$6_token_value__$1$$,slotStart:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1164$$=$icon$jscomp$21$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1164$$)?$or__5025__auto__$jscomp$1164$$:
$text_icon$$}())?$APP.$cljs$core$truth_$$($icon$jscomp$21$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$21$$,size:"s",className:"main_ui_ds_controls_numeric_input__icon"}):$APP.$cljs$core$truth_$$($text_icon$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_numeric_input__text-icon",children:$text_icon$$}):null:null,tokenHasErrors:$token_has_errors_QMARK_$$,onFocus:$on_focus__$1$$,property:$property$jscomp$83$$,onBlur:$handle_blur$jscomp$5$$,
onClick:$open_dropdown_token$$,isOpen:$is_open$jscomp$9$$,tokenWrapperRef:$token_wrapper_ref$jscomp$1$$,disabled:$disabled__$1$$}}():null;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value__$2$jscomp$7$$),$APP.$rumext$v2$adapt$$($default$__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$1$$)],function(){var $value_SINGLEQUOTE_$jscomp$2$$=$is_multiple_QMARK_$$?"":$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable__$1$$)?$value__$2$jscomp$7$$==
null:$nillable__$1$$)?"":$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($value__$2$jscomp$7$$,$default$__$1$jscomp$1$$));$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$value_SINGLEQUOTE_$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,$value_SINGLEQUOTE_$jscomp$2$$);if(!$APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($token_selection_in_progress_STAR_$$)))if($APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,
$applied_token_name$jscomp$1$$),$APP.$cljs$core$truth_$$($applied_token_name$jscomp$1$$)){var $temp__5825__auto__$jscomp$372_token_id_78597$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$ds$controls$numeric_input$get_option_by_name$$($dropdown_options$jscomp$1$$,$applied_token_name$jscomp$1$$));$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,$temp__5825__auto__$jscomp$372_token_id_78597$$)}else $APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,null);$temp__5825__auto__$jscomp$372_token_id_78597$$=
$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$372_token_id_78597$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$372_token_id_78597$$,$value_SINGLEQUOTE_$jscomp$2$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$1$$)],function(){if($applied_token_name$jscomp$1$$==null){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($token_selection_in_progress_STAR_$$)))return null;
$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,null)}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_mouse_wheel$jscomp$1$$)],function(){var $temp__5825__auto__$jscomp$373$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$373$$)){var $key$jscomp$413$$=$APP.$goog$events$listen$$($temp__5825__auto__$jscomp$373$$,
"wheel",$on_mouse_wheel$jscomp$1$$,{passive:!1});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$413$$)}}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$1$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($options_ref$jscomp$2$$,$dropdown_options$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_unmount$jscomp$1$$)],function(){return $handle_unmount$jscomp$1$$});
return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$wrapper_ref$jscomp$3$$,onPointerDown:$on_scrub_pointer_down$$,onPointerMove:$on_scrub_pointer_move$$,onPointerUp:$on_scrub_pointer_up$$,onLostPointerCapture:$on_scrub_lost_pointer_capture$$,className:($class$$jscomp$68$$??"")+" main_ui_ds_controls_numeric_input__input-wrapper "+($is_token_applied_QMARK_$$?"":"main_ui_ds_controls_numeric_input__resizable"),children:[$is_token_applied_QMARK_$$?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$ds$controls$utilities$token_field$token_field_STAR_$$,
$token_props$$):(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$utilities$input_field$input_field_STAR_$$,$input_props$$),$is_open$jscomp$9$$?function(){var $options$jscomp$620$$=$APP.$cljs$core$delay_QMARK_$$($dropdown_options$jscomp$1$$)?$APP.$cljs$core$_deref$$($dropdown_options$jscomp$1$$):$dropdown_options$jscomp$1$$;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,{onClick:$on_option_click$jscomp$2$$,id:$listbox_id$jscomp$2$$,
options:$options$jscomp$620$$,selected:$selected_id$jscomp$7$$,focused:$focused_id$jscomp$3$$,align:$align__$1$jscomp$2$$,emptyToEnd:$empty_to_end__$1$jscomp$2$$,ref:$set_option_ref$jscomp$2$$})}():null]})};
$app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$=function($props_78580_tokens__$1$jscomp$4$$){var $attr$jscomp$65$$=void 0,$align$jscomp$4_props__$1$jscomp$78$$=void 0,$placeholder$jscomp$6$$=void 0,$value$jscomp$818$$=void 0,$applied_token$jscomp$5$$=void 0,$input_type$jscomp$2$$=void 0,$class$$jscomp$69$$=void 0,$on_detach$jscomp$3$$=void 0,$props$jscomp$328$$=void 0;({value:$value$jscomp$818$$,attr:$attr$jscomp$65$$,appliedToken:$applied_token$jscomp$5$$,
align:$align$jscomp$4_props__$1$jscomp$78$$,onDetach:$on_detach$jscomp$3$$,placeholder:$placeholder$jscomp$6$$,inputType:$input_type$jscomp$2$$,className:$class$$jscomp$69$$,...$props$jscomp$328$$}=$props_78580_tokens__$1$jscomp$4$$);var $tokens$jscomp$51$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$);$props_78580_tokens__$1$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$51$$),$APP.$rumext$v2$adapt$$($input_type$jscomp$2$$),
$APP.$rumext$v2$adapt$$($attr$jscomp$65$$)],function(){var $or__5025__auto__$jscomp$inline_8892$$=$input_type$jscomp$2$$;return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($tokens$jscomp$51$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8892$$)?$or__5025__auto__$jscomp$inline_8892$$:$attr$jscomp$65$$)});var $on_detach_attr$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach$jscomp$3$$),$APP.$rumext$v2$adapt$$($attr$jscomp$65$$)],
function($p1__78579_SHARP_$$){return $on_detach$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($p1__78579_SHARP_$$,$attr$jscomp$65$$):$on_detach$jscomp$3$$($p1__78579_SHARP_$$,$attr$jscomp$65$$)});$align$jscomp$4_props__$1$jscomp$78$$={...$props$jscomp$328$$,placeholder:function(){var $or__5025__auto__$jscomp$1166$$=$placeholder$jscomp$6$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1166$$)?$or__5025__auto__$jscomp$1166$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$value$jscomp$818$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--"}(),className:($class$$jscomp$69$$??"")+" main_ui_workspace_sidebar_options_menus_input_wrapper_tokens__numeric-input-wrapper",appliedTokenName:$applied_token$jscomp$5$$,tokens:$APP.$cljs$core$delay_QMARK_$$($props_78580_tokens__$1$jscomp$4$$)?$APP.$cljs$core$_deref$$($props_78580_tokens__$1$jscomp$4$$):$props_78580_tokens__$1$jscomp$4$$,align:$align$jscomp$4_props__$1$jscomp$78$$,onDetach:$on_detach_attr$$,
name:$attr$jscomp$65$$,value:$value$jscomp$818$$};return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,$align$jscomp$4_props__$1$jscomp$78$$)};
$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$=function($shape$jscomp$989$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),$APP.$cljs$cst$1647$r2$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1648$r3$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),$APP.$cljs$cst$1649$r4$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$)]))};
$app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$=function($G__78610__$1_type$jscomp$623$$){$G__78610__$1_type$jscomp$623$$=$G__78610__$1_type$jscomp$623$$ instanceof $APP.$cljs$core$Keyword$$?$G__78610__$1_type$jscomp$623$$.$fqn$:null;switch($G__78610__$1_type$jscomp$623$$){case "bool":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "circle":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "frame":return $app$main$ui$workspace$sidebar$options$menus$measures$frame_options$$;
case "group":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "path":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "rect":return $app$main$ui$workspace$sidebar$options$menus$measures$rect_options$$;case "svg-raw":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "text":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78610__$1_type$jscomp$623$$)].join(""));
}};
$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$=function($shape$jscomp$994_shape__$1$jscomp$105$$){var $flip_x$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$994_shape__$1$jscomp$105$$,$APP.$cljs$cst$1879$flip_x$$),$flip_y$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$994_shape__$1$jscomp$105$$,$APP.$cljs$cst$1880$flip_y$$);$shape$jscomp$994_shape__$1$jscomp$105$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($flip_x$jscomp$8$$)?$flip_y$jscomp$8$$:
$flip_x$jscomp$8$$)?$APP.$clojure$set$rename_keys$$($shape$jscomp$994_shape__$1$jscomp$105$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1647$r2$$],null)):$APP.$cljs$core$truth_$$($flip_x$jscomp$8$$)?$APP.$clojure$set$rename_keys$$($shape$jscomp$994_shape__$1$jscomp$105$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1648$r3$$],null)):$APP.$cljs$core$truth_$$($flip_y$jscomp$8$$)?$APP.$clojure$set$rename_keys$$($shape$jscomp$994_shape__$1$jscomp$105$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1648$r3$$,
$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1646$r1$$],null)):$shape$jscomp$994_shape__$1$jscomp$105$$;return $APP.$cljs$core$select_keys$$($shape$jscomp$994_shape__$1$jscomp$105$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$)};
$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$=function($value$jscomp$822$$,$decimals$jscomp$1$$){return typeof $value$jscomp$822$$==="string"?$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$parse_double$$($value$jscomp$822$$),$decimals$jscomp$1$$):typeof $value$jscomp$822$$==="number"?$APP.$cljs$core$parse_double$$($value$jscomp$822$$.toFixed($decimals$jscomp$1$$)):
null};
$app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$=function($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$){function $matches_QMARK_$jscomp$3$$($p$jscomp$256$$){var $and__5023__auto__$jscomp$786$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$256$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$786$$)?$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$256$$)),$lterm$$):
$and__5023__auto__$jscomp$786$$}if($APP.$cuerdas$core$blank_QMARK_$$($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$))return $APP.$app$main$constants$size_presets$$;var $lterm$$=$APP.$cuerdas$core$lower$$($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$);$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$=$APP.$app$main$constants$size_presets$$;for(var $acc$jscomp$160$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$=
$APP.$cljs$core$first$$($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$);if($APP.$cljs$core$truth_$$($G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$)){var $head$jscomp$28$$=$G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$28$$)))$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$=$APP.$cljs$core$rest$$($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$),
$acc$jscomp$160$$=$G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$=function(){var $G__78617$$=$acc$jscomp$160$$;return $APP.$cljs$core$truth_$$($matches_QMARK_$jscomp$3$$($head$jscomp$28$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78617$$,$head$jscomp$28$$):$G__78617$$}();else{$G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$=$APP.$cljs$core$split_with$$($APP.$cljs$cst$290$width$$,$APP.$cljs$core$rest$$($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$));
$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$,0,null);$G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$,1,null);$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($matches_QMARK_$jscomp$3$$,$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$);var $G__78635$$=$APP.$cljs$core$seq$$($G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$160$$,$head$jscomp$28$$),$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$):
$acc$jscomp$160$$;$G__78632_items$jscomp$60_matching_items_remaining$jscomp$2_term$jscomp$10$$=$G__78633_G__78634_tail$jscomp$10_temp__5823__auto__$jscomp$237_vec__78618$$;$acc$jscomp$160$$=$G__78635$$}}else return $acc$jscomp$160$$}};
$app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$=function($applied_tokens$jscomp$7_props_78627$$){var $shapes$jscomp$199$$=$applied_tokens$jscomp$7_props_78627$$.shapes,$ids$jscomp$280$$=$applied_tokens$jscomp$7_props_78627$$.ids,$type$jscomp$624$$=$applied_tokens$jscomp$7_props_78627$$.type,$values$jscomp$80$$=$applied_tokens$jscomp$7_props_78627$$.values;$applied_tokens$jscomp$7_props_78627$$=$applied_tokens$jscomp$7_props_78627$$.appliedTokens;var $token_numeric_inputs$jscomp$1$$=
$app$main$features$use_feature$$("tokens/numeric-input"),$all_types$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$624$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$199$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$624$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_map_type$$,
$shapes$jscomp$199$$):null}),$options$jscomp$621$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$624$$),$APP.$rumext$v2$adapt$$($all_types$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$624$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_mapcat_type_to_options$$,
$all_types$$):$app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$($type$jscomp$624$$)}),$frames$jscomp$28$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$199$$)],function(){var $objects$jscomp$786$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1607$frame_id$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$786$$))),$shapes$jscomp$199$$)}),$disabled_position_QMARK__selection_parents_selection_parents_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$280$$)});$disabled_position_QMARK__selection_parents_selection_parents_ref$$=$APP.$rumext$v2$deref$$($disabled_position_QMARK__selection_parents_selection_parents_ref$$);
var $disabled_width_sizing_QMARK__shape$jscomp$995$$=$APP.$cljs$core$first$$($shapes$jscomp$199$$),$flex_child_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$disabled_position_QMARK__selection_parents_selection_parents_ref$$),$absolute_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_width_sizing_QMARK__shape$jscomp$995$$),$flex_container_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_width_sizing_QMARK__shape$jscomp$995$$),
$flex_auto_width_QMARK_$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_width_sizing_QMARK__shape$jscomp$995$$),$flex_fill_width_QMARK_$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_width_sizing_QMARK__shape$jscomp$995$$),$flex_auto_height_QMARK_$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_width_sizing_QMARK__shape$jscomp$995$$),$flex_fill_height_QMARK_$$=
$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_width_sizing_QMARK__shape$jscomp$995$$);$disabled_position_QMARK__selection_parents_selection_parents_ref$$=$APP.$cljs$core$truth_$$($flex_child_QMARK_$$)?!$absolute_QMARK_$jscomp$1$$:$flex_child_QMARK_$$;$disabled_width_sizing_QMARK__shape$jscomp$995$$=function(){var $and__5023__auto__$jscomp$788$$=$APP.$cljs$core$truth_$$($flex_child_QMARK_$$)?$flex_child_QMARK_$$:$flex_container_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$788$$)?
($flex_auto_width_QMARK_$$||$flex_fill_width_QMARK_$$)&&!$absolute_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$788$$}();var $disabled_height_sizing_QMARK_$$=function(){var $and__5023__auto__$jscomp$789$$=$APP.$cljs$core$truth_$$($flex_child_QMARK_$$)?$flex_child_QMARK_$$:$flex_container_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$789$$)?($flex_auto_height_QMARK_$$||$flex_fill_height_QMARK_$$)&&!$absolute_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$789$$}(),$on_proportion_lock_change_shapes__$1$jscomp$34$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$199$$),$APP.$rumext$v2$adapt$$($frames$jscomp$28$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$translate_to_frame$$,$shapes$jscomp$199$$,$frames$jscomp$28$$)}),$shape__$1$jscomp$106$$=$APP.$cljs$core$first$$($on_proportion_lock_change_shapes__$1$jscomp$34$$),$values__$1$jscomp$4$$=function(){var $G__78628__$2_rect$jscomp$45$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$106$$,
$APP.$cljs$cst$1604$points$$)),$G__78628__$3_val_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$80$$,$APP.$cljs$cst$1510$x$$),$val_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$80$$,$APP.$cljs$cst$1511$y$$),$G__78628__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78628__$3_val_x$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values$jscomp$80$$,$APP.$cljs$cst$1510$x$$,$G__78628__$2_rect$jscomp$45$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78628__$2_rect$jscomp$45$$,$APP.$cljs$cst$1510$x$$)):$values$jscomp$80$$;$G__78628__$2_rect$jscomp$45$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val_y$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78628__$1$$,$APP.$cljs$cst$1511$y$$,$G__78628__$2_rect$jscomp$45$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78628__$2_rect$jscomp$45$$,$APP.$cljs$cst$1511$y$$)):
$G__78628__$1$$;$G__78628__$3_val_x$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78628__$3_val_x$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$cst$3412$ox$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78628__$2_rect$jscomp$45$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$3412$ox$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)):$G__78628__$2_rect$jscomp$45$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val_y$$,
$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$cst$3413$oy$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78628__$3_val_x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$3413$oy$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)):$G__78628__$3_val_x$$}(),$values__$2$jscomp$1$$=function(){var $G__78629__$2_selrect$jscomp$80$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$106$$,$APP.$cljs$cst$1605$selrect$$),
$rotation$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$106$$,$APP.$cljs$cst$1788$rotation$$,0),$G__78629__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$4$$),$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values__$1$jscomp$4$$,$APP.$cljs$cst$290$width$$,$G__78629__$2_selrect$jscomp$80$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78629__$2_selrect$jscomp$80$$,
$APP.$cljs$cst$290$width$$)):$values__$1$jscomp$4$$;$G__78629__$2_selrect$jscomp$80$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$4$$),$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78629__$1$$,$APP.$cljs$cst$1522$height$$,$G__78629__$2_selrect$jscomp$80$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78629__$2_selrect$jscomp$80$$,$APP.$cljs$cst$1522$height$$)):
$G__78629__$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$4$$),$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78629__$2_selrect$jscomp$80$$,$APP.$cljs$cst$1788$rotation$$,$rotation$jscomp$20$$):$G__78629__$2_selrect$jscomp$80$$}(),$proportion_lock$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1808$proportion_lock$$),
$clip_content_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$show_in_viewer_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$preset_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_presets_dropdown_QMARK_$$=$APP.$cljs$core$_deref$$($preset_state_STAR_$$),$preset_search_term_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$preset_search_term$$=$APP.$cljs$core$_deref$$($preset_search_term_STAR_$$),$preset_container_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$toggle_presets$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($preset_state_STAR_$$,$APP.$cljs$core$not$$);return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,"")}),$close_presets$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_presets_dropdown_QMARK_$$)],function(){$APP.$cljs$core$reset_BANG_$$($preset_state_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,
"")}),$on_preset_search_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$823$$){return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,$value$jscomp$823$$)}),$filtered_size_presets$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($preset_search_term$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$($preset_search_term$$)}),$on_preset_selected$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],
function($event$jscomp$495_height$jscomp$166$$){var $width$jscomp$195$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$495_height$jscomp$166$$),"width"));$event$jscomp$495_height$jscomp$166$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$495_height$jscomp$166$$),"height"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$280$$,
$APP.$cljs$cst$290$width$$,$width$jscomp$195$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$280$$,$APP.$cljs$cst$1522$height$$,$event$jscomp$495_height$jscomp$166$$)]));$APP.$cljs$core$reset_BANG_$$($preset_state_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,"")}),$orientation$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$624$$,
$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)>$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)?$APP.$cljs$cst$1809$horiz$$:$cljs$cst$5686$vert$$:null,$on_orientation_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function($JSCompiler_inline_result$jscomp$1684_orientation__$1_param72161$jscomp$inline_8895$$){var $JSCompiler_temp_const$jscomp$1682$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;$JSCompiler_inline_result$jscomp$1684_orientation__$1_param72161$jscomp$inline_8895$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1684_orientation__$1_param72161$jscomp$inline_8895$$);$JSCompiler_inline_result$jscomp$1684_orientation__$1_param72161$jscomp$inline_8895$$=$app$main$data$workspace$transforms$change_orientation$$($ids$jscomp$280$$,$JSCompiler_inline_result$jscomp$1684_orientation__$1_param72161$jscomp$inline_8895$$);
return $JSCompiler_temp_const$jscomp$1682$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1684_orientation__$1_param72161$jscomp$inline_8895$$)}),$on_size_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$),$APP.$rumext$v2$adapt$$($on_proportion_lock_change_shapes__$1$jscomp$34$$)],function($value$jscomp$824$$,$attr$jscomp$69$$){return typeof $value$jscomp$824$$==="string"||typeof $value$jscomp$824$$==="number"?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$280$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$280$$,$attr$jscomp$69$$,$value$jscomp$824$$)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$280$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$824$$),$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$69$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$280$$],null))]))});$on_proportion_lock_change_shapes__$1$jscomp$34$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$),
$APP.$rumext$v2$adapt$$($proportion_lock$jscomp$1$$)],function(){var $new_lock$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($proportion_lock$jscomp$1$$,$APP.$cljs$cst$1616$multiple$$)?!0:$APP.$cljs$core$not$$($proportion_lock$jscomp$1$$);return $APP.$cljs$core$run_BANG_$$(function($p1__78621_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_shape_proportion_lock$$($p1__78621_SHARP_$$,$new_lock$$))},$ids$jscomp$280$$)});var $on_position_change$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function($value$jscomp$825$$,$attr$jscomp$70$$){return typeof $value$jscomp$825$$==="string"||typeof $value$jscomp$825$$==="number"?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$280$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_positions$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$280$$,
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$attr$jscomp$70$$,$value$jscomp$825$$])))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$280$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$825$$),
$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$70$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$280$$],null))]))}),$on_rotation_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function($value$jscomp$826_value__$1$jscomp$48$$){return typeof $value$jscomp$826_value__$1$jscomp$48$$==="string"||typeof $value$jscomp$826_value__$1$jscomp$48$$==="number"?($value$jscomp$826_value__$1$jscomp$48$$=
$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$826_value__$1$jscomp$48$$,2),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$280$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$280$$,$value$jscomp$826_value__$1$jscomp$48$$))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$280$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$826_value__$1$jscomp$48$$),$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1788$rotation$$,null],null),null),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$280$$],null))]))}),$on_width_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$$)],function($p1__78622_SHARP_$$){return $on_size_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78622_SHARP_$$,$APP.$cljs$cst$290$width$$):$on_size_change$$($p1__78622_SHARP_$$,
$APP.$cljs$cst$290$width$$)}),$on_height_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$$)],function($p1__78623_SHARP_$$){return $on_size_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78623_SHARP_$$,$APP.$cljs$cst$1522$height$$):$on_size_change$$($p1__78623_SHARP_$$,$APP.$cljs$cst$1522$height$$)}),$on_pos_x_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_position_change$$)],
function($p1__78624_SHARP_$$){return $on_position_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_position_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78624_SHARP_$$,$APP.$cljs$cst$1510$x$$):$on_position_change$$($p1__78624_SHARP_$$,$APP.$cljs$cst$1510$x$$)}),$on_pos_y_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_position_change$$)],function($p1__78625_SHARP_$$){return $on_position_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_position_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78625_SHARP_$$,
$APP.$cljs$cst$1511$y$$):$on_position_change$$($p1__78625_SHARP_$$,$APP.$cljs$cst$1511$y$$)}),$on_detach_token$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function($token_name$jscomp$19$$,$attr$jscomp$71$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$19$$,
$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$71$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$280$$],null)))}),$on_change_clip_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function($event$jscomp$496$$){var $value$jscomp$827$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$496$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$280$$,
function($shape__$2$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$2$jscomp$10$$,$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$core$not$$($value$jscomp$827$$))}))}),$on_change_show_in_viewer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$280$$)],function($event$jscomp$497_undo_id$jscomp$107$$){var $value$jscomp$828$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$497_undo_id$jscomp$107$$));
$event$jscomp$497_undo_id$jscomp$107$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($event$jscomp$497_undo_id$jscomp$107$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$280$$,function($shape__$2$jscomp$11$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$2$jscomp$11$$,
$APP.$cljs$cst$1875$hide_in_viewer$$,$APP.$cljs$core$not$$($value$jscomp$828$$))})]));$APP.$cljs$core$truth_$$($value$jscomp$828$$)||$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78626_SHARP_$$){return $app$main$data$workspace$interactions$remove_all_interactions_nav_to$$($p1__78626_SHARP_$$)},$ids$jscomp$280$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($event$jscomp$497_undo_id$jscomp$107$$))}),
$handle_fit_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$selected_fit_content$$())});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"shape-measures-section",className:"main_ui_workspace_sidebar_options_menus_measures__element-set",children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$790$$=$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?
$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5685$presets$$):$options$jscomp$621$$($cljs$cst$5685$presets$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$790$$)?$all_types$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($all_types$$),1):$and__5023__auto__$jscomp$790$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__presets",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$preset_container_ref$$,
onClick:$toggle_presets$$,className:"main_ui_workspace_sidebar_options_menus_measures__presets-wrapper "+($APP.$cljs$core$truth_$$($show_presets_dropdown_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_measures__opened":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__select-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size-presets")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__collapsed-icon",
children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_presets_dropdown_QMARK_$$,"on-close":$close_presets$$,container:$preset_container_ref$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_workspace_sidebar_options_menus_measures__custom-select-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-search",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_preset_search_change$$,value:$preset_search_term$$,autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.search-size-preset")})}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-list",children:$APP.$cljs$core$empty_QMARK_$$($filtered_size_presets$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_menus_measures__dropdown-element main_ui_workspace_sidebar_options_menus_measures__disabled",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.no-size-preset-results")})}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$159$$,$JSCompiler_temp$jscomp$1813_size_preset$$){var $JSCompiler_temp_const$jscomp$1811$$=$out_arr__44124__auto__$jscomp$159$$.push;if($APP.$cljs$core$not$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)))$JSCompiler_temp$jscomp$1813_size_preset$$=
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_menus_measures__dropdown-element main_ui_workspace_sidebar_options_menus_measures__disabled",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)})},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$));
else{var $preset_match$jscomp$inline_8897$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$),$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$),0))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$),
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$),0));$JSCompiler_temp$jscomp$1813_size_preset$$=(0,$APP.$rumext$v2$jsxs$$)("li",{"data-width":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)),"data-height":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)),
onClick:$on_preset_selected$$,className:"main_ui_workspace_sidebar_options_menus_measures__dropdown-element "+($preset_match$jscomp$inline_8897$$?"main_ui_workspace_sidebar_options_menus_measures__match":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)}),
(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-size",children:[$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)," x ",$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$)]})]}),$preset_match$jscomp$inline_8897$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__check-icon",children:$APP.$app$main$ui$icons$tick$$}):
null]},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1813_size_preset$$))}$JSCompiler_temp_const$jscomp$1811$$.call($out_arr__44124__auto__$jscomp$159$$,$JSCompiler_temp$jscomp$1813_size_preset$$);return $out_arr__44124__auto__$jscomp$159$$},[],$filtered_size_presets$$)})]})})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:function(){var $or__5025__auto__$jscomp$1169$$=$APP.$app$common$data$name$$($orientation$jscomp$7$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1169$$)?$or__5025__auto__$jscomp$1169$$:""}(),"on-change":$on_orientation_change$$,name:"frame-orientation",wide:!0,"class":"main_ui_workspace_sidebar_options_menus_measures__radio-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-vertical",value:"vert",id:"size-vertical"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-horizontal",value:"horiz",
id:"size-horizontal"})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fit-content"),onPointerDown:$handle_fit_content$$,icon:"fit-content"})]}):null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$874$size$$):$options$jscomp$621$$($APP.$cljs$cst$874$size$$))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__size",children:[$token_numeric_inputs$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:.01,onChange:$on_width_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,
$APP.$cljs$cst$290$width$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$290$width$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$290$width$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$290$width$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,
$APP.$cljs$cst$290$width$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.width"),disabled:$disabled_width_sizing_QMARK__shape$jscomp$995$$,icon:"character-w"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:.01,align:$APP.$cljs$cst$258$right$$,onChange:$on_height_change$$,attr:$APP.$cljs$cst$1522$height$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,
$APP.$cljs$cst$1522$height$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1522$height$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.height"),disabled:$disabled_height_sizing_QMARK_$$,icon:"character-h"})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.width"),
className:"main_ui_workspace_sidebar_options_menus_measures__width "+($APP.$cljs$core$truth_$$($disabled_width_sizing_QMARK__shape$jscomp$995$$)?"main_ui_workspace_sidebar_options_menus_measures__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_width_change$$,disabled:$disabled_width_sizing_QMARK__shape$jscomp$995$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.height"),
className:"main_ui_workspace_sidebar_options_menus_measures__height "+($APP.$cljs$core$truth_$$($disabled_height_sizing_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_measures__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_height_change$$,disabled:$disabled_height_sizing_QMARK_$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",tooltipPlacement:"top-left",icon:$APP.$cljs$core$truth_$$($proportion_lock$jscomp$1$$)?"lock":"unlock",className:$proportion_lock$jscomp$1$$===!0?"main_ui_workspace_sidebar_options_menus_measures__selected":"",disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($proportion_lock$jscomp$1$$,$APP.$cljs$cst$1616$multiple$$),"aria-label":$APP.$cljs$core$truth_$$($proportion_lock$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size.unlock"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size.lock"),onClick:$on_proportion_lock_change_shapes__$1$jscomp$34$$})]}):null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1676$position$$):$options$jscomp$621$$($APP.$cljs$cst$1676$position$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__position",children:$token_numeric_inputs$jscomp$1$$?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{onChange:$on_pos_x_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$1510$x$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1510$x$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1510$x$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$1510$x$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1510$x$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.x"),
disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,icon:"character-x"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{align:$APP.$cljs$cst$258$right$$,onChange:$on_pos_y_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$1511$y$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1511$y$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1511$y$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$1511$y$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1511$y$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.y"),
disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,icon:"character-y"})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.x"),className:"main_ui_workspace_sidebar_options_menus_measures__x-position "+($APP.$cljs$core$truth_$$($disabled_position_QMARK__selection_parents_selection_parents_ref$$)?"main_ui_workspace_sidebar_options_menus_measures__disabled":
""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"X"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_pos_x_change$$,
disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.y"),className:"main_ui_workspace_sidebar_options_menus_measures__y-position "+($APP.$cljs$core$truth_$$($disabled_position_QMARK__selection_parents_selection_parents_ref$$)?
"main_ui_workspace_sidebar_options_menus_measures__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"Y"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,onChange:$on_pos_y_change$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]})]})}):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1170$$=$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1788$rotation$$):$options$jscomp$621$$($APP.$cljs$cst$1788$rotation$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1170$$)?$or__5025__auto__$jscomp$1170$$:$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2820$radius$$):$options$jscomp$621$$($APP.$cljs$cst$2820$radius$$)}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__rotation-radius",children:[$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1788$rotation$$):
$options$jscomp$621$$($APP.$cljs$cst$1788$rotation$$))?$token_numeric_inputs$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:-359,onChange:$on_rotation_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$1788$rotation$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1788$rotation$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",max:359,attr:$APP.$cljs$cst$1788$rotation$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_78627$$,$APP.$cljs$cst$1788$rotation$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1788$rotation$$),onDetach:$on_detach_token$jscomp$3$$,
property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.rotation"),icon:"rotation"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.rotation"),className:"main_ui_workspace_sidebar_options_menus_measures__rotation",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon",children:$APP.$app$main$ui$icons$rotation$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:-359,max:359,"data-wrap":!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_rotation_change$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]}):
null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2820$radius$$):$options$jscomp$621$$($APP.$cljs$cst$2820$radius$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$border_radius$border_radius_menu_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_measures__border-radius",ids:$ids$jscomp$280$$,values:$values__$2$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$7_props_78627$$}):
null]}):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1171$$=$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5684$clip_content$$):$options$jscomp$621$$($cljs$cst$5684$clip_content$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1171$$)?$or__5025__auto__$jscomp$1171$$:$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5683$show_in_viewer$$):
$options$jscomp$621$$($cljs$cst$5683$show_in_viewer$$)}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__clip-show",children:[$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5684$clip_content$$):$options$jscomp$621$$($cljs$cst$5684$clip_content$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__clip-content",
children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"clip-content",ref:$clip_content_ref$$,checked:$APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)),onChange:$on_change_clip_content$$,className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-input"}),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"clip-content",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.clip-content"),className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-label "+
($APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?"main_ui_workspace_sidebar_options_menus_measures__selected":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"clip-content"})})]}):null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5683$show_in_viewer$$):$options$jscomp$621$$($cljs$cst$5683$show_in_viewer$$))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__show-in-viewer",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"show-in-viewer",ref:$show_in_viewer_ref$$,checked:$APP.$cljs$core$not$$($APP.$cljs$cst$1875$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)),onChange:$on_change_show_in_viewer$$,className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-input"}),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"show-in-viewer",
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.show-in-viewer"),className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-label "+($APP.$cljs$core$not$$($APP.$cljs$cst$1875$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?"main_ui_workspace_sidebar_options_menus_measures__selected":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"play"})})]}):null]}):null]})};
$app$main$ui$workspace$sidebar$options$drawing$frame$options_STAR_$$=function($props_78636_show_QMARK_$jscomp$5$$){var $drawing_state$jscomp$1$$=$props_78636_show_QMARK_$jscomp$5$$.drawingState,$show_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$props_78636_show_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($show_STAR_$$);var $selected_preset_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected_preset_name$$=$APP.$cljs$core$_deref$$($selected_preset_name_STAR_$$),
$search_term_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$search_term$jscomp$5$$=$APP.$cljs$core$_deref$$($search_term_STAR_$jscomp$2$$),$container_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_toggle$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_STAR_$$,$APP.$cljs$core$not$$);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,"")}),$on_close$jscomp$30$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($show_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,"")}),$on_search_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$829$$){return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,$value$jscomp$829$$)}),$filtered_presets$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($search_term$jscomp$5$$)],
function(){return $app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$($search_term$jscomp$5$$)}),$on_preset_selected$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$498_name$jscomp$456$$){var $height$jscomp$167_target$jscomp$149$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$498_name$jscomp$456$$);$event$jscomp$498_name$jscomp$456$$=$APP.$app$util$dom$get_data$$($height$jscomp$167_target$jscomp$149$$,"name");var $width$jscomp$196$$=
$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($height$jscomp$167_target$jscomp$149$$,"width"));$height$jscomp$167_target$jscomp$149$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($height$jscomp$167_target$jscomp$149$$,"height"));$APP.$cljs$core$reset_BANG_$$($selected_preset_name_STAR_$$,$event$jscomp$498_name$jscomp$456$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$drawing$set_default_size$$($width$jscomp$196$$,
$height$jscomp$167_target$jscomp$149$$));$APP.$cljs$core$reset_BANG_$$($show_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,"")}),$orientation$jscomp$8$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$))?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$)>$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$)?$APP.$cljs$cst$1909$horizontal$$:
$APP.$cljs$cst$1910$vertical$$:null,$on_orientation_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($orientation__$1$jscomp$1_orientation__$2$$){$orientation__$1$jscomp$1_orientation__$2$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($orientation__$1$jscomp$1_orientation__$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$drawing$change_orientation$$($orientation__$1$jscomp$1_orientation__$2$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_drawing_frame__presets",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$container_ref$jscomp$2$$,onClick:$on_toggle$$,className:"main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper "+($APP.$cljs$core$truth_$$($props_78636_show_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_options_drawing_frame__opened":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__select-name",
children:$APP.$cljs$core$truth_$$($selected_preset_name$$)?$selected_preset_name$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size-presets")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$props_78636_show_QMARK_$jscomp$5$$,"on-close":$on_close$jscomp$30$$,container:$container_ref$jscomp$2$$,
children:(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_workspace_sidebar_options_drawing_frame__custom-select-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-search",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_search_change$jscomp$2$$,value:$search_term$jscomp$5$$,autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.search-size-preset")})}),
(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-list",children:$APP.$cljs$core$empty_QMARK_$$($filtered_presets$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_drawing_frame__dropdown-element main_ui_workspace_sidebar_options_drawing_frame__disabled",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.no-size-preset-results")})}):
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$160$$,$JSCompiler_temp$jscomp$1816_preset$$){var $JSCompiler_temp_const$jscomp$1814$$=$out_arr__44124__auto__$jscomp$160$$.push;if($APP.$cljs$core$not$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$)))$JSCompiler_temp$jscomp$1816_preset$$=(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_drawing_frame__dropdown-element main_ui_workspace_sidebar_options_drawing_frame__disabled",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$)})},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$));else{var $preset_match$jscomp$inline_8899$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$));$JSCompiler_temp$jscomp$1816_preset$$=(0,$APP.$rumext$v2$jsxs$$)("li",{"data-width":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$)),
"data-height":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$)),"data-name":$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$),onClick:$on_preset_selected$jscomp$1$$,className:"main_ui_workspace_sidebar_options_drawing_frame__dropdown-element "+($preset_match$jscomp$inline_8899$$?"main_ui_workspace_sidebar_options_drawing_frame__match":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_drawing_frame__name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$)}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-size",children:[$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$),
" x ",$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$)]})]}),$preset_match$jscomp$inline_8899$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__check-icon",children:$APP.$app$main$ui$icons$tick$$}):null]},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1816_preset$$))}$JSCompiler_temp_const$jscomp$1814$$.call($out_arr__44124__auto__$jscomp$160$$,$JSCompiler_temp$jscomp$1816_preset$$);
return $out_arr__44124__auto__$jscomp$160$$},[],$filtered_presets$$)})]})})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:function(){var $or__5025__auto__$jscomp$1173$$=$APP.$app$common$data$name$$($orientation$jscomp$8$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1173$$)?$or__5025__auto__$jscomp$1173$$:""}(),"on-change":$on_orientation_change$jscomp$1$$,name:"frame-orientation",wide:!0,"class":"main_ui_workspace_sidebar_options_drawing_frame__radio-buttons",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-vertical",value:"vertical",id:"size-vertical"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-horizontal",value:"horizontal",id:"size-horizontal"})]})]})};
$app$main$ui$workspace$sidebar$options$menus$align$align_options_STAR_$$=function($disabled_align_props_78641$$){var $disabled_distribute_shapes$jscomp$200$$=$disabled_align_props_78641$$.shapes;$disabled_align_props_78641$$=!$APP.$app$main$data$workspace$can_align_QMARK_$$($disabled_distribute_shapes$jscomp$200$$,$disabled_align_props_78641$$.objects);$disabled_distribute_shapes$jscomp$200$$=!$APP.$app$main$data$workspace$can_distribute_QMARK_$$($disabled_distribute_shapes$jscomp$200$$);var $align_objects$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$499_value$jscomp$830$$){$event$jscomp$499_value$jscomp$830$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$499_value$jscomp$830$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$499_value$jscomp$830$$,
null))}),$distribute_objects$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$500_value$jscomp$831$$){$event$jscomp$500_value$jscomp$831$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$500_value$jscomp$831$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$500_value$jscomp$831$$,
null))});return $disabled_align_props_78641$$&&$disabled_distribute_shapes$jscomp$200$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_align__align-options",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_align__align-group-horizontal",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_78641$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hleft",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4814$align_left$$)])),"data-value":"hleft",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_78641$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_left$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_78641$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hcenter",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4865$align_hcenter$$)])),"data-value":"hcenter",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_78641$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_horizontal_center$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_78641$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hright",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4864$align_right$$)])),"data-value":"hright",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_78641$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_right$$}),
(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_distribute_shapes$jscomp$200$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hdistribute",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4810$h_distribute$$)])),"data-value":"horizontal",onClick:$distribute_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_distribute_shapes$jscomp$200$$?
"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$distribute_horizontally$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_align__align-group-vertical",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_78641$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vtop",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4875$align_top$$)])),
"data-value":"vtop",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_78641$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_top$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_78641$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vcenter",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4882$align_vcenter$$)])),
"data-value":"vcenter",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_78641$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_vertical_center$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_78641$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vbottom",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4878$align_bottom$$)])),
"data-value":"vbottom",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_78641$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_bottom$$}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vdistribute",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4818$v_distribute$$)])),
disabled:$disabled_distribute_shapes$jscomp$200$$,"data-value":"vertical",onClick:$distribute_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_distribute_shapes$jscomp$200$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$distribute_vertical_spacing$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$bool$bool_options_STAR_$$=function($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$){var $disabled_bool_btns_shapes_with_children$$=$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$.shapesWithChildren,$total_selected$$=$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$.totalSelected;$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$=
$APP.$cljs$core$first$$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$.shapes);var $head_id$$=$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$,$APP.$cljs$cst$266$id$$),$is_group_QMARK_$jscomp$3$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$),
$is_bool_QMARK_$jscomp$2$$=$APP.$app$common$files$helpers$bool_shape_QMARK_$$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$),$head_bool_type$$=$is_bool_QMARK_$jscomp$2$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$,$APP.$cljs$cst$1888$bool_type$$):$is_bool_QMARK_$jscomp$2$$;$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$=$app$main$features$use_feature$$("render-wasm/v1");
var $has_invalid_shapes_QMARK_$$=$APP.$cljs$core$some$$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$?$APP.$app$common$files$helpers$frame_shape_QMARK_$$:function($p1__78642_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__78642_SHARP_$$)||$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__78642_SHARP_$$)},$disabled_bool_btns_shapes_with_children$$),$head_not_group_like_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$total_selected$$)&&!$is_group_QMARK_$jscomp$3$$&&!$is_bool_QMARK_$jscomp$2$$;$disabled_bool_btns_shapes_with_children$$=function(){var $or__5025__auto__$jscomp$1174$$=$total_selected$$===0;return $or__5025__auto__$jscomp$1174$$?$or__5025__auto__$jscomp$1174$$:$APP.$cljs$core$truth_$$($has_invalid_shapes_QMARK_$$)?$has_invalid_shapes_QMARK_$$:$head_not_group_like_QMARK_$$}();$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$=
function(){var $or__5025__auto__$jscomp$1175$$=$total_selected$$===0;return $or__5025__auto__$jscomp$1175$$?$or__5025__auto__$jscomp$1175$$:$has_invalid_shapes_QMARK_$$}();var $on_change$jscomp$55$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($total_selected$$),$APP.$rumext$v2$adapt$$($is_group_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($is_bool_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($head_id$$),$APP.$rumext$v2$adapt$$($head_bool_type$$)],function($bool_type$jscomp$10_bool_type__$1$$){$bool_type$jscomp$10_bool_type__$1$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$10_bool_type__$1$$);return $total_selected$$>1?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$bool$create_bool$$($bool_type$jscomp$10_bool_type__$1$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total_selected$$,1)&&$is_group_QMARK_$jscomp$3$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$bool$group_to_bool$$($head_id$$,
$bool_type$jscomp$10_bool_type__$1$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total_selected$$,1)&&$is_bool_QMARK_$jscomp$2$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($head_bool_type$$,$bool_type$jscomp$10_bool_type__$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$bool$bool_to_group$$($head_id$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$bool$change_bool_type$$($head_id$$,
$bool_type$jscomp$10_bool_type__$1$$)):null}),$flatten_objects$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});return $APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($disabled_bool_btns_shapes_with_children$$)?$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$:
$disabled_bool_btns_shapes_with_children$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_bool__boolean-options",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_bool__bool-group",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($head_bool_type$$),"class":"main_ui_workspace_sidebar_options_menus_bool__boolean-radio-btn","on-change":$on_change$jscomp$55$$,
name:"bool-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-union",value:"union",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.union"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4830$bool_union$$)),")"].join(""),
id:"bool-opt-union"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-difference",value:"difference",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.difference"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4832$bool_difference$$)),
")"].join(""),id:"bool-opt-differente"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-intersection",value:"intersection",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.intersection"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4795$bool_intersection$$)),
")"].join(""),id:"bool-opt-intersection"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-exclude",value:"exclude",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.exclude"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4851$bool_exclude$$)),
")"].join(""),id:"bool-opt-exclude"})]})}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flatten"),disabled:$disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$,onClick:$flatten_objects$$,className:"main_ui_workspace_sidebar_options_menus_bool__flatten-button "+($APP.$cljs$core$truth_$$($disabled_flatten_head$jscomp$29_props_78643_render_wasm_enabled_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_options_menus_bool__disabled":
""),children:$app$main$ui$workspace$sidebar$options$menus$bool$flatten_icon$$})]}):null};
$app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$=function($props_78644_title$jscomp$36$$){var $max_length$jscomp$7_props__$1$jscomp$79$$=void 0,$meta$jscomp$88$$=void 0,$value$jscomp$832$$=void 0,$on_blur$jscomp$18$$=void 0,$editing_QMARK_$jscomp$8_is_editing$jscomp$1$$=void 0,$props$jscomp$330$$=void 0;({value:$value$jscomp$832$$,meta:$meta$jscomp$88$$,maxLength:$max_length$jscomp$7_props__$1$jscomp$79$$,isEditing:$editing_QMARK_$jscomp$8_is_editing$jscomp$1$$,onBlur:$on_blur$jscomp$18$$,
...$props$jscomp$330$$}=$props_78644_title$jscomp$36$$);$props_78644_title$jscomp$36$$=$APP.$cljs$core$truth_$$($meta$jscomp$88$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$832$$),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($meta$jscomp$88$$)].join(""):$value$jscomp$832$$;var $editing_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($editing_QMARK_$jscomp$8_is_editing$jscomp$1$$,
!1));$editing_QMARK_$jscomp$8_is_editing$jscomp$1$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$3$$);var $input_ref$jscomp$11$$=(0,$APP.$rumext$v2$use_ref$$)(),$last_node_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ref_cb$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$424$$){$APP.$rumext$v2$set_ref_val_BANG_$$($input_ref$jscomp$11$$,$node$jscomp$424$$);return $APP.$cljs$core$truth_$$($node$jscomp$424$$)?$APP.$rumext$v2$set_ref_val_BANG_$$($last_node_STAR_$$,
$node$jscomp$424$$):null}),$on_edit$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$501$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$501$$);$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$3$$,!0);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$11$$))}),$on_stop_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_blur$jscomp$18$$)],function($event$jscomp$502$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$502$$);
$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$3$$,!1);return $APP.$cljs$core$truth_$$($on_blur$jscomp$18$$)?$on_blur$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$502$$):$on_blur$jscomp$18$$($event$jscomp$502$$):null}),$on_focus$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$503$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$503$$);return $APP.$app$util$dom$select_text_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$503$$))}),
$handle_key_down$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$504_node$jscomp$425$$){var $enter_QMARK_$jscomp$5$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$504_node$jscomp$425$$),$esc_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$504_node$jscomp$425$$);$event$jscomp$504_node$jscomp$425$$=$APP.$app$util$dom$get_target$$($event$jscomp$504_node$jscomp$425$$);$enter_QMARK_$jscomp$5$$&&$APP.$app$util$dom$blur_BANG_$$($event$jscomp$504_node$jscomp$425$$);
return $esc_QMARK_$jscomp$6$$?$APP.$app$util$dom$blur_BANG_$$($event$jscomp$504_node$jscomp$425$$):null});$max_length$jscomp$7_props__$1$jscomp$79$$={...$props$jscomp$330$$,ref:$ref_cb$$,defaultValue:$value$jscomp$832$$,maxLength:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_length$jscomp$7_props__$1$jscomp$79$$,255),autoFocus:!0,onFocus:$on_focus$jscomp$10$$,onBlur:$on_stop_edit$jscomp$1$$,onKeyDown:$handle_key_down$jscomp$8$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_blur$jscomp$18$$),
$APP.$rumext$v2$adapt$$($last_node_STAR_$$)],function(){return function(){var $input$jscomp$72$$=$APP.$rumext$v2$ref_val$$($last_node_STAR_$$),$fake_blur_event$$={type:"blur",target:$input$jscomp$72$$,currentTarget:$input$jscomp$72$$,stopPropagation:function(){return null},preventDefault:function(){return null}};return $APP.$cljs$core$truth_$$($input$jscomp$72$$)?$on_blur$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($fake_blur_event$$):$on_blur$jscomp$18$$($fake_blur_event$$):
null}});return $APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_is_editing$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_input_with_meta__input-with-meta-edit-container",children:(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$max_length$jscomp$7_props__$1$jscomp$79$$)}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$props_78644_title$jscomp$36$$,onClick:$on_edit$jscomp$6$$,className:"main_ui_ds_product_input_with_meta__input-with-meta-container",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_product_input_with_meta__input-with-meta-value",children:$value$jscomp$832$$}),$APP.$cljs$core$truth_$$($meta$jscomp$88$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_product_input_with_meta__input-with-meta-data",children:$meta$jscomp$88$$}):null]})};
$app$main$ui$workspace$sidebar$options$menus$variants_help_modal$variants_help_modal$$=function(){var $on_close$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),$close_dialog_outside$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$505$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_target$$($event$jscomp$505$$),$APP.$app$util$dom$get_current_target$$($event$jscomp$505$$))?
$APP.$app$main$data$modal$hide_BANG_$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$close_dialog_outside$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$on_close$jscomp$31$$,className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn",
icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__help-text",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.intro")}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-list",children:[(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"text-mixed",size:"m","aria-hidden":!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-large",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule1")})})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"img",size:"m","aria-hidden":!0})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-large",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule2")}),
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule2.detail")]})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"folder",size:"m","aria-hidden":!0})}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text",typography:"body-large",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule3")}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule3.detail")]})]})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.outro")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__help-image",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/help-variant-connection.png",alt:""})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__button-row",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-accept-btn",onClick:$on_close$jscomp$31$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-ok")})})]})})};
$app$main$ui$workspace$sidebar$options$menus$component$component_annotation_STAR_$$=function($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$){var $component$jscomp$130_shape_id$jscomp$159$$=$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$.component,$rerender_fn$jscomp$4$$=$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$.rerenderFn,$id$jscomp$962_on_toggle_expand$$=$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$.id;$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$=
$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$.shape;var $main_instance_QMARK_$jscomp$4$$=$APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$),$component_id$jscomp$95$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$),$annotation$jscomp$6$$=$APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$130_shape_id$jscomp$159$$);
$component$jscomp$130_shape_id$jscomp$159$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$);var $editing_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$4$$);var $invalid_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cuerdas$core$blank_QMARK_$$($annotation$jscomp$6$$)}),
$invalid_text_QMARK_$$=$APP.$cljs$core$_deref$$($invalid_text_STAR_$$),$size_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$count$$($annotation$jscomp$6$$)}),$size$jscomp$149$$=$APP.$cljs$core$_deref$$($size_STAR_$$),$textarea_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$state$jscomp$1185$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$menus$component$ref_COLON_annotations_state$$),$expanded_QMARK_$$=$APP.$cljs$cst$3547$expanded$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1185$$),
$create_id$$=$APP.$cljs$cst$4528$id_for_create$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1185$$),$creating_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$962_on_toggle_expand$$,$create_id$$),$adjust_textarea_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$374$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$374$$)){var $text$jscomp$142$$=$APP.$app$util$dom$get_value$$($temp__5825__auto__$jscomp$374$$);
$APP.$cljs$core$reset_BANG_$$($invalid_text_STAR_$$,$APP.$cuerdas$core$blank_QMARK_$$($text$jscomp$142$$));$APP.$cljs$core$reset_BANG_$$($size_STAR_$$,$APP.$cljs$core$count$$($text$jscomp$142$$));return $temp__5825__auto__$jscomp$374$$.parentNode.dataset.replicatedValue=$text$jscomp$142$$}return null});$id$jscomp$962_on_toggle_expand$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($expanded_QMARK_$$),$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$),
$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_expanded$$($APP.$cljs$core$not$$($expanded_QMARK_$$)))});var $on_discard$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($adjust_textarea_size$$),$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function($event$jscomp$506_temp__5825__auto__$jscomp$375$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$506_temp__5825__auto__$jscomp$375$$);
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$();$event$jscomp$506_temp__5825__auto__$jscomp$375$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);return $APP.$cljs$core$truth_$$($event$jscomp$506_temp__5825__auto__$jscomp$375$$)?($app$util$dom$set_value_BANG_$$($event$jscomp$506_temp__5825__auto__$jscomp$375$$,$annotation$jscomp$6$$),$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$4$$,!1),$creating_QMARK_$$&&
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null)),$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$?$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$():$adjust_textarea_size$$(),$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$()):null}),$on_edit$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$507_temp__5825__auto__$jscomp$376$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$507_temp__5825__auto__$jscomp$376$$);
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$();return $main_instance_QMARK_$jscomp$4$$&&($event$jscomp$507_temp__5825__auto__$jscomp$376$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$),$APP.$cljs$core$truth_$$($event$jscomp$507_temp__5825__auto__$jscomp$376$$))?($APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$4$$,!0),$APP.$app$util$dom$focus_BANG_$$($event$jscomp$507_temp__5825__auto__$jscomp$376$$),$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$()):null}),$on_save$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function($event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$);$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$rerender_fn$jscomp$4$$();$event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);if($APP.$cljs$core$truth_$$($event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$)){$event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$=$APP.$app$util$dom$get_value$$($event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$);if($APP.$cuerdas$core$blank_QMARK_$$($event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$))return null;
$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$4$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_component_annotation$$($component_id$jscomp$95$$,$event$jscomp$508_temp__5825__auto__$jscomp$377_text$jscomp$143$$));$creating_QMARK_$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null));return $rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$rerender_fn$jscomp$4$$()}return null}),$on_delete_annotation$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$130_shape_id$jscomp$159$$),$APP.$rumext$v2$adapt$$($component_id$jscomp$95$$),$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function($event$jscomp$509$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$509$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-component-annotation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-component-annotation.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-ok"),$APP.$cljs$cst$2479$on_accept$$,function(){$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($creating_QMARK_$$?$app$main$data$workspace$set_annotations_id_for_create$$(null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$update_component_annotation$$($component_id$jscomp$95$$,null),$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$rerender_fn$jscomp$4$$()]))}],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$130_shape_id$jscomp$159$$),$APP.$rumext$v2$adapt$$($state$jscomp$1185$$),$APP.$rumext$v2$adapt$$($create_id$$),$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function(){var $temp__5825__auto___78808$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___78808$$)&&($app$util$dom$set_value_BANG_$$($temp__5825__auto___78808$$,
$annotation$jscomp$6$$),$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$?$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$():$adjust_textarea_size$$());$creating_QMARK_$$||$create_id$$==null||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null));return function(){return $creating_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null)):
null}});return $APP.$cljs$core$truth_$$($creating_QMARK_$$?$creating_QMARK_$$:$annotation$jscomp$6$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation "+($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$)?"main_ui_workspace_sidebar_options_menus_component__editing":"")+" "+($creating_QMARK_$$?"main_ui_workspace_sidebar_options_menus_component__creating":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$id$jscomp$962_on_toggle_expand$$,
className:"main_ui_workspace_sidebar_options_menus_component__annotation-title "+($APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$)?$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$:$creating_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_component__expandeable":"")+" "+($APP.$cljs$core$truth_$$($expanded_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_component__expanded":""),children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$)?
$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$:$creating_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-name",children:$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.edit-annotation"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.create-annotation")}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($expanded_QMARK_$$)?"arrow-down":"arrow-right",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-arrow",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.annotation")})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-actions",children:$main_instance_QMARK_$jscomp$4$$&&$expanded_QMARK_$$?$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$||$creating_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$creating_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save"),
onClick:$on_save$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-ok "+($APP.$cljs$core$truth_$$($invalid_text_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_component__disabled":"")})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.discard"),
onClick:$on_discard$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-nok"})})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit"),onClick:$on_edit$jscomp$7$$,
className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"curve",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-ok"})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),onClick:$on_delete_annotation$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"delete",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-nok"})})]}):null})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:$APP.$cljs$core$not$$($expanded_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_component__annotation-body-hidden":"",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-body",children:(0,$APP.$rumext$v2$jsx$$)("textarea",
{"data-debug":$annotation$jscomp$6$$,onInput:$adjust_textarea_size$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-textarea",id:"annotation-textarea",maxLength:300,readOnly:$APP.$cljs$core$not$$($creating_QMARK_$$?$creating_QMARK_$$:$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$),ref:$textarea_ref$$,defaultValue:$annotation$jscomp$6$$,autoFocus:$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$)?$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$:
$creating_QMARK_$$})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$)?$editing_QMARK_$jscomp$9_props_78646_shape$jscomp$996$$:$creating_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-counter",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$149$$),"/300"].join("")}):null]})]}):null};
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_malformed_warning_message$$=function($JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$),1)&&$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$)!=
null)$JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.single.one");else if($APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$some_QMARK_$$,$JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$))$JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.single.all");else{var $and__5023__auto__$jscomp$inline_8901$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$);$JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$=$and__5023__auto__$jscomp$inline_8901$$?$APP.$cljs$core$some$$($APP.$cljs$core$some_QMARK_$$,
$JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$):$and__5023__auto__$jscomp$inline_8901$$;$JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.single.some"):
null}return $JSCompiler_inline_result$jscomp$1819_JSCompiler_temp$jscomp$1817_JSCompiler_temp$jscomp$1818_malformed_list$$};
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_duplicated_warning_message$$=function($JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$),1)&&$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$)!=
null)$JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.single.one");else if($APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$some_QMARK_$$,$JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$))$JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.single.all");else{var $and__5023__auto__$jscomp$inline_8903$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$);$JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$=$and__5023__auto__$jscomp$inline_8903$$?$APP.$cljs$core$some$$($APP.$cljs$core$some_QMARK_$$,
$JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$):$and__5023__auto__$jscomp$inline_8903$$;$JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.single.some"):
null}return $JSCompiler_inline_result$jscomp$1822_JSCompiler_temp$jscomp$1820_JSCompiler_temp$jscomp$1821_duplicated_list$$};
$app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$=function($components$jscomp$17$$){var $duplicated_props$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78663_SHARP_$$){return $APP.$cljs$core$_val$$($p1__78663_SHARP_$$)>1},$APP.$cljs$core$frequencies$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2001$variant_properties$$,$components$jscomp$17$$)))));
return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__78665_p1__78664_SHARP_$$){$G__78665_p1__78664_SHARP_$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($G__78665_p1__78664_SHARP_$$);return $duplicated_props$$.$cljs$core$IFn$_invoke$arity$1$?$duplicated_props$$.$cljs$core$IFn$_invoke$arity$1$($G__78665_p1__78664_SHARP_$$):$duplicated_props$$($G__78665_p1__78664_SHARP_$$)},$components$jscomp$17$$)};
$app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$=function($components$jscomp$18$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$,$app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$($components$jscomp$18$$))};
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$=function($prop_name$jscomp$1$$,$prop_vals$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($val$jscomp$206$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$val$jscomp$206$$,$APP.$cljs$cst$2287$label$$,$APP.$cuerdas$core$blank_QMARK_$$($val$jscomp$206$$)?["(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.empty")),
")"].join(""):$val$jscomp$206$$],null)},$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78666_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78666_SHARP_$$),$prop_name$jscomp$1$$)},$prop_vals$$))))};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_property_STAR_$$=function($dprops$jscomp$3_on_drop$jscomp$11_props_78667$$){var $options$jscomp$622$$=$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$.options,$on_prop_value_change$$=$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$.onPropValueChange,$pos$jscomp$139$$=$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$.pos,$on_reorder$jscomp$1$$=$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$.onReorder,$on_prop_name_blur$$=$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$.onPropNameBlur,
$prop$jscomp$34$$=$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$.prop;$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$,$data$jscomp$480_from_pos$jscomp$11$$){$data$jscomp$480_from_pos$jscomp$11$$=$cljs$cst$5688$from_pos$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$480_from_pos$jscomp$11$$);$relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$,
$APP.$cljs$cst$2952$bot$$)?$pos$jscomp$139$$+1:$pos$jscomp$139$$;return $on_reorder$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$480_from_pos$jscomp$11$$,$relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$):$on_reorder$jscomp$1$$($data$jscomp$480_from_pos$jscomp$11$$,$relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$)});var $on_prop_value_change__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_prop_value_change$$),
$APP.$rumext$v2$adapt$$($pos$jscomp$139$$)],function($value$jscomp$833$$){return $on_prop_value_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_prop_value_change$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$139$$,$value$jscomp$833$$):$on_prop_value_change$$($pos$jscomp$139$$,$value$jscomp$833$$)}),$dref$jscomp$3_vec__78668$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,
"penpot/variant-property",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$,$APP.$cljs$cst$2959$draggable_QMARK_$$,!0,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5688$from_pos$$,$pos$jscomp$139$$],null)]));$dprops$jscomp$3_on_drop$jscomp$11_props_78667$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$3_vec__78668$$,0,null);$dref$jscomp$3_vec__78668$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$3_vec__78668$$,
1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$3_on_drop$jscomp$11_props_78667$$),$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$3_on_drop$jscomp$11_props_78667$$),
$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-bot":""),children:[$on_reorder$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$3_vec__78668$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-name-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$,{value:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$),isEditing:$APP.$cljs$cst$3518$editing_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($prop$jscomp$34$$)),maxLength:60,"data-position":$pos$jscomp$139$$,onBlur:$on_prop_name_blur$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-value-wrapper",
children:function(){var $mixed_value_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$),!1);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$combobox$combobox_STAR_$$,{id:["variant-prop-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$139$$)].join(""),placeholder:$mixed_value_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",defaultSelected:$mixed_value_QMARK_$$?
"":$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$),options:$options$jscomp$622$$,emptyToEnd:!0,maxLength:60,onChange:$on_prop_value_change__$1$$})}()})]})]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_STAR_$$=function($component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$){var $data$jscomp$481$$=$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$.data,$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$=$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$.shapes,$components$jscomp$19$$=$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$.components;
$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$=$APP.$cljs$core$first$$($components$jscomp$19$$);var $variant_id$jscomp$50$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$),$objects$jscomp$788$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$481$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$)),
$APP.$cljs$cst$1631$objects$$);$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2001$variant_properties$$,$components$jscomp$19$$);var $component_ids$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$19$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$components$jscomp$19$$)});$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$=
$APP.$cljs$core$count$$($component_ids$jscomp$9$$)>1?$app$common$types$variant$compare_properties$cljs$0core$0IFn$0_invoke$0arity$02$$($component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$):$APP.$cljs$core$first$$($component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$);$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2003$variant_error$$,$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$);
$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$=$app$main$ui$workspace$sidebar$options$menus$component$get_variant_malformed_warning_message$$($malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$);var $duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$=$APP.$cljs$core$set$$($app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$($APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$481$$,
$objects$jscomp$788$$,$variant_id$jscomp$50$$)));$duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$,$components$jscomp$19$$));$duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$=$app$main$ui$workspace$sidebar$options$menus$component$get_variant_duplicated_warning_message$$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$);
var $prop_vals$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$481$$),$APP.$rumext$v2$adapt$$($objects$jscomp$788$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$50$$)],function(){return $APP.$app$common$files$variant$extract_properties_values$$($data$jscomp$481$$,$objects$jscomp$788$$,$variant_id$jscomp$50$$)}),$get_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($prop_vals$jscomp$1$$)],function($prop_name$jscomp$2$$){return $app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$($prop_name$jscomp$2$$,
$prop_vals$jscomp$1$$)}),$update_property_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_ids$jscomp$9$$)],function($pos$jscomp$140$$,$value$jscomp$834_value__$1$jscomp$49$$){$value$jscomp$834_value__$1$jscomp$49$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$834_value__$1$jscomp$49$$),"");for(var $c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$=
$APP.$cljs$core$seq$$($component_ids$jscomp$9$$),$G__78837_chunk__78673_seq__78672__$1$$=null,$G__78836_count__78674$$=0,$i__78675$$=0;;)if($i__78675$$<$G__78836_count__78674$$){var $G__78838_id$jscomp$963$$=$G__78837_chunk__78673_seq__78672__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__78675$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"variant-edit-property-value",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:combo-design-tab"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$update_property_value$$($G__78838_id$jscomp$963$$,$pos$jscomp$140$$,$value$jscomp$834_value__$1$jscomp$49$$)]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78838_id$jscomp$963$$,
null));$i__78675$$+=1}else if($c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$))$G__78837_chunk__78673_seq__78672__$1$$=$c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__78837_chunk__78673_seq__78672__$1$$)?($c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$=$APP.$cljs$core$_chunked_first$$($G__78837_chunk__78673_seq__78672__$1$$),
$G__78836_count__78674$$=$APP.$cljs$core$_chunked_rest$$($G__78837_chunk__78673_seq__78672__$1$$),$G__78837_chunk__78673_seq__78672__$1$$=$c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$,$G__78838_id$jscomp$963$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$),$c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$=$G__78836_count__78674$$,$G__78836_count__78674$$=$G__78838_id$jscomp$963$$):($G__78838_id$jscomp$963$$=
$APP.$cljs$core$first$$($G__78837_chunk__78673_seq__78672__$1$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-edit-property-value",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:combo-design-tab"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$update_property_value$$($G__78838_id$jscomp$963$$,
$pos$jscomp$140$$,$value$jscomp$834_value__$1$jscomp$49$$)])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78838_id$jscomp$963$$,null)),$c__5548__auto__$jscomp$42_seq__78672_temp__5825__auto__$jscomp$378$$=$APP.$cljs$core$next$$($G__78837_chunk__78673_seq__78672__$1$$),$G__78837_chunk__78673_seq__78672__$1$$=null,$G__78836_count__78674$$=0),$i__78675$$=0;else return null}),$update_property_name$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$50$$)],function($event$jscomp$510_pos$jscomp$141$$){var $value$jscomp$835$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$510_pos$jscomp$141$$));$event$jscomp$510_pos$jscomp$141$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$510_pos$jscomp$141$$),"position")|0;return $APP.$cljs$core$seq$$($value$jscomp$835$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_property_name$$($variant_id$jscomp$50$$,$event$jscomp$510_pos$jscomp$141$$,$value$jscomp$835$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4424$trigger$$,"workspace:design-tab-variant"],null))):null}),$reorder_properties$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$50$$)],function($from_pos$jscomp$12$$,$to_space_between_pos$jscomp$12$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$reorder_variant_poperties$$($variant_id$jscomp$50$$,
$from_pos$jscomp$12$$,$to_space_between_pos$jscomp$12$$))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$161$$,$p__78676_prop$jscomp$35$$){var $pos$jscomp$142$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78676_prop$jscomp$35$$,
0,null);$p__78676_prop$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78676_prop$jscomp$35$$,1,null);var $JSCompiler_temp_const$jscomp$1823$$=$out_arr__44124__auto__$jscomp$161$$.push;var $G__78680$jscomp$inline_8905_JSCompiler_inline_result$jscomp$1825$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__78676_prop$jscomp$35$$);$G__78680$jscomp$inline_8905_JSCompiler_inline_result$jscomp$1825$$=$get_options$$.$cljs$core$IFn$_invoke$arity$1$?$get_options$$.$cljs$core$IFn$_invoke$arity$1$($G__78680$jscomp$inline_8905_JSCompiler_inline_result$jscomp$1825$$):
$get_options$$($G__78680$jscomp$inline_8905_JSCompiler_inline_result$jscomp$1825$$);$JSCompiler_temp_const$jscomp$1823$$.call($out_arr__44124__auto__$jscomp$161$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_property_STAR_$$,{pos:$pos$jscomp$142$$,prop:$p__78676_prop$jscomp$35$$,options:$G__78680$jscomp$inline_8905_JSCompiler_inline_result$jscomp$1825$$,onPropNameBlur:$update_property_name$$,onPropValueChange:$update_property_value$$,onReorder:$reorder_properties$$},
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($variant_id$jscomp$50$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$142$$)].join("")));return $out_arr__44124__auto__$jscomp$161$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$component$jscomp$131_properties$jscomp$106_props_78671_props_list$jscomp$2$$))})}),$APP.$cljs$core$truth_$$($malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($malformed_list$jscomp$1_malformed_msg_shapes$jscomp$202$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.structure.title"))].join("")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.structure.example")})]}):$APP.$cljs$core$truth_$$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$)})]}):
null]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_copy_STAR_$$=function($component$jscomp$132_props_78683_select_duplicated_comps$$){var $shapes$jscomp$203$$=$component$jscomp$132_props_78683_select_duplicated_comps$$.shapes,$component_file_data$jscomp$1$$=$component$jscomp$132_props_78683_select_duplicated_comps$$.componentFileData,$components$jscomp$20_props_first$$=$component$jscomp$132_props_78683_select_duplicated_comps$$.components,$current_file_id$jscomp$16$$=$component$jscomp$132_props_78683_select_duplicated_comps$$.currentFileId;
$component$jscomp$132_props_78683_select_duplicated_comps$$=$APP.$cljs$core$first$$($components$jscomp$20_props_first$$);var $shape$jscomp$997$$=$APP.$cljs$core$first$$($shapes$jscomp$203$$),$properties$jscomp$107$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2001$variant_properties$$,$components$jscomp$20_props_first$$);$components$jscomp$20_props_first$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$132_props_78683_select_duplicated_comps$$);
var $variant_id$jscomp$51$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$132_props_78683_select_duplicated_comps$$),$component_page_objects$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($component_file_data$jscomp$1$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$132_props_78683_select_duplicated_comps$$)),$APP.$cljs$cst$1631$objects$$),$variant_comps$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_file_data$jscomp$1$$),$APP.$rumext$v2$adapt$$($component_page_objects$jscomp$1$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$51$$)],function(){return $APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($component_file_data$jscomp$1$$,$component_page_objects$jscomp$1$$,$variant_id$jscomp$51$$)}),$duplicated_comps$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_comps$jscomp$1$$)],
function(){return $app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$($variant_comps$jscomp$1$$)}),$malformed_comps$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_comps$jscomp$1$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78681_SHARP_$$){return $APP.$cljs$cst$2003$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_page_objects$jscomp$1$$,
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78681_SHARP_$$)))},$variant_comps$jscomp$1$$)}),$prop_vals$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_file_data$jscomp$1$$),$APP.$rumext$v2$adapt$$($component_page_objects$jscomp$1$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$51$$)],function(){return $APP.$app$common$files$variant$extract_properties_values$$($component_file_data$jscomp$1$$,$component_page_objects$jscomp$1$$,
$variant_id$jscomp$51$$)}),$get_options$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($prop_vals$jscomp$2$$)],function($prop_name$jscomp$3$$){return $app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$($prop_name$jscomp$3$$,$prop_vals$jscomp$2$$)});$component$jscomp$132_props_78683_select_duplicated_comps$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_file_id$jscomp$16$$),$APP.$rumext$v2$adapt$$($shape$jscomp$997$$),
$APP.$rumext$v2$adapt$$($duplicated_comps$$)],function(){var $ids$jscomp$281$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$duplicated_comps$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_file_id$jscomp$16$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$first$$($ids$jscomp$281$$),$APP.$cljs$cst$3939$additional_ids$$,$APP.$cljs$core$rest$$($ids$jscomp$281$$)],null)]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$),$APP.$cljs$core$first$$($duplicated_comps$$),!1))});var $select_malformed_comps$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_file_id$jscomp$16$$),
$APP.$rumext$v2$adapt$$($shape$jscomp$997$$),$APP.$rumext$v2$adapt$$($malformed_comps$$)],function(){var $ids$jscomp$282$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$malformed_comps$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_file_id$jscomp$16$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
$APP.$cljs$core$first$$($ids$jscomp$282$$),$APP.$cljs$cst$3939$additional_ids$$,$APP.$cljs$core$rest$$($ids$jscomp$282$$)]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$),$APP.$cljs$core$first$$($malformed_comps$$),!1))}),$key_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$uuid$next$$()),$key$jscomp$414$$=
$APP.$cljs$core$_deref$$($key_STAR_$$),$mixed_label$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),$switch_component$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$203$$)],function($pos$jscomp$143$$,$val$jscomp$207$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val$jscomp$207$$,$mixed_label$$))return $APP.$cljs$core$reset_BANG_$$($key_STAR_$$,$APP.$app$common$uuid$next$$());var $error_msg$$=$APP.$cljs$core$count$$($shapes$jscomp$203$$)>
1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.component.switch.loop-error-multi"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.component.swap.loop-error");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$variants_switch$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1614$shapes$$,$shapes$jscomp$203$$,$APP.$cljs$cst$1406$pos$$,$pos$jscomp$143$$,
$APP.$cljs$cst$108$val$$,$val$jscomp$207$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1295$on_error$$,function(){$APP.$cljs$core$reset_BANG_$$($key_STAR_$$,$APP.$app$common$uuid$next$$());return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$02$$($error_msg$$))}],null))))}),$switch_component_toggle$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$203$$)],
function($pos$jscomp$144$$,$boolean_pair_inverted_boolean_pair$$,$val$jscomp$208_val__$1$jscomp$16$$){$boolean_pair_inverted_boolean_pair$$=$app$common$data$invert_map$$($boolean_pair_inverted_boolean_pair$$);$val$jscomp$208_val__$1$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($boolean_pair_inverted_boolean_pair$$,$val$jscomp$208_val__$1$jscomp$16$$);return $switch_component$$.$cljs$core$IFn$_invoke$arity$2$?$switch_component$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$144$$,
$val$jscomp$208_val__$1$jscomp$16$$):$switch_component$$($pos$jscomp$144$$,$val$jscomp$208_val__$1$jscomp$16$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$162$$,$p__78684$$){var $pos$jscomp$145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78684$$,
0,null),$prop$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78684$$,1,null);$out_arr__44124__auto__$jscomp$162$$.push(function(){var $mixed_value_QMARK_$jscomp$1$$=$cljs$core$not_every_QMARK_$$(function($p1__78682_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$),$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__78682_SHARP_$$,
$pos$jscomp$145$$)))},$properties$jscomp$107$$),$options$jscomp$623_options__$1$jscomp$87$$=function(){var $G__78688$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$);return $get_options$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$get_options$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78688$$):$get_options$jscomp$1$$($G__78688$$)}(),$boolean_pair$jscomp$1$$=$app$common$types$variant$find_boolean_pair$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$options$jscomp$623_options__$1$jscomp$87$$));$options$jscomp$623_options__$1$jscomp$87$$=$mixed_value_QMARK_$jscomp$1$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$623_options__$1$jscomp$87$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$mixed_label$$,$APP.$cljs$cst$2287$label$$,$mixed_label$$,$APP.$cljs$cst$5109$dimmed$$,!0],null)):$options$jscomp$623_options__$1$jscomp$87$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-container",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$),className:"main_ui_workspace_sidebar_options_menus_component__variant-property-name-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$)})}),$APP.$cljs$core$truth_$$($boolean_pair$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-value-switch-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,{defaultChecked:$mixed_value_QMARK_$jscomp$1$$?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($boolean_pair$jscomp$1$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$)),onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($switch_component_toggle$$,$pos$jscomp$145$$,
$boolean_pair$jscomp$1$$)},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$414$$)].join(""))}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-value-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:$mixed_value_QMARK_$jscomp$1$$?
$mixed_label$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$),options:$options$jscomp$623_options__$1$jscomp$87$$,emptyToEnd:!0,onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($switch_component$$,$pos$jscomp$145$$)},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$36$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$414$$)].join(""))})]},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$145$$),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($mixed_value_QMARK_$jscomp$1$$)].join(""))}());return $out_arr__44124__auto__$jscomp$162$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$components$jscomp$20_props_first$$))}),$APP.$cljs$core$seq$$($malformed_comps$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.copy")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$select_malformed_comps$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.locate")})]}):$APP.$cljs$core$seq$$($duplicated_comps$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.copy.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$component$jscomp$132_props_78683_select_duplicated_comps$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.copy.locate")})]}):
null]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_item_STAR_$$=function($component_id$jscomp$96_props_78690$$){var $is_search$$=$component_id$jscomp$96_props_78690$$.isSearch,$shapes$jscomp$204$$=$component_id$jscomp$96_props_78690$$.shapes,$listing_thumbs$$=$component_id$jscomp$96_props_78690$$.listingThumbs,$file_id$jscomp$407$$=$component_id$jscomp$96_props_78690$$.fileId,$root_shape$jscomp$12$$=$component_id$jscomp$96_props_78690$$.rootShape,$num_variants$jscomp$1$$=$component_id$jscomp$96_props_78690$$.numVariants,
$item$jscomp$128$$=$component_id$jscomp$96_props_78690$$.item,$loop$$=$component_id$jscomp$96_props_78690$$.loop,$container$jscomp$88$$=$component_id$jscomp$96_props_78690$$.container;$component_id$jscomp$96_props_78690$$=$component_id$jscomp$96_props_78690$$.componentId;var $on_select$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$204$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$407$$),$APP.$rumext$v2$adapt$$($item$jscomp$128$$)],function(){return $APP.$cljs$core$truth_$$($loop$$)?
null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$component_multi_swap$$($shapes$jscomp$204$$,$file_id$jscomp$407$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$specialized_panel$clear_specialized_panel$$()]))}),$item_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(),$visible_QMARK_$jscomp$2$$=$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($item_ref$jscomp$7$$);
return(0,$APP.$rumext$v2$jsxs$$)("button",{ref:$item_ref$jscomp$7$$,onClick:$on_select$jscomp$4$$,disabled:$loop$$,className:($APP.$cljs$core$not$$($listing_thumbs$$)?"main_ui_workspace_sidebar_options_menus_component__swap-item-list":"")+" "+($APP.$cljs$core$truth_$$($listing_thumbs$$)?"main_ui_workspace_sidebar_options_menus_component__swap-item-grid":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$),$component_id$jscomp$96_props_78690$$)?
"main_ui_workspace_sidebar_options_menus_component__selected":""),children:[$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$,{fileId:$file_id$jscomp$407$$,className:"main_ui_workspace_sidebar_options_menus_component__swap-item-thumbnail",rootShape:$root_shape$jscomp$12$$,component:$item$jscomp$128$$,container:$container$jscomp$88$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$core$truth_$$($is_search$$)?
$cljs$cst$5689$full_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$),className:"main_ui_workspace_sidebar_options_menus_component__swap-item-name",children:$APP.$cljs$core$truth_$$($is_search$$)?$cljs$cst$5689$full_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$)}),$APP.$app$common$types$component$is_variant_QMARK_$$($item$jscomp$128$$)?
(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.assets.components.num-variants",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$num_variants$jscomp$1$$])),className:"main_ui_workspace_sidebar_options_menus_component__swap-item-variant-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"variant",size:"s"})}):null]},["swap-item-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$128$$))].join(""))};
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$=function($props_78691$$){var $on_enter_group$$=$props_78691$$.onEnterGroup,$group_name$jscomp$5$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_78691$$.item);return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:function(){return $on_enter_group$$.$cljs$core$IFn$_invoke$arity$1$?$on_enter_group$$.$cljs$core$IFn$_invoke$arity$1$($group_name$jscomp$5$$):$on_enter_group$$($group_name$jscomp$5$$)},title:$group_name$jscomp$5$$,
className:"main_ui_workspace_sidebar_options_menus_component__swap-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__swap-group-name",children:$APP.$cljs$core$last$$($APP.$app$common$path_names$split_path$$($group_name$jscomp$5$$))}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_component__swap-group-icon",variant:"ghost",iconId:"arrow-right",size:"s"})]})};
$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$01$$=function($components$jscomp$21_paths$jscomp$7$$){$components$jscomp$21_paths$jscomp$7$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$path_names$split_path$$,$APP.$cljs$cst$296$path$$),$components$jscomp$21_paths$jscomp$7$$);return $app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$21_paths$jscomp$7$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,0)};
$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$=function($paths$jscomp$8$$,$path$jscomp$275$$,$n$jscomp$310$$){var $current$jscomp$58$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$first$$($paths$jscomp$8$$),$n$jscomp$310$$,null);return $current$jscomp$58$$!=null&&$APP.$cljs$core$every_QMARK_$$(function($p1__78692_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$58$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__78692_SHARP_$$,
$n$jscomp$310$$,null))},$paths$jscomp$8$$)?$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$($paths$jscomp$8$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$275$$,$current$jscomp$58$$),$n$jscomp$310$$+1):$path$jscomp$275$$};
$app$main$ui$workspace$sidebar$options$menus$component$same_component_file_QMARK_$$=function($shape_a$$,$shape_b$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_a$$),$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_b$$))};
$app$main$ui$workspace$sidebar$options$menus$component$same_component_QMARK_$$=function($shape_a$jscomp$1$$,$shape_b$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_a$jscomp$1$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_b$jscomp$1$$))};
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_STAR_$$=function($current_file_id$jscomp$17_current_lib_name_props_78704$$){var $shapes$jscomp$205$$=$current_file_id$jscomp$17_current_lib_name_props_78704$$.shapes,$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($shapes$jscomp$205$$)),$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$=$APP.$cljs$core$first$$($shapes$jscomp$205$$);
$current_file_id$jscomp$17_current_lib_name_props_78704$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);var $libraries$jscomp$145$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$objects$jscomp$789$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$options$menus$component$same_component_file_QMARK_$$,
$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$),$shapes$jscomp$205$$),$component_id$jscomp$97$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$options$menus$component$same_component_QMARK_$$,$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$),$shapes$jscomp$205$$)?$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$):
null;$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$=$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$?$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$):$current_file_id$jscomp$17_current_lib_name_props_78704$$;var $components$jscomp$22_on_library_change$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78695_SHARP_$$){return $APP.$app$common$types$file$get_component$$($libraries$jscomp$145$$,
$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__78695_SHARP_$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78695_SHARP_$$))},$shapes$jscomp$205$$);$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$=$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$?$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($components$jscomp$22_on_library_change$jscomp$1$$)):$APP.$app$common$path_names$join_path$$($components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$?
$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$01$$($components$jscomp$22_on_library_change$jscomp$1$$):"");var $filters_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2513$term$$,"",$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$core$truth_$$($groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$)?
$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$:"",$cljs$cst$5690$listing_thumbs_QMARK_$$,!1],null)),$filters$jscomp$13$$=$APP.$cljs$core$_deref$$($filters_STAR_$jscomp$1$$),$search_QMARK_$$=!$APP.$cuerdas$core$blank_QMARK_$$($APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)),$current_library_id$$=$APP.$cljs$core$contains_QMARK_$$($libraries$jscomp$145$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?
$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$):$current_file_id$jscomp$17_current_lib_name_props_78704$$;$current_file_id$jscomp$17_current_lib_name_props_78704$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_library_id$$,$current_file_id$jscomp$17_current_lib_name_props_78704$$)?$APP.$cuerdas$core$upper$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.local-library")):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$145$$,
$current_library_id$$),$APP.$cljs$cst$725$name$$);var $current_lib_data$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$145$$),$APP.$rumext$v2$adapt$$($current_library_id$$)],function(){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$145$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_library_id$$,$APP.$cljs$cst$142$data$$],null))}),$current_lib_counts$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_lib_data$$)],function(){return $APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$2000$variant_id$$,$APP.$app$common$types$components_list$components_seq$$($current_lib_data$$)),$APP.$cljs$core$count$$)});$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78698_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78698_SHARP_$$,
$cljs$cst$5689$full_name$$,$app$common$path_names$merge_path_item_with_dot$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78698_SHARP_$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78698_SHARP_$$)))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78697_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__78697_SHARP_$$,$current_lib_data$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78696_SHARP_$$){return $APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($p1__78696_SHARP_$$)===
!0},$APP.$cljs$core$vals$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($current_lib_data$$)))));$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($path__$1$jscomp$10_split_path$jscomp$1$$){$path__$1$jscomp$10_split_path$jscomp$1$$=$APP.$app$common$path_names$split_path$$($path__$1$jscomp$10_split_path$jscomp$1$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$161$$,$dir$jscomp$6$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$161$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($acc$jscomp$161$$))," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dir$jscomp$6$$)].join(""))},new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($path__$1$jscomp$10_split_path$jscomp$1$$)],
null),$APP.$cljs$core$rest$$($path__$1$jscomp$10_split_path$jscomp$1$$))}),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$empty_QMARK_$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$),$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78699_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$path_names$butlast_path$$($p1__78699_SHARP_$$),
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))})]));$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$=$search_QMARK_$$?null:$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($name$jscomp$457$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$name$jscomp$457$$],null)},$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$,
$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$)));$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$=$search_QMARK_$$?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78700_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($cljs$cst$5689$full_name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78700_SHARP_$$)),$APP.$cuerdas$core$lower$$($APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)))},
$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$):$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78701_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78701_SHARP_$$),$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))},$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$);$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$=
$APP.$cljs$core$truth_$$($search_QMARK_$$?$search_QMARK_$$:$cljs$cst$5690$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5689$full_name$$,$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$):$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$,
$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$));$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$789$$)],function($shape__$1$jscomp$107$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$,$APP.$app$common$files$helpers$get_parents$$($objects$jscomp$789$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$107$$))))});var $parent_components$jscomp$1$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shapes$jscomp$205$$]));$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($library$jscomp$40$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$40$$),$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$40$$)],null)},$APP.$cljs$core$vals$$($libraries$jscomp$145$$));$components$jscomp$22_on_library_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$964$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($filters_STAR_$jscomp$1$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1644$file_id$$,$id$jscomp$964$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2513$term$$,"",$APP.$cljs$cst$296$path$$,""]))});var $on_search_term_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($term$jscomp$11$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2513$term$$,$term$jscomp$11$$)}),$on_search_clear_click$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2513$term$$,"")}),$on_go_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$,$app$common$path_names$butlast_path$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)))}),$on_enter_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78702_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$,$p1__78702_SHARP_$$)}),$toggle_list_style$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($style$jscomp$75$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5690$listing_thumbs_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$75$$,"grid"))}),$filter_path_with_dots$$=$app$common$path_names$join_path_with_dot$$($APP.$app$common$path_names$split_path$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-title",
children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.swap")})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-filters",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{id:"swap-component-search-filter",
iconId:"search",value:$APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$),placeholder:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.search"))," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$145$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_library_id$$,
$APP.$cljs$cst$725$name$$],null)))].join(""),onChange:$on_search_term_change$jscomp$1$$,onClear:$on_search_clear_click$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$current_library_id$$,options:$file_id$jscomp$408_find_parent_components_libraries_options_shape$jscomp$998$$,"on-change":$components$jscomp$22_on_library_change$jscomp$1$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-name",children:$current_file_id$jscomp$17_current_lib_name_props_78704$$}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$cljs$core$truth_$$($cljs$cst$5690$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?"grid":"list",
"on-change":$toggle_list_style$jscomp$3$$,name:"swap-listing-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"view-as-list",value:"list",id:"swap-opt-list"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"flex-grid",value:"grid",id:"swap-opt-grid"})]})]}),$search_QMARK_$$||$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?null:(0,$APP.$rumext$v2$jsxs$$)("button",
{onClick:$on_go_back$$,title:$filter_path_with_dots$$,className:"main_ui_workspace_sidebar_options_menus_component__swap-library-back",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-left",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-back-name",children:$filter_path_with_dots$$})]}),$APP.$cljs$core$empty_QMARK_$$($components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-empty",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.swap.empty")}):null,$APP.$cljs$core$truth_$$($cljs$cst$5690$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$163$$,$item$jscomp$130$$){$out_arr__44124__auto__$jscomp$163$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$,
{item:$item$jscomp$130$$,onEnterGroup:$on_enter_group$jscomp$1$$}));return $out_arr__44124__auto__$jscomp$163$$},[],$groups$jscomp$13_path$jscomp$276_single_QMARK_$jscomp$14_xform$jscomp$42$$)}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:($APP.$cljs$core$truth_$$($cljs$cst$5690$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?"main_ui_workspace_sidebar_options_menus_component__swap-library-grid":"")+" "+($APP.$cljs$core$not$$($cljs$cst$5690$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?
"main_ui_workspace_sidebar_options_menus_component__swap-library-list":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$164$$,$item$jscomp$131$$){$out_arr__44124__auto__$jscomp$164$$.push($APP.$cljs$core$truth_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$131$$))?function(){var $data$jscomp$482_root_shape$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$145$$,
$current_library_id$$),$APP.$cljs$cst$142$data$$),$container$jscomp$89$$=$APP.$app$common$types$file$get_component_page$$($data$jscomp$482_root_shape$jscomp$13$$,$item$jscomp$131$$);$data$jscomp$482_root_shape$jscomp$13$$=$APP.$app$common$types$file$get_component_root$$($data$jscomp$482_root_shape$jscomp$13$$,$item$jscomp$131$$);var $components__$3$$=$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1627$component_id$$,$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$89$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$482_root_shape$jscomp$13$$)))),$loop_QMARK_$$=$APP.$cljs$core$some$$(function($p1__78703_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($components__$3$$,$p1__78703_SHARP_$$)},$parent_components$jscomp$1$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_item_STAR_$$,{loop:$loop_QMARK_$$,isSearch:$search_QMARK_$$,componentId:$component_id$jscomp$97$$,listingThumbs:$cljs$cst$5690$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$),
numVariants:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_lib_counts$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$131$$)),rootShape:$data$jscomp$482_root_shape$jscomp$13$$,shapes:$shapes$jscomp$205$$,item:$item$jscomp$131$$,fileId:$current_library_id$$,container:$container$jscomp$89$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$131$$)??""))}():(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$,
{item:$item$jscomp$131$$,onEnterGroup:$on_enter_group$jscomp$1$$},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$131$$)));return $out_arr__44124__auto__$jscomp$164$$},[],$components__$1_components__$2_every_same_file_QMARK__items$jscomp$61$$)})]})]})]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$=function($props_78727_subtext$$){function $do_action$$($action$jscomp$4$$,$event$jscomp$512$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$512$$);$action$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$action$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$action$jscomp$4$$();return $on_menu_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_menu_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_menu_close$jscomp$2$$()}
var $text$jscomp$144$$=$props_78727_subtext$$.text,$disabled$jscomp$16$$=$props_78727_subtext$$.disabled,$menu_entries$jscomp$1$$=$props_78727_subtext$$.menuEntries,$icon$jscomp$22$$=$props_78727_subtext$$.icon,$on_click$jscomp$45$$=$props_78727_subtext$$.onClick;$props_78727_subtext$$=$props_78727_subtext$$.subtext;var $menu_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$menu_open_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($menu_open_STAR_$$),$menu_entries_QMARK_$$=
$APP.$cljs$core$seq$$($menu_entries$jscomp$1$$),$on_menu_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($menu_open_STAR_$$),$APP.$rumext$v2$adapt$$($menu_open_QMARK_$jscomp$1$$)],function($event$jscomp$511$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$511$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$511$$);return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$$,$APP.$cljs$core$not$$($menu_open_QMARK_$jscomp$1$$))}),$on_menu_close$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($menu_open_STAR_$$)],function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{"data-testid":"component-pill-button",onClick:$on_click$jscomp$45$$,disabled:$disabled$jscomp$16$$,className:"main_ui_workspace_sidebar_options_menus_component__pill-btn "+
($menu_entries_QMARK_$$?"main_ui_workspace_sidebar_options_menus_component__with-menu":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{size:"s",iconId:$icon$jscomp$22$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-name",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-text",
children:$text$jscomp$144$$}),$APP.$cljs$core$truth_$$($props_78727_subtext$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-subtext",children:$props_78727_subtext$$}):null]})]}),$menu_entries_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-actions",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_menu_click$jscomp$3$$,className:"main_ui_workspace_sidebar_options_menus_component__pill-actions-btn "+
($APP.$cljs$core$truth_$$($menu_open_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_options_menus_component__selected":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"menu"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$menu_open_QMARK_$jscomp$1$$,"on-close":$on_menu_close$jscomp$2$$,children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown "+($APP.$cljs$core$truth_$$($props_78727_subtext$$)?
"main_ui_workspace_sidebar_options_menus_component__extended":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$165$$,$p__78729_title$jscomp$37$$){var $action$jscomp$5_map__78730__$1$$=$APP.$cljs$core$__destructure_map$$($p__78729_title$jscomp$37$$);$p__78729_title$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$5_map__78730__$1$$,$APP.$cljs$cst$939$title$$);$action$jscomp$5_map__78730__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$5_map__78730__$1$$,
$APP.$cljs$cst$2683$action$$);$out_arr__44124__auto__$jscomp$165$$.push($p__78729_title$jscomp$37$$!=null?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($do_action$$,$action$jscomp$5_map__78730__$1$$),className:"main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$p__78729_title$jscomp$37$$})},$p__78729_title$jscomp$37$$):null);return $out_arr__44124__auto__$jscomp$165$$},
[],$menu_entries$jscomp$1$$)})})]}):null]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$=function($current_file_id$jscomp$18_props_78732$$){var $shapes$jscomp$206_shapes__$1$jscomp$35$$=$current_file_id$jscomp$18_props_78732$$.shapes,$is_swap_opened$$=$current_file_id$jscomp$18_props_78732$$.isSwapOpened;$current_file_id$jscomp$18_props_78732$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);var $libraries$jscomp$146$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$current_file$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$146$$,$current_file_id$jscomp$18_props_78732$$),$state_STAR_$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1876$show_content$$,!0,$APP.$cljs$cst$4927$menu_open$$,!1],null)}),$open_QMARK_$jscomp$15_state$jscomp$1186$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$14$$);$open_QMARK_$jscomp$15_state$jscomp$1186$$=$APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($open_QMARK_$jscomp$15_state$jscomp$1186$$);
$shapes$jscomp$206_shapes__$1$jscomp$35$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,$shapes$jscomp$206_shapes__$1$jscomp$35$$);var $multi$jscomp$6$$=$APP.$cljs$core$count$$($shapes$jscomp$206_shapes__$1$jscomp$35$$)>1,$copies$jscomp$3$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$in_component_copy_QMARK_$$,$shapes$jscomp$206_shapes__$1$jscomp$35$$),$can_swap_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($copies$jscomp$3$$)),
$all_main_QMARK_$jscomp$4$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$main_instance_QMARK_$$,$shapes$jscomp$206_shapes__$1$jscomp$35$$),$any_variant_QMARK_$jscomp$3$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$shapes$jscomp$206_shapes__$1$jscomp$35$$),$components$jscomp$23$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78731_SHARP_$$){return $APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__78731_SHARP_$$,
$current_file$jscomp$1$$,$libraries$jscomp$146$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]))},$shapes$jscomp$206_shapes__$1$jscomp$35$$),$same_variant_QMARK_$jscomp$1$$=$app$common$types$variant$same_variant_QMARK_$$($components$jscomp$23$$),$shape$jscomp$999$$=$APP.$cljs$core$first$$($shapes$jscomp$206_shapes__$1$jscomp$35$$),$id$jscomp$965$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$),
$shape_name$jscomp$4$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$),$component$jscomp$134$$=$APP.$cljs$core$first$$($components$jscomp$23$$),$data$jscomp$483$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$146$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$)),$APP.$cljs$cst$142$data$$),$is_variant_QMARK_$jscomp$3$$=$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$134$$),
$main_instance_QMARK_$jscomp$5$$=$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$999$$),$toggle_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$14$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$core$not$$)}),$on_click_variant_title_help$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5687$variants_help_modal$$],null));return $app$main$data$modal$allow_click_outside_BANG_$$()}),$on_component_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$)}),$open_component_panel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_swap_QMARK_$$),
$APP.$rumext$v2$adapt$$($shapes$jscomp$206_shapes__$1$jscomp$35$$)],function(){$can_swap_QMARK_$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$specialized_panel$open_specialized_panel$$());return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$("swap-component-search-filter"))})}),$transform_into_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$965$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$965$$))}),$create_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$965$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:button-design-tab-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$965$$)]))}),$add_new_property$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$999$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-property",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:button-design-tab-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3520$property_value$$,"Value 1",$APP.$cljs$cst$3518$editing_QMARK_$$,!0],null)]))]))}),$on_combine_as_variants$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$combine_selected_as_variants$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4424$trigger$$,"workspace:button-design-tab"],null)))}),$rerender_fn$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$14$$,
$APP.$cljs$core$update$$,$cljs$cst$5691$render$$,$APP.$cljs$core$inc$$)}),$menu_entries$jscomp$2$$=$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shapes$jscomp$206_shapes__$1$jscomp$35$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5598$for_design_tab_QMARK_$$,!0],null)])),$path$jscomp$277$$=$app$common$path_names$join_path_with_dot$$($APP.$app$common$path_names$split_path$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$)));
return $APP.$cljs$core$seq$$($shapes$jscomp$206_shapes__$1$jscomp$35$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-title",children:$APP.$cljs$core$truth_$$($is_swap_opened$$)?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_component_back$$,className:"main_ui_workspace_sidebar_options_menus_component__component-title-swap",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-left",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component")})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$15_state$jscomp$1186$$),onCollapsed:$toggle_content$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component"),className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar",titleClass:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-title",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-type",children:$main_instance_QMARK_$jscomp$5$$?$is_variant_QMARK_$jscomp$3$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.variant"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.main"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.copy")})}),$is_variant_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.title"),onClick:$on_click_variant_title_help$$,icon:"help"}):
null,$main_instance_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),onClick:$is_variant_QMARK_$jscomp$3$$?$create_variant$$:$transform_into_variant$$,icon:"variant"}):null]})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$15_state$jscomp$1186$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-pill",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$,{icon:$main_instance_QMARK_$jscomp$5$$?$is_variant_QMARK_$jscomp$3$$?"variant":"component":"component-copy",text:$multi$jscomp$6$$&&$APP.$cljs$core$not$$($same_variant_QMARK_$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
$APP.$cljs$core$last$$($APP.$app$common$path_names$split_path$$($shape_name$jscomp$4$$)),subtext:$APP.$cljs$core$truth_$$(function(){if($can_swap_QMARK_$$){var $or__5025__auto__$jscomp$1184$$=!$multi$jscomp$6$$;return $or__5025__auto__$jscomp$1184$$?$or__5025__auto__$jscomp$1184$$:$same_variant_QMARK_$jscomp$1$$}return $can_swap_QMARK_$$}())?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.unlinked"):
$app$common$path_names$merge_path_item_with_dot$$($path$jscomp$277$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$)):null,onClick:$open_component_panel$$,disabled:$APP.$cljs$core$truth_$$($is_swap_opened$$)?$is_swap_opened$$:!$can_swap_QMARK_$$,menuEntries:$menu_entries$jscomp$2$$}),$is_variant_QMARK_$jscomp$3$$&&$main_instance_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),
onClick:$add_new_property$$,icon:"add"}):null]}),$APP.$cljs$core$truth_$$($is_swap_opened$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_STAR_$$,{shapes:$copies$jscomp$3$$}):null,$APP.$cljs$core$truth_$$(function(){if($is_variant_QMARK_$jscomp$3$$){var $and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$=!$main_instance_QMARK_$jscomp$5$$;return $and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$?
($and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$=$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$)))?($and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$=$APP.$cljs$core$not$$($is_swap_opened$$))?($and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$=
!$multi$jscomp$6$$)?$and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$:$same_variant_QMARK_$jscomp$1$$:$and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$:$and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$:$and__5023__auto____$1$jscomp$135_and__5023__auto____$2$jscomp$43_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1186$$}return $is_variant_QMARK_$jscomp$3$$}())?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_copy_STAR_$$,{currentFileId:$current_file_id$jscomp$18_props_78732$$,components:$components$jscomp$23$$,shapes:$shapes$jscomp$206_shapes__$1$jscomp$35$$,componentFileData:$data$jscomp$483$$}):null,$APP.$cljs$core$truth_$$($is_variant_QMARK_$jscomp$3$$?$main_instance_QMARK_$jscomp$5$$?$APP.$cljs$core$truth_$$($same_variant_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($is_swap_opened$$):$same_variant_QMARK_$jscomp$1$$:
$main_instance_QMARK_$jscomp$5$$:$is_variant_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_STAR_$$,{components:$components$jscomp$23$$,shapes:$shapes$jscomp$206_shapes__$1$jscomp$35$$,data:$data$jscomp$483$$}):null,$APP.$cljs$core$not$$($is_swap_opened$$)&&!$multi$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_annotation_STAR_$$,{id:$id$jscomp$965$$,shape:$shape$jscomp$999$$,
component:$component$jscomp$134$$,rerenderFn:$rerender_fn$jscomp$5$$}):null,$multi$jscomp$6$$&&$all_main_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($any_variant_QMARK_$jscomp$3$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",className:"main_ui_workspace_sidebar_options_menus_component__component-combine",onClick:$on_combine_as_variants$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants")}):
null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3073$display_touched$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{children:[":touched ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$))]}):null]}):null]}):null};
$app$main$ui$workspace$sidebar$options$menus$component$move_empty_items_to_end$$=function($v$jscomp$667$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$empty_QMARK_$$),$v$jscomp$667$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$empty_QMARK_$$),$v$jscomp$667$$)};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_property_STAR_$$=function($is_remove_disabled_props_78757$$){var $on_remove$jscomp$1$$=$is_remove_disabled_props_78757$$.onRemove,$property$jscomp$84$$=$is_remove_disabled_props_78757$$.property,$on_blur$jscomp$19$$=$is_remove_disabled_props_78757$$.onBlur,$pos$jscomp$146$$=$is_remove_disabled_props_78757$$.pos,$on_reorder$jscomp$2$$=$is_remove_disabled_props_78757$$.onReorder;$is_remove_disabled_props_78757$$=$is_remove_disabled_props_78757$$.isRemoveDisabled;
var $values$jscomp$81$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$replace$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,["","--"],null),$app$main$ui$workspace$sidebar$options$menus$component$move_empty_items_to_end$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$84$$)))),$dprops$jscomp$4_on_drop$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$,
$data$jscomp$484_from_pos$jscomp$13$$){$data$jscomp$484_from_pos$jscomp$13$$=$cljs$cst$5688$from_pos$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$484_from_pos$jscomp$13$$);$relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$,$APP.$cljs$cst$2952$bot$$)?$pos$jscomp$146$$+1:$pos$jscomp$146$$;return $on_reorder$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$484_from_pos$jscomp$13$$,
$relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$):$on_reorder$jscomp$2$$($data$jscomp$484_from_pos$jscomp$13$$,$relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$)}),$dref$jscomp$4_vec__78762$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/variant-main-property",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$4_on_drop$jscomp$12$$,$APP.$cljs$cst$2959$draggable_QMARK_$$,
!0,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5688$from_pos$$,$pos$jscomp$146$$],null)]));$dprops$jscomp$4_on_drop$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$4_vec__78762$$,0,null);$dref$jscomp$4_vec__78762$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$4_vec__78762$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$4_on_drop$jscomp$12$$),$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$4_on_drop$jscomp$12$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-bot":""),
children:[$on_reorder$jscomp$2$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$4_vec__78762$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$,{value:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$84$$),"data-position":$pos$jscomp$146$$,
meta:$values$jscomp$81$$,isEditing:$APP.$cljs$cst$3518$editing_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($property$jscomp$84$$)),maxLength:60,onBlur:$on_blur$jscomp$19$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",icon:"remove","data-position":$pos$jscomp$146$$,"aria-label":$APP.$cljs$core$truth_$$($is_remove_disabled_props_78757$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-variant-property.last-property"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-variant-property"),onClick:$on_remove$jscomp$1$$,disabled:$is_remove_disabled_props_78757$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_STAR_$$=function($props_78778_shapes$jscomp$207$$){$props_78778_shapes$jscomp$207$$=$props_78778_shapes$jscomp$207$$.shapes;var $multi_QMARK_$jscomp$1$$=$APP.$cljs$core$count$$($props_78778_shapes$jscomp$207$$)>1,$shape$jscomp$1000$$=$APP.$cljs$core$first$$($props_78778_shapes$jscomp$207$$),$shape_name$jscomp$5$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1000$$),$libraries$jscomp$147_malformed_QMARK_$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$libraries$$),$current_file_id$jscomp$19_duplicated_QMARK__variant_components$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$current_page_id$jscomp$4_open_QMARK_$jscomp$16$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$),$data$jscomp$485$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$147_malformed_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$current_file_id$jscomp$19_duplicated_QMARK__variant_components$jscomp$2$$,$APP.$cljs$cst$142$data$$],null)),$objects$jscomp$790$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$485$$,$current_page_id$jscomp$4_open_QMARK_$jscomp$16$$),$APP.$cljs$cst$1631$objects$$),$variants$jscomp$10$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78771_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$790$$,
$p1__78771_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1000$$)),$variant_id$jscomp$52$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($variants$jscomp$10$$));$current_file_id$jscomp$19_duplicated_QMARK__variant_components$jscomp$2$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$485$$,$objects$jscomp$790$$,$variant_id$jscomp$52$$);var $malformed_ids$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filterv$$(function($p1__78773_SHARP_$$){return $APP.$cljs$cst$2003$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($p1__78773_SHARP_$$)!=null},$variants$jscomp$10$$));$libraries$jscomp$147_malformed_QMARK_$$=$APP.$app$common$data$not_empty_QMARK_$$($malformed_ids$$);var $duplicated_ids$jscomp$2$$=$app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$($current_file_id$jscomp$19_duplicated_QMARK__variant_components$jscomp$2$$);
$current_file_id$jscomp$19_duplicated_QMARK__variant_components$jscomp$2$$=$APP.$app$common$data$not_empty_QMARK_$$($duplicated_ids$jscomp$2$$);var $properties$jscomp$108$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$485$$),$APP.$rumext$v2$adapt$$($objects$jscomp$790$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function(){return $APP.$app$common$files$variant$extract_properties_values$$($data$jscomp$485$$,$objects$jscomp$790$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1000$$))}),
$single_property_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($properties$jscomp$108$$),1),$open_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$current_page_id$jscomp$4_open_QMARK_$jscomp$16$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$6$$);var $menu_entries$jscomp$3_show_in_assets_panel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants$jscomp$10$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_component_in_assets$$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($variants$jscomp$10$$))))}),
$create_variant$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1000$$)],function($trigger$jscomp$4$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$trigger$jscomp$4$$],null)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1000$$))]))}),$add_new_property$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function($trigger$jscomp$5$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-property",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$trigger$jscomp$5$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($variant_id$jscomp$52$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3520$property_value$$,
"Value 1",$APP.$cljs$cst$3518$editing_QMARK_$$,!0],null)]))]))});$menu_entries$jscomp$3_show_in_assets_panel$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-in-assets"),$APP.$cljs$cst$2683$action$$,$menu_entries$jscomp$3_show_in_assets_panel$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),$APP.$cljs$cst$2683$action$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($create_variant$jscomp$1$$,"workspace:design-tab-menu-component")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),$APP.$cljs$cst$2683$action$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($add_new_property$jscomp$1$$,
"workspace:design-tab-menu-component")],null)],null);var $toggle_content$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$6$$,$APP.$cljs$core$not$$)}),$on_click_variant_title_help$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$cljs$cst$5687$variants_help_modal$$],null));return $app$main$data$modal$allow_click_outside_BANG_$$()}),$update_property_name$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function($event$jscomp$513_pos$jscomp$147$$){var $value$jscomp$836$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$513_pos$jscomp$147$$);$event$jscomp$513_pos$jscomp$147$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$513_pos$jscomp$147$$),
"position")|0;return $APP.$cljs$core$seq$$($value$jscomp$836$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_property_name$$($variant_id$jscomp$52$$,$event$jscomp$513_pos$jscomp$147$$,$value$jscomp$836$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4424$trigger$$,"workspace:design-tab-component"],null))):null}),$remove_property$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$),
$APP.$rumext$v2$adapt$$($properties$jscomp$108$$)],function($event$jscomp$514_pos$jscomp$148$$){$event$jscomp$514_pos$jscomp$148$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$514_pos$jscomp$148$$),"position")|0;return $APP.$cljs$core$count$$($properties$jscomp$108$$)>1?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"variant-remove-property",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:button-design-tab"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$remove_property$$($variant_id$jscomp$52$$,$event$jscomp$514_pos$jscomp$148$$)])):null}),$reorder_properties$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function($from_pos$jscomp$14$$,$to_space_between_pos$jscomp$14$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$reorder_variant_poperties$$($variant_id$jscomp$52$$,
$from_pos$jscomp$14$$,$to_space_between_pos$jscomp$14$$))}),$select_shapes_with_malformed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($malformed_ids$$)],function(){var $JSCompiler_temp_const$jscomp$1600$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1602_param72190$jscomp$inline_8907$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$malformed_ids$$);$JSCompiler_inline_result$jscomp$1602_param72190$jscomp$inline_8907$$=$APP.$app$main$data$workspace$selection$select_shapes$$($JSCompiler_inline_result$jscomp$1602_param72190$jscomp$inline_8907$$);return $JSCompiler_temp_const$jscomp$1600$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1602_param72190$jscomp$inline_8907$$)}),$select_shapes_with_duplicated$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($duplicated_ids$jscomp$2$$)],
function(){var $JSCompiler_temp_const$jscomp$1603$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1605_param72190$jscomp$inline_8909$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$duplicated_ids$jscomp$2$$);$JSCompiler_inline_result$jscomp$1605_param72190$jscomp$inline_8909$$=$APP.$app$main$data$workspace$selection$select_shapes$$($JSCompiler_inline_result$jscomp$1605_param72190$jscomp$inline_8909$$);
return $JSCompiler_temp_const$jscomp$1603$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1605_param72190$jscomp$inline_8909$$)});return $APP.$cljs$core$seq$$($props_78778_shapes$jscomp$207$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-title",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($current_page_id$jscomp$4_open_QMARK_$jscomp$16$$),onCollapsed:$toggle_content$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component"),className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar",titleClass:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-title",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-type",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.main")})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.title"),onClick:$on_click_variant_title_help$jscomp$1$$,icon:"help"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($create_variant$jscomp$1$$,"workspace:button-design-tab-component"),icon:"variant"})]})}),$APP.$cljs$core$truth_$$($current_page_id$jscomp$4_open_QMARK_$jscomp$16$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__component-pill",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$,{icon:"component",text:$multi_QMARK_$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):$APP.$cljs$core$last$$($APP.$app$common$path_names$split_path$$($shape_name$jscomp$5$$)),disabled:!0,menuEntries:$menu_entries$jscomp$3_show_in_assets_panel$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($add_new_property$jscomp$1$$,"workspace:button-design-tab-component"),icon:"add"})]}),$multi_QMARK_$jscomp$1$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-list",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$166$$,$p__78797_property$jscomp$85$$){var $pos$jscomp$149$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78797_property$jscomp$85$$,0,null);$p__78797_property$jscomp$85$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78797_property$jscomp$85$$,1,null);$out_arr__44124__auto__$jscomp$166$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_property_STAR_$$,
{pos:$pos$jscomp$149$$,property:$p__78797_property$jscomp$85$$,isRemoveDisabled:$single_property_QMARK_$$,onRemove:$remove_property$$,onBlur:$update_property_name$jscomp$1$$,onReorder:$reorder_properties$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1000$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$149$$)].join("")));return $out_arr__44124__auto__$jscomp$166$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,
$properties$jscomp$108$$))})}),$libraries$jscomp$147_malformed_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.group.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$select_shapes_with_malformed$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.group.locate")})]}):$current_file_id$jscomp$19_duplicated_QMARK__variant_components$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.group.title")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$select_shapes_with_duplicated$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.group.locate")})]}):null]}):null]}):null};
$app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$=function($is_col_QMARK__map__78648_props_78647$$){$is_col_QMARK__map__78648_props_78647$$=$APP.$rumext$v2$util$wrap_props$$($is_col_QMARK__map__78648_props_78647$$);var $alignment__$1_map__78648__$1$$=$APP.$cljs$core$__destructure_map$$($is_col_QMARK__map__78648_props_78647$$);$is_col_QMARK__map__78648_props_78647$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alignment__$1_map__78648__$1$$,$cljs$cst$5692$is_col_QMARK_$$);
var $alignment$jscomp$1_type$jscomp$625$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alignment__$1_map__78648__$1$$,$APP.$cljs$cst$4891$alignment$$),$set_alignment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alignment__$1_map__78648__$1$$,$cljs$cst$5693$set_alignment$$);$alignment__$1_map__78648__$1$$=$APP.$cljs$core$truth_$$($alignment$jscomp$1_type$jscomp$625$$)?$alignment$jscomp$1_type$jscomp$625$$:$APP.$cljs$cst$1672$auto$$;$alignment$jscomp$1_type$jscomp$625$$=$APP.$cljs$core$truth_$$($is_col_QMARK__map__78648_props_78647$$)?
"col":"row";var $handle_set_alignment$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_alignment$$)],function($G__78649_value$jscomp$837$$){$G__78649_value$jscomp$837$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__78649_value$jscomp$837$$);return $set_alignment$$.$cljs$core$IFn$_invoke$arity$1$?$set_alignment$$.$cljs$core$IFn$_invoke$arity$1$($G__78649_value$jscomp$837$$):$set_alignment$$($G__78649_value$jscomp$837$$)});return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_grid_cell__self-align-menu",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($alignment__$1_map__78648__$1$$),"on-change":$handle_set_alignment$$,"allow-empty":!0,name:"flex-align-items-"+($alignment$jscomp$1_type$jscomp$625$$??""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__78648_props_78647$$)?
"align-self-row-left":"align-self-column-top",title:"Align self start",id:"align-self-start-"+($alignment$jscomp$1_type$jscomp$625$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__78648_props_78647$$)?"align-self-row-center":"align-self-column-center",title:"Align self center",id:"align-self-center-"+($alignment$jscomp$1_type$jscomp$625$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"end",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__78648_props_78647$$)?"align-self-row-right":"align-self-column-bottom",title:"Align self end",id:"align-self-end-"+($alignment$jscomp$1_type$jscomp$625$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"stretch",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__78648_props_78647$$)?"align-self-row-stretch":"align-self-column-stretch",title:"Align self stretch",id:"align-self-stretch-"+($alignment$jscomp$1_type$jscomp$625$$??
"")})]})})};
$app$main$ui$ds$controls$checkbox$checkbox_STAR_$$=function($props_78650_props__$1$jscomp$80$$){var $on_change$jscomp$56$$=void 0,$disabled$jscomp$17$$=void 0,$label$jscomp$42$$=void 0,$id$jscomp$966$$=void 0,$class$$jscomp$71$$=void 0,$checked$jscomp$1$$=void 0,$props$jscomp$333$$=void 0;({id:$id$jscomp$966$$,className:$class$$jscomp$71$$,label:$label$jscomp$42$$,checked:$checked$jscomp$1$$,onChange:$on_change$jscomp$56$$,disabled:$disabled$jscomp$17$$,...$props$jscomp$333$$}=$props_78650_props__$1$jscomp$80$$);$props_78650_props__$1$jscomp$80$$=
{...$props$jscomp$333$$,type:"checkbox",className:"main_ui_ds_controls_checkbox__checkbox-input",id:$id$jscomp$966$$,checked:$checked$jscomp$1$$,onChange:$on_change$jscomp$56$$,disabled:$disabled$jscomp$17$$};return(0,$APP.$rumext$v2$jsx$$)("div",{className:($class$$jscomp$71$$??"")+" main_ui_ds_controls_checkbox__checkbox",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$id$jscomp$966$$,className:"main_ui_ds_controls_checkbox__checkbox-label",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_checkbox__checkbox-box "+
($APP.$cljs$core$truth_$$($checked$jscomp$1$$)?"main_ui_ds_controls_checkbox__checked":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$17$$)?"main_ui_ds_controls_checkbox__disabled":""),children:$APP.$cljs$core$truth_$$($checked$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s"}):null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_checkbox__checkbox-text",children:$label$jscomp$42$$}),(0,$APP.$rumext$v2$create_element$$)("input",
$props_78650_props__$1$jscomp$80$$)]})})};
$app$main$ui$workspace$sidebar$options$menus$interactions$event_type_name$$=function($interaction$jscomp$50$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1939$click$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-on-click"),$APP.$cljs$cst$1938$mouse_enter$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-enter"),$APP.$cljs$cst$1936$mouse_leave$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-leave"),$APP.$cljs$cst$1935$after_delay$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-after-delay")],null),$APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$50$$),"--")};
$app$main$ui$workspace$sidebar$options$menus$interactions$action_summary$$=function($G__78705_interaction$jscomp$51$$,$destination$jscomp$13$$){$G__78705_interaction$jscomp$51$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__78705_interaction$jscomp$51$$);switch($G__78705_interaction$jscomp$51$$ instanceof $APP.$cljs$core$Keyword$$?$G__78705_interaction$jscomp$51$$.$fqn$:null){case "navigate":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-navigate-to-dest",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none"))]));case "open-overlay":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-open-overlay-dest",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,
$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none"))]));case "toggle-overlay":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-toggle-overlay-dest",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none"))]));
case "close-overlay":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-close-overlay-dest",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self"))]));case "prev-screen":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-prev-screen");
case "open-url":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-open-url");default:return"--"}};
$app$main$ui$workspace$sidebar$options$menus$interactions$get_frames_options$$=function($frames$jscomp$29$$,$shape$jscomp$1002$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($frame$jscomp$66$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$66$$)),$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$66$$)],
null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78706_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78706_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1002$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78706_SHARP_$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1002$$))},
$frames$jscomp$29$$))};
$app$main$ui$workspace$sidebar$options$menus$interactions$get_shared_frames_options$$=function($shared_frames$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($frame$jscomp$67$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$67$$)),$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$67$$)],null)},
$shared_frames$$)};
$app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$=function($left_button_tooltip_props_78707$$,$external_ref$jscomp$3_handle_focus$jscomp$4$$){var $on_change$jscomp$57$$=$left_button_tooltip_props_78707$$.onChange,$is_left_button_active$$=$left_button_tooltip_props_78707$$.isLeftButtonActive,$description$jscomp$17$$=$left_button_tooltip_props_78707$$.description,$is_right_button_active$$=$left_button_tooltip_props_78707$$.isRightButtonActive,$is_editable$$=$left_button_tooltip_props_78707$$.isEditable,
$right_button_icon_id$$=$left_button_tooltip_props_78707$$.rightButtonIconId,$on_right_button_click$$=$left_button_tooltip_props_78707$$.onRightButtonClick,$left_button_icon_id$$=$left_button_tooltip_props_78707$$.leftButtonIconId,$right_button_tooltip$$=$left_button_tooltip_props_78707$$.rightButtonTooltip,$title$jscomp$38$$=$left_button_tooltip_props_78707$$.title,$on_left_button_click$$=$left_button_tooltip_props_78707$$.onLeftButtonClick;$left_button_tooltip_props_78707$$=$left_button_tooltip_props_78707$$.leftButtonTooltip;
var $handle_key_down$jscomp$9_local_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(),$ref$jscomp$54$$=$APP.$cljs$core$truth_$$($external_ref$jscomp$3_handle_focus$jscomp$4$$)?$external_ref$jscomp$3_handle_focus$jscomp$4$$:$handle_key_down$jscomp$9_local_ref$jscomp$4$$;$external_ref$jscomp$3_handle_focus$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($ref$jscomp$54$$))});$handle_key_down$jscomp$9_local_ref$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_inline_result$jscomp$1826_event$jscomp$516$$){var $input_node$jscomp$9$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$54$$),$value$jscomp$842$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($JSCompiler_inline_result$jscomp$1826_event$jscomp$516$$))),$or__5025__auto__$jscomp$inline_8913$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($JSCompiler_inline_result$jscomp$1826_event$jscomp$516$$);
$JSCompiler_inline_result$jscomp$1826_event$jscomp$516$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8913$$)?$or__5025__auto__$jscomp$inline_8913$$:(0,$APP.$app$util$keyboard$enter_QMARK_$$)($JSCompiler_inline_result$jscomp$1826_event$jscomp$516$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1826_event$jscomp$516$$)?($APP.$app$util$dom$blur_BANG_$$($input_node$jscomp$9$$),$on_change$jscomp$57$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$57$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$842$$):
$on_change$jscomp$57$$($value$jscomp$842$$)):null});var $handle_blur$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$517_value$jscomp$843$$){$event$jscomp$517_value$jscomp$843$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$517_value$jscomp$843$$)));return $on_change$jscomp$57$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$57$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$517_value$jscomp$843$$):
$on_change$jscomp$57$$($event$jscomp$517_value$jscomp$843$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill "+($description$jscomp$17$$!=null?"main_ui_workspace_sidebar_options_menus_interactions__double":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button main_ui_workspace_sidebar_options_menus_interactions__left",
"aria-pressed":$is_left_button_active$$,icon:$left_button_icon_id$$,"aria-label":$left_button_tooltip_props_78707$$,onClick:$on_left_button_click$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-main",children:[$APP.$cljs$core$truth_$$($is_editable$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$ref$jscomp$54$$,defaultValue:$title$jscomp$38$$,onFocus:$external_ref$jscomp$3_handle_focus$jscomp$4$$,onKeyDown:$handle_key_down$jscomp$9_local_ref$jscomp$4$$,
onBlur:$handle_blur$jscomp$6$$,className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input"}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-center",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-info",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-name",children:$title$jscomp$38$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-description",children:$description$jscomp$17$$})]})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button main_ui_workspace_sidebar_options_menus_interactions__right","aria-pressed":$is_right_button_active$$,icon:$right_button_icon_id$$,"aria-label":$right_button_tooltip$$,
onClick:$on_right_button_click$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$=function($props_78708_start_flow$$){var $flow$jscomp$8$$=$props_78708_start_flow$$.flow;$props_78708_start_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($flow$jscomp$8$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1366$section$$,"interactions",$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$8$$)],null)])))});var $rename_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($flow$jscomp$8$$)],function($value$jscomp$844$$){return $APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$844$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$rename_flow$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$8$$),
$value$jscomp$844$$))}),$remove_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($flow$jscomp$8$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$8$$)))});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$,
{onChange:$rename_flow$$,leftButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.flow-start"),leftButtonIconId:"play",onRightButtonClick:$remove_flow$$,onLeftButtonClick:$props_78708_start_flow$$,rightButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.remove"),isEditable:!0,rightButtonIconId:"remove",title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($flow$jscomp$8$$,"")})};
$app$main$ui$workspace$sidebar$options$menus$interactions$interaction_item_STAR_$$=function($destination$jscomp$14_props_78728$$){var $update_interaction$$=$destination$jscomp$14_props_78728$$.updateInteraction,$index$jscomp$485$$=$destination$jscomp$14_props_78728$$.index,$interaction$jscomp$52$$=$destination$jscomp$14_props_78728$$.interaction,$remove_interaction$$=$destination$jscomp$14_props_78728$$.removeInteraction,$shape$jscomp$1003$$=$destination$jscomp$14_props_78728$$.shape,$objects$jscomp$791$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);$destination$jscomp$14_props_78728$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$791$$,$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$));var $frames$jscomp$30$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$791$$)],function(){return $APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$791$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2088$all_frames_QMARK_$$,!0],null))}),$shape_parent_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$791$$)],function(){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$791$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$))}),$relative_to_opts_shape_parents$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frames$jscomp$30$$),
$APP.$rumext$v2$adapt$$($shape$jscomp$1003$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($shape_parent_ids$$),$APP.$cljs$cst$266$id$$),$frames$jscomp$30$$)}),$overlay_pos_type$jscomp$4$$=$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$close_click_outside_QMARK_$$=$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$52$$,
!1),$background_overlay_QMARK_$$=$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$52$$,!1),$preserve_scroll_QMARK_$$=$APP.$cljs$cst$1968$preserve_scroll$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$52$$,!1),$way$jscomp$1$$=$APP.$cljs$cst$1962$way$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),$direction$jscomp$26$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),
$open_extended_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$open_extended_QMARK_$$=$APP.$cljs$core$_deref$$($open_extended_STAR_$$),$ext_delay_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ext_duration_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$toggle_extended$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_extended_STAR_$$,$APP.$cljs$core$not$$)}),$change_event_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$518$$){function $G__78735$$($JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$){a:if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$),$value$jscomp$845$$))switch($value$jscomp$845$$ instanceof $APP.$cljs$core$Keyword$$?$value$jscomp$845$$.$fqn$:null){case "after-delay":$JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$,$APP.$cljs$cst$1557$event_type$$,$value$jscomp$845$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1325$delay$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$,$APP.$cljs$cst$1325$delay$$,600)]));break a;default:$JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$,
$APP.$cljs$cst$1557$event_type$$,$value$jscomp$845$$)}return $JSCompiler_inline_result$jscomp$1517_p1__78709_SHARP_$$}var $value$jscomp$845$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$518$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78735$$):$update_interaction$$($index$jscomp$485$$,$G__78735$$)}),$change_action_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$519$$){function $G__78737$$($p1__78710_SHARP_$$){return $app$common$types$shape$interactions$set_action_type$$($p1__78710_SHARP_$$,$value$jscomp$846$$)}var $value$jscomp$846$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$519$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78737$$):$update_interaction$$($index$jscomp$485$$,
$G__78737$$)}),$change_delay$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($value$jscomp$847$$){function $G__78739$$($p1__78711_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78711_SHARP_$$,$APP.$cljs$cst$1325$delay$$,$value$jscomp$847$$)}return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,
$G__78739$$):$update_interaction$$($index$jscomp$485$$,$G__78739$$)}),$change_destination$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$520$$){function $G__78741$$($p1__78712_SHARP_$$){return $app$common$types$shape$interactions$set_destination$$($p1__78712_SHARP_$$,$value__$1$jscomp$51$$)}var $value__$1$jscomp$51$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$520$$,
"")?$APP.$app$common$uuid$parse$$($event$jscomp$520$$):null;return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78741$$):$update_interaction$$($index$jscomp$485$$,$G__78741$$)}),$change_position_relative_to$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$521$$){function $G__78743$$($p1__78713_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78713_SHARP_$$,
$APP.$cljs$cst$1974$position_relative_to$$,$value$jscomp$849$$)}var $value$jscomp$849$$=$APP.$app$common$uuid$parse_STAR_$$($event$jscomp$521$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78743$$):$update_interaction$$($index$jscomp$485$$,$G__78743$$)}),$change_preserve_scroll$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],
function($event$jscomp$522$$){function $G__78745$$($p1__78714_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78714_SHARP_$$,$APP.$cljs$cst$1968$preserve_scroll$$,$value$jscomp$850$$)}var $value$jscomp$850$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$522$$));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78745$$):$update_interaction$$($index$jscomp$485$$,
$G__78745$$)}),$change_url$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($G__78756_event$jscomp$523_target$jscomp$152$$){$G__78756_event$jscomp$523_target$jscomp$152$$=$APP.$app$util$dom$get_target$$($G__78756_event$jscomp$523_target$jscomp$152$$);var $value$jscomp$851$$=$APP.$app$util$dom$get_value$$($G__78756_event$jscomp$523_target$jscomp$152$$),$has_prefix_QMARK_$$=$APP.$cuerdas$core$starts_with_QMARK_$$($value$jscomp$851$$,
"http://")||$APP.$cuerdas$core$starts_with_QMARK_$$($value$jscomp$851$$,"https://"),$value__$1$jscomp$52$$=$has_prefix_QMARK_$$?$value$jscomp$851$$:["http://",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$851$$)].join("");$has_prefix_QMARK_$$||$app$util$dom$set_value_BANG_$$($G__78756_event$jscomp$523_target$jscomp$152$$,$value__$1$jscomp$52$$);return $APP.$cljs$core$truth_$$($app$util$dom$valid_QMARK_$$($G__78756_event$jscomp$523_target$jscomp$152$$))?($G__78756_event$jscomp$523_target$jscomp$152$$!=
null&&$G__78756_event$jscomp$523_target$jscomp$152$$.classList.remove("error"),$G__78756_event$jscomp$523_target$jscomp$152$$=function($p1__78715_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78715_SHARP_$$,$APP.$cljs$cst$1975$url$$,$value__$1$jscomp$52$$)},$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78756_event$jscomp$523_target$jscomp$152$$):$update_interaction$$($index$jscomp$485$$,
$G__78756_event$jscomp$523_target$jscomp$152$$)):$APP.$app$util$dom$add_class_BANG_$$($G__78756_event$jscomp$523_target$jscomp$152$$,"error")}),$change_overlay_pos_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1003$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($value$jscomp$852$$){function $G__78759_78875$$($p1__78716_SHARP_$$){var $JSCompiler_temp_const$jscomp$inline_13544$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;
var $G__49026$jscomp$inline_13546_JSCompiler_inline_result$jscomp$inline_13545$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__78716_SHARP_$$);$G__49026$jscomp$inline_13546_JSCompiler_inline_result$jscomp$inline_13545$$=$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$($G__49026$jscomp$inline_13546_JSCompiler_inline_result$jscomp$inline_13545$$,
$shape$jscomp$1003$$,$objects$jscomp$791$$,$value$jscomp$852$$):$app$common$types$shape$interactions$calc_overlay_pos_initial$$($G__49026$jscomp$inline_13546_JSCompiler_inline_result$jscomp$inline_13545$$,$shape$jscomp$1003$$,$objects$jscomp$791$$,$value$jscomp$852$$);return $JSCompiler_temp_const$jscomp$inline_13544$$.call($APP.$cljs$core$assoc$$,$p1__78716_SHARP_$$,$APP.$cljs$cst$1971$overlay_pos_type$$,$value$jscomp$852$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1970$overlay_position$$,
$G__49026$jscomp$inline_13546_JSCompiler_inline_result$jscomp$inline_13545$$]))}var $shape_id$jscomp$160$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$);$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78759_78875$$):$update_interaction$$($index$jscomp$485$$,$G__78759_78875$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$852$$,$APP.$cljs$cst$1673$manual$$)){var $G__78761$$=
function($p1__78717_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78717_SHARP_$$,$APP.$cljs$cst$1974$position_relative_to$$,$shape_id$jscomp$160$$)};return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78761$$):$update_interaction$$($index$jscomp$485$$,$G__78761$$)}return null}),$toggle_overlay_pos_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$524$$){function $G__78766$$($p1__78718_SHARP_$$){var $new_pos_type$jscomp$inline_13552$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78718_SHARP_$$),$pos_type$$)?$APP.$cljs$cst$1673$manual$$:$pos_type$$,$JSCompiler_temp_const$jscomp$inline_13553$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $G__49030$jscomp$inline_13555_JSCompiler_inline_result$jscomp$inline_13554$$=
$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__78718_SHARP_$$);$G__49030$jscomp$inline_13555_JSCompiler_inline_result$jscomp$inline_13554$$=$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$($G__49030$jscomp$inline_13555_JSCompiler_inline_result$jscomp$inline_13554$$,$shape$jscomp$1003$$,$objects$jscomp$791$$,$new_pos_type$jscomp$inline_13552$$):
$app$common$types$shape$interactions$calc_overlay_pos_initial$$($G__49030$jscomp$inline_13555_JSCompiler_inline_result$jscomp$inline_13554$$,$shape$jscomp$1003$$,$objects$jscomp$791$$,$new_pos_type$jscomp$inline_13552$$);return $JSCompiler_temp_const$jscomp$inline_13553$$.call($APP.$cljs$core$assoc$$,$p1__78718_SHARP_$$,$APP.$cljs$cst$1971$overlay_pos_type$$,$new_pos_type$jscomp$inline_13552$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1970$overlay_position$$,$G__49030$jscomp$inline_13555_JSCompiler_inline_result$jscomp$inline_13554$$]))}
var $pos_type$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$524$$),"value"));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78766$$):$update_interaction$$($index$jscomp$485$$,$G__78766$$)}),$change_close_click_outside$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$525$$){function $G__78768$$($p1__78719_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78719_SHARP_$$,$APP.$cljs$cst$1972$close_click_outside$$,$value$jscomp$853$$)}var $value$jscomp$853$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$525$$));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,
$G__78768$$):$update_interaction$$($index$jscomp$485$$,$G__78768$$)}),$change_background_overlay$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$526$$){function $G__78770$$($p1__78720_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78720_SHARP_$$,$APP.$cljs$cst$1973$background_overlay$$,$value$jscomp$854$$)}var $value$jscomp$854$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$526$$));
return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78770$$):$update_interaction$$($index$jscomp$485$$,$G__78770$$)}),$change_animation_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$527$$){function $G__78782$$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$){if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$)),
$value$jscomp$855$$))if($value$jscomp$855$$==null)$JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,$APP.$cljs$cst$1969$animation$$);else{var $G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,$APP.$cljs$cst$1969$animation$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1959$animation_type$$,$value$jscomp$855$$);$G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$855$$,$APP.$cljs$cst$1957$dissolve$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$,$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1960$duration$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1960$duration$$],null),300),$APP.$cljs$cst$1961$easing$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1961$easing$$],null),$APP.$cljs$cst$287$linear$$)])):$G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$;$G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$855$$,$APP.$cljs$cst$1958$slide$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$,
$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1960$duration$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1960$duration$$],null),300),$APP.$cljs$cst$1961$easing$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1961$easing$$],null),$APP.$cljs$cst$287$linear$$),$APP.$cljs$cst$1962$way$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1962$way$$],null),$APP.$cljs$cst$297$in$$),
$APP.$cljs$cst$1963$direction$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1963$direction$$],null),$APP.$cljs$cst$258$right$$),$APP.$cljs$cst$1964$offset_effect$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1964$offset_effect$$],null),!1)])):$G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$;$JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$855$$,$APP.$cljs$cst$1956$push$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$,
$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1960$duration$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1960$duration$$],null),300),$APP.$cljs$cst$1961$easing$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1961$easing$$],null),$APP.$cljs$cst$287$linear$$),$APP.$cljs$cst$1963$direction$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,$APP.$cljs$cst$1963$direction$$],null),
$APP.$cljs$cst$258$right$$)])):$G__49095__$1$jscomp$inline_8920_G__49095__$2$jscomp$inline_8921_G__49095__$3$jscomp$inline_8922$$}return $JSCompiler_inline_result$jscomp$1518_p1__78721_SHARP_$$}var $value$jscomp$855$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$event$jscomp$527$$)?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$527$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,
$G__78782$$):$update_interaction$$($index$jscomp$485$$,$G__78782$$)}),$change_duration$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($value$jscomp$856$$){function $G__78784$$($p1__78722_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__78722_SHARP_$$,$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1960$duration$$,$value$jscomp$856$$)}
return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78784$$):$update_interaction$$($index$jscomp$485$$,$G__78784$$)}),$change_easing$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$528$$){function $G__78786$$($p1__78723_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__78723_SHARP_$$,
$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1961$easing$$,$value$jscomp$857$$)}var $value$jscomp$857$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$528$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78786$$):$update_interaction$$($index$jscomp$485$$,$G__78786$$)}),$change_way$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$529$$){function $G__78788$$($p1__78724_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__78724_SHARP_$$,$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1962$way$$,$value$jscomp$858$$)}var $value$jscomp$858$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$529$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,
$G__78788$$):$update_interaction$$($index$jscomp$485$$,$G__78788$$)}),$change_direction$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$530$$){function $G__78790$$($p1__78725_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__78725_SHARP_$$,$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1963$direction$$,$value$jscomp$859$$)}
var $value$jscomp$859$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$530$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78790$$):$update_interaction$$($index$jscomp$485$$,$G__78790$$)}),$change_offset_effect$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$485$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$531$$){function $G__78792$$($p1__78726_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__78726_SHARP_$$,
$APP.$cljs$cst$1969$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1964$offset_effect$$,$value$jscomp$860$$)}var $value$jscomp$860$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$531$$));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$485$$,$G__78792$$):$update_interaction$$($index$jscomp$485$$,$G__78792$$)}),$event_type_options$$=function(){var $G__78794$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1939$click$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-on-click")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1938$mouse_enter$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-enter")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1936$mouse_leave$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-leave")],null)],null);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78794$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1935$after_delay$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-after-delay")],null)):$G__78794$$}(),$action_type_options$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1941$navigate$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-navigate-to")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1946$open_overlay$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-open-overlay")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1944$toggle_overlay$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-toggle-overlay")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1942$close_overlay$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-close-overlay")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1943$prev_screen$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-prev-screen")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1945$open_url$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-open-url")],null)],null),$frames_opts$$=$app$main$ui$workspace$sidebar$options$menus$interactions$get_frames_options$$($frames$jscomp$30$$,$shape$jscomp$1003$$),$default_opts$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),
$APP.$cljs$cst$1942$close_overlay$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self")],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none")],null)],null),$destination_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frames_opts$$),
$APP.$rumext$v2$adapt$$($default_opts$$)],function(){var $sorted_frames_opts$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2287$label$$,$frames_opts$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($default_opts$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$sorted_frames_opts$$]))}),$shape_parents_opts$$=$app$main$ui$workspace$sidebar$options$menus$interactions$get_shared_frames_options$$($relative_to_opts_shape_parents$jscomp$1$$);
$relative_to_opts_shape_parents$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_parents_opts$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$APP.$cljs$cst$1673$manual$$)?$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-auto")],null)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape_parents_opts$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$)),
$APP.$cljs$cst$2287$label$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self")),")"].join("")],null)],null)])):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$)),$APP.$cljs$cst$2287$label$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1003$$))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self")),")"].join("")],null)],null)});var $overlay_position_opts$$=
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-manual")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-center")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1883$top_left$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1884$top_right$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-right")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1947$top_center$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1886$bottom_left$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1885$bottom_right$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-right")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1948$bottom_center$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-center")],null)],null),$basic_animation_opts$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-none")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1957$dissolve$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-dissolve")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1958$slide$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-slide")],null)],null),$animation_opts$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($basic_animation_opts$$)],function(){var $action_type$jscomp$inline_8924$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1941$navigate$$,$action_type$jscomp$inline_8924$$)?$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($basic_animation_opts$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1956$push$$,$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-push")],null)],null)])):$basic_animation_opts$$}),$easing_options$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1721$icon$$,$cljs$cst$5694$easing_linear$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$287$linear$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-linear")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1721$icon$$,$cljs$cst$5695$easing_ease$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1951$ease$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1721$icon$$,$cljs$cst$5696$easing_ease_in$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1950$ease_in$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease-in")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1721$icon$$,$cljs$cst$5697$easing_ease_out$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1952$ease_out$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease-out")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1721$icon$$,$cljs$cst$5698$easing_ease_in_out$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1949$ease_in_out$$,$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease-in-out")],null)],null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-item",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$,{isLeftButtonActive:$open_extended_QMARK_$$,leftButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),leftButtonIconId:"hsva",
onRightButtonClick:function(){return $remove_interaction$$.$cljs$core$IFn$_invoke$arity$1$?$remove_interaction$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$485$$):$remove_interaction$$($index$jscomp$485$$)},onLeftButtonClick:$toggle_extended$$,rightButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.remove"),rightButtonIconId:"remove",title:$app$main$ui$workspace$sidebar$options$menus$interactions$event_type_name$$($interaction$jscomp$52$$),description:$app$main$ui$workspace$sidebar$options$menus$interactions$action_summary$$($interaction$jscomp$52$$,
$destination$jscomp$14_props_78728$$)}),$APP.$cljs$core$truth_$$($open_extended_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("label",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-trigger")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),options:$event_type_options$$,"on-change":$change_event_type$$})})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),
$APP.$cljs$cst$1935$after_delay$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-delay")})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,{ref:$ext_delay_ref$$,icon:"character-m",property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-ms"),onChange:$change_delay$$,value:$APP.$cljs$cst$1325$delay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)})})]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-action")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),options:$action_type_options$$,"on-change":$change_action_type$$})})]}),$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$interactions$has_destination$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-destination")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),options:$destination_options$$,"on-change":$change_destination$$})})]}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$APP.$cljs$cst$1941$navigate$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["preserve-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$485$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-preserve-scroll"),checked:$preserve_scroll_QMARK_$$,onChange:$change_preserve_scroll$$})})}):
null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$APP.$cljs$cst$1945$open_url$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-url")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"url",placeholder:"http://example.com",defaultValue:$APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),onBlur:$change_url$$})})]}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_overlay_opts$$($interaction$jscomp$52$$))?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-position")})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),options:$overlay_position_opts$$,"on-change":$change_overlay_pos_type$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-relative-to")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1974$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),options:$relative_to_opts_shape_parents$jscomp$1$$,"on-change":$change_position_relative_to$$})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__center",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1667$center$$),"data-value":"center",icon:"corner-center","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-center"),
onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__top-left",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1883$top_left$$),"data-value":"top-left",icon:"corner-top-left","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-left"),
onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__top-right",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1884$top_right$$),"data-value":"top-right",icon:"corner-top-right","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-right"),
onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__top-center",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1947$top_center$$),"data-value":"top-center",icon:"corner-top","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-center"),
onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__bottom-left",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1886$bottom_left$$),"data-value":"bottom-left",icon:"corner-bottom-left","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-left"),
onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__bottom-right",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1885$bottom_right$$),"data-value":"bottom-right",icon:"corner-bottom-right","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-right"),
onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__bottom-center",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1948$bottom_center$$),"data-value":"bottom-center",icon:"corner-bottom","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-center"),
onClick:$toggle_overlay_pos_type$$})})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["close-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$485$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-close-outside"),
checked:$close_click_outside_QMARK_$$,onChange:$change_close_click_outside$$})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["background-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$485$$)].join(""),
label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-background"),checked:$background_overlay_QMARK_$$,onChange:$change_background_overlay$$})})})]}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_animation_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"class":"main_ui_workspace_sidebar_options_menus_interactions__animation-select","default-value":function(){var $or__5025__auto__$jscomp$1192$$=$APP.$cljs$cst$1959$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1192$$)?$or__5025__auto__$jscomp$1192$$:""}(),options:$animation_opts$$,"on-change":$change_animation_type$$})})]}),$app$common$types$shape$interactions$has_way_QMARK_$$($interaction$jscomp$52$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-radio",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($way$jscomp$1$$),"on-change":$change_way$$,name:"animation-way",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"in",id:"animation-way-in"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{id:"animation-way-out",value:"out"})]})})}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_direction_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-radio",
children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($direction$jscomp$26$$),"on-change":$change_direction$$,name:"animation-direction",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"row","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__right",value:"right",id:"animation-right"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{icon:"row-reverse","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__left",id:"animation-left",value:"left"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"column","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__down",id:"animation-down",value:"down"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"column-reverse","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__up",
id:"animation-up",value:"up"})]})})}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_duration_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-duration")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,{ref:$ext_duration_ref$$,icon:"character-m",property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-ms"),onChange:$change_duration$$,
value:$APP.$cljs$cst$1960$duration$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$))})})]}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_easing_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_interactions__easing-select",
"dropdown-class":"main_ui_workspace_sidebar_options_menus_interactions__dropdown-upwards","default-value":$APP.$cljs$cst$1961$easing$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),options:$easing_options$$,"on-change":$change_easing$$})})]}):null,$app$common$types$shape$interactions$has_offset_effect_QMARK_$$($interaction$jscomp$52$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["offset-effect-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$485$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-offset-effect"),checked:$APP.$cljs$cst$1964$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),
onChange:$change_offset_effect$$})})}):null]}):null]}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$page_flows_STAR_$$=function($flows$jscomp$9_props_78807$$){$flows$jscomp$9_props_78807$$=$flows$jscomp$9_props_78807$$.flows;var $show_content_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$show_content_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_content_STAR_$$),$toggle_content$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$$,$APP.$cljs$core$not$$)});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$APP.$cljs$core$count$$($flows$jscomp$9_props_78807$$)>0,collapsed:$APP.$cljs$core$not$$($show_content_QMARK_$jscomp$1$$),onCollapsed:$toggle_content$jscomp$2$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.flow-starts"),
className:"main_ui_workspace_sidebar_options_menus_interactions__title-bar"})}),$APP.$cljs$core$truth_$$($show_content_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$167$$,$flow$jscomp$9_p__78810$$){var $id$jscomp$967$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flow$jscomp$9_p__78810$$,0,null);$flow$jscomp$9_p__78810$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flow$jscomp$9_p__78810$$,1,null);$out_arr__44124__auto__$jscomp$167$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$,{flow:$flow$jscomp$9_p__78810$$},$id$jscomp$967$$));return $out_arr__44124__auto__$jscomp$167$$},[],$flows$jscomp$9_props_78807$$)}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$shape_flows_STAR_$$=function($props_78815_show_content_QMARK_$jscomp$2$$){var $flow$jscomp$10_flows$jscomp$10$$=$props_78815_show_content_QMARK_$jscomp$2$$.flows,$shape$jscomp$1004_toggle_content$jscomp$3$$=$props_78815_show_content_QMARK_$jscomp$2$$.shape,$show_content_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$props_78815_show_content_QMARK_$jscomp$2$$=$APP.$cljs$core$_deref$$($show_content_STAR_$jscomp$1$$);
$flow$jscomp$10_flows$jscomp$10$$=$APP.$app$common$types$page$get_frame_flow$$($flow$jscomp$10_flows$jscomp$10$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1004_toggle_content$jscomp$3$$));$shape$jscomp$1004_toggle_content$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$jscomp$1$$,$APP.$cljs$core$not$$)});var $add_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$add_flow_selected_frame$$())});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$flow$jscomp$10_flows$jscomp$10$$!=null,collapsed:$APP.$cljs$core$not$$($props_78815_show_content_QMARK_$jscomp$2$$),onCollapsed:$shape$jscomp$1004_toggle_content$jscomp$3$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.flow"),className:"main_ui_workspace_sidebar_options_menus_interactions__title-bar",children:$flow$jscomp$10_flows$jscomp$10$$==null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.add-flow-start"),onClick:$add_flow$$,icon:"add"}):null})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_78815_show_content_QMARK_$jscomp$2$$)?
$flow$jscomp$10_flows$jscomp$10$$!=null:$props_78815_show_content_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$,{flow:$flow$jscomp$10_flows$jscomp$10$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$10_flows$jscomp$10$$))}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_STAR_$$=function($props_78820_show_content_QMARK_$jscomp$3$$){var $interactions$jscomp$22$$=$props_78820_show_content_QMARK_$jscomp$3$$.interactions,$shape$jscomp$1005$$=$props_78820_show_content_QMARK_$jscomp$3$$.shape,$show_content_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$props_78820_show_content_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($show_content_STAR_$jscomp$2$$);var $toggle_content$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$jscomp$2$$,$APP.$cljs$core$not$$)}),$add_interaction$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1005$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1005$$,
null))}),$remove_interaction$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1005$$)],function($index$jscomp$486$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$1005$$,$index$jscomp$486$$))}),$update_interaction$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1005$$)],
function($index$jscomp$487$$,$update_fn$jscomp$49$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($shape$jscomp$1005$$,$index$jscomp$487$$,$update_fn$jscomp$49$$,null))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__title",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$APP.$cljs$core$count$$($interactions$jscomp$22$$)>0,collapsed:$APP.$cljs$core$not$$($props_78820_show_content_QMARK_$jscomp$3$$),onCollapsed:$toggle_content$jscomp$4$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interactions"),className:"main_ui_workspace_sidebar_options_menus_interactions__title-bar",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interactions.add-interaction"),onClick:$add_interaction$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($props_78820_show_content_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content main_ui_workspace_sidebar_options_menus_interactions__content-interactions",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$168$$,
$interaction$jscomp$53_p__78827$$){var $index$jscomp$488$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($interaction$jscomp$53_p__78827$$,0,null);$interaction$jscomp$53_p__78827$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($interaction$jscomp$53_p__78827$$,1,null);$out_arr__44124__auto__$jscomp$168$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$interaction_item_STAR_$$,{index:$index$jscomp$488$$,shape:$shape$jscomp$1005$$,interaction:$interaction$jscomp$53_p__78827$$,
updateInteraction:$update_interaction$jscomp$1$$,removeInteraction:$remove_interaction$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1005$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$488$$)].join("")));return $out_arr__44124__auto__$jscomp$168$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($interactions$jscomp$22$$))}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_menu_STAR_$$=function($props_78831_shape$jscomp$1006$$){$props_78831_shape$jscomp$1006$$=$props_78831_shape$jscomp$1006$$.shape;var $interactions$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($props_78831_shape$jscomp$1006$$,$APP.$cljs$cst$2051$interactions$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$flows$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_flows$$),$framed_shape_QMARK_$$=
$APP.$cljs$core$truth_$$($props_78831_shape$jscomp$1006$$)?!$app$common$files$helpers$unframed_shape_QMARK_$$($props_78831_shape$jscomp$1006$$):$props_78831_shape$jscomp$1006$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__wrapper",children:[$APP.$cljs$core$truth_$$($props_78831_shape$jscomp$1006$$)?$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($props_78831_shape$jscomp$1006$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$shape_flows_STAR_$$,
{flows:$flows$jscomp$11$$,shape:$props_78831_shape$jscomp$1006$$}):null:$APP.$cljs$core$truth_$$($flows$jscomp$11$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$page_flows_STAR_$$,{flows:$flows$jscomp$11$$}):null,$APP.$cljs$core$truth_$$($framed_shape_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$interactions_STAR_$$,{interactions:$interactions$jscomp$23$$,shape:$props_78831_shape$jscomp$1006$$}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($interactions$jscomp$23$$),
0)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__empty",children:[$APP.$cljs$core$truth_$$($framed_shape_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"add",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.add-interaction")}):
null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"interaction",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.select-a-shape")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"play",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.use-play-button")})]})})}):null]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$=function($G__78733__$1_val$jscomp$209$$){$G__78733__$1_val$jscomp$209$$=$G__78733__$1_val$jscomp$209$$ instanceof $APP.$cljs$core$Keyword$$?$G__78733__$1_val$jscomp$209$$.$fqn$:null;switch($G__78733__$1_val$jscomp$209$$){case "row":return"grid-row";case "row-reverse":return"row-reverse";case "column":return"column";case "column-reverse":return"column-reverse";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78733__$1_val$jscomp$209$$)].join(""));
}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$=function($G__78746__$1_type$jscomp$627$$,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$,$column_QMARK_$$){$G__78746__$1_type$jscomp$627$$=$G__78746__$1_type$jscomp$627$$ instanceof $APP.$cljs$core$Keyword$$?$G__78746__$1_type$jscomp$627$$.$fqn$:null;switch($G__78746__$1_type$jscomp$627$$){case "align-items":if($column_QMARK_$$)switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "start":return"align-items-column-start";case "end":return"align-items-column-end";case "center":return"align-items-column-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));
}else switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof $APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "start":return"align-items-row-start";
case "end":return"align-items-row-end";case "center":return"align-items-row-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));}break;case "justify-content":if($column_QMARK_$$)switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "start":return"justify-content-column-start";case "end":return"justify-content-column-end";case "center":return"justify-content-column-center";case "space-around":return"justify-content-column-around";case "space-evenly":return"justify-content-column-evenly";
case "space-between":return"justify-content-column-between";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));}else switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "start":return"justify-content-row-start";case "end":return"justify-content-row-end";case "center":return"justify-content-row-center";case "space-around":return"justify-content-row-around";case "space-evenly":return"justify-content-row-evenly";
case "space-between":return"justify-content-row-between";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));}break;case "align-content":if($column_QMARK_$$)switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "start":return"align-content-column-start";case "end":return"align-content-column-end";case "center":return"align-content-column-center";case "space-around":return"align-content-column-around";case "space-evenly":return"align-content-column-evenly";
case "space-between":return"align-content-column-between";case "stretch":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));}else switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "start":return"align-content-row-start";case "end":return"align-content-row-end";case "center":return"align-content-row-center";case "space-around":return"align-content-row-around";case "space-evenly":return"align-content-row-evenly";
case "space-between":return"align-content-row-between";case "stretch":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));}break;case "align-self":if($column_QMARK_$$)switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "auto":return"remove";case "start":return"align-self-row-left";case "end":return"align-self-row-right";case "center":return"align-self-row-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));
}else switch($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$=$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$ instanceof $APP.$cljs$core$Keyword$$?$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$.$fqn$:null,$G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$){case "auto":return"remove";
case "start":return"align-self-column-top";case "end":return"align-self-column-bottom";case "center":return"align-self-column-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78747__$1_G__78748__$1_G__78749__$1_G__78750__$1_G__78751__$1_G__78752__$1_G__78753__$1_G__78754__$1_val$jscomp$210$$)].join(""));}break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78746__$1_type$jscomp$627$$)].join(""));
}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$=function($G__78772__$1_type$jscomp$628$$,$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$,$column_QMARK_$jscomp$1$$){$G__78772__$1_type$jscomp$628$$=$G__78772__$1_type$jscomp$628$$ instanceof $APP.$cljs$core$Keyword$$?$G__78772__$1_type$jscomp$628$$.$fqn$:null;switch($G__78772__$1_type$jscomp$628$$){case "align-items":if($column_QMARK_$jscomp$1$$)switch($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$=$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$.$fqn$:null,$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$){case "auto":return"remove";case "start":return"align-self-row-left";case "end":return"align-self-row-right";case "center":return"align-self-row-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$)].join(""));
}else switch($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$=$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$ instanceof $APP.$cljs$core$Keyword$$?$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$.$fqn$:null,$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$){case "auto":return"remove";case "start":return"align-self-column-top";case "end":return"align-self-column-bottom";case "center":return"align-self-column-center";
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$)].join(""));}break;case "justify-items":if($column_QMARK_$jscomp$1$$)switch($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$=$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$ instanceof $APP.$cljs$core$Keyword$$?$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$.$fqn$:null,
$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$){case "start":return"align-content-row-start";case "center":return"align-content-row-center";case "end":return"align-content-row-end";case "space-around":return"align-content-row-around";case "space-between":return"align-content-row-between";case "stretch":return"align-content-row-stretch";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$)].join(""));
}else switch($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$=$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$ instanceof $APP.$cljs$core$Keyword$$?$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$.$fqn$:null,$G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$){case "start":return"align-content-column-start";case "center":return"align-content-column-center";case "end":return"align-content-column-end";case "space-around":return"align-content-column-around";
case "space-between":return"align-content-column-between";case "stretch":return"align-content-column-stretch";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78774__$1_G__78775__$1_G__78776__$1_G__78777__$1_val$jscomp$211$$)].join(""));}break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78772__$1_type$jscomp$628$$)].join(""));}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_flex$$=function($props_78779$$){var $on_change$jscomp$58$$=$props_78779$$["on-change"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__direction-row-flex",selected:$APP.$app$common$data$name$$($props_78779$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$58$$,name:"flex-direction",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"row",id:"flex-direction-row",title:"Row",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1656$row$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"row-reverse",id:"flex-direction-row-reverse",title:"Row reverse",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1661$row_reverse$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"column",id:"flex-direction-column",title:"Column",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$216$column$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"column-reverse",id:"flex-direction-column-reverse",title:"Column reverse",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1662$column_reverse$$)})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$wrap_row$$=function($props_78780_wrap_type$jscomp$2$$){var $on_click$jscomp$46$$=$props_78780_wrap_type$jscomp$2$$["on-click"];$props_78780_wrap_type$jscomp$2$$=$props_78780_wrap_type$jscomp$2$$["wrap-type"];return(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$896$wrap$$,$props_78780_wrap_type$jscomp$2$$)?"No wrap":"Wrap",onClick:$on_click$jscomp$46$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__wrap-button "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_78780_wrap_type$jscomp$2$$,$APP.$cljs$cst$896$wrap$$)?"main_ui_workspace_sidebar_options_menus_layout_container__selected":""),children:$APP.$app$main$ui$icons$wrap$$})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$align_row$$=function($props_78793$$){var $on_change$jscomp$59$$=$props_78793$$["on-change"],$is_column$$=$props_78793$$["is-column"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__align-row",selected:$APP.$app$common$data$name$$($props_78793$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$59$$,name:"flex-align-items",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$1292$start$$,$is_column$$),title:"Align items start",id:"align-items-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4086$align_items$$,
$APP.$cljs$cst$1667$center$$,$is_column$$),title:"Align items center",id:"align-items-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$1293$end$$,$is_column$$),title:"Align items end",id:"align-items-end"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$align_content_row$$=function($props_78795$$){var $on_change$jscomp$60$$=$props_78795$$["on-change"],$is_column$jscomp$1$$=$props_78795$$["is-column"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__align-content-row",selected:$APP.$app$common$data$name$$($props_78795$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$60$$,
name:"flex-align-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$1292$start$$,$is_column$jscomp$1$$),title:"Align content start",id:"align-content-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4087$align_content$$,
$APP.$cljs$cst$1667$center$$,$is_column$jscomp$1$$),title:"Align content center",id:"align-content-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$1293$end$$,$is_column$jscomp$1$$),title:"Align content end",id:"align-content-end"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"space-between",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$1668$space_between$$,$is_column$jscomp$1$$),title:"Align content space-between",id:"align-content-space-between"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-around",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4087$align_content$$,
$APP.$cljs$cst$1665$space_around$$,$is_column$jscomp$1$$),title:"Align content space-around",id:"align-content-space-around"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-evenly",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$1666$space_evenly$$,$is_column$jscomp$1$$),title:"Align content space-evenly",id:"align-content-space-evenly"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_content_row$$=function($props_78796$$){var $on_change$jscomp$61$$=$props_78796$$["on-change"],$is_column$jscomp$2$$=$props_78796$$["is-column"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__justify-content-row",selected:$APP.$app$common$data$name$$($props_78796$$["justify-content"]),"on-change":$on_change$jscomp$61$$,name:"flex-justify",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$1292$start$$,$is_column$jscomp$2$$),title:"Justify content start",id:"justify-content-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4089$justify_content$$,
$APP.$cljs$cst$1667$center$$,$is_column$jscomp$2$$),title:"Justify content center",id:"justify-content-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$1293$end$$,$is_column$jscomp$2$$),title:"Justify content end",id:"justify-content-end"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"space-between",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$1668$space_between$$,$is_column$jscomp$2$$),title:"Justify content space-between",id:"justify-content-space-between"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-around",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4089$justify_content$$,
$APP.$cljs$cst$1665$space_around$$,$is_column$jscomp$2$$),title:"Justify content space-around",id:"justify-content-space-around"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-evenly",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$1666$space_evenly$$,$is_column$jscomp$2$$),title:"Justify content space-evenly",id:"justify-content-space-evenly"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$=function(){return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(!1,!1,!1,!1)};
$app$main$ui$workspace$sidebar$options$menus$layout_container$simple_padding_selection_STAR_$$=function($props_78806_token_numeric_inputs$jscomp$2$$){var $on_change$jscomp$62$$=$props_78806_token_numeric_inputs$jscomp$2$$.onChange,$p2__$1$jscomp$2_value$jscomp$864$$=$props_78806_token_numeric_inputs$jscomp$2$$.value,$ids$jscomp$283$$=$props_78806_token_numeric_inputs$jscomp$2$$.ids,$applied_to_p1__$1_applied_tokens$jscomp$8$$=$props_78806_token_numeric_inputs$jscomp$2$$.appliedTokens;$props_78806_token_numeric_inputs$jscomp$2$$=
$app$main$features$use_feature$$("tokens/numeric-input");var $p1$jscomp$83_p1__$1$jscomp$4$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$864$$),$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$864$$),$applied_to_p3_on_focus_p1_p3$jscomp$23$$=$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$864$$),$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$=
$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$864$$);$p1$jscomp$83_p1__$1$jscomp$4$$=!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p2__$1$jscomp$2_value$jscomp$864$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$83_p1__$1$jscomp$4$$,$applied_to_p3_on_focus_p1_p3$jscomp$23$$)?$p1$jscomp$83_p1__$1$jscomp$4$$:null;$p2__$1$jscomp$2_value$jscomp$864$$=!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$p2__$1$jscomp$2_value$jscomp$864$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$,$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$)?$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$:null;$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);
$applied_to_p3_on_focus_p1_p3$jscomp$23$$=$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);var $applied_to_p4_on_focus_p2$$=$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);$applied_to_p1__$1_applied_tokens$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$,$applied_to_p3_on_focus_p1_p3$jscomp$23$$)?$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$:
null;$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$,$applied_to_p4_on_focus_p2$$)?$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$:null;var $on_change_SINGLEQUOTE_$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$62$$),$APP.$rumext$v2$adapt$$($ids$jscomp$283$$)],function($value__$1$jscomp$53$$,$attr$jscomp$72$$,$event$jscomp$532$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$53$$,
function($p1__78803_SHARP_$$){return $on_change$jscomp$62$$.$cljs$core$IFn$_invoke$arity$4$?$on_change$jscomp$62$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$1663$simple$$,$attr$jscomp$72$$,$p1__78803_SHARP_$$,$event$jscomp$532$$):$on_change$jscomp$62$$($APP.$cljs$cst$1663$simple$$,$attr$jscomp$72$$,$p1__78803_SHARP_$$,$event$jscomp$532$$)},$ids$jscomp$283$$,$attr$jscomp$72$$)});$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$283$$)],
function($token_name$jscomp$20$$,$attr$jscomp$73$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$20$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$73$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$283$$],null)))});var $on_focus$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$)],
function($G__78814_78970__$1_attr$jscomp$74$$,$event$jscomp$533$$){$G__78814_78970__$1_attr$jscomp$74$$=$G__78814_78970__$1_attr$jscomp$74$$ instanceof $APP.$cljs$core$Keyword$$?$G__78814_78970__$1_attr$jscomp$74$$.$fqn$:null;switch($G__78814_78970__$1_attr$jscomp$74$$){case "p1":$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(!0,!1,!0,!1);break;case "p2":$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(!1,
!0,!1,!0);break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78814_78970__$1_attr$jscomp$74$$)].join(""));}return $app$util$dom$select_target$$($event$jscomp$533$$)});$applied_to_p3_on_focus_p1_p3$jscomp$23$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$11$$)],function(){return $on_focus$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1093$p1$$):
$on_focus$jscomp$11$$($APP.$cljs$cst$1093$p1$$)});$applied_to_p4_on_focus_p2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$11$$)],function(){return $on_focus$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1091$p2$$):$on_focus$jscomp$11$$($APP.$cljs$cst$1091$p2$$)});var $on_p1_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$5$$)],
function($p1__78804_SHARP_$$){var $G__78817$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null);return $on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($p1__78804_SHARP_$$,$G__78817$$):$on_change_SINGLEQUOTE_$jscomp$5$$($p1__78804_SHARP_$$,$G__78817$$)}),$on_p2_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$5$$)],
function($p1__78805_SHARP_$$){var $G__78819$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null],null),null);return $on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($p1__78805_SHARP_$$,$G__78819$$):$on_change_SINGLEQUOTE_$jscomp$5$$($p1__78805_SHARP_$$,$G__78819$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__paddings-simple",
children:[$props_78806_token_numeric_inputs$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_p1_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$applied_to_p1__$1_applied_tokens$jscomp$8$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p1$jscomp$83_p1__$1$jscomp$4$$)||$p1$jscomp$83_p1__$1$jscomp$4$$==
null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$1985$vertical_padding$$,attr:$APP.$cljs$cst$1093$p1$$,appliedToken:$applied_to_p1__$1_applied_tokens$jscomp$8$$,value:$p1$jscomp$83_p1__$1$jscomp$4$$,onFocus:$applied_to_p3_on_focus_p1_p3$jscomp$23$$,onDetach:$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.vertical"),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,
nillable:!0,icon:"padding-top-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.vertical"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-simple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_top_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{min:0,onChange:$on_p1_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.vertical"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),value:$p1$jscomp$83_p1__$1$jscomp$4$$,onFocus:$applied_to_p3_on_focus_p1_p3$jscomp$23$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,nillable:!0})]}),
$props_78806_token_numeric_inputs$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_p2_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p2__$1$jscomp$2_value$jscomp$864$$)||
$p2__$1$jscomp$2_value$jscomp$864$$==null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$1991$horizontal_padding$$,attr:$APP.$cljs$cst$1091$p2$$,appliedToken:$applied_to_p2_applied_to_p2__$1_p2$jscomp$64$$,value:$p2__$1$jscomp$2_value$jscomp$864$$,onFocus:$applied_to_p4_on_focus_p2$$,onDetach:$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.horizontal"),
onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,nillable:!0,icon:"padding-left-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.horizontal"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-simple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_left_right$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p2_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.horizontal"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),value:$p2__$1$jscomp$2_value$jscomp$864$$,onFocus:$applied_to_p4_on_focus_p2$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,
nillable:!0})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$multiple_padding_selection_STAR_$$=function($props_78826_token_numeric_inputs$jscomp$3$$){var $on_change$jscomp$63$$=$props_78826_token_numeric_inputs$jscomp$3$$.onChange,$p4$jscomp$10_value$jscomp$865$$=$props_78826_token_numeric_inputs$jscomp$3$$.value,$ids$jscomp$284$$=$props_78826_token_numeric_inputs$jscomp$3$$.ids,$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$=$props_78826_token_numeric_inputs$jscomp$3$$.appliedTokens;$props_78826_token_numeric_inputs$jscomp$3$$=
$app$main$features$use_feature$$("tokens/numeric-input");var $p1$jscomp$84$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$865$$),$p2$jscomp$65$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$865$$),$p3$jscomp$24$$=$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$865$$);$p4$jscomp$10_value$jscomp$865$$=$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$865$$);
var $applied_to_p1$jscomp$1$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$),$applied_to_p2$jscomp$1$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$),$applied_to_p3$jscomp$1$$=$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$);$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$=$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$);
var $on_change_SINGLEQUOTE_$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$63$$),$APP.$rumext$v2$adapt$$($ids$jscomp$284$$)],function($value__$1$jscomp$54$$,$attr$jscomp$75$$,$event$jscomp$534$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$54$$,function($p1__78821_SHARP_$$){return $on_change$jscomp$63$$.$cljs$core$IFn$_invoke$arity$4$?$on_change$jscomp$63$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$1616$multiple$$,
$attr$jscomp$75$$,$p1__78821_SHARP_$$,$event$jscomp$534$$):$on_change$jscomp$63$$($APP.$cljs$cst$1616$multiple$$,$attr$jscomp$75$$,$p1__78821_SHARP_$$,$event$jscomp$534$$)},$ids$jscomp$284$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$75$$]))}),$on_focus$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$)],function($attr$jscomp$76$$,$event$jscomp$535$$){$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$76$$);
return $app$util$dom$select_target$$($event$jscomp$535$$)}),$on_detach_token$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$284$$)],function($token$jscomp$130$$,$attr$jscomp$77$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token$jscomp$130$$,$APP.$cljs$cst$1993$attributes$$,
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$77$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$284$$],null)))}),$on_p1_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],function($p1__78822_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__78822_SHARP_$$,$APP.$cljs$cst$1093$p1$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__78822_SHARP_$$,
$APP.$cljs$cst$1093$p1$$)}),$on_p2_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],function($p1__78823_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__78823_SHARP_$$,$APP.$cljs$cst$1091$p2$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__78823_SHARP_$$,$APP.$cljs$cst$1091$p2$$)}),$on_p3_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],
function($p1__78824_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__78824_SHARP_$$,$APP.$cljs$cst$1687$p3$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__78824_SHARP_$$,$APP.$cljs$cst$1687$p3$$)}),$on_p4_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],function($p1__78825_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__78825_SHARP_$$,$APP.$cljs$cst$1688$p4$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__78825_SHARP_$$,$APP.$cljs$cst$1688$p4$$)}),$on_focus_p1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$12$$)],function(){return $on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1093$p1$$):$on_focus$jscomp$12$$($APP.$cljs$cst$1093$p1$$)}),
$on_focus_p2$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$12$$)],function(){return $on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1091$p2$$):$on_focus$jscomp$12$$($APP.$cljs$cst$1091$p2$$)}),$on_focus_p3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$12$$)],function(){return $on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?
$on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1687$p3$$):$on_focus$jscomp$12$$($APP.$cljs$cst$1687$p3$$)}),$on_focus_p4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$12$$)],function(){return $on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1688$p4$$):$on_focus$jscomp$12$$($APP.$cljs$cst$1688$p4$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__paddings-multiple",
children:[$props_78826_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_p1_change$jscomp$1$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$applied_to_p1$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p1$jscomp$84$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",inputType:$APP.$cljs$cst$1985$vertical_padding$$,attr:$APP.$cljs$cst$1093$p1$$,appliedToken:$applied_to_p1$jscomp$1$$,value:$p1$jscomp$84$$,onFocus:$on_focus_p1$jscomp$1$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.top"),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-top"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.top"),
className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_top$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p1_change$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.top"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",
placeholder:"--",value:$p1$jscomp$84$$,onFocus:$on_focus_p1$jscomp$1$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p1"})]}),$props_78826_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_p2_change$jscomp$1$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$applied_to_p2$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p2$jscomp$65$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$1991$horizontal_padding$$,attr:$APP.$cljs$cst$1091$p2$$,appliedToken:$applied_to_p2$jscomp$1$$,value:$p2$jscomp$65$$,onFocus:$on_focus_p2$jscomp$1$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.right"),
onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.right"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_right$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p2_change$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.right"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$p2$jscomp$65$$,onFocus:$on_focus_p2$jscomp$1$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p2"})]}),
$props_78826_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_p3_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$applied_to_p3$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p3$jscomp$24$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",inputType:$APP.$cljs$cst$1985$vertical_padding$$,attr:$APP.$cljs$cst$1687$p3$$,appliedToken:$applied_to_p3$jscomp$1$$,value:$p3$jscomp$24$$,onFocus:$on_focus_p3$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.bottom"),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.bottom"),
className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p3_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.bottom"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",
placeholder:"--",value:$p3$jscomp$24$$,onFocus:$on_focus_p3$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p3"})]}),$props_78826_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_p4_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$p4$jscomp$10_value$jscomp$865$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$1991$horizontal_padding$$,attr:$APP.$cljs$cst$1688$p4$$,appliedToken:$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$,value:$p4$jscomp$10_value$jscomp$865$$,onFocus:$on_focus_p4$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.left"),
onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-left"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.left"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_left$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p4_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.left"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$p4$jscomp$10_value$jscomp$865$$,onFocus:$on_focus_p4$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p4"})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$=function($props_78848$$){var $type$jscomp$629$$=$props_78848$$.type,$on_type_change$jscomp$1$$=$props_78848$$.onTypeChange,$on_type_change_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_type_change$jscomp$1$$)],function($event$jscomp$536_type__$1$jscomp$15_type__$2$$){$event$jscomp$536_type__$1$jscomp$15_type__$2$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$536_type__$1$jscomp$15_type__$2$$),
"type");$event$jscomp$536_type__$1$jscomp$15_type__$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$536_type__$1$jscomp$15_type__$2$$,"multiple")?$APP.$cljs$cst$1663$simple$$:$APP.$cljs$cst$1616$multiple$$;return $on_type_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_type_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$536_type__$1$jscomp$15_type__$2$$):$on_type_change$jscomp$1$$($event$jscomp$536_type__$1$jscomp$15_type__$2$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return function(){return $app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$(null)}});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-group",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-inputs",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629$$,$APP.$cljs$cst$1663$simple$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$simple_padding_selection_STAR_$$,
$props_78848$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629$$,$APP.$cljs$cst$1616$multiple$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$multiple_padding_selection_STAR_$$,$props_78848$$):null}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.expand"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.expand"),
"data-type":$APP.$app$common$data$name$$($type$jscomp$629$$),onClick:$on_type_change_SINGLEQUOTE_$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629$$,$APP.$cljs$cst$1616$multiple$$)?"main_ui_workspace_sidebar_options_menus_layout_container__selected":""),children:$APP.$app$main$ui$icons$padding_extended$$})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$=function($type$jscomp$630$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$($type$jscomp$630$$))};$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$(null))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$=function($applied_tokens$jscomp$10_props_78862$$){var $on_change$jscomp$64$$=$applied_tokens$jscomp$10_props_78862$$.onChange,$col_gap_disabled_QMARK__is_column$jscomp$3$$=$applied_tokens$jscomp$10_props_78862$$.isColumn,$value$jscomp$867$$=$applied_tokens$jscomp$10_props_78862$$.value,$ids$jscomp$285$$=$applied_tokens$jscomp$10_props_78862$$.ids,$wrap_type$jscomp$3$$=$applied_tokens$jscomp$10_props_78862$$.wrapType;
$applied_tokens$jscomp$10_props_78862$$=$applied_tokens$jscomp$10_props_78862$$.appliedTokens;var $token_numeric_inputs$jscomp$4$$=$app$main$features$use_feature$$("tokens/numeric-input"),$nowrap_QMARK__on_detach_token$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1664$nowrap$$,$wrap_type$jscomp$3$$),$row_gap_disabled_QMARK_$$=$nowrap_QMARK__on_detach_token$jscomp$6$$&&!$col_gap_disabled_QMARK__is_column$jscomp$3$$;$col_gap_disabled_QMARK__is_column$jscomp$3$$=$nowrap_QMARK__on_detach_token$jscomp$6$$&&
$col_gap_disabled_QMARK__is_column$jscomp$3$$;var $on_change_SINGLEQUOTE_$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$64$$),$APP.$rumext$v2$adapt$$($wrap_type$jscomp$3$$),$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function($value__$1$jscomp$55$$,$event$jscomp$537$$,$attr$jscomp$78$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$55$$,function($p1__78856_SHARP_$$){var $G__78868$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("nowrap",
$wrap_type$jscomp$3$$);return $on_change$jscomp$64$$.$cljs$core$IFn$_invoke$arity$4$?$on_change$jscomp$64$$.$cljs$core$IFn$_invoke$arity$4$($G__78868$$,$attr$jscomp$78$$,$p1__78856_SHARP_$$,$event$jscomp$537$$):$on_change$jscomp$64$$($G__78868$$,$attr$jscomp$78$$,$p1__78856_SHARP_$$,$event$jscomp$537$$)},$ids$jscomp$285$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$78$$]))});$nowrap_QMARK__on_detach_token$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],
function($token$jscomp$131$$,$attr$jscomp$79$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token$jscomp$131$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$79$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$285$$],null)))});var $on_row_gap_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$7$$)],
function($p1__78857_SHARP_$$,$p2__78858_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__78857_SHARP_$$,$p2__78858_SHARP_$$,$APP.$cljs$cst$1681$row_gap$$):$on_change_SINGLEQUOTE_$jscomp$7$$($p1__78857_SHARP_$$,$p2__78858_SHARP_$$,$APP.$cljs$cst$1681$row_gap$$)}),$on_column_gap_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$7$$)],
function($p1__78859_SHARP_$$,$p2__78860_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__78859_SHARP_$$,$p2__78860_SHARP_$$,$APP.$cljs$cst$1682$column_gap$$):$on_change_SINGLEQUOTE_$jscomp$7$$($p1__78859_SHARP_$$,$p2__78860_SHARP_$$,$APP.$cljs$cst$1682$column_gap$$)}),$on_focus_row_gap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$($APP.$cljs$cst$1681$row_gap$$))}),$on_focus_column_gap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$($APP.$cljs$cst$1682$column_gap$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$(null)}});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__gap-group",children:[$token_numeric_inputs$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{values:new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1681$row_gap$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$)],null),min:0,onChange:$on_row_gap_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_78862$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1681$row_gap$$,appliedToken:$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_78862$$),value:$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$),onFocus:$on_focus_row_gap$$,onDetach:$nowrap_QMARK__on_detach_token$jscomp$6$$,property:"Row gap",onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,
nillable:!0,disabled:$row_gap_disabled_QMARK_$$,icon:"gap-vertical"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Row gap",className:"main_ui_workspace_sidebar_options_menus_layout_container__row-gap "+($row_gap_disabled_QMARK_$$?"main_ui_workspace_sidebar_options_menus_layout_container__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$gap_vertical$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:0,onChange:$on_row_gap_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$),onFocus:$on_focus_row_gap$$,"data-wrap-type":$APP.$app$common$data$name$$($wrap_type$jscomp$3$$),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,"data-type":"row-gap",nillable:!0,disabled:$row_gap_disabled_QMARK_$$})]}),$token_numeric_inputs$jscomp$4$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_column_gap_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_78862$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1682$column_gap$$,appliedToken:$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_78862$$),value:$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$),onFocus:$on_focus_column_gap$$,onDetach:$nowrap_QMARK__on_detach_token$jscomp$6$$,property:"Column gap",onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,
nillable:!0,disabled:$col_gap_disabled_QMARK__is_column$jscomp$3$$,icon:"gap-horizontal"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Column gap",className:"main_ui_workspace_sidebar_options_menus_layout_container__column-gap "+($col_gap_disabled_QMARK__is_column$jscomp$3$$?"main_ui_workspace_sidebar_options_menus_layout_container__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$gap_horizontal$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_column_gap_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$867$$),onFocus:$on_focus_column_gap$$,"data-wrap-type":$APP.$app$common$data$name$$($wrap_type$jscomp$3$$),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,
"data-type":"column-gap",nillable:!0,disabled:$col_gap_disabled_QMARK__is_column$jscomp$3$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$=function($props_78876$$){var $on_change$jscomp$65$$=$props_78876$$["on-change"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__direction-row-grid",selected:$APP.$app$common$data$name$$($props_78876$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$65$$,name:"grid-direction",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"row",id:"grid-direction-row",title:"Row",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1656$row$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"column",id:"grid-direction-column",title:"Column",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$216$column$$)})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_edit_mode$$=function($edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$){var $id$jscomp$968$$=$edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$.id;$edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$);var $active_QMARK_$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$968$$,$edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$);
$edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$968$$),$APP.$rumext$v2$adapt$$($edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$)],function(){return $active_QMARK_$jscomp$6$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2169$interrupt$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$start_edition_mode$$($id$jscomp$968$$))});
return(0,$APP.$rumext$v2$jsx$$)("button",{alt:"Grid edit mode",onClick:$edition$jscomp$6_props_78877_toggle_edit_mode$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.edit-grid")})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$=function($props_78878$$){var $on_change$jscomp$66$$=$props_78878$$["on-change"],$is_column$jscomp$4$$=$props_78878$$["is-column"],$type$jscomp$631$$=$is_column$jscomp$4$$?"column":"row";return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__align-grid-row",selected:$APP.$app$common$data$name$$($props_78878$$.value),"decode-fn":$APP.$cljs$core$keyword$$,
"on-change":$on_change$jscomp$66$$,name:"flex-align-items-"+($type$jscomp$631$$??""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$1292$start$$,$is_column$jscomp$4$$),title:"Align items start",id:"align-items-start-"+($type$jscomp$631$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$1667$center$$,$is_column$jscomp$4$$),title:"Align items center",id:"align-items-center-"+($type$jscomp$631$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$1293$end$$,
$is_column$jscomp$4$$),title:"Align items end",id:"align-items-end-"+($type$jscomp$631$$??"")})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$=function($props_78880$$){var $on_change$jscomp$67$$=$props_78880$$["on-change"],$is_column$jscomp$5$$=$props_78880$$["is-column"],$type$jscomp$632$$=$is_column$jscomp$5$$?"column":"row";return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__justify-grid-row",selected:$APP.$app$common$data$name$$($props_78880$$.value),
"on-change":$on_change$jscomp$67$$,"decode-fn":$APP.$cljs$core$keyword$$,name:"grid-justify-items-"+($type$jscomp$632$$??""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$1292$start$$,$is_column$jscomp$5$$),title:"Justify items start",id:"justify-items-start-"+($type$jscomp$632$$??"")},"justify-item-start"),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$1667$center$$,$is_column$jscomp$5$$),title:"Justify items center",id:"justify-items-center-"+($type$jscomp$632$$??"")},"justify-item-center"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4088$justify_items$$,
$APP.$cljs$cst$1293$end$$,$is_column$jscomp$5$$),title:"Justify items end",id:"justify-items-end-"+($type$jscomp$632$$??"")},"justify-item-end"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-around",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$1665$space_around$$,$is_column$jscomp$5$$),title:"Justify items space-around",id:"justify-items-space-around-"+($type$jscomp$632$$??
"")},"justify-item-space-around"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-between",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$1668$space_between$$,$is_column$jscomp$5$$),title:"Justify items space-between",id:"justify-items-space-between-"+($type$jscomp$632$$??"")},"justify-item-space-between"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"stretch",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$1669$stretch$$,$is_column$jscomp$5$$),title:"Justify items stretch",id:"justify-items-stretch-"+($type$jscomp$632$$??"")},"justify-item-stretch")]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$manage_values$$=function($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$){$map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$=$APP.$cljs$core$__destructure_map$$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$);var $map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$,
$APP.$cljs$cst$139$type$$);$map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$,$APP.$cljs$cst$260$value$$);switch($map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$ instanceof $APP.$cljs$core$Keyword$$?$map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$.$fqn$:null){case "auto":return"auto";
case "percent":return $APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$/100,null);case "flex":return $map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$=$APP.$cljs$core$__destructure_map$$(null),$map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$,
$APP.$cljs$cst$267$precision$$,2),$map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$=typeof $map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$):$map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$,$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$))?
""+($APP.$app$common$math$precision$$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$,$map__51857__$1$jscomp$inline_13558_precision$jscomp$inline_13559_type$jscomp$633$$)??"")+"fr":null;case "fixed":return $APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$);default:return $map__78882__$1_p__78881_value$jscomp$871_value__$1$jscomp$inline_13560$$}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_track_info$$=function($pointer_enter_props_78886$$){var $remove_element$$=$pointer_enter_props_78886$$["remove-element"],$set_column_type$$=$pointer_enter_props_78886$$["set-column-type"],$on_select_track$$=$pointer_enter_props_78886$$["on-select-track"],$is_column$jscomp$6$$=$pointer_enter_props_78886$$["is-column"],$index$jscomp$489$$=$pointer_enter_props_78886$$.index,$hover_track$$=$pointer_enter_props_78886$$["hover-track"],$type$jscomp$634$$=
$pointer_enter_props_78886$$.type,$set_column_value$$=$pointer_enter_props_78886$$["set-column-value"],$column$jscomp$43$$=$pointer_enter_props_78886$$.column,$reorder_track$$=$pointer_enter_props_78886$$["reorder-track"],$dprops$jscomp$5_drop_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$634$$),$APP.$rumext$v2$adapt$$($reorder_track$$),$APP.$rumext$v2$adapt$$($index$jscomp$489$$)],function($G__78892_drop_position$$,$G__78891_data$jscomp$486$$,
$G__78893_event$jscomp$538$$){$G__78891_data$jscomp$486$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($G__78891_data$jscomp$486$$);$G__78892_drop_position$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1562$top$$,$G__78892_drop_position$$)?$index$jscomp$489$$-1:$index$jscomp$489$$;$G__78893_event$jscomp$538$$=!$APP.$app$util$keyboard$mod_QMARK_$$($G__78893_event$jscomp$538$$);return $reorder_track$$.$cljs$core$IFn$_invoke$arity$4$?$reorder_track$$.$cljs$core$IFn$_invoke$arity$4$($type$jscomp$634$$,
$G__78891_data$jscomp$486$$,$G__78892_drop_position$$,$G__78893_event$jscomp$538$$):$reorder_track$$($type$jscomp$634$$,$G__78891_data$jscomp$486$$,$G__78892_drop_position$$,$G__78893_event$jscomp$538$$)});$pointer_enter_props_78886$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$634$$),$APP.$rumext$v2$adapt$$($hover_track$$),$APP.$rumext$v2$adapt$$($index$jscomp$489$$)],function(){return $hover_track$$.$cljs$core$IFn$_invoke$arity$3$?$hover_track$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$634$$,
$index$jscomp$489$$,!0):$hover_track$$($type$jscomp$634$$,$index$jscomp$489$$,!0)});var $pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$634$$),$APP.$rumext$v2$adapt$$($hover_track$$),$APP.$rumext$v2$adapt$$($index$jscomp$489$$)],function(){return $hover_track$$.$cljs$core$IFn$_invoke$arity$3$?$hover_track$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$634$$,$index$jscomp$489$$,!1):$hover_track$$($type$jscomp$634$$,$index$jscomp$489$$,
!1)}),$handle_select_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$634$$),$APP.$rumext$v2$adapt$$($index$jscomp$489$$)],function(){return $APP.$cljs$core$truth_$$($on_select_track$$)?$on_select_track$$.$cljs$core$IFn$_invoke$arity$2$?$on_select_track$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$634$$,$index$jscomp$489$$):$on_select_track$$($type$jscomp$634$$,$index$jscomp$489$$):null}),$dref$jscomp$5_vec__78887$$=
$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/grid-track",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$5_drop_track$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5699$is_column$$,$is_column$jscomp$6$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$489$$,$APP.$cljs$cst$216$column$$,$column$jscomp$43$$],null),$APP.$cljs$cst$2959$draggable_QMARK_$$,
!0]));$dprops$jscomp$5_drop_track$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$5_vec__78887$$,0,null);$dref$jscomp$5_vec__78887$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$5_vec__78887$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$dref$jscomp$5_vec__78887$$,onPointerEnter:$pointer_enter_props_78886$$,onPointerLeave:$pointer_leave$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$5_drop_track$$),
$APP.$cljs$cst$1562$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$5_drop_track$$),$APP.$cljs$cst$1667$center$$)?"main_ui_workspace_sidebar_options_menus_layout_container__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$5_drop_track$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_options_menus_layout_container__dnd-over-bot":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$handle_select_track$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-dir-icon",children:$APP.$cljs$core$truth_$$($is_column$jscomp$6$$)?$APP.$app$main$ui$icons$flex_vertical$$:$APP.$app$main$ui$icons$flex_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-value",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,value:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$43$$),onChange:function($p1__78884_SHARP_$$){return $set_column_value$$.$cljs$core$IFn$_invoke$arity$3$?$set_column_value$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$634$$,$index$jscomp$489$$,$p1__78884_SHARP_$$):$set_column_value$$($type$jscomp$634$$,$index$jscomp$489$$,$p1__78884_SHARP_$$)},placeholder:"--",
min:0,disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$43$$))})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-unit",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__track-info-unit-selector","default-value":$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$43$$),
options:new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$2287$label$$,"FR"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$2287$label$$,"AUTO"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$2287$label$$,
"PX"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1670$percent$$,$APP.$cljs$cst$2287$label$$,"%"],null)],null),"on-change":function($p1__78885_SHARP_$$){return $set_column_type$$.$cljs$core$IFn$_invoke$arity$3$?$set_column_type$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$634$$,$index$jscomp$489$$,$p1__78885_SHARP_$$):$set_column_type$$($type$jscomp$634$$,$index$jscomp$489$$,$p1__78885_SHARP_$$)}})})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete"),onClick:$remove_element$$,"data-type":$type$jscomp$634$$,"data-index":$index$jscomp$489$$,icon:"remove"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$=function($column_num$jscomp$1_props_78900_track_name$$){var $remove_element$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["remove-element"],$set_column_type$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["set-column-type"],$column_values$$=$column_num$jscomp$1_props_78900_track_name$$["column-values"],$on_select_track$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["on-select-track"],$is_column$jscomp$7$$=
$column_num$jscomp$1_props_78900_track_name$$["is-column"],$expanded_QMARK_$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["expanded?"],$hover_track$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["hover-track"],$toggle$$=$column_num$jscomp$1_props_78900_track_name$$.toggle,$add_new_element$$=$column_num$jscomp$1_props_78900_track_name$$["add-new-element"],$set_column_value$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["set-column-value"],$reorder_track$jscomp$1$$=$column_num$jscomp$1_props_78900_track_name$$["reorder-track"];
$column_num$jscomp$1_props_78900_track_name$$=$APP.$cljs$core$count$$($column_values$$);$column_num$jscomp$1_props_78900_track_name$$=($column_num$jscomp$1_props_78900_track_name$$>1?$is_column$jscomp$7$$?"Columns ":"Rows ":$is_column$jscomp$7$$?"Column ":"Row ")+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($column_num$jscomp$1_props_78900_track_name$$,0)?" - empty":$column_num$jscomp$1_props_78900_track_name$$)??"");var $track_detail$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$options$menus$layout_container$manage_values$$,$column_values$$)),$type$jscomp$635$$=$APP.$cljs$core$truth_$$($is_column$jscomp$7$$)?$APP.$cljs$cst$216$column$$:$APP.$cljs$cst$1656$row$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":$APP.$cljs$core$not$$($is_column$jscomp$7$$)?"inspect-layout-rows":null,className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-track-header",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__expand-icon",children:$APP.$app$main$ui$icons$menu$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$toggle$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$column_num$jscomp$1_props_78900_track_name$$,
className:"main_ui_workspace_sidebar_options_menus_layout_container__track-name",children:$column_num$jscomp$1_props_78900_track_name$$}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$track_detail$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-detail",children:$track_detail$$})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){$APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$1$$)||($toggle$$.$cljs$core$IFn$_invoke$arity$0$?$toggle$$.$cljs$core$IFn$_invoke$arity$0$():
$toggle$$());return $add_new_element$$.$cljs$core$IFn$_invoke$arity$2$?$add_new_element$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$635$$,$APP.$app$common$types$shape$layout$default_track_value$$):$add_new_element$$($type$jscomp$635$$,$APP.$app$common$types$shape$layout$default_track_value$$)},className:"main_ui_workspace_sidebar_options_menus_layout_container__add-column",children:$APP.$app$main$ui$icons$add$$})]}),$APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,
{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks-info-container",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$169$$,$column$jscomp$44_p__78903$$){var $index$jscomp$490$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$44_p__78903$$,0,null);$column$jscomp$44_p__78903$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$44_p__78903$$,
1,null);$out_arr__44124__auto__$jscomp$169$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_track_info$$,{"is-column":$is_column$jscomp$7$$,index:$index$jscomp$490$$,"hover-track":$hover_track$jscomp$1$$,type:$type$jscomp$635$$,"set-column-value":$set_column_value$jscomp$1$$,column:$column$jscomp$44_p__78903$$,"reorder-track":$reorder_track$jscomp$1$$,"remove-element":$remove_element$jscomp$1$$,"set-column-type":$set_column_type$jscomp$1$$,"on-select-track":$on_select_track$jscomp$1$$},
""+($index$jscomp$490$$??"")+"-"+($APP.$app$common$data$name$$($type$jscomp$635$$)??"")));return $out_arr__44124__auto__$jscomp$169$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($column_values$$))})}):null]})};$app$main$ui$workspace$sidebar$options$menus$layout_container$open_flex_help$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$config$flex_help_uri$$))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$config$grid_help_uri$$))};
$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$=function(){var $id$jscomp$969$$=$APP.$app$common$uuid$next$$();return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$id$jscomp$969$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$cst$260$value$$,4,$APP.$cljs$cst$1620$hidden$$,!1],null)};
$app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$=function($blur$jscomp$12_props_78854$$){var $ids$jscomp$288$$=$blur$jscomp$12_props_78854$$.ids,$type$jscomp$651$$=$blur$jscomp$12_props_78854$$.type;$blur$jscomp$12_props_78854$$=$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$12_props_78854$$.values);var $has_value_QMARK_$$=$blur$jscomp$12_props_78854$$!=null,$bg_blur_QMARK_$$=$app$main$features$use_feature$$("render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1197$background_blur$$),$state_STAR_$jscomp$16$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1876$show_content$$,!0,$cljs$cst$5700$show_more_options$$,!1],null)),$more_options_QMARK__state$jscomp$1187$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$16$$),$open_QMARK_$jscomp$19$$=$APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($more_options_QMARK__state$jscomp$1187$$);$more_options_QMARK__state$jscomp$1187$$=
$cljs$cst$5700$show_more_options$$.$cljs$core$IFn$_invoke$arity$1$($more_options_QMARK__state$jscomp$1187$$);var $toggle_content$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$16$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$core$not$$)}),$toggle_more_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$16$$,
$APP.$cljs$core$update$$,$cljs$cst$5700$show_more_options$$,$APP.$cljs$core$not$$)}),$hidden_QMARK_$jscomp$5$$=$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$12_props_78854$$),$change_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$288$$)],function($update_fn$jscomp$50$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$288$$,
$update_fn$jscomp$50$$))}),$handle_add$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$),$APP.$rumext$v2$adapt$$($ids$jscomp$288$$)],function(){function $G__78855$$($p1__78849_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78849_SHARP_$$,$APP.$cljs$cst$1653$blur$$,$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$())}$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$288$$));
return $change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__78855$$):$change_BANG_$$($G__78855$$)}),$handle_delete$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$),$APP.$rumext$v2$adapt$$($ids$jscomp$288$$)],function(){function $G__78861$$($p1__78850_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__78850_SHARP_$$,$APP.$cljs$cst$1653$blur$$)}$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$288$$));
return $change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__78861$$):$change_BANG_$$($G__78861$$)}),$handle_change$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$),$APP.$rumext$v2$adapt$$($ids$jscomp$288$$)],function($value$jscomp$886$$){function $G__78863$$($G__78864__$1_p1__78851_SHARP_$$){$G__78864__$1_p1__78851_SHARP_$$=$APP.$cljs$core$contains_QMARK_$$($G__78864__$1_p1__78851_SHARP_$$,
$APP.$cljs$cst$1653$blur$$)?$G__78864__$1_p1__78851_SHARP_$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78864__$1_p1__78851_SHARP_$$,$APP.$cljs$cst$1653$blur$$,$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$());return $APP.$cljs$core$assoc_in$$($G__78864__$1_p1__78851_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$260$value$$],null),$value$jscomp$886$$)}$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$288$$));
return $change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__78863$$):$change_BANG_$$($G__78863$$)}),$handle_type_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$),$APP.$rumext$v2$adapt$$($ids$jscomp$288$$)],function($value$jscomp$887$$){function $G__78865$$($p1__78852_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__78852_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$139$type$$],null),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$887$$))}$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$288$$));return $change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__78865$$):$change_BANG_$$($G__78865$$)}),$handle_toggle_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$),
$APP.$rumext$v2$adapt$$($ids$jscomp$288$$)],function(){function $G__78866$$($p1__78853_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__78853_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1620$hidden$$],null),$APP.$cljs$core$not$$)}$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$288$$));
return $change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__78866$$):$change_BANG_$$($G__78866$$)}),$type_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($bg_blur_QMARK_$$)],function(){var $G__78867$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"layer-blur",$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.layer-blur")],null)],null);return $bg_blur_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78867$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"background-blur",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.background-blur")],null)):$G__78867$$});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__element-set",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_value_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$19$$),onCollapsed:$toggle_content$jscomp$5$$,title:function(){switch($type$jscomp$651$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$651$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.title.multiple");
case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.title.group");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.title")}}(),className:$has_value_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_blur__title-spacing-blur",children:$has_value_QMARK_$$?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.add-blur"),
onClick:$handle_add$$,icon:"add","data-testid":"add-blur"})})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$19$$)?$has_value_QMARK_$$:$open_QMARK_$jscomp$19$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__element-set-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__first-row "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_options_menus_blur__hidden":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"blur-info",className:"main_ui_workspace_sidebar_options_menus_blur__blur-info",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_more_options$$,className:"main_ui_workspace_sidebar_options_menus_blur__show-more "+($APP.$cljs$core$truth_$$($more_options_QMARK__state$jscomp$1187$$)?"main_ui_workspace_sidebar_options_menus_blur__selected":""),children:$APP.$app$main$ui$icons$menu$$}),$bg_blur_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"class":"main_ui_workspace_sidebar_options_menus_blur__blur-type-select","default-value":$APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$12_props_78854$$)),options:$type_options$$,disabled:$hidden_QMARK_$jscomp$5$$,"on-change":$handle_type_change$$}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_blur__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.title")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.toggle-blur"),onClick:$handle_toggle_visibility$$,icon:$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$5$$)?"hide":"shown"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.remove-blur"),onClick:$handle_delete$$,icon:"remove"})]})]}),$APP.$cljs$core$truth_$$($more_options_QMARK__state$jscomp$1187$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__second-row",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"blur-input-sidebar",className:"main_ui_workspace_sidebar_options_menus_blur__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.blur.value")}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_blur__numeric-input",placeholder:"--",id:"blur-input-sidebar",min:"0",onChange:$handle_change$jscomp$9$$,value:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$12_props_78854$$)})]}):null]}):null]})};
$app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$=function($open_QMARK_$jscomp$20_props_78899$$){var $ids$jscomp$289$$=$open_QMARK_$jscomp$20_props_78899$$.ids,$values$jscomp$85$$=$open_QMARK_$jscomp$20_props_78899$$.values,$state_STAR_$jscomp$17$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$20_props_78899$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$17$$);var $toggle_content$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$17$$,
$APP.$cljs$core$not$$)}),$in_frame_QMARK__old_shapes$jscomp$2$$=$APP.$cljs$core$_deref$$($app$main$refs$objects_by_id$$($ids$jscomp$289$$)),$first_level_QMARK__frames$jscomp$31$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78894_SHARP_$$){return $APP.$cljs$core$deref$$($app$main$refs$object_by_id$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78894_SHARP_$$)))},$in_frame_QMARK__old_shapes$jscomp$2$$),$shapes$jscomp$208$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$translate_to_frame$$,
$in_frame_QMARK__old_shapes$jscomp$2$$,$first_level_QMARK__frames$jscomp$31$$),$values__$1$jscomp$5$$=function(){var $G__78902__$1_map__78901_x$jscomp$1251$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$208$$))),$map__78901__$1_y$jscomp$473$$=$APP.$cljs$core$__destructure_map$$($G__78902__$1_map__78901_x$jscomp$1251$$);$G__78902__$1_map__78901_x$jscomp$1251$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78901__$1_y$jscomp$473$$,
$APP.$cljs$cst$1510$x$$);$map__78901__$1_y$jscomp$473$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78901__$1_y$jscomp$473$$,$APP.$cljs$cst$1511$y$$);$G__78902__$1_map__78901_x$jscomp$1251$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$85$$),$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values$jscomp$85$$,$APP.$cljs$cst$1510$x$$,$G__78902__$1_map__78901_x$jscomp$1251$$):
$values$jscomp$85$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$85$$),$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78902__$1_map__78901_x$jscomp$1251$$,$APP.$cljs$cst$1511$y$$,$map__78901__$1_y$jscomp$473$$):$G__78902__$1_map__78901_x$jscomp$1251$$}(),$values__$2$jscomp$2$$=function(){var $G__78908__$1_map__78907_width$jscomp$197$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$208$$)),
$height$jscomp$168_map__78907__$1$$=$APP.$cljs$core$__destructure_map$$($G__78908__$1_map__78907_width$jscomp$197$$);$G__78908__$1_map__78907_width$jscomp$197$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$168_map__78907__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$168_map__78907__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$168_map__78907__$1$$,$APP.$cljs$cst$1522$height$$);$G__78908__$1_map__78907_width$jscomp$197$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$5$$),
$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values__$1$jscomp$5$$,$APP.$cljs$cst$290$width$$,$G__78908__$1_map__78907_width$jscomp$197$$):$values__$1$jscomp$5$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$5$$),$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__78908__$1_map__78907_width$jscomp$197$$,$APP.$cljs$cst$1522$height$$,
$height$jscomp$168_map__78907__$1$$):$G__78908__$1_map__78907_width$jscomp$197$$}();$first_level_QMARK__frames$jscomp$31$$=($in_frame_QMARK__old_shapes$jscomp$2$$=$ids$jscomp$289$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$),$APP.$app$common$uuid$zero$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$),
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$));var $constraints_h$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1193$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$2$$,$APP.$cljs$cst$1872$constraints_h$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1193$$)?$or__5025__auto__$jscomp$1193$$:$APP.$app$common$geom$shapes$constraints$default_constraints_h$$($values__$2$jscomp$2$$)}(),$constraints_v$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1194$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$2$$,$APP.$cljs$cst$1871$constraints_v$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1194$$)?$or__5025__auto__$jscomp$1194$$:$APP.$app$common$geom$shapes$constraints$default_constraints_v$$($values__$2$jscomp$2$$)}(),$on_constraint_button_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$289$$),$APP.$rumext$v2$adapt$$($values__$2$jscomp$2$$)],function($event$jscomp$541_vec__78909$$){var $button$jscomp$2$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$541_vec__78909$$),"value")),$constraints_h__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($values__$2$jscomp$2$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1902$scale$$),$constraints_v__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($values__$2$jscomp$2$$,$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1902$scale$$);$event$jscomp$541_vec__78909$$=
function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1562$top$$,$button$jscomp$2$$))switch($constraints_v__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_v__$1$$.$fqn$:null){case "top":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1902$scale$$],null);case "topbottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1563$bottom$$],null);case "bottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1901$topbottom$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1562$top$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1563$bottom$$,
$button$jscomp$2$$))switch($constraints_v__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_v__$1$$.$fqn$:null){case "bottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1902$scale$$],null);case "topbottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1562$top$$],null);case "top":return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1901$topbottom$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1563$bottom$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$257$left$$,$button$jscomp$2$$))switch($constraints_h__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_h__$1$$.$fqn$:
null){case "left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1902$scale$$],null);case "leftright":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$258$right$$],null);case "right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,
$APP.$cljs$cst$1900$leftright$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$257$left$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$258$right$$,$button$jscomp$2$$))switch($constraints_h__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_h__$1$$.$fqn$:null){case "right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1902$scale$$],null);case "leftright":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$257$left$$],null);case "left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1900$leftright$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$258$right$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5701$centerv$$,$button$jscomp$2$$))switch($constraints_v__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_v__$1$$.$fqn$:null){case "center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1902$scale$$],
null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1667$center$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5702$centerh$$,$button$jscomp$2$$))switch($constraints_h__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_h__$1$$.$fqn$:null){case "center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1902$scale$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1667$center$$],null)}else{if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$button$jscomp$2$$))return $APP.$cljs$core$List$EMPTY$$;throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($button$jscomp$2$$)].join(""));}}();
var $constraint$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$541_vec__78909$$,0,null),$new_value$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$541_vec__78909$$,1,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$289$$,function($p1__78895_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78895_SHARP_$$,
$constraint$jscomp$3$$,$new_value$jscomp$25$$)}))}),$on_constraint_h_select_changed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$289$$)],function($value$jscomp$888$$){return $APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$888$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$289$$,function($p1__78896_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78896_SHARP_$$,
$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$888$$))}))}),$on_constraint_v_select_changed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$289$$)],function($value$jscomp$889$$){return $APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$889$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$289$$,
function($p1__78897_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78897_SHARP_$$,$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$889$$))}))}),$on_fixed_scroll_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$289$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$289$$,
function($p1__78898_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__78898_SHARP_$$,$APP.$cljs$cst$1645$fixed_scroll$$,$APP.$cljs$core$not$$)}))}),$options_h$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($constraints_h$jscomp$2$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1616$multiple$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,"left",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"right",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.right")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"leftright",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.leftright")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"scale",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.scale")],null)],null)]))}),$options_v$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($constraints_v$jscomp$2$$)],
function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1616$multiple$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")],null)],null):null,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"top",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.top")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"bottom",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.bottom")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"topbottom",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.topbottom")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
"scale",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.scale")],null)],null)]))});return $in_frame_QMARK__old_shapes$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,
{collapsable:!0,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$20_props_78899$$),onCollapsed:$toggle_content$jscomp$6$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints")})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$20_props_78899$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__element-set-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-widget",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-top",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"top",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1562$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1901$topbottom$$)?
"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-left",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"left",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$257$left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1900$leftright$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-center",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"centerv",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1667$center$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})}),(0,$APP.$rumext$v2$jsx$$)("button",
{"data-value":"centerh",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1667$center$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-right",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"right",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,
$APP.$cljs$cst$1900$leftright$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-bottom",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"bottom",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1563$bottom$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1901$topbottom$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-selects",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"constraint-h-select",className:"main_ui_workspace_sidebar_options_menus_constraints__horizontal-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$($constraints_h$jscomp$2$$),"scale"):"",options:$options_h$$,
"on-change":$on_constraint_h_select_changed$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"constraint-v-select",className:"main_ui_workspace_sidebar_options_menus_constraints__vertical-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$($constraints_v$jscomp$2$$),
"scale"):"",options:$options_v$$,"on-change":$on_constraint_v_select_changed$$})}),$first_level_QMARK__frames$jscomp$31$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__checkbox",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"fixed-on-scroll",className:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1645$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$))?"main_ui_workspace_sidebar_options_menus_constraints__checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_constraints__check-mark "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$1645$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$))?"main_ui_workspace_sidebar_options_menus_constraints__checked":""),children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1645$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$))?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.fix-when-scrolling"),
(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"fixed-on-scroll",checked:$APP.$cljs$cst$1645$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$),onChange:$on_fixed_scroll_clicked$$})]})}):null]})]}):null]}):null};
$app$main$ui$workspace$sidebar$options$menus$layer$opacity__GT_string$$=function($opacity$jscomp$50$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($opacity$jscomp$50$$,$APP.$cljs$cst$1616$multiple$$)?""+$APP.$app$common$data$coalesce$$($opacity$jscomp$50$$)*100:$APP.$cljs$cst$1616$multiple$$};
$app$main$ui$workspace$sidebar$options$menus$layer$on_change$$=function($ids$jscomp$292$$,$prop$jscomp$39$$,$value$jscomp$894$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,function($p1__78973_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78973_SHARP_$$,$prop$jscomp$39$$,$value$jscomp$894$$)}))};
$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$=function($m1_QMARK_$$,$m2_QMARK_$$,$m3_QMARK_$$,$m4_QMARK_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_margins_selected$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1700$m1$$,$m1_QMARK_$$,$APP.$cljs$cst$1701$m2$$,$m2_QMARK_$$,$APP.$cljs$cst$1702$m3$$,$m3_QMARK_$$,$APP.$cljs$cst$1703$m4$$,$m4_QMARK_$$],null)))};
$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$=function($prop$jscomp$40$$){return $app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$40$$,$APP.$cljs$cst$1700$m1$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$40$$,$APP.$cljs$cst$1701$m2$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$40$$,$APP.$cljs$cst$1702$m3$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$40$$,
$APP.$cljs$cst$1703$m4$$))};
$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_simple_STAR_$$=function($props_78991_token_numeric_inputs$jscomp$6$$){var $on_change$jscomp$70$$=$props_78991_token_numeric_inputs$jscomp$6$$.onChange,$m2_placeholder_value$jscomp$899$$=$props_78991_token_numeric_inputs$jscomp$6$$.value,$on_blur$jscomp$21$$=$props_78991_token_numeric_inputs$jscomp$6$$.onBlur,$ids$jscomp$294$$=$props_78991_token_numeric_inputs$jscomp$6$$.ids,$applied_tokens$jscomp$15_token_applied_m2__$1$$=$props_78991_token_numeric_inputs$jscomp$6$$.appliedTokens;
$props_78991_token_numeric_inputs$jscomp$6$$=$app$main$features$use_feature$$("tokens/numeric-input");var $m1$jscomp$18_m1__$1$jscomp$1$$=$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$899$$),$m2$jscomp$15_m2__$1$jscomp$1$$=$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$899$$),$m1_placeholder_m3$jscomp$2$$=$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$899$$),$m4$jscomp$2_on_detach_horizontal$$=
$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$899$$);$m1$jscomp$18_m1__$1$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$899$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m1$jscomp$18_m1__$1$jscomp$1$$,$m1_placeholder_m3$jscomp$2$$)?$m1$jscomp$18_m1__$1$jscomp$1$$:null;$m2$jscomp$15_m2__$1$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$899$$,
$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2$jscomp$15_m2__$1$jscomp$1$$,$m4$jscomp$2_on_detach_horizontal$$)?$m2$jscomp$15_m2__$1$jscomp$1$$:null;var $token_applied_m1_token_applied_m1__$1$$=$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$),$on_focus_m2_token_applied_m2$$=$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$),$on_focus_m1_token_applied_m3$$=
$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$),$on_detach_vertical_token_applied_m4$$=$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$);$token_applied_m1_token_applied_m1__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$15_token_applied_m2__$1$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_applied_m1_token_applied_m1__$1$$,
$on_focus_m1_token_applied_m3$$)?$token_applied_m1_token_applied_m1__$1$$:$APP.$cljs$cst$1616$multiple$$;$applied_tokens$jscomp$15_token_applied_m2__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$15_token_applied_m2__$1$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($on_focus_m2_token_applied_m2$$,$on_detach_vertical_token_applied_m4$$)?$on_focus_m2_token_applied_m2$$:$APP.$cljs$cst$1616$multiple$$;$m1_placeholder_m3$jscomp$2$$=
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$899$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m1$jscomp$18_m1__$1$jscomp$1$$,$m1_placeholder_m3$jscomp$2$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_applied_m1_token_applied_m1__$1$$,$on_focus_m1_token_applied_m3$$)?"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple");$m2_placeholder_value$jscomp$899$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$899$$,
$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2$jscomp$15_m2__$1$jscomp$1$$,$m4$jscomp$2_on_detach_horizontal$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$15_token_applied_m2__$1$$,$on_detach_vertical_token_applied_m4$$)?"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple");var $on_focus$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$)],
function($G__79016_79050__$1_attr$jscomp$81$$,$event$jscomp$549$$){$G__79016_79050__$1_attr$jscomp$81$$=$G__79016_79050__$1_attr$jscomp$81$$ instanceof $APP.$cljs$core$Keyword$$?$G__79016_79050__$1_attr$jscomp$81$$.$fqn$:null;switch($G__79016_79050__$1_attr$jscomp$81$$){case "m1":$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$(!0,!1,!0,!1);break;case "m2":$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$(!1,!0,!1,!0);break;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79016_79050__$1_attr$jscomp$81$$)].join(""));}return $app$util$dom$select_target$$($event$jscomp$549$$)}),$on_detach_token$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$294$$)],function($token_name$jscomp$23$$,$attr$jscomp$82$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$23$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$82$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$294$$],null)))});$m4$jscomp$2_on_detach_horizontal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$9$$)],function($token$jscomp$133$$){return $APP.$cljs$core$run_BANG_$$(function($p1__78981_SHARP_$$){return $on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?
$on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$133$$,$p1__78981_SHARP_$$):$on_detach_token$jscomp$9$$($token$jscomp$133$$,$p1__78981_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$m2$$,$APP.$cljs$cst$1703$m4$$],null))});$on_detach_vertical_token_applied_m4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$9$$)],function($token$jscomp$134$$){return $APP.$cljs$core$run_BANG_$$(function($p1__78982_SHARP_$$){return $on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?
$on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$134$$,$p1__78982_SHARP_$$):$on_detach_token$jscomp$9$$($token$jscomp$134$$,$p1__78982_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1700$m1$$,$APP.$cljs$cst$1702$m3$$],null))});var $on_change_SINGLEQUOTE_$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$70$$),$APP.$rumext$v2$adapt$$($ids$jscomp$294$$)],
function($value__$1$jscomp$57$$,$attr$jscomp$83$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$57$$,function($p1__78983_SHARP_$$){return $on_change$jscomp$70$$.$cljs$core$IFn$_invoke$arity$3$?$on_change$jscomp$70$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1663$simple$$,$attr$jscomp$83$$,$p1__78983_SHARP_$$):$on_change$jscomp$70$$($APP.$cljs$cst$1663$simple$$,$attr$jscomp$83$$,$p1__78983_SHARP_$$)},$ids$jscomp$294$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1700$m1$$,
$attr$jscomp$83$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1702$m3$$,null,$APP.$cljs$cst$1700$m1$$,null],null),null):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1703$m4$$,null,$APP.$cljs$cst$1701$m2$$,null],null),null))});$on_focus_m1_token_applied_m3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$14$$)],function(){return $on_focus$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?
$on_focus$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1700$m1$$):$on_focus$jscomp$14$$($APP.$cljs$cst$1700$m1$$)});$on_focus_m2_token_applied_m2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$14$$)],function(){return $on_focus$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1701$m2$$):$on_focus$jscomp$14$$($APP.$cljs$cst$1701$m2$$)});var $on_m1_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$8$$)],
function($p1__78984_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($p1__78984_SHARP_$$,$APP.$cljs$cst$1700$m1$$):$on_change_SINGLEQUOTE_$jscomp$8$$($p1__78984_SHARP_$$,$APP.$cljs$cst$1700$m1$$)}),$on_m2_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$8$$)],function($p1__78985_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($p1__78985_SHARP_$$,$APP.$cljs$cst$1701$m2$$):$on_change_SINGLEQUOTE_$jscomp$8$$($p1__78985_SHARP_$$,$APP.$cljs$cst$1701$m2$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-simple",children:[$props_78991_token_numeric_inputs$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_m1_change$$,
className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin-wrapper",placeholder:$m1_placeholder_m3$jscomp$2$$,inputType:$APP.$cljs$cst$1990$vertical_margin$$,attr:$APP.$cljs$cst$1700$m1$$,appliedToken:$token_applied_m1_token_applied_m1__$1$$,value:$m1$jscomp$18_m1__$1$jscomp$1$$,onFocus:$on_focus_m1_token_applied_m3$$,onDetach:$on_detach_vertical_token_applied_m4$$,property:"Vertical margin ",onBlur:$on_blur$jscomp$21$$,nillable:!0,"default":null,icon:"margin-top-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",
{title:"Vertical margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_top_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:$m1_placeholder_m3$jscomp$2$$,"data-name":"m1",onFocus:$on_focus_m1_token_applied_m3$$,
onChange:$on_m1_change$$,onBlur:$on_blur$jscomp$21$$,nillable:!0,value:$m1$jscomp$18_m1__$1$jscomp$1$$})]}),$props_78991_token_numeric_inputs$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_m2_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin-wrapper",placeholder:$m2_placeholder_value$jscomp$899$$,inputType:$APP.$cljs$cst$1987$horizontal_margin$$,
attr:$APP.$cljs$cst$1701$m2$$,appliedToken:$applied_tokens$jscomp$15_token_applied_m2__$1$$,value:$m2$jscomp$15_m2__$1$jscomp$1$$,onFocus:$on_focus_m2_token_applied_m2$$,onDetach:$m4$jscomp$2_on_detach_horizontal$$,property:"Horizontal margin",onBlur:$on_blur$jscomp$21$$,nillable:!0,"default":null,icon:"margin-left-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Horizontal margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_left_right$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:$m2_placeholder_value$jscomp$899$$,"data-name":"m2",onFocus:$on_focus_m2_token_applied_m2$$,onChange:$on_m2_change$$,onBlur:$on_blur$jscomp$21$$,nillable:!0,value:$m2$jscomp$15_m2__$1$jscomp$1$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_multiple_STAR_$$=function($props_79023_token_numeric_inputs$jscomp$7$$){var $on_change$jscomp$71$$=$props_79023_token_numeric_inputs$jscomp$7$$.onChange,$m4$jscomp$3_value$jscomp$900$$=$props_79023_token_numeric_inputs$jscomp$7$$.value,$on_blur$jscomp$22$$=$props_79023_token_numeric_inputs$jscomp$7$$.onBlur,$ids$jscomp$295$$=$props_79023_token_numeric_inputs$jscomp$7$$.ids,$applied_token_to_m4_applied_tokens$jscomp$16$$=$props_79023_token_numeric_inputs$jscomp$7$$.appliedTokens;
$props_79023_token_numeric_inputs$jscomp$7$$=$app$main$features$use_feature$$("tokens/numeric-input");var $m1$jscomp$19$$=$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$900$$),$m2$jscomp$16$$=$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$900$$),$m3$jscomp$3$$=$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$900$$);$m4$jscomp$3_value$jscomp$900$$=$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$900$$);
var $applied_token_to_m1$$=$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$),$applied_token_to_m2$$=$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$),$applied_token_to_m3$$=$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$);$applied_token_to_m4_applied_tokens$jscomp$16$$=$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$);
var $on_detach_token$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$295$$)],function($token_name$jscomp$24$$,$attr$jscomp$84$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$24$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$84$$]),
$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$295$$],null)))}),$on_focus$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$)],function($attr$jscomp$85$$,$event$jscomp$550$$){$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$($attr$jscomp$85$$);return $app$util$dom$select_target$$($event$jscomp$550$$)}),$on_focus_m1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$15$$)],
function(){return $on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1700$m1$$):$on_focus$jscomp$15$$($APP.$cljs$cst$1700$m1$$)}),$on_focus_m2$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$15$$)],function(){return $on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1701$m2$$):$on_focus$jscomp$15$$($APP.$cljs$cst$1701$m2$$)}),
$on_focus_m3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$15$$)],function(){return $on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1700$m1$$):$on_focus$jscomp$15$$($APP.$cljs$cst$1700$m1$$)}),$on_focus_m4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$15$$)],function(){return $on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?
$on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1701$m2$$):$on_focus$jscomp$15$$($APP.$cljs$cst$1701$m2$$)}),$on_change_SINGLEQUOTE_$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$71$$),$APP.$rumext$v2$adapt$$($ids$jscomp$295$$)],function($value__$1$jscomp$58$$,$attr$jscomp$86$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$58$$,function($p1__79018_SHARP_$$){return $on_change$jscomp$71$$.$cljs$core$IFn$_invoke$arity$3$?
$on_change$jscomp$71$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1616$multiple$$,$attr$jscomp$86$$,$p1__79018_SHARP_$$):$on_change$jscomp$71$$($APP.$cljs$cst$1616$multiple$$,$attr$jscomp$86$$,$p1__79018_SHARP_$$)},$ids$jscomp$295$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$86$$]))}),$on_m1_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79019_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79019_SHARP_$$,$APP.$cljs$cst$1700$m1$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79019_SHARP_$$,$APP.$cljs$cst$1700$m1$$)}),$on_m2_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79020_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79020_SHARP_$$,
$APP.$cljs$cst$1701$m2$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79020_SHARP_$$,$APP.$cljs$cst$1701$m2$$)}),$on_m3_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79021_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79021_SHARP_$$,$APP.$cljs$cst$1702$m3$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79021_SHARP_$$,
$APP.$cljs$cst$1702$m3$$)}),$on_m4_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79022_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79022_SHARP_$$,$APP.$cljs$cst$1703$m4$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79022_SHARP_$$,$APP.$cljs$cst$1703$m4$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-multiple",children:[$props_79023_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_m1_change$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__top-margin-wrapper",inputType:$APP.$cljs$cst$1990$vertical_margin$$,attr:$APP.$cljs$cst$1700$m1$$,appliedToken:$applied_token_to_m1$$,value:$m1$jscomp$19$$,
onFocus:$on_focus_m1$jscomp$1$$,onDetach:$on_detach_token$jscomp$10$$,property:"Top margin",onBlur:$on_blur$jscomp$22$$,nillable:!0,"default":null,icon:"margin-top"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Top margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__top-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_top$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m1",onFocus:$on_focus_m1$jscomp$1$$,onChange:$on_m1_change$jscomp$1$$,onBlur:$on_blur$jscomp$22$$,nillable:!0,value:$m1$jscomp$19$$})]}),$props_79023_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_m2_change$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__right-margin-wrapper",
inputType:$APP.$cljs$cst$1987$horizontal_margin$$,attr:$APP.$cljs$cst$1701$m2$$,appliedToken:$applied_token_to_m2$$,value:$m2$jscomp$16$$,onFocus:$on_focus_m2$jscomp$1$$,onDetach:$on_detach_token$jscomp$10$$,property:"Right margin",onBlur:$on_blur$jscomp$22$$,nillable:!0,"default":null,icon:"margin-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Right margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__right-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",
children:$APP.$app$main$ui$icons$margin_right$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m2",onFocus:$on_focus_m2$jscomp$1$$,onChange:$on_m2_change$jscomp$1$$,onBlur:$on_blur$jscomp$22$$,nillable:!0,value:$m2$jscomp$16$$})]}),$props_79023_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_m3_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin-wrapper",inputType:$APP.$cljs$cst$1990$vertical_margin$$,attr:$APP.$cljs$cst$1702$m3$$,appliedToken:$applied_token_to_m3$$,value:$m3$jscomp$3$$,onFocus:$on_focus_m3$$,onDetach:$on_detach_token$jscomp$10$$,property:"Bottom margin",onBlur:$on_blur$jscomp$22$$,nillable:!0,"default":null,icon:"margin-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Bottom margin",
className:"main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m3",onFocus:$on_focus_m3$$,onChange:$on_m3_change$$,onBlur:$on_blur$jscomp$22$$,
nillable:!0,value:$m3$jscomp$3$$})]}),$props_79023_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_m4_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__left-margin-wrapper",inputType:$APP.$cljs$cst$1987$horizontal_margin$$,attr:$APP.$cljs$cst$1703$m4$$,appliedToken:$applied_token_to_m4_applied_tokens$jscomp$16$$,value:$m4$jscomp$3_value$jscomp$900$$,
onFocus:$on_focus_m4$$,onDetach:$on_detach_token$jscomp$10$$,property:"Left margin",onBlur:$on_blur$jscomp$22$$,nillable:!0,"default":null,icon:"margin-left"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Left margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__left-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_left$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m4",onFocus:$on_focus_m4$$,onChange:$on_m4_change$$,onBlur:$on_blur$jscomp$22$$,nillable:!0,value:$m4$jscomp$3_value$jscomp$900$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_section_STAR_$$=function($props_79024_props__$1$jscomp$81$$){var $on_type_change$jscomp$3$$=$props_79024_props__$1$jscomp$81$$.onTypeChange,$type__$1$jscomp$17$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_79024_props__$1$jscomp$81$$.type,$APP.$cljs$cst$1663$simple$$),$on_blur$jscomp$23$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$)],
function(){return $app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$(!1,!1,!1,!1)});$props_79024_props__$1$jscomp$81$$={...$props_79024_props__$1$jscomp$81$$,onBlur:$on_blur$jscomp$23$$};var $on_type_change_SINGLEQUOTE_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($on_type_change$jscomp$3$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,
$APP.$cljs$cst$1616$multiple$$)?$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1663$simple$$):$on_type_change$jscomp$3$$($APP.$cljs$cst$1663$simple$$):$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1616$multiple$$):$on_type_change$jscomp$3$$($APP.$cljs$cst$1616$multiple$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return function(){return $on_blur$jscomp$23$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$23$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$23$$()}});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__inputs-wrapper",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,$APP.$cljs$cst$1663$simple$$)?
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$margin_simple_STAR_$$,$props_79024_props__$1$jscomp$81$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,$APP.$cljs$cst$1616$multiple$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$margin_multiple_STAR_$$,$props_79024_props__$1$jscomp$81$$):null}),(0,$APP.$rumext$v2$jsx$$)("button",{title:"Margin - multiple",onClick:$on_type_change_SINGLEQUOTE_$jscomp$1$$,
className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-mode "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,$APP.$cljs$cst$1616$multiple$$)?"main_ui_workspace_sidebar_options_menus_layout_item__selected":""),children:$APP.$app$main$ui$icons$margin$$})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_horizontal$$=function($props_79025$$){var $on_change$jscomp$72$$=$props_79025$$["on-change"],$is_auto$$=$props_79025$$["is-auto"],$has_fill$$=$props_79025$$["has-fill"];return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-behaviour "+($has_fill$$||$is_auto$$?"":"main_ui_workspace_sidebar_options_menus_layout_item__one-element")+" "+($has_fill$$||$is_auto$$?"main_ui_workspace_sidebar_options_menus_layout_item__two-element":
"")+" "+($has_fill$$&&$is_auto$$?"main_ui_workspace_sidebar_options_menus_layout_item__three-element":""),children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($props_79025$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$72$$,name:"flex-behaviour-h",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"fix",icon:"fixed-width",title:"Fix width",id:"behaviour-h-fix"}),
$has_fill$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"fill",icon:"fill-content",title:"Width 100%",id:"behaviour-h-fill"}):null,$is_auto$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"auto",icon:"hug-content",title:"Fit content (Horizontal)",id:"behaviour-h-auto"}):null]})})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_vertical$$=function($props_79026$$){var $on_change$jscomp$73$$=$props_79026$$["on-change"],$is_auto$jscomp$1$$=$props_79026$$["is-auto"],$has_fill$jscomp$1$$=$props_79026$$["has-fill"];return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-behaviour "+($has_fill$jscomp$1$$||$is_auto$jscomp$1$$?"":"main_ui_workspace_sidebar_options_menus_layout_item__one-element")+" "+
($has_fill$jscomp$1$$||$is_auto$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_layout_item__two-element":"")+" "+($has_fill$jscomp$1$$&&$is_auto$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_layout_item__three-element":""),children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($props_79026$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$73$$,name:"flex-behaviour-v",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"fix",icon:"fixed-width","icon-class":"main_ui_workspace_sidebar_options_menus_layout_item__rotated",title:"Fix height",id:"behaviour-v-fix"}),$has_fill$jscomp$1$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"fill",icon:"fill-content","icon-class":"main_ui_workspace_sidebar_options_menus_layout_item__rotated",title:"Height 100%",id:"behaviour-v-fill"}):null,$is_auto$jscomp$1$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"auto",icon:"hug-content","icon-class":"main_ui_workspace_sidebar_options_menus_layout_item__rotated",title:"Fit content (Vertical)",id:"behaviour-v-auto"}):null]})})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$align_self_row$$=function($props_79027$$){var $on_change$jscomp$74$$=$props_79027$$["on-change"],$is_col$$=$props_79027$$["is-col"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($props_79027$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$74$$,name:"flex-align-self","allow-empty":!0,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1292$start$$,$is_col$$),title:"Align self start",id:"align-self-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1667$center$$,$is_col$$),title:"Align self center",
id:"align-self-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1293$end$$,$is_col$$),title:"Align self end",id:"align-self-end"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_size_constraints_STAR_$$=function($props_79033_token_numeric_inputs$jscomp$8$$){var $ids$jscomp$296$$=$props_79033_token_numeric_inputs$jscomp$8$$.ids,$values$jscomp$89$$=$props_79033_token_numeric_inputs$jscomp$8$$.values,$applied_token_to_max_h_applied_tokens$jscomp$17$$=$props_79033_token_numeric_inputs$jscomp$8$$.appliedTokens;$props_79033_token_numeric_inputs$jscomp$8$$=$app$main$features$use_feature$$("tokens/numeric-input");var $v_sizing$jscomp$2$$=
$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$89$$),$min_w$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1707$layout_item_min_w$$),$max_w$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1706$layout_item_max_w$$),$min_h$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1705$layout_item_min_h$$),$max_h$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1704$layout_item_max_h$$),$applied_token_to_min_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1707$layout_item_min_w$$),$applied_token_to_max_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1706$layout_item_max_w$$),$applied_token_to_min_h$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,
$APP.$cljs$cst$1705$layout_item_min_h$$);$applied_token_to_max_h_applied_tokens$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1704$layout_item_max_h$$);var $on_detach_token$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function($token_name$jscomp$25$$,$attr$jscomp$87$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$25$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$87$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$296$$],null)))}),$on_size_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function($value$jscomp$904$$,$attr$jscomp$88$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$904$$,
function($p1__79028_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$attr$jscomp$88$$,$p1__79028_SHARP_$$])))},$ids$jscomp$296$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$88$$]))}),$on_layout_item_min_w_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],
function($p1__79029_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79029_SHARP_$$,$APP.$cljs$cst$1707$layout_item_min_w$$):$on_size_change$jscomp$1$$($p1__79029_SHARP_$$,$APP.$cljs$cst$1707$layout_item_min_w$$)}),$on_layout_item_max_w_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],function($p1__79030_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79030_SHARP_$$,$APP.$cljs$cst$1706$layout_item_max_w$$):$on_size_change$jscomp$1$$($p1__79030_SHARP_$$,$APP.$cljs$cst$1706$layout_item_max_w$$)}),$on_layout_item_min_h_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],function($p1__79031_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79031_SHARP_$$,
$APP.$cljs$cst$1705$layout_item_min_h$$):$on_size_change$jscomp$1$$($p1__79031_SHARP_$$,$APP.$cljs$cst$1705$layout_item_min_h$$)}),$on_layout_item_max_h_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],function($p1__79032_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79032_SHARP_$$,$APP.$cljs$cst$1704$layout_item_max_h$$):$on_size_change$jscomp$1$$($p1__79032_SHARP_$$,
$APP.$cljs$cst$1704$layout_item_max_h$$)});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Layout item size constraints",className:"main_ui_workspace_sidebar_options_menus_layout_item__advanced-options",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$89$$),$APP.$cljs$cst$1403$fill$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-fill",
children:[$props_79033_token_numeric_inputs$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_layout_item_min_w_change$$,inputType:$APP.$cljs$cst$1984$min_width$$,attr:$APP.$cljs$cst$1707$layout_item_min_w$$,appliedToken:$applied_token_to_min_w$$,value:$min_w$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-w"),
nillable:!0,textIcon:"MIN W",tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-w"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MIN W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:0,onChange:$on_layout_item_min_w_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1707$layout_item_min_w$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-min-w"})]}),$props_79033_token_numeric_inputs$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_layout_item_max_w_change$$,inputType:$APP.$cljs$cst$281$max_width$$,attr:$APP.$cljs$cst$1706$layout_item_max_w$$,appliedToken:$applied_token_to_max_w$$,value:$max_w$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-w"),nillable:!0,textIcon:"MAX W",tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):(0,$APP.$rumext$v2$jsxs$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-w"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MAX W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_layout_item_max_w_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",
placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1706$layout_item_max_w$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-max-w"})]})]}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v_sizing$jscomp$2$$,$APP.$cljs$cst$1403$fill$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-fill",children:[$props_79033_token_numeric_inputs$jscomp$8$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_layout_item_min_h_change$$,inputType:$APP.$cljs$cst$1986$max_height$$,attr:$APP.$cljs$cst$1705$layout_item_min_h$$,appliedToken:$applied_token_to_min_h$$,value:$min_h$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-h"),nillable:!0,textIcon:"MIN H",
tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-h"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MIN H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:0,onChange:$on_layout_item_min_h_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1705$layout_item_min_h$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-min-h"})]}),$props_79033_token_numeric_inputs$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_layout_item_max_h_change$$,inputType:$APP.$cljs$cst$1986$max_height$$,attr:$APP.$cljs$cst$1704$layout_item_max_h$$,appliedToken:$applied_token_to_max_h_applied_tokens$jscomp$17$$,value:$max_h$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-h"),nillable:!0,textIcon:"MAX H",tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):
(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-h"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MAX H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_layout_item_max_h_change$$,
className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$89$$,$APP.$cljs$cst$1704$layout_item_max_h$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-max-h"})]})]}):null]})};
$app$main$ui$workspace$sidebar$options$rows$shadow_row$shadow_row_STAR_$$=function($props_79004_shadow_style$$){var $shadow__$1$jscomp$17$$=$props_79004_shadow_style$$.shadow,$on_remove$jscomp$3$$=$props_79004_shadow_style$$.onRemove,$is_open$jscomp$10$$=$props_79004_shadow_style$$.isOpen,$index$jscomp$506$$=$props_79004_shadow_style$$.index,$on_toggle_open$$=$props_79004_shadow_style$$.onToggleOpen,$on_detach_color$$=$props_79004_shadow_style$$.onDetachColor,$on_reorder$jscomp$4$$=$props_79004_shadow_style$$.onReorder,
$on_update$$=$props_79004_shadow_style$$.onUpdate,$on_toggle_visibility$jscomp$2$$=$props_79004_shadow_style$$.onToggleVisibility;$props_79004_shadow_style$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$);var $shadow_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$),$hidden_QMARK_$jscomp$7$$=$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$),$dprops$jscomp$6_on_drop$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reorder$jscomp$4$$),
$APP.$rumext$v2$adapt$$($index$jscomp$506$$)],function($relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$,$data$jscomp$487_from_pos$jscomp$16$$){$data$jscomp$487_from_pos$jscomp$16$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$487_from_pos$jscomp$16$$);$relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$,$APP.$cljs$cst$2952$bot$$)?$index$jscomp$506$$+
1:$index$jscomp$506$$;return $on_reorder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$487_from_pos$jscomp$16$$,$relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$):$on_reorder$jscomp$4$$($data$jscomp$487_from_pos$jscomp$16$$,$relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$)}),$dref$jscomp$6_vec__79010$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,
"penpot/shadow-entry",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$6_on_drop$jscomp$13$$,$APP.$cljs$cst$2958$detect_center_QMARK_$$,!1,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$506$$],null)]));$dprops$jscomp$6_on_drop$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$6_vec__79010$$,0,null);$dref$jscomp$6_vec__79010$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$6_vec__79010$$,
1,null);var $on_remove__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$)],function(){return $on_remove$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$506$$):$on_remove$jscomp$3$$($index$jscomp$506$$)}),$trigger_bounding_box_cloaking$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shadow_id$$)],function(){return $APP.$cljs$core$truth_$$($shadow_id$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shadow_id$$],null))):null}),$on_update_offset_x$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($value$jscomp$910$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?
$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$506$$,$APP.$cljs$cst$1650$offset_x$$,$value$jscomp$910$$):$on_update$$($index$jscomp$506$$,$APP.$cljs$cst$1650$offset_x$$,$value$jscomp$910$$)}),$on_update_offset_y$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],
function($value$jscomp$911$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$506$$,$APP.$cljs$cst$1651$offset_y$$,$value$jscomp$911$$):$on_update$$($index$jscomp$506$$,$APP.$cljs$cst$1651$offset_y$$,$value$jscomp$911$$)}),$on_update_spread$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),
$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($value$jscomp$912$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$506$$,$APP.$cljs$cst$1652$spread$$,$value$jscomp$912$$):$on_update$$($index$jscomp$506$$,$APP.$cljs$cst$1652$spread$$,$value$jscomp$912$$)}),
$on_update_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($value$jscomp$913$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$506$$,$APP.$cljs$cst$1653$blur$$,
$value$jscomp$913$$):$on_update$$($index$jscomp$506$$,$APP.$cljs$cst$1653$blur$$,$value$jscomp$913$$)}),$on_update_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),$APP.$rumext$v2$adapt$$($on_update$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($color$jscomp$167$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();
return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$506$$,$APP.$cljs$cst$1298$color$$,$color$jscomp$167$$):$on_update$$($index$jscomp$506$$,$APP.$cljs$cst$1298$color$$,$color$jscomp$167$$)}),$on_detach_color__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$)],function(){return $on_detach_color$$.$cljs$core$IFn$_invoke$arity$1$?$on_detach_color$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$506$$):
$on_detach_color$$($index$jscomp$506$$)}),$on_style_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($G__79015_value$jscomp$914$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();$G__79015_value$jscomp$914$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79015_value$jscomp$914$$);
return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$506$$,$APP.$cljs$cst$1904$style$$,$G__79015_value$jscomp$914$$):$on_update$$($index$jscomp$506$$,$APP.$cljs$cst$1904$style$$,$G__79015_value$jscomp$914$$)}),$on_toggle_visibility__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$506$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function(){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?
$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_toggle_visibility$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_visibility$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$506$$):$on_toggle_visibility$jscomp$2$$($index$jscomp$506$$)}),$on_toggle_open__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shadow_id$$),$APP.$rumext$v2$adapt$$($on_toggle_open$$)],function(){return $on_toggle_open$$.$cljs$core$IFn$_invoke$arity$1$?
$on_toggle_open$$.$cljs$core$IFn$_invoke$arity$1$($shadow_id$$):$on_toggle_open$$($shadow_id$$)}),$type_options$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"drop-shadow",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.drop-shadow")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"inner-shadow",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.inner-shadow")],null)],null)}),$on_open_row$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$5709$color_row$$))}),$on_close_row$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($cljs$cst$5709$color_row$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"shadow-option main_ui_workspace_sidebar_options_rows_shadow_row__shadow-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$6_on_drop$jscomp$13$$),
$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_sidebar_options_rows_shadow_row__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$6_on_drop$jscomp$13$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_options_rows_shadow_row__dnd-over-bot":""),children:[$on_reorder$jscomp$4$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$6_vec__79010$$}):
null,(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-info",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",icon:"menu",className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-button "+
($APP.$cljs$core$truth_$$($is_open$jscomp$10$$)?"main_ui_workspace_sidebar_options_rows_shadow_row__selected":""),"aria-label":"open more options",disabled:$hidden_QMARK_$jscomp$7$$,onClick:$on_toggle_open__$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-select","default-value":$APP.$app$common$data$name$$($props_79004_shadow_style$$),options:$type_options$jscomp$1$$,disabled:$hidden_QMARK_$jscomp$7$$,
"on-change":$on_style_change$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.toggle-shadow"),onClick:$on_toggle_visibility__$1$$,icon:$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$7$$)?"hide":"shown"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.remove-shadow"),onClick:$on_remove__$1$$,icon:"remove"})]})]}),$APP.$cljs$core$truth_$$($is_open$jscomp$10$$)?(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced",isVisible:$is_open$jscomp$10$$,onClose:$on_toggle_open__$1$$,children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.offsetx"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",children:"X"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,placeholder:"--",onChange:$on_update_offset_x$$,value:$APP.$cljs$cst$1650$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.blur"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.blur")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:"--",onChange:$on_update_blur$$,min:0,value:$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.spread"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.spread")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:"--",onChange:$on_update_spread$$,value:$APP.$cljs$cst$1652$spread$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.offsety"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",children:"Y"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,placeholder:"--",onChange:$on_update_offset_y$$,value:$APP.$cljs$cst$1651$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$APP.$cljs$cst$1654$shadow$$,onClose:$on_close_row$$,onChange:$on_update_color$$,className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-color",onDetach:$on_detach_color__$1$$,disableGradient:!0,disableImage:!0,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.color"),color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$),onOpen:$on_open_row$$})]})]}):null]})]})};
$app$main$ui$workspace$sidebar$options$menus$shadow$remove_shadow_by_index$$=function($values$jscomp$91$$,$index$jscomp$507$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filterv$$(function($p__79039$$){var $idx$jscomp$126$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79039$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79039$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$126$$,
$index$jscomp$507$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$91$$)))};
$app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$=function($props_79048_shadows$jscomp$4$$){var $ids$jscomp$298$$=$props_79048_shadows$jscomp$4$$.ids,$type$jscomp$657$$=$props_79048_shadows$jscomp$4$$.type,$values$jscomp$92$$=$props_79048_shadows$jscomp$4$$.values;$props_79048_shadows$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($values$jscomp$92$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$values$jscomp$92$$)?$values$jscomp$92$$:$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$shadow$xf_COLON_add_index$$,$values$jscomp$92$$))});var $ids_ref$$=$app$main$ui$hooks$use_update_ref$$($ids$jscomp$298$$),$open_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$open_state$$=$APP.$cljs$core$_deref$$($open_state_STAR_$$),
$has_shadows_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$props_79048_shadows$jscomp$4$$)||$APP.$cljs$core$seq$$($props_79048_shadows$jscomp$4$$)!=null,$show_content_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$show_content_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($show_content_STAR_$jscomp$3$$),$toggle_content$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$jscomp$3$$,
$APP.$cljs$core$not$$)}),$on_toggle_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79043_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($open_state_STAR_$$,$APP.$cljs$core$update$$,$p1__79043_SHARP_$$,$APP.$cljs$core$not$$)}),$on_remove_all$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $ids__$1$jscomp$23$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$23$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$23$$,function($p1__79044_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__79044_SHARP_$$,$APP.$cljs$cst$1654$shadow$$)}))}),$handle_reorder$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($from_pos$jscomp$17$$,$to_space_between_pos$jscomp$17$$){var $ids__$1$jscomp$24$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$24$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$reorder_shadows$$($ids__$1$jscomp$24$$,$from_pos$jscomp$17$$,$to_space_between_pos$jscomp$17$$))}),$on_add_shadow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $ids__$1$jscomp$25$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$25$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$add_shadow$$($ids__$1$jscomp$25$$))}),$on_detach_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$509$$){var $ids__$1$jscomp$26$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$26$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$26$$,function($p1__79045_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__79045_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$index$jscomp$509$$,$APP.$cljs$cst$1298$color$$],null),$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1736$ref_file$$]))}))}),$on_toggle_visibility$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$510$$){var $ids__$1$jscomp$27$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$27$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$27$$,function($p1__79046_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__79046_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$index$jscomp$510$$,$APP.$cljs$cst$1620$hidden$$],null),$APP.$cljs$core$not$$)}))}),
$on_remove$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$298$$)],function($index$jscomp$511$$){var $ids__$1$jscomp$28$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$28$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$28$$,
function($p1__79047_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__79047_SHARP_$$,$APP.$cljs$cst$1654$shadow$$,$app$main$ui$workspace$sidebar$options$menus$shadow$remove_shadow_by_index$$,$index$jscomp$511$$)}))}),$on_update$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$512$$,$attr$jscomp$89$$,$value$jscomp$915$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($ids_ref$$),
function($shape$jscomp$1014$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1014$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$index$jscomp$512$$],null),function($shadow__$1$jscomp$19$$){return(0,$APP.$app$common$types$shape$shadow$check_shadow$$)($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shadow__$1$jscomp$19$$,$attr$jscomp$89$$,$value$jscomp$915$$))})}))});return(0,$APP.$rumext$v2$jsxs$$)("div",
{"data-testid":"shadow-section",className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_shadows_QMARK_$$,collapsed:$APP.$cljs$core$not$$($show_content_QMARK_$jscomp$4$$),onCollapsed:$toggle_content$jscomp$10$$,title:function(){switch($type$jscomp$657$$ instanceof
$APP.$cljs$core$Keyword$$?$type$jscomp$657$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.title.multiple");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.title.group");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.title")}}(),className:$has_shadows_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_shadow__shadow-title-bar",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$props_79048_shadows$jscomp$4$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.add-shadow"),onClick:$on_add_shadow$$,icon:"add","data-testid":"add-shadow"})})}),$APP.$cljs$core$truth_$$($show_content_QMARK_$jscomp$4$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$props_79048_shadows$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-content",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-multiple-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.remove-shadow"),onClick:$on_remove_all$jscomp$2$$,icon:"remove"})]})}):$props_79048_shadows$jscomp$4$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$172$$,
$map__79054__$1_p__79053$$){$map__79054__$1_p__79053$$=$APP.$cljs$core$__destructure_map$$($map__79054__$1_p__79053$$);var $index$jscomp$513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79054__$1_p__79053$$,$cljs$cst$5710$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_menus_DOT_shadow_SLASH_index$$),$id$jscomp$970$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79054__$1_p__79053$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$172$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$shadow_row$shadow_row_STAR_$$,
{onRemove:$on_remove$jscomp$4$$,onToggleVisibility:$on_toggle_visibility$jscomp$3$$,index:$index$jscomp$513$$,onUpdate:$on_update$jscomp$1$$,onReorder:$handle_reorder$$,shadow:$map__79054__$1_p__79053$$,onDetachColor:$on_detach_color$jscomp$1$$,onToggleOpen:$on_toggle_open$jscomp$1$$,isOpen:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_state$$,$id$jscomp$970$$)},""+($index$jscomp$513$$??"")));return $out_arr__44124__auto__$jscomp$172$$},[],$props_79048_shadows$jscomp$4$$)})}):null:null]})};
$app$main$ui$workspace$sidebar$options$rows$stroke_row$stroke_row_STAR_$$=function($hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$){var $on_remove$jscomp$5$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onRemove,$on_detach_token$jscomp$12$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onDetachToken,$on_stroke_style_change$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onStrokeStyleChange,$stroke$jscomp$34$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.stroke,
$select_on_focus$jscomp$4$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.selectOnFocus,$index$jscomp$514$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.index,$on_stroke_alignment_change$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onStrokeAlignmentChange,$disable_stroke_style$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.disableStrokeStyle,$disable_drag$jscomp$2$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.disableDrag,$on_focus$jscomp$16$$=
$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onFocus,$on_stroke_width_change$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onStrokeWidthChange,$on_blur$jscomp$24$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onBlur,$ids$jscomp$299$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.ids,$on_stroke_cap_start_change$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onStrokeCapStartChange,$title$jscomp$40$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.title,
$on_reorder$jscomp$5$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onReorder,$on_color_change$jscomp$1$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onColorChange,$on_stroke_cap_switch$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onStrokeCapSwitch,$show_caps$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.showCaps,$on_toggle_visibility$jscomp$4$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onToggleVisibility,$on_stroke_cap_end_change$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onStrokeCapEndChange,
$applied_tokens$jscomp$19$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.appliedTokens,$on_color_detach$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$.onColorDetach;$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$=$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$=$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$==null?!1:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$;
var $token_numeric_inputs$jscomp$9$$=$app$main$features$use_feature$$("tokens/numeric-input"),$dprops$jscomp$7_on_drop$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reorder$jscomp$5$$),$APP.$rumext$v2$adapt$$($index$jscomp$514$$)],function($relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$,$data$jscomp$488_from_pos$jscomp$18$$){$data$jscomp$488_from_pos$jscomp$18$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$488_from_pos$jscomp$18$$);
$relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$,$APP.$cljs$cst$2952$bot$$)?$index$jscomp$514$$+1:$index$jscomp$514$$;return $on_reorder$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$488_from_pos$jscomp$18$$,$relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$):$on_reorder$jscomp$5$$($data$jscomp$488_from_pos$jscomp$18$$,
$relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$)}),$dref$jscomp$7_vec__79062$$=$on_reorder$jscomp$5$$!=null?$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/stroke-row",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$7_on_drop$jscomp$14$$,$APP.$cljs$cst$2948$disabled$$,$APP.$cljs$core$_deref$$($disable_drag$jscomp$2$$),$APP.$cljs$cst$2958$detect_center_QMARK_$$,
!1,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$514$$],null)])):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null);$dprops$jscomp$7_on_drop$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$7_vec__79062$$,0,null);$dref$jscomp$7_vec__79062$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$7_vec__79062$$,1,null);var $stroke_color_token$$=
$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$19$$),$on_color_change_refactor$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_color_change$jscomp$1$$)],function($color$jscomp$168$$){return $on_color_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_color_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,$color$jscomp$168$$):$on_color_change$jscomp$1$$($index$jscomp$514$$,
$color$jscomp$168$$)}),$on_color_detach__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_color_detach$$)],function($_$jscomp$3033$$,$color$jscomp$169$$){return $on_color_detach$$.$cljs$core$IFn$_invoke$arity$2$?$on_color_detach$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,$color$jscomp$169$$):$on_color_detach$$($index$jscomp$514$$,$color$jscomp$169$$)}),$on_remove__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),
$APP.$rumext$v2$adapt$$($on_remove$jscomp$5$$)],function(){return $on_remove$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$514$$):$on_remove$jscomp$5$$($index$jscomp$514$$)}),$stroke_width$jscomp$8$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$),$on_width_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_stroke_width_change$$),
$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function($value$jscomp$916$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$916$$,function($p1__79056_SHARP_$$){return $on_stroke_width_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_width_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,$p1__79056_SHARP_$$):$on_stroke_width_change$$($index$jscomp$514$$,$p1__79056_SHARP_$$)},$ids$jscomp$299$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1655$stroke_width$$,null],null),null))}),$stroke_alignment$$=function(){var $or__5025__auto__$jscomp$1198$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1198$$)?$or__5025__auto__$jscomp$1198$$:$APP.$cljs$cst$1667$center$$}(),$stroke_alignment_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stroke_alignment$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$stroke_alignment$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$2287$label$$,"--"],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.center"),$APP.$cljs$cst$266$id$$,"center",$APP.$cljs$cst$1721$icon$$,"stroke-center"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2041$inner$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.inner"),$APP.$cljs$cst$266$id$$,"inner",$APP.$cljs$cst$1721$icon$$,
"stroke-inside"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2042$outer$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.outer"),$APP.$cljs$cst$266$id$$,"outer",$APP.$cljs$cst$1721$icon$$,"stroke-outside"],null)],null)]))}),$on_alignment_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_stroke_alignment_change$$)],
function($G__79066_p1__79057_SHARP_$$){$G__79066_p1__79057_SHARP_$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79066_p1__79057_SHARP_$$);return $on_stroke_alignment_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_alignment_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,$G__79066_p1__79057_SHARP_$$):$on_stroke_alignment_change$$($index$jscomp$514$$,$G__79066_p1__79057_SHARP_$$)}),$on_token_change$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],
function($_$jscomp$3034$$,$token$jscomp$135$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$token$jscomp$135$$,$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$299$$,
$APP.$cljs$cst$4653$expand_with_children$$,!0],null)))}),$stroke_style$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1199$$=$APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1199$$)?$or__5025__auto__$jscomp$1199$$:$APP.$cljs$cst$2037$solid$$}(),$stroke_style_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stroke_style$jscomp$3$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$stroke_style$jscomp$3$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$2287$label$$,"--"],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.solid"),$APP.$cljs$cst$266$id$$,"solid",$APP.$cljs$cst$1721$icon$$,"stroke-solid"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2040$dotted$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.dotted"),$APP.$cljs$cst$266$id$$,"dotted",$APP.$cljs$cst$1721$icon$$,
"stroke-dotted"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2039$dashed$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.dashed"),$APP.$cljs$cst$266$id$$,"dashed",$APP.$cljs$cst$1721$icon$$,"stroke-dashed"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2038$mixed$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.mixed"),
$APP.$cljs$cst$266$id$$,"mixed",$APP.$cljs$cst$1721$icon$$,"stroke-mixed"],null)],null)]))}),$on_style_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_stroke_style_change$$)],function($G__79068_p1__79058_SHARP_$$){$G__79068_p1__79058_SHARP_$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79068_p1__79058_SHARP_$$);return $on_stroke_style_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_style_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,
$G__79068_p1__79058_SHARP_$$):$on_stroke_style_change$$($index$jscomp$514$$,$G__79068_p1__79058_SHARP_$$)}),$on_caps_start_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_stroke_cap_start_change$$)],function($G__79070_p1__79059_SHARP_$$){$G__79070_p1__79059_SHARP_$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79070_p1__79059_SHARP_$$);return $on_stroke_cap_start_change$$.$cljs$core$IFn$_invoke$arity$2$?
$on_stroke_cap_start_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,$G__79070_p1__79059_SHARP_$$):$on_stroke_cap_start_change$$($index$jscomp$514$$,$G__79070_p1__79059_SHARP_$$)}),$on_caps_end_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_stroke_cap_end_change$$)],function($G__79072_p1__79060_SHARP_$$){$G__79072_p1__79060_SHARP_$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79072_p1__79060_SHARP_$$);
return $on_stroke_cap_end_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_cap_end_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,$G__79072_p1__79060_SHARP_$$):$on_stroke_cap_end_change$$($index$jscomp$514$$,$G__79072_p1__79060_SHARP_$$)}),$on_detach_token_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$12$$)],function($token$jscomp$136$$){var $G__79074$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null);return $on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$136$$,$G__79074$$):$on_detach_token$jscomp$12$$($token$jscomp$136$$,$G__79074$$)}),$on_detach_token_width$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$12$$)],function($token$jscomp$137$$){var $G__79076$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,null],null),null);return $on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$137$$,$G__79076$$):$on_detach_token$jscomp$12$$($token$jscomp$137$$,$G__79076$$)}),$stroke_caps_options$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
null,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.none")],null),$APP.$cljs$cst$1472$separator$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2013$line_arrow$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.line-arrow-short"),$APP.$cljs$cst$1721$icon$$,$cljs$cst$5711$stroke_arrow$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2015$triangle_arrow$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.triangle-arrow-short"),$APP.$cljs$cst$1721$icon$$,$cljs$cst$5712$stroke_triangle$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2017$square_marker$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.square-marker-short"),
$APP.$cljs$cst$1721$icon$$,$cljs$cst$5713$stroke_rectangle$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2016$circle_marker$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.circle-marker-short"),$APP.$cljs$cst$1721$icon$$,$cljs$cst$5714$stroke_circle$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2014$diamond_marker$$,$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.diamond-marker-short"),$APP.$cljs$cst$1721$icon$$,$cljs$cst$5715$stroke_diamond$$],null),$APP.$cljs$cst$1472$separator$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2012$round$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.round"),$APP.$cljs$cst$1721$icon$$,$cljs$cst$5716$stroke_rounded$$],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1933$square$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.square"),$APP.$cljs$cst$1721$icon$$,$cljs$cst$5717$stroke_squared$$],null)],null),$on_cap_switch$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_stroke_cap_switch$$)],function(){return $on_stroke_cap_switch$$.$cljs$core$IFn$_invoke$arity$1$?
$on_stroke_cap_switch$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$514$$):$on_stroke_cap_switch$$($index$jscomp$514$$)}),$on_toggle_visibility__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$514$$),$APP.$rumext$v2$adapt$$($on_toggle_visibility$jscomp$4$$)],function(){return $APP.$cljs$core$truth_$$($on_toggle_visibility$jscomp$4$$)?$on_toggle_visibility$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_visibility$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$514$$):
$on_toggle_visibility$jscomp$4$$($index$jscomp$514$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{"aria-label":["stroke-row-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$514$$)].join(""),className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$)?"main_ui_workspace_sidebar_options_rows_stroke_row__hidden":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$7_on_drop$jscomp$14$$),
$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_sidebar_options_rows_stroke_row__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$7_on_drop$jscomp$14$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_options_rows_stroke_row__dnd-over-bot":""),children:[$on_reorder$jscomp$5$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$7_vec__79062$$}):
null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-color-actions",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$APP.$cljs$cst$1739$stroke_color$$,index:$index$jscomp$514$$,onChange:$on_color_change_refactor$$,selectOnFocus:$select_on_focus$jscomp$4$$,onTokenChange:$on_token_change$jscomp$6$$,disableDrag:$disable_drag$jscomp$2$$,onDetachToken:$on_detach_token_color$$,appliedToken:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$514$$,
0)?$stroke_color_token$$:null,onFocus:$on_focus$jscomp$16$$,onDetach:$on_color_detach__$1$$,onBlur:$on_blur$jscomp$24$$,title:$title$jscomp$40$$,color:$APP.$app$common$types$color$stroke__GT_color$$($stroke$jscomp$34$$)}),$on_toggle_visibility__$1$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.toggle-stroke"),onClick:$on_toggle_visibility__$1$jscomp$1$$,
icon:$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$)?"hide":"shown"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.remove-stroke"),onClick:$on_remove__$1$jscomp$1$$,icon:"remove"})]}),$token_numeric_inputs$jscomp$9$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options-tokens",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_width_change$jscomp$1$$,className:"main_ui_workspace_sidebar_options_rows_stroke_row__numeric-input-wrapper",attr:$APP.$cljs$cst$1655$stroke_width$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$19$$,$APP.$cljs$cst$1655$stroke_width$$),value:$stroke_width$jscomp$8$$,onFocus:$on_focus$jscomp$16$$,onDetach:$on_detach_token_width$$,
property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-width"),onBlur:$on_blur$jscomp$24$$,icon:"stroke-size"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:$APP.$app$common$data$name$$($stroke_alignment$$),options:$stroke_alignment_options$$,variant:"icon-only","data-testid":"stroke.alignment",disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$)?
!0:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,wrapperClass:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-align-icon-select",onChange:$on_alignment_change$$}),$APP.$cljs$core$truth_$$($disable_stroke_style$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:$APP.$app$common$data$name$$($stroke_style$jscomp$3$$),options:$stroke_style_options$$,wrapperClass:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-style-icon-select",
"data-testid":"stroke.style",variant:"icon-only",disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$)?!0:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,dropdownAlignment:$APP.$cljs$cst$258$right$$,onChange:$on_style_change$jscomp$1$$})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-width"),className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"stroke-size",size:"s"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:$stroke_width$jscomp$8$$,min:0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),
onChange:$on_width_change$jscomp$1$$,onFocus:$on_focus$jscomp$16$$,selectOnFocus:$select_on_focus$jscomp$4$$,onBlur:$on_blur$jscomp$24$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"stroke.alignment",className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-alignment-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$stroke_alignment$$,options:$stroke_alignment_options$$,disabled:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,
"on-change":$on_alignment_change$$})}),$APP.$cljs$core$truth_$$($disable_stroke_style$$)?null:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"stroke.style",className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-style-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$stroke_style$jscomp$3$$,options:$stroke_style_options$$,disabled:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,"on-change":$on_style_change$jscomp$1$$})})]}),
$APP.$cljs$core$truth_$$($show_caps$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-caps-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1865$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$),options:$stroke_caps_options$$,disabled:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,"on-change":$on_caps_start_change$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"secondary","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.switch"),disabled:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,onClick:$on_cap_switch$$,icon:"switch"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1869$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$),options:$stroke_caps_options$$,disabled:$hidden_QMARK_$jscomp$8_hidden_QMARK___$1_props_79061$$,"on-change":$on_caps_end_change$$})]}):
null]})};
$app$main$ui$workspace$sidebar$options$shapes$bool$options_STAR_$$=function($props_79088_type$jscomp$659$$){var $file_id$jscomp$410$$=$props_79088_type$jscomp$659$$.fileId,$page_id$jscomp$425$$=$props_79088_type$jscomp$659$$.pageId,$shape$jscomp$1015$$=$props_79088_type$jscomp$659$$.shape,$id$jscomp$971$$=$shape$jscomp$1015$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1015$$,$APP.$cljs$cst$266$id$$);$props_79088_type$jscomp$659$$=$shape$jscomp$1015$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1015$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$301$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$971$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$971$$],null)}),$shapes$jscomp$211$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1015$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1015$$],null)}),$applied_tokens$jscomp$21$$=$APP.$cljs$core$seq$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1015$$,$APP.$cljs$cst$1873$applied_tokens$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1015$$,$APP.$cljs$cst$1873$applied_tokens$$):null,$measure_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,
$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),
$layout_container_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref_is_layout_child_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$301$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$301$$)}),$is_layout_child_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref_is_layout_child_ref$$);
$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref_is_layout_child_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$301$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$301$$)});$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref_is_layout_child_ref$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref_is_layout_child_ref$$);var $is_grid_parent_ref_is_layout_child_absolute_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$301$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$301$$)}),$is_grid_parent_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref_is_layout_child_absolute_QMARK_$$);$is_grid_parent_ref_is_layout_child_absolute_QMARK_$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1015$$);var $parents$jscomp$13_parents_by_ids_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$301$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$301$$)});$parents$jscomp$13_parents_by_ids_ref$$=$APP.$rumext$v2$deref$$($parents$jscomp$13_parents_by_ids_ref$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$301$$,type:$props_79088_type$jscomp$659$$,appliedTokens:$applied_tokens$jscomp$21$$,values:$layer_values$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$301$$,appliedTokens:$applied_tokens$jscomp$21$$,type:$props_79088_type$jscomp$659$$,values:$measure_values$$,shapes:$shapes$jscomp$211$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79088_type$jscomp$659$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1015$$)],null),values:$layout_container_values$$,
"applied-tokens":$applied_tokens$jscomp$21$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$806$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$301$$),1);return $and__5023__auto__$jscomp$806$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$1$$)?$is_grid_parent_QMARK_$jscomp$1$$:$is_layout_child_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$806$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,
{shape:$APP.$cljs$core$first$$($parents$jscomp$13_parents_by_ids_ref$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$13_parents_by_ids_ref$$),$APP.$cljs$core$first$$($ids$jscomp$301$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{ids:$ids$jscomp$301$$,type:$props_79088_type$jscomp$659$$,values:$layout_item_values$$,
"is-layout-child?":!0,"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref_is_layout_child_ref$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$1$$,"applied-tokens":$applied_tokens$jscomp$21$$,shape:$shape$jscomp$1015$$}):null,!$is_layout_child_QMARK_$jscomp$1$$||$is_grid_parent_ref_is_layout_child_absolute_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$301$$,values:$constraint_values$$}):null,
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$301$$,type:$props_79088_type$jscomp$659$$,values:$shape$jscomp$1015$$,appliedTokens:$applied_tokens$jscomp$21$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$301$$,type:$props_79088_type$jscomp$659$$,showCaps:!0,values:$stroke_values$$,appliedTokens:$applied_tokens$jscomp$21$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,
{ids:$ids$jscomp$301$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1015$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$301$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,
{type:$props_79088_type$jscomp$659$$,ids:$ids$jscomp$301$$,shapes:$shapes$jscomp$211$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1015$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$425$$,fileId:$file_id$jscomp$410$$})]})};
$app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$=function($open_QMARK_$jscomp$25_props_79095$$){var $ids$jscomp$302$$=$open_QMARK_$jscomp$25_props_79095$$.ids,$attrs$jscomp$178_values$jscomp$94$$=$open_QMARK_$jscomp$25_props_79095$$.values,$state_STAR_$jscomp$21$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$25_props_79095$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$21$$);$attrs$jscomp$178_values$jscomp$94$$=$APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$178_values$jscomp$94$$);
var $has_attributes_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$attrs$jscomp$178_values$jscomp$94$$)||$APP.$cljs$core$seq$$($attrs$jscomp$178_values$jscomp$94$$)!=null,$toggle_content$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$21$$,$APP.$cljs$core$not$$)}),$handle_change$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$302$$)],
function($attr$jscomp$91$$,$value$jscomp$924$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$302$$,function($shape$jscomp$1016$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1016$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],null),
$attr$jscomp$91$$),$value$jscomp$924$$)}))}),$handle_delete$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$302$$)],function($attr$jscomp$92$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$302$$,function($shape$jscomp$1017_shape__$1$jscomp$108$$){var $update_path$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],null),$APP.$cljs$core$butlast$$($attr$jscomp$92$$));$shape$jscomp$1017_shape__$1$jscomp$108$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1017_shape__$1$jscomp$108$$,$update_path$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$last$$($attr$jscomp$92$$));return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1017_shape__$1$jscomp$108$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null)))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1017_shape__$1$jscomp$108$$,$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1904$style$$):$shape$jscomp$1017_shape__$1$jscomp$108$$}))});return $APP.$cljs$core$empty_QMARK_$$($attrs$jscomp$178_values$jscomp$94$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__element-set",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__element-set-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_attributes_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$25_props_79095$$),onCollapsed:$toggle_content$jscomp$12$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.options.svg-attrs.title"),className:$has_attributes_QMARK_$$?
"":"main_ui_workspace_sidebar_options_menus_svg_attrs__title-spacing-svg-attrs"})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$25_props_79095$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__element-set-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$175$$,$attr_value$jscomp$6_p__79097$$){var $attr_key$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$6_p__79097$$,
0,null);$attr_value$jscomp$6_p__79097$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$6_p__79097$$,1,null);$out_arr__44124__auto__$jscomp$175$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$,{attr:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$attr_key$jscomp$6$$],null),value:$attr_value$jscomp$6_p__79097$$,onChange:$handle_change$jscomp$11$$,onDelete:$handle_delete$jscomp$2$$},
$attr_key$jscomp$6$$));return $out_arr__44124__auto__$jscomp$175$$},[],$attrs$jscomp$178_values$jscomp$94$$)}):null]})};
$app$main$ui$workspace$sidebar$options$shapes$circle$options_STAR_$$=function($props_79101_type$jscomp$660$$){var $file_id$jscomp$411$$=$props_79101_type$jscomp$660$$.fileId,$page_id$jscomp$426$$=$props_79101_type$jscomp$660$$.pageId,$shape$jscomp$1018$$=$props_79101_type$jscomp$660$$.shape,$id$jscomp$972$$=$shape$jscomp$1018$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1018$$,$APP.$cljs$cst$266$id$$);$props_79101_type$jscomp$660$$=$shape$jscomp$1018$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1018$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$303$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$972$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$972$$],null)}),$shapes$jscomp$212$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1018$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1018$$],null)}),$applied_tokens$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1018$$,$APP.$cljs$cst$1873$applied_tokens$$),$measure_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,
$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$303$$)}),$is_layout_child_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$);$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$303$$)});$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$);var $is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$303$$)}),$is_grid_parent_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$);$is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1018$$);var $parents$jscomp$14_parents_by_ids_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$303$$)});$parents$jscomp$14_parents_by_ids_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($parents$jscomp$14_parents_by_ids_ref$jscomp$1$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$303$$,type:$props_79101_type$jscomp$660$$,appliedTokens:$applied_tokens$jscomp$22$$,values:$layer_values$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$303$$,appliedTokens:$applied_tokens$jscomp$22$$,type:$props_79101_type$jscomp$660$$,values:$measure_values$jscomp$1$$,shapes:$shapes$jscomp$212$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79101_type$jscomp$660$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1018$$)],null),values:$layout_container_values$jscomp$1$$,
"applied-tokens":$applied_tokens$jscomp$22$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$807$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$303$$),1);return $and__5023__auto__$jscomp$807$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$2$$)?$is_grid_parent_QMARK_$jscomp$2$$:$is_layout_child_QMARK_$jscomp$2$$:$and__5023__auto__$jscomp$807$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,
{shape:$APP.$cljs$core$first$$($parents$jscomp$14_parents_by_ids_ref$jscomp$1$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$14_parents_by_ids_ref$jscomp$1$$),$APP.$cljs$core$first$$($ids$jscomp$303$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$,
"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$2$$,ids:$ids$jscomp$303$$,type:$props_79101_type$jscomp$660$$,values:$layout_item_values$jscomp$1$$,shape:$shape$jscomp$1018$$,"applied-tokens":$applied_tokens$jscomp$22$$,"is-layout-child?":!0,"is-layout-container?":!1}):null,!$is_layout_child_QMARK_$jscomp$2$$||$is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$303$$,
values:$constraint_values$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$303$$,type:$props_79101_type$jscomp$660$$,values:$shape$jscomp$1018$$,appliedTokens:$applied_tokens$jscomp$22$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$303$$,type:$props_79101_type$jscomp$660$$,values:$stroke_values$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$22$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$303$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1018$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$303$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$303$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79101_type$jscomp$660$$,ids:$ids$jscomp$303$$,
shapes:$shapes$jscomp$212$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1018$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$426$$,fileId:$file_id$jscomp$411$$})]})};
$app$main$ui$workspace$sidebar$options$menus$color_selection$prepare_colors$$=function($groups$jscomp$14_shapes$jscomp$213$$,$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$,$libraries$jscomp$148_token_colors$$){$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$),$APP.$app$main$data$workspace$colors$extract_all_colors$$($groups$jscomp$14_shapes$jscomp$213$$,
$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$,$libraries$jscomp$148_token_colors$$));$groups$jscomp$14_shapes$jscomp$213$$=$APP.$app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$2645$attrs$$,function($p1__79102_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__79102_SHARP_$$,$APP.$cljs$cst$2645$attrs$$)},$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$);$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2645$attrs$$,
$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$));$libraries$jscomp$148_token_colors$$=$APP.$cljs$core$filterv$$($APP.$cljs$cst$4186$token_name$$,$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$);var $library_colors$jscomp$2$$=$APP.$cljs$core$filterv$$(function($c$jscomp$313$$){return $APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$313$$)!=null&&$APP.$cljs$cst$4186$token_name$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$313$$)==null},$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$),
$colors$jscomp$25$$=$APP.$cljs$core$filterv$$(function($c$jscomp$314$$){return $APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$314$$)==null&&$APP.$cljs$cst$4186$token_name$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$314$$)==null},$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4382$groups$$,$groups$jscomp$14_shapes$jscomp$213$$,$cljs$cst$5718$all_colors$$,$all_colors$jscomp$2_data$jscomp$489_file_id$jscomp$412$$,
$APP.$cljs$cst$2212$colors$$,$colors$jscomp$25$$,$cljs$cst$5719$token_colors$$,$libraries$jscomp$148_token_colors$$,$cljs$cst$5720$library_colors$$,$library_colors$jscomp$2$$],null)};
$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$=function($color_operations_prev_groups$jscomp$15$$,$old_color$jscomp$3_old_color__$1$$,$prev_color$jscomp$3_prev_colors$$){$old_color$jscomp$3_old_color__$1$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($old_color$jscomp$3_old_color__$1$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$])));
$prev_color$jscomp$3_prev_colors$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get$$,$color_operations_prev_groups$jscomp$15$$),$prev_color$jscomp$3_prev_colors$$);var $color_operations_old$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_operations_prev_groups$jscomp$15$$,$old_color$jscomp$3_old_color__$1$$);$color_operations_prev_groups$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_operations_prev_groups$jscomp$15$$,
$prev_color$jscomp$3_prev_colors$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($color_operations_prev_groups$jscomp$15$$)?$color_operations_prev_groups$jscomp$15$$:$color_operations_old$$,$APP.$cljs$core$truth_$$($prev_color$jscomp$3_prev_colors$$)?$prev_color$jscomp$3_prev_colors$$:$old_color$jscomp$3_old_color__$1$$],null)};
$app$common$geom$grid$calculate_generic_grid$$=function($v$jscomp$668$$,$total_length$$,$map__79136__$1_p__79135$$){$map__79136__$1_p__79135$$=$APP.$cljs$core$__destructure_map$$($map__79136__$1_p__79135$$);var $size$jscomp$150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79136__$1_p__79135$$,$APP.$cljs$cst$874$size$$),$gutter$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79136__$1_p__79135$$,$APP.$cljs$cst$1931$gutter$$),$margin$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79136__$1_p__79135$$,
$APP.$cljs$cst$1929$margin$$),$item_length$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79136__$1_p__79135$$,$APP.$cljs$cst$1930$item_length$$),$type$jscomp$661$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79136__$1_p__79135$$,$APP.$cljs$cst$139$type$$),$size__$1$jscomp$7$$=typeof $size$jscomp$150$$==="number"?$size$jscomp$150$$:$APP.$app$common$math$floor$$(($total_length$$-($margin$jscomp$4$$+($margin$jscomp$4$$-$gutter$jscomp$2$$)))/(($APP.$cljs$core$truth_$$($item_length$jscomp$1$$)?
$item_length$jscomp$1$$:($total_length$$-($margin$jscomp$4$$+($margin$jscomp$4$$-$gutter$jscomp$2$$))-$gutter$jscomp$2$$*12)/12)+$gutter$jscomp$2$$)),$item_length__$1$jscomp$1$$=typeof $item_length$jscomp$1$$==="number"?$item_length$jscomp$1$$:$total_length$$/$size__$1$jscomp$7$$+-$gutter$jscomp$2$$+$gutter$jscomp$2$$/$size__$1$jscomp$7$$+-($margin$jscomp$4$$*2/$size__$1$jscomp$7$$),$offset$jscomp$209$$=function(){switch($type$jscomp$661$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$661$$.$fqn$:
null){case "right":return $total_length$$-$item_length__$1$jscomp$1$$*$size__$1$jscomp$7$$-$gutter$jscomp$2$$*($size__$1$jscomp$7$$-1)-$margin$jscomp$4$$;case "center":return($total_length$$-$item_length__$1$jscomp$1$$*$size__$1$jscomp$7$$-$gutter$jscomp$2$$*($size__$1$jscomp$7$$-1))/2;default:return $margin$jscomp$4$$}}(),$gutter__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1669$stretch$$,$type$jscomp$661$$)?function(){var $gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13562$$=
0>$gutter$jscomp$2$$?0:$gutter$jscomp$2$$;var $y__5111__auto__$jscomp$inline_13563$$=($total_length$$-$item_length__$1$jscomp$1$$*$size__$1$jscomp$7$$-$margin$jscomp$4$$*2)/($size__$1$jscomp$7$$-1);$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13562$$=$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13562$$>$y__5111__auto__$jscomp$inline_13563$$?$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13562$$:$y__5111__auto__$jscomp$inline_13563$$;return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13562$$))?
$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13562$$:0}():$gutter$jscomp$2$$;return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$size__$1$jscomp$7$$,$item_length__$1$jscomp$1$$,function($cur_val$jscomp$2$$){return $offset$jscomp$209$$+$v$jscomp$668$$+($item_length__$1$jscomp$1$$+$gutter__$1$$)*$cur_val$jscomp$2$$},$gutter__$1$$],null)};
$app$common$geom$grid$calculate_column_grid$$=function($height$jscomp$169_p__79143$$,$params$jscomp$421_size$jscomp$151$$){var $map__79144__$1_y$jscomp$474$$=$APP.$cljs$core$__destructure_map$$($height$jscomp$169_p__79143$$),$width$jscomp$198_width__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79144__$1_y$jscomp$474$$,$APP.$cljs$cst$290$width$$);$height$jscomp$169_p__79143$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79144__$1_y$jscomp$474$$,$APP.$cljs$cst$1522$height$$);
var $next_x_vec__79145_x$jscomp$1252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79144__$1_y$jscomp$474$$,$APP.$cljs$cst$1510$x$$);$map__79144__$1_y$jscomp$474$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79144__$1_y$jscomp$474$$,$APP.$cljs$cst$1511$y$$);$next_x_vec__79145_x$jscomp$1252$$=$app$common$geom$grid$calculate_generic_grid$$($next_x_vec__79145_x$jscomp$1252$$,$width$jscomp$198_width__$1$jscomp$10$$,$params$jscomp$421_size$jscomp$151$$);$params$jscomp$421_size$jscomp$151$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_x_vec__79145_x$jscomp$1252$$,0,null);$width$jscomp$198_width__$1$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_x_vec__79145_x$jscomp$1252$$,1,null);$next_x_vec__79145_x$jscomp$1252$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_x_vec__79145_x$jscomp$1252$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$421_size$jscomp$151$$,
$width$jscomp$198_width__$1$jscomp$10$$,$height$jscomp$169_p__79143$$,$next_x_vec__79145_x$jscomp$1252$$,$APP.$cljs$core$constantly$$($map__79144__$1_y$jscomp$474$$)],null)};
$app$common$geom$grid$calculate_row_grid$$=function($p__79153_width$jscomp$199$$,$params$jscomp$422_size$jscomp$152$$){var $map__79154__$1_next_y_vec__79155_y$jscomp$475$$=$APP.$cljs$core$__destructure_map$$($p__79153_width$jscomp$199$$);$p__79153_width$jscomp$199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$170_height__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,
$APP.$cljs$cst$1522$height$$),$x$jscomp$1253$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,$APP.$cljs$cst$1510$x$$);$map__79154__$1_next_y_vec__79155_y$jscomp$475$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,$APP.$cljs$cst$1511$y$$);$map__79154__$1_next_y_vec__79155_y$jscomp$475$$=$app$common$geom$grid$calculate_generic_grid$$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,$height$jscomp$170_height__$1$jscomp$6$$,
$params$jscomp$422_size$jscomp$152$$);$params$jscomp$422_size$jscomp$152$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,0,null);$height$jscomp$170_height__$1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,1,null);$map__79154__$1_next_y_vec__79155_y$jscomp$475$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79154__$1_next_y_vec__79155_y$jscomp$475$$,2,
null);return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$422_size$jscomp$152$$,$p__79153_width$jscomp$199$$,$height$jscomp$170_height__$1$jscomp$6$$,$APP.$cljs$core$constantly$$($x$jscomp$1253$$),$map__79154__$1_next_y_vec__79155_y$jscomp$475$$],null)};
$app$common$geom$grid$calculate_square_grid$$=function($p__79163_width$jscomp$200$$,$map__79166__$1_p__79164$$){function $as_row_col$$($value$jscomp$925$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$quot$$($value$jscomp$925$$,$col_size$$),$APP.$cljs$core$rem$$($value$jscomp$925$$,$col_size$$)],null)}var $map__79165__$1$$=$APP.$cljs$core$__destructure_map$$($p__79163_width$jscomp$200$$);$p__79163_width$jscomp$200$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79165__$1$$,
$APP.$cljs$cst$290$width$$);var $height$jscomp$171$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79165__$1$$,$APP.$cljs$cst$1522$height$$),$x$jscomp$1254$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79165__$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$476$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79165__$1$$,$APP.$cljs$cst$1511$y$$);$map__79166__$1_p__79164$$=$APP.$cljs$core$__destructure_map$$($map__79166__$1_p__79164$$);var $size$jscomp$153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79166__$1_p__79164$$,
$APP.$cljs$cst$874$size$$),$col_size$$=$APP.$cljs$core$quot$$($p__79163_width$jscomp$200$$,$size$jscomp$153$$);return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$col_size$$*$APP.$cljs$core$quot$$($height$jscomp$171$$,$size$jscomp$153$$),$size$jscomp$153$$,$size$jscomp$153$$,function($col$jscomp$24_cur_val$jscomp$3_vec__79167$$){$col$jscomp$24_cur_val$jscomp$3_vec__79167$$=$as_row_col$$($col$jscomp$24_cur_val$jscomp$3_vec__79167$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col$jscomp$24_cur_val$jscomp$3_vec__79167$$,
0,null);$col$jscomp$24_cur_val$jscomp$3_vec__79167$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col$jscomp$24_cur_val$jscomp$3_vec__79167$$,1,null);return $x$jscomp$1254$$+$col$jscomp$24_cur_val$jscomp$3_vec__79167$$*$size$jscomp$153$$},function($cur_val$jscomp$4_vec__79170$$){$cur_val$jscomp$4_vec__79170$$=$as_row_col$$($cur_val$jscomp$4_vec__79170$$);var $row$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_val$jscomp$4_vec__79170$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_val$jscomp$4_vec__79170$$,
1,null);return $y$jscomp$476$$+$row$jscomp$34$$*$size$jscomp$153$$}],null)};
$app$common$geom$grid$grid_gutter$$=function($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,$p__79174_type$jscomp$662$$){var $height$jscomp$172_map__79175__$1$$=$APP.$cljs$core$__destructure_map$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$);$gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$172_map__79175__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$477$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$172_map__79175__$1$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$172_map__79175__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$172_map__79175__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$172_map__79175__$1$$,$APP.$cljs$cst$1522$height$$);var $map__79176__$1_params$jscomp$424$$=$APP.$cljs$core$__destructure_map$$($p__79174_type$jscomp$662$$);$p__79174_type$jscomp$662$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79176__$1_params$jscomp$424$$,
$APP.$cljs$cst$139$type$$);$map__79176__$1_params$jscomp$424$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79176__$1_params$jscomp$424$$,$APP.$cljs$cst$1430$params$$);switch($p__79174_type$jscomp$662$$ instanceof $APP.$cljs$core$Keyword$$?$p__79174_type$jscomp$662$$.$fqn$:null){case "column":return $gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$=$app$common$geom$grid$calculate_generic_grid$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,$width$jscomp$201$$,
$map__79176__$1_params$jscomp$424$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,0,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,1,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,2,null),$gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,
3,null);case "row":return $gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$=$app$common$geom$grid$calculate_generic_grid$$($y$jscomp$477$$,$height$jscomp$172_map__79175__$1$$,$map__79176__$1_params$jscomp$424$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,0,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,1,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,
2,null),$gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79173_vec__79178_vec__79181_x$jscomp$1255$$,3,null);default:return null}};
$app$common$geom$grid$grid_areas$$=function($frame$jscomp$71$$,$grid$jscomp$12$$){var $grid_fn$$=function(){var $G__79188_G__79188__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$12$$);$G__79188_G__79188__$1$$=$G__79188_G__79188__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__79188_G__79188__$1$$.$fqn$:null;switch($G__79188_G__79188__$1$$){case "column":return $app$common$geom$grid$calculate_column_grid$$;case "row":return $app$common$geom$grid$calculate_row_grid$$;case "square":return $app$common$geom$grid$calculate_square_grid$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79188_G__79188__$1$$)].join(""));}}(),$vec__79185$$=function(){var $G__79190$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$12$$);return $grid_fn$$.$cljs$core$IFn$_invoke$arity$2$?$grid_fn$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$71$$,$G__79190$$):$grid_fn$$($frame$jscomp$71$$,$G__79190$$)}(),$num_items$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79185$$,
0,null),$item_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79185$$,1,null),$item_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79185$$,2,null),$next_x$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79185$$,3,null),$next_y$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79185$$,4,null);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79184_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1510$x$$,
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$],[$next_x$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$next_x$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p1__79184_SHARP_$$):$next_x$jscomp$2$$($p1__79184_SHARP_$$),$next_y$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$next_y$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p1__79184_SHARP_$$):$next_y$jscomp$2$$($p1__79184_SHARP_$$),$item_width$$,$item_height$$])},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(0,
$num_items$jscomp$1$$))};
$app$main$data$workspace$grid$add_frame_grid$$=function($frame_id$jscomp$138$$){typeof $app$main$data$workspace$grid$add_frame_grid_79221$$==="undefined"&&($app$main$data$workspace$grid$add_frame_grid_79221$$=function($frame_id$jscomp$139$$,$meta79222$$){this.$frame_id$=$frame_id$jscomp$139$$;this.$meta79222$=$meta79222$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$add_frame_grid_79221$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$grid$add_frame_grid_79221$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5721$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_add_frame_grid$$},$app$main$data$workspace$grid$add_frame_grid_79221$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79223$$,$meta79222__$1$$){return new $app$main$data$workspace$grid$add_frame_grid_79221$$(this.$frame_id$,$meta79222__$1$$)},$app$main$data$workspace$grid$add_frame_grid_79221$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta79222$},$app$main$data$workspace$grid$add_frame_grid_79221$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$add_frame_grid_79221$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3044_params$jscomp$426$$,$state$jscomp$1190$$){var $page$jscomp$166$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$);$_$jscomp$3044_params$jscomp$426$$=function(){var $or__5025__auto__$jscomp$1203$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$166$$,$APP.$cljs$cst$2055$default_grids$$),$APP.$cljs$cst$1933$square$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1203$$)?$or__5025__auto__$jscomp$1203$$:$APP.$cljs$cst$1933$square$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$grid$default_grid_params$$)}();var $grid$jscomp$14$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1933$square$$,$APP.$cljs$cst$1430$params$$,$_$jscomp$3044_params$jscomp$426$$,$APP.$cljs$cst$1932$display$$,!0],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$frame_id$],null),function($obj$jscomp$223$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$223$$,$APP.$cljs$cst$2050$grids$$,
$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79220_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__79220_SHARP_$$,$grid$jscomp$14$$)},$APP.$cljs$core$PersistentVector$EMPTY$$))}))});return new $app$main$data$workspace$grid$add_frame_grid_79221$$($frame_id$jscomp$138$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid$remove_frame_grid$$=function($frame_id$jscomp$140$$,$index$jscomp$529$$){typeof $app$main$data$workspace$grid$remove_frame_grid_79225$$==="undefined"&&($app$main$data$workspace$grid$remove_frame_grid_79225$$=function($frame_id$jscomp$141$$,$index$jscomp$530$$,$meta79226$$){this.$frame_id$=$frame_id$jscomp$141$$;this.index=$index$jscomp$530$$;this.$meta79226$=$meta79226$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$remove_frame_grid_79225$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$remove_frame_grid_79225$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5722$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_remove_frame_grid$$},$app$main$data$workspace$grid$remove_frame_grid_79225$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79227$$,$meta79226__$1$$){return new $app$main$data$workspace$grid$remove_frame_grid_79225$$(this.$frame_id$,this.index,$meta79226__$1$$)},$app$main$data$workspace$grid$remove_frame_grid_79225$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta79226$},$app$main$data$workspace$grid$remove_frame_grid_79225$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$remove_frame_grid_79225$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7439$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$self__$jscomp$7439$$.$frame_id$],null),function($o$jscomp$276$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($o$jscomp$276$$,$APP.$cljs$cst$2050$grids$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79224_SHARP_$$){return $APP.$app$common$data$remove_at_index$$($p1__79224_SHARP_$$,$self__$jscomp$7439$$.index)},$APP.$cljs$core$PersistentVector$EMPTY$$))}))});return new $app$main$data$workspace$grid$remove_frame_grid_79225$$($frame_id$jscomp$140$$,$index$jscomp$529$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid$set_frame_grid$$=function($frame_id$jscomp$142$$,$index$jscomp$531$$,$data$jscomp$490$$){typeof $app$main$data$workspace$grid$set_frame_grid_79229$$==="undefined"&&($app$main$data$workspace$grid$set_frame_grid_79229$$=function($frame_id$jscomp$143$$,$index$jscomp$532$$,$data$jscomp$491$$,$meta79230$$){this.$frame_id$=$frame_id$jscomp$143$$;this.index=$index$jscomp$532$$;this.data=$data$jscomp$491$$;this.$meta79230$=$meta79230$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$set_frame_grid_79229$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_frame_grid_79229$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5723$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_frame_grid$$},$app$main$data$workspace$grid$set_frame_grid_79229$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79231$$,$meta79230__$1$$){return new $app$main$data$workspace$grid$set_frame_grid_79229$$(this.$frame_id$,
this.index,this.data,$meta79230__$1$$)},$app$main$data$workspace$grid$set_frame_grid_79229$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta79230$},$app$main$data$workspace$grid$set_frame_grid_79229$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_frame_grid_79229$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7443$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$7443$$.$frame_id$],null),function($p1__79228_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__79228_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2050$grids$$,$self__$jscomp$7443$$.index],null),$self__$jscomp$7443$$.data)}))});return new $app$main$data$workspace$grid$set_frame_grid_79229$$($frame_id$jscomp$142$$,$index$jscomp$531$$,$data$jscomp$490$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid$set_default_grid$$=function($type$jscomp$664$$,$params$jscomp$427$$){typeof $app$main$data$workspace$grid$set_default_grid_79232$$==="undefined"&&($app$main$data$workspace$grid$set_default_grid_79232$$=function($type$jscomp$665$$,$params$jscomp$428$$,$meta79233$$){this.type=$type$jscomp$665$$;this.params=$params$jscomp$428$$;this.$meta79233$=$meta79233$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$set_default_grid_79232$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_default_grid_79232$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5724$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_default_grid$$},$app$main$data$workspace$grid$set_default_grid_79232$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79234$$,$meta79233__$1$$){return new $app$main$data$workspace$grid$set_default_grid_79232$$(this.type,this.params,$meta79233__$1$$)},$app$main$data$workspace$grid$set_default_grid_79232$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta79233$},$app$main$data$workspace$grid$set_default_grid_79232$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_default_grid_79232$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$,$page_id$jscomp$inline_8940_state$jscomp$1191$$){$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$inline_8940_state$jscomp$1191$$);var $changes$jscomp$inline_8937_changes__$1$jscomp$inline_8943$$=$APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$);$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$=
this.type;var $params$jscomp$inline_8939$$=this.params;$page_id$jscomp$inline_8940_state$jscomp$1191$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$inline_8937_changes__$1$jscomp$inline_8943$$));var $old_val$jscomp$inline_8942_page$jscomp$inline_8941$$=$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$inline_8937_changes__$1$jscomp$inline_8943$$));
$old_val$jscomp$inline_8942_page$jscomp$inline_8941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$inline_8942_page$jscomp$inline_8941$$,$APP.$cljs$cst$2050$grids$$),$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$);$changes$jscomp$inline_8937_changes__$1$jscomp$inline_8943$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_8937_changes__$1$jscomp$inline_8943$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2602$set_default_grid$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$inline_8940_state$jscomp$1191$$,$APP.$cljs$cst$2603$grid_type$$,$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$,$APP.$cljs$cst$1430$params$$,$params$jscomp$inline_8939$$],null));$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_8937_changes__$1$jscomp$inline_8943$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2602$set_default_grid$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$inline_8940_state$jscomp$1191$$,$APP.$cljs$cst$2603$grid_type$$,$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$,
$APP.$cljs$cst$1430$params$$,$old_val$jscomp$inline_8942_page$jscomp$inline_8941$$],null));$JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($JSCompiler_inline_result$jscomp$1671_changes__$2$jscomp$inline_8944_it$jscomp$276_page$jscomp$167_type$jscomp$inline_8938$$))});
return new $app$main$data$workspace$grid$set_default_grid_79232$$($type$jscomp$664$$,$params$jscomp$427$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$sidebar$options$menus$frame_grid$get_size_options$$=function(){return new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,null,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.auto")],null),$APP.$cljs$cst$1472$separator$$,18,12,10,8,6,4,3,2],null)};
$app$main$ui$workspace$sidebar$options$menus$frame_grid$frame_grid_STAR_$$=function($open_QMARK_$jscomp$28_props_79259$$){var $shape$jscomp$1020$$=$open_QMARK_$jscomp$28_props_79259$$.shape,$state_STAR_$jscomp$23$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$28_props_79259$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$23$$);var $frame_grids$$=$APP.$cljs$cst$2050$grids$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1020$$),$has_frame_grids_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$frame_grids$$)||$APP.$cljs$core$seq$$($frame_grids$$)!=null,$toggle_content$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$23$$,$APP.$cljs$core$not$$)}),$id$jscomp$973$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1020$$),$default_grids$jscomp$1$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$menus$frame_grid$lens_COLON_default_grids$$),
$default_grid_params$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_grids$jscomp$1$$)],function(){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$grid$default_grid_params$$,$default_grids$jscomp$1$$]))}),$handle_create_grid$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$973$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$add_frame_grid$$($id$jscomp$973$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_frame_grids_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$28_props_79259$$),onCollapsed:$toggle_content$jscomp$14$$,className:$has_frame_grids_QMARK_$$?
"":"main_ui_workspace_sidebar_options_menus_frame_grid__title-spacing-board-grid",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.title"),children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.add-guide"),onClick:$handle_create_grid$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$28_props_79259$$)?
$APP.$cljs$core$seq$$($frame_grids$$):$open_QMARK_$jscomp$28_props_79259$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__element-set-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$179$$,$grid$jscomp$16_p__79260$$){var $index$jscomp$534$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grid$jscomp$16_p__79260$$,0,null);$grid$jscomp$16_p__79260$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grid$jscomp$16_p__79260$$,
1,null);$out_arr__44124__auto__$jscomp$179$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$frame_grid$grid_options_STAR_$$,{shapeId:$id$jscomp$973$$,grid:$grid$jscomp$16_p__79260$$,index:$index$jscomp$534$$,frameWidth:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1020$$),frameHeight:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1020$$),defaultGridParams:$default_grid_params$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$973$$),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$534$$)].join("")));return $out_arr__44124__auto__$jscomp$179$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$frame_grids$$))}):null]})};
$app$main$ui$workspace$sidebar$options$shapes$frame$options_STAR_$$=function($props_79273_shape_type$jscomp$7$$){var $shapes_with_children$jscomp$1$$=$props_79273_shape_type$jscomp$7$$.shapesWithChildren,$file_id$jscomp$414$$=$props_79273_shape_type$jscomp$7$$.fileId,$libraries$jscomp$150$$=$props_79273_shape_type$jscomp$7$$.libraries,$page_id$jscomp$427$$=$props_79273_shape_type$jscomp$7$$.pageId,$shape$jscomp$1021$$=$props_79273_shape_type$jscomp$7$$.shape,$shape_id$jscomp$162$$=$shape$jscomp$1021$$?.id??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1021$$,$APP.$cljs$cst$266$id$$);$props_79273_shape_type$jscomp$7$$=$shape$jscomp$1021$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1021$$,$APP.$cljs$cst$139$type$$);var $ids$jscomp$305$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape_id$jscomp$162$$],null)}),$shapes$jscomp$215$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1021$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1021$$],null)}),$applied_tokens$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1021$$,$APP.$cljs$cst$1873$applied_tokens$$),$stroke_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,
$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$measure_values$jscomp$2$$=$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$($shape$jscomp$1021$$),$constraint_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_container_values$jscomp$2$$=
$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$layout_item_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$305$$)],
function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$305$$)}),$is_layout_child_QMARK_$jscomp$3$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$);$is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$305$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$305$$)});
$is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$);var $is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$305$$)],function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$305$$)}),$is_grid_parent_QMARK_$jscomp$3$$=
$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$);$is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$305$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$305$$)});$is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$);
var $is_layout_container_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1021$$),$is_flex_layout_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1021$$),$is_grid_layout_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1021$$),$is_layout_child_absolute_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1021$$),
$is_variant_QMARK_$jscomp$4$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1021$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$305$$,type:$props_79273_shape_type$jscomp$7$$,appliedTokens:$applied_tokens$jscomp$23$$,values:$layer_values$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$305$$,appliedTokens:$applied_tokens$jscomp$23$$,values:$measure_values$jscomp$2$$,type:$props_79273_shape_type$jscomp$7$$,shapes:$shapes$jscomp$215$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,{shapes:$shapes$jscomp$215$$}),$APP.$cljs$core$truth_$$($is_variant_QMARK_$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_STAR_$$,{shapes:$shapes$jscomp$215$$}):
null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79273_shape_type$jscomp$7$$,ids:$ids$jscomp$305$$,"applied-tokens":$applied_tokens$jscomp$23$$,values:$layout_container_values$jscomp$2$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$809$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$305$$),1);return $and__5023__auto__$jscomp$809$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$3$$)?
$is_grid_parent_QMARK_$jscomp$3$$:$is_layout_child_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$809$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,{shape:$APP.$cljs$core$first$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$),$APP.$cljs$core$first$$($ids$jscomp$305$$))}):
null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$3$$)?$is_layout_child_QMARK_$jscomp$3$$:$is_layout_container_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$,"is-grid-layout?":$is_grid_layout_QMARK_$jscomp$1$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$3$$,ids:$ids$jscomp$305$$,
type:$props_79273_shape_type$jscomp$7$$,values:$layout_item_values$jscomp$2$$,shape:$shape$jscomp$1021$$,"applied-tokens":$applied_tokens$jscomp$23$$,"is-flex-layout?":$is_flex_layout_QMARK_$jscomp$1$$,"is-layout-child?":$is_layout_child_QMARK_$jscomp$3$$,"is-layout-container?":$is_layout_container_QMARK_$jscomp$1$$}):null,!$is_layout_child_QMARK_$jscomp$3$$||$is_layout_child_absolute_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,
{ids:$ids$jscomp$305$$,values:$constraint_values$jscomp$2$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$305$$,type:$props_79273_shape_type$jscomp$7$$,values:$shape$jscomp$1021$$,appliedTokens:$applied_tokens$jscomp$23$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$305$$,type:$props_79273_shape_type$jscomp$7$$,values:$stroke_values$jscomp$2$$,appliedTokens:$applied_tokens$jscomp$23$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{type:$props_79273_shape_type$jscomp$7$$,shapes:$shapes_with_children$jscomp$1$$,fileId:$file_id$jscomp$414$$,libraries:$libraries$jscomp$150$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$305$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1021$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,
{ids:$ids$jscomp$305$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$frame_grid$frame_grid_STAR_$$,{shape:$shape$jscomp$1021$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79273_shape_type$jscomp$7$$,ids:$ids$jscomp$305$$,
shapes:$shapes$jscomp$215$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1021$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$427$$,fileId:$file_id$jscomp$414$$})]})};
$app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$=function($options__$1$jscomp$88_props_79258$$){var $options$jscomp$625$$=void 0,$on_change$jscomp$78$$=void 0,$selected$jscomp$172$$=void 0,$variant$jscomp$25$$=void 0,$disabled$jscomp$18$$=void 0,$extended$$=void 0,$name$jscomp$458$$=void 0,$allow_empty$jscomp$2$$=void 0,$class$$jscomp$72$$=void 0,$props$jscomp$343$$=void 0;({options:$options$jscomp$625$$,onChange:$on_change$jscomp$78$$,selected:$selected$jscomp$172$$,variant:$variant$jscomp$25$$,
disabled:$disabled$jscomp$18$$,extended:$extended$$,name:$name$jscomp$458$$,allowEmpty:$allow_empty$jscomp$2$$,className:$class$$jscomp$72$$,...$props$jscomp$343$$}=$options__$1$jscomp$88_props_79258$$);$options__$1$jscomp$88_props_79258$$=$APP.$cljs$core$array_QMARK_$$($options$jscomp$625$$)?$APP.$rumext$v2$util$bean$$($options$jscomp$625$$):$options$jscomp$625$$;var $type$jscomp$667$$=$APP.$cljs$core$truth_$$($allow_empty$jscomp$2$$)?"checkbox":"radio",$variant__$1$jscomp$6$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$25$$,
"secondary"),$wrapper_disabled$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled$jscomp$18$$,!1),$handle_click$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$172$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$78$$),$APP.$rumext$v2$adapt$$($allow_empty$jscomp$2$$)],function($disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$){$disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$=$APP.$app$util$dom$get_target$$($disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$);
var $input$jscomp$73_label$jscomp$46$$=$APP.$app$util$dom$get_parent_with_data$$($disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$,"label");$input$jscomp$73_label$jscomp$46$$=$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($input$jscomp$73_label$jscomp$46$$,"input");$disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$=$APP.$app$util$dom$get_attribute$$($disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$,"disabled");return $APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$8_event$jscomp$553_target$jscomp$154$$)?
null:$APP.$app$util$dom$click$$($input$jscomp$73_label$jscomp$46$$)}),$handle_change$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$172$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$78$$),$APP.$rumext$v2$adapt$$($allow_empty$jscomp$2$$)],function($event$jscomp$554$$){var $input$jscomp$74$$=$APP.$app$util$dom$get_target$$($event$jscomp$554$$),$new_value$jscomp$26_value$jscomp$927$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$554$$),
$JSCompiler_inline_result$jscomp$1832_selected_str$$=$APP.$cljs$core$truth_$$($selected$jscomp$172$$)?$APP.$app$common$data$name$$($selected$jscomp$172$$):null,$and__5023__auto__$jscomp$inline_8946$$=$allow_empty$jscomp$2$$;$JSCompiler_inline_result$jscomp$1832_selected_str$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8946$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$26_value$jscomp$927$$,$JSCompiler_inline_result$jscomp$1832_selected_str$$):$and__5023__auto__$jscomp$inline_8946$$;
$new_value$jscomp$26_value$jscomp$927$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1832_selected_str$$)?null:$new_value$jscomp$26_value$jscomp$927$$;$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$78$$)&&($on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$26_value$jscomp$927$$,$event$jscomp$554$$):$on_change$jscomp$78$$($new_value$jscomp$26_value$jscomp$927$$,$event$jscomp$554$$));return $APP.$app$util$dom$blur_BANG_$$($input$jscomp$74$$)});
return(0,$APP.$rumext$v2$create_element$$)("div",{...$props$jscomp$343$$,key:""+($name$jscomp$458$$??"")+"-"+($selected$jscomp$172$$??""),className:($class$$jscomp$72$$??"")+" main_ui_ds_controls_radio_buttons__wrapper "+(($APP.$cljs$core$truth_$$($disabled$jscomp$18$$)?"main_ui_ds_controls_radio_buttons__disabled":"")+" "+($APP.$cljs$core$truth_$$($extended$$)?"main_ui_ds_controls_radio_buttons__extended":""))},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$180$$,
$id$jscomp$974_map__79268_p__79264$$){var $JSCompiler_inline_result$jscomp$11030_idx$jscomp$127$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$974_map__79268_p__79264$$,0,null);$id$jscomp$974_map__79268_p__79264$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$974_map__79268_p__79264$$,1,null);var $JSCompiler_temp_const$jscomp$11028_map__79268__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$974_map__79268_p__79264$$);$id$jscomp$974_map__79268_p__79264$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11028_map__79268__$1$$,$APP.$cljs$cst$266$id$$);var $class$__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11028_map__79268__$1$$,$APP.$cljs$cst$1291$class$$),$value$jscomp$928$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11028_map__79268__$1$$,$APP.$cljs$cst$260$value$$),$label$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11028_map__79268__$1$$,
$APP.$cljs$cst$2287$label$$),$icon$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11028_map__79268__$1$$,$APP.$cljs$cst$1721$icon$$),$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11028_map__79268__$1$$,$APP.$cljs$cst$2948$disabled$$);$JSCompiler_temp_const$jscomp$11028_map__79268__$1$$=$out_arr__44124__auto__$jscomp$180$$.push;var $checked_QMARK_$jscomp$inline_13567_value_str$jscomp$inline_13565$$=
$APP.$app$common$data$name$$($value$jscomp$928$$),$selected_str$jscomp$inline_13566$$=$APP.$cljs$core$truth_$$($selected$jscomp$172$$)?$APP.$app$common$data$name$$($selected$jscomp$172$$):null;$checked_QMARK_$jscomp$inline_13567_value_str$jscomp$inline_13565$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_str$jscomp$inline_13566$$,$checked_QMARK_$jscomp$inline_13567_value_str$jscomp$inline_13565$$);$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$,
!1);$JSCompiler_inline_result$jscomp$11030_idx$jscomp$127$$=(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$id$jscomp$974_map__79268_p__79264$$,"data-label":!0,"data-testid":$id$jscomp$974_map__79268_p__79264$$,className:($class$__$1$jscomp$10$$??"")+" main_ui_ds_controls_radio_buttons__label "+($APP.$cljs$core$truth_$$($extended$$)?"main_ui_ds_controls_radio_buttons__extended":""),children:[$icon$jscomp$23$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:$variant__$1$jscomp$6$$,onClick:$handle_click$jscomp$4$$,"aria-pressed":$checked_QMARK_$jscomp$inline_13567_value_str$jscomp$inline_13565$$,"aria-label":$label$jscomp$47$$,icon:$icon$jscomp$23$$,disabled:$APP.$cljs$core$truth_$$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$)?$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$:$wrapper_disabled$$}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:$variant__$1$jscomp$6$$,onClick:$handle_click$jscomp$4$$,
"aria-pressed":$checked_QMARK_$jscomp$inline_13567_value_str$jscomp$inline_13565$$,className:"main_ui_ds_controls_radio_buttons__button "+($APP.$cljs$core$truth_$$($extended$$)?"main_ui_ds_controls_radio_buttons__extended":""),disabled:$APP.$cljs$core$truth_$$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$)?$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$:$wrapper_disabled$$,children:$label$jscomp$47$$}),(0,$APP.$rumext$v2$jsx$$)("input",{id:$id$jscomp$974_map__79268_p__79264$$,
onChange:$handle_change$jscomp$13$$,type:$type$jscomp$667$$,name:$name$jscomp$458$$,disabled:$APP.$cljs$core$truth_$$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$)?$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13568$$:$wrapper_disabled$$,value:$value$jscomp$928$$,checked:$checked_QMARK_$jscomp$inline_13567_value_str$jscomp$inline_13565$$,className:"main_ui_ds_controls_radio_buttons__input"})]},$JSCompiler_inline_result$jscomp$11030_idx$jscomp$127$$);$JSCompiler_temp_const$jscomp$11028_map__79268__$1$$.call($out_arr__44124__auto__$jscomp$180$$,
$JSCompiler_inline_result$jscomp$11030_idx$jscomp$127$$);return $out_arr__44124__auto__$jscomp$180$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$88_props_79258$$)))};
$app$main$ui$ds$controls$shared$dropdown_navigation$use_dropdown_navigation$$=function($map__79257__$1_on_key_down$jscomp$18_p__79256$$){$map__79257__$1_on_key_down$jscomp$18_p__79256$$=$APP.$cljs$core$__destructure_map$$($map__79257__$1_on_key_down$jscomp$18_p__79256$$);var $focusable_ids$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79257__$1_on_key_down$jscomp$18_p__79256$$,$cljs$cst$5728$focusable_ids$$),$nodes_ref$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79257__$1_on_key_down$jscomp$18_p__79256$$,
$cljs$cst$5729$nodes_ref$$),$on_enter$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79257__$1_on_key_down$jscomp$18_p__79256$$,$cljs$cst$5730$on_enter$$),$searchable$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79257__$1_on_key_down$jscomp$18_p__79256$$,$cljs$cst$5731$searchable$$),$search_input_ref$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79257__$1_on_key_down$jscomp$18_p__79256$$,$cljs$cst$5732$search_input_ref$$),$on_close$jscomp$34$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79257__$1_on_key_down$jscomp$18_p__79256$$,$APP.$cljs$cst$4994$on_close$$),$focused_id_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$focused_id$jscomp$4$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$3$$),$focus_input_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($search_input_ref$jscomp$1$$)],function(){$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,
null);var $temp__5825__auto__$jscomp$381$$=$APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$381$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$381$$):null});$map__79257__$1_on_key_down$jscomp$18_p__79256$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$4$$),$APP.$rumext$v2$adapt$$($focusable_ids$$),$APP.$rumext$v2$adapt$$($searchable$$)],function($event$jscomp$555$$){if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$555$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$555$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$555$$);if($focused_id$jscomp$4$$==null)return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$first$$($focusable_ids$$));var $idx$jscomp$128_wrap_to_input_QMARK_$$=function(){var $or__5025__auto__$jscomp$1213$$=$APP.$cljs$core$first$$($cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79252_SHARP_$$,$p2__79251_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p2__79251_SHARP_$$,
$focused_id$jscomp$4$$)?$p1__79252_SHARP_$$:null},$focusable_ids$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1213$$)?$or__5025__auto__$jscomp$1213$$:-1}(),$next_idx_prev_idx$$=$APP.$cljs$core$mod$$($idx$jscomp$128_wrap_to_input_QMARK_$$+1,$APP.$cljs$core$count$$($focusable_ids$$));return($idx$jscomp$128_wrap_to_input_QMARK_$$=$searchable$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($next_idx_prev_idx$$,0)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$128_wrap_to_input_QMARK_$$,
$APP.$cljs$core$count$$($focusable_ids$$)-1))?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$focus_input_BANG_$$():$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusable_ids$$,$next_idx_prev_idx$$,null))}if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$555$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$555$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$555$$);
if($focused_id$jscomp$4$$==null)return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$last$$($focusable_ids$$));$idx$jscomp$128_wrap_to_input_QMARK_$$=function(){var $or__5025__auto__$jscomp$1214$$=$APP.$cljs$core$first$$($cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79255_SHARP_$$,$p2__79254_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p2__79254_SHARP_$$,$focused_id$jscomp$4$$)?$p1__79255_SHARP_$$:null},$focusable_ids$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1214$$)?$or__5025__auto__$jscomp$1214$$:0}();$next_idx_prev_idx$$=$idx$jscomp$128_wrap_to_input_QMARK_$$-1;return($idx$jscomp$128_wrap_to_input_QMARK_$$=$searchable$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($next_idx_prev_idx$$,-1))?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$focus_input_BANG_$$():$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusable_ids$$,
$APP.$cljs$core$mod$$($next_idx_prev_idx$$,$APP.$cljs$core$count$$($focusable_ids$$)),null))}if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$555$$))){if($APP.$cljs$core$truth_$$($focused_id$jscomp$4$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$555$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$555$$),$on_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_enter$$.$cljs$core$IFn$_invoke$arity$1$($focused_id$jscomp$4$$):$on_enter$$($focused_id$jscomp$4$$)}else if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1215$$=
(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$555$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1215$$)?$or__5025__auto__$jscomp$1215$$:(0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$555$$)}()))return $APP.$app$util$dom$prevent_default$$($event$jscomp$555$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$555$$),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,null),$APP.$cljs$core$truth_$$($on_close$jscomp$34$$)?$on_close$jscomp$34$$.$cljs$core$IFn$_invoke$arity$0$?
$on_close$jscomp$34$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$34$$():null;return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$4$$)],function(){if($focused_id$jscomp$4$$!=null){var $temp__5825__auto__$jscomp$382$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$4$$),$focused_id$jscomp$4$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$382$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$382$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1400$block$$,"nearest",$APP.$cljs$cst$2348$inline$$,"nearest"],null)):null}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5733$focused_id$$,$focused_id$jscomp$4$$,$cljs$cst$5734$focused_id_STAR_$$,$focused_id_STAR_$jscomp$3$$,$cljs$cst$5641$on_key_down$$,$map__79257__$1_on_key_down$jscomp$18_p__79256$$],null)};
$app$main$ui$ds$controls$shared$searchable_options_dropdown$searchable_options_dropdown_STAR_$$=function($on_search_change$jscomp$3_props_79275$$){var $options$jscomp$626$$=void 0,$align$jscomp$5_align__$1$jscomp$3$$=void 0,$selected$jscomp$173$$=void 0,$placeholder$jscomp$7$$=void 0,$on_click$jscomp$47$$=void 0,$class$$jscomp$73_list_props$$=void 0,$props$jscomp$344$$=void 0;({onClick:$on_click$jscomp$47$$,options:$options$jscomp$626$$,selected:$selected$jscomp$173$$,align:$align$jscomp$5_align__$1$jscomp$3$$,
className:$class$$jscomp$73_list_props$$,placeholder:$placeholder$jscomp$7$$,...$props$jscomp$344$$}=$on_search_change$jscomp$3_props_79275$$);$align$jscomp$5_align__$1$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$5_align__$1$jscomp$3$$,$APP.$cljs$cst$257$left$$);var $search_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$search$jscomp$8$$=$APP.$cljs$core$_deref$$($search_STAR_$$),$search_input_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$list_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$nodes_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(null),$filtered_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$626$$),$APP.$rumext$v2$adapt$$($search$jscomp$8$$)],function(){return $APP.$cljs$core$seq$$($search$jscomp$8$$)?$APP.$cljs$core$filterv$$(function($opt$jscomp$3$$){var $or__5025__auto__$jscomp$1216$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1136$token$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($opt$jscomp$3$$));return $or__5025__auto__$jscomp$1216$$?$or__5025__auto__$jscomp$1216$$:$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($opt$jscomp$3$$,"")),$APP.$cuerdas$core$lower$$($search$jscomp$8$$))},$options$jscomp$626$$):$options$jscomp$626$$}),$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filtered_options$$)],
function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($filtered_options$$))});$on_search_change$jscomp$3_props_79275$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$556$$){return $APP.$cljs$core$reset_BANG_$$($search_STAR_$$,(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$556$$))});var $set_option_ref$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$427$$){if($APP.$cljs$core$truth_$$($node$jscomp$427$$)){var $state$jscomp$1193$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),{}),$id$jscomp$975$$=$APP.$app$util$dom$get_data$$($node$jscomp$427$$,"id");$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$5$$,$APP.$app$util$object$set_BANG_$$($state$jscomp$1193$$,$id$jscomp$975$$,$node$jscomp$427$$));return function(){var $state__$1$jscomp$58$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),{});return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$5$$,
$APP.$app$util$object$unset_BANG_$$($state__$1$jscomp$58$$,$id$jscomp$975$$))}}return null});$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$=$app$main$ui$ds$controls$shared$dropdown_navigation$use_dropdown_navigation$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5728$focusable_ids$$,$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$,$cljs$cst$5729$nodes_ref$$,$nodes_ref$jscomp$5$$,$cljs$cst$5730$on_enter$$,function($id$jscomp$976_temp__5825__auto__$jscomp$383$$){$id$jscomp$976_temp__5825__auto__$jscomp$383$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),$id$jscomp$976_temp__5825__auto__$jscomp$383$$);return $APP.$cljs$core$truth_$$($id$jscomp$976_temp__5825__auto__$jscomp$383$$)?$id$jscomp$976_temp__5825__auto__$jscomp$383$$.click():null},$cljs$cst$5731$searchable$$,!0,$cljs$cst$5732$search_input_ref$$,$search_input_ref$jscomp$2$$,$APP.$cljs$cst$4994$on_close$$,null],null));$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$=
$APP.$cljs$core$__destructure_map$$($focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$);var $focused_id$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$,$cljs$cst$5733$focused_id$$),$focused_id_STAR_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$,$cljs$cst$5734$focused_id_STAR_$$);$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$,$cljs$cst$5641$on_key_down$$);var $on_click_inner$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$47$$)],function($event$jscomp$557$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$557$$);return $on_click$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$557$$):
$on_click$jscomp$47$$($event$jscomp$557$$)});$class$$jscomp$73_list_props$$={...$props$jscomp$344$$,className:($class$$jscomp$73_list_props$$??"")+" main_ui_ds_controls_shared_searchable_options_dropdown__option-list "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$5_align__$1$jscomp$3$$,$APP.$cljs$cst$257$left$$)?"main_ui_ds_controls_shared_searchable_options_dropdown__left-align":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$5_align__$1$jscomp$3$$,
$APP.$cljs$cst$258$right$$)?"main_ui_ds_controls_shared_searchable_options_dropdown__right-align":"")),ref:$list_ref$$,tabIndex:"-1",role:"listbox",onKeyDown:$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(0,function(){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$2$$)))return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$2$$));
var $temp__5825__auto__$jscomp$384$$=$APP.$rumext$v2$ref_val$$($list_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$384$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$384$$):null})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$5$$)],function(){if($focused_id$jscomp$5$$!=null){var $temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$=$APP.$rumext$v2$ref_val$$($list_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$)&&
($APP.$cljs$core$truth_$$($app$util$dom$active_QMARK_$$($temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$))||$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$));$temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),$focused_id$jscomp$5$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$385_temp__5825__auto___79277$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1400$block$$,"nearest",$APP.$cljs$cst$2348$inline$$,"nearest"],null)):null}return null});return(0,$APP.$rumext$v2$create_element$$)("ul",$class$$jscomp$73_list_props$$,(0,$APP.$rumext$v2$jsx$$)("li",{role:"presentation",className:"main_ui_ds_controls_shared_searchable_options_dropdown__option-search",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{placeholder:function(){var $or__5025__auto__$jscomp$1217$$=
$placeholder$jscomp$7$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1217$$)?$or__5025__auto__$jscomp$1217$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.search-placeholder")}(),value:$search$jscomp$8$$,ref:$search_input_ref$jscomp$2$$,variant:"comfortable",onChange:$on_search_change$jscomp$3_props_79275$$,onClick:function(){return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$4$$,null)},onKeyDown:$focusable_ids$jscomp$1_map__79276_map__79276__$1_on_key_down$jscomp$19$$})}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$181$$,$option$jscomp$22$$){$out_arr__44124__auto__$jscomp$181$$.push($APP.$app$main$ui$ds$controls$shared$render_option$render_option$$($option$jscomp$22$$,$set_option_ref$jscomp$3$$,$on_click_inner$$,$selected$jscomp$173$$,$focused_id$jscomp$5$$));return $out_arr__44124__auto__$jscomp$181$$},[],$filtered_options$$))};
$app$main$ui$workspace$sidebar$options$menus$token_typography_row$resolved_value_tooltip_STAR_$$=function($props_79280_resolved_value$jscomp$3$$){var $token_name$jscomp$28$$=$props_79280_resolved_value$jscomp$3$$.tokenName;$props_79280_resolved_value$jscomp$3$$=$props_79280_resolved_value$jscomp$3$$.resolvedValue;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")??
"")+": "}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-name-tooltip",children:$token_name$jscomp$28$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.token-resolved-value")}),(0,$APP.$rumext$v2$jsx$$)("ul",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$182$$,
$p__79281_v$jscomp$669$$){var $k$jscomp$692$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79281_v$jscomp$669$$,0,null);$p__79281_v$jscomp$669$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79281_v$jscomp$669$$,1,null);$out_arr__44124__auto__$jscomp$182$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__resolved-key",children:["- ",$APP.$app$common$data$name$$($k$jscomp$692$$),
": "].join("")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__resolved-value",children:$APP.$cljs$core$sequential_QMARK_$$($p__79281_v$jscomp$669$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79279_SHARP_$$){return'"'+($p1__79279_SHARP_$$??"")+'"'},$p__79281_v$jscomp$669$$)):""+($p__79281_v$jscomp$669$$??"")})]},$APP.$app$common$data$name$$($k$jscomp$692$$)));
return $out_arr__44124__auto__$jscomp$182$$},[],$props_79280_resolved_value$jscomp$3$$)})]})]})};
$app$main$ui$workspace$sidebar$options$menus$token_typography_row$token_typography_row_STAR_$$=function($element_ref$jscomp$2_props_79286$$){var $detach_token$jscomp$4$$=void 0,$token_name$jscomp$29$$=void 0,$active_tokens$jscomp$6_not_active$jscomp$1$$=void 0;({tokenName:$token_name$jscomp$29$$,activeTokens:$active_tokens$jscomp$6_not_active$jscomp$1$$,detachToken:$detach_token$jscomp$4$$}=$element_ref$jscomp$2_props_79286$$);$element_ref$jscomp$2_props_79286$$=(0,$APP.$rumext$v2$use_ref$$)(null);
var $id$jscomp$977$$=(0,$APP.$rumext$v2$use_id$$)(),$token$jscomp$139$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79285_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79285_SHARP_$$),$token_name$jscomp$29$$)},$APP.$cljs$cst$1981$typography$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens$jscomp$6_not_active$jscomp$1$$)),$has_errors$jscomp$2$$=$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$139$$)!=
null,$display_name$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1218$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$139$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1218$$)?$or__5025__auto__$jscomp$1218$$:$token_name$jscomp$29$$}(),$resolved_value$jscomp$4_tooltip_content$jscomp$1$$=$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$139$$);$active_tokens$jscomp$6_not_active$jscomp$1$$=$token$jscomp$139$$==null||$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1981$typography$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens$jscomp$6_not_active$jscomp$1$$));
var $on_detach$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($display_name$jscomp$1$$)],function(){return $detach_token$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$detach_token$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($display_name$jscomp$1$$):$detach_token$jscomp$4$$($display_name$jscomp$1$$)});$resolved_value$jscomp$4_tooltip_content$jscomp$1$$=$active_tokens$jscomp$6_not_active$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-active-token.no-name"):
$has_errors$jscomp$2$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("options.deleted-token"):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$token_typography_row$resolved_value_tooltip_STAR_$$,{tokenName:$token_name$jscomp$29$$,resolvedValue:$resolved_value$jscomp$4_tooltip_content$jscomp$1$$});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row "+($has_errors$jscomp$2$$?"main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row-with-errors":
"")+" "+($active_tokens$jscomp$6_not_active$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row-not-active":""),children:[$has_errors$jscomp$2$$||$active_tokens$jscomp$6_not_active$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__error-dot"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"text-typography",className:"main_ui_workspace_sidebar_options_menus_token_typography_row__icon"}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$resolved_value$jscomp$4_tooltip_content$jscomp$1$$,triggerRef:$element_ref$jscomp$2_props_79286$$,className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-tooltip",id:$id$jscomp$977$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{"aria-labelledby":""+($id$jscomp$977$$??""),ref:$element_ref$jscomp$2_props_79286$$,className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-name",
children:$display_name$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("token-actions.detach-token"),tooltipClass:"main_ui_workspace_sidebar_options_menus_token_typography_row__detach-button",tooltipPlacement:"top-left",onClick:$on_detach$jscomp$6$$,icon:"detach"})]})};
$app$util$text$ui$closest_text_editor_content$$=function($target$jscomp$157$$){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?$target$jscomp$157$$.closest('[data-itype\x3d"editor"]'):$target$jscomp$157$$.closest(".public-DraftEditor-content")};
$app$main$ui$workspace$sidebar$options$menus$text$text_align_options_STAR_$$=function($props_79287_values$jscomp$95$$){var $on_change$jscomp$79$$=$props_79287_values$jscomp$95$$.onChange,$on_blur$jscomp$26$$=$props_79287_values$jscomp$95$$.onBlur;$props_79287_values$jscomp$95$$=$props_79287_values$jscomp$95$$.values;var $options$jscomp$627$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"left",$APP.$cljs$cst$266$id$$,"text-align-left",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-left"),$APP.$cljs$cst$1721$icon$$,"text-align-left"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$266$id$$,"text-align-center",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-center"),
$APP.$cljs$cst$1721$icon$$,"text-align-center"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"right",$APP.$cljs$cst$266$id$$,"text-align-right",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-right"),$APP.$cljs$cst$1721$icon$$,"text-align-right"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"justify",$APP.$cljs$cst$266$id$$,"text-align-justify",
$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-justify"),$APP.$cljs$cst$1721$icon$$,"text-justify"],null)],null)}),$handle_change$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$79$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$26$$)],function($G__79288_79309_value$jscomp$929$$){$G__79288_79309_value$jscomp$929$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1763$text_align$$,$G__79288_79309_value$jscomp$929$$],null);$on_change$jscomp$79$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$79$$.$cljs$core$IFn$_invoke$arity$1$($G__79288_79309_value$jscomp$929$$):$on_change$jscomp$79$$($G__79288_79309_value$jscomp$929$$);return $on_blur$jscomp$26$$!=null?$on_blur$jscomp$26$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$26$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$26$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__align-options",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$APP.$cljs$cst$1763$text_align$$.$cljs$core$IFn$_invoke$arity$1$($props_79287_values$jscomp$95$$),onChange:$handle_change$jscomp$14$$,name:"align-text-options",options:$options$jscomp$627$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$text_direction_options_STAR_$$=function($options$jscomp$628_props_79289$$){var $on_change$jscomp$80$$=$options$jscomp$628_props_79289$$.onChange,$on_blur$jscomp$27$$=$options$jscomp$628_props_79289$$.onBlur,$direction$jscomp$28$$=$APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$628_props_79289$$.values);$options$jscomp$628_props_79289$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"ltr",$APP.$cljs$cst$266$id$$,"ltr-text-direction",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.direction-ltr"),$APP.$cljs$cst$1721$icon$$,"text-ltr"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"rtl",$APP.$cljs$cst$266$id$$,"rtl-text-direction",$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.direction-rtl"),$APP.$cljs$cst$1721$icon$$,"text-rtl"],null)],null)});var $handle_change$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$80$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$27$$),$APP.$rumext$v2$adapt$$($direction$jscomp$28$$)],function($G__79290_79311_value$jscomp$930$$){$G__79290_79311_value$jscomp$930$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1764$text_direction$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79290_79311_value$jscomp$930$$,$direction$jscomp$28$$)?"none":$G__79290_79311_value$jscomp$930$$],null);$on_change$jscomp$80$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$80$$.$cljs$core$IFn$_invoke$arity$1$($G__79290_79311_value$jscomp$930$$):$on_change$jscomp$80$$($G__79290_79311_value$jscomp$930$$);return $on_blur$jscomp$27$$!=null?$on_blur$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():
$on_blur$jscomp$27$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-direction-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$direction$jscomp$28$$,onChange:$handle_change$jscomp$15$$,name:"text-direction-options",options:$options$jscomp$628_props_79289$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$vertical_align_STAR_$$=function($props_79291_vertical_align$jscomp$4$$){var $on_change$jscomp$81$$=$props_79291_vertical_align$jscomp$4$$.onChange,$on_blur$jscomp$28$$=$props_79291_vertical_align$jscomp$4$$.onBlur,$values$jscomp$97$$=$props_79291_vertical_align$jscomp$4$$.values;$props_79291_vertical_align$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1219$$=$APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$97$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1219$$)?$or__5025__auto__$jscomp$1219$$:"top"}();var $options$jscomp$629$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"top",$APP.$cljs$cst$266$id$$,"vertical-text-align-top",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.align-top"),
$APP.$cljs$cst$1721$icon$$,"text-top"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$266$id$$,"vertical-text-align-center",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.align-middle"),$APP.$cljs$cst$1721$icon$$,"text-middle"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"bottom",$APP.$cljs$cst$266$id$$,"vertical-text-align-bottom",
$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.align-bottom"),$APP.$cljs$cst$1721$icon$$,"text-bottom"],null)],null)}),$handle_change$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$81$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$28$$)],function($G__79292_79312_value$jscomp$931$$){$G__79292_79312_value$jscomp$931$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1767$vertical_align$$,
$G__79292_79312_value$jscomp$931$$],null);$on_change$jscomp$81$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$81$$.$cljs$core$IFn$_invoke$arity$1$($G__79292_79312_value$jscomp$931$$):$on_change$jscomp$81$$($G__79292_79312_value$jscomp$931$$);return $on_blur$jscomp$28$$!=null?$on_blur$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$28$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__vertical-align-options",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$props_79291_vertical_align$jscomp$4$$,onChange:$handle_change$jscomp$16$$,name:"vertical-align-text-options",options:$options$jscomp$629$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$grow_options_STAR_$$=function($grow_type$jscomp$9_props_79294$$){var $on_blur$jscomp$29$$=$grow_type$jscomp$9_props_79294$$.onBlur,$ids$jscomp$306$$=$grow_type$jscomp$9_props_79294$$.ids;$grow_type$jscomp$9_props_79294$$=$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$9_props_79294$$.values);var $editor_instance$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor$$),$options$jscomp$630$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"fixed",$APP.$cljs$cst$266$id$$,"text-fixed-grow",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.grow-fixed"),$APP.$cljs$cst$1721$icon$$,"text-fixed"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"auto-width",
$APP.$cljs$cst$266$id$$,"text-auto-width-grow",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.grow-auto-width"),$APP.$cljs$cst$1721$icon$$,"text-auto-width"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"auto-height",$APP.$cljs$cst$266$id$$,"text-auto-height-grow",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.grow-auto-height"),
$APP.$cljs$cst$1721$icon$$,"text-auto-height"],null)],null)}),$handle_change$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$29$$),$APP.$rumext$v2$adapt$$($editor_instance$jscomp$4$$)],function($content_79315_value$jscomp$932$$){$on_blur$jscomp$29$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$29$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$29$$();var $uid_79313$$=Symbol(),$grow_type_79314__$1$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($content_79315_value$jscomp$932$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($uid_79313$$));$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")&&($content_79315_value$jscomp$932$$=$APP.$cljs$core$truth_$$($editor_instance$jscomp$4$$)?$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($editor_instance$jscomp$4$$)):
null,$content_79315_value$jscomp$932$$!=null&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$first$$($ids$jscomp$306$$),$content_79315_value$jscomp$932$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4044$finalize_QMARK_$$,!0]))));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$306$$,
function($p1__79293_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79293_SHARP_$$,$APP.$cljs$cst$1770$grow_type$$,$grow_type_79314__$1$$)}));$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$($ids$jscomp$306$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$ids$jscomp$306$$],null))]));$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($uid_79313$$))});return $on_blur$jscomp$29$$!=null?$on_blur$jscomp$29$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$29$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$29$$():null});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__grow-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$APP.$app$common$data$name$$($grow_type$jscomp$9_props_79294$$),onChange:$handle_change$jscomp$17$$,name:"grow-text-options",options:$options$jscomp$630$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$text_decoration_options_STAR_$$=function($props_79295_text_decoration$jscomp$5$$){var $on_change$jscomp$82$$=$props_79295_text_decoration$jscomp$5$$.onChange,$on_blur$jscomp$30$$=$props_79295_text_decoration$jscomp$5$$.onBlur,$token_applied$jscomp$1$$=$props_79295_text_decoration$jscomp$5$$.tokenApplied,$values$jscomp$99$$=$props_79295_text_decoration$jscomp$5$$.values;$props_79295_text_decoration$jscomp$5$$=function(){var $G__79296$$=$APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$99$$);
return $G__79296$$==null?null:$APP.$app$common$data$name$$($G__79296$$)}();var $options$jscomp$631$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_applied$jscomp$1$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$260$value$$,"underline",$APP.$cljs$cst$266$id$$,"underline-text-decoration",$APP.$cljs$cst$2948$disabled$$,$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&
$token_applied$jscomp$1$$!=null,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.text-options.underline",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4784$underline$$)])),$APP.$cljs$cst$1721$icon$$,"text-underlined"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$260$value$$,"line-through",$APP.$cljs$cst$266$id$$,"line-through-text-decoration",
$APP.$cljs$cst$2948$disabled$$,$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$token_applied$jscomp$1$$!=null,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.text-options.strikethrough",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4787$line_through$$)])),$APP.$cljs$cst$1721$icon$$,"text-stroked"],null)],null)}),$handle_change$jscomp$18$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$82$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$30$$)],function($G__79297_79321_value$jscomp$933$$){$G__79297_79321_value$jscomp$933$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,$G__79297_79321_value$jscomp$933$$],null);$on_change$jscomp$82$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$82$$.$cljs$core$IFn$_invoke$arity$1$($G__79297_79321_value$jscomp$933$$):
$on_change$jscomp$82$$($G__79297_79321_value$jscomp$933$$);return $on_blur$jscomp$30$$!=null?$on_blur$jscomp$30$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$30$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$30$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-decoration-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79295_text_decoration$jscomp$5$$,
"none")?null:$props_79295_text_decoration$jscomp$5$$,onChange:$handle_change$jscomp$18$$,name:"text-decoration-options",disabled:$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$token_applied$jscomp$1$$!=null,allowEmpty:!0,options:$options$jscomp$631$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$=function($options$jscomp$632_options__$1$jscomp$89$$,$name$jscomp$459$$){$options$jscomp$632_options__$1$jscomp$89$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$632_options__$1$jscomp$89$$)?$APP.$cljs$core$_deref$$($options$jscomp$632_options__$1$jscomp$89$$):$options$jscomp$632_options__$1$jscomp$89$$;return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79298_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$459$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__79298_SHARP_$$,$APP.$cljs$cst$725$name$$))},$options$jscomp$632_options__$1$jscomp$89$$)};$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$=function($tokens$jscomp$52$$){return $APP.$cljs$core$delay_QMARK_$$($tokens$jscomp$52$$)?$APP.$cljs$core$_deref$$($tokens$jscomp$52$$):$tokens$jscomp$52$$};
$app$main$ui$workspace$sidebar$options$menus$text$find_token_by_id$$=function($tokens$jscomp$53$$,$id$jscomp$978$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79299_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79299_SHARP_$$),$APP.$cljs$core$uuid$$($id$jscomp$978$$))},$APP.$cljs$cst$1981$typography$$.$cljs$core$IFn$_invoke$arity$1$($tokens$jscomp$53$$))};
$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_eq$$=function($s1$jscomp$21$$,$s2$jscomp$18$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($s1$jscomp$21$$),$APP.$cljs$core$count$$($s2$jscomp$18$$))&&$APP.$cljs$core$every_QMARK_$$(function($p__79316_v2$jscomp$31$$){var $v1$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79316_v2$jscomp$31$$,0,null);$p__79316_v2$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79316_v2$jscomp$31$$,
1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($v1$jscomp$39$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$),$APP.$cljs$core$select_keys$$($p__79316_v2$jscomp$31$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$s1$jscomp$21$$,$s2$jscomp$18$$))};
$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_sel$$=function($v$jscomp$670$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79320_SHARP_$$){return $APP.$cljs$core$select_keys$$($p1__79320_SHARP_$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$)},$v$jscomp$670$$)};
$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_eq$$=function($v1$jscomp$40$$,$v2$jscomp$32$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($v1$jscomp$40$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$),$APP.$cljs$core$select_keys$$($v2$jscomp$32$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$))};
$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_sel$$=function($v$jscomp$671$$){return $APP.$cljs$core$truth_$$($v$jscomp$671$$)?$APP.$cljs$core$select_keys$$($v$jscomp$671$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$):null};
$app$main$ui$workspace$sidebar$options$shapes$path$options_STAR_$$=function($props_79308_type$jscomp$672$$){var $file_id$jscomp$418$$=$props_79308_type$jscomp$672$$.fileId,$page_id$jscomp$430$$=$props_79308_type$jscomp$672$$.pageId,$shape$jscomp$1026$$=$props_79308_type$jscomp$672$$.shape,$id$jscomp$986$$=$shape$jscomp$1026$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,$APP.$cljs$cst$266$id$$);$props_79308_type$jscomp$672$$=$shape$jscomp$1026$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$310$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$986$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$986$$],null)}),$shapes$jscomp$219$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1026$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1026$$],null)}),$applied_tokens$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,$APP.$cljs$cst$1873$applied_tokens$$),$measure_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,
$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$310$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$310$$)}),$is_layout_child_QMARK_$jscomp$6$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$);$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$310$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$310$$)});$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$);var $is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$310$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$310$$)}),$is_grid_parent_QMARK_$jscomp$6$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$);$is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1026$$);var $parents$jscomp$17_parents_by_ids_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$310$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$310$$)});$parents$jscomp$17_parents_by_ids_ref$jscomp$4$$=$APP.$rumext$v2$deref$$($parents$jscomp$17_parents_by_ids_ref$jscomp$4$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$310$$,appliedTokens:$applied_tokens$jscomp$30$$,type:$props_79308_type$jscomp$672$$,values:$layer_values$jscomp$5$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$310$$,type:$props_79308_type$jscomp$672$$,appliedTokens:$applied_tokens$jscomp$30$$,values:$measure_values$jscomp$5$$,shapes:$shapes$jscomp$219$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79308_type$jscomp$672$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1026$$)],null),values:$layout_container_values$jscomp$5$$,
"applied-tokens":$applied_tokens$jscomp$30$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$816$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$310$$),1);return $and__5023__auto__$jscomp$816$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$6$$)?$is_grid_parent_QMARK_$jscomp$6$$:$is_layout_child_QMARK_$jscomp$6$$:$and__5023__auto__$jscomp$816$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,
{shape:$APP.$cljs$core$first$$($parents$jscomp$17_parents_by_ids_ref$jscomp$4$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$17_parents_by_ids_ref$jscomp$4$$),$APP.$cljs$core$first$$($ids$jscomp$310$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$,
"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$6$$,ids:$ids$jscomp$310$$,type:$props_79308_type$jscomp$672$$,values:$layout_item_values$jscomp$5$$,shape:$shape$jscomp$1026$$,"applied-tokens":$applied_tokens$jscomp$30$$,"is-layout-child?":!0,"is-layout-container?":!1}):null,!$is_layout_child_QMARK_$jscomp$6$$||$is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$310$$,
values:$constraint_values$jscomp$5$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$310$$,type:$props_79308_type$jscomp$672$$,values:$shape$jscomp$1026$$,appliedTokens:$applied_tokens$jscomp$30$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$310$$,type:$props_79308_type$jscomp$672$$,showCaps:!0,values:$stroke_values$jscomp$5$$,appliedTokens:$applied_tokens$jscomp$30$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$310$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$310$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$310$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79308_type$jscomp$672$$,ids:$ids$jscomp$310$$,
shapes:$shapes$jscomp$219$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$430$$,fileId:$file_id$jscomp$418$$})]})};
$app$main$ui$workspace$sidebar$options$shapes$rect$options_STAR_$$=function($props_79310_type$jscomp$673$$){var $file_id$jscomp$419$$=$props_79310_type$jscomp$673$$.fileId,$page_id$jscomp$431$$=$props_79310_type$jscomp$673$$.pageId,$shape$jscomp$1027$$=$props_79310_type$jscomp$673$$.shape,$id$jscomp$987$$=$shape$jscomp$1027$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1027$$,$APP.$cljs$cst$266$id$$);$props_79310_type$jscomp$673$$=$shape$jscomp$1027$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1027$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$311$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$987$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$987$$],null)}),$shapes$jscomp$220$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1027$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1027$$],null)}),$applied_tokens$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1027$$,$APP.$cljs$cst$1873$applied_tokens$$),$measure_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,
$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$311$$)}),$is_layout_child_QMARK_$jscomp$7$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$);$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$311$$)});$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$);var $is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$311$$)}),$is_grid_parent_QMARK_$jscomp$7$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$);$is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1027$$);var $parents$jscomp$18_parents_by_ids_ref$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$311$$)});$parents$jscomp$18_parents_by_ids_ref$jscomp$5$$=$APP.$rumext$v2$deref$$($parents$jscomp$18_parents_by_ids_ref$jscomp$5$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$311$$,type:$props_79310_type$jscomp$673$$,appliedTokens:$applied_tokens$jscomp$31$$,values:$layer_values$jscomp$6$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$311$$,type:$props_79310_type$jscomp$673$$,values:$measure_values$jscomp$6$$,appliedTokens:$applied_tokens$jscomp$31$$,shapes:$shapes$jscomp$220$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79310_type$jscomp$673$$,ids:$ids$jscomp$311$$,values:$layout_container_values$jscomp$6$$,"applied-tokens":$applied_tokens$jscomp$31$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$817$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$311$$),1);return $and__5023__auto__$jscomp$817$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$7$$)?$is_grid_parent_QMARK_$jscomp$7$$:$is_layout_child_QMARK_$jscomp$7$$:$and__5023__auto__$jscomp$817$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,{shape:$APP.$cljs$core$first$$($parents$jscomp$18_parents_by_ids_ref$jscomp$5$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$18_parents_by_ids_ref$jscomp$5$$),
$APP.$cljs$core$first$$($ids$jscomp$311$$))}):null,$is_layout_child_QMARK_$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{ids:$ids$jscomp$311$$,type:$props_79310_type$jscomp$673$$,values:$layout_item_values$jscomp$6$$,"is-layout-child?":!0,"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$,"applied-tokens":$applied_tokens$jscomp$31$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$7$$,
shape:$shape$jscomp$1027$$}):null,!$is_layout_child_QMARK_$jscomp$7$$||$is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$311$$,values:$constraint_values$jscomp$6$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$311$$,type:$props_79310_type$jscomp$673$$,values:$shape$jscomp$1027$$,appliedTokens:$applied_tokens$jscomp$31$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$311$$,type:$props_79310_type$jscomp$673$$,values:$stroke_values$jscomp$6$$,appliedTokens:$applied_tokens$jscomp$31$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$311$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1027$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,
{ids:$ids$jscomp$311$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$311$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],
null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79310_type$jscomp$673$$,ids:$ids$jscomp$311$$,shapes:$shapes$jscomp$220$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1027$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$431$$,fileId:$file_id$jscomp$419$$})]})};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$=function($color$jscomp$180$$){try{return $APP.$cljs$core$not$$($color$jscomp$180$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$180$$,"none")?null:$APP.$cuerdas$core$starts_with_QMARK_$$($color$jscomp$180$$,"url")?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1616$multiple$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1298$color$$,$APP.$app$common$types$color$parse$$($color$jscomp$180$$),$APP.$cljs$cst$1734$opacity$$,1],null)}catch($e79344$$){return console.error("Error parsing color",$e79344$$),null}};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_fill_values$$=function($shape$jscomp$1028$$){var $fill_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,$app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$),$color$jscomp$181$$=$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$(function(){var $or__5025__auto__$jscomp$1221$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1028$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1403$fill$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1221$$)?$or__5025__auto__$jscomp$1221$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1028$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1403$fill$$],
null))}());return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$818$$=$APP.$cljs$core$empty_QMARK_$$($fill_values$jscomp$2$$);return $and__5023__auto__$jscomp$818$$?$color$jscomp$181$$:$and__5023__auto__$jscomp$818$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$181$$),$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$181$$)],
null):$fill_values$jscomp$2$$};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_stroke_values$$=function($shape$jscomp$1029$$){var $stroke_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1029$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$color$jscomp$182$$=$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$(function(){var $or__5025__auto__$jscomp$1222$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1029$$,new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$2903$stroke$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1222$$)?$or__5025__auto__$jscomp$1222$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1029$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$2903$stroke$$],
null))}()),$stroke_color$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$182$$,"#000000"),$stroke_opacity$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$182$$,1),$stroke_style$jscomp$4$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $or__5025__auto__$jscomp$1223_or__5025__auto____$1$jscomp$133$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1029$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1866$stroke_style$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1223_or__5025__auto____$1$jscomp$133$$))return $or__5025__auto__$jscomp$1223_or__5025__auto____$1$jscomp$133$$;$or__5025__auto__$jscomp$1223_or__5025__auto____$1$jscomp$133$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1029$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1866$stroke_style$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1223_or__5025__auto____$1$jscomp$133$$)?$or__5025__auto__$jscomp$1223_or__5025__auto____$1$jscomp$133$$:$APP.$cljs$core$truth_$$($color$jscomp$182$$)?"solid":"none"}()),$stroke_width$jscomp$9$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $or__5025__auto__$jscomp$1224_or__5025__auto____$1$jscomp$134$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1029$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1655$stroke_width$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1224_or__5025__auto____$1$jscomp$134$$))return $or__5025__auto__$jscomp$1224_or__5025__auto____$1$jscomp$134$$;$or__5025__auto__$jscomp$1224_or__5025__auto____$1$jscomp$134$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1029$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1655$stroke_width$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1224_or__5025__auto____$1$jscomp$134$$)?$or__5025__auto__$jscomp$1224_or__5025__auto____$1$jscomp$134$$:"1"}());return $APP.$cljs$core$empty_QMARK_$$($stroke_values$jscomp$7$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1739$stroke_color$$,$stroke_color$$,$APP.$cljs$cst$1740$stroke_opacity$$,$stroke_opacity$$,$APP.$cljs$cst$1866$stroke_style$$,$stroke_style$jscomp$4$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$1655$stroke_width$$,$stroke_width$jscomp$9$$],null):$stroke_values$jscomp$7$$};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$options_STAR_$$=function($props_79379_type$jscomp$674$$){var $file_id$jscomp$420$$=$props_79379_type$jscomp$674$$.fileId,$page_id$jscomp$432$$=$props_79379_type$jscomp$674$$.pageId,$shape$jscomp$1030$$=$props_79379_type$jscomp$674$$.shape,$id$jscomp$988$$=$shape$jscomp$1030$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1030$$,$APP.$cljs$cst$266$id$$);$props_79379_type$jscomp$674$$=$shape$jscomp$1030$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1030$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$312$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$988$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$988$$],null)}),$shapes$jscomp$221$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1030$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1030$$],null)}),$applied_tokens$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1030$$,$APP.$cljs$cst$1873$applied_tokens$$),$map__79380_map__79380__$1_tag$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1030$$,$APP.$cljs$cst$1637$content$$);$map__79380_map__79380__$1_tag$jscomp$94$$=$APP.$cljs$core$__destructure_map$$($map__79380_map__79380__$1_tag$jscomp$94$$);$map__79380_map__79380__$1_tag$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79380_map__79380__$1_tag$jscomp$94$$,
$APP.$cljs$cst$78$tag$$);var $fill_values$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1030$$)],function(){return $app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_fill_values$$($shape$jscomp$1030$$)}),$stroke_values$jscomp$8$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1030$$)],function(){return $app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_stroke_values$$($shape$jscomp$1030$$)}),
$measure_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$constraint_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$7$$=
$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$312$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$312$$)}),$is_layout_child_QMARK_$jscomp$8$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$);
$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$312$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$312$$)});$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$);var $is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$312$$)],function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$312$$)}),$is_grid_parent_QMARK_$jscomp$8$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$);$is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1030$$);
var $parents$jscomp$19_parents_by_ids_ref$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$312$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$312$$)});$parents$jscomp$19_parents_by_ids_ref$jscomp$6$$=$APP.$rumext$v2$deref$$($parents$jscomp$19_parents_by_ids_ref$jscomp$6$$);return $APP.$cljs$core$contains_QMARK_$$($app$main$ui$workspace$sidebar$options$shapes$svg_raw$svg_elements$$,$map__79380_map__79380__$1_tag$jscomp$94$$)?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{ids:$ids$jscomp$312$$,type:$props_79379_type$jscomp$674$$,appliedTokens:$applied_tokens$jscomp$32$$,values:$measure_values$jscomp$7$$,shapes:$shapes$jscomp$221$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79379_type$jscomp$674$$,ids:new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1030$$)],null),values:$layout_container_values$jscomp$7$$,"applied-tokens":$applied_tokens$jscomp$32$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$819$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$312$$),1);return $and__5023__auto__$jscomp$819$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$8$$)?
$is_grid_parent_QMARK_$jscomp$8$$:$is_layout_child_QMARK_$jscomp$8$$:$and__5023__auto__$jscomp$819$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,{shape:$APP.$cljs$core$first$$($parents$jscomp$19_parents_by_ids_ref$jscomp$6$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$19_parents_by_ids_ref$jscomp$6$$),$APP.$cljs$core$first$$($ids$jscomp$312$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$8$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{ids:$ids$jscomp$312$$,type:$props_79379_type$jscomp$674$$,values:$layout_item_values$jscomp$7$$,"is-layout-child?":!0,"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$8$$,"applied-tokens":$applied_tokens$jscomp$32$$,shape:$shape$jscomp$1030$$}):null,!$is_layout_child_QMARK_$jscomp$8$$||$is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$312$$,values:$constraint_values$jscomp$7$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$312$$,type:$props_79379_type$jscomp$674$$,values:$fill_values$jscomp$3$$,appliedTokens:$applied_tokens$jscomp$32$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,
{ids:$ids$jscomp$312$$,type:$props_79379_type$jscomp$674$$,values:$stroke_values$jscomp$8$$,appliedTokens:$applied_tokens$jscomp$32$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$312$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1030$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$312$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$312$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,
{type:$props_79379_type$jscomp$674$$,ids:$ids$jscomp$312$$,shapes:$shapes$jscomp$221$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1030$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$432$$,fileId:$file_id$jscomp$420$$})]}):null};
$app$main$ui$workspace$sidebar$options$shapes$text$options_STAR_$$=function($props_79378_type$jscomp$675$$){var $file_id$jscomp$421$$=$props_79378_type$jscomp$675$$.fileId,$libraries$jscomp$154$$=$props_79378_type$jscomp$675$$.libraries,$page_id$jscomp$433$$=$props_79378_type$jscomp$675$$.pageId,$shape$jscomp$1031$$=$props_79378_type$jscomp$675$$.shape,$id$jscomp$989$$=$shape$jscomp$1031$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1031$$,$APP.$cljs$cst$266$id$$);$props_79378_type$jscomp$675$$=
$shape$jscomp$1031$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1031$$,$APP.$cljs$cst$139$type$$);var $ids$jscomp$313$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$989$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$989$$],null)}),$shapes$jscomp$222$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1031$$)],
function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1031$$],null)}),$applied_tokens$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1031$$,$APP.$cljs$cst$1873$applied_tokens$$),$measure_values$jscomp$8$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$9$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,
$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$layout_item_values$jscomp$8$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$8$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$9_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$313$$)}),$is_layout_child_QMARK_$jscomp$9$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$9_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$);$is_flex_parent_QMARK_$jscomp$9_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$313$$)});$is_flex_parent_QMARK_$jscomp$9_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$9_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$);var $is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$313$$)}),$is_grid_parent_QMARK_$jscomp$9$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$);$is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1031$$);var $parents$jscomp$20_parents_by_ids_ref$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$313$$)});$parents$jscomp$20_parents_by_ids_ref$jscomp$7$$=$APP.$rumext$v2$deref$$($parents$jscomp$20_parents_by_ids_ref$jscomp$7$$);var $editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_editor_styles$$),$v2_editor_state_map$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_v2_editor_state$$),$v1_editor_state_map$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$),
$editor$jscomp$8_fill_values$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor$$),$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1"),$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2");$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$=
$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$?$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$:$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$?$v2_editor_state_map$$:$v1_editor_state_map$$;$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$=$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$id$jscomp$989$$):null;$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$=
$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$id$jscomp$989$$);$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$=$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$?$editor$jscomp$8_fill_values$jscomp$4$$:null;$editor$jscomp$8_fill_values$jscomp$4$$=$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$4009$editor_styles$$,$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$,$APP.$cljs$cst$4011$editor_state$$,$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$APP.$cljs$cst$4010$editor_instance$$,$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,$APP.$cljs$cst$1811$shape$$,$shape$jscomp$1031$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$text$text_fill_attrs$$,$APP.$cljs$cst$1634$fills$$)],
null));$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1770$grow_type$$],null)),$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$),
$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$1031$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4009$editor_styles$$,$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$,$APP.$cljs$cst$4011$editor_state$$,$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,
$APP.$cljs$cst$4010$editor_instance$$,$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,$APP.$cljs$cst$1811$shape$$,$shape$jscomp$1031$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4009$editor_styles$$,$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$,$APP.$cljs$cst$4011$editor_state$$,$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,
$APP.$cljs$cst$4010$editor_instance$$,$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,$APP.$cljs$cst$1811$shape$$,$shape$jscomp$1031$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$313$$,type:$props_79378_type$jscomp$675$$,appliedTokens:$applied_tokens$jscomp$33$$,
values:$layer_values$jscomp$7$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{ids:$ids$jscomp$313$$,type:$props_79378_type$jscomp$675$$,values:$measure_values$jscomp$8$$,appliedTokens:$applied_tokens$jscomp$33$$,shapes:$shapes$jscomp$222$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79378_type$jscomp$675$$,ids:$ids$jscomp$313$$,values:$layout_container_values$jscomp$8$$,
"applied-tokens":$applied_tokens$jscomp$33$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$820$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$313$$),1);return $and__5023__auto__$jscomp$820$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$9$$)?$is_grid_parent_QMARK_$jscomp$9$$:$is_layout_child_QMARK_$jscomp$9$$:$and__5023__auto__$jscomp$820$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,
{shape:$APP.$cljs$core$first$$($parents$jscomp$20_parents_by_ids_ref$jscomp$7$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$20_parents_by_ids_ref$jscomp$7$$),$APP.$cljs$core$first$$($ids$jscomp$313$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{ids:$ids$jscomp$313$$,type:$props_79378_type$jscomp$675$$,values:$layout_item_values$jscomp$8$$,
"is-layout-child?":!0,"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$9_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$9$$,"applied-tokens":$applied_tokens$jscomp$33$$,shape:$shape$jscomp$1031$$}):null,!$is_layout_child_QMARK_$jscomp$9$$||$is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$313$$,
values:$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$,{ids:$ids$jscomp$313$$,type:$props_79378_type$jscomp$675$$,appliedTokens:$applied_tokens$jscomp$33$$,values:$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,
{ids:$ids$jscomp$313$$,type:$props_79378_type$jscomp$675$$,values:$editor$jscomp$8_fill_values$jscomp$4$$,appliedTokens:$applied_tokens$jscomp$33$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$313$$,type:$props_79378_type$jscomp$675$$,values:$stroke_values$jscomp$9$$,disableStrokeStyle:!0,appliedTokens:$applied_tokens$jscomp$33$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($editor$jscomp$8_fill_values$jscomp$4$$))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{type:$props_79378_type$jscomp$675$$,shapes:$shapes$jscomp$222$$,fileId:$file_id$jscomp$421$$,libraries:$libraries$jscomp$154$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$313$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1031$$,$APP.$cljs$cst$1654$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,
{ids:$ids$jscomp$313$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79378_type$jscomp$675$$,ids:$ids$jscomp$313$$,shapes:$shapes$jscomp$222$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1031$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),
pageId:$page_id$jscomp$433$$,fileId:$file_id$jscomp$421$$})]})};
$app$main$ui$workspace$sidebar$options$single_shape_options_STAR_$$=function($file_id$jscomp$422_props_79414$$){var $libraries$jscomp$155$$,$page_id$jscomp$434$$;({shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,pageId:$page_id$jscomp$434$$,fileId:$file_id$jscomp$422_props_79414$$,libraries:$libraries$jscomp$155$$,...$props$jscomp$347_props__$1$jscomp$83$$}=$file_id$jscomp$422_props_79414$$);var $shape_type$jscomp$8$$=$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$?.type??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,$APP.$cljs$cst$139$type$$),$shape_id$jscomp$164$$=$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,$APP.$cljs$cst$266$id$$),$wasm_modifiers_wasm_modifiers__$1$jscomp$inline_8960$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),
$modifiers$jscomp$113$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$);if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")){$wasm_modifiers_wasm_modifiers__$1$jscomp$inline_8960$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$wasm_modifiers_wasm_modifiers__$1$jscomp$inline_8960$$);var $JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$=
$APP.$app$common$geom$shapes$apply_transform$$($JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($wasm_modifiers_wasm_modifiers__$1$jscomp$inline_8960$$,$shape_id$jscomp$164$$))}else $JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$113$$,
$shape_id$jscomp$164$$),$APP.$cljs$cst$1810$modifiers$$));var $props$jscomp$347_props__$1$jscomp$83$$={...$props$jscomp$347_props__$1$jscomp$83$$,shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$,libraries:$libraries$jscomp$155$$};switch($shape_type$jscomp$8$$ instanceof $APP.$cljs$core$Keyword$$?$shape_type$jscomp$8$$.$fqn$:null){case "frame":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$shapes$frame$options_STAR_$$,
$props$jscomp$347_props__$1$jscomp$83$$);case "group":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$shapes$group$options_STAR_$$,$props$jscomp$347_props__$1$jscomp$83$$);case "text":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$text$options_STAR_$$,{shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$,libraries:$libraries$jscomp$155$$});case "rect":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$rect$options_STAR_$$,
{shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$});case "circle":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$circle$options_STAR_$$,{shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$});case "path":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$path$options_STAR_$$,
{shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$});case "svg-raw":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$svg_raw$options_STAR_$$,{shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$});case "bool":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$bool$options_STAR_$$,
{shape:$JSCompiler_temp$jscomp$1835_shape$jscomp$1032_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$422_props_79414$$,pageId:$page_id$jscomp$434$$});default:return null}};
$app$main$ui$workspace$sidebar$options$specialized_panel_STAR_$$=function($panel$jscomp$2_props_79431$$){$panel$jscomp$2_props_79431$$=$panel$jscomp$2_props_79431$$.panel;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($panel$jscomp$2_props_79431$$),$APP.$cljs$cst$3960$component_swap$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,{shapes:$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($panel$jscomp$2_props_79431$$),
isSwapOpened:!0}):null};
$app$main$ui$workspace$sidebar$options$design_menu_STAR_$$=function($page_id$jscomp$436_props_79438$$){var $shapes$jscomp$224$$=$page_id$jscomp$436_props_79438$$.shapes,$selected$jscomp$175$$=$page_id$jscomp$436_props_79438$$.selected,$file_id$jscomp$424$$=$page_id$jscomp$436_props_79438$$.fileId,$objects$jscomp$798$$=$page_id$jscomp$436_props_79438$$.objects;$page_id$jscomp$436_props_79438$$=$page_id$jscomp$436_props_79438$$.pageId;var $sp_panel$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$specialized_panel$$),$drawing$jscomp$3$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$edition$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$files$jscomp$29$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$libraries$jscomp$157$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$29$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$424$$)],function(){return $APP.$app$main$refs$select_libraries$$($files$jscomp$29$$,$file_id$jscomp$424$$)}),
$edit_grid_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$798$$),$APP.$rumext$v2$adapt$$($edition$jscomp$7$$)],function(){return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$798$$,$edition$jscomp$7$$)}),$grid_edition$jscomp$1_selected_cells$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_grid_edition$$);$grid_edition$jscomp$1_selected_cells$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79436_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$798$$,
$edition$jscomp$7$$),$APP.$cljs$cst$1696$layout_grid_cells$$),$p1__79436_SHARP_$$)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$1_selected_cells$$,$edition$jscomp$7$$),$APP.$cljs$cst$1921$selected$$));var $shapes_with_children_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$175$$),
$APP.$rumext$v2$adapt$$($objects$jscomp$798$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$224$$)],function(){$APP.$cljs$core$reset_BANG_$$($shapes_with_children_STAR_$$,null);a:{var $G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$selected$jscomp$175$$);for(var $G__79507$jscomp$inline_8969_G__79509$jscomp$inline_8971_visited$jscomp$inline_8963$$=
$selected$jscomp$175$$;;){var $children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$=$APP.$cljs$core$peek$$($G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$);if($APP.$cljs$core$truth_$$($children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$))$children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$798$$,$children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$),$children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$),
$APP.$cljs$core$seq$$($children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$)?($children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($G__79507$jscomp$inline_8969_G__79509$jscomp$inline_8971_visited$jscomp$inline_8963$$,$children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$),
$G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$),$children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$),$G__79507$jscomp$inline_8969_G__79509$jscomp$inline_8971_visited$jscomp$inline_8963$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($G__79507$jscomp$inline_8969_G__79509$jscomp$inline_8971_visited$jscomp$inline_8963$$,
$children$jscomp$inline_8966_new_children$jscomp$inline_8967_shape$jscomp$inline_8965_temp__5823__auto__$jscomp$inline_8964$$)):$G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$=$APP.$cljs$core$pop$$($G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$);else{$G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$798$$)),
$G__79507$jscomp$inline_8969_G__79509$jscomp$inline_8971_visited$jscomp$inline_8963$$);break a}}$G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$=void 0}return $APP.$cljs$core$reset_BANG_$$($shapes_with_children_STAR_$$,$G__79506$jscomp$inline_8968_G__79508$jscomp$inline_8970_queue$jscomp$inline_8962_result$jscomp$367$$)});var $shapes_with_children$jscomp$5$$=$APP.$cljs$core$_deref$$($shapes_with_children_STAR_$$),$total_selected$jscomp$1$$=$APP.$cljs$core$count$$($selected$jscomp$175$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__design-options",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$align$align_options_STAR_$$,{shapes:$shapes$jscomp$224$$,objects:$objects$jscomp$798$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$bool$bool_options_STAR_$$,{totalSelected:$total_selected$jscomp$1$$,shapes:$shapes$jscomp$224$$,shapesWithChildren:$shapes_with_children$jscomp$5$$}),
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($edit_grid_QMARK_$$)?$APP.$app$common$data$not_empty_QMARK_$$($grid_edition$jscomp$1_selected_cells$$):$edit_grid_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,{shape:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$798$$,$edition$jscomp$7$$),cells:$grid_edition$jscomp$1_selected_cells$$}):$APP.$cljs$core$truth_$$($edit_grid_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_layout_edition$$,
{ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$edition$jscomp$7$$],null),values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$798$$,$edition$jscomp$7$$)}):$sp_panel$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$specialized_panel_STAR_$$,{panel:$sp_panel$$}):$APP.$app$common$data$not_empty_QMARK_$$($drawing$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$drawing$drawing_options_STAR_$$,
{drawingState:$drawing$jscomp$3$$}):$total_selected$jscomp$1$$===0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$page$options_STAR_$$,{}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shape_options_STAR_$$,{shapes:$shapes$jscomp$224$$,shapesWithChildren:$shapes_with_children$jscomp$5$$,pageId:$page_id$jscomp$436_props_79438$$,fileId:$file_id$jscomp$424$$,selected:$selected$jscomp$175$$,libraries:$libraries$jscomp$157$$})]})};
$app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$=function($props_79485$$){var $frame$jscomp$72$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($props_79485$$.objects,$APP.$cljs$core$first$$($props_79485$$.shapes));return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$inspect$right_sidebar$right_sidebar_STAR_$$,{...$props_79485$$,frame:$frame$jscomp$72$$,from:$APP.$cljs$cst$2532$workspace$$})};
$app$main$ui$workspace$sidebar$options$on_option_tab_change$$=function($mode$jscomp$51_mode__$1$jscomp$3$$){$mode$jscomp$51_mode__$1$jscomp$3$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$51_mode__$1$jscomp$3$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$layout$set_options_mode$$($mode$jscomp$51_mode__$1$jscomp$3$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$51_mode__$1$jscomp$3$$,$APP.$cljs$cst$2672$inspect$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!0)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!1)]))};
$app$main$ui$workspace$sidebar$options$options_content_STAR_$$=function($props_79489$$){var $on_expand$jscomp$2$$=$props_79489$$.onExpand,$on_change_section$jscomp$1$$=$props_79489$$.onChangeSection,$selected$jscomp$176$$=$props_79489$$.selected,$file_id$jscomp$425$$=$props_79489$$.fileId,$objects$jscomp$800$$=$props_79489$$.objects,$page_id$jscomp$437$$=$props_79489$$.pageId,$permissions$jscomp$34$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$),$render_context_lost_QMARK_$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$render_context_lost_QMARK_$$),$options_mode$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$options_mode_global$$),$shapes$jscomp$226$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$176$$),$APP.$rumext$v2$adapt$$($objects$jscomp$800$$)],function(){return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$800$$)),
$selected$jscomp$176$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__tool-window",children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$822$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$34$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$822$$)?$APP.$cljs$core$not$$($render_context_lost_QMARK_$$):$and__5023__auto__$jscomp$822$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,
{tabs:$app$main$ui$workspace$sidebar$options$options_tabs$$,onChange:$app$main$ui$workspace$sidebar$options$on_option_tab_change$$,selected:$APP.$cljs$core$name$$($options_mode$jscomp$1$$),className:"main_ui_workspace_sidebar_options__options-tab-switcher",children:function(){var $G__79495__$1$$=$options_mode$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$options_mode$jscomp$1$$.$fqn$:null;switch($G__79495__$1$$){case "prototype":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__interaction-options",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$interactions_menu_STAR_$$,{shape:$APP.$cljs$core$first$$($shapes$jscomp$226$$)})});case "inspect":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__inspect-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$,{pageId:$page_id$jscomp$437$$,fileId:$file_id$jscomp$425$$,objects:$objects$jscomp$800$$,
selected:$selected$jscomp$176$$,shapes:$shapes$jscomp$226$$,onChangeSection:$on_change_section$jscomp$1$$,onExpand:$on_expand$jscomp$2$$})});case "design":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$design_menu_STAR_$$,{selected:$selected$jscomp$176$$,objects:$objects$jscomp$800$$,pageId:$page_id$jscomp$437$$,fileId:$file_id$jscomp$425$$,shapes:$shapes$jscomp$226$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79495__$1$$)].join(""));
}}()}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__inspect-options main_ui_workspace_sidebar_options__read-only",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$,{pageId:$page_id$jscomp$437$$,fileId:$file_id$jscomp$425$$,objects:$objects$jscomp$800$$,selected:$selected$jscomp$176$$,shapes:$shapes$jscomp$226$$,onChangeSection:$on_change_section$jscomp$1$$,onExpand:$on_expand$jscomp$2$$})})})};
$app$main$ui$workspace$sidebar$options$make_page_objects_ref$$=function($file_id$jscomp$426$$,$page_id$jscomp$438$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79496_SHARP_$$){return $APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($p1__79496_SHARP_$$,$file_id$jscomp$426$$,$page_id$jscomp$438$$)},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$=function($command$jscomp$21_props_79413_unique_key$$){var $char$$jscomp$5$$=$command$jscomp$21_props_79413_unique_key$$.char;$command$jscomp$21_props_79413_unique_key$$=$command$jscomp$21_props_79413_unique_key$$.command;var $modified_keys$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1954$up$$,"↑",$APP.$cljs$cst$1953$down$$,"↓",$APP.$cljs$cst$257$left$$,"←",$APP.$cljs$cst$258$right$$,"→",$cljs$cst$5455$plus$$,"+"],
null),$macos_keys$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2149$shift$$,$APP.$cljs$cst$3729$del$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5742$esc$$,$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$4834$delete$$,$APP.$cljs$cst$381$enter$$,$cljs$cst$5540$option$$,$cljs$cst$5743$control$$],"⇧⌫⌥⎋⌘⌫⏎⌥⌃".split("")),$char$__$2_is_macos_QMARK_$$=$APP.$app$config$check_platform_QMARK_$$(),$char$__$1$$=$APP.$cljs$core$contains_QMARK_$$($modified_keys$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$$jscomp$5$$))?
function(){var $fexpr__79415$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$$jscomp$5$$);return $fexpr__79415$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79415$$.$cljs$core$IFn$_invoke$arity$1$($modified_keys$$):$fexpr__79415$$($modified_keys$$)}():$char$$jscomp$5$$;$char$__$2_is_macos_QMARK_$$=$char$__$2_is_macos_QMARK_$$&&$APP.$cljs$core$contains_QMARK_$$($macos_keys$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$__$1$$))?function(){var $fexpr__79416$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$__$1$$);
return $fexpr__79416$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79416$$.$cljs$core$IFn$_invoke$arity$1$($macos_keys$$):$fexpr__79416$$($macos_keys$$)}():$char$__$1$$;$command$jscomp$21_props_79413_unique_key$$=[$APP.$app$common$data$name$$($command$jscomp$21_props_79413_unique_key$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($char$__$2_is_macos_QMARK_$$)].join("");return(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__key",children:$char$__$2_is_macos_QMARK_$$},
$command$jscomp$21_props_79413_unique_key$$)};
$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$=function($type$jscomp$676$$,$keyname$$){var $translat_pre$$=function(){var $G__79418__$1$$=$type$jscomp$676$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$676$$.$fqn$:null;switch($G__79418__$1$$){case "sc":return"shortcuts.";case "sec":return"shortcut-section.";case "sub-sec":return"shortcut-subsection.";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79418__$1$$)].join(""));}}();
return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($translat_pre$$),$APP.$app$common$data$name$$($keyname$$)].join(""))};
$app$main$ui$workspace$sidebar$shortcuts$add_translation$$=function($type$jscomp$677$$,$item$jscomp$133$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__79419_v$jscomp$672$$){var $k$jscomp$693$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79419_v$jscomp$672$$,0,null);$p__79419_v$jscomp$672$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79419_v$jscomp$672$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$693$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__79419_v$jscomp$672$$,$cljs$cst$5744$translation$$,$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($type$jscomp$677$$,$k$jscomp$693$$))],null)},$item$jscomp$133$$)};
$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$=function($shortcuts$jscomp$8$$){function $get_sc_by_subsection$$($subsection$jscomp$1$$,$p__79424_v$jscomp$673$$){var $k$jscomp$694$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79424_v$jscomp$673$$,0,null);$p__79424_v$jscomp$673$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79424_v$jscomp$673$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__79423_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subsection$jscomp$1$$,
$p1__79423_SHARP_$$)},$APP.$cljs$cst$4785$subsections$$.$cljs$core$IFn$_invoke$arity$1$($p__79424_v$jscomp$673$$)))?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$694$$,$p__79424_v$jscomp$673$$]):null}var $subsections$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4785$subsections$$),$APP.$cljs$core$vals$$($shortcuts$jscomp$8$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$165$$,
$subsection$jscomp$2$$){var $shortcuts_by_subsection$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($get_sc_by_subsection$$,$subsection$jscomp$2$$),$shortcuts$jscomp$8$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$165$$,$subsection$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,
$shortcuts_by_subsection$$],null))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$subsections$$)};
$app$main$ui$workspace$sidebar$shortcuts$shortcuts_keys_STAR_$$=function($last_element_managed_list_props_79428$$){var $chars_list_content$jscomp$251_short_char_list$$=$last_element_managed_list_props_79428$$.content,$command$jscomp$22$$=$last_element_managed_list_props_79428$$.command;$last_element_managed_list_props_79428$$=$APP.$cljs$core$coll_QMARK_$$($chars_list_content$jscomp$251_short_char_list$$)?$chars_list_content$jscomp$251_short_char_list$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$List$EMPTY$$,
$chars_list_content$jscomp$251_short_char_list$$);$chars_list_content$jscomp$251_short_char_list$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$shortcuts$split_sc$$,$last_element_managed_list_props_79428$$);$last_element_managed_list_props_79428$$=$APP.$cljs$core$last$$($chars_list_content$jscomp$251_short_char_list$$);$chars_list_content$jscomp$251_short_char_list$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($chars_list_content$jscomp$251_short_char_list$$))?
$chars_list_content$jscomp$251_short_char_list$$:$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($chars_list_content$jscomp$251_short_char_list$$);var $penultimate$$=$APP.$cljs$core$last$$($chars_list_content$jscomp$251_short_char_list$$);return(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__keys",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$183$$,$chars$jscomp$5$$){$out_arr__44124__auto__$jscomp$183$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$20$$,$char$$jscomp$6$$){$out_arr__44124__auto____$1$jscomp$20$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$,{"char":$char$$jscomp$6$$,command:$command$jscomp$22$$},""+($char$$jscomp$6$$??"")+"-"+($APP.$cljs$core$name$$($command$jscomp$22$$)??"")));return $out_arr__44124__auto____$1$jscomp$20$$},[],$chars$jscomp$5$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($chars$jscomp$5$$,
$penultimate$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__space",children:","}):null]},$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$($chars$jscomp$5$$)));return $out_arr__44124__auto__$jscomp$183$$},[],$chars_list_content$jscomp$251_short_char_list$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_element_managed_list_props_79428$$,$penultimate$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_shortcuts__space",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.or")}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$184$$,$char$$jscomp$7$$){$out_arr__44124__auto__$jscomp$184$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$,{"char":$char$$jscomp$7$$,command:$command$jscomp$22$$},""+($char$$jscomp$7$$??"")+"-"+($APP.$cljs$core$name$$($command$jscomp$22$$)??
"")));return $out_arr__44124__auto__$jscomp$184$$},[],$last_element_managed_list_props_79428$$)]}):null]})};
$app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$=function($filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$){var $is_match_subsection$$=$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$.isMatchSubsection,$is_match_section$$=$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$.isMatchSection,$filter_term$jscomp$2$$=$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$.filterTerm,
$elements$jscomp$7$$=$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$.elements;$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$keys$$($elements$jscomp$7$$);$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79432_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5745$sc$$,
$p1__79432_SHARP_$$)},$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$);var $match_shortcut_QMARK_$$=$APP.$cljs$core$some$$(function($p1__79433_SHARP_$$){return $app$util$strings$matches_search$$($p1__79433_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$2$$))},$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$);$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$823$$=
$APP.$cljs$core$truth_$$($is_match_section$$)?$is_match_section$$:$is_match_subsection$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$823$$)?$APP.$cljs$core$not$$($match_shortcut_QMARK_$$):$and__5023__auto__$jscomp$823$$}())?$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79434_SHARP_$$){return $app$util$strings$matches_search$$($p1__79434_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$2$$))},
$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$);$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$=$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$);return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_shortcuts__sub-menu",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$185$$,
$command_translate$$){$out_arr__44124__auto__$jscomp$185$$.push(function(){var $content$jscomp$252_vec__79439$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79435_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5744$translation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__79435_SHARP_$$)),$command_translate$$)},$elements$jscomp$7$$)),$command$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$252_vec__79439$$,
0,null),$comand_info$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$252_vec__79439$$,1,null);$content$jscomp$252_vec__79439$$=function(){var $or__5025__auto__$jscomp$1226$$=$APP.$cljs$cst$4893$show_command$$.$cljs$core$IFn$_invoke$arity$1$($comand_info$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1226$$)?$or__5025__auto__$jscomp$1226$$:$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($comand_info$$)}();return(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_sidebar_shortcuts__shortcuts-name",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__command-name",children:$command_translate$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcuts_keys_STAR_$$,{content:$content$jscomp$252_vec__79439$$,command:$command$jscomp$23$$})]},$command_translate$$)}());return $out_arr__44124__auto__$jscomp$185$$},[],$filtered$jscomp$3_props_79437_shortcut_name_shortcut_translations_sorted_filtered$$)})};
$app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$=function($props_79442$$){var $is_sub$$=$props_79442$$.isSub,$name$jscomp$460$$=$props_79442$$.name;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:$APP.$cljs$core$truth_$$($is_sub$$)?"main_ui_workspace_sidebar_shortcuts__subsection-title":"main_ui_workspace_sidebar_shortcuts__section-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($props_79442$$.isVisible)?
"arrow-down":"arrow-right",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$truth_$$($is_sub$$)?"main_ui_workspace_sidebar_shortcuts__subsection-name":"main_ui_workspace_sidebar_shortcuts__section-name",children:$name$jscomp$460$$})]})};
$app$main$ui$workspace$sidebar$shortcuts$shortcut_subsection_STAR_$$=function($basic_shortcuts_props_79449_subsections_names$$){var $manage_sections$$=$basic_shortcuts_props_79449_subsections_names$$.manageSections,$is_match_section$jscomp$1$$=$basic_shortcuts_props_79449_subsections_names$$.isMatchSection,$filter_term$jscomp$3$$=$basic_shortcuts_props_79449_subsections_names$$.filterTerm,$subsections$jscomp$1$$=$basic_shortcuts_props_79449_subsections_names$$.subsections,$open_sections$$=$basic_shortcuts_props_79449_subsections_names$$.openSections;
$basic_shortcuts_props_79449_subsections_names$$=$APP.$cljs$core$keys$$($subsections$jscomp$1$$);var $sorted_translations_subsection_translations$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$226$none$$,$APP.$cljs$core$first$$($basic_shortcuts_props_79449_subsections_names$$))?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79443_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5745$sc$$,$p1__79443_SHARP_$$)},$basic_shortcuts_props_79449_subsections_names$$):
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79444_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5746$sub_sec$$,$p1__79444_SHARP_$$)},$basic_shortcuts_props_79449_subsections_names$$);$sorted_translations_subsection_translations$$=$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($sorted_translations_subsection_translations$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$226$none$$,$APP.$cljs$core$first$$($basic_shortcuts_props_79449_subsections_names$$))?
($basic_shortcuts_props_79449_subsections_names$$=$APP.$cljs$cst$226$none$$.$cljs$core$IFn$_invoke$arity$1$($subsections$jscomp$1$$),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$,{elements:$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($basic_shortcuts_props_79449_subsections_names$$),filterTerm:$filter_term$jscomp$3$$,isMatchSection:$is_match_section$jscomp$1$$,isMatchSubsection:!0})):(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_shortcuts__subsection-menu",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$186$$,$sub_translated$$){$out_arr__44124__auto__$jscomp$186$$.push(function(){var $vec__79450_visible_QMARK_$jscomp$3$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79445_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5744$translation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__79445_SHARP_$$)),
$sub_translated$$)},$subsections$jscomp$1$$)),$match_subsection_QMARK__sub_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79450_visible_QMARK_$jscomp$3$$,0,null),$sub_info$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79450_visible_QMARK_$jscomp$3$$,1,null);$vec__79450_visible_QMARK_$jscomp$3$$=$APP.$cljs$core$some$$(function($p1__79446_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79446_SHARP_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$))},
$APP.$cljs$core$_deref$$($open_sections$$));$match_subsection_QMARK__sub_name$$=$app$util$strings$matches_search$$($app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5746$sub_sec$$,$match_subsection_QMARK__sub_name$$),$APP.$cljs$core$_deref$$($filter_term$jscomp$3$$));var $match_shortcuts_QMARK__shortcut_names$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79447_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5745$sc$$,
$p1__79447_SHARP_$$)},$APP.$cljs$core$keys$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$)));$match_shortcuts_QMARK__shortcut_names$$=$APP.$cljs$core$some$$(function($p1__79448_SHARP_$$){return $app$util$strings$matches_search$$($p1__79448_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$3$$))},$match_shortcuts_QMARK__shortcut_names$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($match_subsection_QMARK__sub_name$$)?$match_subsection_QMARK__sub_name$$:
$APP.$cljs$core$truth_$$($match_shortcuts_QMARK__shortcut_names$$)?$match_shortcuts_QMARK__shortcut_names$$:$is_match_section$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:function(){var $G__79453$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$);return $manage_sections$$.$cljs$core$IFn$_invoke$arity$1$?$manage_sections$$.$cljs$core$IFn$_invoke$arity$1$($G__79453$$):$manage_sections$$($G__79453$$)}(),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$,
{name:$sub_translated$$,isVisible:$vec__79450_visible_QMARK_$jscomp$3$$,isSub:!0}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{display:$APP.$cljs$core$truth_$$($vec__79450_visible_QMARK_$jscomp$3$$)?"initial":"none"},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$,{elements:$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$),filterTerm:$filter_term$jscomp$3$$,isMatchSection:$is_match_section$jscomp$1$$,isMatchSubsection:$match_subsection_QMARK__sub_name$$})})]},
$sub_translated$$):null}());return $out_arr__44124__auto__$jscomp$186$$},[],$sorted_translations_subsection_translations$$)})};
$app$main$ui$workspace$sidebar$shortcuts$shortcut_section_STAR_$$=function($props_79461_section_key_section_translation$$){var $manage_sections$jscomp$1$$=$props_79461_section_key_section_translation$$.manageSections,$filter_term$jscomp$4$$=$props_79461_section_key_section_translation$$.filterTerm,$open_sections$jscomp$1$$=$props_79461_section_key_section_translation$$.openSections,$match_section_QMARK__vec__79462$$=$props_79461_section_key_section_translation$$.section;$props_79461_section_key_section_translation$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($match_section_QMARK__vec__79462$$,0,null);var $match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($match_section_QMARK__vec__79462$$,1,null),$section_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$props_79461_section_key_section_translation$$=$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5747$sec$$,
$props_79461_section_key_section_translation$$);$match_section_QMARK__vec__79462$$=$app$util$strings$matches_search$$($props_79461_section_key_section_translation$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$4$$));var $subsections$jscomp$2$$=$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=$APP.$cljs$core$keys$$($subsections$jscomp$2$$);var $match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__79454_SHARP_$$,$p2__79455_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__79454_SHARP_$$,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($p2__79455_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$?$p2__79455_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$($subsections$jscomp$2$$):$p2__79455_SHARP_$$($subsections$jscomp$2$$)))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);
$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79456_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("none",$APP.$app$common$data$name$$($p1__79456_SHARP_$$))?null:$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5746$sub_sec$$,$p1__79456_SHARP_$$)},$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=
$APP.$cljs$core$some$$(function($p1__79457_SHARP_$$){return $app$util$strings$matches_search$$($p1__79457_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$4$$))},$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79458_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5745$sc$$,$p1__79458_SHARP_$$)},
$APP.$cljs$core$keys$$($match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$));$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$=$APP.$cljs$core$some$$(function($p1__79459_SHARP_$$){return $app$util$strings$matches_search$$($p1__79459_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$4$$))},$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$);var $visible_QMARK_$jscomp$4$$=$APP.$cljs$core$some$$(function($p1__79460_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79460_SHARP_$$,
$section_id$$)},$APP.$cljs$core$_deref$$($open_sections$jscomp$1$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($match_section_QMARK__vec__79462$$)?$match_section_QMARK__vec__79462$$:$APP.$cljs$core$truth_$$($match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$)?$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$:$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$manage_sections$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$manage_sections$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($section_id$$):$manage_sections$jscomp$1$$($section_id$$),className:"main_ui_workspace_sidebar_shortcuts__section",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$,{name:$props_79461_section_key_section_translation$$,isVisible:$visible_QMARK_$jscomp$4$$,isSub:!1}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{display:$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$4$$)?"initial":"none"},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_subsection_STAR_$$,
{subsections:$subsections$jscomp$2$$,openSections:$open_sections$jscomp$1$$,manageSections:$manage_sections$jscomp$1$$,isMatchSection:$match_section_QMARK__vec__79462$$,filterTerm:$filter_term$jscomp$4$$})})]}):null};
$app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR_$$=function($class$$jscomp$74_props_79473$$){function $manage_section_on_search$$($node_seq$jscomp$1_section$jscomp$32$$,$term$jscomp$12$$){$node_seq$jscomp$1_section$jscomp$32$$=$APP.$cljs$core$tree_seq$$($APP.$cljs$cst$342$children$$,function($p1__79472_SHARP_$$){return $APP.$cljs$core$vals$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($p1__79472_SHARP_$$))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_shortcuts__$1$$,
$node_seq$jscomp$1_section$jscomp$32$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$167$$,$node$jscomp$432$$){return $APP.$cljs$core$truth_$$($app$util$strings$matches_search$$($cljs$cst$5744$translation$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$432$$),$term$jscomp$12$$))?$add_ids$$($acc$jscomp$167$$,$node$jscomp$432$$):$acc$jscomp$167$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$node_seq$jscomp$1_section$jscomp$32$$)}function $add_ids$$($acc$jscomp$166$$,
$addition_node$jscomp$431$$){var $id$jscomp$991$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($addition_node$jscomp$431$$);$addition_node$jscomp$431$$=function(){var $G__79482$$=$APP.$cljs$core$count$$($id$jscomp$991$$);switch($G__79482$$){case 1:return $id$jscomp$991$$;case 2:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($id$jscomp$991$$)],
null),$id$jscomp$991$$],null);case 3:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($id$jscomp$991$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($id$jscomp$991$$),$APP.$cljs$core$second$$($id$jscomp$991$$)],null)],null);case "default":return null;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79482$$)].join(""));}}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($addition_node$jscomp$431$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$166$$,$addition_node$jscomp$431$$):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$166$$,
$addition_node$jscomp$431$$))}function $manage_sections$jscomp$2$$($item$jscomp$135$$){return function($event$jscomp$559_is_present_QMARK__new_value$jscomp$27$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$559_is_present_QMARK__new_value$jscomp$27$$);$event$jscomp$559_is_present_QMARK__new_value$jscomp$27$$=$APP.$cljs$core$some$$(function($p1__79471_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79471_SHARP_$$,$item$jscomp$135$$)},$APP.$cljs$core$_deref$$($open_sections$jscomp$2$$));
$event$jscomp$559_is_present_QMARK__new_value$jscomp$27$$=$APP.$cljs$core$truth_$$($event$jscomp$559_is_present_QMARK__new_value$jscomp$27$$)?$APP.$cljs$core$filterv$$(function($element$jscomp$84$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$84$$,$item$jscomp$135$$)},$APP.$cljs$core$_deref$$($open_sections$jscomp$2$$)):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($open_sections$jscomp$2$$),$item$jscomp$135$$);return $APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,
$event$jscomp$559_is_present_QMARK__new_value$jscomp$27$$)}}$class$$jscomp$74_props_79473$$=$class$$jscomp$74_props_79473$$.className;var $all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5745$sc$$,$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$path$shortcuts$shortcuts$$,
$APP.$app$main$data$workspace$shortcuts$shortcuts$$))),$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5745$sc$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts$$)),$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5745$sc$$,$APP.$app$main$data$viewer$shortcuts$shortcuts$$)),$open_sections$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null)],null)),$filter_term$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),
$workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5746$sub_sec$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$))),$dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5746$sub_sec$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$($all_sub_names_dashboard_shortcuts_on_search_term_change_2$$))),$viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5746$sub_sec$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$($all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$))),
$basics_elements$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4887$basics$$.$cljs$core$IFn$_invoke$arity$1$($workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$)),$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4887$basics$$.$cljs$core$IFn$_invoke$arity$1$($dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4887$basics$$.$cljs$core$IFn$_invoke$arity$1$($viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$))])));$workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$,$APP.$cljs$cst$4887$basics$$);$dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$,$APP.$cljs$cst$4887$basics$$);$viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$,$cljs$cst$5748$bassics$$);var $all_shortcuts__$1$$=function $app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR__$_walk$$($element$jscomp$83$$,$parent_id$jscomp$107$$){return $element$jscomp$83$$==
null?$element$jscomp$83$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$535_item_id$$,$item$jscomp$134_p__79475$$){var $k$jscomp$695$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$134_p__79475$$,0,null);$item$jscomp$134_p__79475$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$134_p__79475$$,1,null);$index$jscomp$535_item_id$$=
$parent_id$jscomp$107$$==null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$535_item_id$$],null):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$107$$,$index$jscomp$535_item_id$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$695$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($item$jscomp$134_p__79475$$,$APP.$cljs$cst$266$id$$,
$index$jscomp$535_item_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$342$children$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR__$_walk$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$134_p__79475$$),$index$jscomp$535_item_id$$)]))],null)},$element$jscomp$83$$))}(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4887$basics$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null),$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$226$none$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,$basics_elements$$],null)],null),$cljs$cst$5744$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.basics")],null),$APP.$cljs$cst$2532$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[2],null),$APP.$cljs$cst$342$children$$,$workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$,$cljs$cst$5744$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.workspace")],null),$APP.$cljs$cst$5106$dashboard$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[3],null),$APP.$cljs$cst$342$children$$,$dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$,$cljs$cst$5744$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.dashboard")],null),$APP.$cljs$cst$1592$viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[4],null),$APP.$cljs$cst$342$children$$,$viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$,
$cljs$cst$5744$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.viewer")],null)],null),null);$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79467_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5745$sc$$,$p1__79467_SHARP_$$)},$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$keys$$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$),
$APP.$cljs$core$keys$$($all_sub_names_dashboard_shortcuts_on_search_term_change_2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keys$$($all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$)])));$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79468_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5746$sub_sec$$,$p1__79468_SHARP_$$)},
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$keys$$($workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$),$APP.$cljs$core$keys$$($dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keys$$($viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$)])));$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79469_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5747$sec$$,
$p1__79469_SHARP_$$)},$APP.$cljs$core$keys$$($all_shortcuts__$1$$));$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$,$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$]));$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=
$APP.$cljs$core$some$$(function($p1__79470_SHARP_$$){return $app$util$strings$matches_search$$($p1__79470_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$5$$))},$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$);$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$934$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$934$$,""))$APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null)],null));else{var $ids$jscomp$inline_8974$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($manage_section_on_search$$($APP.$cljs$cst$4887$basics$$,$value$jscomp$934$$),$manage_section_on_search$$($APP.$cljs$cst$2532$workspace$$,$value$jscomp$934$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$manage_section_on_search$$($APP.$cljs$cst$5106$dashboard$$,
$value$jscomp$934$$),$manage_section_on_search$$($APP.$cljs$cst$1592$viewer$$,$value$jscomp$934$$)]));$APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,$ids$jscomp$inline_8974$$)}return $APP.$cljs$core$reset_BANG_$$($filter_term$jscomp$5$$,$value$jscomp$934$$)});$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null)],null));return $APP.$cljs$core$reset_BANG_$$($filter_term$jscomp$5$$,"")});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:""+($class$$jscomp$74_props_79473$$??"")+" main_ui_workspace_sidebar_shortcuts__shortcuts",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,{className:"main_ui_workspace_sidebar_shortcuts__shortcuts-title",
text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.title"),onClose:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$2950$shortcuts$$))}}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_shortcuts__search-field",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$,
onClear:$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$,value:$APP.$cljs$core$_deref$$($filter_term$jscomp$5$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.title"),iconId:"search",autoFocus:!0})}),$APP.$cljs$core$truth_$$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_shortcuts__shortcuts-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$187$$,
$section$jscomp$33$$){$out_arr__44124__auto__$jscomp$187$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_section_STAR_$$,{section:$section$jscomp$33$$,manageSections:$manage_sections$jscomp$2$$,openSections:$open_sections$jscomp$2$$,filterTerm:$filter_term$jscomp$5$$},$APP.$cljs$core$first$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($section$jscomp$33$$)))));return $out_arr__44124__auto__$jscomp$187$$},[],$all_shortcuts__$1$$)}):
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_shortcuts__not-found",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.not-found")})]})};
$app$main$ui$workspace$sidebar$sitemap$make_page_ref$$=function($page_id$jscomp$440$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($fdata$jscomp$23_page$jscomp$168$$){$fdata$jscomp$23_page$jscomp$168$$=$APP.$app$main$data$helpers$get_page$$($fdata$jscomp$23_page$jscomp$168$$,$page_id$jscomp$440$$);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($fdata$jscomp$23_page$jscomp$168$$,$cljs$cst$5749$empty_QMARK_$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($fdata$jscomp$23_page$jscomp$168$$)))),$APP.$cljs$cst$1631$objects$$)},$APP.$app$main$refs$workspace_data$$,$APP.$cljs$core$_EQ_$$)};
$app$main$ui$workspace$sidebar$sitemap$page_item$$=function($on_click$jscomp$48_props_79474$$){var $selected_QMARK_$jscomp$3$$=$on_click$jscomp$48_props_79474$$["selected?"],$editing_QMARK_$jscomp$10$$=$on_click$jscomp$48_props_79474$$["editing?"],$hovering_QMARK_$jscomp$1$$=$on_click$jscomp$48_props_79474$$["hovering?"],$index$jscomp$536$$=$on_click$jscomp$48_props_79474$$.index,$deletable_QMARK_$jscomp$1$$=$on_click$jscomp$48_props_79474$$["deletable?"],$page$jscomp$169$$=$on_click$jscomp$48_props_79474$$.page,
$current_page_id$jscomp$5$$=$on_click$jscomp$48_props_79474$$["current-page-id"],$input_ref$jscomp$12$$=(0,$APP.$rumext$v2$use_ref$$)(),$id$jscomp$992$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$169$$),$name$jscomp$461$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$169$$,""),$is_separator_QMARK_$$=function(){var $and__5023__auto__$jscomp$824$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("---",$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$461$$));
return $and__5023__auto__$jscomp$824$$?$cljs$cst$5749$empty_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$169$$):$and__5023__auto__$jscomp$824$$}(),$delete_fn$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$pages$delete_page$$($id$jscomp$992$$))}),$navigate_fn$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$id$jscomp$992$$]))]))}),$read_only_QMARK_$jscomp$21$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);
$on_click$jscomp$48_props_79474$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$),$APP.$rumext$v2$adapt$$($current_page_id$jscomp$5$$),$APP.$rumext$v2$adapt$$($is_separator_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?null:$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$992$$,
$current_page_id$jscomp$5$$)?$APP.$promesa$core$finally$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))?$APP.$promesa$impl$promise$resolved$$(null):$APP.$app$render_wasm$api$webgl$capture_canvas_snapshot_url$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$app$render_wasm$api$webgl$capture_canvas_snapshot_url$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$app$render_wasm$api$webgl$capture_canvas_snapshot_url$$(),function(){$app$render_wasm$api$apply_canvas_blur$$();
return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return(0,$APP.$app$util$timers$request_animation_frame$$)($navigate_fn$$)})}):$navigate_fn$$.$cljs$core$IFn$_invoke$arity$0$?$navigate_fn$$.$cljs$core$IFn$_invoke$arity$0$():$navigate_fn$$()});var $on_delete$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$)],function($event$jscomp$560$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$560$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.body"),$APP.$cljs$cst$2479$on_accept$$,$delete_fn$jscomp$3$$],null)))}),$on_double_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$21$$)],function($event$jscomp$561$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$561$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$561$$);return $APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$21$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$start_rename_page_item$$($id$jscomp$992$$))}),$on_blur$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$),$APP.$rumext$v2$adapt$$($is_separator_QMARK_$$)],function($event$jscomp$562_new_name_79500$$){$event$jscomp$562_new_name_79500$$=
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$562_new_name_79500$$));$APP.$cuerdas$core$empty_QMARK_$$($event$jscomp$562_new_name_79500$$)?$APP.$cljs$core$truth_$$($is_separator_QMARK_$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$pages$delete_page$$($id$jscomp$992$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$rename_page$$($id$jscomp$992$$,
$event$jscomp$562_new_name_79500$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$stop_rename_page_item$$())}),$on_key_down$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$563$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$563$$))?$on_blur$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$563$$):
$on_blur$jscomp$31$$($event$jscomp$563$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$563$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$stop_rename_page_item$$()):null}),$dprops$jscomp$8_on_drop$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$),$APP.$rumext$v2$adapt$$($index$jscomp$536$$)],function($index__$1$jscomp$24_side$jscomp$4$$,$id__$1$jscomp$21_map__79484__$1_p__79483$$){$id__$1$jscomp$21_map__79484__$1_p__79483$$=
$APP.$cljs$core$__destructure_map$$($id__$1$jscomp$21_map__79484__$1_p__79483$$);$id__$1$jscomp$21_map__79484__$1_p__79483$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id__$1$jscomp$21_map__79484__$1_p__79483$$,$APP.$cljs$cst$266$id$$);$index__$1$jscomp$24_side$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2952$bot$$,$index__$1$jscomp$24_side$jscomp$4$$)?$index$jscomp$536$$+1:$index$jscomp$536$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$relocate_page$$($id__$1$jscomp$21_map__79484__$1_p__79483$$,
$index__$1$jscomp$24_side$jscomp$4$$))}),$on_context_menu$jscomp$11_vec__79479$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/page",$APP.$cljs$cst$2955$on_drop$$,$dprops$jscomp$8_on_drop$jscomp$15$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$id$jscomp$992$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$536$$,
$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$169$$)],null),$APP.$cljs$cst$2959$draggable_QMARK_$$,$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$21$$)&&$APP.$cljs$core$not$$($editing_QMARK_$jscomp$10$$)]));$dprops$jscomp$8_on_drop$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($on_context_menu$jscomp$11_vec__79479$$,0,null);var $dref$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($on_context_menu$jscomp$11_vec__79479$$,
1,null);$on_context_menu$jscomp$11_vec__79479$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$21$$)],function($event$jscomp$564_position$jscomp$196$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$564_position$jscomp$196$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$564_position$jscomp$196$$);if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$21$$))return null;$event$jscomp$564_position$jscomp$196$$=
$APP.$app$util$dom$get_client_position$$($event$jscomp$564_position$jscomp$196$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_page_item_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1676$position$$,$event$jscomp$564_position$jscomp$196$$,$APP.$cljs$cst$1624$page$$,$page$jscomp$169$$,$cljs$cst$5602$deletable_QMARK_$$,$deletable_QMARK_$jscomp$1$$],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$3$$)],
function(){return $APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$3$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($dref$jscomp$8$$),!1):null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$10$$)],function(){$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$10$$)&&$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$12$$));return null});
var $selected_QMARK___$1$$=$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$3$$)?$APP.$cljs$core$not$$($is_separator_QMARK_$$):$selected_QMARK_$jscomp$3$$;return(0,$APP.$rumext$v2$jsx$$)("li",{ref:$dref$jscomp$8$$,className:"main_ui_workspace_sidebar_sitemap__page-element "+($APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?"main_ui_workspace_sidebar_sitemap__separator":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK___$1$$)?"main_ui_workspace_sidebar_sitemap__selected":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$8_on_drop$jscomp$15$$),
$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_sidebar_sitemap__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$8_on_drop$jscomp$15$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_sidebar_sitemap__dnd-over-bot":""),children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"page-"+($id$jscomp$992$$??""),tabIndex:"0",onClick:$on_click$jscomp$48_props_79474$$,onDoubleClick:$on_double_click$jscomp$1$$,
onContextMenu:$on_context_menu$jscomp$11_vec__79479$$,className:"main_ui_workspace_sidebar_sitemap__element-list-body "+($APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?"main_ui_workspace_sidebar_sitemap__separator-body":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hovering_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($is_separator_QMARK_$$):$hovering_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_sitemap__hover":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK___$1$$)?"main_ui_workspace_sidebar_sitemap__selected":
""),children:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?$APP.$cljs$core$not$$($editing_QMARK_$jscomp$10$$):$is_separator_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"page-separator",className:"main_ui_workspace_sidebar_sitemap__page-separator"}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_sitemap__page-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"document",size:"s"})}),$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$10$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$input_ref$jscomp$12$$,onBlur:$on_blur$jscomp$31$$,onKeyDown:$on_key_down$jscomp$20$$,autoFocus:!0,defaultValue:$name$jscomp$461$$,className:"main_ui_workspace_sidebar_sitemap__element-name"}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{title:$name$jscomp$461$$,"data-testid":"page-name",className:"main_ui_workspace_sidebar_sitemap__page-name",
children:$name$jscomp$461$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_sitemap__page-actions",children:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($deletable_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$21$$):$deletable_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.title"),onClick:$on_delete$jscomp$12$$,
iconSize:"s",className:"main_ui_workspace_sidebar_sitemap__page-delete-button",iconClass:"main_ui_workspace_sidebar_sitemap__page-delete-button-icon",icon:"delete"}):null})]})]})})})};
$app$main$ui$workspace$sidebar$sitemap$page_item_wrapper$$=function($current_page_id$jscomp$6_props_79486$$){var $selected_QMARK_$jscomp$4$$=$current_page_id$jscomp$6_props_79486$$["selected?"],$editing_QMARK_$jscomp$11$$=$current_page_id$jscomp$6_props_79486$$["editing?"],$index$jscomp$537$$=$current_page_id$jscomp$6_props_79486$$.index,$deletable_QMARK_$jscomp$2$$=$current_page_id$jscomp$6_props_79486$$["deletable?"],$page_id$jscomp$441$$=$current_page_id$jscomp$6_props_79486$$["page-id"];$current_page_id$jscomp$6_props_79486$$=
$current_page_id$jscomp$6_props_79486$$["current-page-id"];var $page$jscomp$170_page_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$441$$)],function(){return $app$main$ui$workspace$sidebar$sitemap$make_page_ref$$($page_id$jscomp$441$$)});$page$jscomp$170_page_ref$$=$APP.$rumext$v2$deref$$($page$jscomp$170_page_ref$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$page_item$$,{page:$page$jscomp$170_page_ref$$,index:$index$jscomp$537$$,
"current-page-id":$current_page_id$jscomp$6_props_79486$$,"deletable?":$deletable_QMARK_$jscomp$2$$,"selected?":$selected_QMARK_$jscomp$4$$,"editing?":$editing_QMARK_$jscomp$11$$})};
$app$main$ui$workspace$sidebar$sitemap$pages_list_STAR_$$=function($pages$jscomp$11_props_79488$$){$pages$jscomp$11_props_79488$$=$APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($pages$jscomp$11_props_79488$$.file);var $deletable_QMARK_$jscomp$3$$=$APP.$cljs$core$count$$($pages$jscomp$11_props_79488$$)>1,$editing_page_id$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$editing_page_item$$),$current_page_id$jscomp$7$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$);
return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_sitemap__page-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$188$$,$p__79490_page_id$jscomp$442$$){var $index$jscomp$538$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79490_page_id$jscomp$442$$,0,null);$p__79490_page_id$jscomp$442$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79490_page_id$jscomp$442$$,
1,null);$out_arr__44124__auto__$jscomp$188$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$page_item_wrapper$$,{"page-id":$p__79490_page_id$jscomp$442$$,index:$index$jscomp$538$$,"deletable?":$deletable_QMARK_$jscomp$3$$,"editing?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__79490_page_id$jscomp$442$$,$editing_page_id$$),"selected?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__79490_page_id$jscomp$442$$,$current_page_id$jscomp$7$$),"current-page-id":$current_page_id$jscomp$7$$},
$p__79490_page_id$jscomp$442$$));return $out_arr__44124__auto__$jscomp$188$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($pages$jscomp$11_props_79488$$))})})};
$app$main$ui$workspace$sidebar$sitemap$sitemap_STAR_$$=function($on_toggle_collapsed_props_79494$$){var $height$jscomp$175$$=$on_toggle_collapsed_props_79494$$.height,$collapsed$jscomp$3$$=$on_toggle_collapsed_props_79494$$.collapsed;$on_toggle_collapsed_props_79494$$=$on_toggle_collapsed_props_79494$$.onToggleCollapsed;var $file$jscomp$175$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$sitemap$ref_COLON_file_with_pages$$),$file_id$jscomp$428$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$175$$,
$APP.$cljs$cst$266$id$$),$project_id$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$175$$,$APP.$cljs$cst$2181$project_id$$),$on_create$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$428$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$36$$)],function($event$jscomp$565$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$create_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$428$$,$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$36$$],null)));return $APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_current_target$$($event$jscomp$565$$))}),$read_only_QMARK_$jscomp$22$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$permissions$jscomp$35$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--height":""+($height$jscomp$175$$??
"")+"px"},className:"main_ui_workspace_sidebar_sitemap__sitemap",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$collapsed$jscomp$3$$,onCollapsed:$on_toggle_collapsed_props_79494$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.sitemap"),className:"main_ui_workspace_sidebar_sitemap__title-spacing-sitemap",children:$read_only_QMARK_$jscomp$22$$?$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$35$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$badge$badge_notification$$,{"is-focus":!0,size:$APP.$cljs$cst$3877$small$$,content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.view-only")}):null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_sitemap__add-page","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.sitemap.add-page"),onClick:$on_create$$,
icon:"add"})}),$collapsed$jscomp$3$$?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_sitemap__tool-window-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$pages_list_STAR_$$,{file:$file$jscomp$175$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$175$$)??""))})]})};
$app$main$ui$ds$product$avatar$avatar_STAR_$$=function($props_79502_variant__$1$jscomp$7$$){var $tag$jscomp$95$$=$props_79502_variant__$1$jscomp$7$$.tag,$href$jscomp$19_profile$jscomp$71$$=$props_79502_variant__$1$jscomp$7$$.profile,$class_SINGLEQUOTE__selected$jscomp$178$$=$props_79502_variant__$1$jscomp$7$$.selected,$class$$jscomp$75$$=$props_79502_variant__$1$jscomp$7$$.className;$props_79502_variant__$1$jscomp$7$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_79502_variant__$1$jscomp$7$$.variant,
"S");var $profile__$1$jscomp$6$$=$APP.$cljs$core$object_QMARK_$$($href$jscomp$19_profile$jscomp$71$$)?$APP.$rumext$v2$util$bean$$($href$jscomp$19_profile$jscomp$71$$):$href$jscomp$19_profile$jscomp$71$$;$href$jscomp$19_profile$jscomp$71$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile__$1$jscomp$6$$)],function(){var $fullname$jscomp$inline_13574_map__79498__$1$jscomp$inline_13571$$=$APP.$cljs$core$__destructure_map$$($profile__$1$jscomp$6$$);var $JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullname$jscomp$inline_13574_map__79498__$1$jscomp$inline_13571$$,$APP.$cljs$cst$3185$photo_url$$);var $photo_id$jscomp$inline_13573$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullname$jscomp$inline_13574_map__79498__$1$jscomp$inline_13571$$,$APP.$cljs$cst$1359$photo_id$$);$fullname$jscomp$inline_13574_map__79498__$1$jscomp$inline_13571$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullname$jscomp$inline_13574_map__79498__$1$jscomp$inline_13571$$,
$APP.$cljs$cst$1360$fullname$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$)||($JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$=$photo_id$jscomp$inline_13573$$==null?null:$APP.$app$config$resolve_media$$($photo_id$jscomp$inline_13573$$),$JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$)?$JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$:(0,$APP.$app$util$avatars$generate$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$fullname$jscomp$inline_13574_map__79498__$1$jscomp$inline_13571$$],null)));return $JSCompiler_inline_result$jscomp$11031_or__5025__auto____$1$jscomp$inline_13575_photo_url$jscomp$inline_13572$$});
$class_SINGLEQUOTE__selected$jscomp$178$$="main_ui_ds_product_avatar__avatar "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79502_variant__$1$jscomp$7$$,"S")?"main_ui_ds_product_avatar__avatar-small":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79502_variant__$1$jscomp$7$$,"M")?"main_ui_ds_product_avatar__avatar-medium":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79502_variant__$1$jscomp$7$$,"L")?"main_ui_ds_product_avatar__avatar-large":
"")+" "+($APP.$cljs$core$truth_$$($class_SINGLEQUOTE__selected$jscomp$178$$)?"main_ui_ds_product_avatar__is-selected":"");return(0,$APP.$rumext$v2$jsx$$)($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$95$$,"div"),{className:($class$$jscomp$75$$??"")+" "+($class_SINGLEQUOTE__selected$jscomp$178$$??""),title:$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$6$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_avatar__avatar-image",
children:(0,$APP.$rumext$v2$jsx$$)("img",{alt:$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$6$$),src:$href$jscomp$19_profile$jscomp$71$$})})})};
$app$main$ui$ds$product$milestone$milestone_STAR_$$=function($props_79511_props__$1$jscomp$85$$){var $created_at$jscomp$1_created_at__$1$jscomp$1$$=void 0,$profile$jscomp$72$$=void 0,$on_blur_input$$=void 0,$on_key_down_input$$=void 0,$on_focus_input$$=void 0,$editing$jscomp$2$$=void 0,$active$jscomp$2$$=void 0,$locked$$=void 0,$label$jscomp$49$$=void 0,$class$$jscomp$76$$=void 0,$on_open_menu$jscomp$1$$=void 0,$props$jscomp$349$$=void 0;({createdAt:$created_at$jscomp$1_created_at__$1$jscomp$1$$,
profile:$profile$jscomp$72$$,onBlurInput:$on_blur_input$$,onKeyDownInput:$on_key_down_input$$,onFocusInput:$on_focus_input$$,editing:$editing$jscomp$2$$,active:$active$jscomp$2$$,locked:$locked$$,label:$label$jscomp$49$$,className:$class$$jscomp$76$$,onOpenMenu:$on_open_menu$jscomp$1$$,...$props$jscomp$349$$}=$props_79511_props__$1$jscomp$85$$);$props_79511_props__$1$jscomp$85$$={...$props$jscomp$349$$,className:($class$$jscomp$76$$??"")+" main_ui_ds_product_milestone__milestone "+($APP.$cljs$core$truth_$$($active$jscomp$2$$)?
"main_ui_ds_product_milestone__is-selected":""),"data-testid":"milestone"};$created_at$jscomp$1_created_at__$1$jscomp$1$$=$APP.$app$common$time$inst_QMARK_$$($created_at$jscomp$1_created_at__$1$jscomp$1$$)?$created_at$jscomp$1_created_at__$1$jscomp$1$$:$APP.$app$common$time$inst$$($created_at$jscomp$1_created_at__$1$jscomp$1$$);return(0,$APP.$rumext$v2$create_element$$)("div",$props_79511_props__$1$jscomp$85$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$avatar$avatar_STAR_$$,{profile:$profile$jscomp$72$$,
variant:"S",className:"main_ui_ds_product_milestone__avatar"}),$editing$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{className:"main_ui_ds_product_milestone__name-input",variant:"seamless",defaultValue:$label$jscomp$49$$,autoFocus:!0,onFocus:$on_focus_input$$,onBlur:$on_blur_input$$,onKeyDown:$on_key_down_input$$}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_milestone__name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",className:"main_ui_ds_product_milestone__name",children:$label$jscomp$49$$}),$APP.$cljs$core$truth_$$($locked$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"lock",className:"main_ui_ds_product_milestone__lock-icon"}):null]}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("time",{dateTime:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($created_at$jscomp$1_created_at__$1$jscomp$1$$,
$APP.$cljs$cst$1138$iso$$),className:"main_ui_ds_product_milestone__date",children:$APP.$app$common$time$timeago$$($created_at$jscomp$1_created_at__$1$jscomp$1$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_milestone__milestone-buttons",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_ds_product_milestone__menu-button",variant:"ghost",icon:"menu","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.version-menu"),
onClick:$on_open_menu$jscomp$1$$})})]}))};
$app$main$ui$ds$utilities$date$date_STAR_$$=function($date__$1_props_79512$$){var $date$jscomp$24$$=void 0,$selected$jscomp$179$$=void 0,$class$$jscomp$77$$=void 0,$typography$jscomp$38$$=void 0;({className:$class$$jscomp$77$$,date:$date$jscomp$24$$,selected:$selected$jscomp$179$$,typography:$typography$jscomp$38$$}=$date__$1_props_79512$$);$date__$1_props_79512$$=function(){var $G__79513$$=$date$jscomp$24$$;return $APP.$app$common$time$inst_QMARK_$$($date$jscomp$24$$)?$G__79513$$:$APP.$app$common$time$inst$$($G__79513$$)}();
return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"time",typography:function(){var $or__5025__auto__$jscomp$1230$$=$typography$jscomp$38$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1230$$)?$or__5025__auto__$jscomp$1230$$:"body-medium"}(),className:($class$$jscomp$77$$??"")+" main_ui_ds_utilities_date__date "+($APP.$cljs$core$truth_$$($selected$jscomp$179$$)?"main_ui_ds_utilities_date__is-selected":""),dateTime:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($date__$1_props_79512$$,
$APP.$cljs$cst$1138$iso$$),children:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($date__$1_props_79512$$,$cljs$cst$5754$localized_date_time$$)})};
$app$main$ui$ds$product$milestone_group$milestone_group_STAR_$$=function($props_79514_props__$1$jscomp$86$$){var $on_menu_click$jscomp$4$$=void 0,$active$jscomp$3_open_QMARK_$jscomp$29$$=void 0,$label$jscomp$50$$=void 0,$class$$jscomp$78_on_toggle_visibility$jscomp$6$$=void 0,$snapshots$$=void 0,$props$jscomp$351_snapshots__$1$$=void 0;({className:$class$$jscomp$78_on_toggle_visibility$jscomp$6$$,active:$active$jscomp$3_open_QMARK_$jscomp$29$$,label:$label$jscomp$50$$,snapshots:$snapshots$$,onMenuClick:$on_menu_click$jscomp$4$$,
...$props$jscomp$351_snapshots__$1$$}=$props_79514_props__$1$jscomp$86$$);$props_79514_props__$1$jscomp$86$$={...$props$jscomp$351_snapshots__$1$$,className:($class$$jscomp$78_on_toggle_visibility$jscomp$6$$??"")+" main_ui_ds_product_milestone_group__milestone "+($APP.$cljs$core$truth_$$($active$jscomp$3_open_QMARK_$jscomp$29$$)?"main_ui_ds_product_milestone_group__is-selected":""),"data-testid":"milestone"};var $open_STAR_$jscomp$11$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$active$jscomp$3_open_QMARK_$jscomp$29$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$11$$);$class$$jscomp$78_on_toggle_visibility$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$11$$,$APP.$cljs$core$not$$)});var $on_menu_click__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$4$$)],function($event$jscomp$566$$){var $index$jscomp$539$$=
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$566$$),"index"));return $APP.$cljs$core$fn_QMARK_$$($on_menu_click$jscomp$4$$)?$on_menu_click$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_menu_click$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$539$$,$event$jscomp$566$$):$on_menu_click$jscomp$4$$($index$jscomp$539$$,$event$jscomp$566$$):null});$props$jscomp$351_snapshots__$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($snapshots$$)],function(){return $APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$540$$,$date$jscomp$25$$){return new $APP.$cljs$core$MapEntry$$($date$jscomp$25$$,$index$jscomp$540$$,null)},$snapshots$$)});return(0,$APP.$rumext$v2$create_element$$)("div",$props_79514_props__$1$jscomp$86$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",
typography:"body-small",className:"main_ui_ds_product_milestone_group__name",children:$label$jscomp$50$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_milestone_group__snapshots",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.expand-snapshot"),onClick:$class$$jscomp$78_on_toggle_visibility$jscomp$6$$,className:"main_ui_ds_product_milestone_group__toggle-snapshots",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"clock",className:"main_ui_ds_product_milestone_group__icon-clock"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",className:"main_ui_ds_product_milestone_group__toggle-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.autosaved.entry",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($props$jscomp$351_snapshots__$1$$)]))}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow",className:"main_ui_ds_product_milestone_group__icon-arrow "+($APP.$cljs$core$truth_$$($active$jscomp$3_open_QMARK_$jscomp$29$$)?"main_ui_ds_product_milestone_group__icon-arrow-toggled":"")})]}),$active$jscomp$3_open_QMARK_$jscomp$29$$?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$189$$,$index$jscomp$541_p__79515$$){var $date$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$541_p__79515$$,0,null);
$index$jscomp$541_p__79515$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$541_p__79515$$,1,null);$out_arr__44124__auto__$jscomp$189$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_milestone_group__version-entry",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$utilities$date$date_STAR_$$,{date:$date$jscomp$26$$,className:"main_ui_ds_product_milestone_group__date",typography:"body-small"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{className:"main_ui_ds_product_milestone_group__entry-button",variant:"ghost",icon:"menu","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.version-menu"),"data-index":$index$jscomp$541_p__79515$$,onClick:$on_menu_click__$1$$})]},"entry-"+($index$jscomp$541_p__79515$$??"")));return $out_arr__44124__auto__$jscomp$189$$},[],$props$jscomp$351_snapshots__$1$$):null]}))};
$app$main$ui$workspace$sidebar$versions$get_versions_stored_days$$=function($subscription_type$jscomp$10_team$jscomp$56$$){$subscription_type$jscomp$10_team$jscomp$56$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$10_team$jscomp$56$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$10_team$jscomp$56$$,"unlimited")?30:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$10_team$jscomp$56$$,
"enterprise")?90:7};
$app$main$ui$workspace$sidebar$versions$get_versions_warning_subtext$$=function($email_owner_team$jscomp$57$$){var $subscription_type$jscomp$11$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($email_owner_team$jscomp$57$$)),$is_owner_QMARK_$jscomp$1$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($email_owner_team$jscomp$57$$));$email_owner_team$jscomp$57$$=
$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some$$(function($p1__79519_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($p1__79519_SHARP_$$))?$p1__79519_SHARP_$$:null},$APP.$cljs$cst$3264$members$$.$cljs$core$IFn$_invoke$arity$1$($email_owner_team$jscomp$57$$)));var $go_to_subscription$jscomp$2$$=""+($APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"#/settings/subscriptions"]))??"");return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)?$APP.$cljs$core$truth_$$($is_owner_QMARK_$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$subscription_type$jscomp$11$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.workspace.versions.warning.enterprise.subtext-owner",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["support@penpot.app",
"support@penpot.app"])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.workspace.versions.warning.subtext-owner",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$go_to_subscription$jscomp$2$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.workspace.versions.warning.subtext-member",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$email_owner_team$jscomp$57$$,$email_owner_team$jscomp$57$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.warning.subtext",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["support@penpot.app"]))};
$app$main$ui$workspace$sidebar$versions$group_snapshots$$=function($data$jscomp$494$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$542$$,$item$jscomp$136$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$136$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$542$$)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79521_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79521_SHARP_$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2289$version$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79520_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("user",$APP.$cljs$cst$5756$created_by$$.$cljs$core$IFn$_invoke$arity$1$($p1__79520_SHARP_$$))},$data$jscomp$494$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($entries$jscomp$43_p__79524$$){var $day$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entries$jscomp$43_p__79524$$,
0,null);$entries$jscomp$43_p__79524$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entries$jscomp$43_p__79524$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$5757$snapshot$$,$APP.$cljs$cst$1569$created_at$$,$APP.$app$common$time$inst$$($day$jscomp$3$$),$cljs$cst$5755$snapshots$$,$entries$jscomp$43_p__79524$$],null)},$APP.$cljs$core$group_by$$(function($p1__79523_SHARP_$$){return $APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__79523_SHARP_$$),
$cljs$cst$5758$iso_date$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79522_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5756$created_by$$.$cljs$core$IFn$_invoke$arity$1$($p1__79522_SHARP_$$))},$data$jscomp$494$$)))))))};$app$main$ui$workspace$sidebar$versions$on_name_input_focus$$=function($event$jscomp$567$$){return $APP.$app$util$dom$select_text_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$567$$))};
$app$main$ui$workspace$sidebar$versions$on_create_version$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$create_version$$())};
$app$main$ui$workspace$sidebar$versions$on_edit_version$$=function($id$jscomp$993$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2152$editing$$,$id$jscomp$993$$],null)))};
$app$main$ui$workspace$sidebar$versions$on_cancel_version_edition$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2152$editing$$,null],null)))};
$app$main$ui$workspace$sidebar$versions$on_rename_version$$=function($id$jscomp$994$$,$label$jscomp$51$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$rename_version$$($id$jscomp$994$$,$label$jscomp$51$$))};$app$main$ui$workspace$sidebar$versions$on_delete_version$$=function($id$jscomp$995$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$delete_version$$($id$jscomp$995$$))};
$app$main$ui$workspace$sidebar$versions$on_pin_version$$=function($id$jscomp$996$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$pin_version$$($id$jscomp$996$$))};$app$main$ui$workspace$sidebar$versions$on_lock_version$$=function($id$jscomp$997$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$lock_version$$($id$jscomp$997$$))};
$app$main$ui$workspace$sidebar$versions$on_unlock_version$$=function($id$jscomp$998$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$unlock_version$$($id$jscomp$998$$))};
$app$main$ui$workspace$sidebar$versions$version_entry_STAR_$$=function($on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$){var $current_profile$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.currentProfile,$on_preview$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onPreview,$on_delete$jscomp$13$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onDelete,$on_cancel_edit$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onCancelEdit,$on_lock$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onLock,
$on_unlock$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onUnlock,$on_edit$jscomp$8$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onEdit,$is_editing$jscomp$2$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.isEditing,$on_restore$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onRestore,$on_rename$jscomp$2$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.onRename,$entry$jscomp$76$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$.entry,$show_menu_QMARK_$jscomp$3$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$);var $created_by$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$));$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_menu_QMARK_$jscomp$3$$,
!0)});var $on_close_menu$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_menu_QMARK_$jscomp$3$$,!1)}),$on_edit__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_edit$jscomp$8$$),$APP.$rumext$v2$adapt$$($entry$jscomp$76$$)],function($event$jscomp$569$$){var $G__79546$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_edit$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?
$on_edit$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($G__79546$$,$event$jscomp$569$$):$on_edit$jscomp$8$$($G__79546$$,$event$jscomp$569$$)}),$on_preview__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_preview$$)],function(){if($APP.$cljs$core$fn_QMARK_$$($on_preview$$)){var $G__79548$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_preview$$.$cljs$core$IFn$_invoke$arity$1$?
$on_preview$$.$cljs$core$IFn$_invoke$arity$1$($G__79548$$):$on_preview$$($G__79548$$)}return null}),$on_restore__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_restore$$)],function(){if($APP.$cljs$core$fn_QMARK_$$($on_restore$$)){var $G__79549$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_restore$$.$cljs$core$IFn$_invoke$arity$1$?$on_restore$$.$cljs$core$IFn$_invoke$arity$1$($G__79549$$):
$on_restore$$($G__79549$$)}return null}),$on_delete__$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$13$$)],function($event$jscomp$570$$){if($APP.$cljs$core$fn_QMARK_$$($on_delete$jscomp$13$$)){var $G__79552$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_delete$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?$on_delete$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($G__79552$$,
$event$jscomp$570$$):$on_delete$jscomp$13$$($G__79552$$,$event$jscomp$570$$)}return null}),$on_lock__$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_lock$$)],function(){if($APP.$cljs$core$truth_$$($on_lock$$)){var $G__79556$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_lock$$.$cljs$core$IFn$_invoke$arity$1$?$on_lock$$.$cljs$core$IFn$_invoke$arity$1$($G__79556$$):
$on_lock$$($G__79556$$)}return null}),$on_unlock__$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_unlock$$)],function(){if($APP.$cljs$core$truth_$$($on_unlock$$)){var $G__79561$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_unlock$$.$cljs$core$IFn$_invoke$arity$1$?$on_unlock$$.$cljs$core$IFn$_invoke$arity$1$($G__79561$$):$on_unlock$$($G__79561$$)}return null}),
$on_name_input_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_rename$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_cancel_edit$$)],function($event$jscomp$571$$){var $G__79566_label$jscomp$52$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$571$$));if(!$APP.$cuerdas$core$empty_QMARK_$$($G__79566_label$jscomp$52$$)&&$APP.$cljs$core$fn_QMARK_$$($on_rename$jscomp$2$$)){var $G__79562$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_rename$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$($G__79562$$,$G__79566_label$jscomp$52$$,$event$jscomp$571$$):$on_rename$jscomp$2$$($G__79562$$,$G__79566_label$jscomp$52$$,$event$jscomp$571$$)}$G__79566_label$jscomp$52$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$?$on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$($G__79566_label$jscomp$52$$,
$event$jscomp$571$$):$on_cancel_edit$$($G__79566_label$jscomp$52$$,$event$jscomp$571$$)}),$on_name_input_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$76$$),$APP.$rumext$v2$adapt$$($on_cancel_edit$$),$APP.$rumext$v2$adapt$$($on_name_input_blur$$)],function($event$jscomp$572$$){if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$572$$)))return $on_name_input_blur$$.$cljs$core$IFn$_invoke$arity$1$?$on_name_input_blur$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$572$$):
$on_name_input_blur$$($event$jscomp$572$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$572$$))&&$APP.$cljs$core$fn_QMARK_$$($on_cancel_edit$$)){var $G__79569$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$);return $on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$?$on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$($G__79569$$,$event$jscomp$572$$):$on_cancel_edit$$($G__79569$$,$event$jscomp$572$$)}return null});return(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_workspace_sidebar_versions__version-entry-wrap",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$milestone$milestone_STAR_$$,{onBlurInput:$on_name_input_blur$$,createdAt:$APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$),label:$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$),profile:$created_by$$,onKeyDownInput:$on_name_input_key_down$$,editing:$is_editing$jscomp$2$$,onFocusInput:$app$main$ui$workspace$sidebar$versions$on_name_input_focus$$,
locked:$cljs$cst$5759$locked_by$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$)!=null,onOpenMenu:$on_open_menu$jscomp$2_profiles$jscomp$4_props_79543$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_menu_QMARK_$jscomp$3$$),"on-close":$on_close_menu$jscomp$5$$,children:function(){var $current_user_id_is_locked_by_me_QMARK_$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_profile$$),$is_locked_QMARK__locked_by_id$$=
$cljs$cst$5759$locked_by$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76$$),$im_the_owner_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_user_id_is_locked_by_me_QMARK_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($created_by$$));$current_user_id_is_locked_by_me_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_user_id_is_locked_by_me_QMARK_$$,$is_locked_QMARK__locked_by_id$$);$is_locked_QMARK__locked_by_id$$=$is_locked_QMARK__locked_by_id$$!=
null;var $can_delete_QMARK_$jscomp$1$$=!$is_locked_QMARK__locked_by_id$$||$is_locked_QMARK__locked_by_id$$&&$current_user_id_is_locked_by_me_QMARK_$$;return(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_sidebar_versions__version-options-dropdown",children:[$im_the_owner_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_edit__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename")}):
null,(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_preview__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.preview")}),(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_restore__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.restore")}),$current_user_id_is_locked_by_me_QMARK_$$?
(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_unlock__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unlock")}):$im_the_owner_QMARK_$$&&!$is_locked_QMARK__locked_by_id$$?(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_lock__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.lock")}):null,$can_delete_QMARK_$jscomp$1$$?
(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_delete__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")}):null]})}()})]})};
$app$main$ui$workspace$sidebar$versions$snapshot_entry_STAR_$$=function($on_pin_snapshot__$1_props_79572$$){var $on_restore_snapshot$$=$on_pin_snapshot__$1_props_79572$$.onRestoreSnapshot,$on_pin_snapshot$$=$on_pin_snapshot__$1_props_79572$$.onPinSnapshot,$on_preview_snapshot$$=$on_pin_snapshot__$1_props_79572$$.onPreviewSnapshot,$entry$jscomp$77$$=$on_pin_snapshot__$1_props_79572$$.entry,$open_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$entry_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);
$on_pin_snapshot__$1_props_79572$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_pin_snapshot$$)],function($event$jscomp$573$$){if($APP.$cljs$core$fn_QMARK_$$($on_pin_snapshot$$)){var $G__79574$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$573$$),"id"));return $on_pin_snapshot$$.$cljs$core$IFn$_invoke$arity$2$?$on_pin_snapshot$$.$cljs$core$IFn$_invoke$arity$2$($G__79574$$,$event$jscomp$573$$):
$on_pin_snapshot$$($G__79574$$,$event$jscomp$573$$)}return null});var $on_restore_snapshot__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_restore_snapshot$$)],function($event$jscomp$574$$){if($APP.$cljs$core$fn_QMARK_$$($on_restore_snapshot$$)){var $G__79584$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$574$$),"id"));return $on_restore_snapshot$$.$cljs$core$IFn$_invoke$arity$2$?$on_restore_snapshot$$.$cljs$core$IFn$_invoke$arity$2$($G__79584$$,
$event$jscomp$574$$):$on_restore_snapshot$$($G__79584$$,$event$jscomp$574$$)}return null}),$on_preview_snapshot__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_preview_snapshot$$)],function($event$jscomp$575$$){if($APP.$cljs$core$fn_QMARK_$$($on_preview_snapshot$$)){var $G__79586$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$575$$),"id"));return $on_preview_snapshot$$.$cljs$core$IFn$_invoke$arity$2$?
$on_preview_snapshot$$.$cljs$core$IFn$_invoke$arity$2$($G__79586$$,$event$jscomp$575$$):$on_preview_snapshot$$($G__79586$$,$event$jscomp$575$$)}return null}),$on_open_snapshot_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$77$$)],function($index$jscomp$543_snapshot$jscomp$4$$,$event$jscomp$576_offset$jscomp$210$$){$index$jscomp$543_snapshot$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5755$snapshots$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$77$$),
$index$jscomp$543_snapshot$jscomp$4$$);var $current_bb$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$rumext$v2$ref_val$$($entry_ref$$)));$event$jscomp$576_offset$jscomp$210$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($event$jscomp$576_offset$jscomp$210$$)))-$current_bb$$+32;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($open_menu_STAR_$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5757$snapshot$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$543_snapshot$jscomp$4$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$195$offset$$,$event$jscomp$576_offset$jscomp$210$$]))});return(0,$APP.$rumext$v2$jsxs$$)("li",{ref:$entry_ref$$,className:"main_ui_workspace_sidebar_versions__version-entry-wrap",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$milestone_group$milestone_group_STAR_$$,
{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.autosaved.version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$77$$),$APP.$cljs$cst$5027$localized_date$$)])),snapshots:$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$,$cljs$cst$5755$snapshots$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$77$$)),
onMenuClick:$on_open_snapshot_menu$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($open_menu_STAR_$$)!=null,"on-close":function(){return $APP.$cljs$core$reset_BANG_$$($open_menu_STAR_$$,null)},children:(0,$APP.$rumext$v2$jsxs$$)("ul",{style:{"--offset":""+($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??"")+"px"},className:"main_ui_workspace_sidebar_versions__version-options-dropdown",
children:[(0,$APP.$rumext$v2$jsx$$)("li",{role:"button","data-id":""+($cljs$cst$5757$snapshot$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??""),onClick:$on_preview_snapshot__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.preview")}),(0,$APP.$rumext$v2$jsx$$)("li",{role:"button","data-id":""+($cljs$cst$5757$snapshot$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??
""),onClick:$on_restore_snapshot__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.restore")}),(0,$APP.$rumext$v2$jsx$$)("li",{role:"button","data-id":""+($cljs$cst$5757$snapshot$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??""),onClick:$on_pin_snapshot__$1_props_79572$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.pin")})]})})]})};
$app$main$ui$workspace$sidebar$versions$versions_toolbox_STAR_$$=function(){var $profiles$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$),$profile$jscomp$73$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$team$jscomp$58$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$map__79598_status$jscomp$26$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$versions$versions$$),$map__79598__$1$$=$APP.$cljs$core$__destructure_map$$($map__79598_status$jscomp$26$$);$map__79598_status$jscomp$26$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79598__$1$$,$APP.$cljs$cst$109$status$$);var $data$jscomp$495$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79598__$1$$,$APP.$cljs$cst$142$data$$),$editing$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79598__$1$$,$APP.$cljs$cst$2152$editing$$),$users$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$495$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($created_by$jscomp$1_p__79599$$){var $map__79600__$1_profile_id$jscomp$19$$=$APP.$cljs$core$__destructure_map$$($created_by$jscomp$1_p__79599$$);$created_by$jscomp$1_p__79599$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79600__$1_profile_id$jscomp$19$$,$APP.$cljs$cst$5756$created_by$$);$map__79600__$1_profile_id$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79600__$1_profile_id$jscomp$19$$,
$APP.$cljs$cst$2313$profile_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("user",$created_by$jscomp$1_p__79599$$)?$map__79600__$1_profile_id$jscomp$19$$:null}),$data$jscomp$495$$)}),$entries$jscomp$44$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($map__79598__$1$$)],function(){return $app$main$ui$workspace$sidebar$versions$group_snapshots$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79591_SHARP_$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2691$filter$$.$cljs$core$IFn$_invoke$arity$1$($map__79598__$1$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("user",$APP.$cljs$cst$5756$created_by$$.$cljs$core$IFn$_invoke$arity$1$($p1__79591_SHARP_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2691$filter$$.$cljs$core$IFn$_invoke$arity$1$($map__79598__$1$$),$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79591_SHARP_$$))},$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__79598__$1$$)))}),$on_preview_version$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$999$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_preview$$($id$jscomp$999$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"preview-version",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"pinned-version"],null))]))}),$on_preview_snapshot$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1000$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_preview$$($id$jscomp$1000$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"preview-version",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"autosaved-version"],null))]))}),$on_restore_version$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1001$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_restore$$($id$jscomp$1001$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-version",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"pinned-version"],null))]))}),$on_restore_snapshot$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1002$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_restore$$($id$jscomp$1002$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-version",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"autosaved-version"],null))]))}),$on_change_filter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($filter_value$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2124$all$$,
$filter_value$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2691$filter$$,null],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5760$own$$,$filter_value$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2691$filter$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$73$$)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2691$filter$$,$filter_value$$],null)))}),$options$jscomp$633$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($users$jscomp$3$$),$APP.$rumext$v2$adapt$$($profile$jscomp$73$$)],function(){var $current_profile_id$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$73$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2124$all$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.filter.all")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$cljs$cst$5760$own$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.filter.mine")],null)],null),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1003$$){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1003$$,$current_profile_id$$)){var $temp__5825__auto__$jscomp$386$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$5$$,
$id$jscomp$1003$$),$APP.$cljs$cst$1360$fullname$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$386$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$id$jscomp$1003$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.filter.user",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$temp__5825__auto__$jscomp$386$$]))],null):null}return null}),$users$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$init_versions_state$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_versions__version-toolbox",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$2124$all$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.filter.label"),options:$options$jscomp$633$$,
"on-change":$on_change_filter$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__79598_status$jscomp$26$$,$APP.$cljs$cst$5019$loading$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_versions__versions-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"clock",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.loading")})}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__79598_status$jscomp$26$$,
$APP.$cljs$cst$5024$loaded$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_versions__version-save-version",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.save"),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.save"),
onClick:$app$main$ui$workspace$sidebar$versions$on_create_version$$,icon:"pin"})]}),$APP.$cljs$core$empty_QMARK_$$($data$jscomp$495$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_versions__versions-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"history",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.empty")})}):(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_versions__versions-entries",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$190$$,$entry$jscomp$78$$){$out_arr__44124__auto__$jscomp$190$$.push(function(){var $G__79605$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);switch($G__79605$$ instanceof $APP.$cljs$core$Keyword$$?$G__79605$$.$fqn$:null){case "version":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$versions$version_entry_STAR_$$,{entry:$entry$jscomp$78$$,onPreview:$on_preview_version$$,
onDelete:$app$main$ui$workspace$sidebar$versions$on_delete_version$$,onLock:$app$main$ui$workspace$sidebar$versions$on_lock_version$$,currentProfile:$profile$jscomp$73$$,onRestore:$on_restore_version$$,onUnlock:$app$main$ui$workspace$sidebar$versions$on_unlock_version$$,onEdit:$app$main$ui$workspace$sidebar$versions$on_edit_version$$,onCancelEdit:$app$main$ui$workspace$sidebar$versions$on_cancel_version_edition$$,onRename:$app$main$ui$workspace$sidebar$versions$on_rename_version$$,isEditing:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$),
$editing$jscomp$3$$)},$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$));case "snapshot":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$versions$snapshot_entry_STAR_$$,{entry:$entry$jscomp$78$$,onPreviewSnapshot:$on_preview_snapshot$jscomp$1$$,onRestoreSnapshot:$on_restore_snapshot$jscomp$1$$,onPinSnapshot:$app$main$ui$workspace$sidebar$versions$on_pin_version$$},$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$));default:return null}}());
return $out_arr__44124__auto__$jscomp$190$$},[],$entries$jscomp$44$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$cta$cta_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.warning.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$sidebar$versions$get_versions_stored_days$$($team$jscomp$58$$)])),children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"div",className:"main_ui_workspace_sidebar_versions__cta",
content:$app$main$ui$workspace$sidebar$versions$get_versions_warning_subtext$$($team$jscomp$58$$)})})]}):null]})};
$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens$$=function($shape$jscomp$1034$$,$token_name$jscomp$31$$,$container$jscomp$90$$){var $temp__5825__auto__$jscomp$387$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1034$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$387$$)?function $app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens_$_iter__79528$$($s__79529$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$=
$s__79529$$;;)if($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$=$APP.$cljs$core$seq$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$)){var $JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$=$APP.$cljs$core$_chunked_first$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$),$size__5502__auto__$jscomp$47$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$),$attribute$jscomp$2_b__79531$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$47$$);a:{for(var $i__79530$jscomp$inline_8976$$=0;;)if($i__79530$jscomp$inline_8976$$<$size__5502__auto__$jscomp$47$$){var $b$jscomp$inline_13577_vec__79532$jscomp$inline_8977$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$,
$i__79530$jscomp$inline_8976$$),$attribute$jscomp$inline_8978_x$jscomp$inline_13578$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13577_vec__79532$jscomp$inline_8977$$,0,null),$applied_token_name$jscomp$inline_8979$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13577_vec__79532$jscomp$inline_8977$$,1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_name$jscomp$inline_8979$$,$token_name$jscomp$31$$)&&($b$jscomp$inline_13577_vec__79532$jscomp$inline_8977$$=
$attribute$jscomp$2_b__79531$$,$attribute$jscomp$inline_8978_x$jscomp$inline_13578$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$cljs$cst$5576$applied_token$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1034$$),$cljs$cst$5761$attribute$$,$attribute$jscomp$inline_8978_x$jscomp$inline_13578$$,$APP.$cljs$cst$4186$token_name$$,$applied_token_name$jscomp$inline_8979$$,$APP.$cljs$cst$2588$container$$,$container$jscomp$90$$],
null),$b$jscomp$inline_13577_vec__79532$jscomp$inline_8977$$.add($attribute$jscomp$inline_8978_x$jscomp$inline_13578$$));$i__79530$jscomp$inline_8976$$+=1}else{$JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$=!0;break a}$JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$=void 0}return $JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($attribute$jscomp$2_b__79531$$),
$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens_$_iter__79528$$($APP.$cljs$core$_chunked_rest$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($attribute$jscomp$2_b__79531$$),null)}$JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$=$APP.$cljs$core$first$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$);$attribute$jscomp$2_b__79531$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$,
0,null);$JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$,$token_name$jscomp$31$$))return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$cljs$cst$5576$applied_token$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1034$$),$cljs$cst$5761$attribute$$,$attribute$jscomp$2_b__79531$$,$APP.$cljs$cst$4186$token_name$$,$JSCompiler_inline_result$jscomp$1836_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__79535$$,$APP.$cljs$cst$2588$container$$,$container$jscomp$90$$],null),$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens_$_iter__79528$$($APP.$cljs$core$rest$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$)));
$s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$=$APP.$cljs$core$rest$$($s__79529__$1_s__79529__$2_temp__5825__auto____$1$jscomp$22$$)}else return null},null,null)}($temp__5825__auto__$jscomp$387$$):null};
$app$main$data$workspace$tokens$remapping$scan_token_value_references$$=function($token$jscomp$141$$,$token_name$jscomp$32$$){var $find_all_token_value_references$$=function $app$main$data$workspace$tokens$remapping$scan_token_value_references_$_find_all_token_value_references$$($token_value$jscomp$7$$){return typeof $token_value$jscomp$7$$==="string"?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79538_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79538_SHARP_$$,
$token_name$jscomp$32$$)},$APP.$app$common$types$token$find_token_value_references$$($token_value$jscomp$7$$)):$APP.$cljs$core$map_QMARK_$$($token_value$jscomp$7$$)?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$tokens$remapping$scan_token_value_references_$_find_all_token_value_references$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($token_value$jscomp$7$$)])):$APP.$cljs$core$sequential_QMARK_$$($token_value$jscomp$7$$)?
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$tokens$remapping$scan_token_value_references_$_find_all_token_value_references$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_value$jscomp$7$$])):$APP.$cljs$core$PersistentVector$EMPTY$$},$temp__5825__auto__$jscomp$388$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$141$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$388$$)?function $app$main$data$workspace$tokens$remapping$scan_token_value_references_$_iter__79539$$($s__79540$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__79540__$2_temp__5825__auto____$1$jscomp$23$$=$APP.$cljs$core$seq$$($s__79540$$);if($s__79540__$2_temp__5825__auto____$1$jscomp$23$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__79540__$2_temp__5825__auto____$1$jscomp$23$$)){var $JSCompiler_inline_result$jscomp$1837_c__5501__auto__$jscomp$48$$=$APP.$cljs$core$_chunked_first$$($s__79540__$2_temp__5825__auto____$1$jscomp$23$$),$size__5502__auto__$jscomp$48$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1837_c__5501__auto__$jscomp$48$$),
$b__79542_referenced_token_name$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$48$$);a:{for(var $i__79541$jscomp$inline_8981$$=0;;)if($i__79541$jscomp$inline_8981$$<$size__5502__auto__$jscomp$48$$){var $referenced_token_name$jscomp$inline_8982_x$jscomp$inline_13581$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1837_c__5501__auto__$jscomp$48$$,$i__79541$jscomp$inline_8981$$),$b$jscomp$inline_13580$$=$b__79542_referenced_token_name$$;$referenced_token_name$jscomp$inline_8982_x$jscomp$inline_13581$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$5762$token_alias$$,$cljs$cst$5763$source_token_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$141$$),$cljs$cst$5764$referenced_token_name$$,$referenced_token_name$jscomp$inline_8982_x$jscomp$inline_13581$$],null);$b$jscomp$inline_13580$$.add($referenced_token_name$jscomp$inline_8982_x$jscomp$inline_13581$$);$i__79541$jscomp$inline_8981$$+=1}else{$JSCompiler_inline_result$jscomp$1837_c__5501__auto__$jscomp$48$$=
!0;break a}$JSCompiler_inline_result$jscomp$1837_c__5501__auto__$jscomp$48$$=void 0}return $JSCompiler_inline_result$jscomp$1837_c__5501__auto__$jscomp$48$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__79542_referenced_token_name$$),$app$main$data$workspace$tokens$remapping$scan_token_value_references_$_iter__79539$$($APP.$cljs$core$_chunked_rest$$($s__79540__$2_temp__5825__auto____$1$jscomp$23$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__79542_referenced_token_name$$),
null)}$b__79542_referenced_token_name$$=$APP.$cljs$core$first$$($s__79540__$2_temp__5825__auto____$1$jscomp$23$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$5762$token_alias$$,$cljs$cst$5763$source_token_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$141$$),$cljs$cst$5764$referenced_token_name$$,$b__79542_referenced_token_name$$],null),$app$main$data$workspace$tokens$remapping$scan_token_value_references_$_iter__79539$$($APP.$cljs$core$rest$$($s__79540__$2_temp__5825__auto____$1$jscomp$23$$)))}return null}},
null,null)}($find_all_token_value_references$$($temp__5825__auto__$jscomp$388$$)):null};
$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$=function($file_data$jscomp$117$$,$old_token_name$$){var $tokens_lib$jscomp$37$$=$APP.$cljs$cst$2139$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$117$$),$containers$jscomp$1$$=$APP.$app$common$types$file$object_containers_seq$$($file_data$jscomp$117$$),$matching_applied$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($container$jscomp$91$$){var $shapes$jscomp$227$$=$APP.$cljs$core$vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$91$$));
return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__79544_SHARP_$$){return $app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens$$($p1__79544_SHARP_$$,$old_token_name$$,$container$jscomp$91$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shapes$jscomp$227$$]))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$containers$jscomp$1$$])),$matching_aliases$$=$APP.$cljs$core$truth_$$($tokens_lib$jscomp$37$$)?function(){var $all_tokens$$=
$app$common$types$tokens_lib$get_all_tokens$$($tokens_lib$jscomp$37$$);return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__79545_SHARP_$$){return $app$main$data$workspace$tokens$remapping$scan_token_value_references$$($p1__79545_SHARP_$$,$old_token_name$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$all_tokens$$]))}():$APP.$cljs$core$PersistentVector$EMPTY$$;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.remapping",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"token-scan-details"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4186$token_name$$,$old_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5765$containers_count$$,$APP.$cljs$core$count$$($containers$jscomp$1$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5766$total_applied_refs$$,$APP.$cljs$core$count$$($matching_applied$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5767$matching_applied$$,
$APP.$cljs$core$count$$($matching_applied$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5768$total_alias_refs$$,$APP.$cljs$core$count$$($matching_aliases$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5769$matching_aliases$$,$APP.$cljs$core$count$$($matching_aliases$$)],null)],null)}),null,"app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$,!1);
return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1873$applied_tokens$$,$matching_applied$$,$cljs$cst$5770$token_aliases$$,$matching_aliases$$,$cljs$cst$5771$total_references$$,$APP.$cljs$core$count$$($matching_applied$$)+$APP.$cljs$core$count$$($matching_aliases$$)],null)};
$app$main$data$workspace$tokens$remapping$build_remap_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file_data$jscomp$118$$,$old_token_name$jscomp$1$$,$new_token_name$$,$map__79568__$1_p__79565_undo_group$jscomp$43$$){$map__79568__$1_p__79565_undo_group$jscomp$43$$=$APP.$cljs$core$__destructure_map$$($map__79568__$1_p__79565_undo_group$jscomp$43$$);$map__79568__$1_p__79565_undo_group$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79568__$1_p__79565_undo_group$jscomp$43$$,
$APP.$cljs$cst$3138$undo_group$$);var $G__79573_scan_results$$=$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$($file_data$jscomp$118$$,$old_token_name$jscomp$1$$),$tokens_lib$jscomp$38$$=$APP.$cljs$cst$2139$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$118$$),$refs_by_container_sets$jscomp$21_shape_changes$jscomp$3$$=$APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$38$$),$tokens_with_sets$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($set$jscomp$19$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$142$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$142$$,$APP.$cljs$cst$203$set$$,$set$jscomp$19$$],null)},$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$38$$,$APP.$app$common$types$tokens_lib$get_id$$($set$jscomp$19$$))))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$refs_by_container_sets$jscomp$21_shape_changes$jscomp$3$$]));$refs_by_container_sets$jscomp$21_shape_changes$jscomp$3$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$2588$container$$,
$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($G__79573_scan_results$$));$refs_by_container_sets$jscomp$21_shape_changes$jscomp$3$$=$APP.$cljs$core$reduce_kv$$(function($changes$jscomp$330$$,$container$jscomp$92_container_changes$$,$refs$jscomp$1$$){var $shape_ids$jscomp$109$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2543$shape_id$$,$refs$jscomp$1$$),$token$jscomp$143$$=function(){var $or__5025__auto__$jscomp$1231$$=$APP.$cljs$core$some$$(function($p1__79550_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($p1__79550_SHARP_$$)),
$new_token_name$$)?$p1__79550_SHARP_$$:null},$tokens_with_sets$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1231$$)?$or__5025__auto__$jscomp$1231$$:$APP.$cljs$core$some$$(function($p1__79551_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($p1__79551_SHARP_$$)),$old_token_name$jscomp$1$$)?$p1__79551_SHARP_$$:null},$tokens_with_sets$$)}(),$attributes$jscomp$77$$=
$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5761$attribute$$,$refs$jscomp$1$$));return $APP.$cljs$core$truth_$$($token$jscomp$143$$)?($container$jscomp$92_container_changes$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$with_container$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$container$jscomp$92_container_changes$$),$file_data$jscomp$118$$),$shape_ids$jscomp$109$$,function($shape$jscomp$1035$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1035$$,$APP.$cljs$cst$1873$applied_tokens$$,function($p1__79554_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__79554_SHARP_$$,$APP.$app$common$files$tokens$attributes_map$$($attributes$jscomp$77$$,$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$143$$))]))})},
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$330$$,$container$jscomp$92_container_changes$$)):$changes$jscomp$330$$},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$file_data$jscomp$118$$),$refs_by_container_sets$jscomp$21_shape_changes$jscomp$3$$);$G__79573_scan_results$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$331$$,$ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$){var $source_token_id$$=$cljs$cst$5763$source_token_id$$.$cljs$core$IFn$_invoke$arity$1$($ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$);$ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$=$APP.$cljs$core$some$$(function($p1__79555_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($p1__79555_SHARP_$$)),
$source_token_id$$)?$p1__79555_SHARP_$$:null},$tokens_with_sets$$);if($APP.$cljs$core$truth_$$($ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$)){var $map__79571__$1_set$jscomp$20$$=$APP.$cljs$core$__destructure_map$$($ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$);$ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79571__$1_set$jscomp$20$$,$APP.$cljs$cst$1136$token$$);$map__79571__$1_set$jscomp$20$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79571__$1_set$jscomp$20$$,$APP.$cljs$cst$203$set$$);var $new_value$jscomp$28_old_value$jscomp$3$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$);$new_value$jscomp$28_old_value$jscomp$3$$=$app$common$types$token$update_token_value_references$$($new_value$jscomp$28_old_value$jscomp$3$$,$old_token_name$jscomp$1$$,$new_token_name$$);return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$331$$,
$APP.$app$common$types$tokens_lib$get_id$$($map__79571__$1_set$jscomp$20$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ref$jscomp$55_temp__5825__auto__$jscomp$389_token$jscomp$144$$,$APP.$cljs$cst$260$value$$,$new_value$jscomp$28_old_value$jscomp$3$$))}return null},$refs_by_container_sets$jscomp$21_shape_changes$jscomp$3$$,$cljs$cst$5770$token_aliases$$.$cljs$core$IFn$_invoke$arity$1$($G__79573_scan_results$$));
return $map__79568__$1_p__79565_undo_group$jscomp$43$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79573_scan_results$$,$APP.$cljs$cst$3138$undo_group$$,$map__79568__$1_p__79565_undo_group$jscomp$43$$):$G__79573_scan_results$$};
$app$main$data$workspace$tokens$remapping$remap_tokens$$=function($var_args$jscomp$1453$$){for(var $args__5755__auto__$jscomp$256$$=[],$len__5749__auto___79609$$=arguments.length,$i__5750__auto___79610$$=0;;)if($i__5750__auto___79610$$<$len__5749__auto___79609$$)$args__5755__auto__$jscomp$256$$.push(arguments[$i__5750__auto___79610$$]),$i__5750__auto___79610$$+=1;else break;return $app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],
2<$args__5755__auto__$jscomp$256$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$256$$.slice(2),0,null):null)};
$app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($old_token_name$jscomp$2$$,$new_token_name$jscomp$1$$,$p__79579$$){var $map__79580__$1$$=$APP.$cljs$core$__destructure_map$$($p__79579$$),$undo_group$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79580__$1$$,$APP.$cljs$cst$3138$undo_group$$);typeof $app$main$data$workspace$tokens$remapping$remap_tokens_79581$$==="undefined"&&($app$main$data$workspace$tokens$remapping$remap_tokens_79581$$=
function($old_token_name$jscomp$3$$,$new_token_name$jscomp$2$$,$p__79579$jscomp$1$$,$map__79580$jscomp$1$$,$undo_group$jscomp$45$$,$meta79582$$){this.$old_token_name$=$old_token_name$jscomp$3$$;this.$new_token_name$=$new_token_name$jscomp$2$$;this.$p__79579$=$p__79579$jscomp$1$$;this.$map__79580$=$map__79580$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$45$$;this.$meta79582$=$meta79582$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$remapping$remap_tokens_79581$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$remap_tokens_79581$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5772$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_remap_tokens$$},$app$main$data$workspace$tokens$remapping$remap_tokens_79581$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79583$$,$meta79582__$1$$){return new $app$main$data$workspace$tokens$remapping$remap_tokens_79581$$(this.$old_token_name$,
this.$new_token_name$,this.$p__79579$,this.$map__79580$,this.$undo_group$,$meta79582__$1$$)},$app$main$data$workspace$tokens$remapping$remap_tokens_79581$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta79582$},$app$main$data$workspace$tokens$remapping$remap_tokens_79581$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$remap_tokens_79581$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3052_file_data$jscomp$119_token_changes$jscomp$1$$,
$state$jscomp$1196$$){var $self__$jscomp$7451$$=this;$_$jscomp$3052_file_data$jscomp$119_token_changes$jscomp$1$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1196$$);$_$jscomp$3052_file_data$jscomp$119_token_changes$jscomp$1$$=$app$main$data$workspace$tokens$remapping$build_remap_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$3052_file_data$jscomp$119_token_changes$jscomp$1$$,$self__$jscomp$7451$$.$old_token_name$,$self__$jscomp$7451$$.$new_token_name$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$7451$$.$undo_group$]));$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"token-remapping"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5773$old_name$$,$self__$jscomp$7451$$.$old_token_name$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5774$new_name$$,$self__$jscomp$7451$$.$new_token_name$],null)],null)}),null,"app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($_$jscomp$3052_file_data$jscomp$119_token_changes$jscomp$1$$))});
return new $app$main$data$workspace$tokens$remapping$remap_tokens_79581$$($old_token_name$jscomp$2$$,$new_token_name$jscomp$1$$,$p__79579$$,$map__79580__$1$$,$undo_group$jscomp$44$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$remapping$bulk_remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($tokens_in_path$$,$new_tokens$jscomp$1$$,$p__79592$$){var $map__79593__$1$$=$APP.$cljs$core$__destructure_map$$($p__79592$$),$undo_group$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79593__$1$$,$APP.$cljs$cst$3138$undo_group$$);typeof $app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$==="undefined"&&($app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$=
function($tokens_in_path$jscomp$1$$,$new_tokens$jscomp$2$$,$p__79592$jscomp$1$$,$map__79593$jscomp$1$$,$undo_group$jscomp$47$$,$meta79595$$){this.$tokens_in_path$=$tokens_in_path$jscomp$1$$;this.$new_tokens$=$new_tokens$jscomp$2$$;this.$p__79592$=$p__79592$jscomp$1$$;this.$map__79593$=$map__79593$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$47$$;this.$meta79595$=$meta79595$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5775$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_bulk_remap_tokens$$},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79596$$,$meta79595__$1$$){return new $app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$(this.$tokens_in_path$,
this.$new_tokens$,this.$p__79592$,this.$map__79593$,this.$undo_group$,$meta79595__$1$$)},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta79595$},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7455$$=
this;return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($old_token$$,$new_token$jscomp$1$$){return $app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($old_token$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_token$jscomp$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$7455$$.$undo_group$]))},
$self__$jscomp$7455$$.$tokens_in_path$,$self__$jscomp$7455$$.$new_tokens$))});return new $app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$($tokens_in_path$$,$new_tokens$jscomp$1$$,$p__79592$$,$map__79593__$1$$,$undo_group$jscomp$46$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$remapping$count_token_references$$=function($file_data$jscomp$120$$,$token_name$jscomp$33$$){var $scan_results$jscomp$1$$=$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$($file_data$jscomp$120$$,$token_name$jscomp$33$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"token-reference-scan"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$33$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5779$applied_refs$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$))],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5780$alias_refs$$,$APP.$cljs$core$count$$($cljs$cst$5770$token_aliases$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$))],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2328$total$$,$cljs$cst$5771$total_references$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$)],null)],null)}),null,"app.main.data.workspace.tokens.remapping",
$APP.$cljs$cst$1161$info$$,!1);return $cljs$cst$5771$total_references$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$)};$app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$=function($ks$jscomp$64$$,$m$jscomp$238$$){return $APP.$cljs$core$some$$(function($p1__79613_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($m$jscomp$238$$,$p1__79613_SHARP_$$)},$ks$jscomp$64$$)};
$app$main$ui$workspace$tokens$management$context_menu$clean_separators$$=function($items$jscomp$62_items_SINGLEQUOTE_$$){$items$jscomp$62_items_SINGLEQUOTE_$$=$APP.$cljs$core$drop_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79616_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79616_SHARP_$$,$APP.$cljs$cst$1472$separator$$)},$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$dedupe$cljs$0core$0IFn$0_invoke$0arity$00$$(),$items$jscomp$62_items_SINGLEQUOTE_$$));
return $APP.$cljs$core$every_QMARK_$$(function($p1__79617_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79617_SHARP_$$,$APP.$cljs$cst$1472$separator$$)},$items$jscomp$62_items_SINGLEQUOTE_$$)?null:$items$jscomp$62_items_SINGLEQUOTE_$$};
$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$=function($shape_ids$jscomp$110_token$jscomp$145$$,$selected_shapes$jscomp$12$$,$attributes$jscomp$78$$){var $ids_by_attributes$jscomp$1$$=$app$common$files$tokens$shapes_ids_by_applied_attributes$$($shape_ids$jscomp$110_token$jscomp$145$$,$selected_shapes$jscomp$12$$,$attributes$jscomp$78$$);$shape_ids$jscomp$110_token$jscomp$145$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$selected_shapes$jscomp$12$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5781$all_selected_QMARK_$$,$app$common$files$tokens$shapes_applied_all_QMARK_$$($ids_by_attributes$jscomp$1$$,$shape_ids$jscomp$110_token$jscomp$145$$,$attributes$jscomp$78$$),$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$110_token$jscomp$145$$,$cljs$cst$5782$selected_pred$$,function($p1__79618_SHARP_$$){return $APP.$cljs$core$seq$$($p1__79618_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$?
$p1__79618_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$($ids_by_attributes$jscomp$1$$):$p1__79618_SHARP_$$($ids_by_attributes$jscomp$1$$))}],null)};
$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$=function($allowed_attributes_attributes$jscomp$79$$,$title$jscomp$41$$,$map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$){var $allowed_shape_attributes_map__79620__$1$$=$APP.$cljs$core$__destructure_map$$($map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$),$token$jscomp$146$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__79620__$1$$,$APP.$cljs$cst$1136$token$$);
$map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__79620__$1$$,$APP.$cljs$cst$5335$selected_shapes$$);var $on_update_shape$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__79620__$1$$,$APP.$cljs$cst$4646$on_update_shape$$),$hint$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__79620__$1$$,$APP.$cljs$cst$275$hint$$);
$allowed_shape_attributes_map__79620__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__79620__$1$$,$cljs$cst$5783$allowed_shape_attributes$$);$allowed_attributes_attributes$jscomp$79$$=$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($allowed_attributes_attributes$jscomp$79$$,$allowed_shape_attributes_map__79620__$1$$);var $on_update_shape_fn$$=$APP.$cljs$core$truth_$$($on_update_shape$jscomp$5$$)?$on_update_shape$jscomp$5$$:$APP.$cljs$core$truth_$$($token$jscomp$146$$)?
$APP.$cljs$cst$4646$on_update_shape$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$get_token_properties$$($token$jscomp$146$$)):null;$map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$=$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$($token$jscomp$146$$,$map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$,$allowed_attributes_attributes$jscomp$79$$);$map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$);
var $selected_pred$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$,$cljs$cst$5782$selected_pred$$),$shape_ids$jscomp$111$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79621_map__79621__$1_p__79619_selected_shapes$jscomp$13$$,$APP.$cljs$cst$4641$shape_ids$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($attribute$jscomp$4$$){var $selected_QMARK_$jscomp$5$$=$selected_pred$$.$cljs$core$IFn$_invoke$arity$1$?
$selected_pred$$.$cljs$core$IFn$_invoke$arity$1$($attribute$jscomp$4$$):$selected_pred$$($attribute$jscomp$4$$),$props$jscomp$352$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attribute$jscomp$4$$]),$APP.$cljs$cst$1136$token$$,$token$jscomp$146$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$111$$],null),$unnaply_props$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$146$$),$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attribute$jscomp$4$$]),$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$111$$],null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,$title$jscomp$41$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$16$$,$APP.$cljs$cst$5784$selected_QMARK_$$,$selected_QMARK_$jscomp$5$$,$APP.$cljs$cst$2683$action$$,function(){return $APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$5$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$352$$,$APP.$cljs$cst$4646$on_update_shape$$,$on_update_shape_fn$$)))}],null)},$allowed_attributes_attributes$jscomp$79$$)};
$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$=function($attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$,$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$){var $allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$=$APP.$cljs$core$__destructure_map$$($attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$);$attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,
$cljs$cst$5785$attribute_labels$$);var $on_update_shape_all$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,$cljs$cst$5786$on_update_shape_all$$),$on_update_shape$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,$APP.$cljs$cst$4646$on_update_shape$$),$hint$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,
$APP.$cljs$cst$275$hint$$);$allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$=$APP.$cljs$core$__destructure_map$$($all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$);var $token$jscomp$147$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,$APP.$cljs$cst$1136$token$$);$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,
$APP.$cljs$cst$5335$selected_shapes$$);$allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$,$cljs$cst$5783$allowed_shape_attributes$$);if($attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$=$APP.$cljs$core$seq$$($APP.$cljs$core$select_keys$$($attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$,$allowed_shape_attributes$jscomp$1_map__79624__$1_map__79625__$1$$))){var $attributes$jscomp$80$$=
$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$));$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$=$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$($token$jscomp$147$$,$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$,$attributes$jscomp$80$$);$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$=$APP.$cljs$core$__destructure_map$$($all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$);
var $all_selected_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$,$cljs$cst$5781$all_selected_QMARK_$$),$selected_pred$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$,$cljs$cst$5782$selected_pred$$),$shape_ids$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$,
$APP.$cljs$cst$4641$shape_ids$$);$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$=function(){var $props$jscomp$353$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1993$attributes$$,$attributes$jscomp$80$$,$APP.$cljs$cst$1136$token$$,$token$jscomp$147$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$112$$],null),$unnaply_props$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$147$$),
$APP.$cljs$cst$1993$attributes$$,$attributes$jscomp$80$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$112$$],null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.all"),$APP.$cljs$cst$5784$selected_QMARK_$$,$all_selected_QMARK_$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$17$$,$APP.$cljs$cst$2683$action$$,function(){return $APP.$cljs$core$truth_$$($all_selected_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$1$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$353$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$cljs$core$truth_$$($on_update_shape_all$$)?$on_update_shape_all$$:$on_update_shape$jscomp$6$$)))}],null)}();$attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__79627_title$jscomp$42$$){var $attr$jscomp$93$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79627_title$jscomp$42$$,0,null);$p__79627_title$jscomp$42$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79627_title$jscomp$42$$,1,null);var $selected_QMARK_$jscomp$6$$=$selected_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$selected_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$93$$):$selected_pred$jscomp$1$$($attr$jscomp$93$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,
$p__79627_title$jscomp$42$$,$APP.$cljs$cst$5784$selected_QMARK_$$,function(){var $and__5023__auto__$jscomp$829$$=$APP.$cljs$core$not$$($all_selected_QMARK_$$);return $and__5023__auto__$jscomp$829$$?$selected_QMARK_$jscomp$6$$:$and__5023__auto__$jscomp$829$$}(),$APP.$cljs$cst$2683$action$$,function(){var $event$jscomp$577_props$jscomp$354$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$93$$]),$APP.$cljs$cst$1136$token$$,
$token$jscomp$147$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$112$$],null),$unnaply_props$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$147$$),$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$93$$]),$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$112$$],null);$event$jscomp$577_props$jscomp$354$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$$)?
$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$577_props$jscomp$354$$,$APP.$cljs$cst$4645$attributes_to_remove$$,$attributes$jscomp$80$$)):$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$6$$)?$APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$2$$):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$577_props$jscomp$354$$,
$APP.$cljs$cst$4646$on_update_shape$$,$on_update_shape$jscomp$6$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$577_props$jscomp$354$$)}],null)},$attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$all_action_map__79626_map__79626__$1_p__79623_selected_shapes$jscomp$14$$],null):null,$attribute_labels_p__79622_single_actions_temp__5825__auto__$jscomp$390$$)}return null};
$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$=function($all_attr_labels_p__79631_single_items$$){var $hint$jscomp$18_map__79632__$1_multi_items$$=$APP.$cljs$core$__destructure_map$$($all_attr_labels_p__79631_single_items$$),$token$jscomp$148$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,$APP.$cljs$cst$1136$token$$),$map__79634_map__79634__$1_selected_shapes$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,
$APP.$cljs$cst$5335$selected_shapes$$);$all_attr_labels_p__79631_single_items$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,$cljs$cst$5787$all_attr_labels$$);var $horizontal_attr_labels$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,$cljs$cst$5788$horizontal_attr_labels$$),$vertical_attr_labels$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,
$cljs$cst$5789$vertical_attr_labels$$),$on_update_shape$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,$APP.$cljs$cst$4646$on_update_shape$$);$hint$jscomp$18_map__79632__$1_multi_items$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,$APP.$cljs$cst$275$hint$$);var $horizontal_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($horizontal_attr_labels$$)),
$vertical_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($vertical_attr_labels$$)),$attrs$jscomp$182$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($horizontal_attrs$$,$vertical_attrs$$);$map__79634_map__79634__$1_selected_shapes$jscomp$15$$=$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$($token$jscomp$148$$,$map__79634_map__79634__$1_selected_shapes$jscomp$15$$,$attrs$jscomp$182$$);
$map__79634_map__79634__$1_selected_shapes$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($map__79634_map__79634__$1_selected_shapes$jscomp$15$$);var $all_selected_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79634_map__79634__$1_selected_shapes$jscomp$15$$,$cljs$cst$5781$all_selected_QMARK_$$),$selected_pred$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79634_map__79634__$1_selected_shapes$jscomp$15$$,$cljs$cst$5782$selected_pred$$),$shape_ids$jscomp$113$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79634_map__79634__$1_selected_shapes$jscomp$15$$,$APP.$cljs$cst$4641$shape_ids$$),$horizontal_selected_QMARK_$$=$APP.$cljs$core$not$$($all_selected_QMARK_$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$($selected_pred$jscomp$2$$,$horizontal_attrs$$),$vertical_selected_QMARK_$$=$APP.$cljs$core$not$$($all_selected_QMARK_$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$($selected_pred$jscomp$2$$,$vertical_attrs$$);$hint$jscomp$18_map__79632__$1_multi_items$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.all"),$APP.$cljs$cst$5784$selected_QMARK_$$,$all_selected_QMARK_$jscomp$1$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$18_map__79632__$1_multi_items$$,$APP.$cljs$cst$2683$action$$,function(){var $props$jscomp$355$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1993$attributes$$,
$attrs$jscomp$182$$,$APP.$cljs$cst$1136$token$$,$token$jscomp$148$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$113$$],null),$unnaply_props$jscomp$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$148$$),$APP.$cljs$cst$1993$attributes$$,$attrs$jscomp$182$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$113$$],null);return $APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$3$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$355$$,$APP.$cljs$cst$4646$on_update_shape$$,$on_update_shape$jscomp$7$$)))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"Horizontal",$APP.$cljs$cst$5784$selected_QMARK_$$,$horizontal_selected_QMARK_$$,$APP.$cljs$cst$2683$action$$,function(){var $event$jscomp$578_props$jscomp$356$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$148$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$113$$],null);$event$jscomp$578_props$jscomp$356$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$578_props$jscomp$356$$,$APP.$cljs$cst$4645$attributes_to_remove$$,$vertical_attrs$$)):$horizontal_selected_QMARK_$$?
$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$578_props$jscomp$356$$,$APP.$cljs$cst$4645$attributes_to_remove$$,$horizontal_attrs$$)):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($event$jscomp$578_props$jscomp$356$$,$APP.$cljs$cst$1993$attributes$$,$horizontal_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4646$on_update_shape$$,
$on_update_shape$jscomp$7$$])));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$578_props$jscomp$356$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"Vertical",$APP.$cljs$cst$5784$selected_QMARK_$$,$vertical_selected_QMARK_$$,$APP.$cljs$cst$2683$action$$,function(){var $event$jscomp$579_props$jscomp$357$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$148$$,$APP.$cljs$cst$4641$shape_ids$$,
$shape_ids$jscomp$113$$],null);$event$jscomp$579_props$jscomp$357$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$579_props$jscomp$357$$,$APP.$cljs$cst$4645$attributes_to_remove$$,$horizontal_attrs$$)):$vertical_selected_QMARK_$$?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$579_props$jscomp$357$$,
$APP.$cljs$cst$4645$attributes_to_remove$$,$vertical_attrs$$)):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($event$jscomp$579_props$jscomp$357$$,$APP.$cljs$cst$1993$attributes$$,$vertical_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4646$on_update_shape$$,$on_update_shape$jscomp$7$$])));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$579_props$jscomp$357$$)}],
null)],null);$all_attr_labels_p__79631_single_items$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__79635_title$jscomp$43$$){var $attr$jscomp$94$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79635_title$jscomp$43$$,0,null);$p__79635_title$jscomp$43$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79635_title$jscomp$43$$,1,null);var $same_axis_selected_QMARK_$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($horizontal_attrs$$,
$attr$jscomp$94$$))?$horizontal_selected_QMARK_$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vertical_attrs$$,$attr$jscomp$94$$))?$vertical_selected_QMARK_$$:!0,$selected_QMARK_$jscomp$7$$=function(){var $and__5023__auto__$jscomp$830_and__5023__auto____$1$jscomp$146$$=$APP.$cljs$core$not$$($all_selected_QMARK_$jscomp$1$$);return $and__5023__auto__$jscomp$830_and__5023__auto____$1$jscomp$146$$?($and__5023__auto__$jscomp$830_and__5023__auto____$1$jscomp$146$$=!$same_axis_selected_QMARK_$$)?
$selected_pred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$selected_pred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$94$$):$selected_pred$jscomp$2$$($attr$jscomp$94$$):$and__5023__auto__$jscomp$830_and__5023__auto____$1$jscomp$146$$:$and__5023__auto__$jscomp$830_and__5023__auto____$1$jscomp$146$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$p__79635_title$jscomp$43$$,$APP.$cljs$cst$5784$selected_QMARK_$$,$selected_QMARK_$jscomp$7$$,$APP.$cljs$cst$2683$action$$,
function(){var $event$jscomp$580_props$jscomp$358$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$94$$]),$APP.$cljs$cst$1136$token$$,$token$jscomp$148$$,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$113$$],null),$unnaply_props$jscomp$4$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$148$$),
$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$94$$]),$APP.$cljs$cst$4641$shape_ids$$,$shape_ids$jscomp$113$$],null);$event$jscomp$580_props$jscomp$358$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$580_props$jscomp$358$$,$APP.$cljs$cst$4645$attributes_to_remove$$,$attrs$jscomp$182$$)):$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$7$$)?
$APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$4$$):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$580_props$jscomp$358$$,$APP.$cljs$cst$4646$on_update_shape$$,$on_update_shape$jscomp$7$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$580_props$jscomp$358$$)}],null)},$all_attr_labels_p__79631_single_items$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$18_map__79632__$1_multi_items$$,
$all_attr_labels_p__79631_single_items$$)};
$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_padding$$=function($value$jscomp$936$$,$shape_ids$jscomp$114$$,$attributes$jscomp$81$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($attributes$jscomp$81$$),1)?$APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$114$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1685$layout_padding_type$$,$APP.$cljs$cst$1616$multiple$$],null)):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$936$$,$shape_ids$jscomp$114$$,$attributes$jscomp$81$$)]))};
$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_margin$$=function($value$jscomp$937$$,$shape_ids$jscomp$115$$,$attributes$jscomp$82$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($attributes$jscomp$82$$),1)?$APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$115$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1698$layout_item_margin_type$$,$APP.$cljs$cst$1616$multiple$$],null)):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$937$$,$shape_ids$jscomp$115$$,$attributes$jscomp$82$$)]))};
$app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$=function($gap_items_map__79640__$1_p__79639$$){$gap_items_map__79640__$1_p__79639$$=$APP.$cljs$core$__destructure_map$$($gap_items_map__79640__$1_p__79639$$);var $margin_items_token$jscomp$149$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__79640__$1_p__79639$$,$APP.$cljs$cst$1136$token$$),$selected_shapes$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__79640__$1_p__79639$$,
$APP.$cljs$cst$5335$selected_shapes$$),$allowed_shape_attributes$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__79640__$1_p__79639$$,$cljs$cst$5783$allowed_shape_attributes$$),$is_selected_inside_layout$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__79640__$1_p__79639$$,$cljs$cst$5790$is_selected_inside_layout$$),$padding_attr_labels_padding_items$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,"Padding top",$APP.$cljs$cst$1091$p2$$,
"Padding right",$APP.$cljs$cst$1687$p3$$,"Padding bottom",$APP.$cljs$cst$1688$p4$$,"Padding left"],null);$padding_attr_labels_padding_items$$=$APP.$cljs$core$truth_$$($app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$($allowed_shape_attributes$jscomp$2$$,$padding_attr_labels_padding_items$$))?$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1136$token$$,$margin_items_token$jscomp$149$$,
$APP.$cljs$cst$5335$selected_shapes$$,$selected_shapes$jscomp$16$$,$cljs$cst$5787$all_attr_labels$$,$padding_attr_labels_padding_items$$,$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.paddings"),$cljs$cst$5788$horizontal_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,"Padding right",$APP.$cljs$cst$1688$p4$$,"Padding left"],null),$cljs$cst$5789$vertical_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1093$p1$$,"Padding top",$APP.$cljs$cst$1687$p3$$,"Padding bottom"],null),$APP.$cljs$cst$4646$on_update_shape$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_padding$$],null)):null;var $margin_attr_labels$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1700$m1$$,"Margin top",$APP.$cljs$cst$1701$m2$$,"Margin right",$APP.$cljs$cst$1702$m3$$,"Margin bottom",$APP.$cljs$cst$1703$m4$$,"Margin left"],null);$margin_items_token$jscomp$149$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_selected_inside_layout$$)?
$is_selected_inside_layout$$:$app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$($allowed_shape_attributes$jscomp$2$$,$margin_attr_labels$$))?$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1136$token$$,$margin_items_token$jscomp$149$$,$APP.$cljs$cst$5335$selected_shapes$$,$selected_shapes$jscomp$16$$,$cljs$cst$5787$all_attr_labels$$,$margin_attr_labels$$,$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.margins"),
$cljs$cst$5788$horizontal_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1701$m2$$,"Margin right",$APP.$cljs$cst$1703$m4$$,"Margin left"],null),$cljs$cst$5789$vertical_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1700$m1$$,"Margin top",$APP.$cljs$cst$1702$m3$$,"Margin bottom"],null),$APP.$cljs$cst$4646$on_update_shape$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_margin$$],null)):null;$gap_items_map__79640__$1_p__79639$$=
$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5785$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1682$column_gap$$,"Column Gap",$APP.$cljs$cst$1681$row_gap$$,"Row Gap"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.gaps"),$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_gap$$],
null),$gap_items_map__79640__$1_p__79639$$);return $app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($gap_items_map__79640__$1_p__79639$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$padding_attr_labels_padding_items$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],null),$margin_items_token$jscomp$149$$])))};
$app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$=function($context_data$jscomp$1$$){return $app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5785$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,"Width",
$APP.$cljs$cst$1522$height$$,"Height"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.size"),$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$],null),$context_data$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5785$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1707$layout_item_min_w$$,"Min Width",$APP.$cljs$cst$1705$layout_item_min_h$$,"Min Height"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.min-size"),$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$],null),$context_data$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],null),$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5785$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1706$layout_item_max_w$$,"Max Width",$APP.$cljs$cst$1704$layout_item_max_h$$,"Max Height"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.max-size"),
$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$],null),$context_data$jscomp$1$$)])))};
$app$main$ui$workspace$tokens$management$context_menu$update_shape_radius_for_corners$$=function($value$jscomp$938$$,$shape_ids$jscomp$116$$,$attributes$jscomp$83$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5682$expand_border_radius$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$938$$,
$shape_ids$jscomp$116$$,$attributes$jscomp$83$$)]))};
$app$main$ui$workspace$tokens$management$context_menu$default_actions$$=function($map__79644__$1_map__79645_map__79645__$1_p__79643$$){$map__79644__$1_map__79645_map__79645__$1_p__79643$$=$APP.$cljs$core$__destructure_map$$($map__79644__$1_map__79645_map__79645__$1_p__79643$$);var $token$jscomp$150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79644__$1_map__79645_map__79645__$1_p__79643$$,$APP.$cljs$cst$1136$token$$),$selected_token_set_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79644__$1_map__79645_map__79645__$1_p__79643$$,
$APP.$cljs$cst$2138$selected_token_set_id$$),$on_delete_token$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79644__$1_map__79645_map__79645__$1_p__79643$$,$cljs$cst$5792$on_delete_token$$),$errors$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79644__$1_map__79645_map__79645__$1_p__79643$$,$APP.$cljs$cst$570$errors$$);$map__79644__$1_map__79645_map__79645__$1_p__79643$$=$app$main$data$workspace$tokens$application$get_token_properties$$($token$jscomp$150$$);
$map__79644__$1_map__79645_map__79645__$1_p__79643$$=$APP.$cljs$core$__destructure_map$$($map__79644__$1_map__79645_map__79645__$1_p__79643$$);var $modal$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79644__$1_map__79645_map__79645__$1_p__79643$$,$APP.$cljs$cst$4550$modal$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.edit"),
$cljs$cst$5793$no_selectable$$,!0,$APP.$cljs$cst$2683$action$$,function($event$jscomp$581$$){var $fields$jscomp$8_map__79646__$1$$=$APP.$cljs$core$__destructure_map$$($modal$jscomp$2$$),$key$jscomp$416$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fields$jscomp$8_map__79646__$1$$,$APP.$cljs$cst$302$key$$);$fields$jscomp$8_map__79646__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fields$jscomp$8_map__79646__$1$$,$APP.$cljs$cst$4659$fields$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$581$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$(null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($key$jscomp$416$$,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1510$x$$,$event$jscomp$581$$.clientX,$APP.$cljs$cst$1511$y$$,$event$jscomp$581$$.clientY,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$258$right$$,
$APP.$cljs$cst$4659$fields$$,$fields$jscomp$8_map__79646__$1$$,$APP.$cljs$cst$5077$initial_errors$$,$errors$jscomp$30$$,$APP.$cljs$cst$2683$action$$,"edit",$APP.$cljs$cst$2138$selected_token_set_id$$,$selected_token_set_id$$,$APP.$cljs$cst$1136$token$$,$token$jscomp$150$$],null))]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.duplicate"),$cljs$cst$5793$no_selectable$$,!0,$APP.$cljs$cst$2683$action$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$duplicate_token$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$150$$)))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.copy-name"),$cljs$cst$5793$no_selectable$$,!0,$APP.$cljs$cst$2683$action$$,function(){return $APP.$app$util$clipboard$to_clipboard$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$150$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.delete"),$cljs$cst$5793$no_selectable$$,!0,$APP.$cljs$cst$2683$action$$,function(){return $on_delete_token$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete_token$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$150$$):$on_delete_token$$($token$jscomp$150$$)}],null)],null)};
$app$main$ui$workspace$tokens$management$context_menu$allowed_shape_attributes$$=function($shapes$jscomp$228$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$into$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79647_SHARP_$$){return $APP.$app$common$types$token$shape_type__GT_attributes$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__79647_SHARP_$$),$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($p1__79647_SHARP_$$))},
$shapes$jscomp$228$$))};
$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$=function($p__79648_type$jscomp$678_with_actions$$){var $context_data__$1_map__79649__$1$$=$APP.$cljs$core$__destructure_map$$($p__79648_type$jscomp$678_with_actions$$);$p__79648_type$jscomp$678_with_actions$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($context_data__$1_map__79649__$1$$,$APP.$cljs$cst$139$type$$);var $token$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($context_data__$1_map__79649__$1$$,$APP.$cljs$cst$1136$token$$),
$selected_shapes$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($context_data__$1_map__79649__$1$$,$APP.$cljs$cst$5335$selected_shapes$$);$context_data__$1_map__79649__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data__$1_map__79649__$1$$,$cljs$cst$5783$allowed_shape_attributes$$,$app$main$ui$workspace$tokens$management$context_menu$allowed_shape_attributes$$($selected_shapes$jscomp$17$$));$p__79648_type$jscomp$678_with_actions$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$context_menu$shape_attribute_actions_map$$,
$APP.$cljs$core$truth_$$($p__79648_type$jscomp$678_with_actions$$)?$p__79648_type$jscomp$678_with_actions$$:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$151$$));return $APP.$cljs$core$truth_$$($p__79648_type$jscomp$678_with_actions$$)?$p__79648_type$jscomp$678_with_actions$$.$cljs$core$IFn$_invoke$arity$1$?$p__79648_type$jscomp$678_with_actions$$.$cljs$core$IFn$_invoke$arity$1$($context_data__$1_map__79649__$1$$):$p__79648_type$jscomp$678_with_actions$$($context_data__$1_map__79649__$1$$):
$APP.$cljs$core$PersistentVector$EMPTY$$};
$app$main$ui$workspace$tokens$management$context_menu$selection_actions$$=function($context_data$jscomp$6$$){var $attribute_actions$jscomp$1$$=$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$($context_data$jscomp$6$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($attribute_actions$jscomp$1$$,$APP.$cljs$core$seq$$($attribute_actions$jscomp$1$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],
null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$tokens$management$context_menu$default_actions$$($context_data$jscomp$6$$)]))};$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$=function($event$jscomp$582$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$582$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$582$$)};
$app$main$ui$workspace$tokens$management$context_menu$menu_entry$$=function($on_click$jscomp$49_props_79650$$){var $selected_QMARK_$jscomp$8$$=$on_click$jscomp$49_props_79650$$["selected?"],$children$jscomp$302$$=$on_click$jscomp$49_props_79650$$.children,$no_selectable$$=$on_click$jscomp$49_props_79650$$["no-selectable"],$value$jscomp$939$$=$on_click$jscomp$49_props_79650$$.value,$hint$jscomp$19$$=$on_click$jscomp$49_props_79650$$.hint,$submenu_offset$$=$on_click$jscomp$49_props_79650$$["submenu-offset"],
$title$jscomp$44$$=$on_click$jscomp$49_props_79650$$.title;$on_click$jscomp$49_props_79650$$=$on_click$jscomp$49_props_79650$$["on-click"];var $submenu_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$hovering_QMARK_$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$parent_menu_dom_element_pos_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$parent_menu_dom_element_pos$$=$APP.$cljs$core$_deref$$($parent_menu_dom_element_pos_STAR_$$),$is_submenu_outside_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$is_submenu_outside_QMARK_$$=$APP.$cljs$core$_deref$$($is_submenu_outside_STAR_$$),$hint_QMARK_$$=$APP.$cljs$core$truth_$$($hint$jscomp$19$$)?$APP.$cljs$core$seq$$($hint$jscomp$19$$):$hint$jscomp$19$$,$on_pointer_enter$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_submenu_outside_QMARK_$$)],function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$jscomp$2$$,!0);var $temp__5825__auto__$jscomp$391$$=$APP.$rumext$v2$ref_val$$($submenu_ref$jscomp$1$$);
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$391$$)?($APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$391$$,"display","block"),$APP.$cljs$core$reset_BANG_$$($is_submenu_outside_STAR_$$,$APP.$app$util$dom$is_element_outside_QMARK_$$($temp__5825__auto__$jscomp$391$$))):null}),$on_pointer_leave$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_submenu_outside_QMARK_$$)],function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$jscomp$2$$,
!1);var $temp__5825__auto__$jscomp$392$$=$APP.$rumext$v2$ref_val$$($submenu_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$392$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(50,function(){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($hovering_QMARK_$jscomp$2$$)))return null;$APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$392$$,"display","none");return $APP.$cljs$core$reset_BANG_$$($is_submenu_outside_STAR_$$,!1)}):
null}),$get_parent_menu_entry_position$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($parent_menu_dom_element$$){return $parent_menu_dom_element$$!=null?$APP.$cljs$core$reset_BANG_$$($parent_menu_dom_element_pos_STAR_$$,""+($parent_menu_dom_element$$.offsetTop??"")+"px"):null});return(0,$APP.$rumext$v2$jsxs$$)("li",{ref:$get_parent_menu_entry_position$$,"data-value":$value$jscomp$939$$,onClick:$on_click$jscomp$49_props_79650$$,onPointerEnter:$on_pointer_enter$jscomp$6$$,onPointerLeave:$on_pointer_leave$jscomp$6$$,
className:"main_ui_workspace_tokens_management_context_menu__context-menu-item "+($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$832$$=$APP.$cljs$core$not$$($no_selectable$$);return $and__5023__auto__$jscomp$832$$?$selected_QMARK_$jscomp$8$$:$and__5023__auto__$jscomp$832$$}())?"main_ui_workspace_tokens_management_context_menu__context-menu-item-selected":"")+" "+($APP.$cljs$core$not$$($no_selectable$$)&&$APP.$cljs$core$not$$($selected_QMARK_$jscomp$8$$)?"main_ui_workspace_tokens_management_context_menu__context-menu-item-unselected":
"")+" "+($APP.$cljs$core$truth_$$($hint_QMARK_$$)?"main_ui_workspace_tokens_management_context_menu__context-menu-item-hint-wrapper":""),children:[$APP.$cljs$core$truth_$$($hint$jscomp$19$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_context_menu__context-menu-item-hint",children:$hint$jscomp$19$$}):null,$APP.$cljs$core$not$$($no_selectable$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_tokens_management_context_menu__icon-wrapper"}):
null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_context_menu__item-text",children:$title$jscomp$44$$}),$APP.$cljs$core$truth_$$($children$jscomp$302$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$submenu_ref$jscomp$1$$,style:{left:""+($submenu_offset$$??"")+"px",top:$APP.$cljs$core$truth_$$($is_submenu_outside_QMARK_$$)?
"unset":$parent_menu_dom_element_pos$$},onContextMenu:$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$,className:"main_ui_workspace_tokens_management_context_menu__token-context-submenu "+($APP.$cljs$core$truth_$$($is_submenu_outside_QMARK_$$)?"main_ui_workspace_tokens_management_context_menu__token-context-submenu-top":""),children:$children$jscomp$302$$})]}):null]})};
$app$main$ui$workspace$tokens$management$context_menu$token_context_menu_tree$$=function($map__79660_props_79659_width$jscomp$204$$){$map__79660_props_79659_width$jscomp$204$$=$APP.$rumext$v2$util$wrap_props$$($map__79660_props_79659_width$jscomp$204$$);var $map__79660__$1_token$jscomp$152_token_id$jscomp$24$$=$APP.$cljs$core$__destructure_map$$($map__79660_props_79659_width$jscomp$204$$);$map__79660_props_79659_width$jscomp$204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79660__$1_token$jscomp$152_token_id$jscomp$24$$,
$APP.$cljs$cst$290$width$$);var $errors$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79660__$1_token$jscomp$152_token_id$jscomp$24$$,$APP.$cljs$cst$570$errors$$),$on_delete_token$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79660__$1_token$jscomp$152_token_id$jscomp$24$$,$cljs$cst$5792$on_delete_token$$),$objects$jscomp$802$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$180$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);
$map__79660__$1_token$jscomp$152_token_id$jscomp$24$$=$APP.$cljs$cst$2644$token_id$$.$cljs$core$IFn$_invoke$arity$1$($map__79660__$1_token$jscomp$152_token_id$jscomp$24$$);$map__79660__$1_token$jscomp$152_token_id$jscomp$24$$=$APP.$rumext$v2$deref$$($app$main$refs$workspace_token_in_selected_set$$($map__79660__$1_token$jscomp$152_token_id$jscomp$24$$));var $token_type$jscomp$16$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__79660__$1_token$jscomp$152_token_id$jscomp$24$$),$selected_token_set_id$jscomp$1$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$selected_shapes$jscomp$19$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$180$$),$APP.$rumext$v2$adapt$$($objects$jscomp$802$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$802$$)),$selected$jscomp$180$$)}),
$is_selected_inside_layout$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_type$jscomp$16$$),$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$19$$),$APP.$rumext$v2$adapt$$($objects$jscomp$802$$)],function(){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1980$dimensions$$,null,$APP.$cljs$cst$1983$spacing$$,null],null),null),$token_type$jscomp$16$$)?
$APP.$cljs$core$some$$(function($p1__79658_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$802$$,$p1__79658_SHARP_$$)},$selected_shapes$jscomp$19$$):null});return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_management_context_menu__context-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$menu_tree$$,{"submenu-offset":$map__79660_props_79659_width$jscomp$204$$,token:$map__79660__$1_token$jscomp$152_token_id$jscomp$24$$,
errors:$errors$jscomp$32$$,"selected-token-set-id":$selected_token_set_id$jscomp$1$$,"selected-shapes":$selected_shapes$jscomp$19$$,"is-selected-inside-layout":$is_selected_inside_layout$jscomp$1$$,"on-delete-token":$on_delete_token$jscomp$1$$})})};
$app$main$ui$workspace$tokens$management$context_menu$token_context_menu$$=function($map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$){$map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$=$APP.$rumext$v2$util$wrap_props$$($map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$);$map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$=$APP.$cljs$core$__destructure_map$$($map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$);$map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$,$cljs$cst$5792$on_delete_token$$);var $mdata$jscomp$23$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$context_menu$tokens_menu_ref$$),$is_open_QMARK_$jscomp$2$$=$APP.$cljs$core$boolean$0$$($mdata$jscomp$23$$),$width$jscomp$205$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$dropdown_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(),$dropdown_direction_STAR_$jscomp$1$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("down"),$dropdown_direction$jscomp$1$$=$APP.$cljs$core$_deref$$($dropdown_direction_STAR_$jscomp$1$$),$dropdown_direction_change_STAR_$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(0),$top$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$23$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1511$y$$],null))+5,$left$jscomp$36$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$23$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1510$x$$],null))+5,$container$jscomp$93$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5795$popup$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$2$$)],function(){var $temp__5825__auto__$jscomp$393$$=
$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$393$$)?$APP.$cljs$core$reset_BANG_$$($width$jscomp$205$$,$temp__5825__auto__$jscomp$393$$.offsetWidth):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$2$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,
$is_open_QMARK_$jscomp$2$$)?($APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$1$$,"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$1$$,0)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($dropdown_ref$jscomp$2$$)],function(){var $dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$2$$),$and__5023__auto__$jscomp$inline_8986$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$1$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8986$$?$dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$inline_8986$$)?($dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$=$APP.$app$util$dom$is_element_outside_QMARK_$$($dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$),$APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$1$$,
$dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$?"up":"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$1$$,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$1$$)+1)):null});return $is_open_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$portal$$)($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$is_open_QMARK_$jscomp$2$$,"on-close":function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$(null))},
children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"tokens-context-menu-for-token",ref:$dropdown_ref$jscomp$2$$,"data-direction":$dropdown_direction$jscomp$1$$,style:{"--bottom":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction$jscomp$1$$,"up")?"40px":"unset","--top":""+($top$jscomp$18$$??"")+"px",left:""+($left$jscomp$36$$??"")+"px"},onContextMenu:$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$,className:"main_ui_workspace_tokens_management_context_menu__token-context-menu",
children:$APP.$cljs$core$truth_$$($mdata$jscomp$23$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$context_menu$token_context_menu_tree$$,$APP.$rumext$v2$util$map__GT_obj$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($mdata$jscomp$23$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_deref$$($width$jscomp$205$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5792$on_delete_token$$,$map__79662_map__79662__$1_on_delete_token$jscomp$2_props_79661$$])))):
null})}),$container$jscomp$93$$):null};
$app$main$ui$ds$layers$layer_button$layer_button_STAR_$$=function($props_79642$$){var $expanded$jscomp$7$$=void 0,$description$jscomp$18$$=void 0,$children$jscomp$303$$=void 0,$is_expandable$$=void 0,$on_toggle_expand$jscomp$1$$=void 0,$on_context_menu$jscomp$12$$=void 0,$icon$jscomp$24$$=void 0,$label$jscomp$53$$=void 0,$class$$jscomp$79$$=void 0,$props$jscomp$359$$=void 0;({expanded:$expanded$jscomp$7$$,description:$description$jscomp$18$$,children:$children$jscomp$303$$,isExpandable:$is_expandable$$,
onToggleExpand:$on_toggle_expand$jscomp$1$$,onContextMenu:$on_context_menu$jscomp$12$$,icon:$icon$jscomp$24$$,label:$label$jscomp$53$$,className:$class$$jscomp$79$$,...$props$jscomp$359$$}=$props_79642$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_layers_layer_button__layer-button-wrapper",children:[(0,$APP.$rumext$v2$create_element$$)("button",{...$props$jscomp$359$$,className:($class$$jscomp$79$$??"")+" main_ui_ds_layers_layer_button__layer-button "+($APP.$cljs$core$truth_$$($expanded$jscomp$7$$)?
"main_ui_ds_layers_layer_button__layer-button-expanded":""),type:"button",onClick:$on_toggle_expand$jscomp$1$$,onContextMenu:$on_context_menu$jscomp$12$$},(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_layers_layer_button__layer-button-content",children:[$APP.$cljs$core$truth_$$($is_expandable$$)?$APP.$cljs$core$truth_$$($expanded$jscomp$7$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_ds_layers_layer_button__folder-node-icon"}):
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_ds_layers_layer_button__folder-node-icon"}):null,$APP.$cljs$core$truth_$$($icon$jscomp$24$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$24$$,className:"main_ui_ds_layers_layer_button__layer-button-icon"}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layers_layer_button__layer-button-name",children:$label$jscomp$53$$}),
$APP.$cljs$core$truth_$$($description$jscomp$18$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layers_layer_button__layer-button-description",children:$description$jscomp$18$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layers_layer_button__layer-button-quantity"})]})),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_layers_layer_button__layer-button-actions",children:$children$jscomp$303$$})]})};
$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$=function($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$){$JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$);
var $JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$,$APP.$cljs$cst$4605$resolved_value$$);$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$)?
$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$):$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$)?($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$)?
$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$.to("hex").toString():null,$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$.isHex())?$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$=1:($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$=$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$.getAttribute("alpha"),
$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$)?$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$:1),$JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$,$APP.$cljs$cst$1734$opacity$$,$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$],null)):$JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=
null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$),$APP.$cljs$cst$1298$color$$):
$JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$)?($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=$APP.$app$main$data$tinycolor$valid_color$$($JSCompiler_inline_result$jscomp$inline_13585_or__5025__auto__$jscomp$inline_13586_resolved_value$jscomp$5$$),$JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=
$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$)?$APP.$cljs$core$truth_$$($APP.$app$main$data$tinycolor$alpha$$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1298$color$$,$APP.$app$main$data$tinycolor$__GT_hex_string$$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$),$APP.$cljs$cst$1734$opacity$$,$APP.$app$main$data$tinycolor$alpha$$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$)],
null):$APP.$app$main$data$tinycolor$__GT_hex_string$$($JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$):null):$JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$=null;return $JSCompiler_temp$jscomp$10950_JSCompiler_temp$jscomp$10951_JSCompiler_temp$jscomp$11032_JSCompiler_temp_const$jscomp$inline_13584_map__79666__$1_p__79665_temp__5825__auto__$jscomp$inline_13590$$};
$app$main$ui$ds$foundations$utilities$token$token_status$token_status_icon_STAR_$$=function($icon_id$jscomp$6_props_79664$$){var $class$$jscomp$80_or__5025__auto__$jscomp$inline_8988$$,$props$jscomp$360$$;({iconId:$icon_id$jscomp$6_props_79664$$,className:$class$$jscomp$80_or__5025__auto__$jscomp$inline_8988$$,...$props$jscomp$360$$}=$icon_id$jscomp$6_props_79664$$);return(0,$APP.$rumext$v2$create_element$$)("svg",{...$props$jscomp$360$$,className:""+(($APP.$cljs$core$truth_$$($class$$jscomp$80_or__5025__auto__$jscomp$inline_8988$$)?
$class$$jscomp$80_or__5025__auto__$jscomp$inline_8988$$:"")??"")+" main_ui_ds_foundations_utilities_token_token_status__token-icon",width:"14px",height:"14px"},(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-"+($icon_id$jscomp$6_props_79664$$??""),width:"14px",height:"14px",x:0,y:0}))};
$app$main$ui$workspace$tokens$management$token_pill$partially_applied_attr$$=function($app_token_keys_filtered_keys$$,$is_applied$$,$map__79670__$1_p__79669$$){$map__79670__$1_p__79669$$=$APP.$cljs$core$__destructure_map$$($map__79670__$1_p__79669$$);var $attributes$jscomp$84$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79670__$1_p__79669$$,$APP.$cljs$cst$1993$attributes$$),$all_attributes$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79670__$1_p__79669$$,
$APP.$cljs$cst$4655$all_attributes$$);$app_token_keys_filtered_keys$$=$APP.$cljs$core$truth_$$($all_attributes$jscomp$1$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79667_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($all_attributes$jscomp$1$$,$p1__79667_SHARP_$$)},$app_token_keys_filtered_keys$$):$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79668_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($attributes$jscomp$84$$,$p1__79668_SHARP_$$)},
$app_token_keys_filtered_keys$$);return $APP.$cljs$core$truth_$$($is_applied$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$token_pill$attribute_dictionary$$,$app_token_keys_filtered_keys$$)):null};
$app$main$ui$workspace$tokens$management$token_pill$translate_and_format$$=function($grouped_values$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__79671_values$jscomp$102$$){var $category$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79671_values$jscomp$102$$,0,null);$p__79671_values$jscomp$102$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79671_values$jscomp$102$$,
1,null);var $JSCompiler_inline_result$jscomp$1844_fexpr__79675$jscomp$inline_8990$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null);$JSCompiler_inline_result$jscomp$1844_fexpr__79675$jscomp$inline_8990$$=$JSCompiler_inline_result$jscomp$1844_fexpr__79675$jscomp$inline_8990$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1844_fexpr__79675$jscomp$inline_8990$$.$cljs$core$IFn$_invoke$arity$1$($category$jscomp$2$$):
$JSCompiler_inline_result$jscomp$1844_fexpr__79675$jscomp$inline_8990$$($category$jscomp$2$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1844_fexpr__79675$jscomp$inline_8990$$)?"- "+(($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($category$jscomp$2$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($category$jscomp$2$$))??
""):"- "+(($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($category$jscomp$2$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($category$jscomp$2$$))??"")+": "+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$token_pill$attribute_dictionary$$,
$p__79671_values$jscomp$102$$))??"")+"."},$grouped_values$$))};$app$main$ui$workspace$tokens$management$token_pill$contains_reference_value_QMARK_$$=function($match$jscomp$58_text$jscomp$145$$,$active_tokens$jscomp$8$$){$match$jscomp$58_text$jscomp$145$$=$APP.$cljs$core$second$$($APP.$cljs$core$re_find$$(/\{([^}]+)\}/,$match$jscomp$58_text$jscomp$145$$));return $APP.$cljs$core$contains_QMARK_$$($active_tokens$jscomp$8$$,$match$jscomp$58_text$jscomp$145$$)};
$app$main$ui$workspace$tokens$management$token_pill$applied_all_attributes_QMARK_$$=function($ids_by_attributes$jscomp$2_token$jscomp$155$$,$selected_shapes$jscomp$20_shape_ids$jscomp$117$$,$attributes$jscomp$85$$){$ids_by_attributes$jscomp$2_token$jscomp$155$$=$app$common$files$tokens$shapes_ids_by_applied_attributes$$($ids_by_attributes$jscomp$2_token$jscomp$155$$,$selected_shapes$jscomp$20_shape_ids$jscomp$117$$,$attributes$jscomp$85$$);$selected_shapes$jscomp$20_shape_ids$jscomp$117$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$app$main$ui$workspace$tokens$management$token_pill$xf_COLON_map_id$$,$selected_shapes$jscomp$20_shape_ids$jscomp$117$$);return $app$common$files$tokens$shapes_applied_all_QMARK_$$($ids_by_attributes$jscomp$2_token$jscomp$155$$,$selected_shapes$jscomp$20_shape_ids$jscomp$117$$,$attributes$jscomp$85$$)};
$app$main$ui$workspace$tokens$management$token_pill$attributes_match_selection_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($selected_shapes$jscomp$21$$,$attrs$jscomp$183$$,$map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$){$map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$=$APP.$cljs$core$__destructure_map$$($map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$);$map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$,$cljs$cst$5799$selected_inside_layout_QMARK_$$);$map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$=$APP.$cljs$core$truth_$$($map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$)?$APP.$clojure$set$subset_QMARK_$$($APP.$app$common$types$token$spacing_margin_keys$$,$attrs$jscomp$183$$):$map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$;
return $APP.$cljs$core$truth_$$($map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$)?$map__79683__$1_or__5025__auto__$jscomp$1238_p__79682_selected_inside_layout_QMARK_$$:$APP.$cljs$core$some$$(function($is_layout$jscomp$inline_13594_shape$jscomp$1037$$){var $token_type$jscomp$inline_13593$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($is_layout$jscomp$inline_13594_shape$jscomp$1037$$);$is_layout$jscomp$inline_13594_shape$jscomp$1037$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($is_layout$jscomp$inline_13594_shape$jscomp$1037$$);
return $APP.$app$common$data$not_empty_QMARK_$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$183$$,$APP.$app$common$types$token$shape_type__GT_attributes$$($token_type$jscomp$inline_13593$$,$is_layout$jscomp$inline_13594_shape$jscomp$1037$$)))},$selected_shapes$jscomp$21$$)};
$app$main$ui$workspace$tokens$management$token_tree$token_tree_STAR_$$=function($ordered_nodes_permissions$jscomp$36_props_79700$$){var $active_theme_tokens$jscomp$2$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.activeThemeTokens,$folded_token_paths$jscomp$1$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.foldedTokenPaths,$selected_shapes$jscomp$24$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.selectedShapes,$is_selected_inside_layout$jscomp$4$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.isSelectedInsideLayout,
$on_token_pill_click$jscomp$4$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.onTokenPillClick,$selected_token_set_id$jscomp$3$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.selectedTokenSetId,$type$jscomp$683$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.type,$on_pill_context_menu$jscomp$1$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.onPillContextMenu,$on_node_context_menu$jscomp$1$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.onNodeContextMenu,$tokens_lib$jscomp$40$$=
$ordered_nodes_permissions$jscomp$36_props_79700$$.tokensLib,$tokens$jscomp$55$$=$ordered_nodes_permissions$jscomp$36_props_79700$$.tokens,$raw_tree$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$55$$)],function(){return $app$common$path_names$build_tree_root$$($tokens$jscomp$55$$)});$ordered_nodes_permissions$jscomp$36_props_79700$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);var $can_edit_QMARK_$jscomp$4$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($ordered_nodes_permissions$jscomp$36_props_79700$$),
$on_node_context_menu__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($on_node_context_menu$jscomp$1$$)],function($event$jscomp$587$$,$node$jscomp$437$$){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$4$$)?$on_node_context_menu$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_node_context_menu$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$587$$,$node$jscomp$437$$):$on_node_context_menu$jscomp$1$$($event$jscomp$587$$,
$node$jscomp$437$$):null});$ordered_nodes_permissions$jscomp$36_props_79700$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($raw_tree$$)],function(){var $groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($g$jscomp$163_p__79704$$,$item$jscomp$138$$){var $l$jscomp$111$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$163_p__79704$$,0,null);$g$jscomp$163_p__79704$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$163_p__79704$$,
1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$138$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l$jscomp$111$$,$item$jscomp$138$$),$g$jscomp$163_p__79704$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l$jscomp$111$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$163_p__79704$$,
$item$jscomp$138$$)],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$raw_tree$$),$leafs$jscomp$1_sorted_leafs$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$,0,null);$groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$,
1,null);$leafs$jscomp$1_sorted_leafs$jscomp$1$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$leafs$jscomp$1_sorted_leafs$jscomp$1$$);$groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($leafs$jscomp$1_sorted_leafs$jscomp$1$$,
$groups$jscomp$18_sorted_groups$jscomp$1_vec__79701$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_token_tree__token-tree-wrapper",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$193$$,$JSCompiler_temp$jscomp$1852_node$jscomp$438$$){var $JSCompiler_temp_const$jscomp$1850$$=$out_arr__44124__auto__$jscomp$193$$.push;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1852_node$jscomp$438$$))){var $token$jscomp$inline_9002$$=
$APP.$app$common$types$tokens_lib$get_token$$($tokens_lib$jscomp$40$$,$selected_token_set_id$jscomp$3$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1852_node$jscomp$438$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1999$leaf$$,$APP.$cljs$cst$266$id$$],null)));$JSCompiler_temp$jscomp$1852_node$jscomp$438$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_pill$token_pill_STAR_$$,
{token:$token$jscomp$inline_9002$$,selectedShapes:$selected_shapes$jscomp$24$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$4$$,activeThemeTokens:$active_theme_tokens$jscomp$2$$,onClick:$on_token_pill_click$jscomp$4$$,onContextMenu:$on_pill_context_menu$jscomp$1$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1852_node$jscomp$438$$)))}else $JSCompiler_temp$jscomp$1852_node$jscomp$438$$=(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_workspace_tokens_management_token_tree__node-parent",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$,{foldedTokenPaths:$folded_token_paths$jscomp$1$$,tokensLib:$tokens_lib$jscomp$40$$,onPillContextMenu:$on_pill_context_menu$jscomp$1$$,onTokenPillClick:$on_token_pill_click$jscomp$4$$,onNodeContextMenu:$on_node_context_menu__$1$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$4$$,type:$type$jscomp$683$$,activeThemeTokens:$active_theme_tokens$jscomp$2$$,
selectedShapes:$selected_shapes$jscomp$24$$,selectedTokenSetId:$selected_token_set_id$jscomp$3$$,node:$JSCompiler_temp$jscomp$1852_node$jscomp$438$$})},$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1852_node$jscomp$438$$));$JSCompiler_temp_const$jscomp$1850$$.call($out_arr__44124__auto__$jscomp$193$$,$JSCompiler_temp$jscomp$1852_node$jscomp$438$$);return $out_arr__44124__auto__$jscomp$193$$},[],$ordered_nodes_permissions$jscomp$36_props_79700$$)})};
$app$main$ui$workspace$tokens$management$group$token_section_icon$$=function($type$jscomp$684$$){switch($type$jscomp$684$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$684$$.$fqn$:null){case "border-radius":return"corner-radius";case "color":return"drop";case "boolean":return"boolean-difference";case "font-family":return"text-font-family";case "font-size":return"text-font-size";case "letter-spacing":return"text-letterspacing";case "text-case":return"text-mixed";case "text-decoration":return"text-underlined";
case "font-weight":return"text-font-weight";case "typography":return"text-typography";case "opacity":return"percentage";case "number":return"number";case "rotation":return"rotation";case "spacing":return"padding-extended";case "string":return"text-mixed";case "stroke-width":return"stroke-size";case "dimensions":return"expand";case "sizing":return"expand";case "shadow":return"drop-shadow";default:return"add"}};
$app$main$ui$workspace$tokens$management$group$token_group_STAR_$$=function($folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$){var $active_theme_tokens$jscomp$3$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.activeThemeTokens,$selected_shapes$jscomp$25$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.selectedShapes,$is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.isSelectedInsideLayout,
$selected_token_set_id$jscomp$4$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.selectedTokenSetId,$type$jscomp$685$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.type,$selected_ids$jscomp$10$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.selectedIds,$tokens_lib$jscomp$41$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.tokensLib,$tokens$jscomp$56$$=$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$.tokens;
$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$type$jscomp$685$$);$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$=$APP.$cljs$core$__destructure_map$$($folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$);var $modal$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$,
$APP.$cljs$cst$4550$modal$$),$title$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$,$APP.$cljs$cst$939$title$$);$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$group$ref_COLON_folded_token_paths$$);var $is_type_unfolded_unfolded_token_types_state$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$group$ref_COLON_unfolded_token_types$$),
$can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$file$$);$is_type_unfolded_unfolded_token_types_state$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($is_type_unfolded_unfolded_token_types_state$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2643$set_id$$.$cljs$core$IFn$_invoke$arity$1$($is_type_unfolded_unfolded_token_types_state$$),
$selected_token_set_id$jscomp$4$$)&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($APP.$cljs$cst$925$types$$.$cljs$core$IFn$_invoke$arity$1$($is_type_unfolded_unfolded_token_types_state$$)),$type$jscomp$685$$);$can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$);var $edition$jscomp$8_tokens__$1$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$objects$jscomp$803_on_pill_context_menu$jscomp$2$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$not_editing_QMARK_$jscomp$1$$=$APP.$cljs$core$empty_QMARK_$$($can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$)&&!($edition$jscomp$8_tokens__$1$jscomp$5$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$803_on_pill_context_menu$jscomp$2$$,$edition$jscomp$8_tokens__$1$jscomp$5$$))));
$can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);$is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$,!1);$edition$jscomp$8_tokens__$1$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$56$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,
$tokens$jscomp$56$$))});var $expandable_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$($edition$jscomp$8_tokens__$1$jscomp$5$$),!1);$objects$jscomp$803_on_pill_context_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_theme_tokens$jscomp$3$$)],function($event$jscomp$588$$,$token$jscomp$159$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$588$$);var $resolved_token$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_tokens$jscomp$3$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$159$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1136$token$$,$APP.$cljs$cst$1676$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$588$$),$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$18$$),
$APP.$cljs$cst$2644$token_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$159$$)],null)))});var $on_node_context_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$589$$,$node$jscomp$439$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$589$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3766$node$$,$node$jscomp$439$$,$APP.$cljs$cst$139$type$$,$type$jscomp$685$$,$APP.$cljs$cst$1676$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$589$$)],null)))}),$on_toggle_open_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$685$$),$APP.$rumext$v2$adapt$$($expandable_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($expandable_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$toggle_token_type$$($type$jscomp$685$$)):
null}),$on_popover_open_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$685$$),$APP.$rumext$v2$adapt$$($title$jscomp$48$$),$APP.$rumext$v2$adapt$$($modal$jscomp$3$$)],function($JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$){$APP.$app$util$dom$stop_propagation$$($JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$);var $JSCompiler_temp_const$jscomp$1853$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;
$JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$);$JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$=$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($modal$jscomp$3$$),new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$),
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$),$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$4659$fields$$,$APP.$cljs$cst$4659$fields$$.$cljs$core$IFn$_invoke$arity$1$($modal$jscomp$3$$),$APP.$cljs$cst$939$title$$,$title$jscomp$48$$,$APP.$cljs$cst$2683$action$$,"create",$cljs$cst$5428$token_type$$,$type$jscomp$685$$],null));return $JSCompiler_temp_const$jscomp$1853$$.call($APP.$app$main$store$emit_BANG_$$,
$JSCompiler_inline_result$jscomp$1855_event$jscomp$590_pos$jscomp$inline_9004$$)}),$on_token_pill_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($not_editing_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected_ids$jscomp$10$$),$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$41$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$4$$)],function($event$jscomp$591$$,$token$jscomp$160_token__$1$jscomp$1$$){$token$jscomp$160_token__$1$jscomp$1$$=$APP.$app$common$types$tokens_lib$get_token$$($tokens_lib$jscomp$41$$,
$selected_token_set_id$jscomp$4$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$160_token__$1$jscomp$1$$));$APP.$app$util$dom$stop_propagation$$($event$jscomp$591$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$160_token__$1$jscomp$1$$),$APP.$cljs$cst$1978$number$$)?$not_editing_QMARK_$jscomp$1$$&&$APP.$cljs$core$seq$$($selected_shapes$jscomp$25$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$160_token__$1$jscomp$1$$,$APP.$cljs$cst$4641$shape_ids$$,$selected_ids$jscomp$10$$],null))):$APP.$cljs$core$seq$$($selected_shapes$jscomp$25$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.error-text-edition"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,
$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$2353$timeout$$,3E3],null))):null:null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"section-"+($APP.$cljs$core$name$$($type$jscomp$685$$)??""),className:"main_ui_workspace_tokens_management_group__token-section-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$layers$layer_button$layer_button_STAR_$$,{"aria-expanded":$is_type_unfolded_unfolded_token_types_state$$,isExpandable:$expandable_QMARK_$$,label:$title$jscomp$48$$,children:$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{id:["add-token-button-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($title$jscomp$48$$)].join(""),
icon:"add","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.add-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$title$jscomp$48$$])),variant:"ghost",onClick:$on_popover_open_click$$,className:"main_ui_workspace_tokens_management_group__token-section-icon"}):null,onToggleExpand:$on_toggle_open_click$$,"aria-controls":"token-tree-"+($APP.$cljs$core$name$$($type$jscomp$685$$)??""),expanded:$is_type_unfolded_unfolded_token_types_state$$,
description:$APP.$cljs$core$truth_$$($expandable_QMARK_$$)?""+($APP.$cljs$core$count$$($edition$jscomp$8_tokens__$1$jscomp$5$$)??""):null,icon:$app$main$ui$workspace$tokens$management$group$token_section_icon$$($type$jscomp$685$$)}),$is_type_unfolded_unfolded_token_types_state$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_tree$token_tree_STAR_$$,{foldedTokenPaths:$folded_token_paths$jscomp$2_map__79711_map__79711__$1_props_79710$$,tokensLib:$tokens_lib$jscomp$41$$,onPillContextMenu:$objects$jscomp$803_on_pill_context_menu$jscomp$2$$,
onTokenPillClick:$on_token_pill_click$jscomp$5$$,onNodeContextMenu:$on_node_context_menu$jscomp$2$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$,type:$type$jscomp$685$$,activeThemeTokens:$active_theme_tokens$jscomp$3$$,selectedShapes:$selected_shapes$jscomp$25$$,selectedTokenSetId:$selected_token_set_id$jscomp$4$$,tokens:$edition$jscomp$8_tokens__$1$jscomp$5$$}):null]})};
$app$main$ui$workspace$tokens$management$node_context_menu$prevent_default$$=function($event$jscomp$592$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$592$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$592$$)};
$app$main$ui$workspace$tokens$management$node_context_menu$token_node_context_menu_STAR_$$=function($dropdown_action_props_79679$$){var $on_delete_node$$=$dropdown_action_props_79679$$.onDeleteNode,$on_duplicate_node$$=$dropdown_action_props_79679$$.onDuplicateNode,$on_rename_node$$=$dropdown_action_props_79679$$.onRenameNode,$mdata$jscomp$24$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$node_context_menu$tokens_node_menu_ref$$),$is_open_QMARK_$jscomp$3$$=$APP.$cljs$core$boolean$0$$($mdata$jscomp$24$$),
$dropdown_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)();$dropdown_action_props_79679$$=(0,$APP.$rumext$v2$use_ref$$)();var $dropdown_direction_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("down"),$dropdown_direction$jscomp$2$$=$APP.$cljs$core$_deref$$($dropdown_direction_STAR_$jscomp$2$$),$dropdown_direction_change_STAR_$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(0),$top$jscomp$19$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1511$y$$],null))+5,$left$jscomp$37$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1510$x$$],null))+5,$container$jscomp$94$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5795$popup$$),$rename_node$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$24$$),$APP.$rumext$v2$adapt$$($on_rename_node$$)],function(){var $node$jscomp$440$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$3766$node$$),$type$jscomp$686$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$truth_$$($node$jscomp$440$$)?$on_rename_node$$.$cljs$core$IFn$_invoke$arity$2$?
$on_rename_node$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$440$$,$type$jscomp$686$$):$on_rename_node$$($node$jscomp$440$$,$type$jscomp$686$$):null}),$duplicate_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$24$$),$APP.$rumext$v2$adapt$$($on_duplicate_node$$)],function(){var $node$jscomp$441$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$3766$node$$),$type$jscomp$687$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,
$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$truth_$$($node$jscomp$441$$)?$on_duplicate_node$$.$cljs$core$IFn$_invoke$arity$2$?$on_duplicate_node$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$441$$,$type$jscomp$687$$):$on_duplicate_node$$($node$jscomp$441$$,$type$jscomp$687$$):null}),$delete_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$24$$)],function(){var $node$jscomp$442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,
$APP.$cljs$cst$3766$node$$),$type$jscomp$688$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$truth_$$($node$jscomp$442$$)?$on_delete_node$$.$cljs$core$IFn$_invoke$arity$2$?$on_delete_node$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$442$$,$type$jscomp$688$$):$on_delete_node$$($node$jscomp$442$$,$type$jscomp$688$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$3$$)],
function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$is_open_QMARK_$jscomp$3$$)?($APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$2$$,"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$2$$,0)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$3$$),
$APP.$rumext$v2$adapt$$($dropdown_ref$jscomp$3$$),$APP.$rumext$v2$adapt$$($dropdown_action_props_79679$$)],function(){var $dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$3$$),$and__5023__auto__$jscomp$inline_9006$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$2$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9006$$?$dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$:
$and__5023__auto__$jscomp$inline_9006$$)?($dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$=$APP.$app$util$dom$is_element_outside_QMARK_$$($dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$),$APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$2$$,$dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$?"up":"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$2$$,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$2$$)+1)):null});return $is_open_QMARK_$jscomp$3$$?
(0,$APP.$rumext$v2$portal$$)($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$is_open_QMARK_$jscomp$3$$,"on-close":function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$(null))},children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"tokens-context-menu-for-token-node",ref:$dropdown_ref$jscomp$3$$,"data-direction":$dropdown_direction$jscomp$2$$,style:{"--bottom":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction$jscomp$2$$,
"up")?"40px":"unset","--top":""+($top$jscomp$19$$??"")+"px",left:""+($left$jscomp$37$$??"")+"px"},onContextMenu:$app$main$ui$workspace$tokens$management$node_context_menu$prevent_default$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu",children:$APP.$cljs$core$truth_$$($mdata$jscomp$24$$)?(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-list",children:[(0,$APP.$rumext$v2$jsx$$)("li",
{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-listitem",children:(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",onClick:$rename_node$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-listitem",children:(0,$APP.$rumext$v2$jsx$$)("button",
{type:"button",onClick:$duplicate_node$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.duplicate")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-listitem",children:(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",onClick:$delete_node$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")})})]}):null})}),$container$jscomp$94$$):null};
$app$main$ui$workspace$tokens$management$selected_set_info_STAR_$$=function($props_79735$$){var $selected_token_set_id$jscomp$5$$=$props_79735$$.selectedTokenSetId,$tokens_lib$jscomp$42$$=$props_79735$$.tokensLib,$selected_token_set$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$42$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$5$$)],function(){return $APP.$cljs$core$truth_$$($selected_token_set_id$jscomp$5$$)?$tokens_lib$jscomp$42$$==
null?null:$APP.$app$common$types$tokens_lib$get_set$$($tokens_lib$jscomp$42$$,$selected_token_set_id$jscomp$5$$):null}),$active_token_sets_names$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$42$$)],function(){return $tokens_lib$jscomp$42$$==null?null:$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$42$$)}),$token_set_active_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_token_sets_names$$)],
function($name$jscomp$464$$){return $APP.$cljs$core$contains_QMARK_$$($active_token_sets_names$$,$name$jscomp$464$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management__sets-header-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"headline-small",className:"main_ui_workspace_tokens_management__sets-header","data-testid":"active-token-set-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.tokens-section-title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$get_name$$($selected_token_set$$)]))}),$selected_token_set_id$jscomp$5$$!=null&&$APP.$cljs$core$not$$(function(){var $G__79738$$=$APP.$app$common$types$tokens_lib$get_name$$($selected_token_set$$);return $token_set_active_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$token_set_active_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__79738$$):$token_set_active_QMARK_$$($G__79738$$)}())?(0,$APP.$rumext$v2$jsx$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.inactive-set-description"),className:"main_ui_workspace_tokens_management__sets-header-status",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_workspace_tokens_management__sets-header-status-icon",iconId:"eye-off"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_management__sets-header-status-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.inactive-set")})]})}):null]})};
$app$main$ui$workspace$tokens$management$tokens_section_STAR_$$=function($empty_group_props_79742$$){function $on_duplicate_node$jscomp$1$$($node$jscomp$449$$,$type$jscomp$697$$,$new_node_name$jscomp$6$$){var $G__79759$jscomp$inline_9010_tokens_in_path_ids$jscomp$4$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$449$$);$G__79759$jscomp$inline_9010_tokens_in_path_ids$jscomp$4$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$697$$,
$G__79759$jscomp$inline_9010_tokens_in_path_ids$jscomp$4$$):$filter_tokens_by_path_ids$$($type$jscomp$697$$,$G__79759$jscomp$inline_9010_tokens_in_path_ids$jscomp$4$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$bulk_create_tokens$$($selected_token_set_id$jscomp$6$$,$G__79759$jscomp$inline_9010_tokens_in_path_ids$jscomp$4$$,
$type$jscomp$697$$,$node$jscomp$449$$,$new_node_name$jscomp$6$$)]))}var $resolved_active_tokens$jscomp$1$$=$empty_group_props_79742$$.resolvedActiveTokens,$active_tokens$jscomp$9$$=$empty_group_props_79742$$.activeTokens,$tokens_lib$jscomp$43$$=$empty_group_props_79742$$.tokensLib,$objects$jscomp$804$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$181$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),$selected_shapes$jscomp$26$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$181$$),
$APP.$rumext$v2$adapt$$($objects$jscomp$804$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$804$$)),$selected$jscomp$181$$)}),$is_selected_inside_layout$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$26$$),$APP.$rumext$v2$adapt$$($objects$jscomp$804$$)],
function(){return $APP.$cljs$core$some$$(function($p1__79739_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$804$$,$p1__79739_SHARP_$$)},$selected_shapes$jscomp$26$$)}),$selected_token_set_id$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$selected_token_set_tokens$$=$APP.$cljs$core$truth_$$($selected_token_set_id$jscomp$6$$)?$tokens_lib$jscomp$43$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$43$$,
$selected_token_set_id$jscomp$6$$):null,$tokens$jscomp$57$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$)],function(){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$active_tokens$jscomp$9$$,$selected_token_set_tokens$$]))}),$tokens_by_type$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$57$$),
$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$)],function(){var $tokens__$1$jscomp$6$$=$APP.$cljs$core$reduce_kv$$(function($tokens__$1$jscomp$7$$,$k$jscomp$696$$){return $APP.$cljs$core$contains_QMARK_$$($selected_token_set_tokens$$,$k$jscomp$696$$)?$tokens__$1$jscomp$7$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens__$1$jscomp$7$$,$k$jscomp$696$$)},$tokens$jscomp$57$$,$tokens$jscomp$57$$);return $app$common$types$tokens_lib$group_by_type$$($tokens__$1$jscomp$6$$)}),$filled_group_vec__79743$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_by_type$jscomp$1$$)],function(){a:{var $G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1191$token_shadow$$)?$APP.$app$main$data$workspace$tokens$application$token_properties$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,
$APP.$cljs$cst$1654$shadow$$),$G__79760$jscomp$inline_13630_G__79763$jscomp$inline_13633_a$jscomp$inline_14663_empty$jscomp$inline_13625$$=[];var $G__79761$jscomp$inline_13631_G__79764$jscomp$inline_13634_JSCompiler_inline_result$jscomp$11033_a$jscomp$inline_14660_filled$jscomp$inline_13626$$=[];for($G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$=$APP.$cljs$core$seq$$($APP.$cljs$core$keys$$($G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$));;){var $temp__5823__auto__$jscomp$inline_13628_type$jscomp$inline_13629$$=
$APP.$cljs$core$first$$($G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_13628_type$jscomp$inline_13629$$))$APP.$cljs$core$truth_$$($APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type$jscomp$1$$,$temp__5823__auto__$jscomp$inline_13628_type$jscomp$inline_13629$$)))?($G__79761$jscomp$inline_13631_G__79764$jscomp$inline_13634_JSCompiler_inline_result$jscomp$11033_a$jscomp$inline_14660_filled$jscomp$inline_13626$$.push($temp__5823__auto__$jscomp$inline_13628_type$jscomp$inline_13629$$),
$G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$=$APP.$cljs$core$rest$$($G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$)):($G__79760$jscomp$inline_13630_G__79763$jscomp$inline_13633_a$jscomp$inline_14663_empty$jscomp$inline_13625$$.push($temp__5823__auto__$jscomp$inline_13628_type$jscomp$inline_13629$$),$G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$=
$APP.$cljs$core$rest$$($G__79762$jscomp$inline_13632_G__79765$jscomp$inline_13635_all_types$jscomp$inline_13624_types$jscomp$inline_13627$$));else{$G__79761$jscomp$inline_13631_G__79764$jscomp$inline_13634_JSCompiler_inline_result$jscomp$11033_a$jscomp$inline_14660_filled$jscomp$inline_13626$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$seq$$($app$util$array$sort_BANG_$$($G__79760$jscomp$inline_13630_G__79763$jscomp$inline_13633_a$jscomp$inline_14663_empty$jscomp$inline_13625$$)),
$APP.$cljs$core$seq$$($app$util$array$sort_BANG_$$($G__79761$jscomp$inline_13631_G__79764$jscomp$inline_13634_JSCompiler_inline_result$jscomp$11033_a$jscomp$inline_14660_filled$jscomp$inline_13626$$))],null);break a}}$G__79761$jscomp$inline_13631_G__79764$jscomp$inline_13634_JSCompiler_inline_result$jscomp$11033_a$jscomp$inline_14660_filled$jscomp$inline_13626$$=void 0}return $G__79761$jscomp$inline_13631_G__79764$jscomp$inline_13634_JSCompiler_inline_result$jscomp$11033_a$jscomp$inline_14660_filled$jscomp$inline_13626$$});
$empty_group_props_79742$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filled_group_vec__79743$$,0,null);$filled_group_vec__79743$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filled_group_vec__79743$$,1,null);var $filter_tokens_by_path$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($tokens_filtered_by_type$$,$node$jscomp$443$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$161$$){var $token_path$jscomp$1$$=
$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$161$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"."]));return $APP.$cljs$core$count$$($token_path$jscomp$1$$)>0&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$161$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$443$$)),
"."].join(""))},$tokens_filtered_by_type$$)}),$filter_tokens_by_path_ids$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$)],function($type$jscomp$690$$,$path$jscomp$278$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$162_token_value$jscomp$8$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$162_token_value$jscomp$8$$,0,null);$token$jscomp$162_token_value$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$162_token_value$jscomp$8$$,
1,null);return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$162_token_value$jscomp$8$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$163_token_value$jscomp$9$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$163_token_value$jscomp$9$$,0,null);$token$jscomp$163_token_value$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$163_token_value$jscomp$9$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$163_token_value$jscomp$9$$),
$type$jscomp$690$$)&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$163_token_value$jscomp$9$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$278$$),"."].join(""))},$selected_token_set_tokens$$))}),$remaining_tokens_of_type_in_set_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($remaining_tokens_selected_token_set_tokens__$1$$,$tokens_in_path_ids$$){var $token_ids$jscomp$6$$=$APP.$cljs$core$set$$($tokens_in_path_ids$$);
$remaining_tokens_selected_token_set_tokens__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$164$$){return!$APP.$cljs$core$contains_QMARK_$$($token_ids$jscomp$6$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$164$$))},$remaining_tokens_selected_token_set_tokens__$1$$);return $APP.$cljs$core$seq$$($remaining_tokens_selected_token_set_tokens__$1$$)}),$delete_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),
$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function(){return function($path$jscomp$279_token$jscomp$165$$){var $id$jscomp$1005$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$279_token$jscomp$165$$),$type$jscomp$691$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$279_token$jscomp$165$$);$path$jscomp$279_token$jscomp$165$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$279_token$jscomp$165$$);var $remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$=
$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$);$remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$,$type$jscomp$691$$);var $G__79757$jscomp$inline_9008$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1005$$],null);$remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$=
$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$,$G__79757$jscomp$inline_9008$$):$remaining_tokens_of_type_in_set_QMARK_$$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$,$G__79757$jscomp$inline_9008$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token$$($selected_token_set_id$jscomp$6$$,
$id$jscomp$1005$$));return $APP.$cljs$core$truth_$$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($type$jscomp$691$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$279_token$jscomp$165$$)].join(""))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$($type$jscomp$691$$))}}),
$delete_node$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function(){return function($node$jscomp$444_path$jscomp$280$$,$type$jscomp$692$$){$node$jscomp$444_path$jscomp$280$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$444_path$jscomp$280$$);var $tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$=$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$),
$remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$,$type$jscomp$692$$);$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$692$$,$node$jscomp$444_path$jscomp$280$$):$filter_tokens_by_path_ids$$($type$jscomp$692$$,$node$jscomp$444_path$jscomp$280$$);
$remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$=$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$,$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$):$remaining_tokens_of_type_in_set_QMARK_$$($remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$,$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$bulk_delete_tokens$$($selected_token_set_id$jscomp$6$$,$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$));return $APP.$cljs$core$truth_$$($remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($type$jscomp$692$$),
".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$444_path$jscomp$280$$)].join(""))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$($type$jscomp$692$$))}}),$bulk_rename_tokens_in_path$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filter_tokens_by_path_ids$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function($new_path$jscomp$3_node$jscomp$445$$,
$type$jscomp$693$$,$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$){var $old_path$jscomp$3$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_path$jscomp$3_node$jscomp$445$$);$new_path$jscomp$3_node$jscomp$445$$=$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$($new_path$jscomp$3_node$jscomp$445$$,null,$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$);$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?
$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$693$$,$old_path$jscomp$3$$):$filter_tokens_by_path_ids$$($type$jscomp$693$$,$old_path$jscomp$3$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$$($selected_token_set_id$jscomp$6$$,$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$,
$type$jscomp$693$$,$old_path$jscomp$3$$,$new_path$jscomp$3_node$jscomp$445$$)]))}),$bulk_remap_tokens_in_path$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filter_tokens_by_path$$),$APP.$rumext$v2$adapt$$($filter_tokens_by_path_ids$$),$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function($node$jscomp$446$$,$type$jscomp$694$$,$new_node_name$jscomp$3$$){var $old_path$jscomp$4$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$446$$),
$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$=$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$);$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$type$jscomp$694$$);$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$=
$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$node$jscomp$446$$):$filter_tokens_by_path$$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$node$jscomp$446$$);var $tokens_in_path_ids$jscomp$3$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$694$$,
$old_path$jscomp$4$$):$filter_tokens_by_path_ids$$($type$jscomp$694$$,$old_path$jscomp$4$$),$new_node_path$$=$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$446$$,null,$new_node_name$jscomp$3$$),$new_tokens$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$166$$){var $new_token_path$jscomp$1$$=$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$446$$,$token$jscomp$166$$,$new_node_name$jscomp$3$$);
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($token$jscomp$166$$,$APP.$cljs$cst$725$name$$,$new_token_path$jscomp$1$$)},$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$),$undo_group$jscomp$48$$=$APP.$app$common$uuid$next$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($selected_token_set_id$jscomp$6$$,
$tokens_in_path_ids$jscomp$3$$,$type$jscomp$694$$,$old_path$jscomp$4$$,$new_node_path$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$48$$])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$remapping$bulk_remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$new_tokens$jscomp$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3138$undo_group$$,
$undo_group$jscomp$48$$])),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$(),$APP.$app$main$data$modal$hide$$()]))}),$on_remap_node_warning$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($bulk_remap_tokens_in_path$$),$APP.$rumext$v2$adapt$$($bulk_rename_tokens_in_path$$)],function($node$jscomp$447$$,$type$jscomp$695$$,$new_node_name$jscomp$4$$){var $remap_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5774$new_name$$,
$new_node_name$jscomp$4$$,$cljs$cst$5773$old_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$447$$),$APP.$cljs$cst$139$type$$,"node"],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5806$tokens_SLASH_remapping_confirmation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5807$remap_data$$,$remap_data$$,$cljs$cst$5808$on_remap$$,function(){return $bulk_remap_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$?$bulk_remap_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$447$$,$type$jscomp$695$$,$new_node_name$jscomp$4$$):$bulk_remap_tokens_in_path$$($node$jscomp$447$$,$type$jscomp$695$$,$new_node_name$jscomp$4$$)},$cljs$cst$5809$on_rename$$,function(){return $bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$?$bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$447$$,
$type$jscomp$695$$,$new_node_name$jscomp$4$$):$bulk_rename_tokens_in_path$$($node$jscomp$447$$,$type$jscomp$695$$,$new_node_name$jscomp$4$$)}],null))]))}),$on_rename_node$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($filter_tokens_by_path$$),$APP.$rumext$v2$adapt$$($on_remap_node_warning$$),$APP.$rumext$v2$adapt$$($bulk_rename_tokens_in_path$$)],function($node$jscomp$448$$,$type$jscomp$696$$,$new_node_name$jscomp$5$$){var $state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=
$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_data$jscomp$121$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$);$state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$);$state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$,$type$jscomp$696$$);$state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$,
$node$jscomp$448$$):$filter_tokens_by_path$$($state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$,$node$jscomp$448$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($count$jscomp$70$$,$token$jscomp$167$$){return $count$jscomp$70$$+$app$main$data$workspace$tokens$remapping$count_token_references$$($file_data$jscomp$121$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$167$$))},0,$state$jscomp$1197_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$)>
0?$on_remap_node_warning$$.$cljs$core$IFn$_invoke$arity$3$?$on_remap_node_warning$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$448$$,$type$jscomp$696$$,$new_node_name$jscomp$5$$):$on_remap_node_warning$$($node$jscomp$448$$,$type$jscomp$696$$,$new_node_name$jscomp$5$$):$bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$?$bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$448$$,$type$jscomp$696$$,$new_node_name$jscomp$5$$):$bulk_rename_tokens_in_path$$($node$jscomp$448$$,
$type$jscomp$696$$,$new_node_name$jscomp$5$$)}),$open_rename_node_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($on_rename_node$jscomp$1$$)],function($node$jscomp$450$$,$type$jscomp$698$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5810$tokens_SLASH_rename_node$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3766$node$$,$node$jscomp$450$$,$cljs$cst$5811$tokens_in_active_set$$,$selected_token_set_tokens$$,$cljs$cst$5809$on_rename$$,function($p1__79740_SHARP_$$){return $on_rename_node$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename_node$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$450$$,$type$jscomp$698$$,$p1__79740_SHARP_$$):$on_rename_node$jscomp$1$$($node$jscomp$450$$,$type$jscomp$698$$,$p1__79740_SHARP_$$)}],null)))}),$open_duplicate_node_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),
$APP.$rumext$v2$adapt$$($on_duplicate_node$jscomp$1$$)],function($node$jscomp$451$$,$type$jscomp$699$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5810$tokens_SLASH_rename_node$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5812$new_node_name$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$451$$)),
"-copy"].join(""),$APP.$cljs$cst$3766$node$$,$node$jscomp$451$$,$APP.$cljs$cst$1994$variant$$,"duplicate",$cljs$cst$5811$tokens_in_active_set$$,$selected_token_set_tokens$$,$cljs$cst$5809$on_rename$$,function($p1__79741_SHARP_$$){return $on_duplicate_node$jscomp$1$$($node$jscomp$451$$,$type$jscomp$699$$,$p1__79741_SHARP_$$)}],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$43$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],
function(){var $JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$=$APP.$cljs$core$truth_$$($tokens_lib$jscomp$43$$)?($JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$=$selected_token_set_id$jscomp$6$$==null)?$JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$:$APP.$cljs$core$truth_$$($selected_token_set_id$jscomp$6$$)?$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$get_set$$($tokens_lib$jscomp$43$$,
$selected_token_set_id$jscomp$6$$)):$selected_token_set_id$jscomp$6$$:$tokens_lib$jscomp$43$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$)?($JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$=$APP.$cljs$core$first$$($APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$43$$)),$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($APP.$app$common$types$tokens_lib$get_id$$($JSCompiler_inline_result$jscomp$1857_match$jscomp$59_or__5025__auto__$jscomp$inline_9012$$))):null):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$token_context_menu$$,{"on-delete-token":$delete_token$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$node_context_menu$token_node_context_menu_STAR_$$,{onRenameNode:$open_rename_node_modal$$,onDuplicateNode:$open_duplicate_node_modal$$,onDeleteNode:$delete_node$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$selected_set_info_STAR_$$,{tokensLib:$tokens_lib$jscomp$43$$,selectedTokenSetId:$selected_token_set_id$jscomp$6$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$194$$,
$JSCompiler_inline_result$jscomp$1860_type$jscomp$700$$){var $JSCompiler_temp_const$jscomp$1858$$=$out_arr__44124__auto__$jscomp$194$$.push,$tokens__$1$jscomp$inline_9014$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type$jscomp$1$$,$JSCompiler_inline_result$jscomp$1860_type$jscomp$700$$);$JSCompiler_inline_result$jscomp$1860_type$jscomp$700$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$group$token_group_STAR_$$,{isSelectedInsideLayout:$is_selected_inside_layout$jscomp$6$$,
type:$JSCompiler_inline_result$jscomp$1860_type$jscomp$700$$,selectedTokenSetId:$selected_token_set_id$jscomp$6$$,selectedIds:$selected$jscomp$181$$,tokensLib:$tokens_lib$jscomp$43$$,tokens:$tokens__$1$jscomp$inline_9014$$,activeThemeTokens:$resolved_active_tokens$jscomp$1$$,selectedShapes:$selected_shapes$jscomp$26$$},$APP.$cljs$core$name$$($JSCompiler_inline_result$jscomp$1860_type$jscomp$700$$));$JSCompiler_temp_const$jscomp$1858$$.call($out_arr__44124__auto__$jscomp$194$$,$JSCompiler_inline_result$jscomp$1860_type$jscomp$700$$);
return $out_arr__44124__auto__$jscomp$194$$},[],$filled_group_vec__79743$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$195$$,$type$jscomp$701$$){$out_arr__44124__auto__$jscomp$195$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$group$token_group_STAR_$$,{tokens:$APP.$cljs$core$PersistentVector$EMPTY$$,type:$type$jscomp$701$$,selectedShapes:$selected_shapes$jscomp$26$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$6$$,
activeThemeTokens:$resolved_active_tokens$jscomp$1$$},$APP.$cljs$core$name$$($type$jscomp$701$$)));return $out_arr__44124__auto__$jscomp$195$$},[],$empty_group_props_79742$$)]})};
$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set$$=function($errors$jscomp$35_tokens_lib$jscomp$44$$,$token_set$jscomp$20$$,$name$jscomp$465_name__$1$jscomp$23$$){$name$jscomp$465_name__$1$jscomp$23$$=$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$465_name__$1$jscomp$23$$,$APP.$app$common$types$tokens_lib$get_name$$($token_set$jscomp$20$$));$errors$jscomp$35_tokens_lib$jscomp$44$$=$app$common$schema$validation_errors$$($name$jscomp$465_name__$1$jscomp$23$$,
$APP.$app$common$files$tokens$make_token_set_name_schema$$($errors$jscomp$35_tokens_lib$jscomp$44$$,$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$20$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$());return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$35_tokens_lib$jscomp$44$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$rename_token_set$$($token_set$jscomp$20$$,
$name$jscomp$465_name__$1$jscomp$23$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.token-set-already-exists"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,9E3],null)))};
$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set_group$$=function($path$jscomp$281$$,$name$jscomp$466$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$rename_token_set_group$$($path$jscomp$281$$,$name$jscomp$466$$)]))};
$app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$=function($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$45$$,$parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9018$$,$name$jscomp$467_name__$1$jscomp$24$$){$parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9018$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$tokens_lib$get_name$$($parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9018$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,
"/"]));$name$jscomp$467_name__$1$jscomp$24$$=$APP.$cljs$core$truth_$$($parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9018$$)?$APP.$app$common$types$tokens_lib$join_set_path$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9018$$,$APP.$app$common$types$tokens_lib$split_set_name$$($name$jscomp$467_name__$1$jscomp$24$$))):$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$467_name__$1$jscomp$24$$);
$errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$45$$=$app$common$schema$validation_errors$$($name$jscomp$467_name__$1$jscomp$24$$,$APP.$app$common$files$tokens$make_token_set_name_schema$$($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$45$$,null));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-token-set",
$APP.$cljs$cst$725$name$$,$name$jscomp$467_name__$1$jscomp$24$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$()]));return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$45$$)?($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$45$$=$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,
$name$jscomp$467_name__$1$jscomp$24$$])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$tokens$library_edit$create_token_set$$($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$45$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$(),$app$main$data$workspace$tokens$library_edit$clear_tokens_types$$()]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.token-set-already-exists"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,9E3],null)))};$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_creation$$($APP.$cljs$core$PersistentVector$EMPTY$$))};
$app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$=function($on_key_down$jscomp$21_props_79709$$){var $on_cancel$jscomp$8$$=$on_key_down$jscomp$21_props_79709$$.onCancel,$default_value$jscomp$5$$=$on_key_down$jscomp$21_props_79709$$.defaultValue,$on_submit$jscomp$17$$=$on_key_down$jscomp$21_props_79709$$.onSubmit,$on_submit__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$jscomp$8$$),$APP.$rumext$v2$adapt$$($on_submit$jscomp$17$$),$APP.$rumext$v2$adapt$$($default_value$jscomp$5$$)],
function($event$jscomp$593_value$jscomp$942$$){$event$jscomp$593_value$jscomp$942$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$593_value$jscomp$942$$);return $APP.$cuerdas$core$empty_QMARK_$$($event$jscomp$593_value$jscomp$942$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$593_value$jscomp$942$$,$default_value$jscomp$5$$)?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$8$$():$on_submit$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$?
$on_submit$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$593_value$jscomp$942$$):$on_submit$jscomp$17$$($event$jscomp$593_value$jscomp$942$$)});$on_key_down$jscomp$21_props_79709$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit__$1$$),$APP.$rumext$v2$adapt$$($on_cancel$jscomp$8$$)],function($event$jscomp$594$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$594$$))?$on_submit__$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_submit__$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$594$$):$on_submit__$1$$($event$jscomp$594$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$594$$))?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$8$$():null});return(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",onBlur:$on_submit__$1$$,onKeyDown:$on_key_down$jscomp$21_props_79709$$,maxLength:"256",autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.set-edit-placeholder"),
defaultValue:$default_value$jscomp$5$$,className:"main_ui_workspace_tokens_sets_lists__editing-node"})};
$app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$=function($checked$jscomp$2_props_79712$$){var $aria_label$jscomp$10$$=$checked$jscomp$2_props_79712$$["aria-label"],$disabled$jscomp$19$$=$checked$jscomp$2_props_79712$$.disabled,$on_click$jscomp$51$$=$checked$jscomp$2_props_79712$$.onClick;$checked$jscomp$2_props_79712$$=$checked$jscomp$2_props_79712$$.checked;var $all_QMARK__checked_QMARK_$jscomp$7$$=$checked$jscomp$2_props_79712$$===!0,$mixed_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($checked$jscomp$2_props_79712$$,
"mixed");$all_QMARK__checked_QMARK_$jscomp$7$$=$all_QMARK__checked_QMARK_$jscomp$7$$||$mixed_QMARK_$$;return(0,$APP.$rumext$v2$jsx$$)("div",{role:"checkbox","aria-checked":""+($checked$jscomp$2_props_79712$$??""),disabled:$disabled$jscomp$19$$,title:$APP.$cljs$core$truth_$$($disabled$jscomp$19$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-permisions-set"):null,tabIndex:0,onClick:$APP.$cljs$core$truth_$$($disabled$jscomp$19$$)?null:$on_click$jscomp$51$$,className:"main_ui_workspace_tokens_sets_lists__checkbox-style "+
($all_QMARK__checked_QMARK_$jscomp$7$$?"main_ui_workspace_tokens_sets_lists__checkbox-checked-style":"")+" "+($APP.$cljs$core$truth_$$($all_QMARK__checked_QMARK_$jscomp$7$$?$disabled$jscomp$19$$:$all_QMARK__checked_QMARK_$jscomp$7$$)?"main_ui_workspace_tokens_sets_lists__checkbox-disabled-checked":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$19$$)?"main_ui_workspace_tokens_sets_lists__checkbox-disabled":""),children:$all_QMARK__checked_QMARK_$jscomp$7$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{"aria-label":$aria_label$jscomp$10$$,className:"main_ui_workspace_tokens_sets_lists__check-icon",size:"s",iconId:$mixed_QMARK_$$?"remove":"tick"}):null})};
$app$main$ui$workspace$tokens$sets$lists$inline_add_button_STAR_$$=function(){var $can_edit_QMARK_$jscomp$6$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_sets_lists__empty-sets-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_sets_lists__empty-state-message",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-sets-yet")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$,className:"main_ui_workspace_tokens_sets_lists__create-set-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.create-one")})]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sets_lists__empty-sets-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_sets_lists__empty-state-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-sets-yet")})})};$app$main$ui$workspace$tokens$sets$lists$add_button_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",icon:"add",onClick:$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add set")})};
$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_group_STAR_$$=function($depth$jscomp$18_props_79716$$){var $path$jscomp$282$$=$depth$jscomp$18_props_79716$$.path,$index$jscomp$545$$=$depth$jscomp$18_props_79716$$.index,$on_edit_submit$$=$depth$jscomp$18_props_79716$$.onEditSubmit,$is_selected$jscomp$6$$=$depth$jscomp$18_props_79716$$.isSelected,$on_toggle$jscomp$1$$=$depth$jscomp$18_props_79716$$.onToggle,$is_collapsed$$=$depth$jscomp$18_props_79716$$.isCollapsed,$on_drop$jscomp$16$$=$depth$jscomp$18_props_79716$$.onDrop,
$dprops$jscomp$9_is_draggable$$=$depth$jscomp$18_props_79716$$.isDraggable,$is_active$jscomp$4$$=$depth$jscomp$18_props_79716$$.isActive,$on_toggle_collapse$jscomp$1$$=$depth$jscomp$18_props_79716$$.onToggleCollapse,$on_start_edition$$=$depth$jscomp$18_props_79716$$.onStartEdition,$is_editing$jscomp$3$$=$depth$jscomp$18_props_79716$$.isEditing,$label$jscomp$54$$=$depth$jscomp$18_props_79716$$.label,$id$jscomp$1006$$=$depth$jscomp$18_props_79716$$.id,$on_reset_edition$$=$depth$jscomp$18_props_79716$$.onResetEdition;
$depth$jscomp$18_props_79716$$=$depth$jscomp$18_props_79716$$.depth;var $can_edit_QMARK_$jscomp$7$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$label_id$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1006$$),"-label"].join(""),$on_context_menu$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$3$$),$APP.$rumext$v2$adapt$$($id$jscomp$1006$$),$APP.$rumext$v2$adapt$$($path$jscomp$282$$),
$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$7$$)],function($event$jscomp$595$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$595$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$595$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$7$$)?$APP.$cljs$core$not$$($is_editing$jscomp$3$$):$can_edit_QMARK_$jscomp$7$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1676$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$595$$),$APP.$cljs$cst$2120$is_group$$,!0,$APP.$cljs$cst$266$id$$,$id$jscomp$1006$$,$APP.$cljs$cst$296$path$$,$path$jscomp$282$$],null))):null}),$on_collapse_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$596$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$596$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$596$$);return $on_toggle_collapse$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_toggle_collapse$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$282$$):$on_toggle_collapse$jscomp$1$$($path$jscomp$282$$)}),$on_double_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1006$$)],function(){return $on_start_edition$$.$cljs$core$IFn$_invoke$arity$1$?$on_start_edition$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1006$$):$on_start_edition$$($id$jscomp$1006$$)}),$on_checkbox_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_toggle$jscomp$1$$),
$APP.$rumext$v2$adapt$$($path$jscomp$282$$),$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$7$$)],function(){return $on_toggle$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$282$$):$on_toggle$jscomp$1$$($path$jscomp$282$$)}),$on_edit_submit_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path$jscomp$282$$),$APP.$rumext$v2$adapt$$($on_edit_submit$$),$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$7$$)],
function($p1__79715_SHARP_$$){return $on_edit_submit$$.$cljs$core$IFn$_invoke$arity$2$?$on_edit_submit$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$282$$,$p1__79715_SHARP_$$):$on_edit_submit$$($path$jscomp$282$$,$p1__79715_SHARP_$$)}),$dref$jscomp$9_on_drop__$1_vec__79717$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$545$$),$APP.$rumext$v2$adapt$$($on_drop$jscomp$16$$)],function($position$jscomp$197$$,$data$jscomp$496$$){return $on_drop$jscomp$16$$.$cljs$core$IFn$_invoke$arity$3$?
$on_drop$jscomp$16$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$545$$,$position$jscomp$197$$,$data$jscomp$496$$):$on_drop$jscomp$16$$($index$jscomp$545$$,$position$jscomp$197$$,$data$jscomp$496$$)});$dref$jscomp$9_on_drop__$1_vec__79717$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/token-set",$APP.$cljs$cst$2955$on_drop$$,$dref$jscomp$9_on_drop__$1_vec__79717$$,
$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,$index$jscomp$545$$,$APP.$cljs$cst$2120$is_group$$,!0],null),$APP.$cljs$cst$2958$detect_center_QMARK_$$,!0,$APP.$cljs$cst$2959$draggable_QMARK_$$,$APP.$cljs$core$truth_$$($dprops$jscomp$9_is_draggable$$)?$APP.$cljs$core$not$$($is_editing$jscomp$3$$):$dprops$jscomp$9_is_draggable$$]));$dprops$jscomp$9_is_draggable$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$9_on_drop__$1_vec__79717$$,
0,null);$dref$jscomp$9_on_drop__$1_vec__79717$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$9_on_drop__$1_vec__79717$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$dref$jscomp$9_on_drop__$1_vec__79717$$,"data-testid":"tokens-set-group-item",style:{"--tree-depth":$depth$jscomp$18_props_79716$$},onContextMenu:$on_context_menu$jscomp$14$$,className:"main_ui_workspace_tokens_sets_lists__set-item-container main_ui_workspace_tokens_sets_lists__set-item-group "+($APP.$cljs$core$truth_$$($is_selected$jscomp$6$$)?
"main_ui_workspace_tokens_sets_lists__selected-set":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$9_is_draggable$$),$APP.$cljs$cst$1667$center$$)?"main_ui_workspace_tokens_sets_lists__dnd-over":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$9_is_draggable$$),$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-top":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$9_is_draggable$$),$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-bot":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_sets_lists__set-item-group-collapse-button",onClick:$on_collapse_click$$,"data-testid":"tokens-set-group-collapse","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.collapse"),
icon:$APP.$cljs$core$truth_$$($is_collapsed$$)?"arrow-right":"arrow-down",variant:"action"}),$APP.$cljs$core$truth_$$($is_editing$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$,{defaultValue:$label$jscomp$54$$,onCancel:$on_reset_edition$$,onSubmit:$on_edit_submit_SINGLEQUOTE_$$}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{role:"button",title:$label$jscomp$54$$,tabIndex:0,onDoubleClick:$on_double_click$jscomp$2$$,
id:$label_id$$,className:"main_ui_workspace_tokens_sets_lists__set-name",children:$label$jscomp$54$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$,{onClick:$on_checkbox_click$$,disabled:$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$7$$),checked:function(){var $G__79721__$1$$=$is_active$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$is_active$jscomp$4$$.$fqn$:null;switch($G__79721__$1$$){case "all":return!0;case "partial":return"mixed";case "none":return!1;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79721__$1$$)].join(""));}}(),arialLabel:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.select-set")})]})]})};
$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$=function($depth$jscomp$19_props_79723$$){var $set$jscomp$21$$=$depth$jscomp$19_props_79723$$.set,$path$jscomp$283$$=$depth$jscomp$19_props_79723$$.path,$is_new$$=$depth$jscomp$19_props_79723$$.isNew,$index$jscomp$546$$=$depth$jscomp$19_props_79723$$.index,$on_edit_submit$jscomp$1$$=$depth$jscomp$19_props_79723$$.onEditSubmit,$is_selected$jscomp$7$$=$depth$jscomp$19_props_79723$$.isSelected,$on_toggle$jscomp$2$$=$depth$jscomp$19_props_79723$$.onToggle,
$on_drop$jscomp$17$$=$depth$jscomp$19_props_79723$$.onDrop,$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$=$depth$jscomp$19_props_79723$$.isDraggable,$is_active$jscomp$5$$=$depth$jscomp$19_props_79723$$.isActive,$on_start_edition$jscomp$1$$=$depth$jscomp$19_props_79723$$.onStartEdition,$on_select$jscomp$5$$=$depth$jscomp$19_props_79723$$.onSelect,$is_editing$jscomp$4$$=$depth$jscomp$19_props_79723$$.isEditing,$label$jscomp$55$$=$depth$jscomp$19_props_79723$$.label,$id$jscomp$1007$$=$depth$jscomp$19_props_79723$$.id,
$on_reset_edition$jscomp$1$$=$depth$jscomp$19_props_79723$$.onResetEdition;$depth$jscomp$19_props_79723$$=$depth$jscomp$19_props_79723$$.depth;var $can_edit_QMARK_$jscomp$8$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$on_click$jscomp$52$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$4$$),$APP.$rumext$v2$adapt$$($on_select$jscomp$5$$),$APP.$rumext$v2$adapt$$($id$jscomp$1007$$)],function($event$jscomp$597$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$597$$);
return $APP.$cljs$core$truth_$$($is_editing$jscomp$4$$)?null:$APP.$cljs$core$fn_QMARK_$$($on_select$jscomp$5$$)?$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1007$$):$on_select$jscomp$5$$($id$jscomp$1007$$):null}),$on_context_menu$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$4$$),$APP.$rumext$v2$adapt$$($id$jscomp$1007$$),$APP.$rumext$v2$adapt$$($path$jscomp$283$$),
$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$8$$)],function($event$jscomp$598$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$598$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$598$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$8$$)?$APP.$cljs$core$not$$($is_editing$jscomp$4$$):$can_edit_QMARK_$jscomp$8$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1676$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$598$$),$APP.$cljs$cst$2120$is_group$$,!1,$APP.$cljs$cst$266$id$$,$id$jscomp$1007$$,$APP.$cljs$cst$296$path$$,$path$jscomp$283$$],null))):null}),$on_double_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1007$$),$APP.$rumext$v2$adapt$$($is_new$$)],function(){return $APP.$cljs$core$truth_$$($is_new$$)?null:$on_start_edition$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_start_edition$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1007$$):$on_start_edition$jscomp$1$$($id$jscomp$1007$$)}),$on_checkbox_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set$jscomp$21$$),$APP.$rumext$v2$adapt$$($on_toggle$jscomp$2$$)],function($G__79727_event$jscomp$599$$){$APP.$app$util$dom$stop_propagation$$($G__79727_event$jscomp$599$$);return $APP.$cljs$core$fn_QMARK_$$($on_toggle$jscomp$2$$)?($G__79727_event$jscomp$599$$=
$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$21$$),$on_toggle$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__79727_event$jscomp$599$$):$on_toggle$jscomp$2$$($G__79727_event$jscomp$599$$)):null}),$on_edit_submit_SINGLEQUOTE_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set$jscomp$21$$),$APP.$rumext$v2$adapt$$($on_edit_submit$jscomp$1$$)],function($p1__79722_SHARP_$$){return $on_edit_submit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$on_edit_submit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($set$jscomp$21$$,$p1__79722_SHARP_$$):$on_edit_submit$jscomp$1$$($set$jscomp$21$$,$p1__79722_SHARP_$$)}),$dref$jscomp$10_on_drag$jscomp$2_vec__79724$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path$jscomp$283$$)],function(){return $APP.$cljs$core$truth_$$($is_selected$jscomp$7$$)?null:$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$283$$):
$on_select$jscomp$5$$($path$jscomp$283$$)}),$on_drop__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$546$$),$APP.$rumext$v2$adapt$$($on_drop$jscomp$17$$)],function($position$jscomp$198$$,$data$jscomp$497$$){return $on_drop$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$?$on_drop$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$546$$,$position$jscomp$198$$,$data$jscomp$497$$):$on_drop$jscomp$17$$($index$jscomp$546$$,$position$jscomp$198$$,
$data$jscomp$497$$)});$dref$jscomp$10_on_drag$jscomp$2_vec__79724$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/token-set",$APP.$cljs$cst$2956$on_drag$$,$dref$jscomp$10_on_drag$jscomp$2_vec__79724$$,$APP.$cljs$cst$2955$on_drop$$,$on_drop__$1$jscomp$1$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,$index$jscomp$546$$,
$APP.$cljs$cst$2120$is_group$$,!1],null),$APP.$cljs$cst$2959$draggable_QMARK_$$,$APP.$cljs$core$truth_$$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$)?$APP.$cljs$core$not$$($is_editing$jscomp$4$$):$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$]));$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$10_on_drag$jscomp$2_vec__79724$$,0,null);$dref$jscomp$10_on_drag$jscomp$2_vec__79724$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$10_on_drag$jscomp$2_vec__79724$$,
1,null);$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,$APP.$cljs$cst$2960$over$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{onDoubleClick:$on_double_click$jscomp$3$$,role:"button",className:"main_ui_workspace_tokens_sets_lists__set-item-container "+($APP.$cljs$core$truth_$$($is_selected$jscomp$7$$)?"main_ui_workspace_tokens_sets_lists__selected-set":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,
$APP.$cljs$cst$1667$center$$)?"main_ui_workspace_tokens_sets_lists__dnd-over":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,$APP.$cljs$cst$1562$top$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,$APP.$cljs$cst$2952$bot$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-bot":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"document",className:"main_ui_workspace_tokens_sets_lists__icon "+($APP.$cljs$core$not$$($depth$jscomp$19_props_79723$$)?"main_ui_workspace_tokens_sets_lists__root-icon":"")}),$APP.$cljs$core$truth_$$($is_editing$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$,{defaultValue:$label$jscomp$55$$,onCancel:$on_reset_edition$jscomp$1$$,onSubmit:$on_edit_submit_SINGLEQUOTE_$jscomp$1$$}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_tokens_sets_lists__set-name",children:$label$jscomp$55$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$,{onClick:$on_checkbox_click$jscomp$1$$,disabled:$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$8$$),arialLabel:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.select-set"),checked:$is_active$jscomp$5$$})]})],id:["token-set-item-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("/",
$path$jscomp$283$$))].join(""),"data-testid":"tokens-set-item",onContextMenu:$on_context_menu$jscomp$15$$,style:{"--tree-depth":$depth$jscomp$19_props_79723$$},"aria-checked":$is_active$jscomp$5$$,onClick:$on_click$jscomp$52$$,ref:$dref$jscomp$10_on_drag$jscomp$2_vec__79724$$})};
$app$main$ui$workspace$tokens$sets$lists$token_sets_tree_STAR_$$=function($props_79729$$){var $on_toggle_set$$=$props_79729$$.onToggleSet,$is_token_set_active$$=$props_79729$$.isTokenSetActive,$on_edit_submit_group$$=$props_79729$$.onEditSubmitGroup,$new_path$jscomp$4$$=$props_79729$$.newPath,$selected$jscomp$182$$=$props_79729$$.selected,$edition_id$jscomp$2$$=$props_79729$$.editionId,$token_sets$$=$props_79729$$.tokenSets,$is_draggable$jscomp$2$$=$props_79729$$.isDraggable,$is_token_set_group_active$$=
$props_79729$$.isTokenSetGroupActive,$on_edit_submit_set$$=$props_79729$$.onEditSubmitSet,$on_start_edition$jscomp$2$$=$props_79729$$.onStartEdition,$on_select$jscomp$6$$=$props_79729$$.onSelect,$on_toggle_set_group$$=$props_79729$$.onToggleSetGroup,$on_reset_edition$jscomp$2$$=$props_79729$$.onResetEdition,$tokens_lib$jscomp$46$$=$props_79729$$.tokensLib,$collapsed_paths_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$collapsed_paths$jscomp$1$$=
$APP.$cljs$core$_deref$$($collapsed_paths_STAR_$$),$collapsed_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($collapsed_paths$jscomp$1$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$collapsed_paths$jscomp$1$$)),$on_drop$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($collapsed_paths$jscomp$1$$)],function($index$jscomp$547_params$jscomp$430$$,
$position$jscomp$199$$,$data$jscomp$498$$){$index$jscomp$547_params$jscomp$430$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4676$from_index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$498$$),$APP.$cljs$cst$4677$to_index$$,$index$jscomp$547_params$jscomp$430$$,$APP.$cljs$cst$1676$position$$,$position$jscomp$199$$,$APP.$cljs$cst$4678$collapsed_paths$$,$collapsed_paths$jscomp$1$$],null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2120$is_group$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$498$$))?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$drop_token_set_group$$($index$jscomp$547_params$jscomp$430$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$drop_token_set$$($index$jscomp$547_params$jscomp$430$$))}),$on_toggle_collapse$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($path$jscomp$284$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_paths_STAR_$$,
function($p1__79728_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__79728_SHARP_$$,$path$jscomp$284$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($p1__79728_SHARP_$$,$path$jscomp$284$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__79728_SHARP_$$,$path$jscomp$284$$)})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $sub$jscomp$24$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($paths_SINGLEQUOTE_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_paths_STAR_$$,
function($paths$jscomp$9$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$disj$$,$paths$jscomp$9$$,$paths_SINGLEQUOTE_$$)})},$APP.$beicon$v2$core$map$$($cljs$cst$5427$paths$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5426$expand_token_sets$$),$APP.$app$main$store$stream$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$24$$)}});
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$196$$,$JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$){$JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$);var $JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,
$APP.$cljs$cst$2121$token_set$$),$id$jscomp$1008$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,$APP.$cljs$cst$266$id$$),$index$jscomp$548$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,$APP.$cljs$cst$1795$index$$),$G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,
$APP.$cljs$cst$2119$is_new$$),$is_group$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,$APP.$cljs$cst$2120$is_group$$),$path$jscomp$285$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,$APP.$cljs$cst$296$path$$),$depth$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$,$APP.$cljs$cst$839$depth$$);
$JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$=$out_arr__44124__auto__$jscomp$196$$.push;$is_group$$?$JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$sets_tree_set_group_STAR_$$,{onResetEdition:$on_reset_edition$jscomp$2$$,isCollapsed:$collapsed_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$collapsed_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$285$$):$collapsed_QMARK_$jscomp$1$$($path$jscomp$285$$),
isActive:$is_token_set_group_active$$.$cljs$core$IFn$_invoke$arity$1$?$is_token_set_group_active$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$285$$):$is_token_set_group_active$$($path$jscomp$285$$),index:$index$jscomp$548$$,onStartEdition:$on_start_edition$jscomp$2$$,onToggle:$on_toggle_set_group$$,isDraggable:$is_draggable$jscomp$2$$,label:$APP.$cljs$core$peek$$($path$jscomp$285$$),path:$path$jscomp$285$$,id:$id$jscomp$1008$$,onDrop:$on_drop$jscomp$18$$,depth:$depth$jscomp$20$$,isSelected:!1,onEditSubmit:$on_edit_submit_group$$,
isEditing:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition_id$jscomp$2$$,$id$jscomp$1008$$),onToggleCollapse:$on_toggle_collapse$jscomp$2$$},$index$jscomp$548$$):$G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$?$JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$,{onResetEdition:$on_reset_edition$jscomp$2$$,isActive:!0,index:$index$jscomp$548$$,
isDraggable:!1,label:"",path:$path$jscomp$285$$,id:$id$jscomp$1008$$,onDrop:$on_drop$jscomp$18$$,isNew:!0,depth:$depth$jscomp$20$$,isSelected:!0,onEditSubmit:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$,$tokens_lib$jscomp$46$$),set:$JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$,isEditing:!0},$index$jscomp$548$$):($G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$=
$APP.$app$common$types$tokens_lib$get_name$$($JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$),$G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$=$is_token_set_active$$.$cljs$core$IFn$_invoke$arity$1$?$is_token_set_active$$.$cljs$core$IFn$_invoke$arity$1$($G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$):$is_token_set_active$$($G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$),
$JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$,{onResetEdition:$on_reset_edition$jscomp$2$$,isActive:$G__79733$jscomp$inline_9020_JSCompiler_inline_result$jscomp$1865_is_new$jscomp$1$$,index:$index$jscomp$548$$,onStartEdition:$on_start_edition$jscomp$2$$,onToggle:$on_toggle_set$$,isDraggable:$is_draggable$jscomp$2$$,label:$APP.$cljs$core$peek$$($path$jscomp$285$$),path:$path$jscomp$285$$,
id:$id$jscomp$1008$$,onDrop:$on_drop$jscomp$18$$,isNew:!1,depth:$depth$jscomp$20$$,isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$182$$,$id$jscomp$1008$$),onEditSubmit:$on_edit_submit_set$$,set:$JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$,isEditing:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition_id$jscomp$2$$,$id$jscomp$1008$$),onSelect:$on_select$jscomp$6$$},$index$jscomp$548$$));$JSCompiler_temp_const$jscomp$1861_map__79732__$1_p__79731$$.call($out_arr__44124__auto__$jscomp$196$$,
$JSCompiler_temp$jscomp$1863_JSCompiler_temp$jscomp$1864_token_set$jscomp$22$$);return $out_arr__44124__auto__$jscomp$196$$},[],$app$common$types$tokens_lib$sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($token_sets$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2113$skip_children_pred$$,$collapsed_QMARK_$jscomp$1$$,$APP.$cljs$cst$2118$new_at_path$$,$new_path$jscomp$4$$],null)])))};
$app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$=function($draggable_QMARK_$jscomp$1_props_79734$$){var $on_toggle_token_set$$=$draggable_QMARK_$jscomp$1_props_79734$$.onToggleTokenSet,$is_token_set_active$jscomp$1$$=$draggable_QMARK_$jscomp$1_props_79734$$.isTokenSetActive,$on_toggle_token_set_group$$=$draggable_QMARK_$jscomp$1_props_79734$$.onToggleTokenSetGroup,$new_path$jscomp$5$$=$draggable_QMARK_$jscomp$1_props_79734$$.newPath,$selected$jscomp$183$$=$draggable_QMARK_$jscomp$1_props_79734$$.selected,
$on_update_token_set_group$$=$draggable_QMARK_$jscomp$1_props_79734$$.onUpdateTokenSetGroup,$edition_id$jscomp$3$$=$draggable_QMARK_$jscomp$1_props_79734$$.editionId,$token_sets$jscomp$1$$=$draggable_QMARK_$jscomp$1_props_79734$$.tokenSets,$on_update_token_set$$=$draggable_QMARK_$jscomp$1_props_79734$$.onUpdateTokenSet,$is_token_set_group_active$jscomp$1$$=$draggable_QMARK_$jscomp$1_props_79734$$.isTokenSetGroupActive,$on_create_token_set$$=$draggable_QMARK_$jscomp$1_props_79734$$.onCreateTokenSet,
$on_start_edition$jscomp$3$$=$draggable_QMARK_$jscomp$1_props_79734$$.onStartEdition,$on_select$jscomp$7$$=$draggable_QMARK_$jscomp$1_props_79734$$.onSelect,$on_reset_edition$jscomp$3$$=$draggable_QMARK_$jscomp$1_props_79734$$.onResetEdition,$tokens_lib$jscomp$47$$=$draggable_QMARK_$jscomp$1_props_79734$$.tokensLib,$theme_modal_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($draggable_QMARK_$jscomp$1_props_79734$$.origin,"theme-modal"),$can_edit_QMARK_$jscomp$9$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);
$draggable_QMARK_$jscomp$1_props_79734$$=function(){var $and__5023__auto__$jscomp$855$$=!$theme_modal_QMARK_$$;return $and__5023__auto__$jscomp$855$$?$can_edit_QMARK_$jscomp$9$$:$and__5023__auto__$jscomp$855$$}();var $empty_state_QMARK_$$=$theme_modal_QMARK_$$&&$APP.$cljs$core$empty_QMARK_$$($token_sets$jscomp$1$$)&&$APP.$cljs$core$not$$($new_path$jscomp$5$$),$on_reset_edition__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reset_edition$jscomp$3$$)],
function($v$jscomp$674$$){return $APP.$cljs$core$fn_QMARK_$$($on_reset_edition$jscomp$3$$)?$on_reset_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_reset_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$674$$):$on_reset_edition$jscomp$3$$($v$jscomp$674$$):null}),$on_start_edition__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_edition$jscomp$3$$)],function($v$jscomp$675$$){return $APP.$cljs$core$fn_QMARK_$$($on_start_edition$jscomp$3$$)?
$on_start_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_start_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$675$$):$on_start_edition$jscomp$3$$($v$jscomp$675$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sets_lists__sets-list",children:$empty_state_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_sets_lists__empty-state-message-sets",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-sets-create")}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$token_sets_tree_STAR_$$,{onResetEdition:$on_reset_edition__$1$$,tokenSets:$token_sets$jscomp$1$$,onCreateTokenSet:$on_create_token_set$$,selected:$selected$jscomp$183$$,onToggleSetGroup:$on_toggle_token_set_group$$,tokensLib:$tokens_lib$jscomp$47$$,onStartEdition:$on_start_edition__$1$$,newPath:$new_path$jscomp$5$$,isDraggable:$draggable_QMARK_$jscomp$1_props_79734$$,
onEditSubmitSet:$on_update_token_set$$,isTokenSetActive:$is_token_set_active$jscomp$1$$,onToggleSet:$on_toggle_token_set$$,editionId:$edition_id$jscomp$3$$,onSelect:$on_select$jscomp$7$$,isTokenSetGroupActive:$is_token_set_group_active$jscomp$1$$,onEditSubmitGroup:$on_update_token_set_group$$})})};
$app$main$ui$workspace$tokens$sets$on_select_token_set_click$$=function($id$jscomp$1009$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($id$jscomp$1009$$)]))};$app$main$ui$workspace$tokens$sets$on_toggle_token_set_click$$=function($name$jscomp$468$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_set$$($name$jscomp$468$$))};
$app$main$ui$workspace$tokens$sets$on_toggle_token_set_group_click$$=function($path$jscomp$286$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$toggle_token_set_group$$($path$jscomp$286$$))};
$app$main$ui$workspace$tokens$sets$sets_list_STAR_$$=function($props_79747_token_sets$jscomp$2$$){var $new_path$jscomp$6$$=$props_79747_token_sets$jscomp$2$$.newPath,$selected$jscomp$184$$=$props_79747_token_sets$jscomp$2$$.selected,$edition_id$jscomp$4$$=$props_79747_token_sets$jscomp$2$$.editionId,$tokens_lib$jscomp$48$$=$props_79747_token_sets$jscomp$2$$.tokensLib;$props_79747_token_sets$jscomp$2$$=$tokens_lib$jscomp$48$$==null?null:$APP.$app$common$types$tokens_lib$get_set_tree$$($tokens_lib$jscomp$48$$);
var $can_edit_QMARK_$jscomp$10$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$token_set_active_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$48$$)],function($name$jscomp$469$$){return $APP.$cljs$core$truth_$$($tokens_lib$jscomp$48$$)?$APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$($tokens_lib$jscomp$48$$,$name$jscomp$469$$):null}),$token_set_group_active_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($group_path$jscomp$11$$){return $APP.$cljs$core$_deref$$($app$main$refs$token_sets_at_path_all_active$$($group_path$jscomp$11$$))}),
$on_reset_edition$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$10$$)],function(){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$10$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$()])):
null}),$on_start_edition$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$10$$)],function($id$jscomp$1010$$){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$10$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_edition$$($id$jscomp$1010$$)):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$,
{onResetEdition:$on_reset_edition$jscomp$4$$,tokenSets:$props_79747_token_sets$jscomp$2$$,onCreateTokenSet:$app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$,selected:$selected$jscomp$184$$,onUpdateTokenSetGroup:$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set_group$$,origin:"set-panel",onToggleTokenSet:$app$main$ui$workspace$tokens$sets$on_toggle_token_set_click$$,onUpdateTokenSet:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$sets$helpers$on_update_token_set$$,
$tokens_lib$jscomp$48$$),tokensLib:$tokens_lib$jscomp$48$$,onStartEdition:$on_start_edition$jscomp$4$$,newPath:$new_path$jscomp$6$$,isTokenSetActive:$token_set_active_QMARK_$jscomp$1$$,canEdit:$can_edit_QMARK_$jscomp$10$$,onToggleTokenSetGroup:$app$main$ui$workspace$tokens$sets$on_toggle_token_set_group_click$$,editionId:$edition_id$jscomp$4$$,onSelect:$app$main$ui$workspace$tokens$sets$on_select_token_set_click$$,isTokenSetGroupActive:$token_set_group_active_QMARK_$$})};
$app$main$ui$workspace$tokens$sets$context_menu$prevent_default$$=function($event$jscomp$600$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$600$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$600$$)};$app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$=function($props_79766$$){return(0,$APP.$rumext$v2$jsx$$)("li",{"data-value":$props_79766$$.value,onClick:$props_79766$$.onClick,className:"main_ui_workspace_tokens_sets_context_menu__context-menu-item",children:$props_79766$$.title})};
$app$main$ui$workspace$tokens$sets$context_menu$menu_STAR_$$=function($create_set_at_path_props_79767$$){var $path$jscomp$287$$=$create_set_at_path_props_79767$$.path,$is_group$jscomp$1$$=$create_set_at_path_props_79767$$.isGroup,$id$jscomp$1011$$=$create_set_at_path_props_79767$$.id;$create_set_at_path_props_79767$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path$jscomp$287$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_creation$$($path$jscomp$287$$))});
var $on_edit$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1011$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_edition$$($id$jscomp$1011$$))}),$on_duplicate$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_group$jscomp$1$$),$APP.$rumext$v2$adapt$$($id$jscomp$1011$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$duplicate_token_set$$($id$jscomp$1011$$))}),
$on_delete$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_group$jscomp$1$$),$APP.$rumext$v2$adapt$$($path$jscomp$287$$)],$APP.$cljs$core$truth_$$($is_group$jscomp$1$$)?function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$delete_token_set_group$$($path$jscomp$287$$))}:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_set$$($id$jscomp$1011$$))});
return(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_tokens_sets_context_menu__context-list",children:[$APP.$cljs$core$truth_$$($is_group$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-set-to-group"),onClick:$create_set_at_path_props_79767$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),onClick:$on_edit$jscomp$9$$}),$APP.$cljs$core$truth_$$($is_group$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.duplicate"),onClick:$on_duplicate$jscomp$3$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
onClick:$on_delete$jscomp$14$$})]})};
$app$main$ui$workspace$tokens$sets$context_menu$token_set_context_menu_STAR_$$=function(){var $map__79769_position$jscomp$200$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$sets$context_menu$ref_COLON_token_sets_context_menu$$),$map__79769__$1_path$jscomp$288$$=$APP.$cljs$core$__destructure_map$$($map__79769_position$jscomp$200$$);$map__79769_position$jscomp$200$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79769__$1_path$jscomp$288$$,$APP.$cljs$cst$1676$position$$);var $is_group$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79769__$1_path$jscomp$288$$,$APP.$cljs$cst$2120$is_group$$),$id$jscomp$1012$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79769__$1_path$jscomp$288$$,$APP.$cljs$cst$266$id$$);$map__79769__$1_path$jscomp$288$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79769__$1_path$jscomp$288$$,$APP.$cljs$cst$296$path$$);var $position_top$$=($map__79769_position$jscomp$200$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79769_position$jscomp$200$$,
$APP.$cljs$cst$1511$y$$))+5,$position_left$$=($map__79769_position$jscomp$200$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79769_position$jscomp$200$$,$APP.$cljs$cst$1510$x$$))+5,$on_close$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$(null))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,
{show:$map__79769_position$jscomp$200$$!=null,"on-close":$on_close$jscomp$35$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"tokens-context-menu-for-set",style:{top:$position_top$$,left:$position_left$$},onContextMenu:$app$main$ui$workspace$tokens$sets$context_menu$prevent_default$$,className:"main_ui_workspace_tokens_sets_context_menu__token-set-context-menu",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_STAR_$$,{isGroup:$is_group$jscomp$2$$,id:$id$jscomp$1012$$,
path:$map__79769__$1_path$jscomp$288$$})})})};
$app$main$ui$workspace$tokens$themes$theme_selector$themes_list$$=function($props_79770$$){var $map__79771$$=$APP.$rumext$v2$util$wrap_props$$($props_79770$$),$map__79771__$1$$=$APP.$cljs$core$__destructure_map$$($map__79771$$),$themes$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79771__$1$$,$APP.$cljs$cst$2122$themes$$),$active_theme_paths$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79771__$1$$,$cljs$cst$5813$active_theme_paths$$),$on_close$jscomp$36$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79771__$1$$,$APP.$cljs$cst$4994$on_close$$),$grouped_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79771__$1$$,$cljs$cst$5814$grouped_QMARK_$$);return $APP.$cljs$core$seq$$($themes$jscomp$8$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_themes_theme_selector__theme-options",children:$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return function $app$main$ui$workspace$tokens$themes$theme_selector$themes_list_$_iter__79772$$($s__79773$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $temp__5825__auto__$jscomp$395$$=$APP.$cljs$core$seq$$($s__79773$$);if($temp__5825__auto__$jscomp$395$$){var $s__79773__$2$$=$temp__5825__auto__$jscomp$395$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__79773__$2$$)){var $c__5501__auto__$jscomp$49$$=$APP.$cljs$core$_chunked_first$$($s__79773__$2$$),$size__5502__auto__$jscomp$49$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$49$$),$b__79775$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$49$$);return function(){for(var $i__79774$$=
0;;)if($i__79774$$<$size__5502__auto__$jscomp$49$$){var $vec__79776$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$49$$,$i__79774$$),$_$jscomp$3061$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79776$$,0,null),$map__79779$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79776$$,1,null),$map__79779__$1$$=$APP.$cljs$core$__destructure_map$$($map__79779$$),$theme$jscomp$14$$=$map__79779__$1$$,$id$jscomp$1014$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79779__$1$$,
$APP.$cljs$cst$266$id$$),$name$jscomp$471$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79779__$1$$,$APP.$cljs$cst$725$name$$),$theme_id$jscomp$7$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$14$$),$selected_QMARK_$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$1$$,$theme_id$jscomp$7$$);$APP.$cljs$core$chunk_append$$($b__79775$$,(0,$APP.$rumext$v2$jsxs$$)("li",{role:"option","aria-selected":$selected_QMARK_$jscomp$11$$,
onClick:function($i__79774$jscomp$1$$,$theme_id$jscomp$8$$,$selected_QMARK_$jscomp$12$$,$vec__79776$jscomp$1$$,$_$jscomp$3062$$,$map__79779$jscomp$1$$,$map__79779__$1$jscomp$1$$,$theme$jscomp$15$$,$id$jscomp$1015$$,$name$jscomp$472$$,$c__5501__auto__$jscomp$50$$,$size__5502__auto__$jscomp$50$$,$b__79775$jscomp$1$$,$s__79773__$2$jscomp$1$$,$temp__5825__auto__$jscomp$396$$,$map__79771$jscomp$1$$,$map__79771__$1$jscomp$1$$,$themes$jscomp$9$$,$active_theme_paths$jscomp$2$$,$on_close$jscomp$37$$){return function($e$jscomp$354$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$354$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1015$$));return $on_close$jscomp$37$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$37$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$37$$()}}($i__79774$$,$theme_id$jscomp$7$$,$selected_QMARK_$jscomp$11$$,$vec__79776$$,$_$jscomp$3061$$,$map__79779$$,$map__79779__$1$$,$theme$jscomp$14$$,$id$jscomp$1014$$,$name$jscomp$471$$,$c__5501__auto__$jscomp$49$$,
$size__5502__auto__$jscomp$49$$,$b__79775$$,$s__79773__$2$$,$temp__5825__auto__$jscomp$395$$,$map__79771$$,$map__79771__$1$$,$themes$jscomp$8$$,$active_theme_paths$jscomp$1$$,$on_close$jscomp$36$$,$grouped_QMARK_$$),className:"main_ui_workspace_tokens_themes_theme_selector__checked-element "+($APP.$cljs$core$truth_$$($grouped_QMARK_$$)?"main_ui_workspace_tokens_themes_theme_selector__sub-item":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$11$$)?"main_ui_workspace_tokens_themes_theme_selector__is-selected":
""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_theme_selector__label",title:$name$jscomp$471$$,children:$name$jscomp$471$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick","aria-hidden":!0,className:"main_ui_workspace_tokens_themes_theme_selector__check-icon "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$11$$)?"main_ui_workspace_tokens_themes_theme_selector__check-icon-visible":
"")})]},$theme_id$jscomp$7$$));$i__79774$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__79775$$),$app$main$ui$workspace$tokens$themes$theme_selector$themes_list_$_iter__79772$$($APP.$cljs$core$_chunked_rest$$($s__79773__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__79775$$),null)}var $vec__79780$$=$APP.$cljs$core$first$$($s__79773__$2$$),$_$jscomp$3060$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79780$$,0,null),$map__79783$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79780$$,1,null),$map__79783__$1$$=$APP.$cljs$core$__destructure_map$$($map__79783$$),$theme$jscomp$13$$=$map__79783__$1$$,$id$jscomp$1013$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79783__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$470$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79783__$1$$,$APP.$cljs$cst$725$name$$),$theme_id$jscomp$6$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$13$$),
$selected_QMARK_$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$1$$,$theme_id$jscomp$6$$);return $APP.$cljs$core$cons$$((0,$APP.$rumext$v2$jsxs$$)("li",{role:"option","aria-selected":$selected_QMARK_$jscomp$10$$,onClick:function($theme_id$jscomp$9$$,$selected_QMARK_$jscomp$13$$,$vec__79780$jscomp$1$$,$_$jscomp$3063$$,$map__79783$jscomp$1$$,$map__79783__$1$jscomp$1$$,$theme$jscomp$16$$,$id$jscomp$1016$$,$name$jscomp$473$$,$s__79773__$2$jscomp$2$$,$temp__5825__auto__$jscomp$397$$,
$map__79771$jscomp$2$$,$map__79771__$1$jscomp$2$$,$themes$jscomp$10$$,$active_theme_paths$jscomp$3$$,$on_close$jscomp$38$$){return function($e$jscomp$355$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$355$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1016$$));return $on_close$jscomp$38$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$38$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$38$$()}}($theme_id$jscomp$6$$,
$selected_QMARK_$jscomp$10$$,$vec__79780$$,$_$jscomp$3060$$,$map__79783$$,$map__79783__$1$$,$theme$jscomp$13$$,$id$jscomp$1013$$,$name$jscomp$470$$,$s__79773__$2$$,$temp__5825__auto__$jscomp$395$$,$map__79771$$,$map__79771__$1$$,$themes$jscomp$8$$,$active_theme_paths$jscomp$1$$,$on_close$jscomp$36$$,$grouped_QMARK_$$),className:"main_ui_workspace_tokens_themes_theme_selector__checked-element "+($APP.$cljs$core$truth_$$($grouped_QMARK_$$)?"main_ui_workspace_tokens_themes_theme_selector__sub-item":
"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$10$$)?"main_ui_workspace_tokens_themes_theme_selector__is-selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_theme_selector__label",title:$name$jscomp$470$$,children:$name$jscomp$470$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick","aria-hidden":!0,className:"main_ui_workspace_tokens_themes_theme_selector__check-icon "+
($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$10$$)?"main_ui_workspace_tokens_themes_theme_selector__check-icon-visible":"")})]},$theme_id$jscomp$6$$),$app$main$ui$workspace$tokens$themes$theme_selector$themes_list_$_iter__79772$$($APP.$cljs$core$rest$$($s__79773__$2$$)))}return null}},null,null)}($themes$jscomp$8$$)}())}):null};
$app$main$ui$workspace$tokens$themes$theme_selector$open_tokens_theme_modal$$=function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5815$tokens_SLASH_themes$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$tokens$themes$theme_selector$theme_options$$=function($map__79785_map__79785__$1_props_79784$$){$map__79785_map__79785__$1_props_79784$$=$APP.$rumext$v2$util$wrap_props$$($map__79785_map__79785__$1_props_79784$$);$map__79785_map__79785__$1_props_79784$$=$APP.$cljs$core$__destructure_map$$($map__79785_map__79785__$1_props_79784$$);var $active_theme_paths$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79785_map__79785__$1_props_79784$$,$cljs$cst$5813$active_theme_paths$$),
$themes$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79785_map__79785__$1_props_79784$$,$APP.$cljs$cst$2122$themes$$),$on_close$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79785_map__79785__$1_props_79784$$,$APP.$cljs$cst$4994$on_close$$);return(0,$APP.$rumext$v2$jsxs$$)("ul",{role:"listbox",className:"main_ui_workspace_tokens_themes_theme_selector__theme-options main_ui_workspace_tokens_themes_theme_selector__custom-select-dropdown",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$197$$,
$p__79786_themes__$1$$){var $group$jscomp$53$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79786_themes__$1$$,0,null);$p__79786_themes__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79786_themes__$1$$,1,null);$out_arr__44124__auto__$jscomp$197$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{"aria-labelledby":""+($group$jscomp$53$$??"")+"-label",role:"group",children:[$APP.$cljs$core$seq$$($group$jscomp$53$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"headline-small",className:"main_ui_workspace_tokens_themes_theme_selector__group",id:""+($APP.$cuerdas$core$kebab$$($group$jscomp$53$$)??"")+"-label",title:$group$jscomp$53$$,children:$group$jscomp$53$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$themes_list$$,{themes:$p__79786_themes__$1$$,"active-theme-paths":$active_theme_paths$jscomp$4$$,"on-close":$on_close$jscomp$39$$,"grouped?":!0})]},$group$jscomp$53$$));return $out_arr__44124__auto__$jscomp$197$$},
[],$themes$jscomp$11$$),(0,$APP.$rumext$v2$jsx$$)("li",{"aria-hidden":!0,className:"main_ui_workspace_tokens_themes_theme_selector__separator"}),(0,$APP.$rumext$v2$jsxs$$)("li",{role:"option",onClick:$app$main$ui$workspace$tokens$themes$theme_selector$open_tokens_theme_modal$$,className:"main_ui_workspace_tokens_themes_theme_selector__checked-element main_ui_workspace_tokens_themes_theme_selector__checked-element-button",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.edit-themes")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right","aria-hidden":!0})]})]})};
$app$main$ui$workspace$tokens$themes$theme_selector$theme_selector$$=function($map__79791_props_79790_themes$jscomp$12$$){$map__79791_props_79790_themes$jscomp$12$$=$APP.$rumext$v2$util$wrap_props$$($map__79791_props_79790_themes$jscomp$12$$);$APP.$cljs$core$__destructure_map$$($map__79791_props_79790_themes$jscomp$12$$);var $active_theme_paths$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_active_theme_paths_no_hidden$$),$active_themes_count_current_label$jscomp$1$$=$APP.$cljs$core$count$$($active_theme_paths$jscomp$5$$);
$map__79791_props_79790_themes$jscomp$12$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_theme_tree_no_hidden$$);var $can_edit_QMARK_$jscomp$11$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$));$active_themes_count_current_label$jscomp$1$$=$active_themes_count_current_label$jscomp$1$$>1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.active-themes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$active_themes_count_current_label$jscomp$1$$])):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_themes_count_current_label$jscomp$1$$,1)?function(){var $G__79792_G__79792__$1_G__79792__$2$$=$APP.$cljs$core$first$$($active_theme_paths$jscomp$5$$);$G__79792_G__79792__$1_G__79792__$2$$=$G__79792_G__79792__$1_G__79792__$2$$==null?null:$APP.$app$common$path_names$split_group_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__79792_G__79792__$1_G__79792__$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,
"/",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]));$G__79792_G__79792__$1_G__79792__$2$$=$G__79792_G__79792__$1_G__79792__$2$$==null?null:$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty_QMARK_$$,$G__79792_G__79792__$1_G__79792__$2$$);return $G__79792_G__79792__$1_G__79792__$2$$==null?null:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" / ",$G__79792_G__79792__$1_G__79792__$2$$)}():$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-active-theme");
var $state_STAR_$jscomp$24$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$4561$is_open_QMARK_$$,!1,$APP.$cljs$cst$1611$rect$$,null],null)}),$rect$jscomp$47_state$jscomp$1198$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$24$$),$is_open_QMARK_$jscomp$4$$=$APP.$cljs$cst$4561$is_open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1198$$);
$rect$jscomp$47_state$jscomp$1198$$=$APP.$cljs$cst$1611$rect$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1198$$);var $on_close_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$24$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!1)}),$on_open_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$11$$)],
function($event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$11$$)&&($event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$),$APP.$cljs$core$truth_$$($event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$))?($event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$=$APP.$app$util$dom$get_bounding_rect$$($event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$24$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1611$rect$$,$event$jscomp$601_rect__$1$jscomp$1_temp__5825__auto__$jscomp$398$$]))):null}),$container$jscomp$95$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5795$popup$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{role:"combobox",
"aria-expanded":$is_open_QMARK_$jscomp$4$$,tabIndex:"0",className:"main_ui_workspace_tokens_themes_theme_selector__custom-select "+($APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$11$$)?"main_ui_workspace_tokens_themes_theme_selector__disabled-select":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_theme_selector__current-label",children:$active_themes_count_current_label$jscomp$1$$}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_workspace_tokens_themes_theme_selector__dropdown-button","aria-hidden":!0}),$APP.$cljs$core$truth_$$($is_open_QMARK_$jscomp$4$$)?(0,$APP.$rumext$v2$portal$$)((0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"theme-select-dropdown",style:{top:$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1198$$),left:$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1198$$),
width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1198$$)},className:"main_ui_workspace_tokens_themes_theme_selector__dropdown-portal",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$is_open_QMARK_$jscomp$4$$,"on-close":$on_close_dropdown$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$theme_options$$,{"active-theme-paths":$active_theme_paths$jscomp$5$$,themes:$map__79791_props_79790_themes$jscomp$12$$,
"on-close":$on_close_dropdown$$})})}),$container$jscomp$95$$):null],"data-testid":"theme-select","aria-haspopup":"listbox",onClick:$on_open_dropdown$$,disabled:$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$11$$)})};
$app$main$ui$workspace$tokens$themes$themes_header_STAR_$$=function(){var $ordered_themes$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_themes_no_hidden$$),$can_edit_QMARK_$jscomp$12$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$open_modal$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$356$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$356$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5815$tokens_SLASH_themes$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes__themes-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"headline-small",className:"main_ui_workspace_tokens_themes__themes-header",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.themes")}),$APP.$cljs$core$empty_QMARK_$$($ordered_themes$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_themes__empty-theme-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes__empty-state-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-themes")}),$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$12$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$open_modal$jscomp$1$$,className:"main_ui_workspace_tokens_themes__create-theme-button",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.create-one")}):null]}):$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$12$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes__theme-selector-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$theme_selector$$,{}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",className:"main_ui_workspace_tokens_themes__edit-theme-button",
onClick:$open_modal$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit")})]}):(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$12$$)?null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-permission-themes"),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$theme_selector$$,{})})]})};
$app$main$ui$workspace$tokens$sidebar$token_sets_list_STAR_$$=function($props_79811_tokens_lib$jscomp$49$$){$props_79811_tokens_lib$jscomp$49$$=$props_79811_tokens_lib$jscomp$49$$.tokensLib;var $token_sets$jscomp$3$$=$props_79811_tokens_lib$jscomp$49$$==null?null:$APP.$app$common$types$tokens_lib$get_set_tree$$($props_79811_tokens_lib$jscomp$49$$),$selected_token_set_id$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$map__79812_token_set_edition_id$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_tokens$$),
$map__79812__$1_token_set_new_path$$=$APP.$cljs$core$__destructure_map$$($map__79812_token_set_edition_id$$);$map__79812_token_set_edition_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79812__$1_token_set_new_path$$,$APP.$cljs$cst$4729$token_set_edition_id$$);$map__79812__$1_token_set_new_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79812__$1_token_set_new_path$$,$APP.$cljs$cst$4731$token_set_new_path$$);return $APP.$cljs$core$empty_QMARK_$$($token_sets$jscomp$3$$)&&
$APP.$cljs$core$not$$($map__79812__$1_token_set_new_path$$)?$APP.$cljs$core$truth_$$($map__79812__$1_token_set_new_path$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$inline_add_button_STAR_$$,{}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$sets_list_STAR_$$,{tokensLib:$props_79811_tokens_lib$jscomp$49$$,newPath:$map__79812__$1_token_set_new_path$$,editionId:$map__79812_token_set_edition_id$$,
selected:$selected_token_set_id$jscomp$7$$})})};
$app$main$ui$workspace$tokens$sidebar$token_management_section_STAR_$$=function($props_79814$$){var $resize_height$$=$props_79814$$.resizeHeight,$can_edit_QMARK_$jscomp$13$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$token_set_context_menu_STAR_$$,{}),(0,$APP.$rumext$v2$jsxs$$)("section",{"data-testid":"token-management-sidebar",
style:{"--resize-height":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($resize_height$$),"px"].join("")},className:"main_ui_workspace_tokens_sidebar__token-management-section-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$themes_header_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sidebar__sidebar-header",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.sets"),
children:$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$add_button_STAR_$$,{}):null})}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$sidebar$token_sets_list_STAR_$$,$props_79814$$)]})]})};
$app$main$ui$workspace$tokens$sidebar$import_export_button_STAR_$$=function(){var $show_menu_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_menu_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($show_menu_STAR_$jscomp$1$$),$can_edit_QMARK_$jscomp$14$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$open_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$602$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$602$$);
return $APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$jscomp$1$$,!0)}),$close_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$603$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$603$$);return $APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$jscomp$1$$,!1)}),$on_export$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5816$tokens_SLASH_export$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}),$on_modal_show$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5817$tokens_SLASH_import$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}),$open_settings_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$604$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$604$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5818$tokens_SLASH_settings$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_sidebar__import-export-button-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$open_menu$$,type:"button",icon:"import-export",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.tools")}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:$show_menu_QMARK_$jscomp$4$$,onClose:$close_menu$jscomp$2$$,id:"tokens-menu",className:"main_ui_workspace_tokens_sidebar__import-export-menu",children:[$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$14$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_tokens_sidebar__import-export-menu-item",onClick:$on_modal_show$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sidebar__import-menu-item",
children:(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.import")})})}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_tokens_sidebar__import-export-menu-item",onClick:$on_export$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.export")})]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$14$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1212$token_base_font_size$$):$can_edit_QMARK_$jscomp$14$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",icon:"settings","aria-label":"Settings",onClick:$open_settings_modal$$}):null]})};
$app$main$ui$workspace$tokens$sidebar$tokens_sidebar_tab_STAR_$$=function($props_79816$$){var $tokens_lib$jscomp$50$$=$props_79816$$.tokensLib,$map__79817_on_pointer_down_pages$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$2100$tokens$$,200,38,"0.6",$APP.$cljs$cst$1511$y$$,!1,null,null),$map__79817__$1_size_pages_opened$$=$APP.$cljs$core$__destructure_map$$($map__79817_on_pointer_down_pages$$);$map__79817_on_pointer_down_pages$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79817__$1_size_pages_opened$$,
$APP.$cljs$cst$4542$on_pointer_down$$);var $on_lost_pointer_capture_pages$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79817__$1_size_pages_opened$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move_pages$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79817__$1_size_pages_opened$$,$APP.$cljs$cst$4544$on_pointer_move$$);$map__79817__$1_size_pages_opened$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79817__$1_size_pages_opened$$,$APP.$cljs$cst$874$size$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_sidebar__sidebar-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sidebar$token_management_section_STAR_$$,{resizeHeight:$map__79817__$1_size_pages_opened$$,tokensLib:$tokens_lib$jscomp$50$$}),(0,$APP.$rumext$v2$jsxs$$)("article",{"data-testid":"tokens-sidebar",className:"main_ui_workspace_tokens_sidebar__tokens-section-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__79817_on_pointer_down_pages$$,
onLostPointerCapture:$on_lost_pointer_capture_pages$$,onPointerMove:$on_pointer_move_pages$$,className:"main_ui_workspace_tokens_sidebar__resize-area-horiz",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sidebar__resize-handle-horiz"})}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$tokens_section_STAR_$$,$props_79816$$)]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sidebar$import_export_button_STAR_$$,{})]})};
$app$main$ui$workspace$sidebar$collapse_button_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$app$main$ui$workspace$sidebar$toggle_collapse_left_sidebar$$,className:"main_ui_workspace_sidebar__collapse-sidebar-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.collapse")})})};
$app$main$ui$workspace$sidebar$on_close_document_history$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3719$document_history$$))};
$app$main$ui$workspace$sidebar$right_sidebar_STAR_$$=function($props_79829$$){var $file_id$jscomp$430$$=$props_79829$$.fileId,$layout$jscomp$24$$=$props_79829$$.layout,$dbg_shape_panel_QMARK__section$jscomp$35$$=$props_79829$$.section,$page_id$jscomp$443$$=$props_79829$$.pageId,$active_tokens$jscomp$11$$=$props_79829$$.activeTokens,$is_comments_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79829$$.drawingTool,$APP.$cljs$cst$3436$comments$$),$is_history_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$24$$,
$APP.$cljs$cst$3719$document_history$$),$can_be_expanded_QMARK__is_inspect_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dbg_shape_panel_QMARK__section$jscomp$35$$,$APP.$cljs$cst$2672$inspect$$);$dbg_shape_panel_QMARK__section$jscomp$35$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3075$shape_panel$$);var $current_section_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1161$info$$),$current_section$jscomp$1_map__79830_on_pointer_down$jscomp$6$$=
$APP.$cljs$core$_deref$$($current_section_STAR_$$);$can_be_expanded_QMARK__is_inspect_QMARK_$$=$dbg_shape_panel_QMARK__section$jscomp$35$$||!$is_comments_QMARK_$$&&!$is_history_QMARK_$$&&$can_be_expanded_QMARK__is_inspect_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$1_map__79830_on_pointer_down$jscomp$6$$,$APP.$cljs$cst$273$code$$);$current_section$jscomp$1_map__79830_on_pointer_down$jscomp$6$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$273$code$$,
318,318,768,$APP.$cljs$cst$1510$x$$,!0,$APP.$cljs$cst$258$right$$,null);var $map__79830__$1_on_change_section$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($current_section$jscomp$1_map__79830_on_pointer_down$jscomp$6$$);$current_section$jscomp$1_map__79830_on_pointer_down$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79830__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$4542$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79830__$1_on_change_section$jscomp$3$$,
$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79830__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$4544$on_pointer_move$$),$set_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79830__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$4546$set_size$$),$width$jscomp$208$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79830__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$874$size$$);
$map__79830__$1_on_change_section$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79828_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($current_section_STAR_$$,$p1__79828_SHARP_$$)});var $on_expand$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($width$jscomp$208$$),$APP.$rumext$v2$adapt$$($set_width$$)],function(){var $G__79831$$=$width$jscomp$208$$>318?318:768;return $set_width$$.$cljs$core$IFn$_invoke$arity$1$?
$set_width$$.$cljs$core$IFn$_invoke$arity$1$($G__79831$$):$set_width$$($G__79831$$)}),$active_tokens_by_type$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$11$$)],function(){return new $APP.$cljs$core$Delay$$(function(){return $app$common$types$tokens_lib$group_by_type$$($active_tokens$jscomp$11$$)})});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$sidebar$$),{value:$APP.$cljs$cst$258$right$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$active_tokens_by_type$$),
{value:$active_tokens_by_type$$,children:(0,$APP.$rumext$v2$jsxs$$)("aside",{id:"right-sidebar-aside","data-testid":"right-sidebar","data-size":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$208$$),onContextMenu:$app$util$dom$prevent_default_context_menu$$,style:{"--right-sidebar-width":$can_be_expanded_QMARK__is_inspect_QMARK_$$?""+($width$jscomp$208$$??"")+"px":"318px"},className:"main_ui_workspace_sidebar__right-settings-bar "+($can_be_expanded_QMARK__is_inspect_QMARK_$$?"":
"main_ui_workspace_sidebar__not-expand")+" "+($width$jscomp$208$$>318?"main_ui_workspace_sidebar__expanded":""),children:[$can_be_expanded_QMARK__is_inspect_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$current_section$jscomp$1_map__79830_on_pointer_down$jscomp$6$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$4$$,onPointerMove:$on_pointer_move$jscomp$5$$,className:"main_ui_workspace_sidebar__resize-area"}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$right_header$right_header_STAR_$$,
{fileId:$file_id$jscomp$430$$,layout:$layout$jscomp$24$$,pageId:$page_id$jscomp$443$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__settings-bar-inside",children:$dbg_shape_panel_QMARK__section$jscomp$35$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_info_STAR_$$,{}):$is_comments_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$comments$comments_sidebar_STAR_$$,{}):$is_history_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history_content_STAR_$$,
{}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$options_toolbox_STAR_$$,{...$props_79829$$,onChangeSection:$map__79830__$1_on_change_section$jscomp$3$$,onExpand:$on_expand$jscomp$4$$})})]})})})};
$app$main$ui$workspace$sidebar$sidebar_STAR_$$=function($page_id$jscomp$444_props_79832$$){var $drawing_tool$jscomp$1$$=$page_id$jscomp$444_props_79832$$.drawingTool,$selected$jscomp$186$$=$page_id$jscomp$444_props_79832$$.selected,$file_id$jscomp$431$$=$page_id$jscomp$444_props_79832$$.fileId,$layout$jscomp$25$$=$page_id$jscomp$444_props_79832$$.layout,$file$jscomp$177$$=$page_id$jscomp$444_props_79832$$.file,$section$jscomp$36$$=$page_id$jscomp$444_props_79832$$.section;$page_id$jscomp$444_props_79832$$=
$page_id$jscomp$444_props_79832$$.pageId;var $tokens_lib$jscomp$52$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$active_tokens$jscomp$12_resolved_active_tokens$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$52$$)],function(){return $APP.$cljs$core$truth_$$($tokens_lib$jscomp$52$$)?$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$52$$):$APP.$cljs$core$PersistentArrayMap$EMPTY$$}),$selected_token_set_id$jscomp$8$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$active_tokens_force_set$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$52$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$8$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($tokens_lib$jscomp$52$$)?$selected_token_set_id$jscomp$8$$:$tokens_lib$jscomp$52$$)?$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$($tokens_lib$jscomp$52$$,
$selected_token_set_id$jscomp$8$$):$APP.$cljs$core$PersistentArrayMap$EMPTY$$}),$tokenscript_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$);$active_tokens$jscomp$12_resolved_active_tokens$jscomp$3$$=$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$($active_tokens$jscomp$12_resolved_active_tokens$jscomp$3$$);var $tokenscript_resolved_active_tokens_force_set$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens_force_set$$),
$APP.$rumext$v2$adapt$$($tokenscript_QMARK_$$)],function(){return $tokenscript_QMARK_$$?$APP.$app$main$data$tokenscript$resolve_tokens$$($active_tokens_force_set$$):null}),$resolved_active_tokens_force_set$$=$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$($active_tokens_force_set$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($cljs$cst$5617$collapse_left_sidebar$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$25$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$collapsed_button_STAR_$$,
{}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$left_sidebar_STAR_$$,{layout:$layout$jscomp$25$$,file:$file$jscomp$177$$,pageId:$page_id$jscomp$444_props_79832$$,tokensLib:$tokens_lib$jscomp$52$$,activeTokens:$active_tokens_force_set$$,resolvedActiveTokens:$tokenscript_QMARK_$$?$tokenscript_resolved_active_tokens_force_set$$:$resolved_active_tokens_force_set$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$right_sidebar_STAR_$$,{pageId:$page_id$jscomp$444_props_79832$$,selected:$selected$jscomp$186$$,
tokensLib:$tokens_lib$jscomp$52$$,section:$section$jscomp$36$$,activeTokens:$active_tokens$jscomp$12_resolved_active_tokens$jscomp$3$$,layout:$layout$jscomp$25$$,drawingTool:$drawing_tool$jscomp$1$$,file:$file$jscomp$177$$,fileId:$file_id$jscomp$431$$})]})};
$app$util$zip$writer$$=function(){var $map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1726$mtype$$,"application/zip"],null)]));$map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$,
$APP.$cljs$cst$1726$mtype$$);$map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.BlobWriter($APP.$cljs$core$truth_$$($map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$)?$map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$:"application/octet-stream");return new $shadow$js$shim$module$0$0zip_js$0zip$$.ZipWriter($map__79838__$1$jscomp$inline_13637_mtype$jscomp$inline_13638_stream_writer$$)};
$app$util$zip$add$$=function($writer$jscomp$174$$,$path$jscomp$289$$,$content$jscomp$253$$){if($content$jscomp$253$$ instanceof Uint8Array)$writer$jscomp$174$$.add($path$jscomp$289$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.Uint8ArrayReader($content$jscomp$253$$));else if($content$jscomp$253$$ instanceof ArrayBuffer)$writer$jscomp$174$$.add($path$jscomp$289$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.Uint8ArrayReader(new Uint8Array($content$jscomp$253$$)));else if($content$jscomp$253$$ instanceof
Blob)$writer$jscomp$174$$.add($path$jscomp$289$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.BlobReader($content$jscomp$253$$));else if(typeof $content$jscomp$253$$==="string")$writer$jscomp$174$$.add($path$jscomp$289$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.TextReader($content$jscomp$253$$));else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("invalid data received for zip/add fn",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$1754$invalid_type$$,$APP.$cljs$cst$275$hint$$,"invalid data received for zip/add fn"],null),null])),null);};$app$util$zip$read_as_text$$=function($entry$jscomp$80$$){var $writer$jscomp$175$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.TextWriter;return $entry$jscomp$80$$.getData($writer$jscomp$175$$)};$app$util$zip$close$$=function($closeable$$){return $closeable$$.close()};
$app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$=function($children$jscomp$305_props_79843$$){var $is_disabled$jscomp$1$$=$children$jscomp$305_props_79843$$.isDisabled,$on_export$jscomp$1$$=$children$jscomp$305_props_79843$$.onExport;$children$jscomp$305_props_79843$$=$children$jscomp$305_props_79843$$.children;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export_modal__export-preview",children:[$APP.$cljs$core$truth_$$($is_disabled$jscomp$1$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-medium",className:"main_ui_workspace_tokens_export_modal__preview-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.preview")}),$APP.$cljs$core$truth_$$($is_disabled$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__disabled-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.no-tokens-themes-sets")}):$children$jscomp$305_props_79843$$,
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export_modal__export-actions",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",disabled:$is_disabled$jscomp$1$$,onClick:$on_export$jscomp$1$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export")})]})]})};
$app$main$ui$workspace$tokens$export$0$modal$single_file_tab_STAR_$$=function(){var $is_disabled$jscomp$2_tokens_data$jscomp$1$$=function(){var $G__79845$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$tokens_lib$$);return $G__79845$$==null?null:$APP.$app$common$types$tokens_lib$export_dtcg_json$$($G__79845$$)}(),$tokens_json$$=$is_disabled$jscomp$2_tokens_data$jscomp$1$$==null?null:$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$($is_disabled$jscomp$2_tokens_data$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,
$APP.$cljs$core$identity$$,$APP.$cljs$cst$294$indent$$,2]));$is_disabled$jscomp$2_tokens_data$jscomp$1$$=$APP.$cljs$core$empty_QMARK_$$($is_disabled$jscomp$2_tokens_data$jscomp$1$$);var $on_export$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_json$$)],function(){return $APP.$cljs$core$truth_$$($tokens_json$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"export-tokens",$APP.$cljs$cst$139$type$$,"single"],null))),$APP.$app$util$dom$trigger_download$$("tokens.json",$APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($tokens_json$$)?$tokens_json$$:"{}","application/json"))):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$,{isDisabled:$is_disabled$jscomp$2_tokens_data$jscomp$1$$,onExport:$on_export$jscomp$2$$,
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__json-preview",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$code_block$code_block$$,{code:$tokens_json$$,type:"json"})})})};
$app$main$ui$workspace$tokens$export$0$modal$download_tokens_zip_BANG_$$=function($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$){var $writer$jscomp$176$$=$app$util$zip$writer$$();$G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$=$APP.$cljs$core$seq$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$);for(var $G__79893_chunk__79849_79878_path_79897$$=null,$G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$=
0,$i__79851_79880$$=0;;)if($i__79851_79880$$<$G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$){var $content_79883_vec__79858_79881$$=$G__79893_chunk__79849_79878_path_79897$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__79851_79880$$),$path_79882$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content_79883_vec__79858_79881$$,0,null);$content_79883_vec__79858_79881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content_79883_vec__79858_79881$$,
1,null);$app$util$zip$add$$($writer$jscomp$176$$,$path_79882$$,$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$($content_79883_vec__79858_79881$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$,$APP.$cljs$cst$294$indent$$,2])));$i__79851_79880$$+=1}else if($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$=$APP.$cljs$core$seq$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$)?
($G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$=$APP.$cljs$core$_chunked_first$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$),$G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$=$APP.$cljs$core$_chunked_rest$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$),$G__79893_chunk__79849_79878_path_79897$$=$G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$,
$G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$=$APP.$cljs$core$count$$($G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$)):($G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$=$APP.$cljs$core$first$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$),$G__79893_chunk__79849_79878_path_79897$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$,
0,null),$G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$,1,null),$app$util$zip$add$$($writer$jscomp$176$$,$G__79893_chunk__79849_79878_path_79897$$,$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$($G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,
$APP.$cljs$core$identity$$,$APP.$cljs$cst$294$indent$$,2]))),$G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$=$APP.$cljs$core$next$$($G__79892_multi_file_entries_seq__79848_79877_seq__79848_79890__$1_temp__5825__auto___79889$$),$G__79893_chunk__79849_79878_path_79897$$=null,$G__79894_c__5548__auto___79891_content_79898_count__79850_79879_vec__79861_79896$$=0),$i__79851_79880$$=0;else break;return $app$util$zip$close$$($writer$jscomp$176$$).then(function($p1__79847_SHARP_$$){return $APP.$app$util$dom$trigger_download$$("tokens.zip",
$p1__79847_SHARP_$$)})};
$app$main$ui$workspace$tokens$export$0$modal$multi_file_tab_STAR_$$=function(){var $files$jscomp$30$$=function(){var $G__79865$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$tokens_lib$$);return $G__79865$$==null?null:$app$common$types$tokens_lib$export_dtcg_multi_file$$($G__79865$$)}(),$is_disabled$jscomp$3$$=$APP.$cljs$core$empty_QMARK_$$($files$jscomp$30$$)||$APP.$cljs$core$every_QMARK_$$(function($p__79866_v$jscomp$676$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79866_v$jscomp$676$$,0,
null);$p__79866_v$jscomp$676$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79866_v$jscomp$676$$,1,null);return $APP.$cljs$core$empty_QMARK_$$($p__79866_v$jscomp$676$$)},$files$jscomp$30$$),$on_export$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$30$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"export-tokens",$APP.$cljs$cst$139$type$$,"multiple"],null)));return $app$main$ui$workspace$tokens$export$0$modal$download_tokens_zip_BANG_$$($files$jscomp$30$$)});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$,{onExport:$on_export$jscomp$3$$,isDisabled:$is_disabled$jscomp$3$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__preview-container",children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_export_modal__file-list",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$198$$,$p__79870_path$jscomp$291$$){$p__79870_path$jscomp$291$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79870_path$jscomp$291$$,0,null);$out_arr__44124__auto__$jscomp$198$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_tokens_export_modal__file-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__file-icon",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"document"})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$p__79870_path$jscomp$291$$,className:"main_ui_workspace_tokens_export_modal__file-name",children:$p__79870_path$jscomp$291$$})]},$p__79870_path$jscomp$291$$));return $out_arr__44124__auto__$jscomp$198$$},[],$files$jscomp$30$$)})})})};
$app$main$ui$workspace$tokens$export$0$modal$export_modal_body_STAR_$$=function(){var $selected_tab_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("single"),$selected_tab$jscomp$1$$=$APP.$cljs$core$_deref$$($selected_tab_STAR_$jscomp$1$$),$on_change_tab$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79874_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected_tab_STAR_$jscomp$1$$,$p1__79874_SHARP_$$)}),$tabs$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.single-file"),$APP.$cljs$cst$266$id$$,"single"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.multiple-files"),
$APP.$cljs$cst$266$id$$,"multiple"],null)],null)}),$JSCompiler_temp_const$jscomp$1867$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_export_modal__export-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export-tokens")});a:switch($selected_tab$jscomp$1$$){case "single":var $JSCompiler_inline_result$jscomp$1868$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$single_file_tab_STAR_$$,
{});break a;case "multiple":$JSCompiler_inline_result$jscomp$1868$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$multi_file_tab_STAR_$$,{});break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($selected_tab$jscomp$1$$)].join(""));}return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export_modal__export-modal-wrapper",children:[$JSCompiler_temp_const$jscomp$1867$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,
{tabs:$tabs$jscomp$7$$,selected:$selected_tab$jscomp$1$$,onChange:$on_change_tab$jscomp$3$$,children:$JSCompiler_inline_result$jscomp$1868$$})]})};
$app$main$ui$workspace$tokens$export$0$export_modal_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_export__close-btn",onClick:$APP.$app$main$data$modal$hide_BANG_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$export_modal_body_STAR_$$,{})]})})};
$app$main$data$workspace$tokens$import_export$group_by_value$$=function($m$jscomp$239$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$168$$,$p__79908_v$jscomp$677$$){var $k$jscomp$697$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79908_v$jscomp$677$$,0,null);$p__79908_v$jscomp$677$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79908_v$jscomp$677$$,1,null);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$168$$,
$p__79908_v$jscomp$677$$,$APP.$cljs$core$conj$$,$k$jscomp$697$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$m$jscomp$239$$)};
$app$main$data$workspace$tokens$import_export$show_unknown_types_warning$$=function($unknown_tokens$jscomp$1$$){var $type__GT_tokens$$=$app$main$data$workspace$tokens$import_export$group_by_value$$($unknown_tokens$jscomp$1$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.import-export",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unsupported token types found during import"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2100$tokens$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__79913_type$jscomp$702$$){var $path$jscomp$292$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79913_type$jscomp$702$$,
0,null);$p__79913_type$jscomp$702$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79913_type$jscomp$702$$,1,null);return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$292$$)," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__79913_type$jscomp$702$$),")"].join("")},$unknown_tokens$jscomp$1$$))],null)],null)}),null,"app.main.data.workspace.tokens.import-export",$APP.$cljs$cst$1162$warn$$,!1);return $APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.unknown-token-type-message"),$APP.$cljs$cst$5338$detail$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",function(){return function $app$main$data$workspace$tokens$import_export$show_unknown_types_warning_$_iter__79917$$($s__79918$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$399$$=$APP.$cljs$core$seq$$($s__79918$$);if($temp__5825__auto__$jscomp$399$$){var $s__79918__$2$$=
$temp__5825__auto__$jscomp$399$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__79918__$2$$)){var $c__5501__auto__$jscomp$51$$=$APP.$cljs$core$_chunked_first$$($s__79918__$2$$),$size__5502__auto__$jscomp$51$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$51$$),$b__79920$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$51$$);return function(){for(var $i__79919$$=0;;)if($i__79919$$<$size__5502__auto__$jscomp$51$$){var $vec__79921$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$51$$,$i__79919$$),
$token_type$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79921$$,0,null),$token_paths$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79921$$,1,null);$APP.$cljs$core$chunk_append$$($b__79920$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.unknown-token-type-section",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$18$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.warning-count",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($token_paths$jscomp$1$$))]))]))),"\x3cul\x3e",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__79912_SHARP_$$){return["\x3cli\x3e",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__79912_SHARP_$$),
"\x3c/li\x3e"].join("")}}($i__79919$$,$vec__79921$$,$token_type$jscomp$18$$,$token_paths$jscomp$1$$,$c__5501__auto__$jscomp$51$$,$size__5502__auto__$jscomp$51$$,$b__79920$$,$s__79918__$2$$,$temp__5825__auto__$jscomp$399$$,$type__GT_tokens$$),$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($token_paths$jscomp$1$$)))),"\x3c/ul\x3e"].join(""));$i__79919$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__79920$$),$app$main$data$workspace$tokens$import_export$show_unknown_types_warning_$_iter__79917$$($APP.$cljs$core$_chunked_rest$$($s__79918__$2$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__79920$$),null)}var $vec__79924$$=$APP.$cljs$core$first$$($s__79918__$2$$),$token_type$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79924$$,0,null),$token_paths$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79924$$,1,null);return $APP.$cljs$core$cons$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.unknown-token-type-section",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$17$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.warning-count",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($token_paths$$))]))]))),"\x3cul\x3e",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__79912_SHARP_$jscomp$1$$){return["\x3cli\x3e",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__79912_SHARP_$jscomp$1$$),"\x3c/li\x3e"].join("")}}($vec__79924$$,$token_type$jscomp$17$$,$token_paths$$,$s__79918__$2$$,$temp__5825__auto__$jscomp$399$$,$type__GT_tokens$$),$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($token_paths$$)))),"\x3c/ul\x3e"].join(""),$app$main$data$workspace$tokens$import_export$show_unknown_types_warning_$_iter__79917$$($APP.$cljs$core$rest$$($s__79918__$2$$)))}return null}},null,null)}($type__GT_tokens$$)}()),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$],null))};
$app$main$data$workspace$tokens$import_export$decode_json$$=function($json_string$$){try{return $APP.$app$common$json$decode$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($json_string$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$],null)]))}catch($e79927$$){if($e79927$$ instanceof Error)throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4575$error_DOT_import_SLASH_json_parse_error$$,
$json_string$$,$e79927$$);throw $e79927$$;}};
$app$main$data$workspace$tokens$import_export$parse_decoded_json$$=function($decoded_json$jscomp$8$$,$e$jscomp$358_file_name$jscomp$11$$){try{var $G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$=!$APP.$cljs$core$contains_QMARK_$$($decoded_json$jscomp$8$$,"$metadata")&&!$APP.$cljs$core$contains_QMARK_$$($decoded_json$jscomp$8$$,"$themes");var $json_format$jscomp$inline_13643$$=
$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$($decoded_json$jscomp$8$$);if($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2131$json_format_SLASH_legacy$$,$json_format$jscomp$inline_13643$$))var $JSCompiler_temp$jscomp$inline_13644$$=$app$common$types$tokens_lib$parse_single_set_dtcg_json$$($e$jscomp$358_file_name$jscomp$11$$,
$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$($decoded_json$jscomp$8$$));else{if($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2132$json_format_SLASH_dtcg$$,$json_format$jscomp$inline_13643$$))var $JSCompiler_temp$jscomp$inline_13645$$=$app$common$types$tokens_lib$parse_single_set_dtcg_json$$($e$jscomp$358_file_name$jscomp$11$$,
$decoded_json$jscomp$8$$);else{if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2131$json_format_SLASH_legacy$$,$json_format$jscomp$inline_13643$$)){var $sets_data$jscomp$inline_13647$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($decoded_json$jscomp$8$$,"$themes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["$metadata"])),$other_data$jscomp$inline_13648$$=$APP.$cljs$core$select_keys$$($decoded_json$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["$themes","$metadata"],null)),$dtcg_sets_data$jscomp$inline_13649$$=$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$($sets_data$jscomp$inline_13647$$);var $JSCompiler_temp$jscomp$inline_13646$$=$APP.$app$common$types$tokens_lib$parse_multi_set_dtcg_json$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$other_data$jscomp$inline_13648$$,$dtcg_sets_data$jscomp$inline_13649$$])))}else $JSCompiler_temp$jscomp$inline_13646$$=
$APP.$app$common$types$tokens_lib$parse_multi_set_dtcg_json$$($decoded_json$jscomp$8$$);$JSCompiler_temp$jscomp$inline_13645$$=$JSCompiler_temp$jscomp$inline_13646$$}$JSCompiler_temp$jscomp$inline_13644$$=$JSCompiler_temp$jscomp$inline_13645$$}return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2139$tokens_lib$$,$JSCompiler_temp$jscomp$inline_13644$$,$cljs$cst$5823$unknown_tokens$$,$app$common$types$tokens_lib$get_tokens_of_unknown_type$$($decoded_json$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)],
null)}catch($e79928$$){if($e79928$$ instanceof Error)throw $e$jscomp$358_file_name$jscomp$11$$=$e79928$$,$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$=$APP.$cljs$core$ex_data$$($e$jscomp$358_file_name$jscomp$11$$),$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$=
$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$==null?null:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$,$APP.$cljs$cst$570$errors$$],null)),$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$=$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$==null?null:$APP.$cljs$core$first$$($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$),
$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$297$in$$.$cljs$core$IFn$_invoke$arity$1$($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$),new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$],null))?$app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4586$error_DOT_import_SLASH_invalid_token_name$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$),$e$jscomp$358_file_name$jscomp$11$$):null,$APP.$cljs$core$truth_$$($G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$)?
$G__79907$jscomp$inline_13653_G__79907__$1$jscomp$inline_13654_or__5025__auto__$jscomp$inline_9027_schema_error$jscomp$inline_13652_single_set_QMARK_$jscomp$inline_13642$$:$app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$2134$error_DOT_import_SLASH_invalid_json_data$$,$decoded_json$jscomp$8$$,$e$jscomp$358_file_name$jscomp$11$$);throw $e79928$$;}};
$app$main$data$workspace$tokens$import_export$validate_library$$=function($map__79930__$1_p__79929_unknown_tokens$jscomp$2$$){$map__79930__$1_p__79929_unknown_tokens$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__79930__$1_p__79929_unknown_tokens$jscomp$2$$);var $tokens_lib$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79930__$1_p__79929_unknown_tokens$jscomp$2$$,$APP.$cljs$cst$2139$tokens_lib$$);$map__79930__$1_p__79929_unknown_tokens$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79930__$1_p__79929_unknown_tokens$jscomp$2$$,
$cljs$cst$5823$unknown_tokens$$);$APP.$cljs$core$truth_$$($map__79930__$1_p__79929_unknown_tokens$jscomp$2$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$import_export$show_unknown_types_warning$$($map__79930__$1_p__79929_unknown_tokens$jscomp$2$$));try{var $tokens_tree$jscomp$10$$=$APP.$app$common$types$tokens_lib$get_all_tokens_map$$($tokens_lib$jscomp$53$$),$resolved_tokens$jscomp$25$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens_tree$jscomp$10$$)):$app$main$data$style_dictionary$resolve_tokens_with_verbose_errors$$($tokens_tree$jscomp$10$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($sd_error$$){var $first__79906$jscomp$inline_9032_reference_errors_vec__79904$jscomp$inline_9030$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($sd_error$$,"\n");var $first__79906__$1$jscomp$inline_9034_seq__79905$jscomp$inline_9031$$=
$APP.$cljs$core$seq$$($first__79906$jscomp$inline_9032_reference_errors_vec__79904$jscomp$inline_9030$$);$first__79906$jscomp$inline_9032_reference_errors_vec__79904$jscomp$inline_9030$$=$APP.$cljs$core$first$$($first__79906__$1$jscomp$inline_9034_seq__79905$jscomp$inline_9031$$);var $seq__79905__$1$jscomp$inline_9033_seq__79905__$2$jscomp$inline_9035$$=$APP.$cljs$core$next$$($first__79906__$1$jscomp$inline_9034_seq__79905$jscomp$inline_9031$$);$first__79906__$1$jscomp$inline_9034_seq__79905$jscomp$inline_9031$$=
$APP.$cljs$core$first$$($seq__79905__$1$jscomp$inline_9033_seq__79905__$2$jscomp$inline_9035$$);$seq__79905__$1$jscomp$inline_9033_seq__79905__$2$jscomp$inline_9035$$=$APP.$cljs$core$next$$($seq__79905__$1$jscomp$inline_9033_seq__79905__$2$jscomp$inline_9035$$);$first__79906$jscomp$inline_9032_reference_errors_vec__79904$jscomp$inline_9030$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first__79906$jscomp$inline_9032_reference_errors_vec__79904$jscomp$inline_9030$$,"Error: ")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first__79906__$1$jscomp$inline_9034_seq__79905$jscomp$inline_9031$$,
"Reference Errors:")?$seq__79905__$1$jscomp$inline_9033_seq__79905__$2$jscomp$inline_9035$$:null;if($APP.$cljs$core$truth_$$($first__79906$jscomp$inline_9032_reference_errors_vec__79904$jscomp$inline_9030$$))return(0,$APP.$beicon$v2$core$of$$)($tokens_lib$jscomp$53$$);throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4587$error_DOT_import_SLASH_style_dictionary_unknown_error$$,$sd_error$$,$sd_error$$);},$APP.$beicon$v2$core$map$$(function(){return $tokens_lib$jscomp$53$$},
$resolved_tokens$jscomp$25$$))}catch($e79931$$){if($e79931$$ instanceof Error)throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4587$error_DOT_import_SLASH_style_dictionary_unknown_error$$,"",$e79931$$);throw $e79931$$;}};
$app$main$data$workspace$tokens$import_export$import_file_stream$$=function($file_path$$,$file_text$$){var $file_name$jscomp$12$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$butlast$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($file_path$$,".")));return $APP.$beicon$v2$core$mapcat$$($app$main$data$workspace$tokens$import_export$validate_library$$,$APP.$beicon$v2$core$map$$(function($p1__79933_SHARP_$$){return $app$main$data$workspace$tokens$import_export$parse_decoded_json$$($p1__79933_SHARP_$$,
$file_name$jscomp$12$$)},$APP.$beicon$v2$core$map$$($app$main$data$workspace$tokens$import_export$decode_json$$,$file_text$$)))};
$app$main$data$workspace$tokens$import_export$import_directory_stream$$=function($file_stream$$){return $APP.$beicon$v2$core$mapcat$$($app$main$data$workspace$tokens$import_export$validate_library$$,$APP.$beicon$v2$core$map$$(function($merged_json$$){return $app$main$data$workspace$tokens$import_export$parse_decoded_json$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($merged_json$$))?$APP.$cljs$core$val$$($APP.$cljs$core$first$$($merged_json$$)):$merged_json$$,
$APP.$cljs$core$ffirst$$($merged_json$$))},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($merged_json$jscomp$1$$,$decoded_json$jscomp$9$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($decoded_json$jscomp$9$$))?$merged_json$jscomp$1$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($merged_json$jscomp$1$$,$decoded_json$jscomp$9$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$map$$(function($file_text$jscomp$1_p__79943$$){var $file_path$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$1_p__79943$$,0,null);$file_text$jscomp$1_p__79943$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$1_p__79943$$,1,null);var $path$jscomp$inline_13656_set_name$jscomp$30$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("/",$APP.$cljs$core$rest$$($APP.$app$common$path_names$split_path$$($file_path$jscomp$1$$)));$path$jscomp$inline_13656_set_name$jscomp$30$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$butlast$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($path$jscomp$inline_13656_set_name$jscomp$30$$,
".")));try{return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$path$jscomp$inline_13656_set_name$jscomp$30$$,$app$main$data$workspace$tokens$import_export$decode_json$$($file_text$jscomp$1_p__79943$$)])}catch($e79947$$){if($e79947$$ instanceof Error)return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$file_path$jscomp$1$$,$APP.$cljs$cst$849$error$$,$e79947$$],null);throw $e79947$$;}},$file_stream$$))))};
$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$=function($type$jscomp$703$$,$tokens_lib_stream$$){$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($tokens_lib_stream$$,function($lib$jscomp$15$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-tokens",$APP.$cljs$cst$139$type$$,$type$jscomp$703$$],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$import_tokens_lib$$($lib$jscomp$15$$)]));return $APP.$app$main$data$modal$hide_BANG_$$()},function($err$jscomp$51$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$app$main$data$workspace$tokens$errors$humanize_errors$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$ex_data$$($err$jscomp$51$$)],null)),$APP.$cljs$cst$5338$detail$$,$app$main$data$workspace$tokens$errors$detail_errors$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$ex_data$$($err$jscomp$51$$)],null)),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$],null)))})};
$app$main$ui$workspace$tokens$import$0$modal$import_type_dropdown_STAR_$$=function($file_type_options_initial_option_props_79960$$){var $options$jscomp$634$$=$file_type_options_initial_option_props_79960$$.options,$button_text$jscomp$1_text_render$$=$file_type_options_initial_option_props_79960$$.textRender,$default$$jscomp$92$$=$file_type_options_initial_option_props_79960$$.default,$on_click$jscomp$54$$=$file_type_options_initial_option_props_79960$$.onClick;$file_type_options_initial_option_props_79960$$=
function(){var $or__5025__auto__$jscomp$1248$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79958_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__79958_SHARP_$$),$default$$jscomp$92$$)},$options$jscomp$634$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1248$$)?$or__5025__auto__$jscomp$1248$$:$APP.$cljs$core$first$$($options$jscomp$634$$)}();var $selected_option_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($file_type_options_initial_option_props_79960$$),$selected_option$jscomp$4$$=$APP.$cljs$core$_deref$$($selected_option_STAR_$$),$show_dropdown_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$file_type_options_initial_option_props_79960$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$634$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($option$jscomp$23$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$23$$)),$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$23$$),$APP.$cljs$cst$4564$aria_label$$,$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$23$$)],null)},$options$jscomp$634$$)});$button_text$jscomp$1_text_render$$=$APP.$cljs$core$truth_$$($button_text$jscomp$1_text_render$$)?
$button_text$jscomp$1_text_render$$.$cljs$core$IFn$_invoke$arity$1$?$button_text$jscomp$1_text_render$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$):$button_text$jscomp$1_text_render$$($selected_option$jscomp$4$$):$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$);var $toggle_dropdown$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$605$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$605$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$605$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_QMARK_$jscomp$6$$,$APP.$cljs$core$not$$)}),$close_dropdown$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$6$$,!1)}),$handle_option_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$634$$)],function($event$jscomp$606_option$jscomp$24$$){var $option_id$jscomp$1$$=
$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_current_target$$($event$jscomp$606_option$jscomp$24$$),"id");$event$jscomp$606_option$jscomp$24$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79959_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__79959_SHARP_$$)),$option_id$jscomp$1$$)},$options$jscomp$634$$));
$close_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$close_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$close_dropdown$jscomp$5$$();return $APP.$cljs$core$truth_$$($event$jscomp$606_option$jscomp$24$$)?$APP.$cljs$core$reset_BANG_$$($selected_option_STAR_$$,$event$jscomp$606_option$jscomp$24$$):null}),$handle_main_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$54$$),$APP.$rumext$v2$adapt$$($selected_option$jscomp$4$$)],
function($G__79965_event$jscomp$607$$){$APP.$app$util$dom$prevent_default$$($G__79965_event$jscomp$607$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected_option$jscomp$4$$)?$on_click$jscomp$54$$:$selected_option$jscomp$4$$)?($G__79965_event$jscomp$607$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$),$on_click$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$54$$.$cljs$core$IFn$_invoke$arity$1$($G__79965_event$jscomp$607$$):$on_click$jscomp$54$$($G__79965_event$jscomp$607$$)):
null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_modal__dropdown-btn-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_workspace_tokens_import_modal__dropdown-btn",onClick:$handle_main_click$$,children:$button_text$jscomp$1_text_render$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_workspace_tokens_import_modal__dropdown-trigger-btn",
icon:"arrow-down",onClick:$toggle_dropdown$jscomp$4$$,"aria-label":"Show options"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_dropdown_QMARK_$jscomp$6$$),"on-close":$close_dropdown$jscomp$5$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,{options:$file_type_options_initial_option_props_79960$$,selected:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$)),
onClick:$handle_option_click$$,setRef:function(){return null}})})]})};$app$main$ui$workspace$tokens$import$0$modal$has_token_files_QMARK_$$=function($file_paths$$){var $and__5023__auto__$jscomp$859$$=$APP.$cljs$core$seq$$($file_paths$$);return $and__5023__auto__$jscomp$859$$?$APP.$cljs$core$some$$(function($p1__79966_SHARP_$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($p1__79966_SHARP_$$,".json")},$file_paths$$):$and__5023__auto__$jscomp$859$$};
$app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$=function($file_stream$jscomp$1$$){return $APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$identity$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file_entries_file_paths$jscomp$1$$){$file_entries_file_paths$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$file_entries_file_paths$jscomp$1$$);if($APP.$cljs$core$truth_$$($app$main$ui$workspace$tokens$import$0$modal$has_token_files_QMARK_$$($file_entries_file_paths$jscomp$1$$)))return null;
throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4589$error_DOT_import_SLASH_no_token_files_found$$,$file_entries_file_paths$jscomp$1$$,null);},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$169$$,$file_text$jscomp$2_p__79969$$){var $file_path$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$2_p__79969$$,0,null);$file_text$jscomp$2_p__79969$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$2_p__79969$$,
1,null);return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$169$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_path$jscomp$2$$,$file_text$jscomp$2_p__79969$$],null))},$APP.$cljs$core$PersistentVector$EMPTY$$,$file_stream$jscomp$1$$)))};
$app$main$ui$workspace$tokens$import$0$modal$import_modal_body_STAR_$$=function(){var $file_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$dir_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$zip_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$on_display_file_explorer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($file_input_ref$$))}),$on_display_dir_explorer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($dir_input_ref$$))}),
$on_display_zip_explorer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($zip_input_ref$$))}),$handle_import_action$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_display_file_explorer$$),$APP.$rumext$v2$adapt$$($on_display_dir_explorer$$),$APP.$rumext$v2$adapt$$($on_display_zip_explorer$$)],function($val$jscomp$218$$){switch($val$jscomp$218$$ instanceof $APP.$cljs$core$Keyword$$?
$val$jscomp$218$$.$fqn$:null){case "file":return $on_display_file_explorer$$.$cljs$core$IFn$_invoke$arity$0$?$on_display_file_explorer$$.$cljs$core$IFn$_invoke$arity$0$():$on_display_file_explorer$$();case "folder":return $on_display_dir_explorer$$.$cljs$core$IFn$_invoke$arity$0$?$on_display_dir_explorer$$.$cljs$core$IFn$_invoke$arity$0$():$on_display_dir_explorer$$();case "zip":return $on_display_zip_explorer$$.$cljs$core$IFn$_invoke$arity$0$?$on_display_zip_explorer$$.$cljs$core$IFn$_invoke$arity$0$():
$on_display_zip_explorer$$();default:return null}}),$on_import_directory$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$608_files$jscomp$31$$){$event$jscomp$608_files$jscomp$31$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$178$$){var $name$jscomp$474$$=$file$jscomp$178$$.name;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$178$$.type,"application/json")||$APP.$cuerdas$core$ends_with_QMARK_$$($name$jscomp$474$$,
".json")},$APP.$app$util$dom$get_files$$($APP.$app$util$dom$get_target$$($event$jscomp$608_files$jscomp$31$$)));$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$("multiple",$app$main$data$workspace$tokens$import_export$import_directory_stream$$($app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$($APP.$beicon$v2$core$mapcat$$(function($file$jscomp$179$$){return $APP.$beicon$v2$core$map$$(function($file_text$jscomp$3$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$179$$.webkitRelativePath,$file_text$jscomp$3$$],null)},$app$util$webapi$read_file_as_text$$($file$jscomp$179$$))},$APP.$beicon$v2$core$from$$($event$jscomp$608_files$jscomp$31$$)))));return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($dir_input_ref$$),"")}),$on_import_zip_file$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$609_zipfile$$){$event$jscomp$609_zipfile$$=$APP.$cljs$core$first$$($APP.$app$util$dom$get_files$$($APP.$app$util$dom$get_target$$($event$jscomp$609_zipfile$$)));
var $zipfile_name$$=$APP.$cuerdas$core$strip_suffix$$($event$jscomp$609_zipfile$$.name,".zip");$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$("zip",$app$main$data$workspace$tokens$import_export$import_directory_stream$$($app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$($APP.$beicon$v2$core$mapcat$$(function($file_content_zip_reader$$){$file_content_zip_reader$$=$app$util$zip$reader$$($file_content_zip_reader$$);return $APP.$beicon$v2$core$finalize$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$zip$close$$,
$file_content_zip_reader$$),$APP.$beicon$v2$core$mapcat$$(function($entries$jscomp$47$$){return $APP.$beicon$v2$core$merge_map$$(function($content_promise_entry$jscomp$81$$){var $filename$jscomp$12$$=""+($zipfile_name$$??"")+"/"+($content_promise_entry$jscomp$81$$.filename??"");$content_promise_entry$jscomp$81$$=$app$util$zip$read_as_text$$($content_promise_entry$jscomp$81$$);return $APP.$beicon$v2$core$from$$($content_promise_entry$jscomp$81$$.then(function($text$jscomp$146$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$filename$jscomp$12$$,$text$jscomp$146$$],null)}))},$APP.$beicon$v2$core$filter$$(function($entry$jscomp$82$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($entry$jscomp$82$$.filename,".json")},$APP.$beicon$v2$core$from$$($entries$jscomp$47$$)))},$APP.$beicon$v2$core$from$$($file_content_zip_reader$$.getEntries())))},$APP.$app$util$webapi$read_file_as_array_buffer$$($event$jscomp$609_zipfile$$)))));return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($zip_input_ref$$),
"")}),$on_import_json_file$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$610_file$jscomp$180$$){$event$jscomp$610_file$jscomp$180$$=$APP.$cljs$core$first$$($APP.$app$util$dom$get_files$$($APP.$app$util$dom$get_target$$($event$jscomp$610_file$jscomp$180$$)));$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$("single",$app$main$data$workspace$tokens$import_export$import_file_stream$$($event$jscomp$610_file$jscomp$180$$.name,$app$util$webapi$read_file_as_text$$($event$jscomp$610_file$jscomp$180$$)));
return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($file_input_ref$$),"")}),$render_button_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($option$jscomp$25$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.import-button-prefix",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$25$$)]))});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_import_modal__import-modal-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_import_modal__import-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-tokens")}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"ul",typography:"body-medium",
className:"main_ui_workspace_tokens_import_modal__import-description",children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-single-file")}),(0,$APP.$rumext$v2$jsx$$)("li",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-multiple-files")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{type:$APP.$cljs$cst$2312$context$$,
appearance:"neutral",level:"default",isHtml:!0,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-warning")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_modal__import-actions",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"file",ref:$file_input_ref$$,style:{display:"none"},accept:".json",onChange:$on_import_json_file$$}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"file",ref:$zip_input_ref$$,style:{display:"none"},accept:".zip",
onChange:$on_import_zip_file$$}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"file",ref:$dir_input_ref$$,style:{display:"none"},accept:"",webkitdirectory:"true",onChange:$on_import_directory$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$import$0$modal$import_type_dropdown_STAR_$$,
{options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-menu-json-option"),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$208$file$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-menu-zip-option"),
$APP.$cljs$cst$260$value$$,$cljs$cst$5824$zip$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-menu-folder-option"),$APP.$cljs$cst$260$value$$,$cljs$cst$5825$folder$$],null)],null),onClick:$handle_import_action$$,textRender:$render_button_text$$,"default":$APP.$cljs$cst$208$file$$})]})]})};
$app$main$ui$workspace$tokens$import$0$import_modal_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_import__close-btn",onClick:$APP.$app$main$data$modal$hide_BANG_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$import$0$modal$import_modal_body_STAR_$$,{})]})})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$=function($tokens$jscomp$58_tokens__$1$jscomp$9$$,$prev_token$jscomp$2$$,$token_name$jscomp$34$$,$value$jscomp$944$$){var $valid_token_name_QMARK_$$=function(){var $and__5023__auto__$jscomp$860$$=typeof $token_name$jscomp$34$$==="string";return $and__5023__auto__$jscomp$860$$?$APP.$cljs$core$re_matches$$($APP.$app$common$types$token$token_name_validation_regex$$,$token_name$jscomp$34$$):$and__5023__auto__$jscomp$860$$}(),
$token$jscomp$168$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$944$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$not$$($valid_token_name_QMARK_$$)||$APP.$cuerdas$core$blank_QMARK_$$($token_name$jscomp$34$$)?"__PENPOT__TOKEN__NAME__PLACEHOLDER__":$token_name$jscomp$34$$],null);$tokens$jscomp$58_tokens__$1$jscomp$9$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$58_tokens__$1$jscomp$9$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$2$$)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$168$$),function($p1__79932_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__79932_SHARP_$$,$prev_token$jscomp$2$$,
$token$jscomp$168$$]))]))});return $APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$38_map__79934_resolved_tokens$jscomp$26$$){$errors$jscomp$38_map__79934_resolved_tokens$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$38_map__79934_resolved_tokens$jscomp$26$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$168$$));var $map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$38_map__79934_resolved_tokens$jscomp$26$$);
$errors$jscomp$38_map__79934_resolved_tokens$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$,$APP.$cljs$cst$570$errors$$);$map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$,$APP.$cljs$cst$4605$resolved_value$$);$map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$):$map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$;return $APP.$cljs$core$truth_$$($map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,
$map__79934__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$first$$($errors$jscomp$38_map__79934_resolved_tokens$jscomp$26$$)],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$58_tokens__$1$jscomp$9$$)):$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$58_tokens__$1$jscomp$9$$))};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$=function($hex$jscomp$17_hex__$1$jscomp$3$$){var $alpha$jscomp$20_temp__5825__auto__$jscomp$402$$=$APP.$app$main$data$tinycolor$valid_color$$($hex$jscomp$17_hex__$1$jscomp$3$$);if($APP.$cljs$core$truth_$$($alpha$jscomp$20_temp__5825__auto__$jscomp$402$$)){$hex$jscomp$17_hex__$1$jscomp$3$$=$APP.$app$main$data$tinycolor$__GT_hex_string$$($alpha$jscomp$20_temp__5825__auto__$jscomp$402$$);$alpha$jscomp$20_temp__5825__auto__$jscomp$402$$=
$APP.$app$main$data$tinycolor$alpha$$($alpha$jscomp$20_temp__5825__auto__$jscomp$402$$);var $b$jscomp$363_vec__79936$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$17_hex__$1$jscomp$3$$),$r$jscomp$141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$363_vec__79936$$,0,null),$g$jscomp$164$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$363_vec__79936$$,1,null);$b$jscomp$363_vec__79936$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$363_vec__79936$$,
2,null);var $v$jscomp$678_vec__79939$$=$app$common$types$color$hex__GT_hsv$$($hex$jscomp$17_hex__$1$jscomp$3$$),$h$jscomp$184$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$678_vec__79939$$,0,null),$s$jscomp$587$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$678_vec__79939$$,1,null);$v$jscomp$678_vec__79939$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$678_vec__79939$$,2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,8,
[$APP.$cljs$cst$2687$hex$$,$hex$jscomp$17_hex__$1$jscomp$3$$,$APP.$cljs$cst$1743$r$$,$r$jscomp$141$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$164$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$363_vec__79936$$,$APP.$cljs$cst$1899$h$$,$h$jscomp$184$$,$APP.$cljs$cst$4168$s$$,$s$jscomp$587$$,$APP.$cljs$cst$3670$v$$,$v$jscomp$678_vec__79939$$,$APP.$cljs$cst$746$alpha$$,$alpha$jscomp$20_temp__5825__auto__$jscomp$402$$],null)}return null};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$=function($props_79948_wrapper_node_ref$$){var $on_change$jscomp$84$$=$props_79948_wrapper_node_ref$$.onChange,$color$jscomp$184$$=$props_79948_wrapper_node_ref$$.color;$props_79948_wrapper_node_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $dragging_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_start_drag$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$3$$,
!0)}),$on_finish_drag$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$3$$,!1)}),$internal_color_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$($color$jscomp$184$$)}),$internal_color$jscomp$1$$=$APP.$cljs$core$_deref$$($internal_color_STAR_$jscomp$1$$),$on_change_SINGLEQUOTE_$jscomp$10$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$84$$)],function($map__79953__$1_p__79952$$){$map__79953__$1_p__79952$$=$APP.$cljs$core$__destructure_map$$($map__79953__$1_p__79952$$);var $hex$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79953__$1_p__79952$$,$APP.$cljs$cst$2687$hex$$),$alpha$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79953__$1_p__79952$$,$APP.$cljs$cst$746$alpha$$),$dragging_QMARK_$jscomp$9$$=
$APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$3$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$9$$)?$hex$jscomp$18$$:$dragging_QMARK_$jscomp$9$$))return null;$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$jscomp$1$$,$map__79953__$1_p__79952$$);return $on_change$jscomp$84$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$84$$.$cljs$core$IFn$_invoke$arity$2$($hex$jscomp$18$$,$alpha$jscomp$21$$):$on_change$jscomp$84$$($hex$jscomp$18$$,$alpha$jscomp$21$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$184$$)],
function(){var $temp__5825__auto__$jscomp$403$$=$APP.$app$main$data$tinycolor$valid_color$$($color$jscomp$184$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$403$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$tinycolor$__GT_hex_string$$($temp__5825__auto__$jscomp$403$$),$APP.$cljs$cst$2687$hex$$.$cljs$core$IFn$_invoke$arity$1$($internal_color$jscomp$1$$))?null:$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$jscomp$1$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$($temp__5825__auto__$jscomp$403$$)):
null});$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$($props_79948_wrapper_node_ref$$,$internal_color$jscomp$1$$);return(0,$APP.$rumext$v2$jsx$$)("div",{ref:$props_79948_wrapper_node_ref$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$,{color:$internal_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$6$$,onFinishDrag:$on_finish_drag$jscomp$6$$,onChange:$on_change_SINGLEQUOTE_$jscomp$10$$})})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$color_input_STAR_$$=function($props_79955_touched_QMARK_$jscomp$7$$){var $error$jscomp$144_name$jscomp$475$$=void 0,$token$jscomp$169$$=void 0,$tokens$jscomp$59$$=void 0,$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$=void 0;({name:$error$jscomp$144_name$jscomp$475$$,tokens:$tokens$jscomp$59$$,token:$token$jscomp$169$$,...$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$}=$props_79955_touched_QMARK_$jscomp$7$$);
var $form$jscomp$189$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$5$$=$error$jscomp$144_name$jscomp$475$$,$token_name$jscomp$35$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$props_79955_touched_QMARK_$jscomp$7$$=function(){var $and__5023__auto__$jscomp$862$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$189$$)),$input_name$jscomp$5$$);return $and__5023__auto__$jscomp$862$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$5$$],null)):$and__5023__auto__$jscomp$862$$}();$error$jscomp$144_name$jscomp$475$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$5$$],null));var $extra_error$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,
$input_name$jscomp$5$$],null)),$value$jscomp$945$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$5$$],null),""),$color_resolved$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$cljs$cst$5826$color_result$$],null),""),$hint$jscomp$21_valid_color$$=function(){var $or__5025__auto__$jscomp$1249$$=$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$945$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1249$$)?$or__5025__auto__$jscomp$1249$$:$APP.$app$main$data$tinycolor$valid_color$$($color_resolved$$)}(),$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);
a:switch($APP.$cljs$cst$3184$theme$$.$cljs$core$IFn$_invoke$arity$1$($default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$)){case "light":$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$="#eef0f2";break a;default:$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$="#2e3434"}$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$=$APP.$cljs$core$truth_$$($hint$jscomp$21_valid_color$$)?$APP.$app$main$data$tinycolor$__GT_hex_string$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$21_valid_color$$)):
$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$;var $alpha$jscomp$22_swatch$$=$APP.$cljs$core$truth_$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$21_valid_color$$))?$APP.$app$main$data$tinycolor$alpha$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$21_valid_color$$)):1,$resolve_stream$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$169$$)],function(){var $temp__5823__auto__$jscomp$240$$=
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$169$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$240$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$240$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$hint$jscomp$21_valid_color$$=$APP.$cljs$core$_deref$$($hint_STAR_$$);var $color_ramp_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$color_ramp_open_QMARK_$$=$APP.$cljs$core$_deref$$($color_ramp_open_STAR_$$),$on_change$jscomp$85_on_click_swatch$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_ramp_open_QMARK_$$)],function(){return $APP.$cljs$core$reset_BANG_$$($color_ramp_open_STAR_$$,$APP.$cljs$core$not$$($color_ramp_open_QMARK_$$))});$alpha$jscomp$22_swatch$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1298$color$$,$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$,$APP.$cljs$cst$1734$opacity$$,$alpha$jscomp$22_swatch$$],null),showTooltip:!1,"data-testid":"token-form-color-bullet",className:"main_ui_workspace_tokens_management_forms_controls_color_input__slot-start",onClick:$on_change$jscomp$85_on_click_swatch$$});$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$5$$),$APP.$rumext$v2$adapt$$($value$jscomp$945$$)],function($JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$,$alpha__$1$$){var $G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$=$value$jscomp$945$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$945$$),$prev_computed_color_to_rgba_QMARK_$$=$APP.$cljs$core$truth_$$($G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$)?
null:$value$jscomp$945$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$945$$);$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$=$APP.$cljs$core$truth_$$($G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$)?$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$:$prev_computed_color_to_rgba_QMARK_$$;$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$=$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$==
null?null:$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$.getFormat();$prev_computed_color_to_rgba_QMARK_$$=$alpha__$1$$<1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$,"hex")||$APP.$cljs$core$not$$($G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$));var $to_hex_QMARK_$$=$APP.$cljs$core$not$$($G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($alpha__$1$$,1);$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$=$prev_computed_color_to_rgba_QMARK_$$?"rgba":$to_hex_QMARK_$$?"hex":$APP.$cljs$core$truth_$$($G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$)?$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$:"hex";$JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$=$APP.$app$main$data$tinycolor$valid_color$$($JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$).setAlpha($APP.$cljs$core$truth_$$($alpha__$1$$)?
$alpha__$1$$:1);$JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$=$app$main$data$tinycolor$__GT_string$$($JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$,$G__79963$jscomp$inline_13658_format$jscomp$43_prev_format_prev_input_color$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$945$$,$JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$)?($APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$189$$,
$input_name$jscomp$5$$,$JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$,!0),$resolve_stream$$.next($JSCompiler_inline_result$jscomp$14080_color_value$jscomp$5_hex__$1$jscomp$4$$)):null});$on_change$jscomp$85_on_click_swatch$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$5$$)],function($event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$){$event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$=
$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$));$event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$=$APP.$cljs$core$truth_$$($app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$($event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$))?"#"+($event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$??""):$event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$;$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$189$$,
$input_name$jscomp$5$$,$event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$,!0);return $resolve_stream$$.next($event$jscomp$611_raw_value$jscomp$2_value__$1$jscomp$61$$)});$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$={...$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$,onChange:$on_change$jscomp$85_on_click_swatch$$,value:$APP.$cljs$core$truth_$$($value$jscomp$945$$)?$value$jscomp$945$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$21_valid_color$$),
variant:"comfortable",slotStart:$alpha$jscomp$22_swatch$$,hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$21_valid_color$$)};$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$144_name$jscomp$475$$)?$props_79955_touched_QMARK_$jscomp$7$$:$error$jscomp$144_name$jscomp$475$$)?{...$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$144_name$jscomp$475$$)}:
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extra_error$jscomp$1$$)?$props_79955_touched_QMARK_$jscomp$7$$:$extra_error$jscomp$1$$)?{...$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($extra_error$jscomp$1$$)}:$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$59$$),
$APP.$rumext$v2$adapt$$($token$jscomp$169$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$5$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$35$$)],function(){var $subs$jscomp$24$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error__$1_message$jscomp$117_p__79967$$){var $map__79968__$1_value__$1$jscomp$62$$=$APP.$cljs$core$__destructure_map$$($error__$1_message$jscomp$117_p__79967$$);$error__$1_message$jscomp$117_p__79967$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79968__$1_value__$1$jscomp$62$$,
$APP.$cljs$cst$849$error$$);$map__79968__$1_value__$1$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79968__$1_value__$1$jscomp$62$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$5$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$$)){if($APP.$cljs$core$truth_$$($error__$1_message$jscomp$117_p__79967$$)){if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error__$1_message$jscomp$117_p__79967$$,
$token_name$jscomp$35$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$117_p__79967$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$input_name$jscomp$5$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$117_p__79967$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$cljs$cst$5826$color_result$$],null),"");return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$117_p__79967$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1_message$jscomp$117_p__79967$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($map__79968__$1_value__$1$jscomp$62$$)]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$189$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$5$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$5826$color_result$$],
null),$map__79968__$1_value__$1$jscomp$62$$);return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$117_p__79967$$,$APP.$cljs$cst$139$type$$,"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$368$$){return $APP.$app$common$data$update_when$$($result$jscomp$368$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$,
$tokens$jscomp$59$$,$token$jscomp$169$$,$token_name$jscomp$35$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$24$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$364_props__$1$jscomp$89_props__$2$jscomp$6$$),$APP.$cljs$core$truth_$$($color_ramp_open_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$,
{color:$value$jscomp$945$$,onChange:$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$74$$}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$=function($form$jscomp$191$$,$field$jscomp$9$$,$index$jscomp$550$$,$value$jscomp$947$$,$value_subfield$jscomp$1$$){function $clean_errors$jscomp$1$$($errors$jscomp$39$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$39$$,$field$jscomp$9$$))}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$191$$,
function($state$jscomp$1199$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($state$jscomp$1199$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$1$$,$index$jscomp$550$$,$field$jscomp$9$$],null),$APP.$cljs$core$truth_$$(!0)?
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$947$$):$value$jscomp$947$$),$APP.$cljs$cst$570$errors$$,$clean_errors$jscomp$1$$),$APP.$cljs$cst$5073$extra_errors$$,$clean_errors$jscomp$1$$),$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$indexed_color_input_STAR_$$=function($error$jscomp$145_props_79977$$){var $index$jscomp$551$$=void 0,$hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$=void 0,$token$jscomp$170$$=void 0,$value_subfield$jscomp$2$$=void 0,$tokens$jscomp$60$$=void 0,$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$=void 0;({name:$hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$,tokens:$tokens$jscomp$60$$,token:$token$jscomp$170$$,index:$index$jscomp$551$$,
valueSubfield:$value_subfield$jscomp$2$$,...$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$}=$error$jscomp$145_props_79977$$);var $form$jscomp$192$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$6$$=$hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$,$token_name$jscomp$36$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$error$jscomp$145_props_79977$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$input_name$jscomp$6$$],null));var $value$jscomp$948$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$input_name$jscomp$6$$],null),""),$color_resolved$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,
$value_subfield$jscomp$2$$,$index$jscomp$551$$,$cljs$cst$5826$color_result$$],null),"");$hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1253$$=$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$948$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1253$$)?$or__5025__auto__$jscomp$1253$$:$APP.$app$main$data$tinycolor$valid_color$$($color_resolved$jscomp$1$$)}();var $default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);a:switch($APP.$cljs$cst$3184$theme$$.$cljs$core$IFn$_invoke$arity$1$($default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$)){case "light":$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$="#eef0f2";break a;default:$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$="#2e3434"}$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$=
$APP.$cljs$core$truth_$$($hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$)?$APP.$app$main$data$tinycolor$__GT_hex_string$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$)):$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$;var $alpha$jscomp$23_swatch$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$))?$APP.$app$main$data$tinycolor$alpha$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$)):
1,$resolve_stream$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$170$$)],function(){var $temp__5823__auto__$jscomp$241$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$170$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$input_name$jscomp$6$$],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$241$$)?
$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$241$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$1$$);var $color_ramp_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$color_ramp_open_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($color_ramp_open_STAR_$jscomp$1$$),
$on_change$jscomp$86_on_click_swatch$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_ramp_open_QMARK_$jscomp$1$$)],function(){return $APP.$cljs$core$reset_BANG_$$($color_ramp_open_STAR_$jscomp$1$$,$APP.$cljs$core$not$$($color_ramp_open_QMARK_$jscomp$1$$))});$alpha$jscomp$23_swatch$jscomp$1$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,
$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$,$APP.$cljs$cst$1734$opacity$$,$alpha$jscomp$23_swatch$jscomp$1$$],null),showTooltip:!1,"data-testid":"token-form-color-bullet",className:"main_ui_workspace_tokens_management_forms_controls_color_input__slot-start",onClick:$on_change$jscomp$86_on_click_swatch$jscomp$1$$});$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$1$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$6$$),$APP.$rumext$v2$adapt$$($value$jscomp$948$$),$APP.$rumext$v2$adapt$$($index$jscomp$551$$)],function($JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$,$alpha__$1$jscomp$1$$){var $G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$value$jscomp$948$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$948$$),$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$=
$APP.$cljs$core$truth_$$($G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)?null:$value$jscomp$948$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$948$$);$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$APP.$cljs$core$truth_$$($G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)?$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$:
$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$;$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$==null?null:$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$.getFormat();$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$=$alpha__$1$jscomp$1$$<1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$,
"hex")||$APP.$cljs$core$not$$($G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$));var $to_hex_QMARK_$jscomp$1$$=$APP.$cljs$core$not$$($G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($alpha__$1$jscomp$1$$,1);$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$?
"rgba":$to_hex_QMARK_$jscomp$1$$?"hex":$APP.$cljs$core$truth_$$($G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)?$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$:"hex";$JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$=$APP.$app$main$data$tinycolor$valid_color$$($JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$).setAlpha($APP.$cljs$core$truth_$$($alpha__$1$jscomp$1$$)?
$alpha__$1$jscomp$1$$:1);$JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$=$app$main$data$tinycolor$__GT_string$$($JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$,$G__79981$jscomp$inline_13660_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$948$$,$JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$)?($app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$($form$jscomp$192$$,
$input_name$jscomp$6$$,$index$jscomp$551$$,$JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$,$value_subfield$jscomp$2$$),$resolve_stream$jscomp$1$$.next($JSCompiler_inline_result$jscomp$14081_color_value$jscomp$6_hex__$1$jscomp$5$$)):null});$on_change$jscomp$86_on_click_swatch$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$1$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$6$$),$APP.$rumext$v2$adapt$$($index$jscomp$551$$)],
function($event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$){$event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$));$event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$=$APP.$cljs$core$truth_$$($app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$($event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$))?"#"+($event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$??
""):$event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$;$app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$($form$jscomp$192$$,$input_name$jscomp$6$$,$index$jscomp$551$$,$event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$,$value_subfield$jscomp$2$$);return $resolve_stream$jscomp$1$$.next($event$jscomp$612_raw_value$jscomp$3_value__$1$jscomp$64$$)});$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$=
{...$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$,onChange:$on_change$jscomp$86_on_click_swatch$jscomp$1$$,value:$APP.$cljs$core$truth_$$($value$jscomp$948$$)?$value$jscomp$948$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$),slotStart:$alpha$jscomp$23_swatch$jscomp$1$$,hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$22_name$jscomp$476_valid_color$jscomp$1$$)};$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$=
$APP.$cljs$core$truth_$$($error$jscomp$145_props_79977$$)?{...$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$145_props_79977$$)}:$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$1$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$60$$),$APP.$rumext$v2$adapt$$($token$jscomp$170$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$6$$),$APP.$rumext$v2$adapt$$($index$jscomp$551$$),$APP.$rumext$v2$adapt$$($value_subfield$jscomp$2$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$36$$)],function(){var $subs$jscomp$25$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$){$error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$=$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$);
var $error__$1$jscomp$1_message$jscomp$118$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$,$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$1_message$jscomp$118$$)?
$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$1_message$jscomp$118$$)):$error__$1$jscomp$1_message$jscomp$118$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$],
null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$6$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$6$$])),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$cljs$cst$5826$color_result$$],null),""),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$1_message$jscomp$118$$!=null){$error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$1_message$jscomp$118$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$,
$token_name$jscomp$36$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$input_name$jscomp$6$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$cljs$cst$5826$color_result$$],null),"");return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$1_message$jscomp$118$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$)]));var $input_value$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$input_name$jscomp$6$$],null),"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update$$,
$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$551$$,$cljs$cst$5826$color_result$$],null),$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$));
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_value$jscomp$1$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($error_SINGLEQUOTE__map__79983__$1_p__79982_value__$1$jscomp$65$$))?$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$1_message$jscomp$118$$,$APP.$cljs$cst$139$type$$,
"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$369$$){return $APP.$app$common$data$update_when$$($result$jscomp$369$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$,$tokens$jscomp$60$$,$token$jscomp$170$$,$token_name$jscomp$36$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$1$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$25$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$365_props__$1$jscomp$90_props__$2$jscomp$7$$),$APP.$cljs$core$truth_$$($color_ramp_open_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$,{color:$value$jscomp$948$$,
onChange:$default_bullet_color$jscomp$1_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$75$$}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$first_focusable_id$$=function($options$jscomp$635$$){return $APP.$cljs$core$some$$(function($p1__79935_SHARP_$$){var $JSCompiler_inline_result$jscomp$1870_and__5023__auto__$jscomp$inline_9040$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79935_SHARP_$$);$JSCompiler_inline_result$jscomp$1870_and__5023__auto__$jscomp$inline_9040$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1870_and__5023__auto__$jscomp$inline_9040$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__79935_SHARP_$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1472$separator$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__79935_SHARP_$$)):$JSCompiler_inline_result$jscomp$1870_and__5023__auto__$jscomp$inline_9040$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1870_and__5023__auto__$jscomp$inline_9040$$)?
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79935_SHARP_$$):null},$options$jscomp$635$$)};
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$=function($focusables_ids$jscomp$315$$,$focused_id$jscomp$6_idx$jscomp$129$$,$G__79942__$1_direction$jscomp$29$$){$focusables_ids$jscomp$315$$=$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$focusables_ids$jscomp$315$$));$focused_id$jscomp$6_idx$jscomp$129$$=$APP.$cljs$core$clj__GT_js$$($focusables_ids$jscomp$315$$).indexOf($focused_id$jscomp$6_idx$jscomp$129$$);
var $count$jscomp$71$$=$APP.$cljs$core$count$$($focusables_ids$jscomp$315$$);$G__79942__$1_direction$jscomp$29$$=$G__79942__$1_direction$jscomp$29$$ instanceof $APP.$cljs$core$Keyword$$?$G__79942__$1_direction$jscomp$29$$.$fqn$:null;switch($G__79942__$1_direction$jscomp$29$$){case "down":return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusables_ids$jscomp$315$$,$APP.$cljs$core$mod$$($focused_id$jscomp$6_idx$jscomp$129$$+1,$count$jscomp$71$$),null);case "up":return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusables_ids$jscomp$315$$,
$APP.$cljs$core$mod$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($focused_id$jscomp$6_idx$jscomp$129$$,-1)?0:$focused_id$jscomp$6_idx$jscomp$129$$-1,$count$jscomp$71$$),null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79942__$1_direction$jscomp$29$$)].join(""));}};
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$use_navigation$$=function($map__79951__$1_on_key_down$jscomp$22_p__79950$$){$map__79951__$1_on_key_down$jscomp$22_p__79950$$=$APP.$cljs$core$__destructure_map$$($map__79951__$1_on_key_down$jscomp$22_p__79950$$);var $is_open$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,$cljs$cst$5668$is_open$$),$options$jscomp$636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,
$APP.$cljs$cst$873$options$$),$nodes_ref$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,$cljs$cst$5729$nodes_ref$$),$is_open_STAR_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,$cljs$cst$5827$is_open_STAR_$$),$toggle_dropdown$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,$cljs$cst$5828$toggle_dropdown$$),
$on_enter$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,$cljs$cst$5730$on_enter$$),$get_selected_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79951__$1_on_key_down$jscomp$22_p__79950$$,$cljs$cst$5829$get_selected_id$$),$focused_id_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$focused_id$jscomp$7$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$5$$);$map__79951__$1_on_key_down$jscomp$22_p__79950$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$11$$),$APP.$rumext$v2$adapt$$($focused_id$jscomp$7$$)],function($event$jscomp$613_next_id$jscomp$1$$){var $focusables$jscomp$1_up_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$613_next_id$jscomp$1$$),$down_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$613_next_id$jscomp$1$$),$enter_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$613_next_id$jscomp$1$$),
$esc_QMARK_$jscomp$8$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$613_next_id$jscomp$1$$),$tab_QMARK_$$=(0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$613_next_id$jscomp$1$$),$open_dropdown$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$613_next_id$jscomp$1$$.key,"{"),$close_dropdown$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$613_next_id$jscomp$1$$.key,"}"),$options__$1$jscomp$90$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$636$$)?
$APP.$cljs$core$_deref$$($options$jscomp$636$$):$options$jscomp$636$$;if($APP.$cljs$core$truth_$$($down_QMARK_$jscomp$6$$)){$APP.$app$util$dom$prevent_default$$($event$jscomp$613_next_id$jscomp$1$$);$focusables$jscomp$1_up_QMARK_$jscomp$6$$=$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($options__$1$jscomp$90$$);if($APP.$cljs$core$truth_$$($is_open$jscomp$11$$)){if($APP.$cljs$core$seq$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$))return $event$jscomp$613_next_id$jscomp$1$$=
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$,$focused_id$jscomp$7$$,$APP.$cljs$cst$1953$down$$),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,$event$jscomp$613_next_id$jscomp$1$$)}else if($APP.$cljs$core$seq$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$))return $toggle_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$613_next_id$jscomp$1$$):
$toggle_dropdown$jscomp$5$$($event$jscomp$613_next_id$jscomp$1$$),$APP.$cljs$core$truth_$$($get_selected_id$$)&&($get_selected_id$$.$cljs$core$IFn$_invoke$arity$0$?$get_selected_id$$.$cljs$core$IFn$_invoke$arity$0$():$get_selected_id$$()),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$first_focusable_id$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$));return null}if($APP.$cljs$core$truth_$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$))return $APP.$cljs$core$truth_$$($is_open$jscomp$11$$)?
($APP.$app$util$dom$prevent_default$$($event$jscomp$613_next_id$jscomp$1$$),$focusables$jscomp$1_up_QMARK_$jscomp$6$$=$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($options__$1$jscomp$90$$),$event$jscomp$613_next_id$jscomp$1$$=$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$,$focused_id$jscomp$7$$,$APP.$cljs$cst$1954$up$$),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,
$event$jscomp$613_next_id$jscomp$1$$)):null;if($open_dropdown$jscomp$5$$)return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!0),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,null);if($close_dropdown$jscomp$6$$)return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!1);if($APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$6$$)){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_open$jscomp$11$$)?$focused_id$jscomp$7$$:$is_open$jscomp$11$$))return $focusables$jscomp$1_up_QMARK_$jscomp$6$$=
$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($options__$1$jscomp$90$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$613_next_id$jscomp$1$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__79949_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79949_SHARP_$$),$focused_id$jscomp$7$$)},$focusables$jscomp$1_up_QMARK_$jscomp$6$$))?$on_enter$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_enter$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($focused_id$jscomp$7$$):$on_enter$jscomp$1$$($focused_id$jscomp$7$$):null}else if($APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$8$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$11$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$613_next_id$jscomp$1$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$613_next_id$jscomp$1$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!1)}else if($APP.$cljs$core$truth_$$($tab_QMARK_$$)&&
$APP.$cljs$core$truth_$$($is_open$jscomp$11$$))return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!1),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,null);return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$11$$)],function(){return $APP.$cljs$core$not$$($is_open$jscomp$11$$)?$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,null):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$7$$),
$APP.$rumext$v2$adapt$$($nodes_ref$jscomp$7$$)],function(){if($APP.$cljs$core$truth_$$($focused_id$jscomp$7$$)){var $node$jscomp$454$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$7$$),$focused_id$jscomp$7$$);return $APP.$cljs$core$truth_$$($node$jscomp$454$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$454$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1400$block$$,
"nearest",$APP.$cljs$cst$2348$inline$$,"nearest"],null)):null}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5733$focused_id$$,$focused_id$jscomp$7$$,$cljs$cst$5641$on_key_down$$,$map__79951__$1_on_key_down$jscomp$22_p__79950$$],null)};
$app$main$ui$workspace$tokens$management$forms$controls$floating_dropdown$use_floating_dropdown$$=function($is_open$jscomp$12$$,$input_wrapper_ref$jscomp$1$$,$outer_wrapper_ref$$,$dropdown_ref$jscomp$4$$){function $calculate_position$$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$){$combobox_rect_node$jscomp$455_position__$1$jscomp$9$$=$APP.$app$util$dom$get_bounding_rect$$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$);var $dropdown_height_dropdown_node$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$4$$);
$dropdown_height_dropdown_node$$=$APP.$cljs$core$truth_$$($dropdown_height_dropdown_node$$)?$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($dropdown_height_dropdown_node$$)):0;var $windows_height$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_window_size$$()),$space_below$$=$windows_height$$-$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$);
$combobox_rect_node$jscomp$455_position__$1$jscomp$9$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($dropdown_height_dropdown_node$$)?$dropdown_height_dropdown_node$$>$space_below$$:$dropdown_height_dropdown_node$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1563$bottom$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($windows_height$$-$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)- -8),"px"].join(""),
$APP.$cljs$cst$257$left$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)),"px"].join(""),$APP.$cljs$cst$290$width$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)),"px"].join(""),$APP.$cljs$cst$4735$placement$$,$APP.$cljs$cst$1562$top$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1562$top$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)+4),"px"].join(""),$APP.$cljs$cst$257$left$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)),"px"].join(""),$APP.$cljs$cst$290$width$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)),
"px"].join(""),$APP.$cljs$cst$4735$placement$$,$APP.$cljs$cst$1563$bottom$$],null);$APP.$cljs$core$reset_BANG_$$($ready_STAR_$$,!0);return $APP.$cljs$core$reset_BANG_$$($position_STAR_$$,$combobox_rect_node$jscomp$455_position__$1$jscomp$9$$)}var $position_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$position$jscomp$201$$=$APP.$cljs$core$_deref$$($position_STAR_$$),$ready_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$ready$$=$APP.$cljs$core$_deref$$($ready_STAR_$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$12$$),$APP.$rumext$v2$adapt$$($dropdown_ref$jscomp$4$$),$APP.$rumext$v2$adapt$$($input_wrapper_ref$jscomp$1$$),$APP.$rumext$v2$adapt$$($outer_wrapper_ref$$)],function(){if($APP.$cljs$core$truth_$$($is_open$jscomp$12$$)){var $recalculate$$=function(){return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $calculate_position$$($APP.$rumext$v2$ref_val$$($input_wrapper_ref$jscomp$1$$))})},
$handler$jscomp$45$$=function($event$jscomp$614_target$jscomp$160$$){var $dropdown_node$jscomp$2$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$4$$);$event$jscomp$614_target$jscomp$160$$=$APP.$app$util$dom$get_target$$($event$jscomp$614_target$jscomp$160$$);return $dropdown_node$jscomp$2$$!=null&&$event$jscomp$614_target$jscomp$160$$ instanceof Node&&!$APP.$cljs$core$not$$($dropdown_node$jscomp$2$$.contains($event$jscomp$614_target$jscomp$160$$))?null:$recalculate$$()},$resize_observer$$=new ResizeObserver(function(){return $recalculate$$()}),
$outer_node$$=$APP.$rumext$v2$ref_val$$($outer_wrapper_ref$$),$dropdown_node$jscomp$1$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$4$$);$handler$jscomp$45$$(null);window.addEventListener("resize",$handler$jscomp$45$$);window.addEventListener("scroll",$handler$jscomp$45$$,!0);$APP.$cljs$core$truth_$$($outer_node$$)&&$resize_observer$$.observe($outer_node$$);$APP.$cljs$core$truth_$$($dropdown_node$jscomp$1$$)&&$resize_observer$$.observe($dropdown_node$jscomp$1$$);return function(){window.removeEventListener("resize",
$handler$jscomp$45$$);window.removeEventListener("scroll",$handler$jscomp$45$$,!0);return $resize_observer$$.disconnect()}}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1904$style$$,$position$jscomp$201$$,$cljs$cst$5830$ready_QMARK_$$,$ready$$,$cljs$cst$5831$recalculate$$,$calculate_position$$],null)};
$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$token_at_cursor$$=function($token_name$jscomp$37_value$jscomp$950$$,$cursor$jscomp$4_last_open$jscomp$3$$){$cursor$jscomp$4_last_open$jscomp$3$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($token_name$jscomp$37_value$jscomp$950$$,0,$cursor$jscomp$4_last_open$jscomp$3$$),"{");var $last_close$jscomp$2$$=$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($token_name$jscomp$37_value$jscomp$950$$,
"}",$APP.$cljs$core$truth_$$($cursor$jscomp$4_last_open$jscomp$3$$)?$cursor$jscomp$4_last_open$jscomp$3$$:0);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($cursor$jscomp$4_last_open$jscomp$3$$)?$APP.$cljs$core$truth_$$($last_close$jscomp$2$$)?$last_close$jscomp$2$$>$cursor$jscomp$4_last_open$jscomp$3$$:$last_close$jscomp$2$$:$cursor$jscomp$4_last_open$jscomp$3$$)?($token_name$jscomp$37_value$jscomp$950$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($token_name$jscomp$37_value$jscomp$950$$,
$cursor$jscomp$4_last_open$jscomp$3$$+1,$last_close$jscomp$2$$),$APP.$cljs$core$seq$$($token_name$jscomp$37_value$jscomp$950$$)&&$APP.$cljs$core$not$$($APP.$cuerdas$core$includes_QMARK_$$($token_name$jscomp$37_value$jscomp$950$$," "))?$token_name$jscomp$37_value$jscomp$950$$:null):null};
$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$remove_self_token$$=function($filtered_options$jscomp$1_filtered_options__$1$$,$current_token$$){var $group$jscomp$54$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_token$$),$current_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_token$$);$filtered_options$jscomp$1_filtered_options__$1$$=$APP.$cljs$core$_deref$$($filtered_options$jscomp$1_filtered_options__$1$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($filtered_options$jscomp$1_filtered_options__$1$$,
$group$jscomp$54$$,function($options$jscomp$637$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79964_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79964_SHARP_$$),$current_id$jscomp$9$$)},$options$jscomp$637$$)})};
$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$=function($id$jscomp$1018_name$jscomp$477_option$jscomp$27$$,$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,$cursor$jscomp$6_input_node$jscomp$12$$,$JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$){$cursor$jscomp$6_input_node$jscomp$12$$=
$cursor$jscomp$6_input_node$jscomp$12$$!=null?$cursor$jscomp$6_input_node$jscomp$12$$.selectionStart:null;$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$APP.$rumext$v2$ref_val$$($G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$);
$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$APP.$cljs$core$delay_QMARK_$$($G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$)?
$APP.$cljs$core$_deref$$($G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$):$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$;
$id$jscomp$1018_name$jscomp$477_option$jscomp$27$$=$APP.$app$main$ui$ds$controls$select$get_option$$($G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,$id$jscomp$1018_name$jscomp$477_option$jscomp$27$$);$id$jscomp$1018_name$jscomp$477_option$jscomp$27$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1018_name$jscomp$477_option$jscomp$27$$);
var $close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,0,$cursor$jscomp$6_input_node$jscomp$12$$);$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$,"{");$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$,
"}");if($G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$!=null&&($close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$==null||$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$<
$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$)){var $JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,
0,$cursor$jscomp$6_input_node$jscomp$12$$),$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,$cursor$jscomp$6_input_node$jscomp$12$$);$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$app$common$data$nth_index_of_STAR_$$($JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$,"{",$APP.$cljs$cst$271$backward$$);$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=$app$common$data$nth_index_of_STAR_$$($first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$,
"}",$APP.$cljs$cst$270$forward$$);$JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$=$app$common$data$nth_index_of_STAR_$$($JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$," ",$APP.$cljs$cst$271$backward$$);$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$=$app$common$data$nth_index_of_STAR_$$($first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$,
" ",$APP.$cljs$cst$270$forward$$);if($APP.$cljs$core$boolean$0$$(typeof $G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$==="number"&&typeof $close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$===
"number"&&($JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$==null||$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$>$JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$)&&
($first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$==null||$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$<$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$)))$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$app$common$data$nth_index_of_STAR_$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,0,$cursor$jscomp$6_input_node$jscomp$12$$),"{",$APP.$cljs$cst$271$backward$$),$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=$app$common$data$nth_index_of_STAR_$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,
$cursor$jscomp$6_input_node$jscomp$12$$),"}",$APP.$cljs$cst$270$forward$$),$JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$=$app$common$types$token$build_result$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,typeof $close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$===
"number"?$cursor$jscomp$6_input_node$jscomp$12$$+$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$+1:$cursor$jscomp$6_input_node$jscomp$12$$,$id$jscomp$1018_name$jscomp$477_option$jscomp$27$$);else{$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,0,$cursor$jscomp$6_input_node$jscomp$12$$);b:{$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,0,$cursor$jscomp$6_input_node$jscomp$12$$);for($first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$=
$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$,"{");;)if($JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$=$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$,$JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$)?$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$>0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$,
$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$-1),"{"):$JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$,$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14676_and__5023__auto__$jscomp$inline_14677_last_space_left$jscomp$inline_13676_left$jscomp$inline_13672$$))--$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$;
else{$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=$first_space_right$jscomp$inline_13677_i$jscomp$inline_14675_right$jscomp$inline_13673$$;break b}$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$=void 0}$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$," ");$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$APP.$cljs$core$last$$($cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$close_pos$jscomp$inline_13675_close_pos$jscomp$inline_9046_last_close$jscomp$inline_13668_left$jscomp$inline_13666_left$jscomp$inline_14674_open_pos$jscomp$inline_13682$$,$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$==
null?null:$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$+1],null))));$JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$=$app$common$types$token$build_result$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,$G__49182$jscomp$inline_13684_JSCompiler_inline_result$jscomp$10957_last_open$jscomp$inline_13667_left$jscomp$inline_13681_open_pos$jscomp$inline_13674_open_pos$jscomp$inline_9045_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,
$cursor$jscomp$6_input_node$jscomp$12$$,$id$jscomp$1018_name$jscomp$477_option$jscomp$27$$)}}else $JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$=$app$common$types$token$build_result$$($JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$,$cursor$jscomp$6_input_node$jscomp$12$$,$cursor$jscomp$6_input_node$jscomp$12$$,$id$jscomp$1018_name$jscomp$477_option$jscomp$27$$);return $JSCompiler_inline_result$jscomp$1542_value$jscomp$952$$};
$app$main$ui$workspace$tokens$management$forms$controls$combobox$resolve_value$$=function($tokens$jscomp$61_tokens__$1$jscomp$10$$,$prev_token$jscomp$3$$,$token_name$jscomp$38$$,$value$jscomp$953$$){var $valid_token_name_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$871$$=typeof $token_name$jscomp$38$$==="string";return $and__5023__auto__$jscomp$871$$?$APP.$cljs$core$re_matches$$($APP.$app$common$types$token$token_name_validation_regex$$,$token_name$jscomp$38$$):$and__5023__auto__$jscomp$871$$}(),
$token$jscomp$171$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$953$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$not$$($valid_token_name_QMARK_$jscomp$1$$)||$APP.$cuerdas$core$blank_QMARK_$$($token_name$jscomp$38$$)?"__PENPOT__TOKEN__NAME__PLACEHOLDER__":$token_name$jscomp$38$$],null);$tokens$jscomp$61_tokens__$1$jscomp$10$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$61_tokens__$1$jscomp$10$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$3$$)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$171$$),function($p1__79986_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__79986_SHARP_$$,$prev_token$jscomp$3$$,
$token$jscomp$171$$]))]))});return $APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$){$errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$171$$));var $map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$);
$errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$,$APP.$cljs$cst$570$errors$$);$map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$,$APP.$cljs$cst$4605$resolved_value$$);$map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$):$map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$;return $APP.$cljs$core$truth_$$($map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,
$map__79988__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$truth_$$($errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$)?$APP.$cljs$core$first$$($errors$jscomp$40_map__79988_resolved_tokens$jscomp$27$$):$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4601$error_SLASH_unknown$$,$value$jscomp$953$$)],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$61_tokens__$1$jscomp$10$$)):$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$61_tokens__$1$jscomp$10$$))};
$app$main$ui$workspace$tokens$management$forms$controls$combobox$value_combobox_STAR_$$=function($input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$){var $ref$jscomp$56$$=void 0,$name$jscomp$478$$=void 0,$token$jscomp$172$$=void 0,$empty_to_end$jscomp$4$$=void 0,$token_type$jscomp$21$$=void 0,$tokens$jscomp$62$$=void 0,$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$=void 0;({name:$name$jscomp$478$$,tokens:$tokens$jscomp$62$$,token:$token$jscomp$172$$,tokenType:$token_type$jscomp$21$$,
emptyToEnd:$empty_to_end$jscomp$4$$,ref:$ref$jscomp$56$$,...$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$}=$input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$);var $form$jscomp$193$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$token_name$jscomp$39$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$APP.$cljs$cst$725$name$$],null),null),$touched_QMARK_$jscomp$8$$=function(){var $and__5023__auto__$jscomp$872$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$193$$)),$name$jscomp$478$$);return $and__5023__auto__$jscomp$872$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1626$touched$$,$name$jscomp$478$$],null)):$and__5023__auto__$jscomp$872$$}(),$error$jscomp$146$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$name$jscomp$478$$],null)),$extra_error$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$name$jscomp$478$$],null)),$value$jscomp$954$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$name$jscomp$478$$],null),""),$is_open_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$is_open$jscomp$13$$=$APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$4$$),
$listbox_id$jscomp$4$$=(0,$APP.$rumext$v2$use_id$$)(),$filter_term_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$filter_term$jscomp$6$$=$APP.$cljs$core$_deref$$($filter_term_STAR_$jscomp$1$$),$selected_id_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected_id$jscomp$8$$=$APP.$cljs$core$_deref$$($selected_id_STAR_$jscomp$3$$),$options_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$internal_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$nodes_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(null),$wrapper_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null);$input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $icon_button_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ref__$1$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1259$$=$ref$jscomp$56$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1259$$)?$or__5025__auto__$jscomp$1259$$:
$internal_ref$jscomp$1$$}(),$container$jscomp$96$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$205$default$$),$raw_tokens_by_type$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$),$filtered_tokens_by_type$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($raw_tokens_by_type$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$21$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($raw_tokens_by_type$$,
$token_type$jscomp$21$$)}),$visible_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filtered_tokens_by_type$$),$APP.$rumext$v2$adapt$$($token$jscomp$172$$)],function(){return $APP.$cljs$core$truth_$$($token$jscomp$172$$)?$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$remove_self_token$$($filtered_tokens_by_type$$,$token$jscomp$172$$):$filtered_tokens_by_type$$}),$dropdown_options$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($visible_options$$),
$APP.$rumext$v2$adapt$$($filter_term$jscomp$6$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$($visible_options$$,["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($filter_term$jscomp$6$$)].join(""))}),$set_option_ref$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$456_state__$2$jscomp$9$$){var $state__$1$jscomp$60$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$8$$),
{}),$id$jscomp$1019$$=$APP.$app$util$dom$get_data$$($node$jscomp$456_state__$2$jscomp$9$$,"id");$node$jscomp$456_state__$2$jscomp$9$$=$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$60$$,$id$jscomp$1019$$,$node$jscomp$456_state__$2$jscomp$9$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$8$$,$node$jscomp$456_state__$2$jscomp$9$$)}),$get_selected_id$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$3$$)],function(){var $input_node$jscomp$13_options$jscomp$639$$=
$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$),$value__$1$jscomp$66$$=$APP.$app$util$dom$get_input_value$$($input_node$jscomp$13_options$jscomp$639$$),$token_name__$1$$=$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$token_at_cursor$$($value__$1$jscomp$66$$,$input_node$jscomp$13_options$jscomp$639$$!=null?$input_node$jscomp$13_options$jscomp$639$$.selectionStart:null);$input_node$jscomp$13_options$jscomp$639$$=$APP.$cljs$core$delay_QMARK_$$($dropdown_options$jscomp$3$$)?$APP.$cljs$core$_deref$$($dropdown_options$jscomp$3$$):
$dropdown_options$jscomp$3$$;return $APP.$cljs$core$truth_$$($token_name__$1$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79989_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79989_SHARP_$$),$token_name__$1$$)},$input_node$jscomp$13_options$jscomp$639$$))):null}),$toggle_dropdown$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$13$$)],
function($event$jscomp$615$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$615$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$4$$,$APP.$cljs$core$not$$);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$3$$,$get_selected_id$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$get_selected_id$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$get_selected_id$jscomp$1$$());return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$))}),
$resolve_stream$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$172$$)],function(){return $APP.$cljs$core$contains_QMARK_$$($token$jscomp$172$$,$APP.$cljs$cst$260$value$$)?$APP.$beicon$v2$core$behavior_subject$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$172$$)):$APP.$beicon$v2$core$subject$$()}),$map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$954$$),
$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),$APP.$rumext$v2$adapt$$($name$jscomp$478$$)],function($id$jscomp$1020_map__79995_map__79995__$1$$){var $input_node$jscomp$15$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$),$input_value$jscomp$2_value__$1$jscomp$67$$=$APP.$app$util$dom$get_input_value$$($input_node$jscomp$15$$);$id$jscomp$1020_map__79995_map__79995__$1$$=$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$($id$jscomp$1020_map__79995_map__79995__$1$$,
$options_ref$jscomp$4$$,$input_node$jscomp$15$$,$input_value$jscomp$2_value__$1$jscomp$67$$);$id$jscomp$1020_map__79995_map__79995__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1020_map__79995_map__79995__$1$$);$input_value$jscomp$2_value__$1$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1020_map__79995_map__79995__$1$$,$APP.$cljs$cst$260$value$$);var $cursor$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1020_map__79995_map__79995__$1$$,
$APP.$cljs$cst$1997$cursor$$);$APP.$cljs$core$truth_$$($input_value$jscomp$2_value__$1$jscomp$67$$)&&($APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$193$$,$name$jscomp$478$$,$input_value$jscomp$2_value__$1$jscomp$67$$,!0),$resolve_stream$jscomp$2$$.next($input_value$jscomp$2_value__$1$jscomp$67$$),setTimeout(function(){$input_node$jscomp$15$$.selectionStart=$cursor$jscomp$8$$;return $input_node$jscomp$15$$.selectionEnd=$cursor$jscomp$8$$},0));$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,
"");return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1)});$map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$=$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$use_navigation$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$5668$is_open$$,$is_open$jscomp$13$$,$cljs$cst$5729$nodes_ref$$,$nodes_ref$jscomp$8$$,$APP.$cljs$cst$873$options$$,$dropdown_options$jscomp$3$$,$cljs$cst$5828$toggle_dropdown$$,$toggle_dropdown$jscomp$6$$,
$cljs$cst$5827$is_open_STAR_$$,$is_open_STAR_$jscomp$4$$,$cljs$cst$5730$on_enter$$,$map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$,$cljs$cst$5829$get_selected_id$$,$get_selected_id$jscomp$1$$],null));$map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$);var $focused_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$,
$cljs$cst$5733$focused_id$$);$map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$,$cljs$cst$5641$on_key_down$$);var $on_change$jscomp$87$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),$APP.$rumext$v2$adapt$$($name$jscomp$478$$),$APP.$rumext$v2$adapt$$($form$jscomp$193$$)],function($event$jscomp$616_value__$1$jscomp$68$$){var $JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$=
$APP.$app$util$dom$get_target$$($event$jscomp$616_value__$1$jscomp$68$$);$event$jscomp$616_value__$1$jscomp$68$$=$APP.$app$util$dom$get_input_value$$($JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$);$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$=$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$!=null?$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$.selectionStart:
null;var $text_before$jscomp$inline_14681$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$616_value__$1$jscomp$68$$,0,$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$),$last_open$jscomp$inline_14682$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($text_before$jscomp$inline_14681$$,"{"),$last_close$jscomp$inline_14683_or__5025__auto__$jscomp$inline_14686$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($text_before$jscomp$inline_14681$$,
"}");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($last_open$jscomp$inline_14682$$)?$last_close$jscomp$inline_14683_or__5025__auto__$jscomp$inline_14686$$==null||$last_open$jscomp$inline_14682$$>$last_close$jscomp$inline_14683_or__5025__auto__$jscomp$inline_14686$$:$last_open$jscomp$inline_14682$$)?($last_close$jscomp$inline_14683_or__5025__auto__$jscomp$inline_14686$$=$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$616_value__$1$jscomp$68$$,"}",$last_open$jscomp$inline_14682$$),
$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1292$start$$,$last_open$jscomp$inline_14682$$,$APP.$cljs$cst$1293$end$$,$APP.$cljs$core$truth_$$($last_close$jscomp$inline_14683_or__5025__auto__$jscomp$inline_14686$$)?$last_close$jscomp$inline_14683_or__5025__auto__$jscomp$inline_14686$$:$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$,
$APP.$cljs$cst$2125$partial$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($text_before$jscomp$inline_14681$$,$last_open$jscomp$inline_14682$$+1)],null)):$JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$=null;$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$193$$,$name$jscomp$478$$,$event$jscomp$616_value__$1$jscomp$68$$,!1);$resolve_stream$jscomp$2$$.next($event$jscomp$616_value__$1$jscomp$68$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$))return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,
!0),$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,$APP.$cljs$cst$2125$partial$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$inline_14684_cursor$jscomp$inline_14680_node$jscomp$457_token__$1$jscomp$2$$));$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1);return $APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,"")}),$on_option_click$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$954$$),$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),
$APP.$rumext$v2$adapt$$($ref__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($name$jscomp$478$$)],function($event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$){var $input_node$jscomp$16$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$);$event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$),"id");var $input_value$jscomp$3_value__$1$jscomp$69$$=$APP.$app$util$dom$get_input_value$$($input_node$jscomp$16$$);
$event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$=$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$($event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$,$options_ref$jscomp$4$$,$input_node$jscomp$16$$,$input_value$jscomp$3_value__$1$jscomp$69$$);$event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$);$input_value$jscomp$3_value__$1$jscomp$69$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$,$APP.$cljs$cst$260$value$$);var $cursor$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$617_id$jscomp$1021_map__79996_map__79996__$1$$,$APP.$cljs$cst$1997$cursor$$);$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,"");$APP.$app$util$dom$focus_BANG_$$($input_node$jscomp$16$$);return $APP.$cljs$core$truth_$$($input_value$jscomp$3_value__$1$jscomp$69$$)?
($APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1),$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$193$$,$name$jscomp$478$$,$input_value$jscomp$3_value__$1$jscomp$69$$,!0),$resolve_stream$jscomp$2$$.next($input_value$jscomp$3_value__$1$jscomp$69$$),setTimeout(function(){$input_node$jscomp$16$$.selectionStart=$cursor$jscomp$9$$;return $input_node$jscomp$16$$.selectionEnd=$cursor$jscomp$9$$},0)):null}),$hint_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$hint$jscomp$23$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$2$$);$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$={...$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$,role:"combobox",inputWrapperRef:$input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$,onChange:$on_change$jscomp$87$$,"aria-expanded":$is_open$jscomp$13$$,hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$23$$),"data-option-focused":$APP.$cljs$core$boolean$0$$($focused_id$jscomp$8$$),
hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$23$$),value:$value$jscomp$954$$,"aria-controls":$listbox_id$jscomp$4$$,ref:$ref__$1$jscomp$3$$,slotEnd:$APP.$cljs$core$_deref$$($filtered_tokens_by_type$$)!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),tabIndex:"-1",className:"main_ui_workspace_tokens_management_forms_controls_combobox__invisible-button",
onMouseDown:$APP.$app$util$dom$prevent_default$$,onClick:$toggle_dropdown$jscomp$6$$,ref:$icon_button_ref$$,tooltipClass:"main_ui_workspace_tokens_management_forms_controls_combobox__button-tooltip",variant:"action",icon:"arrow-down"}):null,"aria-activedescendant":$focused_id$jscomp$8$$,onKeyDown:$map__79991_map__79991__$1_on_key_down$jscomp$23_on_option_enter$jscomp$1$$,variant:"comfortable"};$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extra_error$jscomp$2$$)?
$extra_error$jscomp$2$$:$APP.$cljs$core$truth_$$($error$jscomp$146$$)?$touched_QMARK_$jscomp$8$$:$error$jscomp$146$$)?{...$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$146$$)?$error$jscomp$146$$:$extra_error$jscomp$2$$)}:$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$;$input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$=$app$main$ui$workspace$tokens$management$forms$controls$floating_dropdown$use_floating_dropdown$$($is_open$jscomp$13$$,
$input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$,$wrapper_ref$jscomp$4$$,$dropdown_ref$jscomp$5$$);$input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$=$APP.$cljs$core$__destructure_map$$($input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$);var $style$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$,$APP.$cljs$cst$1904$style$$),$ready_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($input_wrapper_ref$jscomp$2_map__79992_map__79992__$1_props_79990$$,
$cljs$cst$5830$ready_QMARK_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$62$$),$APP.$rumext$v2$adapt$$($token$jscomp$172$$),$APP.$rumext$v2$adapt$$($name$jscomp$478$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$39$$)],function(){var $subs$jscomp$26$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error__$1$jscomp$2_message$jscomp$119_p__79997$$){var $map__79998__$1_value__$1$jscomp$70$$=
$APP.$cljs$core$__destructure_map$$($error__$1$jscomp$2_message$jscomp$119_p__79997$$);$error__$1$jscomp$2_message$jscomp$119_p__79997$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79998__$1_value__$1$jscomp$70$$,$APP.$cljs$cst$849$error$$);$map__79998__$1_value__$1$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79998__$1_value__$1$jscomp$70$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$name$jscomp$478$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$jscomp$1$$)){if($APP.$cljs$core$truth_$$($error__$1$jscomp$2_message$jscomp$119_p__79997$$)){if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error__$1$jscomp$2_message$jscomp$119_p__79997$$,$token_name$jscomp$39$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$193$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$119_p__79997$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$193$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$5073$extra_errors$$,$name$jscomp$478$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$119_p__79997$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$119_p__79997$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$2_message$jscomp$119_p__79997$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__79998__$1_value__$1$jscomp$70$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$193$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$478$$]));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$119_p__79997$$,
$APP.$cljs$cst$139$type$$,"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$370$$){return $APP.$app$common$data$update_when$$($result$jscomp$370$$,$APP.$cljs$cst$849$error$$,function($error__$1$jscomp$3_fexpr__79999$$){var $G__80000$$=$APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$3_fexpr__79999$$);$error__$1$jscomp$3_fexpr__79999$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$3_fexpr__79999$$);
return $error__$1$jscomp$3_fexpr__79999$$.$cljs$core$IFn$_invoke$arity$1$?$error__$1$jscomp$3_fexpr__79999$$.$cljs$core$IFn$_invoke$arity$1$($G__80000$$):$error__$1$jscomp$3_fexpr__79999$$($G__80000$$)})},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$combobox$resolve_value$$,$tokens$jscomp$62$$,$token$jscomp$172$$,$token_name$jscomp$39$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$2$$))));
return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$26$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$3$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($options_ref$jscomp$4$$,$dropdown_options$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_STAR_$jscomp$4$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($wrapper_ref$jscomp$4$$)],
function(){if($APP.$cljs$core$truth_$$($is_open$jscomp$13$$)){var $handler$jscomp$46$$=function($event$jscomp$618_target$jscomp$161$$){var $wrapper_node$$=$APP.$rumext$v2$ref_val$$($wrapper_ref$jscomp$4$$),$dropdown_node$jscomp$3$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$5$$);$event$jscomp$618_target$jscomp$161$$=$APP.$app$util$dom$get_target$$($event$jscomp$618_target$jscomp$161$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($wrapper_node$$)?$APP.$cljs$core$truth_$$($dropdown_node$jscomp$3$$)?
$APP.$cljs$core$not$$($APP.$app$util$dom$child_QMARK_$$($event$jscomp$618_target$jscomp$161$$,$wrapper_node$$))&&$APP.$cljs$core$not$$($APP.$app$util$dom$child_QMARK_$$($event$jscomp$618_target$jscomp$161$$,$dropdown_node$jscomp$3$$)):$dropdown_node$jscomp$3$$:$wrapper_node$$)?$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1):null};document.addEventListener("mousedown",$handler$jscomp$46$$);return function(){return document.removeEventListener("mousedown",$handler$jscomp$46$$)}}return null});
return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$wrapper_ref$jscomp$4$$,children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$366_props__$1$jscomp$91_props__$2$jscomp$8$$),$is_open$jscomp$13$$?function(){var $options$jscomp$640$$=$APP.$cljs$core$delay_QMARK_$$($dropdown_options$jscomp$3$$)?$APP.$cljs$core$_deref$$($dropdown_options$jscomp$3$$):$dropdown_options$jscomp$3$$;return(0,$APP.$rumext$v2$portal$$)($APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,
{selected:$selected_id$jscomp$8$$,align:$APP.$cljs$cst$258$right$$,wrapperRef:$dropdown_ref$jscomp$5$$,className:"main_ui_workspace_tokens_management_forms_controls_combobox__dropdown",emptyToEnd:$empty_to_end$jscomp$4$$,id:$listbox_id$jscomp$4$$,style:{visibility:$APP.$cljs$core$truth_$$($ready_QMARK_$jscomp$1$$)?"visible":"hidden",left:$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$),top:function(){var $or__5025__auto__$jscomp$1262$$=$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1262$$)?$or__5025__auto__$jscomp$1262$$:"unset"}(),bottom:function(){var $or__5025__auto__$jscomp$1263$$=$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1263$$)?$or__5025__auto__$jscomp$1263$$:"unset"}(),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$)},focused:$focused_id$jscomp$8$$,onClick:$on_option_click$jscomp$4$$,
ref:$set_option_ref$jscomp$5$$,options:$options$jscomp$640$$}),$container$jscomp$96$$)}():null]})};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$=function($tokens$jscomp$63_tokens__$1$jscomp$11$$,$prev_token$jscomp$4$$,$_token_name_tmp_value$$,$value$jscomp$955$$){$_token_name_tmp_value$$=$APP.$app$common$types$token$split_font_family$$($value$jscomp$955$$);var $token$jscomp$173$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"__PENPOT__FONT_FAMILY__PLACEHOLDER__",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$260$value$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$4$$),$APP.$cljs$cst$1981$typography$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$4$$),$APP.$cljs$cst$1758$font_family$$,$_token_name_tmp_value$$):$_token_name_tmp_value$$],null);$tokens$jscomp$63_tokens__$1$jscomp$11$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($tokens$jscomp$63_tokens__$1$jscomp$11$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$173$$),function($p1__80001_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80001_SHARP_$$,$prev_token$jscomp$4$$,$token$jscomp$173$$]))]))});return $APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$){$errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$173$$));var $map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$);$errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$,
$APP.$cljs$cst$570$errors$$);$map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$,$APP.$cljs$cst$4605$resolved_value$$);$map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$):
$map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$;return $APP.$cljs$core$truth_$$($map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$map__80002__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$truth_$$($errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$)?
$APP.$cljs$core$first$$($errors$jscomp$41_map__80002_resolved_tokens$jscomp$28$$):$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4601$error_SLASH_unknown$$,$value$jscomp$955$$)],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$63_tokens__$1$jscomp$11$$)):$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$63_tokens__$1$jscomp$11$$))};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$fonts_combobox_STAR_$$=function($font$jscomp$49_props_80003$$){var $error$jscomp$147_name$jscomp$479$$=void 0,$token$jscomp$174$$=void 0,$tokens$jscomp$64$$=void 0,$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$=void 0;({token:$token$jscomp$174$$,tokens:$tokens$jscomp$64$$,name:$error$jscomp$147_name$jscomp$479$$,...$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$}=$font$jscomp$49_props_80003$$);var $form$jscomp$194$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$7$$=$error$jscomp$147_name$jscomp$479$$,$token_name$jscomp$40$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null),$touched_QMARK_$jscomp$9$$=function(){var $and__5023__auto__$jscomp$875$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$194$$)),
$input_name$jscomp$7$$);return $and__5023__auto__$jscomp$875$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$7$$],null)):$and__5023__auto__$jscomp$875$$}();$error$jscomp$147_name$jscomp$479$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$7$$],null));var $value$jscomp$956$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$7$$],null),"");$font$jscomp$49_props_80003$$=$APP.$app$main$fonts$find_font_family$$($value$jscomp$956$$);var $resolve_stream$jscomp$3$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$174$$)],function(){var $temp__5823__auto__$jscomp$242$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$174$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$242$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$242$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$hint$jscomp$24$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$3$$),$font_selector_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$font_selector_open_QMARK_$$=$APP.$cljs$core$_deref$$($font_selector_open_STAR_$$),$on_click_dropdown_button_on_close_font_selector$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_selector_open_QMARK_$$)],function($e$jscomp$361$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$361$$);return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$$,
$APP.$cljs$core$not$$($font_selector_open_QMARK_$$))}),$font_selector_button$$=(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$on_click_dropdown_button_on_close_font_selector$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-select"),icon:"arrow-down",variant:"action",type:"button"});$on_click_dropdown_button_on_close_font_selector$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$$,
!1)});var $on_select_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$49_props_80003$$)],function($family$jscomp$8_map__80005__$1_p__80004$$){$family$jscomp$8_map__80005__$1_p__80004$$=$APP.$cljs$core$__destructure_map$$($family$jscomp$8_map__80005__$1_p__80004$$);$family$jscomp$8_map__80005__$1_p__80004$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$8_map__80005__$1_p__80004$$,$APP.$cljs$cst$2675$family$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$956$$,
$family$jscomp$8_map__80005__$1_p__80004$$)?($APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$194$$,$input_name$jscomp$7$$,$family$jscomp$8_map__80005__$1_p__80004$$,!0),$resolve_stream$jscomp$3$$.next($family$jscomp$8_map__80005__$1_p__80004$$)):null}),$on_change$jscomp$88$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$3$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$7$$)],function($event$jscomp$619_value__$1$jscomp$72$$){$event$jscomp$619_value__$1$jscomp$72$$=
$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$619_value__$1$jscomp$72$$));$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$194$$,$input_name$jscomp$7$$,$event$jscomp$619_value__$1$jscomp$72$$,!1);return $resolve_stream$jscomp$3$$.next($event$jscomp$619_value__$1$jscomp$72$$)});$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$={...$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$,onChange:$on_change$jscomp$88$$,
value:$APP.$cljs$core$truth_$$($value$jscomp$956$$)?$value$jscomp$956$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$24$$),slotEnd:$font_selector_button$$,variant:"comfortable",hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$24$$)};$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$147_name$jscomp$479$$)?$touched_QMARK_$jscomp$9$$:$error$jscomp$147_name$jscomp$479$$)?
{...$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$147_name$jscomp$479$$)}:$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$3$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$64$$),$APP.$rumext$v2$adapt$$($token$jscomp$174$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$7$$),
$APP.$rumext$v2$adapt$$($touched_QMARK_$jscomp$9$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$40$$)],function(){var $subs$jscomp$27$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$){var $map__80007__$1_value__$1$jscomp$73$$=$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$);$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80007__$1_value__$1$jscomp$73$$,$APP.$cljs$cst$849$error$$);$map__80007__$1_value__$1$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80007__$1_value__$1$jscomp$73$$,$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$9$$)){if($APP.$cljs$core$truth_$$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$)){$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$=
$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$,$token_name$jscomp$40$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$194$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$194$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$input_name$jscomp$7$$],null),$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$);
return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80007__$1_value__$1$jscomp$73$$]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$194$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$7$$]));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$120_p__80006$$,$APP.$cljs$cst$139$type$$,
"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$371$$){return $APP.$app$common$data$update_when$$($result$jscomp$371$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$,$tokens$jscomp$64$$,$token$jscomp$174$$,$token_name$jscomp$40$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$3$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$27$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$367_props__$1$jscomp$92_props__$2$jscomp$9$$),$APP.$cljs$core$truth_$$($font_selector_open_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,{currentFont:$font$jscomp$49_props_80003$$,onSelect:$on_select_font$$,onClose:$on_click_dropdown_button_on_close_font_selector$$,fullSize:!0})}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$196$$,$field$jscomp$11$$,$value$jscomp$958$$,$trim_QMARK_$jscomp$5$$){function $clean_errors$jscomp$2$$($errors$jscomp$42$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$42$$,$field$jscomp$11$$))}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$196$$,
function($state$jscomp$1201$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($state$jscomp$1201$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$field$jscomp$11$$],null),$APP.$cljs$core$truth_$$($trim_QMARK_$jscomp$5$$)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$958$$):
$value$jscomp$958$$),$APP.$cljs$cst$570$errors$$,$clean_errors$jscomp$2$$),$APP.$cljs$cst$5073$extra_errors$$,$clean_errors$jscomp$2$$),$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$composite_fonts_combobox_STAR_$$=function($font$jscomp$50_props_80010$$){var $error$jscomp$148_name$jscomp$480$$=void 0,$token$jscomp$175$$=void 0,$tokens$jscomp$65$$=void 0,$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$=void 0;({token:$token$jscomp$175$$,tokens:$tokens$jscomp$65$$,name:$error$jscomp$148_name$jscomp$480$$,...$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$}=$font$jscomp$50_props_80010$$);
var $form$jscomp$197$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$8$$=$error$jscomp$148_name$jscomp$480$$,$token_name$jscomp$41$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$197$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$error$jscomp$148_name$jscomp$480$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$197$$),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null));var $value$jscomp$959$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$197$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null),"");$font$jscomp$50_props_80010$$=
$APP.$app$main$fonts$find_font_family$$($value$jscomp$959$$);var $resolve_stream$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$175$$)],function(){var $temp__5823__auto__$jscomp$243$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$175$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$243$$)?
$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$243$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$25$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$4$$),$font_selector_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$font_selector_open_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($font_selector_open_STAR_$jscomp$1$$),
$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_selector_open_QMARK_$jscomp$1$$)],function($e$jscomp$362$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$362$$);return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$jscomp$1$$,$APP.$cljs$core$not$$($font_selector_open_QMARK_$jscomp$1$$))}),$font_selector_button$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-select"),icon:"arrow-down",variant:"action",type:"button"});$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$jscomp$1$$,!1)});var $on_select_font$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$50_props_80010$$)],
function($family$jscomp$9_map__80012__$1_p__80011$$){$family$jscomp$9_map__80012__$1_p__80011$$=$APP.$cljs$core$__destructure_map$$($family$jscomp$9_map__80012__$1_p__80011$$);$family$jscomp$9_map__80012__$1_p__80011$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$9_map__80012__$1_p__80011$$,$APP.$cljs$cst$2675$family$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$959$$,$family$jscomp$9_map__80012__$1_p__80011$$)?($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$197$$,
$input_name$jscomp$8$$,$family$jscomp$9_map__80012__$1_p__80011$$,!0),$resolve_stream$jscomp$4$$.next($family$jscomp$9_map__80012__$1_p__80011$$)):null}),$on_change$jscomp$89$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$4$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$8$$)],function($event$jscomp$620_value__$1$jscomp$75$$){$event$jscomp$620_value__$1$jscomp$75$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$620_value__$1$jscomp$75$$));
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$197$$,$input_name$jscomp$8$$,$event$jscomp$620_value__$1$jscomp$75$$,!1);return $resolve_stream$jscomp$4$$.next($event$jscomp$620_value__$1$jscomp$75$$)});$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$={...$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$,onChange:$on_change$jscomp$89$$,value:$APP.$cljs$core$truth_$$($value$jscomp$959$$)?
$value$jscomp$959$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$25$$),slotEnd:$font_selector_button$jscomp$1$$,variant:"comfortable",hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$25$$)};$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$=$APP.$cljs$core$truth_$$($error$jscomp$148_name$jscomp$480$$)?{...$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$148_name$jscomp$480$$)}:
$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$4$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$65$$),$APP.$rumext$v2$adapt$$($token$jscomp$175$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$8$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$41$$)],function(){var $subs$jscomp$28$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$){$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$=
$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$);var $error__$1$jscomp$5_message$jscomp$121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$,
$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$5_message$jscomp$121$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$5_message$jscomp$121$$)):$error__$1$jscomp$5_message$jscomp$121$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$8$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$8$$])),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$5_message$jscomp$121$$!=null){$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$5_message$jscomp$121$$);
if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$,$token_name$jscomp$41$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$197$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$197$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$],
null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$5_message$jscomp$121$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$]));
var $input_value$jscomp$4$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$197$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null),"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));return $APP.$cljs$core$empty_QMARK_$$($error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_value$jscomp$4$$,$error_SINGLEQUOTE_$jscomp$2_map__80014__$1_p__80013_value__$1$jscomp$76$$)?
$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$5_message$jscomp$121$$,$APP.$cljs$cst$139$type$$,"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$372$$){return $APP.$app$common$data$update_when$$($result$jscomp$372$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$)},
$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$,$tokens$jscomp$65$$,$token$jscomp$175$$,$token_name$jscomp$41$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$4$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$28$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,
$props$jscomp$368_props__$1$jscomp$93_props__$2$jscomp$10$$),$APP.$cljs$core$truth_$$($font_selector_open_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,{currentFont:$font$jscomp$50_props_80010$$,onSelect:$on_select_font$jscomp$1$$,onClose:$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$,
fullSize:!0})}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value_tokenscript$$=function($token_result_tokens$jscomp$66$$,$prev_token$jscomp$5_token$jscomp$inline_13687$$,$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$){$prev_token$jscomp$5_token$jscomp$inline_13687$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($prev_token$jscomp$5_token$jscomp$inline_13687$$,$APP.$cljs$cst$260$value$$,
$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$);$token_result_tokens$jscomp$66$$=$APP.$app$main$data$tokenscript$process_tokens$$($token_result_tokens$jscomp$66$$).resolver.updateToken({tokenPath:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$5_token$jscomp$inline_13687$$),tokenData:$APP.$app$main$data$tokenscript$clj__GT_token__GT_tokenscript_token$$($prev_token$jscomp$5_token$jscomp$inline_13687$$)}).resolved;
$token_result_tokens$jscomp$66$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.ProcessorError?($G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$=$token_result_tokens$jscomp$66$$.dependencyChain,$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$=$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$==
null?null:$APP.$cljs$core$seq$$($G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$),$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$=$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$==null?null:$APP.$cljs$core$rest$$($G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$),
$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$)],
null)):$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$=$token_result_tokens$jscomp$66$$ instanceof Error?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$)],
null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$token_result_tokens$jscomp$66$$],null);return(0,$APP.$beicon$v2$core$of$$)($G__80015$jscomp$inline_9048_G__80015__$1$jscomp$inline_9049_JSCompiler_inline_result$jscomp$1872_JSCompiler_temp$jscomp$1871_value$jscomp$960$$)};
$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$=function($tokens$jscomp$67_tokens__$1$jscomp$12$$,$prev_token$jscomp$6$$,$token_name$jscomp$42$$,$value$jscomp$961$$){var $valid_token_name_QMARK_$jscomp$2$$=function(){var $and__5023__auto__$jscomp$878$$=typeof $token_name$jscomp$42$$==="string";return $and__5023__auto__$jscomp$878$$?$APP.$cljs$core$re_matches$$($APP.$app$common$types$token$token_name_validation_regex$$,$token_name$jscomp$42$$):$and__5023__auto__$jscomp$878$$}(),
$token$jscomp$176$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$961$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$not$$($valid_token_name_QMARK_$jscomp$2$$)||$APP.$cuerdas$core$blank_QMARK_$$($token_name$jscomp$42$$)?"__PENPOT__TOKEN__NAME__PLACEHOLDER__":$token_name$jscomp$42$$],null);$tokens$jscomp$67_tokens__$1$jscomp$12$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$67_tokens__$1$jscomp$12$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$6$$)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$176$$),function($p1__80016_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80016_SHARP_$$,$prev_token$jscomp$6$$,
$token$jscomp$176$$]))]))});return $APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$){$errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$176$$));var $map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$);
$errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$,$APP.$cljs$cst$570$errors$$);$map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$,$APP.$cljs$cst$4605$resolved_value$$);$map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$):$map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$;return $APP.$cljs$core$truth_$$($map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,
$map__80017__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$truth_$$($errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$)?$APP.$cljs$core$first$$($errors$jscomp$43_map__80017_resolved_tokens$jscomp$29$$):$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4601$error_SLASH_unknown$$,$value$jscomp$961$$)],null))},$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$67_tokens__$1$jscomp$12$$))};
$app$main$ui$workspace$tokens$management$forms$controls$input$input_STAR_$$=function($props_80018_touched_QMARK_$jscomp$10$$){var $error$jscomp$149_name$jscomp$481$$=void 0,$token$jscomp$177$$=void 0,$tokens$jscomp$68$$=void 0,$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$=void 0;({name:$error$jscomp$149_name$jscomp$481$$,tokens:$tokens$jscomp$68$$,token:$token$jscomp$177$$,...$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$}=$props_80018_touched_QMARK_$jscomp$10$$);var $form$jscomp$198$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$9$$=$error$jscomp$149_name$jscomp$481$$,$token_name$jscomp$43$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$props_80018_touched_QMARK_$jscomp$10$$=function(){var $and__5023__auto__$jscomp$879$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$198$$)),
$input_name$jscomp$9$$);return $and__5023__auto__$jscomp$879$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$9$$],null)):$and__5023__auto__$jscomp$879$$}();$error$jscomp$149_name$jscomp$481$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$9$$],null));var $value$jscomp$962$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$9$$],null),""),$resolve_stream$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$177$$)],
function(){return $APP.$cljs$core$contains_QMARK_$$($token$jscomp$177$$,$APP.$cljs$cst$260$value$$)?$APP.$beicon$v2$core$behavior_subject$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$177$$)):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$26$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$5$$),$on_change$jscomp$90$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$5$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$9$$)],function($event$jscomp$621_value__$1$jscomp$77$$){$event$jscomp$621_value__$1$jscomp$77$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$621_value__$1$jscomp$77$$));$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$198$$,$input_name$jscomp$9$$,$event$jscomp$621_value__$1$jscomp$77$$,!0);return $resolve_stream$jscomp$5$$.next($event$jscomp$621_value__$1$jscomp$77$$)});$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$=
{...$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$,onChange:$on_change$jscomp$90$$,defaultValue:$value$jscomp$962$$,variant:"comfortable",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$26$$),hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$26$$)};$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$149_name$jscomp$481$$)?$props_80018_touched_QMARK_$jscomp$10$$:
$error$jscomp$149_name$jscomp$481$$)?{...$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$149_name$jscomp$481$$)}:$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$5$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$68$$),$APP.$rumext$v2$adapt$$($token$jscomp$177$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$9$$),
$APP.$rumext$v2$adapt$$($token_name$jscomp$43$$)],function(){var $resolve_value$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value_tokenscript$$:$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,$subs$jscomp$29$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error__$1$jscomp$6_message$jscomp$122_p__80019$$){var $map__80020__$1_value__$1$jscomp$78$$=
$APP.$cljs$core$__destructure_map$$($error__$1$jscomp$6_message$jscomp$122_p__80019$$);$error__$1$jscomp$6_message$jscomp$122_p__80019$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80020__$1_value__$1$jscomp$78$$,$APP.$cljs$cst$849$error$$);$map__80020__$1_value__$1$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80020__$1_value__$1$jscomp$78$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$198$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$9$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$jscomp$2$$)){if($APP.$cljs$core$truth_$$($error__$1$jscomp$6_message$jscomp$122_p__80019$$)){if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error__$1$jscomp$6_message$jscomp$122_p__80019$$,$token_name$jscomp$43$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$198$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$6_message$jscomp$122_p__80019$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$198$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$5073$extra_errors$$,$input_name$jscomp$9$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$6_message$jscomp$122_p__80019$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$6_message$jscomp$122_p__80019$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$6_message$jscomp$122_p__80019$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80020__$1_value__$1$jscomp$78$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$198$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$9$$]));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,
$error__$1$jscomp$6_message$jscomp$122_p__80019$$,$APP.$cljs$cst$139$type$$,"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$374$$){return $APP.$app$common$data$update_when$$($result$jscomp$374$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($resolve_value$$,$tokens$jscomp$68$$,$token$jscomp$177$$,$token_name$jscomp$43$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$5$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$29$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$369_props__$1$jscomp$94_props__$2$jscomp$11$$)};
$app$main$ui$workspace$tokens$management$forms$controls$input$on_composite_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$200$$,$field$jscomp$13$$,$value$jscomp$964$$){function $clean_errors$jscomp$3$$($G__80027__$1_G__80027__$2_errors$jscomp$44$$){$G__80027__$1_G__80027__$2_errors$jscomp$44$$=$G__80027__$1_G__80027__$2_errors$jscomp$44$$==null?null:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80027__$1_G__80027__$2_errors$jscomp$44$$,$APP.$cljs$cst$260$value$$,
function($p1__80021_SHARP_$$){return $APP.$cljs$core$map_QMARK_$$($p1__80021_SHARP_$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__80021_SHARP_$$,$field$jscomp$13$$):null});$G__80027__$1_G__80027__$2_errors$jscomp$44$$=$G__80027__$1_G__80027__$2_errors$jscomp$44$$==null?null:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80027__$1_G__80027__$2_errors$jscomp$44$$,$APP.$cljs$cst$260$value$$,function($p1__80022_SHARP_$$){return $APP.$cljs$core$seq$$($p1__80022_SHARP_$$)?
$p1__80022_SHARP_$$:null});return $G__80027__$1_G__80027__$2_errors$jscomp$44$$==null?null:$APP.$cljs$core$not_empty$$($G__80027__$1_G__80027__$2_errors$jscomp$44$$)}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$200$$,function($state$jscomp$1202$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1202$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$field$jscomp$13$$],null),$APP.$cljs$core$truth_$$(!0)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$964$$):$value$jscomp$964$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$260$value$$,$field$jscomp$13$$],null),!0),$APP.$cljs$cst$570$errors$$,
$clean_errors$jscomp$3$$),$APP.$cljs$cst$5073$extra_errors$$,$clean_errors$jscomp$3$$),$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$=function($error$jscomp$150_props_80028_props__$3$jscomp$1$$){var $name$jscomp$482$$=void 0,$token$jscomp$178$$=void 0,$tokens$jscomp$69$$=void 0,$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$=void 0;({name:$name$jscomp$482$$,tokens:$tokens$jscomp$69$$,token:$token$jscomp$178$$,...$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$}=$error$jscomp$150_props_80028_props__$3$jscomp$1$$);var $form$jscomp$201$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$10$$=$name$jscomp$482$$,$token_name$jscomp$44$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$error$jscomp$150_props_80028_props__$3$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$201$$),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null));var $extra_error$jscomp$3$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null)),
$value$jscomp$965$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null),""),$touched_QMARK_$jscomp$11$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null)),$resolve_stream$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$178$$)],function(){var $temp__5823__auto__$jscomp$244$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$178$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null));
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$244$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$244$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$27$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$6$$),$on_change$jscomp$91$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$6$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$10$$)],function($event$jscomp$622_value__$1$jscomp$80$$){$event$jscomp$622_value__$1$jscomp$80$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$622_value__$1$jscomp$80$$));$app$main$ui$workspace$tokens$management$forms$controls$input$on_composite_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$201$$,$input_name$jscomp$10$$,$event$jscomp$622_value__$1$jscomp$80$$);return $resolve_stream$jscomp$6$$.next($event$jscomp$622_value__$1$jscomp$80$$)});
$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$={...$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$,onChange:$on_change$jscomp$91$$,defaultValue:$value$jscomp$965$$,variant:"comfortable",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$27$$),hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$27$$)};$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extra_error$jscomp$3$$)?
$extra_error$jscomp$3$$:$APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$11$$)?$error$jscomp$150_props_80028_props__$3$jscomp$1$$:$touched_QMARK_$jscomp$11$$)?{...$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$150_props_80028_props__$3$jscomp$1$$)?$error$jscomp$150_props_80028_props__$3$jscomp$1$$:$extra_error$jscomp$3$$)}:$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$;
$error$jscomp$150_props_80028_props__$3$jscomp$1$$=$APP.$cljs$core$not$$($error$jscomp$150_props_80028_props__$3$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_name$jscomp$10$$,$cljs$cst$5832$reference$$)?{...$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$,hintFormated:!0}:$props$jscomp$370_props__$1$jscomp$95_props__$2$jscomp$12$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$6$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$69$$),
$APP.$rumext$v2$adapt$$($token$jscomp$178$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$10$$),$APP.$rumext$v2$adapt$$($name$jscomp$482$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$44$$)],function(){var $subs$jscomp$30$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$){$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$=$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$);
var $error__$1$jscomp$7_input_value$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$,$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$7_input_value$jscomp$5$$)?
$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$7_input_value$jscomp$5$$)):$error__$1$jscomp$7_input_value$jscomp$5$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$10$$])),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$10$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$7_input_value$jscomp$5$$!=null){$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$7_input_value$jscomp$5$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$,
$token_name$jscomp$44$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$201$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$201$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$7_input_value$jscomp$5$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null),"");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$482$$,
$APP.$cljs$cst$1765$line_height$$)){var $JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$=$APP.$app$common$files$tokens$parse_token_value$$($error__$1$jscomp$7_input_value$jscomp$5$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$)){var $map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$);$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$,$APP.$cljs$cst$4574$unit$$);$map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$,$APP.$cljs$cst$260$value$$);var $font_size$jscomp$inline_13693$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1760$font_size$$],null),"");$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("%",$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$)?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$)/100:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("px",$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$)?
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$)/$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_13693$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$)?$map__80032__$1$jscomp$inline_13690_value__$2$jscomp$inline_13692$$:
null;$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$=$APP.$app$main$data$workspace$tokens$format$format_token_value$$($JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$)}else $JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$=
null}else $JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$=$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$);$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$)?$JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$:$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$5345$async_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5832$reference$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($error__$1$jscomp$7_input_value$jscomp$5$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11036_calculated$jscomp$inline_13694_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13689_unit$jscomp$inline_13691$$))?$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80031__$1_message$jscomp$123_p__80030_value__$1$jscomp$81$$,$APP.$cljs$cst$139$type$$,"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$375$$){return $APP.$app$common$data$update_when$$($result$jscomp$375$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},
$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,$tokens$jscomp$69$$,$token$jscomp$178$$,$token_name$jscomp$44$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$6$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$30$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$error$jscomp$150_props_80028_props__$3$jscomp$1$$)};
$app$main$ui$workspace$tokens$management$forms$controls$input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$=function($form$jscomp$203$$,$field$jscomp$15$$,$index$jscomp$553$$,$value$jscomp$967$$,$value_subfield$jscomp$4$$){function $clean_errors$jscomp$4$$($errors$jscomp$45$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$45$$,$field$jscomp$15$$))}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$203$$,
function($state$jscomp$1203$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($state$jscomp$1203$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$4$$,$index$jscomp$553$$,$field$jscomp$15$$],null),$APP.$cljs$core$truth_$$(!0)?
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$967$$):$value$jscomp$967$$),$APP.$cljs$cst$570$errors$$,$clean_errors$jscomp$4$$),$APP.$cljs$cst$5073$extra_errors$$,$clean_errors$jscomp$4$$),$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$=function($error$jscomp$151_props_80036$$){var $index$jscomp$554$$=void 0,$extra_error$jscomp$4_name$jscomp$483$$=void 0,$token$jscomp$179$$=void 0,$value_subfield$jscomp$5$$=void 0,$tokens$jscomp$70$$=void 0,$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$=void 0;({name:$extra_error$jscomp$4_name$jscomp$483$$,tokens:$tokens$jscomp$70$$,token:$token$jscomp$179$$,index:$index$jscomp$554$$,
valueSubfield:$value_subfield$jscomp$5$$,...$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$}=$error$jscomp$151_props_80036$$);var $form$jscomp$204$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$11$$=$extra_error$jscomp$4_name$jscomp$483$$,$token_name$jscomp$45$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$error$jscomp$151_props_80036$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$554$$,$input_name$jscomp$11$$],null));$extra_error$jscomp$4_name$jscomp$483$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$204$$),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$554$$,$input_name$jscomp$11$$],null));var $value_from_form$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,
$value_subfield$jscomp$5$$,$index$jscomp$554$$,$input_name$jscomp$11$$],null),""),$resolve_stream$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$179$$),$APP.$rumext$v2$adapt$$($index$jscomp$554$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$11$$)],function(){var $temp__5823__auto__$jscomp$245$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$179$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$554$$,$input_name$jscomp$11$$],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$245$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$245$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$28$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$7$$),$on_change$jscomp$92$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$7$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$11$$),$APP.$rumext$v2$adapt$$($index$jscomp$554$$)],function($event$jscomp$623_value$jscomp$969$$){$event$jscomp$623_value$jscomp$969$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$623_value$jscomp$969$$));$app$main$ui$workspace$tokens$management$forms$controls$input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$($form$jscomp$204$$,
$input_name$jscomp$11$$,$index$jscomp$554$$,$event$jscomp$623_value$jscomp$969$$,$value_subfield$jscomp$5$$);return $resolve_stream$jscomp$7$$.next($event$jscomp$623_value$jscomp$969$$)});$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$={...$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$,onChange:$on_change$jscomp$92$$,value:$value_from_form$$,variant:"comfortable",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$28$$),
hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$28$$)};$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$151_props_80036$$)?$error$jscomp$151_props_80036$$:$extra_error$jscomp$4_name$jscomp$483$$)?{...$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$151_props_80036$$)?
$error$jscomp$151_props_80036$$:$extra_error$jscomp$4_name$jscomp$483$$)}:$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$;$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$=$APP.$cljs$core$not$$($error$jscomp$151_props_80036$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_name$jscomp$11$$,$cljs$cst$5832$reference$$)?{...$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$,hintFormated:!0}:$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$;
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$7$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$70$$),$APP.$rumext$v2$adapt$$($token$jscomp$179$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$11$$),$APP.$rumext$v2$adapt$$($index$jscomp$554$$),$APP.$rumext$v2$adapt$$($value_subfield$jscomp$5$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$45$$)],function(){var $subs$jscomp$31$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$){$error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$=
$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$);var $error__$1$jscomp$8_message$jscomp$124$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$,
$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$8_message$jscomp$124$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4603$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$8_message$jscomp$124$$)):$error__$1$jscomp$8_message$jscomp$124$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$554$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$11$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,
$index$jscomp$554$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$11$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);
if($error__$1$jscomp$8_message$jscomp$124$$!=null){$error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$8_message$jscomp$124$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$,$token_name$jscomp$45$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$204$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$204$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$554$$,$input_name$jscomp$11$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$,
$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$8_message$jscomp$124$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$)]));var $input_value$jscomp$6$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$204$$),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$554$$,$input_name$jscomp$11$$],null),"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_value$jscomp$6$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($error_SINGLEQUOTE_$jscomp$4_map__80038__$1_p__80037_value$jscomp$970$$))?$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$8_message$jscomp$124$$,$APP.$cljs$cst$139$type$$,"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$376$$){return $APP.$app$common$data$update_when$$($result$jscomp$376$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,
$tokens$jscomp$70$$,$token$jscomp$179$$,$token_name$jscomp$45$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$7$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$31$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$371_props__$1$jscomp$96_props__$2$jscomp$13_props__$3$jscomp$2$$)};
$app$main$ui$workspace$tokens$management$forms$controls$select$select_indexed_STAR_$$=function($props_80029_value$jscomp$971$$){var $index$jscomp$555$$=void 0,$name$jscomp$484_on_change$jscomp$93$$=void 0,$indexed_type$$=void 0,$props$jscomp$372$$=void 0;({name:$name$jscomp$484_on_change$jscomp$93$$,index:$index$jscomp$555$$,indexedType:$indexed_type$$,...$props$jscomp$372$$}=$props_80029_value$jscomp$971$$);var $form$jscomp$205$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$12$$=
$name$jscomp$484_on_change$jscomp$93$$;$props_80029_value$jscomp$971$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$205$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$indexed_type$$,$index$jscomp$555$$,$input_name$jscomp$12$$],null),!1);$name$jscomp$484_on_change$jscomp$93$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($input_name$jscomp$12$$)],
function($id$jscomp$1022_is_inner_QMARK_$$){$id$jscomp$1022_is_inner_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1022_is_inner_QMARK_$$,"inner");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$205$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$indexed_type$$,$index$jscomp$555$$,$input_name$jscomp$12$$],null),$id$jscomp$1022_is_inner_QMARK_$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$205$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([""]))});return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{...$props$jscomp$372$$,defaultSelected:$APP.$cljs$core$truth_$$($props_80029_value$jscomp$971$$)?"inner":"drop",variant:"ghost",onChange:$name$jscomp$484_on_change$jscomp$93$$})};
$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$=function($token_name$jscomp$46$$,$token_value$jscomp$11$$){return $APP.$app$common$types$token$token_value_self_reference_QMARK_$$($token_name$jscomp$46$$,$token_value$jscomp$11$$)?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4591$error_DOT_token_SLASH_direct_self_reference$$):null};
$app$main$ui$workspace$tokens$management$forms$validators$validate_resolve_token$$=function($token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$,$prev_token$jscomp$7$$,$tokens$jscomp$71$$){var $token__$1$jscomp$3$$=$APP.$cljs$core$not$$($app$common$schema$valid_QMARK_$$($APP.$app$common$types$token$schema_COLON_token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$)))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$,
$APP.$cljs$cst$725$name$$,"__PENPOT__TOKEN__NAME__PLACEHOLDER__"):$token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$;$token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$=function(){var $G__80043__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$3$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$7$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$71$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$7$$)):
$tokens$jscomp$71$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80043__$1$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$3$$),function($p1__80041_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80041_SHARP_$$,
$prev_token$jscomp$7$$,$token__$1$jscomp$3$$]))]))})}();return $APP.$beicon$v2$core$mapcat$$(function($resolved_tokens$jscomp$30$$){var $resolved_token$jscomp$23$$=function(){var $G__80044$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$30$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$3$$));return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80044$$,
$APP.$cljs$cst$4605$resolved_value$$,$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$):$G__80044$$}();return $APP.$cljs$core$truth_$$($APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$23$$))?(0,$APP.$beicon$v2$core$of$$)($resolved_token$jscomp$23$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,function(){var $or__5025__auto__$jscomp$1271$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$23$$));
return $or__5025__auto__$jscomp$1271$$?$or__5025__auto__$jscomp$1271$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($cljs$cst$5833$error_SLASH_unknown_error$$)],null)}()],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$)):
$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($token$jscomp$181_tokens_SINGLEQUOTE_$jscomp$2$$))};
$app$main$ui$workspace$tokens$management$forms$validators$validate_token_with$$=function($token$jscomp$182$$,$temp__5823__auto__$jscomp$246_validators$jscomp$9$$){$temp__5823__auto__$jscomp$246_validators$jscomp$9$$=$APP.$cljs$core$some$$(function($validate$jscomp$5$$){return $validate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$validate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$182$$):$validate$jscomp$5$$($token$jscomp$182$$)},$temp__5823__auto__$jscomp$246_validators$jscomp$9$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$246_validators$jscomp$9$$)?$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$temp__5823__auto__$jscomp$246_validators$jscomp$9$$],null)],null)):(0,$APP.$beicon$v2$core$of$$)($token$jscomp$182$$)};
$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$=function($map__80048__$1_p__80047_token$jscomp$183$$){$map__80048__$1_p__80047_token$jscomp$183$$=$APP.$cljs$core$__destructure_map$$($map__80048__$1_p__80047_token$jscomp$183$$);var $token_name$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80048__$1_p__80047_token$jscomp$183$$,$APP.$cljs$cst$4186$token_name$$),$token_value$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80048__$1_p__80047_token$jscomp$183$$,
$cljs$cst$5834$token_value$$),$token_description$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80048__$1_p__80047_token$jscomp$183$$,$cljs$cst$5835$token_description$$),$prev_token$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80048__$1_p__80047_token$jscomp$183$$,$cljs$cst$5836$prev_token$$),$tokens$jscomp$72$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80048__$1_p__80047_token$jscomp$183$$,$APP.$cljs$cst$2100$tokens$$),$validators$jscomp$10$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__80048__$1_p__80047_token$jscomp$183$$,$APP.$cljs$cst$5072$validators$$,$app$main$ui$workspace$tokens$management$forms$validators$default_validators$$);$map__80048__$1_p__80047_token$jscomp$183$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$token_name$jscomp$47$$,$APP.$cljs$cst$260$value$$,$token_value$jscomp$12$$,$APP.$cljs$cst$936$description$$,
$token_description$$],null));return $APP.$beicon$v2$core$mapcat$$(function($p1__80046_SHARP_$$){return $app$main$ui$workspace$tokens$management$forms$validators$validate_resolve_token$$($p1__80046_SHARP_$$,$prev_token$jscomp$8$$,$tokens$jscomp$72$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__80045_SHARP_$$){return $app$main$ui$workspace$tokens$management$forms$validators$validate_token_with$$($p1__80045_SHARP_$$,$validators$jscomp$10$$)},(0,$APP.$beicon$v2$core$of$$)($map__80048__$1_p__80047_token$jscomp$183$$)))};
$app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$=function($token_name$jscomp$48$$,$token_vals$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__80049_SHARP_$$){return $APP.$app$common$types$token$token_value_self_reference_QMARK_$$($token_name$jscomp$48$$,$p1__80049_SHARP_$$)},$token_vals$$))?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4591$error_DOT_token_SLASH_direct_self_reference$$):null};
$app$main$ui$workspace$tokens$management$forms$generic_form$get_value_for_validator$$=function($active_tab$$,$value$jscomp$972$$,$value_subfield$jscomp$6$$,$value_type$$){switch($value_type$$ instanceof $APP.$cljs$core$Keyword$$?$value_type$$.$fqn$:null){case "indexed":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$$,$cljs$cst$5832$reference$$)?$cljs$cst$5832$reference$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$972$$):$value_subfield$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?
$value_subfield$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$972$$):$value_subfield$jscomp$6$$($value$jscomp$972$$);case "composite":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$$,$cljs$cst$5832$reference$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$972$$,$cljs$cst$5832$reference$$):$value$jscomp$972$$;default:return $value$jscomp$972$$}};
$app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$=function($props_80052_token_properties_token_title$$){var $is_create$$=$props_80052_token_properties_token_title$$.isCreate,$value_type$jscomp$1$$=$props_80052_token_properties_token_title$$.valueType,$make_schema$$=$props_80052_token_properties_token_title$$.makeSchema,$active_tokens_by_type$jscomp$1_validator$jscomp$35$$=$props_80052_token_properties_token_title$$.validator,$input_value_placeholder$$=$props_80052_token_properties_token_title$$.inputValuePlaceholder,
$tokens_tree_in_selected_set$$=$props_80052_token_properties_token_title$$.tokensTreeInSelectedSet,$selected_token_set_id$jscomp$9$$=$props_80052_token_properties_token_title$$.selectedTokenSetId,$general_errors_input_component_schema$jscomp$245$$=$props_80052_token_properties_token_title$$.inputComponent,$token$jscomp$184$$=$props_80052_token_properties_token_title$$.token,$initial_errors$jscomp$2$$=$props_80052_token_properties_token_title$$.initialErrors,$token_type$jscomp$22$$=$props_80052_token_properties_token_title$$.tokenType,
$value_subfield$jscomp$7$$=$props_80052_token_properties_token_title$$.valueSubfield,$initial$jscomp$37$$=$props_80052_token_properties_token_title$$.initial,$action$jscomp$7$$=$props_80052_token_properties_token_title$$.action,$make_schema__$1$$=function(){return $APP.$cljs$core$truth_$$($make_schema$$)?$make_schema$$:function($p1__80051_SHARP_$$){return $APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($p1__80051_SHARP_$$,$token_type$jscomp$22$$))}}(),$input_component__$1$$=
$APP.$cljs$core$truth_$$($general_errors_input_component_schema$jscomp$245$$)?$general_errors_input_component_schema$jscomp$245$$:$app$main$ui$workspace$tokens$management$forms$controls$input$input_STAR_$$,$validate_token$$=$APP.$cljs$core$truth_$$($active_tokens_by_type$jscomp$1_validator$jscomp$35$$)?$active_tokens_by_type$jscomp$1_validator$jscomp$35$$:$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$,$active_tab_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$184$$),
"{"))?$cljs$cst$5832$reference$$:$cljs$cst$5837$composite$$}),$active_tab$jscomp$1$$=$APP.$cljs$core$_deref$$($active_tab_STAR_$$),$token__$1$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$184$$)],function(){return $APP.$cljs$core$truth_$$($token$jscomp$184$$)?$token$jscomp$184$$:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$22$$],null)});$props_80052_token_properties_token_title$$=$app$main$data$workspace$tokens$application$get_token_properties$$($token__$1$jscomp$4$$);
$props_80052_token_properties_token_title$$=$APP.$cuerdas$core$lower$$($APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($props_80052_token_properties_token_title$$));var $tokens$jscomp$73$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_map$$),$tokens_in_selected_set$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_in_selected_set$$),$tokens__$1$jscomp$13$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$73$$),
$APP.$rumext$v2$adapt$$($tokens_in_selected_set$$),$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$)],function(){var $G__80053$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tokens$jscomp$73$$,$tokens_in_selected_set$$]));var $JSCompiler_inline_result$jscomp$1873_and__5023__auto__$jscomp$inline_9051$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$);$JSCompiler_inline_result$jscomp$1873_and__5023__auto__$jscomp$inline_9051$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1873_and__5023__auto__$jscomp$inline_9051$$)?$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$):$JSCompiler_inline_result$jscomp$1873_and__5023__auto__$jscomp$inline_9051$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1873_and__5023__auto__$jscomp$inline_9051$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80053$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),
$token__$1$jscomp$4$$):$G__80053$$});$active_tokens_by_type$jscomp$1_validator$jscomp$35$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$13$$)],function(){return new $APP.$cljs$core$Delay$$(function(){return $app$common$types$tokens_lib$group_by_type$$($tokens__$1$jscomp$13$$)})});$general_errors_input_component_schema$jscomp$245$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_tree_in_selected_set$$),
$APP.$rumext$v2$adapt$$($active_tab$jscomp$1$$)],function(){return $make_schema__$1$$.$cljs$core$IFn$_invoke$arity$2$?$make_schema__$1$$.$cljs$core$IFn$_invoke$arity$2$($tokens_tree_in_selected_set$$,$active_tab$jscomp$1$$):$make_schema__$1$$($tokens_tree_in_selected_set$$,$active_tab$jscomp$1$$)});var $handle_key_down_delete_initial__$1$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($initial$jscomp$37$$)],
function(){return $APP.$cljs$core$truth_$$($initial$jscomp$37$$)?$initial$jscomp$37$$:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$22$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$4$$,""),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$4$$,""),$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$4$$,
"")],null)}),$handle_key_down_cancel_initial_general_errors$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($handle_key_down_delete_initial__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($initial_errors$jscomp$2$$)],function(){return $APP.$cljs$core$truth_$$($initial_errors$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$)))?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value_type$jscomp$1$$,$cljs$cst$5837$composite$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value_type$jscomp$1$$,$cljs$cst$5838$indexed$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5832$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$))],
null)],null)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$))],null)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,["",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$))],
null)],null):null}),$form$jscomp$206$$=$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$298$schema$$,$general_errors_input_component_schema$jscomp$245$$,$APP.$cljs$cst$5077$initial_errors$$,$handle_key_down_cancel_initial_general_errors$$,$APP.$cljs$cst$5076$initial$$,$handle_key_down_delete_initial__$1$jscomp$3$$]));$general_errors_input_component_schema$jscomp$245$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$206$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,""],null));var $on_toggle_tab$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$206$$)],function($new_tab_new_tab__$1$$){$new_tab_new_tab__$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($new_tab_new_tab__$1$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_tab_new_tab__$1$$,$cljs$cst$5832$reference$$)?
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$206$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5345$async_errors$$,$cljs$cst$5832$reference$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,"Need valid reference"],null)):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$206$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5345$async_errors$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5832$reference$$]));return $APP.$cljs$core$reset_BANG_$$($active_tab_STAR_$$,$new_tab_new_tab__$1$$)}),$on_cancel$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$363$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$363$$);return $APP.$app$main$data$modal$hide_BANG_$$()}),$on_delete_token$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$9$$),
$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$)],function($e$jscomp$364$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$364$$);$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token$$($selected_token_set_id$jscomp$9$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$)))});$handle_key_down_delete_initial__$1$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_delete_token$jscomp$3$$)],
function($e$jscomp$365$$){var $JSCompiler_inline_result$jscomp$1874_or__5025__auto__$jscomp$inline_9053$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$365$$);$JSCompiler_inline_result$jscomp$1874_or__5025__auto__$jscomp$inline_9053$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1874_or__5025__auto__$jscomp$inline_9053$$)?$JSCompiler_inline_result$jscomp$1874_or__5025__auto__$jscomp$inline_9053$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$365$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1874_or__5025__auto__$jscomp$inline_9053$$)?
$on_delete_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$365$$):$on_delete_token$jscomp$3$$($e$jscomp$365$$):null});$handle_key_down_cancel_initial_general_errors$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$jscomp$9$$)],function($e$jscomp$366$$){var $JSCompiler_inline_result$jscomp$1875_or__5025__auto__$jscomp$inline_9055$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$366$$);
$JSCompiler_inline_result$jscomp$1875_or__5025__auto__$jscomp$inline_9055$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1875_or__5025__auto__$jscomp$inline_9055$$)?$JSCompiler_inline_result$jscomp$1875_or__5025__auto__$jscomp$inline_9055$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$366$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1875_or__5025__auto__$jscomp$inline_9055$$)?$on_cancel$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$on_cancel$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$366$$):
$on_cancel$jscomp$9$$($e$jscomp$366$$):null});var $on_remap_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$22$$)],function($valid_token$$,$new_name$jscomp$38$$,$old_name$jscomp$2$$,$description$jscomp$19$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$($token_type$jscomp$22$$,$new_name$jscomp$38$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$new_name$jscomp$38$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$$),$APP.$cljs$cst$936$description$$,$description$jscomp$19$$],null)),
$app$main$data$workspace$tokens$remapping$remap_tokens$$($old_name$jscomp$2$$,$new_name$jscomp$38$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$(),$APP.$app$main$data$modal$hide_BANG_$$()]))}),$on_rename_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$22$$)],function($valid_token$jscomp$1$$,$name$jscomp$485$$,$description$jscomp$20$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$($token_type$jscomp$22$$,
$name$jscomp$485$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$name$jscomp$485$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$jscomp$1$$),$APP.$cljs$cst$936$description$$,$description$jscomp$20$$],
null)),$APP.$app$main$data$modal$hide_BANG_$$()]))}),$on_submit$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($validate_token$$),$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$13$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$22$$),$APP.$rumext$v2$adapt$$($value_subfield$jscomp$7$$),$APP.$rumext$v2$adapt$$($value_type$jscomp$1$$),$APP.$rumext$v2$adapt$$($active_tab$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_remap_token$$),
$APP.$rumext$v2$adapt$$($on_rename_token$$),$APP.$rumext$v2$adapt$$($is_create$$)],function($form__$1$jscomp$20$$,$event$jscomp$624$$){var $name$jscomp$486$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$20$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$725$name$$],null)),$description$jscomp$21$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$20$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$936$description$$],null)),$value$jscomp$973$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$20$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$260$value$$],null)),$value_for_validation$$=$app$main$ui$workspace$tokens$management$forms$generic_form$get_value_for_validator$$($active_tab$jscomp$1$$,
$value$jscomp$973$$,$value_subfield$jscomp$7$$,$value_type$jscomp$1$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$624$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($valid_token$jscomp$2$$){function $on_rename$jscomp$3$$(){return $on_rename_token$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename_token$$.$cljs$core$IFn$_invoke$arity$3$($valid_token$jscomp$2$$,$name$jscomp$486$$,$description$jscomp$21$$):$on_rename_token$$($valid_token$jscomp$2$$,$name$jscomp$486$$,
$description$jscomp$21$$)}function $on_remap$$(){return $on_remap_token$$.$cljs$core$IFn$_invoke$arity$4$?$on_remap_token$$.$cljs$core$IFn$_invoke$arity$4$($valid_token$jscomp$2$$,$name$jscomp$486$$,$old_name$jscomp$3$$,$description$jscomp$21$$):$on_remap_token$$($valid_token$jscomp$2$$,$name$jscomp$486$$,$old_name$jscomp$3$$,$description$jscomp$21$$)}var $is_rename_state$jscomp$1204$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_data$jscomp$122_references_count$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($is_rename_state$jscomp$1204$$),
$old_name$jscomp$3$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$);$is_rename_state$jscomp$1204$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$7$$,"edit")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$486$$,$old_name$jscomp$3$$);$file_data$jscomp$122_references_count$$=$app$main$data$workspace$tokens$remapping$count_token_references$$($file_data$jscomp$122_references_count$$,$old_name$jscomp$3$$);var $remap_data$jscomp$1$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5774$new_name$$,$name$jscomp$486$$,$cljs$cst$5773$old_name$$,$old_name$jscomp$3$$,$APP.$cljs$cst$139$type$$,"token"],null);if($is_rename_state$jscomp$1204$$&&$file_data$jscomp$122_references_count$$>0)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5806$tokens_SLASH_remapping_confirmation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$cljs$cst$5807$remap_data$$,$remap_data$jscomp$1$$,$cljs$cst$5808$on_remap$$,$on_remap$$,$cljs$cst$5809$on_rename$$,$on_rename$jscomp$3$$],null)));$is_rename_state$jscomp$1204$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$($token_type$jscomp$22$$,$name$jscomp$486$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$truth_$$($is_create$$)?$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$725$name$$,$name$jscomp$486$$,$APP.$cljs$cst$139$type$$,$token_type$jscomp$22$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$jscomp$2$$),$APP.$cljs$cst$936$description$$,$description$jscomp$21$$],null)]))):$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$name$jscomp$486$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$jscomp$2$$),$APP.$cljs$cst$936$description$$,$description$jscomp$21$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$open_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$)),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$(),
$APP.$app$main$data$modal$hide_BANG_$$()]))},function($error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$){$error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$=$APP.$cljs$core$__destructure_map$$($error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$);$error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$,
$APP.$cljs$cst$570$errors$$);$error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$=$app$main$data$workspace$tokens$errors$humanize_errors$$($error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$);$error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$=$APP.$cljs$core$first$$($error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$20$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$cst$260$value$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_message_error_messages_errors$jscomp$46_map__80055__$1_p__80054$$],null))},function(){var $G__80056$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5834$token_value$$,$value_for_validation$$,$APP.$cljs$cst$4186$token_name$$,$name$jscomp$486$$,
$cljs$cst$5835$token_description$$,$description$jscomp$21$$,$cljs$cst$5836$prev_token$$,$token__$1$jscomp$4$$,$APP.$cljs$cst$2100$tokens$$,$tokens__$1$jscomp$13$$],null);return $validate_token$$.$cljs$core$IFn$_invoke$arity$1$?$validate_token$$.$cljs$core$IFn$_invoke$arity$1$($G__80056$$):$validate_token$$($G__80056$$)}())});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$active_tokens_by_type$$),{value:$active_tokens_by_type$jscomp$1_validator$jscomp$35$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_STAR_$$,
{className:"main_ui_workspace_tokens_management_forms_generic_form__form-wrapper",form:$form$jscomp$206$$,onSubmit:$on_submit$jscomp$18$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__token-rows",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_management_forms_generic_form__form-modal-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$7$$,
"edit")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.edit-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$22$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.create-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$22$$]))}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__input-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,
{id:"token-name",name:$APP.$cljs$cst$725$name$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.enter-token-name",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$props_80052_token_properties_token_title$$])),maxLength:255,variant:"comfortable",trim:!0,autoFocus:!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__input-row",
children:function(){switch($value_type$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$value_type$jscomp$1$$.$fqn$:null){case "indexed":return(0,$APP.$rumext$v2$jsx$$)($input_component__$1$$,{token:$token__$1$jscomp$4$$,tokens:$tokens__$1$jscomp$13$$,tab:$active_tab$jscomp$1$$,valueSubfield:$value_subfield$jscomp$7$$,handleToggle:$on_toggle_tab$$});case "composite":return(0,$APP.$rumext$v2$jsx$$)($input_component__$1$$,{token:$token__$1$jscomp$4$$,tokens:$tokens__$1$jscomp$13$$,tab:$active_tab$jscomp$1$$,
handleToggle:$on_toggle_tab$$});default:return(0,$APP.$rumext$v2$jsx$$)($input_component__$1$$,{placeholder:$APP.$cljs$core$truth_$$($input_value_placeholder$$)?$input_value_placeholder$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-value-enter"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-value"),name:$APP.$cljs$cst$260$value$$,token:$token__$1$jscomp$4$$,tokenType:$token_type$jscomp$22$$,tokens:$tokens__$1$jscomp$13$$})}}()}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__input-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,{id:"token-description",name:$APP.$cljs$cst$936$description$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-description"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-description"),maxLength:255,variant:"comfortable",isOptional:!0})}),
$general_errors_input_component_schema$jscomp$245$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$2343$warning$$,appearance:$APP.$cljs$cst$4985$ghost$$,children:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($general_errors_input_component_schema$jscomp$245$$)}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__button-row "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$7$$,
"edit")?"main_ui_workspace_tokens_management_forms_generic_form__with-delete":""),children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$7$$,"edit")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_delete_token$jscomp$3$$,onKeyDown:$handle_key_down_delete_initial__$1$jscomp$3$$,className:"main_ui_workspace_tokens_management_forms_generic_form__delete-btn",type:"button",icon:"delete",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")}):
null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_cancel$jscomp$9$$,onKeyDown:$handle_key_down_cancel_initial_general_errors$$,type:"button",id:"token-modal-cancel",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_submit_STAR_$$,{variant:"primary",onSubmit:$on_submit$jscomp$18$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save")})]})]})})})};
$app$main$ui$workspace$tokens$management$forms$color$form_STAR_$$=function($props_80060$$){var $token$jscomp$185$$=$props_80060$$.token,$token_type$jscomp$23$$=$props_80060$$.tokenType,$initial$jscomp$38$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_type$jscomp$23$$),$APP.$rumext$v2$adapt$$($token$jscomp$185$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$23$$,$APP.$cljs$cst$725$name$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$185$$,""),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$185$$,""),$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$185$$,""),$cljs$cst$5826$color_result$$,""],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,{...$props_80060$$,makeSchema:function($p1__80059_SHARP__s$jscomp$inline_9057$$){$p1__80059_SHARP__s$jscomp$inline_9057$$=
$APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($p1__80059_SHARP__s$jscomp$inline_9057$$,$token_type$jscomp$23$$));return $app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$($p1__80059_SHARP__s$jscomp$inline_9057$$,$cljs$cst$5826$color_result$$,$APP.$cljs$cst$198$string$$)},initial:$initial$jscomp$38$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$controls$color_input$color_input_STAR_$$})};
$app$main$ui$workspace$tokens$management$forms$font_family$check_font_family_token_self_reference$$=function($token$jscomp$186$$){return $app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$186$$),$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$186$$))};
$app$main$ui$workspace$tokens$management$forms$font_family$validate_font_family_token$$=function($props$jscomp$375$$){return $app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$375$$,$cljs$cst$5834$token_value$$,$APP.$app$common$types$token$split_font_family$$),$APP.$cljs$cst$5072$validators$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($token$jscomp$187$$){return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$187$$))?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$):null},$app$main$ui$workspace$tokens$management$forms$font_family$check_font_family_token_self_reference$$],null)))};
$app$main$ui$workspace$tokens$management$forms$font_family$form_STAR_$$=function($props_80063_token__$1$jscomp$5$$){var $token$jscomp$188$$=void 0,$token_type$jscomp$24$$=void 0,$props$jscomp$376$$=void 0;({token:$token$jscomp$188$$,tokenType:$token_type$jscomp$24$$,...$props$jscomp$376$$}=$props_80063_token__$1$jscomp$5$$);$props_80063_token__$1$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$188$$)],function(){return $APP.$cljs$core$truth_$$($token$jscomp$188$$)?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($token$jscomp$188$$,$APP.$cljs$cst$260$value$$,$app$common$types$token$join_font_family$$):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$24$$],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,{...$props$jscomp$376$$,token:$props_80063_token__$1$jscomp$5$$,tokenType:$token_type$jscomp$24$$,makeSchema:function($p1__80062_SHARP__s$jscomp$inline_9061$$){$p1__80062_SHARP__s$jscomp$inline_9061$$=
$APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($p1__80062_SHARP__s$jscomp$inline_9061$$,$token_type$jscomp$24$$));return $app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$($p1__80062_SHARP__s$jscomp$inline_9061$$,$APP.$cljs$cst$260$value$$,$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$)},validator:$app$main$ui$workspace$tokens$management$forms$font_family$validate_font_family_token$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$fonts_combobox_STAR_$$})};
$app$main$ui$workspace$tokens$management$forms$shadow$check_shadow_token_self_reference$$=function($shadow_values$jscomp$1_token$jscomp$189$$){var $token_name$jscomp$49$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shadow_values$jscomp$1_token$jscomp$189$$);$shadow_values$jscomp$1_token$jscomp$189$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($shadow_values$jscomp$1_token$jscomp$189$$);return $APP.$cljs$core$some$$(function($p__80064_shadow_map$jscomp$2$$){var $shadow_idx$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80064_shadow_map$jscomp$2$$,0,null);$p__80064_shadow_map$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80064_shadow_map$jscomp$2$$,1,null);return $APP.$cljs$core$some$$(function($p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$){var $k$jscomp$698$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$,0,null);$p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$,1,null);$p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$=$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$($token_name$jscomp$49$$,$p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$);return $APP.$cljs$core$truth_$$($p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p__80068_temp__5825__auto__$jscomp$405_v$jscomp$679$$,
$APP.$cljs$cst$4622$shadow_key$$,$k$jscomp$698$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4623$shadow_index$$,$shadow_idx$$])):null},$p__80064_shadow_map$jscomp$2$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($shadow_values$jscomp$1_token$jscomp$189$$))};
$app$main$ui$workspace$tokens$management$forms$shadow$check_empty_shadow_token$$=function($token$jscomp$190$$){return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1280$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$190$$));return $or__5025__auto__$jscomp$1280$$?$or__5025__auto__$jscomp$1280$$:$APP.$cljs$core$some$$(function($shadow__$1$jscomp$22$$){return $cljs$core$not_every_QMARK_$$(function($p1__80072_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($shadow__$1$jscomp$22$$,
$p1__80072_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1650$offset_x$$,$APP.$cljs$cst$1651$offset_y$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1652$spread$$,$APP.$cljs$cst$1298$color$$],null))},$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$190$$))}())?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$):null};
$app$main$ui$workspace$tokens$management$forms$shadow$validate_shadow_token$$=function($map__80075__$1_p__80074_params__$1$jscomp$58$$){$map__80075__$1_p__80074_params__$1$jscomp$58$$=$APP.$cljs$core$__destructure_map$$($map__80075__$1_p__80074_params__$1$jscomp$58$$);var $token_value$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80075__$1_p__80074_params__$1$jscomp$58$$,$cljs$cst$5834$token_value$$);if($token_value$jscomp$13$$==null)return(0,$APP.$beicon$v2$core$of$$)(null);
if(typeof $token_value$jscomp$13$$==="string")return $app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($map__80075__$1_p__80074_params__$1$jscomp$58$$);$map__80075__$1_p__80074_params__$1$jscomp$58$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__80075__$1_p__80074_params__$1$jscomp$58$$,$cljs$cst$5834$token_value$$,function($value$jscomp$974$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($shadow__$1$jscomp$23$$){return $APP.$app$common$data$update_when$$($shadow__$1$jscomp$23$$,
$APP.$cljs$cst$2133$inset$$,function($p1__80073_SHARP_$$){return $APP.$cljs$core$boolean_QMARK_$$($p1__80073_SHARP_$$)?$p1__80073_SHARP_$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("true",$p1__80073_SHARP_$$)?!0:!1})},$APP.$cljs$core$truth_$$($value$jscomp$974$$)?$value$jscomp$974$$:$APP.$cljs$core$PersistentVector$EMPTY$$)}),$APP.$cljs$cst$5072$validators$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$shadow$check_empty_shadow_token$$,
$app$main$ui$workspace$tokens$management$forms$shadow$check_shadow_token_self_reference$$],null));return $app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($map__80075__$1_p__80074_params__$1$jscomp$58$$)};
$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$=function($token$jscomp$191_value$jscomp$975$$,$index$jscomp$556$$,$prop$jscomp$42$$,$value_subfield$jscomp$8$$){$token$jscomp$191_value$jscomp$975$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$191_value$jscomp$975$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$8$$,$index$jscomp$556$$,$prop$jscomp$42$$],null));
return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$42$$,$APP.$cljs$cst$1298$color$$)?$APP.$cljs$cst$1298$color$$:$APP.$cljs$cst$1980$dimensions$$,$APP.$cljs$cst$260$value$$,$token$jscomp$191_value$jscomp$975$$],null))};
$app$main$ui$workspace$tokens$management$forms$shadow$shadow_formset_STAR_$$=function($props_80076_tokens$jscomp$74$$){var $index$jscomp$557$$=$props_80076_tokens$jscomp$74$$.index,$show_button$$=$props_80076_tokens$jscomp$74$$.showButton,$spread_token_spread_token__$1_token$jscomp$192$$=$props_80076_tokens$jscomp$74$$.token,$remove_shadow_block$$=$props_80076_tokens$jscomp$74$$.removeShadowBlock,$value_subfield$jscomp$9$$=$props_80076_tokens$jscomp$74$$.valueSubfield;$props_80076_tokens$jscomp$74$$=
$props_80076_tokens$jscomp$74$$.tokens;var $inset_token_inset_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$192$$,$index$jscomp$557$$,$APP.$cljs$cst$2133$inset$$,$value_subfield$jscomp$9$$);$inset_token_inset_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($inset_token_inset_token__$1$$);var $color_token_color_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$192$$,
$index$jscomp$557$$,$APP.$cljs$cst$1298$color$$,$value_subfield$jscomp$9$$);$color_token_color_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($color_token_color_token__$1$$);var $offset_x_token_offset_x_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$192$$,$index$jscomp$557$$,$APP.$cljs$cst$1650$offset_x$$,$value_subfield$jscomp$9$$);$offset_x_token_offset_x_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($offset_x_token_offset_x_token__$1$$);
var $offset_y_token_offset_y_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$192$$,$index$jscomp$557$$,$APP.$cljs$cst$1651$offset_y$$,$value_subfield$jscomp$9$$);$offset_y_token_offset_y_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($offset_y_token_offset_y_token__$1$$);var $blur_token_blur_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$192$$,
$index$jscomp$557$$,$APP.$cljs$cst$1653$blur$$,$value_subfield$jscomp$9$$);$blur_token_blur_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($blur_token_blur_token__$1$$);$spread_token_spread_token__$1_token$jscomp$192$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$192$$,$index$jscomp$557$$,$APP.$cljs$cst$1652$spread$$,$value_subfield$jscomp$9$$);$spread_token_spread_token__$1_token$jscomp$192$$=$APP.$app$main$ui$hooks$use_equal_memo$$($spread_token_spread_token__$1_token$jscomp$192$$);
var $on_button_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$557$$)],function($event$jscomp$625$$){return $remove_shadow_block$$.$cljs$core$IFn$_invoke$arity$2$?$remove_shadow_block$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$557$$,$event$jscomp$625$$):$remove_shadow_block$$($index$jscomp$557$$,$event$jscomp$625$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":["shadow-input-fields-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$557$$)].join(""),
className:"main_ui_workspace_tokens_management_forms_shadow__shadow-block",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__select-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$select$select_indexed_STAR_$$,{options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"drop",
$APP.$cljs$cst$2287$label$$,"drop shadow",$APP.$cljs$cst$1721$icon$$,"drop-shadow"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"inner",$APP.$cljs$cst$2287$label$$,"inner shadow",$APP.$cljs$cst$1721$icon$$,"inner-shadow"],null)],null),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-inset"),token:$inset_token_inset_token__$1$$,tokens:$props_80076_tokens$jscomp$74$$,index:$index$jscomp$557$$,indexedType:$value_subfield$jscomp$9$$,
name:$APP.$cljs$cst$2133$inset$$}),$APP.$cljs$core$truth_$$($show_button$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-remove-shadow"),onClick:$on_button_click$jscomp$1$$,icon:"remove"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__inputs-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$color_input$indexed_color_input_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-value-enter"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.color"),name:$APP.$cljs$cst$1298$color$$,token:$color_token_color_token__$1$$,valueSubfield:$value_subfield$jscomp$9$$,
index:$index$jscomp$557$$,tokens:$props_80076_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-x"),icon:"character-x",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-x"),
name:$APP.$cljs$cst$1650$offset_x$$,token:$offset_x_token_offset_x_token__$1$$,index:$index$jscomp$557$$,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80076_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-y"),
icon:"character-y",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-y"),name:$APP.$cljs$cst$1651$offset_y$$,token:$offset_y_token_offset_y_token__$1$$,index:$index$jscomp$557$$,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80076_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,
{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-blur"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-blur"),name:$APP.$cljs$cst$1653$blur$$,slotStart:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_forms_shadow__visible-label",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-blur")),
":"].join("")}),token:$blur_token_blur_token__$1$$,index:$index$jscomp$557$$,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80076_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-spread"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-spread"),
name:$APP.$cljs$cst$1652$spread$$,slotStart:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_forms_shadow__visible-label",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-spread")),":"].join("")}),token:$spread_token_spread_token__$1_token$jscomp$192$$,valueSubfield:$value_subfield$jscomp$9$$,index:$index$jscomp$557$$,tokens:$props_80076_tokens$jscomp$74$$})})]})]})};
$app$main$ui$workspace$tokens$management$forms$shadow$composite_form_STAR_$$=function($props_80077$$){var $token$jscomp$193$$=$props_80077$$.token,$remove_shadow_block$jscomp$1$$=$props_80077$$.removeShadowBlock,$value_subfield$jscomp$10$$=$props_80077$$.valueSubfield,$tokens$jscomp$75$$=$props_80077$$.tokens,$form$jscomp$207$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$length$jscomp$60$$=$APP.$cljs$core$count$$(function(){var $G__80078$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$207$$)));
return $value_subfield$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$value_subfield$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($G__80078$$):$value_subfield$jscomp$10$$($G__80078$$)}());return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$199$$,$index$jscomp$558$$){$out_arr__44124__auto__$jscomp$199$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$shadow$shadow_formset_STAR_$$,{index:$index$jscomp$558$$,token:$token$jscomp$193$$,
tokens:$tokens$jscomp$75$$,valueSubfield:$value_subfield$jscomp$10$$,removeShadowBlock:$remove_shadow_block$jscomp$1$$,showButton:$length$jscomp$60$$>1},$index$jscomp$558$$));return $out_arr__44124__auto__$jscomp$199$$},[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($length$jscomp$60$$))};
$app$main$ui$workspace$tokens$management$forms$shadow$reference_form_STAR_$$=function($props_80079_tokens$jscomp$76$$){var $token$jscomp$194$$=$props_80079_tokens$jscomp$76$$.token;$props_80079_tokens$jscomp$76$$=$props_80079_tokens$jscomp$76$$.tokens;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row-reference",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.reference-composite-shadow"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reference"),icon:"drop-shadow",name:$cljs$cst$5832$reference$$,token:$token$jscomp$194$$,tokens:$props_80079_tokens$jscomp$76$$})})};
$app$main$ui$workspace$tokens$management$forms$shadow$tabs_wrapper_STAR_$$=function($on_add_shadow_block_props_80081$$){var $tab$jscomp$9$$=void 0,$handle_toggle$jscomp$1$$=void 0,$token$jscomp$195$$=void 0,$value_subfield$jscomp$11$$=void 0,$tokens$jscomp$77$$=void 0;({token:$token$jscomp$195$$,tokens:$tokens$jscomp$77$$,tab:$tab$jscomp$9$$,handleToggle:$handle_toggle$jscomp$1$$,valueSubfield:$value_subfield$jscomp$11$$}=$on_add_shadow_block_props_80081$$);var $form$jscomp$208$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$);
$on_add_shadow_block_props_80081$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value_subfield$jscomp$11$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$208$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$11$$],null),$APP.$cljs$core$conj$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$]))});
var $remove_shadow_block$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value_subfield$jscomp$11$$)],function($index$jscomp$559$$,$event$jscomp$626$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$626$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$208$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,
$value_subfield$jscomp$11$$],null),function($p1__80080_SHARP_$$){return $APP.$app$common$data$remove_at_index$$($p1__80080_SHARP_$$,$index$jscomp$559$$)})});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__title-bar",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.shadow")}),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-add-shadow"),onClick:$on_add_shadow_block_props_80081$$,icon:"add"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_tokens_management_forms_shadow__listing-options",selected:$APP.$app$common$data$name$$($tab$jscomp$9$$),"on-change":$handle_toggle$jscomp$1$$,
name:"reference-composite-tab",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"layers",value:"composite",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.individual-tokens"),id:"composite-opt"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"tokens",value:"reference",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.use-reference"),id:"reference-opt"})]})]}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$9$$,$cljs$cst$5837$composite$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$shadow$composite_form_STAR_$$,{token:$token$jscomp$195$$,tokens:$tokens$jscomp$77$$,removeShadowBlock:$remove_shadow_block$jscomp$2$$,valueSubfield:$value_subfield$jscomp$11$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$shadow$reference_form_STAR_$$,{token:$token$jscomp$195$$,tokens:$tokens$jscomp$77$$})]})};
$app$main$ui$workspace$tokens$management$forms$shadow$make_schema$$=function($tokens_tree$jscomp$11$$,$active_tab$jscomp$2$$){return $APP.$app$common$schema$schema$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80082_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80082_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$token$schema_COLON_token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80083_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80083_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name-validation-error"))].join("")}])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80084_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.token-name-duplication-validation-error",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80084_SHARP_$$)]))}],null),function($p1__80085_SHARP_$$){return!$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$($p1__80085_SHARP_$$,$tokens_tree$jscomp$11$$)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1650$offset_x$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1651$offset_y$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-token-blur-value-error")}],
null),function($blur$jscomp$13_n$jscomp$311$$){$blur$jscomp$13_n$jscomp$311$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$13_n$jscomp$311$$);return $blur$jscomp$13_n$jscomp$311$$==null||!($blur$jscomp$13_n$jscomp$311$$<0)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1652$spread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5826$color_result$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2133$inset$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$421$boolean$$],null)],null)],null)],null)],null),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$jscomp$2$$,$cljs$cst$5832$reference$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5832$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!1],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null):new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5832$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3388$error_SLASH_field$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$cljs$cst$5832$reference$$],null),$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.self-reference")}],null),function($name$jscomp$487_p__80094$$){var $map__80095__$1_reference$jscomp$1_value$jscomp$976$$=
$APP.$cljs$core$__destructure_map$$($name$jscomp$487_p__80094$$);$name$jscomp$487_p__80094$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80095__$1_reference$jscomp$1_value$jscomp$976$$,$APP.$cljs$cst$725$name$$);$map__80095__$1_reference$jscomp$1_value$jscomp$976$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80095__$1_reference$jscomp$1_value$jscomp$976$$,$APP.$cljs$cst$260$value$$);$map__80095__$1_reference$jscomp$1_value$jscomp$976$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80095__$1_reference$jscomp$1_value$jscomp$976$$,
$cljs$cst$5832$reference$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__80095__$1_reference$jscomp$1_value$jscomp$976$$)?$name$jscomp$487_p__80094$$:$map__80095__$1_reference$jscomp$1_value$jscomp$976$$)?!$APP.$app$common$types$token$token_value_self_reference_QMARK_$$($name$jscomp$487_p__80094$$,$map__80095__$1_reference$jscomp$1_value$jscomp$976$$):!0}],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return"Must be a valid shadow or reference"},$APP.$cljs$cst$3388$error_SLASH_field$$,$APP.$cljs$cst$260$value$$],null),function($map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$){$map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$);var $shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$,$APP.$cljs$cst$260$value$$);$map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$,$cljs$cst$5832$reference$$);$map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$=$APP.$cljs$core$truth_$$($map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$)?
!$APP.$cuerdas$core$blank_QMARK_$$($map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$):$map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$;$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$,$APP.$cljs$cst$1654$shadow$$);$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$=$APP.$cljs$core$seq$$($shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$)&&
$APP.$cljs$core$every_QMARK_$$(function($offset_x$jscomp$12_p__80099$$){var $color$jscomp$185_map__80100__$1$$=$APP.$cljs$core$__destructure_map$$($offset_x$jscomp$12_p__80099$$);$offset_x$jscomp$12_p__80099$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$185_map__80100__$1$$,$APP.$cljs$cst$1650$offset_x$$);var $offset_y$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$185_map__80100__$1$$,$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$185_map__80100__$1$$,
$APP.$cljs$cst$1653$blur$$),$spread$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$185_map__80100__$1$$,$APP.$cljs$cst$1652$spread$$);$color$jscomp$185_map__80100__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$185_map__80100__$1$$,$APP.$cljs$cst$1298$color$$);return!$APP.$cuerdas$core$blank_QMARK_$$($offset_x$jscomp$12_p__80099$$)&&!$APP.$cuerdas$core$blank_QMARK_$$($offset_y$jscomp$12$$)&&!$APP.$cuerdas$core$blank_QMARK_$$($blur$jscomp$14$$)&&
!$APP.$cuerdas$core$blank_QMARK_$$($spread$jscomp$8$$)&&!$APP.$cuerdas$core$blank_QMARK_$$($color$jscomp$185_map__80100__$1$$)},$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$);return $APP.$cljs$core$truth_$$($map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$)?$map__80097__$1_p__80096_ref_valid_QMARK__reference$jscomp$2$$:$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$977$$}],null)],null))};
$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$=function($value$jscomp$978$$){return typeof $value$jscomp$978$$==="string"?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5832$reference$$,$value$jscomp$978$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null):$APP.$cljs$core$vector_QMARK_$$($value$jscomp$978$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5832$reference$$,null,$APP.$cljs$cst$1654$shadow$$,$value$jscomp$978$$],
null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5832$reference$$,null,$APP.$cljs$cst$1654$shadow$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$],null)],null)};
$app$main$ui$workspace$tokens$management$forms$shadow$form_STAR_$$=function($props_80101$$){var $token$jscomp$196$$=$props_80101$$.token,$token_type$jscomp$25$$=$props_80101$$.tokenType,$token__$1$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$196$$)],function(){if($APP.$cljs$core$truth_$$($token$jscomp$196$$))return $token$jscomp$196$$;var $temp__5823__auto__$jscomp$247$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$196$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$247$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$25$$,$APP.$cljs$cst$260$value$$,$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$($temp__5823__auto__$jscomp$247$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$25$$,$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5832$reference$$,null,$APP.$cljs$cst$1654$shadow$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$],null)],null)],null)}),$initial$jscomp$39$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$6$$)],function(){var $raw_value$jscomp$4_value$jscomp$980$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$6$$);
$raw_value$jscomp$4_value$jscomp$980$$=$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$($raw_value$jscomp$4_value$jscomp$980$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$6$$,""),$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$6$$,""),$APP.$cljs$cst$260$value$$,$raw_value$jscomp$4_value$jscomp$980$$],
null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,{...$props_80101$$,token:$token__$1$jscomp$6$$,tokenType:$token_type$jscomp$25$$,initial:$initial$jscomp$39$$,makeSchema:$app$main$ui$workspace$tokens$management$forms$shadow$make_schema$$,valueType:$cljs$cst$5838$indexed$$,valueSubfield:$APP.$cljs$cst$1654$shadow$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$shadow$tabs_wrapper_STAR_$$,validator:$app$main$ui$workspace$tokens$management$forms$shadow$validate_shadow_token$$})};
$app$main$ui$workspace$tokens$management$forms$typography$check_typography_token_self_reference$$=function($token$jscomp$197_token_values$$){var $token_name$jscomp$50$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$197_token_values$$);$token$jscomp$197_token_values$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$197_token_values$$);return $APP.$cljs$core$some$$(function($p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$){var $k$jscomp$699$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$,0,null);$p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$,1,null);a:switch($k$jscomp$699$$ instanceof $APP.$cljs$core$Keyword$$?$k$jscomp$699$$.$fqn$:null){case "font-family":$p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$=$app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$($token_name$jscomp$50$$,
$p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$);break a;default:$p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$=$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$($token_name$jscomp$50$$,$p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$)}return $APP.$cljs$core$truth_$$($p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__80086_temp__5825__auto__$jscomp$406_v$jscomp$680$$,$APP.$cljs$cst$4621$typography_key$$,
$k$jscomp$699$$):null},$token$jscomp$197_token_values$$)};$app$main$ui$workspace$tokens$management$forms$typography$check_empty_typography_token$$=function($token$jscomp$198$$){return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$198$$))?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$):null};
$app$main$ui$workspace$tokens$management$forms$typography$validate_typography_token$$=function($map__80093__$1_p__80092$$){$map__80093__$1_p__80092$$=$APP.$cljs$core$__destructure_map$$($map__80093__$1_p__80092$$);var $token_value$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80093__$1_p__80092$$,$cljs$cst$5834$token_value$$);return $token_value$jscomp$14$$==null?(0,$APP.$beicon$v2$core$of$$)(null):typeof $token_value$jscomp$14$$==="string"?$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($map__80093__$1_p__80092$$):
$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__80093__$1_p__80092$$,$cljs$cst$5834$token_value$$,function($v$jscomp$681$$){return $APP.$app$common$data$update_when$$($APP.$cljs$core$truth_$$($v$jscomp$681$$)?$v$jscomp$681$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1758$font_family$$,function($p1__80091_SHARP_$$){return typeof $p1__80091_SHARP_$$===
"string"?$APP.$app$common$types$token$split_font_family$$($p1__80091_SHARP_$$):$p1__80091_SHARP_$$})}),$APP.$cljs$cst$5072$validators$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$typography$check_empty_typography_token$$,$app$main$ui$workspace$tokens$management$forms$typography$check_typography_token_self_reference$$],null)))};
$app$main$ui$workspace$tokens$management$forms$typography$composite_form_STAR_$$=function($props_80098_tokens$jscomp$78$$){var $token$jscomp$199$$=$props_80098_tokens$jscomp$78$$.token;$props_80098_tokens$jscomp$78$$=$props_80098_tokens$jscomp$78$$.tokens;var $letter_spacing_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],function(){var $temp__5823__auto__$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$248$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$260$value$$,$app$common$types$token$join_font_family$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$248$$,$APP.$cljs$cst$1766$letter_spacing$$))],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1766$letter_spacing$$],
null)}),$font_family_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],function(){var $temp__5823__auto__$jscomp$249$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$249$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$249$$,
$APP.$cljs$cst$1758$font_family$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1758$font_family$$],null)}),$font_size_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],function(){var $temp__5823__auto__$jscomp$250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$250$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$250$$,$APP.$cljs$cst$1760$font_size$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1760$font_size$$],null)}),$font_weight_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],
function(){var $temp__5823__auto__$jscomp$251$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$251$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$251$$,$APP.$cljs$cst$1761$font_weight$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1761$font_weight$$],null)}),$line_height_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],function(){var $temp__5823__auto__$jscomp$252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$252$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1980$dimensions$$,
$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$252$$,$APP.$cljs$cst$1765$line_height$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1980$dimensions$$],null)}),$text_case_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],function(){var $temp__5823__auto__$jscomp$253$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$253$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1979$text_case$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$253$$,$APP.$cljs$cst$1979$text_case$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1979$text_case$$],null)}),$text_decoration_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$199$$)],
function(){var $temp__5823__auto__$jscomp$254$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$254$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1768$text_decoration$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$254$$,$APP.$cljs$cst$1768$text_decoration$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1768$text_decoration$$],null)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$composite_fonts_combobox_STAR_$$,{icon:"text-font-family",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-value-enter"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-value"),name:$APP.$cljs$cst$1758$font_family$$,token:$font_family_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Font Size",icon:"text-font-size",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-size-value-enter"),name:$APP.$cljs$cst$1760$font_size$$,token:$font_size_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Font Weight",icon:"text-font-weight",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-weight-value-enter"),name:$APP.$cljs$cst$1761$font_weight$$,token:$font_weight_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Line Height",icon:"text-lineheight",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.line-height-value-enter"),name:$APP.$cljs$cst$1765$line_height$$,token:$line_height_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Letter Spacing",icon:"text-letterspacing",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.letter-spacing-value-enter-composite"),name:$APP.$cljs$cst$1766$letter_spacing$$,token:$letter_spacing_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Text Case",
icon:"text-mixed",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-case-value-enter"),name:$APP.$cljs$cst$1979$text_case$$,token:$text_case_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Text Decoration",icon:"text-underlined",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-decoration-value-enter"),name:$APP.$cljs$cst$1768$text_decoration$$,token:$text_decoration_sub_token$$,tokens:$props_80098_tokens$jscomp$78$$})})]})};
$app$main$ui$workspace$tokens$management$forms$typography$reference_form_STAR_$$=function($props_80102_tokens$jscomp$79$$){var $token$jscomp$200$$=$props_80102_tokens$jscomp$79$$.token;$props_80102_tokens$jscomp$79$$=$props_80102_tokens$jscomp$79$$.tokens;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.reference-composite"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reference"),icon:"text-typography",name:$cljs$cst$5832$reference$$,token:$token$jscomp$200$$,tokens:$props_80102_tokens$jscomp$79$$})})};
$app$main$ui$workspace$tokens$management$forms$typography$tabs_wrapper_STAR_$$=function($props_80103$$){var $tab$jscomp$10$$=void 0,$handle_toggle$jscomp$2$$=void 0,$token$jscomp$201$$=void 0,$tokens$jscomp$80$$=void 0;({token:$token$jscomp$201$$,tokens:$tokens$jscomp$80$$,tab:$tab$jscomp$10$$,handleToggle:$handle_toggle$jscomp$2$$}=$props_80103$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__title-bar",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.typography")}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_tokens_management_forms_typography__listing-options",selected:$APP.$app$common$data$name$$($tab$jscomp$10$$),"on-change":$handle_toggle$jscomp$2$$,name:"reference-composite-tab",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{icon:"layers",value:"composite",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.individual-tokens"),id:"composite-opt"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"tokens",value:"reference",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.use-reference"),id:"reference-opt"})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__inputs-wrapper",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$10$$,$cljs$cst$5837$composite$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$typography$composite_form_STAR_$$,{token:$token$jscomp$201$$,tokens:$tokens$jscomp$80$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$typography$reference_form_STAR_$$,{token:$token$jscomp$201$$,tokens:$tokens$jscomp$80$$})})]})};
$app$main$ui$workspace$tokens$management$forms$typography$make_schema$$=function($tokens_tree$jscomp$12$$,$active_tab$jscomp$3$$){return $APP.$app$common$schema$schema$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80104_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80104_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$token$schema_COLON_token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80105_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80105_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name-validation-error"))].join("")}])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80106_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.token-name-duplication-validation-error",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80106_SHARP_$$)]))}],null),function($p1__80107_SHARP_$$){return!$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$($p1__80107_SHARP_$$,$tokens_tree$jscomp$12$$)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1765$line_height$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1766$letter_spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1979$text_case$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$jscomp$3$$,$cljs$cst$5832$reference$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5832$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!1],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5832$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],
null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3388$error_SLASH_field$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$cljs$cst$5832$reference$$],null),$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.self-reference")}],
null),function($name$jscomp$488_p__80108$$){var $map__80109__$1_reference$jscomp$3_value$jscomp$988$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$488_p__80108$$);$name$jscomp$488_p__80108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80109__$1_reference$jscomp$3_value$jscomp$988$$,$APP.$cljs$cst$725$name$$);$map__80109__$1_reference$jscomp$3_value$jscomp$988$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80109__$1_reference$jscomp$3_value$jscomp$988$$,$APP.$cljs$cst$260$value$$);
$map__80109__$1_reference$jscomp$3_value$jscomp$988$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80109__$1_reference$jscomp$3_value$jscomp$988$$,$cljs$cst$5832$reference$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__80109__$1_reference$jscomp$3_value$jscomp$988$$)?$name$jscomp$488_p__80108$$:$map__80109__$1_reference$jscomp$3_value$jscomp$988$$)?!$APP.$app$common$types$token$token_value_self_reference_QMARK_$$($name$jscomp$488_p__80108$$,$map__80109__$1_reference$jscomp$3_value$jscomp$988$$):
!0}],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3388$error_SLASH_field$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1765$line_height$$],null),$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.composite-line-height-needs-font-size")}],
null),function($line_heigh_map__80111__$1_p__80110$$){$line_heigh_map__80111__$1_p__80110$$=$APP.$cljs$core$__destructure_map$$($line_heigh_map__80111__$1_p__80110$$);var $font_size$jscomp$15_value$jscomp$989$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_heigh_map__80111__$1_p__80110$$,$APP.$cljs$cst$260$value$$);$line_heigh_map__80111__$1_p__80110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_size$jscomp$15_value$jscomp$989$$,$APP.$cljs$cst$1765$line_height$$);$font_size$jscomp$15_value$jscomp$989$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_size$jscomp$15_value$jscomp$989$$,$APP.$cljs$cst$1760$font_size$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($line_heigh_map__80111__$1_p__80110$$)?$APP.$cljs$core$not$$($font_size$jscomp$15_value$jscomp$989$$):$line_heigh_map__80111__$1_p__80110$$)?!1:!0}],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return"At least one composite field must be set"},$APP.$cljs$cst$3388$error_SLASH_field$$,$APP.$cljs$cst$260$value$$],null),function($attrs$jscomp$184$$){return $APP.$cljs$core$reduce_kv$$(function($_$jscomp$3070$$,$___$1$jscomp$2083$$,$v$jscomp$682$$){return $APP.$cuerdas$core$empty_QMARK_$$($v$jscomp$682$$)?!1:$APP.$cljs$core$reduced$$(!0)},!1,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$184$$,$APP.$cljs$cst$260$value$$))}],
null)],null))};
$app$main$ui$workspace$tokens$management$forms$typography$form_STAR_$$=function($props_80112$$){var $token$jscomp$202$$=$props_80112$$.token,$initial$jscomp$40$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$202$$)],function(){var $JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$202$$);typeof $JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$===
"string"?$JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5832$reference$$,$JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$],null):$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$)?($JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$,$APP.$cljs$cst$1758$font_family$$,$app$common$types$token$join_font_family$$):$JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$,
$JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$=$APP.$cljs$core$select_keys$$($JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1765$line_height$$,
$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1979$text_case$$,$APP.$cljs$cst$1768$text_decoration$$],null))):$JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$202$$,""),$APP.$cljs$cst$260$value$$,$JSCompiler_temp$jscomp$11037_JSCompiler_temp$jscomp$11038_processed_value_value$jscomp$990_value__$1$jscomp$inline_13696$$,
$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$202$$,"")],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,{...$props_80112$$,initial:$initial$jscomp$40$$,makeSchema:$app$main$ui$workspace$tokens$management$forms$typography$make_schema$$,token:$token$jscomp$202$$,validator:$app$main$ui$workspace$tokens$management$forms$typography$validate_typography_token$$,valueType:$cljs$cst$5837$composite$$,
inputComponent:$app$main$ui$workspace$tokens$management$forms$typography$tabs_wrapper_STAR_$$})};
$app$main$ui$workspace$tokens$management$forms$form_container$form_container_STAR_$$=function($props_80115_token_type__$1$$){var $token$jscomp$203$$=void 0,$initial_errors$jscomp$3_props__$1$jscomp$102$$=void 0,$token_type$jscomp$26$$=void 0,$props$jscomp$387_text_case_props$$=void 0;({token:$token$jscomp$203$$,tokenType:$token_type$jscomp$26$$,initialErrors:$initial_errors$jscomp$3_props__$1$jscomp$102$$,...$props$jscomp$387_text_case_props$$}=$props_80115_token_type__$1$$);$props_80115_token_type__$1$$=
function(){var $or__5025__auto__$jscomp$1285$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$203$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1285$$)?$or__5025__auto__$jscomp$1285$$:$token_type$jscomp$26$$}();var $tokens_in_selected_set$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_in_selected_set$$),$token_path$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$203$$)],
function(){return $APP.$app$common$types$tokens_lib$get_token_path$$($token$jscomp$203$$)}),$text_decoration_props_tokens_tree_in_selected_set$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_path$jscomp$2$$),$APP.$rumext$v2$adapt$$($tokens_in_selected_set$jscomp$1$$)],function(){return $APP.$app$common$data$dissoc_in$$($APP.$app$common$types$tokens_lib$tokens_tree$$($tokens_in_selected_set$jscomp$1$$),$token_path$jscomp$2$$)});$initial_errors$jscomp$3_props__$1$jscomp$102$$=
{...$props$jscomp$387_text_case_props$$,tokenType:$props_80115_token_type__$1$$,tokensTreeInSelectedSet:$text_decoration_props_tokens_tree_in_selected_set$jscomp$1$$,token:$token$jscomp$203$$,initialErrors:$initial_errors$jscomp$3_props__$1$jscomp$102$$};$props$jscomp$387_text_case_props$$={...$initial_errors$jscomp$3_props__$1$jscomp$102$$,inputValuePlaceholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-case-value-enter")};$text_decoration_props_tokens_tree_in_selected_set$jscomp$1$$=
{...$initial_errors$jscomp$3_props__$1$jscomp$102$$,inputValuePlaceholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-decoration-value-enter")};var $font_weight_props$$={...$initial_errors$jscomp$3_props__$1$jscomp$102$$,inputValuePlaceholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-weight-value-enter")},$border_radius_props$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1239$token_combobox$$)?
{...$initial_errors$jscomp$3_props__$1$jscomp$102$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$controls$combobox$value_combobox_STAR_$$}:$initial_errors$jscomp$3_props__$1$jscomp$102$$;switch($props_80115_token_type__$1$$ instanceof $APP.$cljs$core$Keyword$$?$props_80115_token_type__$1$$.$fqn$:null){case "color":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$color$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$102$$);case "typography":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$typography$form_STAR_$$,
$initial_errors$jscomp$3_props__$1$jscomp$102$$);case "shadow":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$shadow$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$102$$);case "font-family":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$font_family$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$102$$);case "text-case":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,
$props$jscomp$387_text_case_props$$);case "text-decoration":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$text_decoration_props_tokens_tree_in_selected_set$jscomp$1$$);case "font-weight":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$font_weight_props$$);case "border-radius":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,
$border_radius_props$$);default:return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$102$$)}};
$app$main$ui$workspace$tokens$management$forms$modals$calculate_position$$=function($map__80119__$1_max_y$jscomp$3_p__80118$$,$position$jscomp$202$$,$x$jscomp$1258$$,$y$jscomp$480$$,$token_type$jscomp$27$$){$map__80119__$1_max_y$jscomp$3_p__80118$$=$APP.$cljs$core$__destructure_map$$($map__80119__$1_max_y$jscomp$3_p__80118$$);var $vh$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80119__$1_max_y$jscomp$3_p__80118$$,$APP.$cljs$cst$1522$height$$),$modal_height$jscomp$1$$=function(){switch($token_type$jscomp$27$$ instanceof
$APP.$cljs$core$Keyword$$?$token_type$jscomp$27$$.$fqn$:null){case "color":return 500;case "typography":return 660;case "shadow":return 660;default:return 400}}();$map__80119__$1_max_y$jscomp$3_p__80118$$=$vh$jscomp$5$$-$modal_height$jscomp$1$$;var $overflow_fix$$=function(){var $y__5111__auto__$jscomp$144$$=$y$jscomp$480$$+-50+$modal_height$jscomp$1$$+-$vh$jscomp$5$$;return 0>$y__5111__auto__$jscomp$144$$?0:$y__5111__auto__$jscomp$144$$}(),$max_height_top$jscomp$1$$=["calc(100vh - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(""+
($y$jscomp$480$$-70)+"px")].join(""),$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$);$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$=$APP.$cljs$core$truth_$$($left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$)?80:58;var $left_position$$=""+($x$jscomp$1258$$-325)+"px";return $x$jscomp$1258$$==null||$y$jscomp$480$$==null?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,"auto",$APP.$cljs$cst$258$right$$,"16rem",$APP.$cljs$cst$1562$top$$,
"4rem"],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$202$$,$APP.$cljs$cst$257$left$$)?$y$jscomp$480$$>$map__80119__$1_max_y$jscomp$3_p__80118$$?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,$left_position$$,$APP.$cljs$cst$1563$bottom$$,"1rem",$APP.$cljs$cst$5839$maxHeight$$,"calc(100vh -1rem"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,$left_position$$,$APP.$cljs$cst$5839$maxHeight$$,$max_height_top$jscomp$1$$,
$APP.$cljs$cst$1562$top$$,""+($y$jscomp$480$$-50-$overflow_fix$$)+"px"],null):$y$jscomp$480$$>$map__80119__$1_max_y$jscomp$3_p__80118$$?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,""+($x$jscomp$1258$$+$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$??"")+"px",$APP.$cljs$cst$1563$bottom$$,"1rem",$APP.$cljs$cst$5839$maxHeight$$,"calc(100vh -1rem"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,""+($x$jscomp$1258$$+$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$??
"")+"px",$APP.$cljs$cst$1562$top$$,""+($y$jscomp$480$$-70-$overflow_fix$$)+"px",$APP.$cljs$cst$5839$maxHeight$$,$max_height_top$jscomp$1$$],null)};
$app$main$ui$workspace$tokens$management$forms$modals$use_viewport_position_style$$=function($x$jscomp$1259$$,$y$jscomp$481$$,$position$jscomp$203$$,$token_type$jscomp$28$$){var $vport$jscomp$10$$=$APP.$rumext$v2$deref$$($APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2203$vport$$,$APP.$app$main$refs$workspace_local$$));return $APP.$cljs$core$clj__GT_js$$($app$main$ui$workspace$tokens$management$forms$modals$calculate_position$$($vport$jscomp$10$$,$position$jscomp$203$$,
$x$jscomp$1259$$,$y$jscomp$481$$,$token_type$jscomp$28$$))};
$app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$=function($props_80124_wrapper_style$$){var $selected_token_set_id$jscomp$10$$=$props_80124_wrapper_style$$["selected-token-set-id"],$token$jscomp$204$$=$props_80124_wrapper_style$$.token,$initial_errors$jscomp$4$$=$props_80124_wrapper_style$$["initial-errors"],$token_type$jscomp$29$$=$props_80124_wrapper_style$$["token-type"],$action$jscomp$8$$=$props_80124_wrapper_style$$.action;$props_80124_wrapper_style$$=$app$main$ui$workspace$tokens$management$forms$modals$use_viewport_position_style$$($props_80124_wrapper_style$$.x,
$props_80124_wrapper_style$$.y,$props_80124_wrapper_style$$.position,$token_type$jscomp$29$$);var $modal_size_large_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_type$jscomp$29$$,$APP.$cljs$cst$1981$typography$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_type$jscomp$29$$,$APP.$cljs$cst$1298$color$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_type$jscomp$29$$,$APP.$cljs$cst$1654$shadow$$)),
$modal_size_large_QMARK_$$=$APP.$cljs$core$_deref$$($modal_size_large_STAR_$$),$close_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),$update_modal_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($visible$jscomp$3$$){return $APP.$cljs$core$reset_BANG_$$($modal_size_large_STAR_$$,$visible$jscomp$3$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:$props_80124_wrapper_style$$,"data-testid":"token-update-create-modal",
className:"main_ui_workspace_tokens_management_forms_modals__token-modal-wrapper "+($APP.$cljs$core$truth_$$($modal_size_large_QMARK_$$)?"main_ui_workspace_tokens_management_forms_modals__token-modal-large":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$close_modal$$,className:"main_ui_workspace_tokens_management_forms_modals__close-btn",icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$form_container$form_container_STAR_$$,{isCreate:!$APP.$app$common$types$tokens_lib$token_QMARK_$$($token$jscomp$204$$),token:$token$jscomp$204$$,action:$action$jscomp$8$$,selectedTokenSetId:$selected_token_set_id$jscomp$10$$,tokenType:$token_type$jscomp$29$$,initialErrors:$initial_errors$jscomp$4$$,onDisplayColorpicker:$update_modal_size$$})]})};
$app$main$ui$workspace$tokens$management$forms$modals$boolean_modal$$=function($properties$jscomp$109_props_80125$$){$properties$jscomp$109_props_80125$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$109_props_80125$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$109_props_80125$$))};
$app$main$ui$workspace$tokens$management$forms$modals$border_radius_modal$$=function($properties$jscomp$110_props_80126$$){$properties$jscomp$110_props_80126$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$110_props_80126$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$110_props_80126$$))};
$app$main$ui$workspace$tokens$management$forms$modals$color_modal$$=function($properties$jscomp$111_props_80127$$){$properties$jscomp$111_props_80127$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$111_props_80127$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$111_props_80127$$))};
$app$main$ui$workspace$tokens$management$forms$modals$stroke_width_modal$$=function($properties$jscomp$112_props_80128$$){$properties$jscomp$112_props_80128$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$112_props_80128$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$112_props_80128$$))};
$app$main$ui$workspace$tokens$management$forms$modals$box_shadow_modal$$=function($properties$jscomp$113_props_80129$$){$properties$jscomp$113_props_80129$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$113_props_80129$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$113_props_80129$$))};
$app$main$ui$workspace$tokens$management$forms$modals$sizing_modal$$=function($properties$jscomp$114_props_80130$$){$properties$jscomp$114_props_80130$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$114_props_80130$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$114_props_80130$$))};
$app$main$ui$workspace$tokens$management$forms$modals$dimensions_modal$$=function($properties$jscomp$115_props_80131$$){$properties$jscomp$115_props_80131$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$115_props_80131$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$115_props_80131$$))};
$app$main$ui$workspace$tokens$management$forms$modals$number_modal$$=function($properties$jscomp$116_props_80132$$){$properties$jscomp$116_props_80132$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$116_props_80132$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$116_props_80132$$))};
$app$main$ui$workspace$tokens$management$forms$modals$opacity_modal$$=function($properties$jscomp$117_props_80133$$){$properties$jscomp$117_props_80133$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$117_props_80133$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$117_props_80133$$))};
$app$main$ui$workspace$tokens$management$forms$modals$other_modal$$=function($properties$jscomp$118_props_80134$$){$properties$jscomp$118_props_80134$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$118_props_80134$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$118_props_80134$$))};
$app$main$ui$workspace$tokens$management$forms$modals$rotation_modal$$=function($properties$jscomp$119_props_80135$$){$properties$jscomp$119_props_80135$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$119_props_80135$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$119_props_80135$$))};
$app$main$ui$workspace$tokens$management$forms$modals$spacing_modal$$=function($properties$jscomp$120_props_80141$$){$properties$jscomp$120_props_80141$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$120_props_80141$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$120_props_80141$$))};
$app$main$ui$workspace$tokens$management$forms$modals$string_modal$$=function($properties$jscomp$121_props_80142$$){$properties$jscomp$121_props_80142$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$121_props_80142$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$121_props_80142$$))};
$app$main$ui$workspace$tokens$management$forms$modals$typography_modal$$=function($properties$jscomp$122_props_80143$$){$properties$jscomp$122_props_80143$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$122_props_80143$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$122_props_80143$$))};
$app$main$ui$workspace$tokens$management$forms$modals$font_size_modal$$=function($properties$jscomp$123_props_80144$$){$properties$jscomp$123_props_80144$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$123_props_80144$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$123_props_80144$$))};
$app$main$ui$workspace$tokens$management$forms$modals$letter_spacing_modal$$=function($properties$jscomp$124_props_80145$$){$properties$jscomp$124_props_80145$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$124_props_80145$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$124_props_80145$$))};
$app$main$ui$workspace$tokens$management$forms$modals$font_familiy_modal$$=function($properties$jscomp$125_props_80146$$){$properties$jscomp$125_props_80146$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$125_props_80146$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$125_props_80146$$))};
$app$main$ui$workspace$tokens$management$forms$modals$text_case_modal$$=function($properties$jscomp$126_props_80147$$){$properties$jscomp$126_props_80147$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$126_props_80147$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$126_props_80147$$))};
$app$main$ui$workspace$tokens$management$forms$modals$text_decoration_modal$$=function($properties$jscomp$127_props_80148$$){$properties$jscomp$127_props_80148$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$127_props_80148$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$127_props_80148$$))};
$app$main$ui$workspace$tokens$management$forms$modals$font_weight_modal$$=function($properties$jscomp$128_props_80149$$){$properties$jscomp$128_props_80149$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$128_props_80149$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$128_props_80149$$))};
$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_form_STAR_$$=function($on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$){var $variant$jscomp$27$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.variant,$on_close$jscomp$40$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.onClose,$new_node_name$jscomp$7$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.newNodeName,$node$jscomp$459$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.node,
$active_tokens$jscomp$13$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.activeTokens,$tokens_tree$jscomp$13$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.tokensTree,$on_submit$jscomp$19$$=$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$.onSubmit;$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$13$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$app$common$files$tokens$make_node_token_name_schema$$($active_tokens$jscomp$13$$,$tokens_tree$jscomp$13$$,$node$jscomp$459$$)],null)],null)});var $initial$jscomp$41_is_disabled_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($node$jscomp$459$$),$APP.$rumext$v2$adapt$$($new_node_name$jscomp$7$$)],
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($new_node_name$jscomp$7$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$459$$))],null)}),$form$jscomp$209$$=$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$298$schema$$,$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$,
$APP.$cljs$cst$5076$initial$$,$initial$jscomp$41_is_disabled_QMARK_$$]));$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$209$$),$APP.$rumext$v2$adapt$$($on_submit$jscomp$19$$)],function(){var $name$jscomp$489$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$725$name$$],null));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$489$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$459$$))?$on_submit$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$on_submit$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$489$$):$on_submit$jscomp$19$$($name$jscomp$489$$):null});$initial$jscomp$41_is_disabled_QMARK_$$=$APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$209$$)))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$725$name$$],null)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$459$$));var $hint_path$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($form$jscomp$209$$)),
$APP.$rumext$v2$adapt$$($node$jscomp$459$$)],function(){var $new_name$jscomp$39_new_path$jscomp$7$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$725$name$$],null)),$path$jscomp$296$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$459$$));
$new_name$jscomp$39_new_path$jscomp$7$$=$APP.$cuerdas$core$replace$$($path$jscomp$296$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$459$$),$new_name$jscomp$39_new_path$jscomp$7$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$725$name$$],null)))?
$new_name$jscomp$39_new_path$jscomp$7$$:$path$jscomp$296$$});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$forms$form_STAR_$$,{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__form-wrapper",form:$form$jscomp$209$$,onSubmit:$on_submit__$1$jscomp$1_props_80121_schema$jscomp$246$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_management_forms_rename_node_modal__form-modal-title",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$27$$,"rename")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.rename-group"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.duplicate-group")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name"),
hintType:"hint",hintMessage:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$27$$,"rename")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.rename-group-name-hint",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$hint_path$$])):null,id:"rename-node",maxLength:255,name:$APP.$cljs$cst$725$name$$,variant:"comfortable",autoFocus:!0}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__form-actions",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",name:"cancel",onClick:$on_close$jscomp$40$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_submit_STAR_$$,{variant:"primary",disabled:$initial$jscomp$41_is_disabled_QMARK_$$,name:"rename",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$27$$,"rename")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.duplicate")})]})]})};
$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_modal$$=function($map__80123_new_node_name$jscomp$8_props_80122$$){$map__80123_new_node_name$jscomp$8_props_80122$$=$APP.$rumext$v2$util$wrap_props$$($map__80123_new_node_name$jscomp$8_props_80122$$);var $map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($map__80123_new_node_name$jscomp$8_props_80122$$);$map__80123_new_node_name$jscomp$8_props_80122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,
$cljs$cst$5812$new_node_name$$);var $node$jscomp$460$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,$APP.$cljs$cst$3766$node$$),$tokens_in_active_set$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,$cljs$cst$5811$tokens_in_active_set$$),$on_rename$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,
$cljs$cst$5809$on_rename$$);$map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,$APP.$cljs$cst$1994$variant$$);$map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,"rename");var $tokens_tree_in_selected_set$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_in_active_set$$),
$APP.$rumext$v2$adapt$$($node$jscomp$460$$)],function(){return $APP.$app$common$data$dissoc_in$$($APP.$app$common$types$tokens_lib$tokens_tree$$($tokens_in_active_set$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$460$$))}),$close_modal$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$rename$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_rename$jscomp$4$$)],
function($new_name$jscomp$40$$){return $on_rename$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_rename$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($new_name$jscomp$40$$):$on_rename$jscomp$4$$($new_name$jscomp$40$$)}),$on_key_down$jscomp$24$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$close_modal$jscomp$1$$],null))],function($event$jscomp$627$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$627$$))?
$close_modal$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$close_modal$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$close_modal$jscomp$1$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{onKeyDown:$on_key_down$jscomp$24$$,"data-testid":"token-rename-node-modal",className:"main_ui_workspace_tokens_management_forms_rename_node_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__close-btn",onClick:$close_modal$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_form_STAR_$$,{newNodeName:$map__80123_new_node_name$jscomp$8_props_80122$$,node:$node$jscomp$460$$,variant:$map__80123__$1_variant$jscomp$28_variant__$1$jscomp$8$$,activeTokens:$tokens_in_active_set$$,
tokensTree:$tokens_tree_in_selected_set$jscomp$2$$,onClose:$close_modal$jscomp$1$$,onSubmit:$rename$jscomp$4$$})]})})};
$app$main$ui$workspace$tokens$remapping_modal$token_remapping_modal$$=function($map__80140_props_80136_remap_data$jscomp$2$$){$map__80140_props_80136_remap_data$jscomp$2$$=$APP.$rumext$v2$util$wrap_props$$($map__80140_props_80136_remap_data$jscomp$2$$);var $map__80140__$1_old_name$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__80140_props_80136_remap_data$jscomp$2$$);$map__80140_props_80136_remap_data$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80140__$1_old_name$jscomp$4$$,
$cljs$cst$5807$remap_data$$);var $on_remap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80140__$1_old_name$jscomp$4$$,$cljs$cst$5808$on_remap$$),$on_rename$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80140__$1_old_name$jscomp$4$$,$cljs$cst$5809$on_rename$$);$map__80140__$1_old_name$jscomp$4$$=$cljs$cst$5773$old_name$$.$cljs$core$IFn$_invoke$arity$1$($map__80140_props_80136_remap_data$jscomp$2$$);var $new_name$jscomp$41$$=$cljs$cst$5774$new_name$$.$cljs$core$IFn$_invoke$arity$1$($map__80140_props_80136_remap_data$jscomp$2$$),
$confirm_remap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_remap$jscomp$1$$),$APP.$rumext$v2$adapt$$($map__80140__$1_old_name$jscomp$4$$),$APP.$rumext$v2$adapt$$($new_name$jscomp$41$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_remap$jscomp$1$$)?$on_remap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_remap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_remap$jscomp$1$$():null}),$rename_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_rename$jscomp$5$$)],
function(){return $APP.$cljs$core$fn_QMARK_$$($on_rename$jscomp$5$$)?$on_rename$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$on_rename$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_rename$jscomp$5$$():null}),$cancel_action$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_key_down$jscomp$25$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cancel_action$$)],
function($event$jscomp$628$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$628$$))?$cancel_action$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_action$$.$cljs$core$IFn$_invoke$arity$0$():$cancel_action$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{onKeyDown:$on_key_down$jscomp$25$$,role:"alertdialog","aria-modal":"true","aria-labelledby":"modal-title",className:"main_ui_workspace_tokens_remapping_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{"data-testid":"token-remapping-modal",className:"main_ui_workspace_tokens_remapping_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$cancel_action$$,className:"main_ui_workspace_tokens_remapping_modal__close-btn",icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__modal-header",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,id:"modal-title",typography:"headline-large",className:"main_ui_workspace_tokens_remapping_modal__modal-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__80140_props_80136_remap_data$jscomp$2$$),"token")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.remap-token-references-title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80140__$1_old_name$jscomp$4$$,$new_name$jscomp$41$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.remap-node-references-title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80140__$1_old_name$jscomp$4$$,$new_name$jscomp$41$$]))})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__modal-content",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__80140_props_80136_remap_data$jscomp$2$$),
"token")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap-token-warning-effects")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap-node-warning-effects")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap-warning-time")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__action-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$rename_token$$,type:"button",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.not-remap")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$confirm_remap$$,type:"button",variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap")})]})})]})})};
$app$main$data$workspace$tokens$typography$set_base_font_size$$=function($base_font_size$jscomp$2$$){typeof $app$main$data$workspace$tokens$typography$set_base_font_size_80137$$==="undefined"&&($app$main$data$workspace$tokens$typography$set_base_font_size_80137$$=function($base_font_size$jscomp$3$$,$meta80138$$){this.$base_font_size$=$base_font_size$jscomp$3$$;this.$meta80138$=$meta80138$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$typography$set_base_font_size_80137$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$typography$set_base_font_size_80137$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5843$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_typography_SLASH_set_base_font_size$$},$app$main$data$workspace$tokens$typography$set_base_font_size_80137$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_80139$$,$meta80138__$1$$){return new $app$main$data$workspace$tokens$typography$set_base_font_size_80137$$(this.$base_font_size$,
$meta80138__$1$$)},$app$main$data$workspace$tokens$typography$set_base_font_size_80137$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta80138$},$app$main$data$workspace$tokens$typography$set_base_font_size_80137$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$typography$set_base_font_size_80137$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file_id$jscomp$432_it$jscomp$277_new_base_font_size$jscomp$inline_9067$$,
$changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$){$file_id$jscomp$432_it$jscomp$277_new_base_font_size$jscomp$inline_9067$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$,$APP.$cljs$cst$2532$workspace$$),$APP.$cljs$cst$1917$current_file_id$$);$changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$,$APP.$cljs$cst$1916$files$$),$file_id$jscomp$432_it$jscomp$277_new_base_font_size$jscomp$inline_9067$$),$APP.$cljs$cst$142$data$$);$changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$=$APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$);$file_id$jscomp$432_it$jscomp$277_new_base_font_size$jscomp$inline_9067$$=this.$base_font_size$;var $file_data$jscomp$inline_9068_previous_font_size$jscomp$inline_9069$$=$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$));$file_data$jscomp$inline_9068_previous_font_size$jscomp$inline_9069$$=
$app$common$types$file$get_base_font_size$$($file_data$jscomp$inline_9068_previous_font_size$jscomp$inline_9069$$);$changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$,$APP.$cljs$cst$3133$redo_changes$$,
$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2659$set_base_font_size$$,$APP.$cljs$cst$2576$base_font_size$$,$file_id$jscomp$432_it$jscomp$277_new_base_font_size$jscomp$inline_9067$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2659$set_base_font_size$$,$APP.$cljs$cst$2576$base_font_size$$,$file_data$jscomp$inline_9068_previous_font_size$jscomp$inline_9069$$],
null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$332_changes$jscomp$inline_9066_file_data$jscomp$123_state$jscomp$1205$$))});return new $app$main$data$workspace$tokens$typography$set_base_font_size_80137$$($base_font_size$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$tokens$settings$menu$token_settings_STAR_$$=function(){var $file_data$jscomp$124$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_data$$),$base_font_size_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$common$types$file$get_base_font_size$$($file_data$jscomp$124$$)}),$base_font_size$jscomp$4$$=$APP.$cljs$core$_deref$$($base_font_size_STAR_$$),$valid_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),
$is_valid$$=$APP.$cljs$core$_deref$$($valid_QMARK__STAR_$$),$hint_message$jscomp$1$$=$APP.$cljs$core$truth_$$($is_valid$$)?["1rem \x3d ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base_font_size$jscomp$4$$)].join(""):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.base-font-size.error"),$on_change_base_font_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_font_size_STAR_$$)],function($e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$){$e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$=
(0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$);$APP.$cljs$core$reset_BANG_$$($valid_QMARK__STAR_$$,$APP.$cljs$core$boolean$0$$($APP.$cljs$core$re_matches$$(/^\d+(\.\d+)?(px)?$/,$e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$)));return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$re_matches$$(/^\d+(\.\d+)?(px)?$/,$e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$))?($e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$=$APP.$cuerdas$core$ends_with_QMARK_$$($e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$,
"px")?$e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$),"px"].join(""),$APP.$cljs$core$reset_BANG_$$($base_font_size_STAR_$$,$e$jscomp$367_unit_value$jscomp$1_value$jscomp$992$$)):null}),$on_set_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_font_size$jscomp$4$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$typography$set_base_font_size$$($base_font_size$jscomp$4$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}),$handle_key_down$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_font_size$jscomp$4$$),$APP.$rumext$v2$adapt$$($is_valid$$)],function($and__5023__auto__$jscomp$inline_9071_e$jscomp$368$$){$and__5023__auto__$jscomp$inline_9071_e$jscomp$368$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($and__5023__auto__$jscomp$inline_9071_e$jscomp$368$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9071_e$jscomp$368$$)?
$is_valid$$:$and__5023__auto__$jscomp$inline_9071_e$jscomp$368$$)?$on_set_font$$.$cljs$core$IFn$_invoke$arity$0$?$on_set_font$$.$cljs$core$IFn$_invoke$arity$0$():$on_set_font$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"token-font-settings-modal",className:"main_ui_workspace_tokens_settings_menu__setting-modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__setting-modal",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_tokens_settings_menu__close-btn",icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-layout",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_settings_menu__settings-modal-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.settings")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-subtitle-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-large",className:"main_ui_workspace_tokens_settings_menu__settings-subtitle",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.base-font-size")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",className:"main_ui_workspace_tokens_settings_menu__settings-modal-description",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.setting-description")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"text",
placeholder:"16",defaultValue:$base_font_size$jscomp$4$$,hintMessage:$hint_message$jscomp$1$$,hintType:$APP.$cljs$core$truth_$$($is_valid$$)?"hint":"error",onKeyDown:$handle_key_down$jscomp$10$$,onChange:$on_change_base_font_size$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-actions",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$APP.$app$main$data$modal$hide_BANG_$$,type:"button",variant:"secondary",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_set_font$$,type:"button",disabled:$APP.$cljs$core$not$$($is_valid$$),variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save")})]})]})]})]})})};
$app$main$ui$workspace$tokens$settings$token_settings_modal_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$settings$menu$token_settings_STAR_$$,{})};
$app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$=function($create_theme_map__80154_map__80154__$1_props_80153$$){$create_theme_map__80154_map__80154__$1_props_80153$$=$APP.$rumext$v2$util$wrap_props$$($create_theme_map__80154_map__80154__$1_props_80153$$);$create_theme_map__80154_map__80154__$1_props_80153$$=$APP.$cljs$core$__destructure_map$$($create_theme_map__80154_map__80154__$1_props_80153$$);var $change_view$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($create_theme_map__80154_map__80154__$1_props_80153$$,
$cljs$cst$5844$change_view$$);$create_theme_map__80154_map__80154__$1_props_80153$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_view$$)],function(){return $change_view$$.$cljs$core$IFn$_invoke$arity$1$?$change_view$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5845$create_theme$$):$change_view$$($cljs$cst$5845$create_theme$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,
{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.themes-list")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__empty-themes-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__empty-themes-message",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"title-medium",className:"main_ui_workspace_tokens_themes_create_modal__empty-theme-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-themes-currently")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",className:"main_ui_workspace_tokens_themes_create_modal__empty-theme-subtitle",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.create-new-theme")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__button-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:$create_theme_map__80154_map__80154__$1_props_80153$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-new-theme")})]})]})]})};
$app$main$ui$workspace$tokens$themes$create_modal$themes_overview$$=function($props_80155$$){var $map__80156$$=$APP.$rumext$v2$util$wrap_props$$($props_80155$$),$map__80156__$1$$=$APP.$cljs$core$__destructure_map$$($map__80156$$),$change_view$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80156__$1$$,$cljs$cst$5844$change_view$$),$active_theme_paths$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_active_theme_paths$$),$themes_groups$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_theme_tree_no_hidden$$),
$create_theme$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_view$jscomp$1$$)],function($e$jscomp$369$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$369$$);$APP.$app$util$dom$stop_propagation$$($e$jscomp$369$$);return $change_view$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$change_view$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5845$create_theme$$):$change_view$jscomp$1$$($cljs$cst$5845$create_theme$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.themes-list")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",
className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-description",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.themes-description")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_themes_create_modal__theme-group-wrapper",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$200$$,$p__80157$$){var $group$jscomp$55$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80157$$,
0,null),$themes$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80157$$,1,null);$out_arr__44124__auto__$jscomp$200$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{children:[$APP.$cljs$core$seq$$($group$jscomp$55$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:3,className:"main_ui_workspace_tokens_themes_create_modal__theme-group-label",typography:"body-large",children:(0,$APP.$rumext$v2$jsxs$$)("div",{title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.group-name")),
": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$55$$)].join(""),className:"main_ui_workspace_tokens_themes_create_modal__group-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"group",className:"main_ui_workspace_tokens_themes_create_modal__group-title-icon"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",className:"main_ui_workspace_tokens_themes_create_modal__group-title-name",
children:$group$jscomp$55$$})]})}):null,(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_themes_create_modal__theme-group-rows-wrapper",children:$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return function $app$main$ui$workspace$tokens$themes$create_modal$themes_overview_$_iter__80161$$($s__80162$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$407$$=$APP.$cljs$core$seq$$($s__80162$$);if($temp__5825__auto__$jscomp$407$$){var $s__80162__$2$$=
$temp__5825__auto__$jscomp$407$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80162__$2$$)){var $c__5501__auto__$jscomp$53$$=$APP.$cljs$core$_chunked_first$$($s__80162__$2$$),$size__5502__auto__$jscomp$53$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$53$$),$b__80164$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$53$$);return function(){for(var $i__80163$$=0;;)if($i__80163$$<$size__5502__auto__$jscomp$53$$){var $vec__80165$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$53$$,$i__80163$$),
$_$jscomp$3073$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80165$$,0,null),$map__80168$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80165$$,1,null),$map__80168__$1$$=$APP.$cljs$core$__destructure_map$$($map__80168$$),$theme$jscomp$18$$=$map__80168__$1$$,$id$jscomp$1024$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80168__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$491$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80168__$1$$,
$APP.$cljs$cst$725$name$$),$theme_path$jscomp$2$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$18$$),$selected_QMARK_$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$6$$,$theme_path$jscomp$2$$)!=null,$delete_theme$jscomp$1$$=function($i__80163$jscomp$1$$,$theme_path$jscomp$3$$,$selected_QMARK_$jscomp$16$$,$vec__80165$jscomp$1$$,$_$jscomp$3074$$,$map__80168$jscomp$1$$,$map__80168__$1$jscomp$1$$,$theme$jscomp$19$$,$id$jscomp$1025$$){return function($e$jscomp$370$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$370$$);
$APP.$app$util$dom$stop_propagation$$($e$jscomp$370$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($id$jscomp$1025$$))}}($i__80163$$,$theme_path$jscomp$2$$,$selected_QMARK_$jscomp$15$$,$vec__80165$$,$_$jscomp$3073$$,$map__80168$$,$map__80168__$1$$,$theme$jscomp$18$$,$id$jscomp$1024$$,$name$jscomp$491$$,$c__5501__auto__$jscomp$53$$,$size__5502__auto__$jscomp$53$$,$b__80164$$,$s__80162__$2$$,$temp__5825__auto__$jscomp$407$$,
$p__80157$$,$group$jscomp$55$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80156$$,$map__80156__$1$$,$change_view$jscomp$1$$),$on_switch_theme$jscomp$1$$=function($i__80163$jscomp$2$$,$theme_path$jscomp$4$$,$selected_QMARK_$jscomp$17$$,$delete_theme$jscomp$2$$,$vec__80165$jscomp$2$$,$_$jscomp$3075$$,$map__80168$jscomp$2$$,$map__80168__$1$jscomp$2$$,$theme$jscomp$20$$,$id$jscomp$1026$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1026$$))}}($i__80163$$,
$theme_path$jscomp$2$$,$selected_QMARK_$jscomp$15$$,$delete_theme$jscomp$1$$,$vec__80165$$,$_$jscomp$3073$$,$map__80168$$,$map__80168__$1$$,$theme$jscomp$18$$,$id$jscomp$1024$$,$name$jscomp$491$$,$c__5501__auto__$jscomp$53$$,$size__5502__auto__$jscomp$53$$,$b__80164$$,$s__80162__$2$$,$temp__5825__auto__$jscomp$407$$,$p__80157$$,$group$jscomp$55$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80156$$,$map__80156__$1$$,$change_view$jscomp$1$$),$on_edit_theme$jscomp$1$$=
function($i__80163$jscomp$3$$,$theme_path$jscomp$5$$,$selected_QMARK_$jscomp$18$$,$delete_theme$jscomp$3$$,$on_switch_theme$jscomp$2$$,$vec__80165$jscomp$3$$,$_$jscomp$3076$$,$map__80168$jscomp$3$$,$map__80168__$1$jscomp$3$$,$theme$jscomp$21$$,$id$jscomp$1027$$,$name$jscomp$494$$,$c__5501__auto__$jscomp$56$$,$size__5502__auto__$jscomp$56$$,$b__80164$jscomp$3$$,$s__80162__$2$jscomp$3$$,$temp__5825__auto__$jscomp$410$$,$vec__80158$jscomp$3$$,$group$jscomp$58$$,$themes$jscomp$16$$,$active_theme_paths$jscomp$9$$,
$themes_groups$jscomp$3$$,$create_theme$jscomp$4$$,$map__80156$jscomp$3$$,$map__80156__$1$jscomp$3$$,$change_view$jscomp$4$$){return function($G__80170_e$jscomp$371$$){$APP.$app$util$dom$prevent_default$$($G__80170_e$jscomp$371$$);$APP.$app$util$dom$stop_propagation$$($G__80170_e$jscomp$371$$);$G__80170_e$jscomp$371$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5847$theme_info$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$21$$),
$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$21$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$21$$)],null)],null);return $change_view$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$change_view$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5846$edit_theme$$,$G__80170_e$jscomp$371$$):$change_view$jscomp$4$$($cljs$cst$5846$edit_theme$$,$G__80170_e$jscomp$371$$)}}($i__80163$$,$theme_path$jscomp$2$$,$selected_QMARK_$jscomp$15$$,$delete_theme$jscomp$1$$,
$on_switch_theme$jscomp$1$$,$vec__80165$$,$_$jscomp$3073$$,$map__80168$$,$map__80168__$1$$,$theme$jscomp$18$$,$id$jscomp$1024$$,$name$jscomp$491$$,$c__5501__auto__$jscomp$53$$,$size__5502__auto__$jscomp$53$$,$b__80164$$,$s__80162__$2$$,$temp__5825__auto__$jscomp$407$$,$p__80157$$,$group$jscomp$55$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80156$$,$map__80156__$1$$,$change_view$jscomp$1$$);$APP.$cljs$core$chunk_append$$($b__80164$$,(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_workspace_tokens_themes_create_modal__theme-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-switch-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,{label:$name$jscomp$491$$,onChange:$on_switch_theme$jscomp$1$$,defaultChecked:$selected_QMARK_$jscomp$15$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-actions-row",children:[function(){var $G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$=
$theme$jscomp$18$$;$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$=$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$==null?null:$APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$);$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$=
$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$==null?null:$APP.$cljs$core$seq$$($G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$);$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$=$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$==null?null:$APP.$cljs$core$count$$($G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$);
return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:($APP.$cljs$core$truth_$$($G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$)?"main_ui_workspace_tokens_themes_create_modal__sets-count-button":"")+" "+($APP.$cljs$core$not$$($G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$)?"main_ui_workspace_tokens_themes_create_modal__sets-count-empty-button":""),
variant:"secondary",type:"button",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.sets-hint"),onClick:$on_edit_theme$jscomp$1$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__label-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",children:$APP.$cljs$core$truth_$$($G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.num-active-sets",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__80171$jscomp$inline_9073_G__80171__$1$jscomp$inline_9074_G__80171__$2$jscomp$inline_9075_sets_count$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-active-sets")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right"})]})})}(),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$delete_theme$jscomp$1$$,variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.delete-theme-title"),icon:"delete"})]})]},$theme_path$jscomp$2$$));$i__80163$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80164$$),$app$main$ui$workspace$tokens$themes$create_modal$themes_overview_$_iter__80161$$($APP.$cljs$core$_chunked_rest$$($s__80162__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80164$$),
null)}var $vec__80172$$=$APP.$cljs$core$first$$($s__80162__$2$$),$_$jscomp$3072$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80172$$,0,null),$map__80175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80172$$,1,null),$map__80175__$1$$=$APP.$cljs$core$__destructure_map$$($map__80175$$),$theme$jscomp$17$$=$map__80175__$1$$,$id$jscomp$1023$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80175__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$490$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80175__$1$$,
$APP.$cljs$cst$725$name$$),$theme_path$jscomp$1$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$17$$),$selected_QMARK_$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$6$$,$theme_path$jscomp$1$$)!=null,$delete_theme$$=function($theme_path$jscomp$6$$,$selected_QMARK_$jscomp$19$$,$vec__80172$jscomp$1$$,$_$jscomp$3077$$,$map__80175$jscomp$1$$,$map__80175__$1$jscomp$1$$,$theme$jscomp$22$$,$id$jscomp$1028$$){return function($e$jscomp$372$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$372$$);
$APP.$app$util$dom$stop_propagation$$($e$jscomp$372$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($id$jscomp$1028$$))}}($theme_path$jscomp$1$$,$selected_QMARK_$jscomp$14$$,$vec__80172$$,$_$jscomp$3072$$,$map__80175$$,$map__80175__$1$$,$theme$jscomp$17$$,$id$jscomp$1023$$,$name$jscomp$490$$,$s__80162__$2$$,$temp__5825__auto__$jscomp$407$$,$p__80157$$,$group$jscomp$55$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,
$themes_groups$$,$create_theme$jscomp$1$$,$map__80156$$,$map__80156__$1$$,$change_view$jscomp$1$$),$on_switch_theme$$=function($theme_path$jscomp$7$$,$selected_QMARK_$jscomp$20$$,$delete_theme$jscomp$4$$,$vec__80172$jscomp$2$$,$_$jscomp$3078$$,$map__80175$jscomp$2$$,$map__80175__$1$jscomp$2$$,$theme$jscomp$23$$,$id$jscomp$1029$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1029$$))}}($theme_path$jscomp$1$$,
$selected_QMARK_$jscomp$14$$,$delete_theme$$,$vec__80172$$,$_$jscomp$3072$$,$map__80175$$,$map__80175__$1$$,$theme$jscomp$17$$,$id$jscomp$1023$$,$name$jscomp$490$$,$s__80162__$2$$,$temp__5825__auto__$jscomp$407$$,$p__80157$$,$group$jscomp$55$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80156$$,$map__80156__$1$$,$change_view$jscomp$1$$),$on_edit_theme$$=function($theme_path$jscomp$8$$,$selected_QMARK_$jscomp$21$$,$delete_theme$jscomp$5$$,$on_switch_theme$jscomp$3$$,
$vec__80172$jscomp$3$$,$_$jscomp$3079$$,$map__80175$jscomp$3$$,$map__80175__$1$jscomp$3$$,$theme$jscomp$24$$,$id$jscomp$1030$$,$name$jscomp$497$$,$s__80162__$2$jscomp$6$$,$temp__5825__auto__$jscomp$413$$,$vec__80158$jscomp$6$$,$group$jscomp$61$$,$themes$jscomp$19$$,$active_theme_paths$jscomp$12$$,$themes_groups$jscomp$6$$,$create_theme$jscomp$7$$,$map__80156$jscomp$6$$,$map__80156__$1$jscomp$6$$,$change_view$jscomp$7$$){return function($G__80177_e$jscomp$373$$){$APP.$app$util$dom$prevent_default$$($G__80177_e$jscomp$373$$);
$APP.$app$util$dom$stop_propagation$$($G__80177_e$jscomp$373$$);$G__80177_e$jscomp$373$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5847$theme_info$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$24$$),$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$24$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$24$$)],null)],
null);return $change_view$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$?$change_view$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5846$edit_theme$$,$G__80177_e$jscomp$373$$):$change_view$jscomp$7$$($cljs$cst$5846$edit_theme$$,$G__80177_e$jscomp$373$$)}}($theme_path$jscomp$1$$,$selected_QMARK_$jscomp$14$$,$delete_theme$$,$on_switch_theme$$,$vec__80172$$,$_$jscomp$3072$$,$map__80175$$,$map__80175__$1$$,$theme$jscomp$17$$,$id$jscomp$1023$$,$name$jscomp$490$$,$s__80162__$2$$,$temp__5825__auto__$jscomp$407$$,
$p__80157$$,$group$jscomp$55$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80156$$,$map__80156__$1$$,$change_view$jscomp$1$$);return $APP.$cljs$core$cons$$((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_tokens_themes_create_modal__theme-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-switch-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,
{label:$name$jscomp$490$$,onChange:$on_switch_theme$$,defaultChecked:$selected_QMARK_$jscomp$14$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-actions-row",children:[function(){var $G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$=$theme$jscomp$17$$;$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$=$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$==
null?null:$APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$);$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$=$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$==null?null:$APP.$cljs$core$seq$$($G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$);
$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$=$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$==null?null:$APP.$cljs$core$count$$($G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:($APP.$cljs$core$truth_$$($G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$)?
"main_ui_workspace_tokens_themes_create_modal__sets-count-button":"")+" "+($APP.$cljs$core$not$$($G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$)?"main_ui_workspace_tokens_themes_create_modal__sets-count-empty-button":""),variant:"secondary",type:"button",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.sets-hint"),onClick:$on_edit_theme$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__label-wrapper",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",children:$APP.$cljs$core$truth_$$($G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.num-active-sets",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__80178$jscomp$inline_9077_G__80178__$1$jscomp$inline_9078_G__80178__$2$jscomp$inline_9079_sets_count$jscomp$1$$])):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-active-sets")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right"})]})})}(),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$delete_theme$$,variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.delete-theme-title"),icon:"delete"})]})]},$theme_path$jscomp$1$$),$app$main$ui$workspace$tokens$themes$create_modal$themes_overview_$_iter__80161$$($APP.$cljs$core$rest$$($s__80162__$2$$)))}return null}},
null,null)}($themes$jscomp$13$$)}())})]},"token-theme-group"+($group$jscomp$55$$??"")));return $out_arr__44124__auto__$jscomp$200$$},[],$themes_groups$$)}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__button-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:$create_theme$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-new-theme")})]})]})};
$app$main$ui$workspace$tokens$themes$create_modal$theme_inputs_STAR_$$=function($options$jscomp$641_props_80179_theme_groups$$){var $theme$jscomp$25$$=$options$jscomp$641_props_80179_theme_groups$$.theme,$on_change_field$$=$options$jscomp$641_props_80179_theme_groups$$.onChangeField,$tokens_lib$jscomp$54$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$);$options$jscomp$641_props_80179_theme_groups$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_theme_groups$$);var $theme_name_ref$$=
(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$25$$));$options$jscomp$641_props_80179_theme_groups$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($group$jscomp$62$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$group$jscomp$62$$,$APP.$cljs$cst$266$id$$,$group$jscomp$62$$],null)},$options$jscomp$641_props_80179_theme_groups$$);var $current_group_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$25$$)),
$current_group$$=$APP.$cljs$core$_deref$$($current_group_STAR_$$),$current_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$25$$)),$current_name$jscomp$2$$=$APP.$cljs$core$_deref$$($current_name_STAR_$$),$group_errors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$group_errors$$=$APP.$cljs$core$_deref$$($group_errors_STAR_$$),$name_errors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$name_errors$$=$APP.$cljs$core$_deref$$($name_errors_STAR_$$),$on_update_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_field$$),$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$54$$),$APP.$rumext$v2$adapt$$($current_name$jscomp$2$$)],function($value$jscomp$993$$){var $errors$jscomp$47$$=$app$common$schema$validation_errors$$($value$jscomp$993$$,$APP.$app$common$files$tokens$make_token_theme_group_schema$$($tokens_lib$jscomp$54$$,$current_name$jscomp$2$$,
$APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$25$$)));$APP.$cljs$core$reset_BANG_$$($group_errors_STAR_$$,$errors$jscomp$47$$);return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$47$$)?($APP.$cljs$core$reset_BANG_$$($current_group_STAR_$$,$value$jscomp$993$$),$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$value$jscomp$993$$):$on_change_field$$($APP.$cljs$cst$1608$group$$,$value$jscomp$993$$)):$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,""):$on_change_field$$($APP.$cljs$cst$1608$group$$,"")}),$on_update_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_field$$),$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$54$$),$APP.$rumext$v2$adapt$$($current_group$$)],function($event$jscomp$629_value$jscomp$994$$){$event$jscomp$629_value$jscomp$994$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$629_value$jscomp$994$$));
var $errors$jscomp$48$$=$app$common$schema$validation_errors$$($event$jscomp$629_value$jscomp$994$$,$APP.$app$common$files$tokens$make_token_theme_name_schema$$($tokens_lib$jscomp$54$$,$current_group$$,$APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$25$$)));$APP.$cljs$core$reset_BANG_$$($name_errors_STAR_$$,$errors$jscomp$48$$);$APP.$rumext$v2$set_ref_val_BANG_$$($theme_name_ref$$,$event$jscomp$629_value$jscomp$994$$);return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$48$$)?($APP.$cljs$core$reset_BANG_$$($current_name_STAR_$$,
$event$jscomp$629_value$jscomp$994$$),$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$event$jscomp$629_value$jscomp$994$$):$on_change_field$$($APP.$cljs$cst$725$name$$,$event$jscomp$629_value$jscomp$994$$)):$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,""):$on_change_field$$($APP.$cljs$cst$725$name$$,"")});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-inputs-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__group-input-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$utilities$label$label_STAR_$$,{htmlFor:"groups-dropdown",isOptional:!0,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.group")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$combobox$combobox_STAR_$$,
{id:"groups-dropdown",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.group-placeholder"),defaultSelected:$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$25$$),options:$APP.$cljs$core$clj__GT_js$$($options$jscomp$641_props_80179_theme_groups$$),hasError:$APP.$app$common$data$not_empty_QMARK_$$($group_errors$$),onChange:$on_update_group$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__group-input-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{onChange:$on_update_name$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.theme-placeholder"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.theme"),hintType:$APP.$cljs$core$empty_QMARK_$$($name_errors$$)?null:"error",hintMessage:$APP.$cljs$core$first$$($name_errors$$),maxLength:255,defaultValue:$APP.$rumext$v2$ref_val$$($theme_name_ref$$),
variant:"comfortable",autoFocus:!0})})]})};
$app$main$ui$workspace$tokens$themes$create_modal$theme_modal_buttons_STAR_$$=function($handle_key_down_cancel$jscomp$1_props_80180$$){var $disabled_QMARK_$jscomp$10$$=$handle_key_down_cancel$jscomp$1_props_80180$$["disabled?"],$close_modal$jscomp$2$$=$handle_key_down_cancel$jscomp$1_props_80180$$.closeModal,$on_save_form$$=$handle_key_down_cancel$jscomp$1_props_80180$$.onSaveForm;$handle_key_down_cancel$jscomp$1_props_80180$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($close_modal$jscomp$2$$)],function($event$jscomp$630$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$630$$))?
$close_modal$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$close_modal$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$630$$):$close_modal$jscomp$2$$($event$jscomp$630$$):null});var $handle_key_down_save$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_save_form$$)],function($event$jscomp$631$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$631$$))?$on_save_form$$.$cljs$core$IFn$_invoke$arity$1$?$on_save_form$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$631$$):
$on_save_form$$($event$jscomp$631$$):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$close_modal$jscomp$2$$,onKeyDown:$handle_key_down_cancel$jscomp$1_props_80180$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"submit",
onClick:$on_save_form$$,onKeyDown:$handle_key_down_save$jscomp$1$$,disabled:$disabled_QMARK_$jscomp$10$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.save-theme")})]})};
$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$=function($theme$jscomp$26$$,$sets$jscomp$22_tlib__$1$$){var $tlib$jscomp$2$$=$APP.$app$common$types$tokens_lib$make_tokens_lib$$().$app$common$types$tokens_lib$ITokenThemes$add_theme$arity$2$(null,$theme$jscomp$26$$);$sets$jscomp$22_tlib__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$tokens_lib$add_set$$,$tlib$jscomp$2$$,$sets$jscomp$22_tlib__$1$$);return $APP.$app$common$types$tokens_lib$activate_theme$$($sets$jscomp$22_tlib__$1$$,
$APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$26$$))};
$app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$=function($is_editing$jscomp$5_props_80183$$){var $has_prev_view$$=$is_editing$jscomp$5_props_80183$$.hasPrevView,$change_view$jscomp$8$$=$is_editing$jscomp$5_props_80183$$.changeView,$on_save$jscomp$1$$=$is_editing$jscomp$5_props_80183$$.onSave,$disabled_QMARK_$jscomp$11_theme$jscomp$27$$=$is_editing$jscomp$5_props_80183$$.theme;$is_editing$jscomp$5_props_80183$$=$is_editing$jscomp$5_props_80183$$.isEditing;var $ordered_token_sets$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_ordered_token_sets$$),$tokens_lib$jscomp$55$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$token_sets$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_sets_tree$$),$current_theme_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_QMARK_$jscomp$11_theme$jscomp$27$$),$current_theme$$=$APP.$cljs$core$_deref$$($current_theme_STAR_$$),$lib$jscomp$16$$=$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$($current_theme$$,
$ordered_token_sets$$),$on_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_view$jscomp$8$$)],function(){return $change_view$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$change_view$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5848$themes_overview$$):$change_view$jscomp$8$$($cljs$cst$5848$themes_overview$$)});$disabled_QMARK_$jscomp$11_theme$jscomp$27$$=$APP.$cuerdas$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current_theme$$)));
var $on_change_field$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($field$jscomp$16$$,$value$jscomp$995$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($current_theme_STAR_$$,function($p1__80181_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80181_SHARP_$$,$field$jscomp$16$$,$value$jscomp$995$$)})}),$on_save_form$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$),
$APP.$rumext$v2$adapt$$($on_save$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_back$$)],function($e$jscomp$374_theme_SINGLEQUOTE_$jscomp$1$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$374_theme_SINGLEQUOTE_$jscomp$1$$);$e$jscomp$374_theme_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($current_theme$$,$APP.$cljs$cst$725$name$$,$APP.$cuerdas$core$trim$$),
$APP.$cljs$cst$1608$group$$,$APP.$cuerdas$core$trim$$),$APP.$cljs$cst$936$description$$,$APP.$cuerdas$core$trim$$);$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$374_theme_SINGLEQUOTE_$jscomp$1$$))||($on_save$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_save$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$374_theme_SINGLEQUOTE_$jscomp$1$$):$on_save$jscomp$1$$($e$jscomp$374_theme_SINGLEQUOTE_$jscomp$1$$));return $on_back$$.$cljs$core$IFn$_invoke$arity$0$?
$on_back$$.$cljs$core$IFn$_invoke$arity$0$():$on_back$$()}),$close_modal$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$375$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$375$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_delete_theme$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$),$APP.$rumext$v2$adapt$$($on_back$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($APP.$app$common$types$tokens_lib$get_id$$($current_theme$$)));
return $on_back$$.$cljs$core$IFn$_invoke$arity$0$?$on_back$$.$cljs$core$IFn$_invoke$arity$0$():$on_back$$()}),$token_set_group_active_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$)],function($group_path$jscomp$12$$){return $app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$($lib$jscomp$16$$,$group_path$jscomp$12$$)}),$token_set_active_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$)],
function($name$jscomp$498$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($current_theme$$),$name$jscomp$498$$)}),$on_toggle_token_set$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$)],function($set_name$jscomp$31$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($current_theme_STAR_$$,function($p1__80182_SHARP_$$){return $APP.$app$common$types$tokens_lib$toggle_set$$($p1__80182_SHARP_$$,
$set_name$jscomp$31$$)})}),$on_toggle_token_set_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$),$APP.$rumext$v2$adapt$$($ordered_token_sets$$)],function($group_path$jscomp$13$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($current_theme_STAR_$$,function($theme_SINGLEQUOTE_$jscomp$2$$){var $lib_SINGLEQUOTE_$jscomp$3$$=$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$($theme_SINGLEQUOTE_$jscomp$2$$,
$ordered_token_sets$$);return $app$common$logic$tokens$toggle_token_set_group$$($group_path$jscomp$13$$,$lib_SINGLEQUOTE_$jscomp$3$$,$theme_SINGLEQUOTE_$jscomp$2$$)})}),$on_click_token_set$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_toggle_token_set$jscomp$1$$)],function($G__80184_set$jscomp$22_set_id$jscomp$45$$){$G__80184_set$jscomp$22_set_id$jscomp$45$$=$APP.$app$common$types$tokens_lib$get_set$$($lib$jscomp$16$$,$G__80184_set$jscomp$22_set_id$jscomp$45$$);
$G__80184_set$jscomp$22_set_id$jscomp$45$$=$APP.$app$common$types$tokens_lib$get_name$$($G__80184_set$jscomp$22_set_id$jscomp$45$$);return $on_toggle_token_set$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_token_set$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80184_set$jscomp$22_set_id$jscomp$45$$):$on_toggle_token_set$jscomp$1$$($G__80184_set$jscomp$22_set_id$jscomp$45$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-title",children:$APP.$cljs$core$truth_$$($is_editing$jscomp$5_props_80183$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.edit-theme-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-new-theme")}),(0,$APP.$rumext$v2$jsx$$)("form",
{onSubmit:$on_save_form$jscomp$1$$,className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-form",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-wrapper",children:[$APP.$cljs$core$truth_$$($has_prev_view$$)?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_back$$,type:"button",className:"main_ui_workspace_tokens_themes_create_modal__back-btn",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-left","aria-hidden":!0}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.back-to-themes")]}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$theme_inputs_STAR_$$,{theme:$current_theme$$,onChangeField:$on_change_field$jscomp$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_create_modal__select-sets-message",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.set-selection-theme")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__sets-list-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$,{tokenSets:$token_sets$jscomp$4$$,origin:"theme-modal",onToggleTokenSet:$on_toggle_token_set$jscomp$1$$,tokensLib:$tokens_lib$jscomp$55$$,isTokenSetActive:$token_set_active_QMARK_$jscomp$2$$,
canEdit:!1,onToggleTokenSetGroup:$on_toggle_token_set_group$jscomp$1$$,onSelect:$on_click_token_set$$,isTokenSetGroupActive:$token_set_group_active_QMARK_$jscomp$1$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-footer",children:[$APP.$cljs$core$truth_$$($is_editing$jscomp$5_props_80183$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",icon:"delete",onClick:$on_delete_theme$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")}):
null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__button-footer",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$theme_modal_buttons_STAR_$$,{closeModal:$close_modal$jscomp$3$$,onSaveForm:$on_save_form$jscomp$1$$,"disabled?":$disabled_QMARK_$jscomp$11_theme$jscomp$27$$})})]})]})})]})};
$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$=function($prev_view_type$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5848$themes_overview$$,null,$cljs$cst$5849$empty_themes$$,null],null),null),$prev_view_type$$)};
$app$main$ui$workspace$tokens$themes$create_modal$edit_theme$$=function($change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$){$change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$=$APP.$rumext$v2$util$wrap_props$$($change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$);$change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$=$APP.$cljs$core$__destructure_map$$($change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$);var $has_prev_view$jscomp$1_state$jscomp$1206$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$,$APP.$cljs$cst$769$state$$);$change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$,$cljs$cst$5844$change_view$$);var $map__80189__$1_on_save$jscomp$2_vec__80190$$=$APP.$cljs$core$__destructure_map$$($has_prev_view$jscomp$1_state$jscomp$1206$$);$map__80189__$1_on_save$jscomp$2_vec__80190$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80189__$1_on_save$jscomp$2_vec__80190$$,$cljs$cst$5847$theme_info$$);var $theme_id$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80189__$1_on_save$jscomp$2_vec__80190$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80189__$1_on_save$jscomp$2_vec__80190$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80189__$1_on_save$jscomp$2_vec__80190$$,2,null);var $theme$jscomp$28$$=
$APP.$rumext$v2$deref$$($app$main$refs$workspace_token_theme$$($theme_id$jscomp$10$$));$has_prev_view$jscomp$1_state$jscomp$1206$$=$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$($cljs$cst$5850$prev_type$$.$cljs$core$IFn$_invoke$arity$1$($has_prev_view$jscomp$1_state$jscomp$1206$$));$map__80189__$1_on_save$jscomp$2_vec__80190$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($theme$jscomp$28$$)],function($theme_SINGLEQUOTE_$jscomp$3$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$28$$),
$theme_SINGLEQUOTE_$jscomp$3$$))});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$,{changeView:$change_view$jscomp$9_map__80188_map__80188__$1_props_80187$$,theme:$theme$jscomp$28$$,onSave:$map__80189__$1_on_save$jscomp$2_vec__80190$$,isEditing:!0,hasPrevView:$has_prev_view$jscomp$1_state$jscomp$1206$$})};
$app$main$ui$workspace$tokens$themes$create_modal$create_theme$$=function($has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$){$has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$=$APP.$rumext$v2$util$wrap_props$$($has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$);var $change_view$jscomp$10_map__80194__$1$$=$APP.$cljs$core$__destructure_map$$($has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$);$has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$10_map__80194__$1$$,$APP.$cljs$cst$769$state$$);$change_view$jscomp$10_map__80194__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$10_map__80194__$1$$,$cljs$cst$5844$change_view$$);var $theme$jscomp$29$$=$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,""])),$on_save$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($theme__$1$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-tokens-theme"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$($theme__$1$$)]))});$has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$=
$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$($cljs$cst$5850$prev_type$$.$cljs$core$IFn$_invoke$arity$1$($has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$));return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$,{changeView:$change_view$jscomp$10_map__80194__$1$$,theme:$theme$jscomp$29$$,onSave:$on_save$jscomp$3$$,hasPrevView:$has_prev_view$jscomp$2_map__80194_props_80193_state$jscomp$1207$$})};
$app$main$ui$workspace$tokens$themes$create_modal$themes_modal_body_STAR_$$=function(){var $themes$jscomp$20$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_themes_no_hidden$$),$state_STAR_$jscomp$25$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$empty_QMARK_$$($themes$jscomp$20$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5845$create_theme$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5848$themes_overview$$],null)}),$state$jscomp$1208$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$25$$),$change_view$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){function $G__80202$$($type$jscomp$706$$,$var_args$jscomp$1461$$){var $G__80203__i_p__80196$jscomp$1$$=null;if(arguments.length>1){$G__80203__i_p__80196$jscomp$1$$=0;for(var $G__80203__a$$=Array(arguments.length-1);$G__80203__i_p__80196$jscomp$1$$<$G__80203__a$$.length;)$G__80203__a$$[$G__80203__i_p__80196$jscomp$1$$]=
arguments[$G__80203__i_p__80196$jscomp$1$$+1],++$G__80203__i_p__80196$jscomp$1$$;$G__80203__i_p__80196$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__80203__a$$,0,null)}return $G__80202__delegate$$.call(this,$type$jscomp$706$$,$G__80203__i_p__80196$jscomp$1$$)}function $G__80202__delegate$$($type$jscomp$705$$,$map__80197__$1_p__80196$$){$map__80197__$1_p__80196$$=$APP.$cljs$core$__destructure_map$$($map__80197__$1_p__80196$$);var $theme_info$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80197__$1_p__80196$$,
$cljs$cst$5847$theme_info$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$25$$,function($G__80198__$1_current_state$$){$G__80198__$1_current_state$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__80198__$1_current_state$$,$APP.$cljs$cst$139$type$$,$type$jscomp$705$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5850$prev_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__80198__$1_current_state$$)]));
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80198__$1_current_state$$,$cljs$cst$5847$theme_info$$,$theme_info$jscomp$1$$)})}$G__80202$$.$cljs$lang$maxFixedArity$=1;$G__80202$$.$cljs$lang$applyTo$=function($arglist__80204_p__80196$jscomp$2$$){var $type$jscomp$707$$=$APP.$cljs$core$first$$($arglist__80204_p__80196$jscomp$2$$);$arglist__80204_p__80196$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__80204_p__80196$jscomp$2$$);return $G__80202__delegate$$($type$jscomp$707$$,$arglist__80204_p__80196$jscomp$2$$)};
$G__80202$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__80202__delegate$$;return $G__80202$$}()),$component$jscomp$135$$=function(){var $G__80199_G__80199__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1208$$);$G__80199_G__80199__$1$$=$G__80199_G__80199__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__80199_G__80199__$1$$.$fqn$:null;switch($G__80199_G__80199__$1$$){case "empty-themes":return $app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$;case "themes-overview":return $APP.$cljs$core$empty_QMARK_$$($themes$jscomp$20$$)?
$app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$:$app$main$ui$workspace$tokens$themes$create_modal$themes_overview$$;case "edit-theme":return $app$main$ui$workspace$tokens$themes$create_modal$edit_theme$$;case "create-theme":return $app$main$ui$workspace$tokens$themes$create_modal$create_theme$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80199_G__80199__$1$$)].join(""));}}();return(0,$APP.$rumext$v2$jsx$$)($component$jscomp$135$$,
{state:$state$jscomp$1208$$,"change-view":$change_view$jscomp$11$$})};
$app$main$ui$workspace$tokens$themes$create_modal$token_themes_modal$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"token-theme-update-create-modal",className:"main_ui_workspace_tokens_themes_create_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_themes_create_modal__close-btn",
onClick:$APP.$app$main$data$modal$hide_BANG_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),variant:"action",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$themes_modal_body_STAR_$$,{})]})})};
$app$main$ui$flex_controls$common$flex_display_pill$$=function($map__80186_props_80185_x$jscomp$1261$$){$map__80186_props_80185_x$jscomp$1261$$=$APP.$rumext$v2$util$wrap_props$$($map__80186_props_80185_x$jscomp$1261$$);var $color$jscomp$186_map__80186__$1$$=$APP.$cljs$core$__destructure_map$$($map__80186_props_80185_x$jscomp$1261$$);$map__80186_props_80185_x$jscomp$1261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$483$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$209$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$1522$height$$),$font_size$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,
$APP.$cljs$cst$1760$font_size$$),$border_radius$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$1982$border_radius$$),$value$jscomp$996$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$260$value$$);$color$jscomp$186_map__80186__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186_map__80186__$1$$,$APP.$cljs$cst$1298$color$$);return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"distance-pill",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__80186_props_80185_x$jscomp$1261$$,y:$y$jscomp$483$$,width:$width$jscomp$209$$,height:$height$jscomp$177$$,rx:$border_radius$jscomp$1$$,ry:$border_radius$jscomp$1$$,style:{fill:$color$jscomp$186_map__80186__$1$$}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$map__80186_props_80185_x$jscomp$1261$$+$width$jscomp$209$$/2,y:$y$jscomp$483$$+$height$jscomp$177$$/2,textAnchor:"middle",dominantBaseline:"central",style:{fill:"var(--app-white)",
fontSize:$font_size$jscomp$16$$},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($value$jscomp$996$$)?$value$jscomp$996$$:0)})]})};
$app$main$ui$workspace$viewport$viewport_ref$init_observer$$=function($node$jscomp$461$$){var $observer$jscomp$8$$=new ResizeObserver($app$main$ui$workspace$viewport$viewport_ref$on_change_bounds$$);$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$current_observer$$)!=null&&$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$current_observer$$).disconnect();$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$viewport$viewport_ref$current_observer$$,$observer$jscomp$8$$);
return $node$jscomp$461$$!=null?$observer$jscomp$8$$.observe($node$jscomp$461$$):null};
$app$main$ui$workspace$viewport$viewport_ref$on_change_bounds$$=function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$))){var $brect_brect__$1$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$));$brect_brect__$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($brect_brect__$1$$)),$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($brect_brect__$1$$)));
return $APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$,$brect_brect__$1$$)}return null};
$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$=function(){var $ref$jscomp$57$$=(0,$APP.$rumext$v2$use_ref$$)(null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ref$jscomp$57$$,$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function($node$jscomp$462$$){$APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$57$$,$node$jscomp$462$$);$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$,
$node$jscomp$462$$);$node$jscomp$462$$!=null&&$APP.$goog$events$listen$$($node$jscomp$462$$,"mouseleave",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$BlurEvent$$(null,null,null))});return $app$main$ui$workspace$viewport$viewport_ref$init_observer$$($node$jscomp$462$$)}})],null)};
$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$=function($pt$jscomp$26$$){var $zoom$jscomp$67_zoom__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2196$zoom$$,1);if($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$)!=null&&$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$)!=
null){var $box_vbox$jscomp$36$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$).viewBox.baseVal,$brect$jscomp$1$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$);$box_vbox$jscomp$36$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($box_vbox$jscomp$36$$.x,$box_vbox$jscomp$36$$.y);$zoom$jscomp$67_zoom__$1$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$67_zoom__$1$jscomp$1$$);
return $APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$divide$$($APP.$app$common$geom$point$subtract$$($pt$jscomp$26$$,$brect$jscomp$1$$),$zoom$jscomp$67_zoom__$1$jscomp$1$$),$box_vbox$jscomp$36$$)}return null};
$app$main$ui$flex_controls$gap$gap_display$$=function($map__80209_map__80209__$1_props_80208$$){$map__80209_map__80209__$1_props_80208$$=$APP.$rumext$v2$util$wrap_props$$($map__80209_map__80209__$1_props_80208$$);$map__80209_map__80209__$1_props_80208$$=$APP.$cljs$core$__destructure_map$$($map__80209_map__80209__$1_props_80208$$);var $on_change$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$APP.$cljs$cst$4157$on_change$$),$selected_QMARK_$jscomp$22$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$APP.$cljs$cst$5784$selected_QMARK_$$),$hover_QMARK_$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5580$hover_QMARK_$$),$zoom$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$APP.$cljs$cst$2196$zoom$$),$on_pointer_leave$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,
$cljs$cst$5851$on_pointer_leave$$),$gap_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5852$gap_type$$),$on_pointer_enter$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5853$on_pointer_enter$$),$mouse_pos$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5854$mouse_pos$$),$on_context_menu$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,
$cljs$cst$5798$on_context_menu$$),$on_move_selected$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5855$on_move_selected$$),$hover_value$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5856$hover_value$$),$rect_data$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$cljs$cst$5857$rect_data$$),$gap$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,
$APP.$cljs$cst$4065$gap$$),$frame_id$jscomp$144$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80209_map__80209__$1_props_80208$$,$APP.$cljs$cst$1607$frame_id$$),$resizing$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$start$jscomp$248$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$original_value$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$last_pos$jscomp$2$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$negate_QMARK_$jscomp$3$$=$cljs$cst$5858$resize_negate_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),$axis$jscomp$39$$=$cljs$cst$5859$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),$on_pointer_down$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$144$$),$APP.$rumext$v2$adapt$$($gap_type$$),$APP.$rumext$v2$adapt$$($gap$jscomp$5$$)],function($event$jscomp$632$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$632$$);
$APP.$cljs$core$reset_BANG_$$($resizing$$,$gap_type$$);$APP.$cljs$core$reset_BANG_$$($start$jscomp$248$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$632$$));return $APP.$cljs$core$reset_BANG_$$($original_value$$,$cljs$cst$5860$initial_value$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$))}),$calc_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$144$$),$APP.$rumext$v2$adapt$$($gap_type$$),$APP.$rumext$v2$adapt$$($gap$jscomp$5$$)],
function($pos$jscomp$151$$){var $delta$jscomp$61$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__80219$$=$APP.$app$common$geom$point$to_vec$$($APP.$cljs$core$_deref$$($start$jscomp$248$$),$pos$jscomp$151$$);return $APP.$cljs$core$truth_$$($negate_QMARK_$jscomp$3$$)?$APP.$app$common$geom$point$negate$$($G__80219$$):$G__80219$$}(),$axis$jscomp$39$$),$val$jscomp$219$$=function(){var $x__5110__auto__$jscomp$145$$=$APP.$cljs$core$_deref$$($original_value$$)+$delta$jscomp$61$$/
$zoom$jscomp$68$$;return $x__5110__auto__$jscomp$145$$>0?$x__5110__auto__$jscomp$145$$:0}()|0,$layout_gap$jscomp$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($gap$jscomp$5$$,$gap_type$$,$val$jscomp$219$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val$jscomp$219$$,$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$144$$],
null),$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1680$layout_gap$$,$layout_gap$jscomp$4$$))],null)}),$on_lost_pointer_capture$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$$)],function($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$){$APP.$app$util$dom$release_pointer$$($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$);
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($resizing$$),$gap_type$$)&&($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$=$APP.$cljs$core$_deref$$($last_pos$jscomp$2$$),$G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$=$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$):
$calc_modifiers$$($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$,0,null),$G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$,1,null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($G__80225$jscomp$inline_9081_event$jscomp$633_modifiers_80284_vec__80222_80282$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()])));$APP.$cljs$core$reset_BANG_$$($resizing$$,null);$APP.$cljs$core$reset_BANG_$$($start$jscomp$248$$,null);$APP.$cljs$core$reset_BANG_$$($original_value$$,0);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),
$on_pointer_move$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$94$$)],function($event$jscomp$634_pos$jscomp$152_val$jscomp$220$$){$event$jscomp$634_pos$jscomp$152_val$jscomp$220$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$634_pos$jscomp$152_val$jscomp$220$$);$APP.$cljs$core$reset_BANG_$$($last_pos$jscomp$2$$,$event$jscomp$634_pos$jscomp$152_val$jscomp$220$$);$APP.$cljs$core$reset_BANG_$$($mouse_pos$$,
$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$634_pos$jscomp$152_val$jscomp$220$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($resizing$$),$gap_type$$)){var $modifiers$jscomp$114_vec__80227$$=$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$634_pos$jscomp$152_val$jscomp$220$$):$calc_modifiers$$($event$jscomp$634_pos$jscomp$152_val$jscomp$220$$);$event$jscomp$634_pos$jscomp$152_val$jscomp$220$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$114_vec__80227$$,0,null);$modifiers$jscomp$114_vec__80227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$114_vec__80227$$,1,null);$APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$1$$,$event$jscomp$634_pos$jscomp$152_val$jscomp$220$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modifiers$jscomp$114_vec__80227$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$114_vec__80227$$,!1,!1,null));return $APP.$cljs$core$truth_$$($on_change$jscomp$94$$)?$on_change$jscomp$94$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$94$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$114_vec__80227$$):$on_change$jscomp$94$$($modifiers$jscomp$114_vec__80227$$):null}return null});return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"gap-rect",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),className:"info-area",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),onContextMenu:$on_context_menu$jscomp$16$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$8$$)?$hover_QMARK_$jscomp$8$$:$selected_QMARK_$jscomp$22$$)?
"var(--color-accent-quaternary)":"none",opacity:$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$22$$)?.5:.25},y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),onPointerMove:$on_pointer_move$jscomp$6$$,onPointerDown:$on_move_selected$$,onPointerLeave:$on_pointer_leave$jscomp$7$$,onPointerEnter:$on_pointer_enter$jscomp$7$$}),function(){var $handle_width$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$39$$,$APP.$cljs$cst$1510$x$$)?2/$zoom$jscomp$68$$:function(){var $x__5113__auto__$jscomp$79$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)*.5,$y__5114__auto__$jscomp$79$$=20/$zoom$jscomp$68$$;return $x__5113__auto__$jscomp$79$$<$y__5114__auto__$jscomp$79$$?$x__5113__auto__$jscomp$79$$:$y__5114__auto__$jscomp$79$$}(),$handle_height$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$39$$,$APP.$cljs$cst$1511$y$$)?2/$zoom$jscomp$68$$:function(){var $x__5113__auto__$jscomp$80$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)*
.5,$y__5114__auto__$jscomp$80$$=30/$zoom$jscomp$68$$;return $x__5113__auto__$jscomp$80$$<$y__5114__auto__$jscomp$80$$?$x__5113__auto__$jscomp$80$$:$y__5114__auto__$jscomp$80$$}();return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$handle_width$$,height:$handle_height$$,className:"handle "+(($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$8$$)?$hover_QMARK_$jscomp$8$$:$selected_QMARK_$jscomp$22$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5859$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),
$APP.$cljs$cst$1510$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",90):null)??""),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)-$handle_width$$)/2,onContextMenu:$on_context_menu$jscomp$16$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$8$$)?$hover_QMARK_$jscomp$8$$:$selected_QMARK_$jscomp$22$$)?"var(--color-accent-quaternary)":
"none",opacity:$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$22$$)?0:1},onLostPointerCapture:$on_lost_pointer_capture$jscomp$5$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)-$handle_height$$)/2,onPointerMove:$on_pointer_move$jscomp$6$$,onPointerDown:$on_pointer_down$jscomp$7$$,onPointerLeave:$on_pointer_leave$jscomp$7$$,onPointerEnter:$on_pointer_enter$jscomp$7$$})}()]})};
$app$main$ui$flex_controls$gap$gap_rects$$=function($map__80255_map__80255__$1_pill_width_props_80254$$){function $create_rgdd_block$$($block$jscomp$9_y$jscomp$489$$){var $x$jscomp$1267$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?$x1$jscomp$40$$+$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$):$x1$jscomp$40$$+$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$);$block$jscomp$9_y$jscomp$489$$=$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$9_y$jscomp$489$$)-
$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$):$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$9_y$jscomp$489$$);var $w$jscomp$45$$=$width$jscomp$210$$-($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$)+$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,
$cljs$cst$5852$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$block$jscomp$9_y$jscomp$489$$,$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1682$column_gap$$:$APP.$cljs$cst$1681$row_gap$$,$w$jscomp$45$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$),$x$jscomp$1267$$,
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$)])}function $create_rgdd$$($shape$jscomp$1041_y$jscomp$488$$){var $block$jscomp$8_w$jscomp$44$$=$get_container_block$$($shape$jscomp$1041_y$jscomp$488$$),$x$jscomp$1266$$=$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$8_w$jscomp$44$$);$shape$jscomp$1041_y$jscomp$488$$=$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1041_y$jscomp$488$$))-
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1041_y$jscomp$488$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1702$m3$$],null))-$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$):$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1041_y$jscomp$488$$))+$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1041_y$jscomp$488$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1702$m3$$],null));$block$jscomp$8_w$jscomp$44$$=$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$8_w$jscomp$44$$)-$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$8_w$jscomp$44$$);return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,
$cljs$cst$5852$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$shape$jscomp$1041_y$jscomp$488$$,$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1681$row_gap$$:$APP.$cljs$cst$1682$column_gap$$,$block$jscomp$8_w$jscomp$44$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$),
$x$jscomp$1266$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$)])}function $create_cgdd_block$$($block$jscomp$7_x$jscomp$1265$$){$block$jscomp$7_x$jscomp$1265$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$7_x$jscomp$1265$$)-$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$):$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$7_x$jscomp$1265$$);
var $y$jscomp$487$$=$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?$y1$jscomp$42$$+$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$):$y1$jscomp$42$$+$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$),$h$jscomp$186$$=$height$jscomp$178$$-($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$)+$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,
$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$cljs$cst$5852$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$y$jscomp$487$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1682$column_gap$$:$APP.$cljs$cst$1681$row_gap$$,$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$),
$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$),$block$jscomp$7_x$jscomp$1265$$,$APP.$cljs$cst$1510$x$$,$h$jscomp$186$$])}function $create_cgdd$$($shape$jscomp$1040_x$jscomp$1264$$){var $block$jscomp$6_h$jscomp$185$$=$get_container_block$$($shape$jscomp$1040_x$jscomp$1264$$);$shape$jscomp$1040_x$jscomp$1264$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1040_x$jscomp$1264$$))-
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1040_x$jscomp$1264$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1701$m2$$],null))-$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$):$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1040_x$jscomp$1264$$))+$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1040_x$jscomp$1264$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1701$m2$$],null));var $y$jscomp$486$$=$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$6_h$jscomp$185$$);$block$jscomp$6_h$jscomp$185$$=$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$6_h$jscomp$185$$)-$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$6_h$jscomp$185$$);return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,
$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$cljs$cst$5852$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$y$jscomp$486$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1681$row_gap$$:$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$),
$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$6$$),$shape$jscomp$1040_x$jscomp$1264$$,$APP.$cljs$cst$1510$x$$,$block$jscomp$6_h$jscomp$185$$])}function $get_container_block$$($selrect$jscomp$81_shape$jscomp$1039$$){$selrect$jscomp$81_shape$jscomp$1039$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$81_shape$jscomp$1039$$);var $x$jscomp$1263$$=($APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$81_shape$jscomp$1039$$)+
$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$81_shape$jscomp$1039$$))/2,$y$jscomp$485$$=($APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$81_shape$jscomp$1039$$)+$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$81_shape$jscomp$1039$$))/2;return $APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80243_SHARP_$$){return $is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($p1__80243_SHARP_$$)<=
$x$jscomp$1263$$&&$x$jscomp$1263$$<=$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($p1__80243_SHARP_$$):$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($p1__80243_SHARP_$$)<=$y$jscomp$485$$&&$y$jscomp$485$$<=$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($p1__80243_SHARP_$$)},$wrap_blocks$$))}function $on_pointer_leave$jscomp$8$$(){return $APP.$cljs$core$reset_BANG_$$($hover$jscomp$2$$,null)}function $on_pointer_enter$jscomp$8$$($hover_type$$,$val$jscomp$221$$){$APP.$cljs$core$reset_BANG_$$($hover$jscomp$2$$,
$hover_type$$);return $APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$2$$,$val$jscomp$221$$)}$map__80255_map__80255__$1_pill_width_props_80254$$=$APP.$rumext$v2$util$wrap_props$$($map__80255_map__80255__$1_pill_width_props_80254$$);$map__80255_map__80255__$1_pill_width_props_80254$$=$APP.$cljs$core$__destructure_map$$($map__80255_map__80255__$1_pill_width_props_80254$$);var $children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80255_map__80255__$1_pill_width_props_80254$$,
$APP.$cljs$cst$1606$frame$$),$zoom$jscomp$69$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80255_map__80255__$1_pill_width_props_80254$$,$APP.$cljs$cst$2196$zoom$$),$on_move_selected$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80255_map__80255__$1_pill_width_props_80254$$,$cljs$cst$5855$on_move_selected$$),$on_context_menu$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80255_map__80255__$1_pill_width_props_80254$$,$cljs$cst$5798$on_context_menu$$),
$frame_id$jscomp$145$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$),$display_blocks_saved_dir$jscomp$1$$=$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$),$is_col_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$display_blocks_saved_dir$jscomp$1$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1662$column_reverse$$,$display_blocks_saved_dir$jscomp$1$$),$flip_x$jscomp$9$$=$APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$),$flip_y$jscomp$9$$=$APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$);$map__80255_map__80255__$1_pill_width_props_80254$$=
40/$zoom$jscomp$69$$;var $pill_height$$=20/$zoom$jscomp$69$$,$workspace_modifiers$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$workspace_wasm_modifiers$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),$gap_selected$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_gap_selected$$),$hover$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_value$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),
$mouse_pos$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$current_modifiers$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame__$1$jscomp$6$$=$APP.$app$common$types$modifiers$apply_structure_modifiers$$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($current_modifiers$jscomp$1$$),
$frame_id$jscomp$145$$),$APP.$cljs$cst$1810$modifiers$$)),$padding$jscomp$11$$=$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$6$$),$gap$jscomp$6$$=$APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$6$$);$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$6$$);$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$=
$APP.$cljs$core$__destructure_map$$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$);var $width$jscomp$210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$,$APP.$cljs$cst$1522$height$$),
$x1$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$,$APP.$cljs$cst$1523$x1$$),$y1$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$,$APP.$cljs$cst$1524$y1$$),$on_change$jscomp$95$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers$jscomp$115$$){return $APP.$cljs$core$reset_BANG_$$($current_modifiers$jscomp$1$$,
$modifiers$jscomp$115$$)}),$negate$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?!0:!1,$APP.$cljs$cst$1681$row_gap$$,$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?!0:!1],null),$objects$jscomp$805$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$children$jscomp$306$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$805$$,$frame_id$jscomp$145$$)),$children_to_display$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row_reverse$$,$display_blocks_saved_dir$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1662$column_reverse$$,$display_blocks_saved_dir$jscomp$1$$)?$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($children$jscomp$306$$):
$APP.$cljs$core$rest$$($children$jscomp$306$$);$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?function(){var $modifiers$jscomp$116$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$workspace_wasm_modifiers$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$1038$$){return $APP.$app$common$geom$shapes$apply_transform$$($shape$jscomp$1038$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$116$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1038$$)))},$children_to_display$$)}():$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80238_SHARP_$$){return $APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($p1__80238_SHARP_$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($workspace_modifiers$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80238_SHARP_$$),$APP.$cljs$cst$1810$modifiers$$],null)))},$children_to_display$$);var $wrap_blocks$$=function(){var $block_children_layout_data$jscomp$17$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80239_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80239_SHARP_$$),
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$6$$)),$p1__80239_SHARP_$$],null)},$children$jscomp$306$$),$bounds$jscomp$83$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$805$$),function($p1__80240_SHARP_$$){return $APP.$app$common$geom$shapes$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$805$$,$p1__80240_SHARP_$$))});$block_children_layout_data$jscomp$17$$=$APP.$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($frame__$1$jscomp$6$$,
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$6$$),$block_children_layout_data$jscomp$17$$,$bounds$jscomp$83$$,$objects$jscomp$805$$);var $layout_bounds$jscomp$11$$=$APP.$cljs$cst$3666$layout_bounds$$.$cljs$core$IFn$_invoke$arity$1$($block_children_layout_data$jscomp$17$$);return function $app$main$ui$flex_controls$gap$gap_rects_$_iter__80261$$($s__80262$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__80262__$2_temp__5825__auto__$jscomp$414$$=
$APP.$cljs$core$seq$$($s__80262$$);if($s__80262__$2_temp__5825__auto__$jscomp$414$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80262__$2_temp__5825__auto__$jscomp$414$$)){var $c__5501__auto__$jscomp$57$$=$APP.$cljs$core$_chunked_first$$($s__80262__$2_temp__5825__auto__$jscomp$414$$),$size__5502__auto__$jscomp$57$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$57$$),$b__80264$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$57$$);return function(){for(var $i__80263$$=0;;)if($i__80263$$<
$size__5502__auto__$jscomp$57$$){var $map__80265_map__80265__$1$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$57$$,$i__80263$$);$map__80265_map__80265__$1$$=$APP.$cljs$core$__destructure_map$$($map__80265_map__80265__$1$$);var $start_p$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80265_map__80265__$1$$,$APP.$cljs$cst$3663$start_p$$),$line_width$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80265_map__80265__$1$$,$APP.$cljs$cst$3801$line_width$$),
$line_height$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80265_map__80265__$1$$,$APP.$cljs$cst$1765$line_height$$),$layout_gap_row$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80265_map__80265__$1$$,$APP.$cljs$cst$3803$layout_gap_row$$),$layout_gap_col$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80265_map__80265__$1$$,$APP.$cljs$cst$3804$layout_gap_col$$),$num_children$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80265_map__80265__$1$$,
$APP.$cljs$cst$3802$num_children$$);$APP.$cljs$core$chunk_append$$($b__80264$$,function(){var $line_height__$1$jscomp$7$$=$is_col_QMARK_$jscomp$2$$?$line_height$jscomp$23$$+($num_children$jscomp$7$$-1)*$layout_gap_col$jscomp$12$$:$line_height$jscomp$23$$,$end_p$jscomp$3$$=$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$11$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$11$$,$is_col_QMARK_$jscomp$2$$?$line_width$jscomp$10$$:$line_width$jscomp$10$$+
($num_children$jscomp$7$$-1)*$layout_gap_row$jscomp$12$$)),$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$11$$,$line_height__$1$jscomp$7$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1523$x1$$,function(){var $x__5113__auto__$jscomp$81$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5114__auto__$jscomp$81$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);return $x__5113__auto__$jscomp$81$$<
$y__5114__auto__$jscomp$81$$?$x__5113__auto__$jscomp$81$$:$y__5114__auto__$jscomp$81$$}(),$APP.$cljs$cst$1524$y1$$,function(){var $x__5113__auto__$jscomp$82$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5114__auto__$jscomp$82$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);return $x__5113__auto__$jscomp$82$$<$y__5114__auto__$jscomp$82$$?$x__5113__auto__$jscomp$82$$:$y__5114__auto__$jscomp$82$$}(),$APP.$cljs$cst$1525$x2$$,function(){var $x__5110__auto__$jscomp$146$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5111__auto__$jscomp$146$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);return $x__5110__auto__$jscomp$146$$>$y__5111__auto__$jscomp$146$$?$x__5110__auto__$jscomp$146$$:$y__5111__auto__$jscomp$146$$}(),$APP.$cljs$cst$1526$y2$$,function(){var $x__5110__auto__$jscomp$147$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5111__auto__$jscomp$147$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);
return $x__5110__auto__$jscomp$147$$>$y__5111__auto__$jscomp$147$$?$x__5110__auto__$jscomp$147$$:$y__5111__auto__$jscomp$147$$}()],null)}());$i__80263$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80264$$),$app$main$ui$flex_controls$gap$gap_rects_$_iter__80261$$($APP.$cljs$core$_chunked_rest$$($s__80262__$2_temp__5825__auto__$jscomp$414$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80264$$),null)}var $map__80270_map__80270__$1$$=$APP.$cljs$core$first$$($s__80262__$2_temp__5825__auto__$jscomp$414$$);
$map__80270_map__80270__$1$$=$APP.$cljs$core$__destructure_map$$($map__80270_map__80270__$1$$);var $start_p$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80270_map__80270__$1$$,$APP.$cljs$cst$3663$start_p$$),$line_width$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80270_map__80270__$1$$,$APP.$cljs$cst$3801$line_width$$),$line_height$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80270_map__80270__$1$$,$APP.$cljs$cst$1765$line_height$$),
$layout_gap_row$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80270_map__80270__$1$$,$APP.$cljs$cst$3803$layout_gap_row$$),$layout_gap_col$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80270_map__80270__$1$$,$APP.$cljs$cst$3804$layout_gap_col$$),$num_children$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80270_map__80270__$1$$,$APP.$cljs$cst$3802$num_children$$);return $APP.$cljs$core$cons$$(function(){var $line_height__$1$jscomp$8$$=
$is_col_QMARK_$jscomp$2$$?$line_height$jscomp$22$$+($num_children$jscomp$6$$-1)*$layout_gap_col$jscomp$11$$:$line_height$jscomp$22$$,$end_p$jscomp$4$$=$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$10$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$11$$,$is_col_QMARK_$jscomp$2$$?$line_width$jscomp$9$$:$line_width$jscomp$9$$+($num_children$jscomp$6$$-1)*$layout_gap_row$jscomp$11$$)),$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$11$$,
$line_height__$1$jscomp$8$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1523$x1$$,function(){var $x__5113__auto__$jscomp$83$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5114__auto__$jscomp$83$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);return $x__5113__auto__$jscomp$83$$<$y__5114__auto__$jscomp$83$$?$x__5113__auto__$jscomp$83$$:$y__5114__auto__$jscomp$83$$}(),$APP.$cljs$cst$1524$y1$$,function(){var $x__5113__auto__$jscomp$84$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5114__auto__$jscomp$84$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);return $x__5113__auto__$jscomp$84$$<$y__5114__auto__$jscomp$84$$?$x__5113__auto__$jscomp$84$$:$y__5114__auto__$jscomp$84$$}(),$APP.$cljs$cst$1525$x2$$,function(){var $x__5110__auto__$jscomp$148$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5111__auto__$jscomp$148$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);
return $x__5110__auto__$jscomp$148$$>$y__5111__auto__$jscomp$148$$?$x__5110__auto__$jscomp$148$$:$y__5111__auto__$jscomp$148$$}(),$APP.$cljs$cst$1526$y2$$,function(){var $x__5110__auto__$jscomp$149$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5111__auto__$jscomp$149$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);return $x__5110__auto__$jscomp$149$$>$y__5111__auto__$jscomp$149$$?$x__5110__auto__$jscomp$149$$:$y__5111__auto__$jscomp$149$$}()],
null)}(),$app$main$ui$flex_controls$gap$gap_rects_$_iter__80261$$($APP.$cljs$core$rest$$($s__80262__$2_temp__5825__auto__$jscomp$414$$)))}return null}},null,null)}($APP.$cljs$cst$3055$layout_lines$$.$cljs$core$IFn$_invoke$arity$1$($block_children_layout_data$jscomp$17$$))}();$display_blocks_saved_dir$jscomp$1$$=$is_col_QMARK_$jscomp$2$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_cgdd_block$$,$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($wrap_blocks$$)):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_rgdd_block$$,
$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($wrap_blocks$$));$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$=$is_col_QMARK_$jscomp$2$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_rgdd$$,$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_cgdd$$,$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$);
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"gaps",pointerEvents:"visible",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$201$$,$JSCompiler_temp_const$jscomp$1878_p__80273$$){var $JSCompiler_inline_result$jscomp$1880_index$jscomp$560$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1878_p__80273$$,0,null),$display_item$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1878_p__80273$$,
1,null);$JSCompiler_temp_const$jscomp$1878_p__80273$$=$out_arr__44124__auto__$jscomp$201$$.push;var $gap_type$jscomp$inline_9087$$=$cljs$cst$5852$gap_type$$.$cljs$core$IFn$_invoke$arity$1$($display_item$$);$JSCompiler_inline_result$jscomp$1880_index$jscomp$560$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_display$$,{zoom:$zoom$jscomp$69$$,"on-pointer-leave":$on_pointer_leave$jscomp$8$$,"gap-type":$gap_type$jscomp$inline_9087$$,"mouse-pos":$mouse_pos$jscomp$1$$,"on-pointer-enter":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_pointer_enter$jscomp$8$$,
$gap_type$jscomp$inline_9087$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap$jscomp$6$$,$gap_type$jscomp$inline_9087$$)),"on-context-menu":$on_context_menu$jscomp$17$$,"on-move-selected":$on_move_selected$jscomp$1$$,"hover-value":$hover_value$jscomp$2$$,gap:$gap$jscomp$6$$,"rect-data":$display_item$$,"frame-id":$frame_id$jscomp$145$$,"on-change":$on_change$jscomp$95$$,"selected?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($gap_selected$jscomp$2$$,$gap_type$jscomp$inline_9087$$),
"hover?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$2$$),$gap_type$jscomp$inline_9087$$)},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$145$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1880_index$jscomp$560$$)].join(""));$JSCompiler_temp_const$jscomp$1878_p__80273$$.call($out_arr__44124__auto__$jscomp$201$$,$JSCompiler_inline_result$jscomp$1880_index$jscomp$560$$);return $out_arr__44124__auto__$jscomp$201$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($display_blocks_saved_dir$jscomp$1$$,$children_to_display__$1_display_children_frame$jscomp$73_map__80256_map__80256__$1$$))),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover$jscomp$2$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$common$flex_display_pill$$,{height:$pill_height$$,width:$map__80255_map__80255__$1_pill_width_props_80254$$,"font-size":11/
$zoom$jscomp$69$$,"border-radius":4/$zoom$jscomp$69$$,color:"var(--color-accent-quaternary)",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$1$$)),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$1$$))-$map__80255_map__80255__$1_pill_width_props_80254$$,value:$APP.$cljs$core$_deref$$($hover_value$jscomp$2$$)}):null]})};
$app$main$ui$flex_controls$gap$gap_control$$=function($frame$jscomp$74_map__80281_props_80280$$){$frame$jscomp$74_map__80281_props_80280$$=$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$74_map__80281_props_80280$$);var $map__80281__$1_on_context_menu$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$74_map__80281_props_80280$$);$frame$jscomp$74_map__80281_props_80280$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80281__$1_on_context_menu$jscomp$18$$,$APP.$cljs$cst$1606$frame$$);
var $zoom$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80281__$1_on_context_menu$jscomp$18$$,$APP.$cljs$cst$2196$zoom$$),$on_move_selected$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80281__$1_on_context_menu$jscomp$18$$,$cljs$cst$5855$on_move_selected$$);$map__80281__$1_on_context_menu$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80281__$1_on_context_menu$jscomp$18$$,$cljs$cst$5798$on_context_menu$$);return $APP.$cljs$core$truth_$$($frame$jscomp$74_map__80281_props_80280$$)?
(0,$APP.$rumext$v2$jsx$$)("g",{className:"measurement-gaps",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-shapes",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_rects$$,{frame:$frame$jscomp$74_map__80281_props_80280$$,zoom:$zoom$jscomp$70$$,"on-move-selected":$on_move_selected$jscomp$2$$,"on-context-menu":$map__80281__$1_on_context_menu$jscomp$18$$})})}):null};
$app$main$ui$flex_controls$margin$margin_display$$=function($map__80207_props_80206_selected_QMARK_$jscomp$23$$){$map__80207_props_80206_selected_QMARK_$jscomp$23$$=$APP.$rumext$v2$util$wrap_props$$($map__80207_props_80206_selected_QMARK_$jscomp$23$$);var $map__80207__$1_on_pointer_down$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($map__80207_props_80206_selected_QMARK_$jscomp$23$$),$hover_all_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,
$cljs$cst$5862$hover_all_QMARK_$$),$hover_h_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5863$hover_h_QMARK_$$),$on_change$jscomp$96$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$APP.$cljs$cst$4157$on_change$$);$map__80207_props_80206_selected_QMARK_$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$APP.$cljs$cst$5784$selected_QMARK_$$);
var $hover_QMARK_$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5580$hover_QMARK_$$),$margin$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$APP.$cljs$cst$1929$margin$$),$zoom$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$APP.$cljs$cst$2196$zoom$$),$on_pointer_leave$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,
$cljs$cst$5851$on_pointer_leave$$),$margin_num$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5864$margin_num$$),$on_pointer_enter$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5853$on_pointer_enter$$),$mouse_pos$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5854$mouse_pos$$),$hover_v_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5865$hover_v_QMARK_$$),$shape_id$jscomp$165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$APP.$cljs$cst$2543$shape_id$$),$hover_value$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,$cljs$cst$5856$hover_value$$),$rect_data$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80207__$1_on_pointer_down$jscomp$8$$,
$cljs$cst$5857$rect_data$$),$resizing_QMARK_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$start$jscomp$249$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$original_value$jscomp$1$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$last_pos$jscomp$3$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$negate_QMARK_$jscomp$4$$=$cljs$cst$5858$resize_negate_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$)===!0,
$axis$jscomp$40$$=$cljs$cst$5859$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$);$map__80207__$1_on_pointer_down$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$165$$),$APP.$rumext$v2$adapt$$($margin_num$$),$APP.$rumext$v2$adapt$$($margin$jscomp$6$$)],function($event$jscomp$635$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$635$$);$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$$,!0);$APP.$cljs$core$reset_BANG_$$($start$jscomp$249$$,
$APP.$app$util$dom$get_client_position$$($event$jscomp$635$$));return $APP.$cljs$core$reset_BANG_$$($original_value$jscomp$1$$,$cljs$cst$5860$initial_value$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$))});var $calc_modifiers$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$165$$),$APP.$rumext$v2$adapt$$($margin_num$$),$APP.$rumext$v2$adapt$$($margin$jscomp$6$$),$APP.$rumext$v2$adapt$$($hover_all_QMARK_$$),$APP.$rumext$v2$adapt$$($hover_v_QMARK_$$),
$APP.$rumext$v2$adapt$$($hover_h_QMARK_$$)],function($pos$jscomp$153$$){var $delta$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__80210$$=$APP.$app$common$geom$point$to_vec$$($APP.$cljs$core$_deref$$($start$jscomp$249$$),$pos$jscomp$153$$);return $negate_QMARK_$jscomp$4$$?$APP.$app$common$geom$point$negate$$($G__80210$$):$G__80210$$}(),$axis$jscomp$40$$),$val$jscomp$222$$=function(){var $x__5110__auto__$jscomp$150$$=$APP.$cljs$core$_deref$$($original_value$jscomp$1$$)+
$delta$jscomp$62$$/$zoom$jscomp$71$$;return $x__5110__auto__$jscomp$150$$>0?$x__5110__auto__$jscomp$150$$:0}()|0,$layout_item_margin$jscomp$6$$=$APP.$cljs$core$truth_$$($hover_all_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($margin$jscomp$6$$,$APP.$cljs$cst$1700$m1$$,$val$jscomp$222$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1701$m2$$,$val$jscomp$222$$,$APP.$cljs$cst$1702$m3$$,$val$jscomp$222$$,$APP.$cljs$cst$1703$m4$$,$val$jscomp$222$$])):
$APP.$cljs$core$truth_$$($hover_v_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($margin$jscomp$6$$,$APP.$cljs$cst$1700$m1$$,$val$jscomp$222$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1702$m3$$,$val$jscomp$222$$])):$APP.$cljs$core$truth_$$($hover_h_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($margin$jscomp$6$$,$APP.$cljs$cst$1701$m2$$,$val$jscomp$222$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1703$m4$$,
$val$jscomp$222$$])):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($margin$jscomp$6$$,$margin_num$$,$val$jscomp$222$$),$layout_item_margin_type$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$),$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$),
$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$)]))?$APP.$cljs$cst$1663$simple$$:$APP.$cljs$cst$1616$multiple$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val$jscomp$222$$,$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$165$$],null),$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),
$APP.$cljs$cst$1699$layout_item_margin$$,$layout_item_margin$jscomp$6$$),$APP.$cljs$cst$1698$layout_item_margin_type$$,$layout_item_margin_type$jscomp$2$$))],null)}),$on_lost_pointer_capture$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$1$$)],function($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$){$APP.$app$util$dom$release_pointer$$($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$);
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$=$APP.$cljs$core$_deref$$($last_pos$jscomp$3$$),$G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$=$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$):
$calc_modifiers$jscomp$1$$($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$,0,null),$G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$,1,null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($G__80214$jscomp$inline_9089_event$jscomp$636_modifiers_80246_vec__80211_80244$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()])));$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$$,!1);$APP.$cljs$core$reset_BANG_$$($start$jscomp$249$$,null);$APP.$cljs$core$reset_BANG_$$($original_value$jscomp$1$$,0);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),
$on_pointer_move$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$96$$)],function($event$jscomp$637_pos$jscomp$154_val$jscomp$223$$){$event$jscomp$637_pos$jscomp$154_val$jscomp$223$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$637_pos$jscomp$154_val$jscomp$223$$);$APP.$cljs$core$reset_BANG_$$($mouse_pos$jscomp$2$$,$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$637_pos$jscomp$154_val$jscomp$223$$));
$APP.$cljs$core$reset_BANG_$$($last_pos$jscomp$3$$,$event$jscomp$637_pos$jscomp$154_val$jscomp$223$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($resizing_QMARK_$$))){var $modifiers$jscomp$117_vec__80215$$=$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$637_pos$jscomp$154_val$jscomp$223$$):$calc_modifiers$jscomp$1$$($event$jscomp$637_pos$jscomp$154_val$jscomp$223$$);$event$jscomp$637_pos$jscomp$154_val$jscomp$223$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$117_vec__80215$$,0,null);$modifiers$jscomp$117_vec__80215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$117_vec__80215$$,1,null);$APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$3$$,$event$jscomp$637_pos$jscomp$154_val$jscomp$223$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modifiers$jscomp$117_vec__80215$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$117_vec__80215$$,!1,!1,null));return $APP.$cljs$core$truth_$$($on_change$jscomp$96$$)?$on_change$jscomp$96$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$96$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$117_vec__80215$$):$on_change$jscomp$96$$($modifiers$jscomp$117_vec__80215$$):null}return null});return(0,$APP.$rumext$v2$jsx$$)("rect",
{width:function(){var $y__5111__auto__$jscomp$151$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$);return 0>$y__5111__auto__$jscomp$151$$?0:$y__5111__auto__$jscomp$151$$}(),height:function(){var $y__5111__auto__$jscomp$152$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$);return 0>$y__5111__auto__$jscomp$152$$?0:$y__5111__auto__$jscomp$152$$}(),className:"margin-rect "+(($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$9$$)?
$hover_QMARK_$jscomp$9$$:$map__80207_props_80206_selected_QMARK_$jscomp$23$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5859$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),$APP.$cljs$cst$1510$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",90):null)??""),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$9$$)?
$hover_QMARK_$jscomp$9$$:$map__80207_props_80206_selected_QMARK_$jscomp$23$$)?"var(--status-color-warning-500)":"none",opacity:$APP.$cljs$core$truth_$$($map__80207_props_80206_selected_QMARK_$jscomp$23$$)?.5:.25},onLostPointerCapture:$on_lost_pointer_capture$jscomp$6$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),onPointerMove:$on_pointer_move$jscomp$7$$,onPointerDown:$map__80207__$1_on_pointer_down$jscomp$8$$,onPointerLeave:$on_pointer_leave$jscomp$9$$,onPointerEnter:$on_pointer_enter$jscomp$9$$})};
$app$main$ui$flex_controls$margin$margin_rects$$=function($frame$jscomp$75_map__80220_margin_display_data_props_80218$$){function $hover_QMARK_$jscomp$10$$($value$jscomp$997$$){if($APP.$cljs$core$truth_$$($hover_all_QMARK_$jscomp$1$$))return $hover_all_QMARK_$jscomp$1$$;var $or__5025__auto____$1$jscomp$138_or__5025__auto____$2$jscomp$32$$=function(){var $and__5023__auto__$jscomp$893$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$997$$,$APP.$cljs$cst$1700$m1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$997$$,
$APP.$cljs$cst$1702$m3$$);return $and__5023__auto__$jscomp$893$$?$hover_v_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$893$$}();if($APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$138_or__5025__auto____$2$jscomp$32$$))return $or__5025__auto____$1$jscomp$138_or__5025__auto____$2$jscomp$32$$;$or__5025__auto____$1$jscomp$138_or__5025__auto____$2$jscomp$32$$=function(){var $and__5023__auto__$jscomp$894$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$997$$,$APP.$cljs$cst$1701$m2$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$997$$,$APP.$cljs$cst$1703$m4$$);return $and__5023__auto__$jscomp$894$$?$hover_h_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$894$$}();return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$138_or__5025__auto____$2$jscomp$32$$)?$or__5025__auto____$1$jscomp$138_or__5025__auto____$2$jscomp$32$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$value$jscomp$997$$)}$frame$jscomp$75_map__80220_margin_display_data_props_80218$$=
$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$);var $map__80220__$1_pill_width$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$),$map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80220__$1_pill_width$jscomp$1$$,$APP.$cljs$cst$1811$shape$$);$frame$jscomp$75_map__80220_margin_display_data_props_80218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80220__$1_pill_width$jscomp$1$$,
$APP.$cljs$cst$1606$frame$$);var $zoom$jscomp$72$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80220__$1_pill_width$jscomp$1$$,$APP.$cljs$cst$2196$zoom$$),$alt_QMARK_$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80220__$1_pill_width$jscomp$1$$,$APP.$cljs$cst$4204$alt_QMARK_$$),$shift_QMARK_$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80220__$1_pill_width$jscomp$1$$,$APP.$cljs$cst$4203$shift_QMARK_$$),$shape_id$jscomp$166$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$);
$map__80220__$1_pill_width$jscomp$1$$=40/$zoom$jscomp$72$$;var $pill_height$jscomp$1$$=20/$zoom$jscomp$72$$,$margins_selected$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_margins_selected$$),$current_modifiers$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$=$APP.$app$common$types$modifiers$apply_structure_modifiers$$($map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($current_modifiers$jscomp$2$$),$shape_id$jscomp$166$$),$APP.$cljs$cst$1810$modifiers$$));var $hover_value$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$mouse_pos$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_all_QMARK_$jscomp$1$$=
function(){var $and__5023__auto__$jscomp$890$$=$APP.$cljs$core$_deref$$($hover$jscomp$3$$)!=null;return $and__5023__auto__$jscomp$890$$?$alt_QMARK_$jscomp$13$$:$and__5023__auto__$jscomp$890$$}(),$hover_v_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$891$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1700$m1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1702$m3$$);
return $and__5023__auto__$jscomp$891$$?$shift_QMARK_$jscomp$32$$:$and__5023__auto__$jscomp$891$$}(),$hover_h_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$892$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1701$m2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1703$m4$$);return $and__5023__auto__$jscomp$892$$?$shift_QMARK_$jscomp$32$$:$and__5023__auto__$jscomp$892$$}(),
$margin$jscomp$7$$=$APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$);$map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$);var $map__80221__$1_y2$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$);
$map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80221__$1_y2$jscomp$40$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80221__$1_y2$jscomp$40$$,$APP.$cljs$cst$1522$height$$),$x1$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80221__$1_y2$jscomp$40$$,$APP.$cljs$cst$1523$x1$$),$x2$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80221__$1_y2$jscomp$40$$,
$APP.$cljs$cst$1525$x2$$),$y1$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80221__$1_y2$jscomp$40$$,$APP.$cljs$cst$1524$y1$$);$map__80221__$1_y2$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80221__$1_y2$jscomp$40$$,$APP.$cljs$cst$1526$y2$$);var $on_pointer_enter$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($hover_type$jscomp$1$$,$val$jscomp$224$$){$APP.$cljs$core$reset_BANG_$$($hover$jscomp$3$$,$hover_type$jscomp$1$$);
return $APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$4$$,$val$jscomp$224$$)}),$on_pointer_leave$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($hover$jscomp$3$$,null)}),$on_change$jscomp$97$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers$jscomp$118$$){return $APP.$cljs$core$reset_BANG_$$($current_modifiers$jscomp$2$$,$modifiers$jscomp$118$$)});$frame$jscomp$75_map__80220_margin_display_data_props_80218$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1700$m1$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$))?
$map__80221__$1_y2$jscomp$40$$:$y1$jscomp$43$$-$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$166$$),"-m1"].join(""),$map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$,$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),
$x1$jscomp$41$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$)]),$APP.$cljs$cst$1701$m2$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$y1$jscomp$43$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$),
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$166$$),"-m2"].join(""),$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$))?$x1$jscomp$41$$-$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$):$x2$jscomp$38$$,
$APP.$cljs$cst$1510$x$$,$height$jscomp$179$$]),$APP.$cljs$cst$1702$m3$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$))?
$y1$jscomp$43$$-$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$):$map__80221__$1_y2$jscomp$40$$,$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$166$$),"-m3"].join(""),$map__80221_shape$jscomp$1042_shape__$1$jscomp$110_width$jscomp$211$$,$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),
$x1$jscomp$41$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$)]),$APP.$cljs$cst$1703$m4$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$y1$jscomp$43$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$),
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$166$$),"-m4"].join(""),$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$75_map__80220_margin_display_data_props_80218$$))?$x2$jscomp$38$$:$x1$jscomp$41$$-$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),
$APP.$cljs$cst$1510$x$$,$height$jscomp$179$$])],null);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"margins",pointerEvents:"visible",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$202$$,$p__80226_rect_data$jscomp$2$$){var $margin_num$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80226_rect_data$jscomp$2$$,0,null);$p__80226_rect_data$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80226_rect_data$jscomp$2$$,
1,null);$out_arr__44124__auto__$jscomp$202$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_display$$,{zoom:$zoom$jscomp$72$$,"on-pointer-leave":$on_pointer_leave$jscomp$10$$,"margin-num":$margin_num$jscomp$1$$,"mouse-pos":$mouse_pos$jscomp$3$$,"on-pointer-enter":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_pointer_enter$jscomp$10$$,$margin_num$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin$jscomp$7$$,$margin_num$jscomp$1$$)),
"hover-v?":$hover_v_QMARK_$jscomp$1$$,"shape-id":$shape_id$jscomp$166$$,"hover-value":$hover_value$jscomp$4$$,"rect-data":$p__80226_rect_data$jscomp$2$$,"hover-all?":$hover_all_QMARK_$jscomp$1$$,"hover-h?":$hover_h_QMARK_$jscomp$1$$,"on-change":$on_change$jscomp$97$$,"selected?":$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margins_selected$jscomp$2$$,$margin_num$jscomp$1$$),"hover?":$hover_QMARK_$jscomp$10$$($margin_num$jscomp$1$$),margin:$margin$jscomp$7$$},$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($p__80226_rect_data$jscomp$2$$)));
return $out_arr__44124__auto__$jscomp$202$$},[],$frame$jscomp$75_map__80220_margin_display_data_props_80218$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover$jscomp$3$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$common$flex_display_pill$$,{height:$pill_height$jscomp$1$$,width:$map__80220__$1_pill_width$jscomp$1$$,"font-size":11/$zoom$jscomp$72$$,"border-radius":4/$zoom$jscomp$72$$,color:"var(--status-color-warning-500)",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$3$$)),
y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$3$$))-$map__80220__$1_pill_width$jscomp$1$$,value:$APP.$cljs$core$_deref$$($hover_value$jscomp$4$$)}):null]})};
$app$main$ui$flex_controls$margin$margin_control$$=function($map__80234_props_80233_shape$jscomp$1043$$){$map__80234_props_80233_shape$jscomp$1043$$=$APP.$rumext$v2$util$wrap_props$$($map__80234_props_80233_shape$jscomp$1043$$);var $map__80234__$1_shift_QMARK_$jscomp$33$$=$APP.$cljs$core$__destructure_map$$($map__80234_props_80233_shape$jscomp$1043$$);$map__80234_props_80233_shape$jscomp$1043$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80234__$1_shift_QMARK_$jscomp$33$$,$APP.$cljs$cst$1811$shape$$);
var $parent$jscomp$300$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80234__$1_shift_QMARK_$jscomp$33$$,$APP.$cljs$cst$1365$parent$$),$zoom$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80234__$1_shift_QMARK_$jscomp$33$$,$APP.$cljs$cst$2196$zoom$$),$alt_QMARK_$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80234__$1_shift_QMARK_$jscomp$33$$,$APP.$cljs$cst$4204$alt_QMARK_$$);$map__80234__$1_shift_QMARK_$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80234__$1_shift_QMARK_$jscomp$33$$,
$APP.$cljs$cst$4203$shift_QMARK_$$);return $APP.$cljs$core$truth_$$($map__80234_props_80233_shape$jscomp$1043$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"measurement-gaps",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-shapes",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_rects$$,{shape:$map__80234_props_80233_shape$jscomp$1043$$,frame:$parent$jscomp$300$$,zoom:$zoom$jscomp$73$$,"alt?":$alt_QMARK_$jscomp$14$$,"shift?":$map__80234__$1_shift_QMARK_$jscomp$33$$})})}):
null};
$app$main$ui$flex_controls$padding$padding_display$$=function($map__80236_map__80236__$1_props_80235$$){$map__80236_map__80236__$1_props_80235$$=$APP.$rumext$v2$util$wrap_props$$($map__80236_map__80236__$1_props_80235$$);$map__80236_map__80236__$1_props_80235$$=$APP.$cljs$core$__destructure_map$$($map__80236_map__80236__$1_props_80235$$);var $hover_all_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5862$hover_all_QMARK_$$),$hover_h_QMARK_$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5863$hover_h_QMARK_$$),$on_change$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$APP.$cljs$cst$4157$on_change$$),$selected_QMARK_$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$APP.$cljs$cst$5784$selected_QMARK_$$),$hover_QMARK_$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,
$cljs$cst$5580$hover_QMARK_$$),$zoom$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$APP.$cljs$cst$2196$zoom$$),$on_pointer_leave$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5851$on_pointer_leave$$),$on_pointer_enter$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5853$on_pointer_enter$$),$mouse_pos$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5854$mouse_pos$$),$hover_v_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5865$hover_v_QMARK_$$),$padding_num$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5866$padding_num$$),$on_context_menu$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,
$cljs$cst$5798$on_context_menu$$),$on_move_selected$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5855$on_move_selected$$),$hover_value$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5856$hover_value$$),$padding$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$APP.$cljs$cst$256$padding$$),$rect_data$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$cljs$cst$5857$rect_data$$),$frame_id$jscomp$146$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236_map__80236__$1_props_80235$$,$APP.$cljs$cst$1607$frame_id$$),$resizing_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$start$jscomp$250$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$original_value$jscomp$2$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(0),
$last_pos$jscomp$4$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$negate_QMARK_$jscomp$5$$=$cljs$cst$5858$resize_negate_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)===!0,$axis$jscomp$41$$=$cljs$cst$5859$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),$on_pointer_down$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$146$$),$APP.$rumext$v2$adapt$$($rect_data$jscomp$3$$),$APP.$rumext$v2$adapt$$($padding_num$$)],
function($event$jscomp$638$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$638$$);$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$jscomp$1$$,!0);$APP.$cljs$core$reset_BANG_$$($start$jscomp$250$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$638$$));return $APP.$cljs$core$reset_BANG_$$($original_value$jscomp$2$$,$cljs$cst$5860$initial_value$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$))}),$calc_modifiers$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$146$$),
$APP.$rumext$v2$adapt$$($padding_num$$),$APP.$rumext$v2$adapt$$($padding$jscomp$12$$),$APP.$rumext$v2$adapt$$($hover_all_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($hover_v_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($hover_h_QMARK_$jscomp$2$$)],function($pos$jscomp$155$$){var $delta$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__80237$$=$APP.$app$common$geom$point$to_vec$$($APP.$cljs$core$_deref$$($start$jscomp$250$$),$pos$jscomp$155$$);return $negate_QMARK_$jscomp$5$$?
$APP.$app$common$geom$point$negate$$($G__80237$$):$G__80237$$}(),$axis$jscomp$41$$),$val$jscomp$225$$=function(){var $x__5110__auto__$jscomp$153$$=$APP.$cljs$core$_deref$$($original_value$jscomp$2$$)+$delta$jscomp$63$$/$zoom$jscomp$74$$;return $x__5110__auto__$jscomp$153$$>0?$x__5110__auto__$jscomp$153$$:0}()|0,$layout_padding$jscomp$11$$=$APP.$cljs$core$truth_$$($hover_all_QMARK_$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($padding$jscomp$12$$,$APP.$cljs$cst$1093$p1$$,
$val$jscomp$225$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1091$p2$$,$val$jscomp$225$$,$APP.$cljs$cst$1687$p3$$,$val$jscomp$225$$,$APP.$cljs$cst$1688$p4$$,$val$jscomp$225$$])):$APP.$cljs$core$truth_$$($hover_v_QMARK_$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($padding$jscomp$12$$,$APP.$cljs$cst$1093$p1$$,$val$jscomp$225$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1687$p3$$,$val$jscomp$225$$])):
$APP.$cljs$core$truth_$$($hover_h_QMARK_$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($padding$jscomp$12$$,$APP.$cljs$cst$1091$p2$$,$val$jscomp$225$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1688$p4$$,$val$jscomp$225$$])):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$12$$,$padding_num$$,$val$jscomp$225$$),$layout_padding_type$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$),
$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$),$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$)]))?$APP.$cljs$cst$1663$simple$$:$APP.$cljs$cst$1616$multiple$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val$jscomp$225$$,$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$146$$],null),$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1686$layout_padding$$,$layout_padding$jscomp$11$$),$APP.$cljs$cst$1685$layout_padding_type$$,$layout_padding_type$jscomp$4$$))],null)}),$on_lost_pointer_capture$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$2$$)],
function($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$){$APP.$app$util$dom$release_pointer$$($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$=$APP.$cljs$core$_deref$$($last_pos$jscomp$4$$),$G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$=
$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$):$calc_modifiers$jscomp$2$$($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$,0,null),$G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$,1,null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($G__80250$jscomp$inline_9091_event$jscomp$639_modifiers_80279_vec__80247_80277$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()])));$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$jscomp$1$$,
!1);$APP.$cljs$core$reset_BANG_$$($start$jscomp$250$$,null);$APP.$cljs$core$reset_BANG_$$($original_value$jscomp$2$$,0);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),$on_pointer_move$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$2$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$98$$)],function($event$jscomp$640_pos$jscomp$156_val$jscomp$226$$){$event$jscomp$640_pos$jscomp$156_val$jscomp$226$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$640_pos$jscomp$156_val$jscomp$226$$);$APP.$cljs$core$reset_BANG_$$($mouse_pos$jscomp$4$$,$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$640_pos$jscomp$156_val$jscomp$226$$));$APP.$cljs$core$reset_BANG_$$($last_pos$jscomp$4$$,$event$jscomp$640_pos$jscomp$156_val$jscomp$226$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($resizing_QMARK_$jscomp$1$$))){var $modifiers$jscomp$119_vec__80251$$=$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$640_pos$jscomp$156_val$jscomp$226$$):$calc_modifiers$jscomp$2$$($event$jscomp$640_pos$jscomp$156_val$jscomp$226$$);$event$jscomp$640_pos$jscomp$156_val$jscomp$226$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$119_vec__80251$$,
0,null);$modifiers$jscomp$119_vec__80251$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$119_vec__80251$$,1,null);$APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$5$$,$event$jscomp$640_pos$jscomp$156_val$jscomp$226$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modifiers$jscomp$119_vec__80251$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$119_vec__80251$$,!1,!1,null));return $APP.$cljs$core$truth_$$($on_change$jscomp$98$$)?$on_change$jscomp$98$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$98$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$119_vec__80251$$):$on_change$jscomp$98$$($modifiers$jscomp$119_vec__80251$$):null}return null});return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"padding-rect",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{width:function(){var $y__5111__auto__$jscomp$154$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$);return 0>$y__5111__auto__$jscomp$154$$?0:$y__5111__auto__$jscomp$154$$}(),height:function(){var $y__5111__auto__$jscomp$155$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$);return 0>$y__5111__auto__$jscomp$155$$?0:$y__5111__auto__$jscomp$155$$}(),className:"info-area",
x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),onContextMenu:$on_context_menu$jscomp$19$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$11$$)?$hover_QMARK_$jscomp$11$$:$selected_QMARK_$jscomp$24$$)?"var(--color-accent-quaternary)":"none",opacity:$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$24$$)?.5:.25},y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),onPointerMove:$on_pointer_move$jscomp$8$$,
onPointerDown:$on_move_selected$jscomp$3$$,onPointerLeave:$on_pointer_leave$jscomp$11$$,onPointerEnter:$on_pointer_enter$jscomp$11$$}),function(){var $handle_width$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$41$$,$APP.$cljs$cst$1510$x$$)?2/$zoom$jscomp$74$$:function(){var $x__5113__auto__$jscomp$85$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)*.5,$y__5114__auto__$jscomp$85$$=20/$zoom$jscomp$74$$;return $x__5113__auto__$jscomp$85$$<
$y__5114__auto__$jscomp$85$$?$x__5113__auto__$jscomp$85$$:$y__5114__auto__$jscomp$85$$}(),$handle_height$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$41$$,$APP.$cljs$cst$1511$y$$)?2/$zoom$jscomp$74$$:function(){var $x__5113__auto__$jscomp$86$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)*.5,$y__5114__auto__$jscomp$86$$=30/$zoom$jscomp$74$$;return $x__5113__auto__$jscomp$86$$<$y__5114__auto__$jscomp$86$$?$x__5113__auto__$jscomp$86$$:
$y__5114__auto__$jscomp$86$$}();return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$handle_width$jscomp$1$$,height:$handle_height$jscomp$1$$,className:"handle "+(($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$11$$)?$hover_QMARK_$jscomp$11$$:$selected_QMARK_$jscomp$24$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5859$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),$APP.$cljs$cst$1510$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",
0):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",90):null)??""),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)-$handle_width$jscomp$1$$)/2,onContextMenu:$on_context_menu$jscomp$19$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$11$$)?$hover_QMARK_$jscomp$11$$:$selected_QMARK_$jscomp$24$$)?"var(--color-accent-quaternary)":"none",opacity:$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$24$$)?
0:1},onLostPointerCapture:$on_lost_pointer_capture$jscomp$7$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)-$handle_height$jscomp$1$$)/2,onPointerMove:$on_pointer_move$jscomp$8$$,onPointerDown:$on_pointer_down$jscomp$9$$,onPointerLeave:$on_pointer_leave$jscomp$11$$,onPointerEnter:$on_pointer_enter$jscomp$11$$})}()]})};
$app$main$ui$flex_controls$padding$padding_rects$$=function($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$){function $hover_QMARK_$jscomp$12$$($value$jscomp$998$$){if($APP.$cljs$core$truth_$$($hover_all_QMARK_$jscomp$3$$))return $hover_all_QMARK_$jscomp$3$$;var $or__5025__auto____$1$jscomp$139_or__5025__auto____$2$jscomp$33$$=function(){var $and__5023__auto__$jscomp$898$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$998$$,$APP.$cljs$cst$1093$p1$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$998$$,$APP.$cljs$cst$1687$p3$$);return $and__5023__auto__$jscomp$898$$?$hover_v_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$898$$}();if($APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$139_or__5025__auto____$2$jscomp$33$$))return $or__5025__auto____$1$jscomp$139_or__5025__auto____$2$jscomp$33$$;$or__5025__auto____$1$jscomp$139_or__5025__auto____$2$jscomp$33$$=function(){var $and__5023__auto__$jscomp$899$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$998$$,
$APP.$cljs$cst$1091$p2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$998$$,$APP.$cljs$cst$1688$p4$$);return $and__5023__auto__$jscomp$899$$?$hover_h_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$899$$}();return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$139_or__5025__auto____$2$jscomp$33$$)?$or__5025__auto____$1$jscomp$139_or__5025__auto____$2$jscomp$33$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$value$jscomp$998$$)}
$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$=$APP.$rumext$v2$util$wrap_props$$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$);$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$=$APP.$cljs$core$__destructure_map$$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$);var $frame$jscomp$76_height$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,
$APP.$cljs$cst$1606$frame$$),$zoom$jscomp$75$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,$APP.$cljs$cst$2196$zoom$$),$alt_QMARK_$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,$APP.$cljs$cst$4204$alt_QMARK_$$),$shift_QMARK_$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,
$APP.$cljs$cst$4203$shift_QMARK_$$),$on_move_selected$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,$cljs$cst$5855$on_move_selected$$),$on_context_menu$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,$cljs$cst$5798$on_context_menu$$),$frame_id$jscomp$147$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$76_height$jscomp$180$$),
$paddings_selected$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_paddings_selected$$),$current_modifiers$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame__$1$jscomp$7$$=$APP.$app$common$types$modifiers$apply_structure_modifiers$$($frame$jscomp$76_height$jscomp$180$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($current_modifiers$jscomp$3$$),$frame_id$jscomp$147$$),
$APP.$cljs$cst$1810$modifiers$$)),$hover_value$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$mouse_pos$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_all_QMARK_$jscomp$3$$=function(){var $and__5023__auto__$jscomp$895$$=$APP.$cljs$core$_deref$$($hover$jscomp$4$$)!=null;return $and__5023__auto__$jscomp$895$$?$alt_QMARK_$jscomp$15$$:$and__5023__auto__$jscomp$895$$}(),
$hover_v_QMARK_$jscomp$3$$=function(){var $and__5023__auto__$jscomp$896$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1093$p1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1687$p3$$);return $and__5023__auto__$jscomp$896$$?$shift_QMARK_$jscomp$34$$:$and__5023__auto__$jscomp$896$$}(),$hover_h_QMARK_$jscomp$3$$=function(){var $and__5023__auto__$jscomp$897$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),
$APP.$cljs$cst$1091$p2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1688$p4$$);return $and__5023__auto__$jscomp$897$$?$shift_QMARK_$jscomp$34$$:$and__5023__auto__$jscomp$897$$}(),$padding$jscomp$13$$=$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$);$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$);
var $map__80259__$1_pill_width$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$);$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80259__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$290$width$$);$frame$jscomp$76_height$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80259__$1_pill_width$jscomp$2$$,
$APP.$cljs$cst$1522$height$$);var $x1$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80259__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$1523$x1$$),$x2$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80259__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$1525$x2$$),$y1$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80259__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$1524$y1$$),$y2$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80259__$1_pill_width$jscomp$2$$,
$APP.$cljs$cst$1526$y2$$);$map__80259__$1_pill_width$jscomp$2$$=40/$zoom$jscomp$75$$;var $pill_height$jscomp$2$$=20/$zoom$jscomp$75$$,$negate$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?!0:!1,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?!0:!1,$APP.$cljs$cst$1687$p3$$,
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?!0:!1,$APP.$cljs$cst$1688$p4$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?!0:!1],null),$negate__$1$$=function(){var $G__80260__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($negate$jscomp$1$$,
$APP.$cljs$cst$1091$p2$$,$APP.$cljs$core$not$$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($negate$jscomp$1$$))):$negate$jscomp$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80260__$1$$,$APP.$cljs$cst$1687$p3$$,$APP.$cljs$core$not$$($APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($negate$jscomp$1$$))):
$G__80260__$1$$}();$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?
$y2$jscomp$41$$-$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$):$y1$jscomp$44$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?$APP.$cljs$cst$1563$bottom$$:$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$147$$),"-p1"].join(""),$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,
$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$x1$jscomp$42$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$)]),$APP.$cljs$cst$1091$p2$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],
[$y1$jscomp$44$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$147$$),"-p2"].join(""),$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?$x1$jscomp$42$$:$x2$jscomp$39$$-
$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1510$x$$,$frame$jscomp$76_height$jscomp$180$$]),$APP.$cljs$cst$1687$p3$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?
$y1$jscomp$44$$:$y2$jscomp$41$$-$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$147$$),"-p3"].join(""),$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$,$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$x1$jscomp$42$$,$APP.$cljs$cst$1511$y$$,
$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$)]),$APP.$cljs$cst$1688$p4$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$5861$resize_type$$,$cljs$cst$5858$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5860$initial_value$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$5859$resize_axis$$,$APP.$cljs$cst$1522$height$$],[$y1$jscomp$44$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?
$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$147$$),"-p4"].join(""),$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$))?$x2$jscomp$39$$-
$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$):$x1$jscomp$42$$,$APP.$cljs$cst$1510$x$$,$frame$jscomp$76_height$jscomp$180$$])],null);var $on_pointer_enter$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($hover_type$jscomp$2$$,$val$jscomp$227$$){$APP.$cljs$core$reset_BANG_$$($hover$jscomp$4$$,$hover_type$jscomp$2$$);return $APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$6$$,$val$jscomp$227$$)}),$on_pointer_leave$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($hover$jscomp$4$$,
null)}),$on_change$jscomp$99$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers$jscomp$120$$){return $APP.$cljs$core$reset_BANG_$$($current_modifiers$jscomp$3$$,$modifiers$jscomp$120$$)});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"paddings",pointerEvents:"visible",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$203$$,$p__80266_rect_data$jscomp$4$$){var $padding_num$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80266_rect_data$jscomp$4$$,
0,null);$p__80266_rect_data$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80266_rect_data$jscomp$4$$,1,null);$out_arr__44124__auto__$jscomp$203$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_display$$,{zoom:$zoom$jscomp$75$$,"on-pointer-leave":$on_pointer_leave$jscomp$12$$,"mouse-pos":$mouse_pos$jscomp$5$$,"on-pointer-enter":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_pointer_enter$jscomp$12$$,$padding_num$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding$jscomp$13$$,
$padding_num$jscomp$1$$)),"hover-v?":$hover_v_QMARK_$jscomp$3$$,"padding-num":$padding_num$jscomp$1$$,"on-context-menu":$on_context_menu$jscomp$20$$,"on-move-selected":$on_move_selected$jscomp$4$$,"hover-value":$hover_value$jscomp$6$$,padding:$padding$jscomp$13$$,"rect-data":$p__80266_rect_data$jscomp$4$$,"frame-id":$frame_id$jscomp$147$$,"hover-all?":$hover_all_QMARK_$jscomp$3$$,"hover-h?":$hover_h_QMARK_$jscomp$3$$,"on-change":$on_change$jscomp$99$$,"selected?":$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($paddings_selected$jscomp$2$$,
$padding_num$jscomp$1$$),"hover?":$hover_QMARK_$jscomp$12$$($padding_num$jscomp$1$$)},$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($p__80266_rect_data$jscomp$4$$)));return $out_arr__44124__auto__$jscomp$203$$},[],$map__80258_map__80258__$1_map__80259_padding_rect_data_props_80257_width$jscomp$212$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$common$flex_display_pill$$,{height:$pill_height$jscomp$2$$,width:$map__80259__$1_pill_width$jscomp$2$$,
"font-size":11/$zoom$jscomp$75$$,"border-radius":4/$zoom$jscomp$75$$,color:"var(--color-accent-quaternary)",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$5$$)),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$5$$))-$map__80259__$1_pill_width$jscomp$2$$,value:$APP.$cljs$core$_deref$$($hover_value$jscomp$6$$)}):null]})};
$app$main$ui$flex_controls$padding$padding_control$$=function($frame$jscomp$77_map__80272_props_80271$$){$frame$jscomp$77_map__80272_props_80271$$=$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$77_map__80272_props_80271$$);var $map__80272__$1_on_context_menu$jscomp$21$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$77_map__80272_props_80271$$);$frame$jscomp$77_map__80272_props_80271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80272__$1_on_context_menu$jscomp$21$$,$APP.$cljs$cst$1606$frame$$);
var $zoom$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80272__$1_on_context_menu$jscomp$21$$,$APP.$cljs$cst$2196$zoom$$),$alt_QMARK_$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80272__$1_on_context_menu$jscomp$21$$,$APP.$cljs$cst$4204$alt_QMARK_$$),$shift_QMARK_$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80272__$1_on_context_menu$jscomp$21$$,$APP.$cljs$cst$4203$shift_QMARK_$$),$on_move_selected$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80272__$1_on_context_menu$jscomp$21$$,
$cljs$cst$5855$on_move_selected$$);$map__80272__$1_on_context_menu$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80272__$1_on_context_menu$jscomp$21$$,$cljs$cst$5798$on_context_menu$$);return $APP.$cljs$core$truth_$$($frame$jscomp$77_map__80272_props_80271$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"measurement-gaps",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-shapes",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_rects$$,
{frame:$frame$jscomp$77_map__80272_props_80271$$,zoom:$zoom$jscomp$76$$,"alt?":$alt_QMARK_$jscomp$16$$,"shift?":$shift_QMARK_$jscomp$35$$,"on-move-selected":$on_move_selected$jscomp$5$$,"on-context-menu":$map__80272__$1_on_context_menu$jscomp$21$$})})}):null};
$app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$=function($props_80286_x$jscomp$1268$$){var $is_last$$=$props_80286_x$jscomp$1268$$.isLast,$edit_mode_is_active$jscomp$6$$=$props_80286_x$jscomp$1268$$.editMode,$is_new$jscomp$2$$=$props_80286_x$jscomp$1268$$.isNew,$zoom$jscomp$77$$=$props_80286_x$jscomp$1268$$.zoom,$is_selected$jscomp$8$$=$props_80286_x$jscomp$1268$$.isSelected,$is_start_path$$=$props_80286_x$jscomp$1268$$.isStartPath,$is_curve$$=$props_80286_x$jscomp$1268$$.isCurve,$is_preview$$=
$props_80286_x$jscomp$1268$$.isPreview,$is_hover_on_enter$jscomp$2$$=$props_80286_x$jscomp$1268$$.isHover,$position$jscomp$205$$=$props_80286_x$jscomp$1268$$.position,$map__80287__$1_y$jscomp$490$$=$APP.$cljs$core$__destructure_map$$($position$jscomp$205$$);$props_80286_x$jscomp$1268$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80287__$1_y$jscomp$490$$,$APP.$cljs$cst$1510$x$$);$map__80287__$1_y$jscomp$490$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80287__$1_y$jscomp$490$$,
$APP.$cljs$cst$1511$y$$);var $is_draw$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode_is_active$jscomp$6$$,$APP.$cljs$cst$4224$draw$$),$is_move$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode_is_active$jscomp$6$$,$APP.$cljs$cst$1798$move$$);$edit_mode_is_active$jscomp$6$$=$is_selected$jscomp$8$$||$is_hover_on_enter$jscomp$2$$;$is_hover_on_enter$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_pointer_enter$$($position$jscomp$205$$))});
var $on_leave$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_pointer_leave$$($position$jscomp$205$$))});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"path-point",children:[(0,$APP.$rumext$v2$jsx$$)("circle",{className:"path-point",cx:$props_80286_x$jscomp$1268$$,cy:$map__80287__$1_y$jscomp$490$$,r:$edit_mode_is_active$jscomp$6$$?5/$zoom$jscomp$77$$:
4/$zoom$jscomp$77$$,style:{strokeWidth:1/$zoom$jscomp$77$$,stroke:$edit_mode_is_active$jscomp$6$$?"var(--app-black)":$is_preview$$?"var(--color-accent-quaternary)":"var(--color-accent-tertiary)",fill:$APP.$cljs$core$truth_$$($is_selected$jscomp$8$$)?"var(--color-accent-tertiary)":"var(--app-white)"}}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$map__80287__$1_y$jscomp$490$$,className:$is_draw$$?$APP.$app$main$ui$css_cursors$get_static$$("pen-node"):$is_move$$?$APP.$app$main$ui$css_cursors$get_static$$("pointer-node"):
null,style:{strokeWidth:0,fill:"none"},r:15/$zoom$jscomp$77$$,onPointerDown:function($event$jscomp$641_is_mod$$){if($app$util$dom$left_mouse_QMARK_$$($event$jscomp$641_is_mod$$)){$APP.$app$util$dom$stop_propagation$$($event$jscomp$641_is_mod$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$641_is_mod$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_new$jscomp$2$$)?$APP.$cljs$core$meta$$($position$jscomp$205$$)!=null:$is_new$jscomp$2$$)){var $JSCompiler_temp_const$jscomp$11005_is_shift$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$11007_param70014$jscomp$inline_13698$$=$APP.$cljs$core$meta$$($position$jscomp$205$$);$JSCompiler_inline_result$jscomp$11007_param70014$jscomp$inline_13698$$=$app$main$data$workspace$path$edition$create_node_at_position$$($JSCompiler_inline_result$jscomp$11007_param70014$jscomp$inline_13698$$);$JSCompiler_temp_const$jscomp$11005_is_shift$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$11007_param70014$jscomp$inline_13698$$)}$JSCompiler_temp_const$jscomp$11005_is_shift$$=
$event$jscomp$641_is_mod$$.shiftKey;$event$jscomp$641_is_mod$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$641_is_mod$$);return $APP.$cljs$core$truth_$$($is_last$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$drawing$reset_last_handler$$()):$is_move$$&&$event$jscomp$641_is_mod$$&&$APP.$cljs$core$not$$($is_curve$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$205$$)):
$APP.$cljs$core$truth_$$($is_move$$?$event$jscomp$641_is_mod$$?$is_curve$$:$event$jscomp$641_is_mod$$:$is_move$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$205$$)):$is_move$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$start_move_path_point$$($position$jscomp$205$$,$JSCompiler_temp_const$jscomp$11005_is_shift$$)):$APP.$cljs$core$truth_$$($is_draw$$?
$is_start_path$$:$is_draw$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$drawing$start_path_from_point$$($position$jscomp$205$$)):$is_draw$$&&$APP.$cljs$core$not$$($is_start_path$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$drawing$close_path_drag_start$$($position$jscomp$205$$)):null}return null},onPointerLeave:$on_leave$jscomp$2$$,cx:$props_80286_x$jscomp$1268$$,onPointerEnter:$is_hover_on_enter$jscomp$2$$,
pointerEvents:$is_preview$$?null:"visible"})]})};
$app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$=function($point$jscomp$80_props_80288$$){var $handler$jscomp$47_y$jscomp$491$$=$point$jscomp$80_props_80288$$.handler,$edit_mode$jscomp$1_is_active$jscomp$7$$=$point$jscomp$80_props_80288$$.editMode,$zoom$jscomp$78$$=$point$jscomp$80_props_80288$$.zoom,$index$jscomp$561$$=$point$jscomp$80_props_80288$$.index,$is_selected$jscomp$9$$=$point$jscomp$80_props_80288$$.isSelected,$prefix$jscomp$71$$=$point$jscomp$80_props_80288$$.prefix,$is_hover$jscomp$1$$=
$point$jscomp$80_props_80288$$.isHover,$snap_angle$$=$point$jscomp$80_props_80288$$.snapAngle;$point$jscomp$80_props_80288$$=$point$jscomp$80_props_80288$$.point;var $x$jscomp$1269$$=$handler$jscomp$47_y$jscomp$491$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$47_y$jscomp$491$$,$APP.$cljs$cst$1510$x$$);$handler$jscomp$47_y$jscomp$491$$=$handler$jscomp$47_y$jscomp$491$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$47_y$jscomp$491$$,$APP.$cljs$cst$1511$y$$);
var $is_draw$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$1_is_active$jscomp$7$$,$APP.$cljs$cst$4224$draw$$),$is_move$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$1_is_active$jscomp$7$$,$APP.$cljs$cst$1798$move$$);$edit_mode$jscomp$1_is_active$jscomp$7$$=$is_selected$jscomp$9$$||$is_hover$jscomp$1$$;var $on_enter$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$561$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$71$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_handler_enter$$($index$jscomp$561$$,$prefix$jscomp$71$$))}),$on_leave$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$561$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$71$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_handler_leave$$($index$jscomp$561$$,
$prefix$jscomp$71$$))}),$on_pointer_down$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$561$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$71$$),$APP.$rumext$v2$adapt$$($is_move$jscomp$1$$)],function($event$jscomp$642$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$642$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$642$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$642$$),$is_move$jscomp$1$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$start_move_handler$$($index$jscomp$561$$,
$prefix$jscomp$71$$)):null):null});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"handler",pointerEvents:$is_draw$jscomp$1$$?"none":"visible",children:[(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80288$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80288$$),x2:$x$jscomp$1269$$,y2:$handler$jscomp$47_y$jscomp$491$$,style:{stroke:$is_hover$jscomp$1$$?"var(--app-black)":"var(--df-secondary)",
strokeWidth:1/$zoom$jscomp$78$$}}),$snap_angle$$?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80288$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80288$$),x2:$x$jscomp$1269$$,y2:$handler$jscomp$47_y$jscomp$491$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:1/$zoom$jscomp$78$$}}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1269$$-3/$zoom$jscomp$78$$,y:$handler$jscomp$47_y$jscomp$491$$-
3/$zoom$jscomp$78$$,width:6/$zoom$jscomp$78$$,height:6/$zoom$jscomp$78$$,style:{strokeWidth:1/$zoom$jscomp$78$$,stroke:$edit_mode$jscomp$1_is_active$jscomp$7$$?"var(--app-black)":"var(--color-accent-tertiary)",fill:$is_selected$jscomp$9$$?"var(--color-accent-tertiary)":"var(--app-white)"}}),(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$x$jscomp$1269$$,cy:$handler$jscomp$47_y$jscomp$491$$,r:15/$zoom$jscomp$78$$,onPointerDown:$on_pointer_down$jscomp$11$$,onPointerEnter:$on_enter$jscomp$3$$,onPointerLeave:$on_leave$jscomp$3$$,
style:{fill:"none",strokeWidth:0},className:$is_move$jscomp$1$$?$APP.$app$main$ui$css_cursors$get_static$$("pointer-move"):null})]})};
$app$main$ui$workspace$shapes$path$editor$path_preview_STAR_$$=function($path$jscomp$297_props_80289$$){var $zoom$jscomp$79$$=$path$jscomp$297_props_80289$$.zoom,$from$jscomp$30$$=$path$jscomp$297_props_80289$$.from,$segment$jscomp$59$$=$path$jscomp$297_props_80289$$.segment;$path$jscomp$297_props_80289$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$59$$))?function(){var $segments__$1$jscomp$4$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1430$params$$,$from$jscomp$30$$],null)],null),$segment$jscomp$59$$);return $APP.$app$common$types$path$impl$path_data$$($segments__$1$jscomp$4$$)}():null;var $position$jscomp$206$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($segment$jscomp$59$$)],
function(){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$59$$))});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"preview",style:{pointerEvents:"none"},children:[$path$jscomp$297_props_80289$$!=null?(0,$APP.$rumext$v2$jsx$$)("path",{style:{fill:"none",stroke:"var(--app-black)",strokeWidth:1/$zoom$jscomp$79$$,strokeDasharray:4/$zoom$jscomp$79$$},d:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$297_props_80289$$)}):
null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,{position:$position$jscomp$206$$,isPreview:!0,zoom:$zoom$jscomp$79$$})]})};
$app$main$ui$workspace$shapes$path$editor$path_snap_STAR_$$=function($matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$){var $zoom$jscomp$80$$=$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$.zoom,$selected$jscomp$187$$=$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$.selected,$points$jscomp$101$$=$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$.points;$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$187$$),
$APP.$rumext$v2$adapt$$($points$jscomp$101$$)],function(){return $APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$101$$,$selected$jscomp$187$$)});$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$=$APP.$app$main$snap$get_snap_delta_match$$($selected$jscomp$187$$,$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$,1/$zoom$jscomp$80$$);$matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$)),
$APP.$cljs$core$second$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$)));return(0,$APP.$rumext$v2$jsx$$)("g",{className:"snap-paths",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$204$$,$from$jscomp$31_p__80291$$){var $idx$jscomp$130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from$jscomp$31_p__80291$$,0,null),$to$jscomp$27_vec__80295$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from$jscomp$31_p__80291$$,
1,null);$from$jscomp$31_p__80291$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$27_vec__80295$$,0,null);$to$jscomp$27_vec__80295$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$27_vec__80295$$,1,null);$out_arr__44124__auto__$jscomp$204$$.push((0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$31_p__80291$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$31_p__80291$$),x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$27_vec__80295$$),
y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$27_vec__80295$$),style:{stroke:"var(--color-accent-quaternary)",strokeWidth:1/$zoom$jscomp$80$$}},"snap-"+($idx$jscomp$130$$??"")+"-"+($from$jscomp$31_p__80291$$??"")+"-"+($to$jscomp$27_vec__80295$$??"")));return $out_arr__44124__auto__$jscomp$204$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($matches$jscomp$11_props_80290_ranges$jscomp$9_snap_matches$$))})};
$app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$=function($editor_ref_props_80307$$){var $zoom$jscomp$81$$=$editor_ref_props_80307$$.zoom,$prev_handler$jscomp$6_state$jscomp$1209$$=$editor_ref_props_80307$$.state,$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$=$editor_ref_props_80307$$.shape,$hover_point$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$editor_ref_props_80307$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $map__80308__$1_show_snap_QMARK_$$=
$APP.$cljs$core$__destructure_map$$($prev_handler$jscomp$6_state$jscomp$1209$$);$prev_handler$jscomp$6_state$jscomp$1209$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3554$prev_handler$$);var $edit_mode$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4223$edit_mode$$),$moving_handler$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,
$APP.$cljs$cst$4249$moving_handler$$),$hover_points$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4235$hover_points$$),$snap_toggled$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4202$snap_toggled$$),$moving_nodes$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4251$moving_nodes$$),$hover_handlers$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,
$APP.$cljs$cst$4238$hover_handlers$$),$last_point$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3553$last_point$$),$selected_points$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4241$selected_points$$),$content_modifiers$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$1924$content_modifiers$$),$preview$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3556$preview$$),$drag_handler$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80308__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3555$drag_handler$$),$selected_points__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($selected_points$jscomp$7$$)?$selected_points$jscomp$7$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$base_content$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$,
$APP.$cljs$cst$1637$content$$);$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_content$jscomp$1$$)],function(){return $APP.$app$common$types$path$get_points$$($base_content$jscomp$1$$)});var $content$jscomp$255$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_content$jscomp$1$$),$APP.$rumext$v2$adapt$$($content_modifiers$jscomp$5$$)],function(){return $APP.$app$common$types$path$apply_content_modifiers$$($base_content$jscomp$1$$,
$content_modifiers$jscomp$5$$)}),$content_points$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$255$$)],function(){return $APP.$app$common$types$path$get_points$$($content$jscomp$255$$)}),$point__GT_base$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$hash_map$$,$content_points$$,$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$)),
$base__GT_point$$=$APP.$clojure$set$map_invert$$($point__GT_base$$),$points$jscomp$102$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content_points$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$content_points$$)});$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($content$jscomp$255$$));
var $handlers$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$255$$)],function(){return $app$common$types$path$get_handlers$$($content$jscomp$255$$)}),$is_path_start$$=$last_point$jscomp$4$$==null;$map__80308__$1_show_snap_QMARK_$$=function(){if($snap_toggled$jscomp$3$$){var $or__5025__auto__$jscomp$1298_or__5025__auto____$1$jscomp$140_or__5025__auto____$2$jscomp$34$$=$drag_handler$$!=null;return $or__5025__auto__$jscomp$1298_or__5025__auto____$1$jscomp$140_or__5025__auto____$2$jscomp$34$$||
($or__5025__auto__$jscomp$1298_or__5025__auto____$1$jscomp$140_or__5025__auto____$2$jscomp$34$$=$preview$jscomp$5$$!=null)?$or__5025__auto__$jscomp$1298_or__5025__auto____$1$jscomp$140_or__5025__auto____$2$jscomp$34$$:($or__5025__auto__$jscomp$1298_or__5025__auto____$1$jscomp$140_or__5025__auto____$2$jscomp$34$$=$moving_handler$$!=null)?$or__5025__auto__$jscomp$1298_or__5025__auto____$1$jscomp$140_or__5025__auto____$2$jscomp$34$$:$moving_nodes$$}return $snap_toggled$jscomp$3$$}();$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edit_mode$jscomp$2$$)],
function(){var $key$jscomp$417$$=$APP.$goog$events$listen$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$document$$,"#app"),"dblclick",function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$2$$,$APP.$cljs$cst$1798$move$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2169$interrupt$$):null});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$417$$)}});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$streams$mouse_position$$,
[$APP.$rumext$v2$adapt$$($base_content$jscomp$1$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$81$$)],function($position$jscomp$207$$){var $precision$jscomp$inline_9095_temp__5825__auto__$jscomp$415$$=.01/$zoom$jscomp$81$$;var $content__$1$jscomp$inline_9096$$=$APP.$app$common$types$path$impl$path_data$$($base_content$jscomp$1$$);$precision$jscomp$inline_9095_temp__5825__auto__$jscomp$415$$=$APP.$cljs$core$count$$($content__$1$jscomp$inline_9096$$)>0?$app$common$types$path$segment$closest_point$$($content__$1$jscomp$inline_9096$$,
$position$jscomp$207$$,$precision$jscomp$inline_9095_temp__5825__auto__$jscomp$415$$):null;return $APP.$cljs$core$truth_$$($precision$jscomp$inline_9095_temp__5825__auto__$jscomp$415$$)?$APP.$cljs$core$reset_BANG_$$($hover_point$$,$APP.$app$common$geom$point$distance$$($position$jscomp$207$$,$precision$jscomp$inline_9095_temp__5825__auto__$jscomp$415$$)<10/$zoom$jscomp$81$$?$precision$jscomp$inline_9095_temp__5825__auto__$jscomp$415$$:null):null});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"path-editor",
ref:$editor_ref_props_80307$$,children:[(0,$APP.$rumext$v2$jsx$$)("path",{d:$content$jscomp$255$$.toString(),style:{fill:"none",stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$81$$}}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($preview$jscomp$5$$)?$APP.$cljs$core$not$$($drag_handler$$):$preview$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_preview_STAR_$$,{segment:$preview$jscomp$5$$,from:$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$,
zoom:$zoom$jscomp$81$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($drag_handler$$)?$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$:$drag_handler$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"drag-handler",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,{point:$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$,handler:$drag_handler$$,editMode:$edit_mode$jscomp$2$$,zoom:$zoom$jscomp$81$$})}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover_point$$))?
(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-point",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,{position:$APP.$cljs$core$_deref$$($hover_point$$),editMode:$edit_mode$jscomp$2$$,isNew:!0,isStartPath:$is_path_start$$,zoom:$zoom$jscomp$81$$})}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$205$$,$position$jscomp$208$$){$out_arr__44124__auto__$jscomp$205$$.push(function(){var $pos_x$jscomp$5$$=
$position$jscomp$208$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$208$$,$APP.$cljs$cst$1510$x$$),$pos_y$jscomp$5$$=$position$jscomp$208$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$208$$,$APP.$cljs$cst$1511$y$$),$position_handlers$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80309_prefix$jscomp$72$$){var $handler_position$jscomp$1_index$jscomp$562$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80309_prefix$jscomp$72$$,
0,null);$p__80309_prefix$jscomp$72$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80309_prefix$jscomp$72$$,1,null);$handler_position$jscomp$1_index$jscomp$562$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,$handler_position$jscomp$1_index$jscomp$562$$,$p__80309_prefix$jscomp$72$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$208$$,$handler_position$jscomp$1_index$jscomp$562$$)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handlers$jscomp$7$$,
$position$jscomp$208$$))),$point_selected_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($selected_points__$1$jscomp$3$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_base$$,$position$jscomp$208$$)),$point_hover_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($hover_points$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_base$$,$position$jscomp$208$$)),$is_last$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_point$jscomp$4$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_base$$,
$position$jscomp$208$$)),$is_curve$jscomp$1$$=$APP.$cljs$core$boolean$0$$($position_handlers$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"path-node",children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"point-handlers",pointerEvents:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$2$$,$APP.$cljs$cst$4224$draw$$)?"none":null,children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$21$$,$JSCompiler_temp_const$jscomp$11039_p__80313$$){var $JSCompiler_inline_result$jscomp$11041_hindex$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11039_p__80313$$,0,null),$prefix$jscomp$73$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11039_p__80313$$,1,null);$JSCompiler_temp_const$jscomp$11039_p__80313$$=$out_arr__44124__auto____$1$jscomp$21$$.push;var $handler_position$jscomp$inline_13700$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,$JSCompiler_inline_result$jscomp$11041_hindex$$,$prefix$jscomp$73$$),
$handler_hover_QMARK_$jscomp$inline_13701$$=$APP.$cljs$core$contains_QMARK_$$($hover_handlers$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$11041_hindex$$,$prefix$jscomp$73$$],null)),$moving_handler_QMARK_$jscomp$inline_13702$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler_position$jscomp$inline_13700$$,$moving_handler$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($position_handlers$$))){var $i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($position_handlers$$,0,null);var $i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$,0,null);var $p1$jscomp$inline_14693$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$,
1,null),$p2$jscomp$inline_14696_vec__80304$jscomp$inline_14694$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($position_handlers$$,1,null);$i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$inline_14696_vec__80304$jscomp$inline_14694$$,0,null);$p2$jscomp$inline_14696_vec__80304$jscomp$inline_14694$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$inline_14696_vec__80304$jscomp$inline_14694$$,
1,null);$i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,$i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$,$p1$jscomp$inline_14693$$);$i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,
$i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$,$p2$jscomp$inline_14696_vec__80304$jscomp$inline_14694$$);$i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$=$APP.$app$common$geom$point$subtract$$($i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$,$position$jscomp$208$$);$i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$=
$APP.$app$common$geom$point$subtract$$($i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$,$position$jscomp$208$$);$i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$=180-$APP.$app$common$geom$point$angle_with_other$$($i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$,$i2$jscomp$inline_14695_p2__$1$jscomp$inline_14698_v2$jscomp$inline_14700_vec__80301$jscomp$inline_14691$$)<=
.1}else $i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$=null;$JSCompiler_inline_result$jscomp$11041_hindex$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($position$jscomp$208$$)?$handler_position$jscomp$inline_13700$$:$position$jscomp$208$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,{editMode:$edit_mode$jscomp$2$$,zoom:$zoom$jscomp$81$$,index:$JSCompiler_inline_result$jscomp$11041_hindex$$,
prefix:$prefix$jscomp$73$$,isHover:$handler_hover_QMARK_$jscomp$inline_13701$$,point:$position$jscomp$208$$,snapAngle:$moving_handler_QMARK_$jscomp$inline_13702$$?$i1$jscomp$inline_14692_matching_handler_QMARK_$jscomp$inline_13703_p1__$1$jscomp$inline_14697_v1$jscomp$inline_14699$$:$moving_handler_QMARK_$jscomp$inline_13702$$,handler:$handler_position$jscomp$inline_13700$$},""+($JSCompiler_inline_result$jscomp$11041_hindex$$??"")+"-"+($APP.$app$common$data$name$$($prefix$jscomp$73$$)??"")):null;$JSCompiler_temp_const$jscomp$11039_p__80313$$.call($out_arr__44124__auto____$1$jscomp$21$$,
$JSCompiler_inline_result$jscomp$11041_hindex$$);return $out_arr__44124__auto____$1$jscomp$21$$},[],$position_handlers$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,{position:$position$jscomp$208$$,zoom:$zoom$jscomp$81$$,editMode:$edit_mode$jscomp$2$$,isSelected:$point_selected_QMARK_$$,isHover:$point_hover_QMARK_$$,isLast:$is_last$jscomp$1$$,isStartPath:$is_path_start$$,isCurve:$is_curve$jscomp$1$$})]},""+($pos_x$jscomp$5$$??"")+"-"+($pos_y$jscomp$5$$??
""))}());return $out_arr__44124__auto__$jscomp$205$$},[],$points$jscomp$102$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($prev_handler$jscomp$6_state$jscomp$1209$$)?$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$:$prev_handler$jscomp$6_state$jscomp$1209$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"prev-handler",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,{point:$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1044$$,
editMode:$edit_mode$jscomp$2$$,handler:$prev_handler$jscomp$6_state$jscomp$1209$$,zoom:$zoom$jscomp$81$$})}):null,$map__80308__$1_show_snap_QMARK_$$?function(){var $snap_points$jscomp$1_vec__80317$$=$drag_handler$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$drag_handler$$]),$points$jscomp$102$$],null):$preview$jscomp$5$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($preview$jscomp$5$$)]),$points$jscomp$102$$],null):$moving_handler$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$moving_handler$$]),$points$jscomp$102$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($base__GT_point$$,$selected_points__$1$jscomp$3$$)),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($selected_points__$1$jscomp$3$$,$points$jscomp$102$$))],null),$snap_selected$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($snap_points$jscomp$1_vec__80317$$,
0,null);$snap_points$jscomp$1_vec__80317$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($snap_points$jscomp$1_vec__80317$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"path-snap",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_snap_STAR_$$,{selected:$snap_selected$$,points:$snap_points$jscomp$1_vec__80317$$,zoom:$zoom$jscomp$81$$})})}():null]})};
$app$main$ui$workspace$shapes$text$editor$block_component$$=function($props_80320$$){var $bprops_style$jscomp$77$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80320$$,"blockProps"),$data$jscomp$499_dir$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($bprops_style$jscomp$77$$,"data");$bprops_style$jscomp$77$$=$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($bprops_style$jscomp$77$$,
"data"));$data$jscomp$499_dir$jscomp$9$$=$APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$499_dir$jscomp$9$$,"auto");return(0,$APP.$rumext$v2$jsx$$)("div",{style:$bprops_style$jscomp$77$$,dir:$data$jscomp$499_dir$jscomp$9$$,children:(0,$APP.$rumext$v2$create_element$$)($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.EditorBlock,$props_80320$$)})};
$app$main$ui$workspace$shapes$text$editor$styles_fn$$=function($shape$jscomp$1046$$,$data$jscomp$500_styles$jscomp$29$$,$content$jscomp$256$$){$data$jscomp$500_styles$jscomp$29$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$256$$.getText(),"")?$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($content$jscomp$256$$.getData().toJS(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0])):$APP.$app$common$text$styles_to_attrs$$($data$jscomp$500_styles$jscomp$29$$);
return $APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$1046$$,$data$jscomp$500_styles$jscomp$29$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2685$show_text_QMARK_$$,!1],null))};
$app$main$ui$workspace$shapes$text$editor$get_blocks_to_setup$$=function($block_changes$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80323_v$jscomp$683$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80323_v$jscomp$683$$,0,null);$p__80323_v$jscomp$683$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80323_v$jscomp$683$$,1,null);return $APP.$cljs$cst$4000$old$$.$cljs$core$IFn$_invoke$arity$1$($p__80323_v$jscomp$683$$)==
null},$block_changes$$))};
$app$main$ui$workspace$shapes$text$editor$get_blocks_to_add_styles$$=function($block_changes$jscomp$1$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80327_v$jscomp$684$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80327_v$jscomp$684$$,0,null);$p__80327_v$jscomp$684$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80327_v$jscomp$684$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4000$old$$.$cljs$core$IFn$_invoke$arity$1$($p__80327_v$jscomp$684$$),
$APP.$cljs$cst$4001$new$$.$cljs$core$IFn$_invoke$arity$1$($p__80327_v$jscomp$684$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4000$old$$.$cljs$core$IFn$_invoke$arity$1$($p__80327_v$jscomp$684$$),"")},$block_changes$jscomp$1$$))};
$app$main$ui$workspace$shapes$text$editor$shape__GT_justify$$=function($content$jscomp$257_map__80332__$1_p__80331$$){$content$jscomp$257_map__80332__$1_p__80331$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$257_map__80332__$1_p__80331$$);$content$jscomp$257_map__80332__$1_p__80331$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$257_map__80332__$1_p__80331$$,$APP.$cljs$cst$1637$content$$);switch($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$257_map__80332__$1_p__80331$$),
"top")){case "center":return"center";case "top":return"flex-start";case "bottom":return"flex-end";default:return null}};
$app$main$ui$workspace$shapes$text$editor$text_editor_svg$$=function($clip_id$jscomp$2_props_80359$$){var $modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$=$clip_id$jscomp$2_props_80359$$.modifiers,$shape$jscomp$1048$$=$clip_id$jscomp$2_props_80359$$.shape,$shape_id$jscomp$167$$=$shape$jscomp$1048$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1048$$,$APP.$cljs$cst$266$id$$),$modifiers__$1$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$,
$shape_id$jscomp$167$$),$APP.$cljs$cst$1810$modifiers$$);$clip_id$jscomp$2_props_80359$$="text-edition-clip"+($shape_id$jscomp$167$$??"");$modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$167$$)],function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($shape_id$jscomp$167$$)});var $text_modifier$jscomp$4$$=$APP.$rumext$v2$deref$$($modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$),
$maybe_zoom$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1347$safari_16$$)?$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$):null,$shape__$1$jscomp$112$$=function(){var $G__80360__$1$$=$text_modifier$jscomp$4$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($shape$jscomp$1048$$,$text_modifier$jscomp$4$$):$shape$jscomp$1048$$;return $modifiers__$1$jscomp$17$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__80360__$1$$,
$modifiers__$1$jscomp$17$$):$G__80360__$1$$}(),$bounds$jscomp$84_height$jscomp$181$$=$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape__$1$jscomp$112$$),$x$jscomp$1270$$=Math.min($bounds$jscomp$84_height$jscomp$181$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$84_height$jscomp$181$$,$APP.$cljs$cst$1510$x$$),$shape__$1$jscomp$112$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1510$x$$)),$y$jscomp$492$$=Math.min($bounds$jscomp$84_height$jscomp$181$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$84_height$jscomp$181$$,$APP.$cljs$cst$1511$y$$),$shape__$1$jscomp$112$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1511$y$$));$modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$=Math.max($bounds$jscomp$84_height$jscomp$181$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$84_height$jscomp$181$$,$APP.$cljs$cst$290$width$$),$shape__$1$jscomp$112$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$290$width$$));$bounds$jscomp$84_height$jscomp$181$$=Math.max($bounds$jscomp$84_height$jscomp$181$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$84_height$jscomp$181$$,$APP.$cljs$cst$1522$height$$),$shape__$1$jscomp$112$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1522$height$$));var $style$jscomp$78$$=function(){var $G__80361_G__80361__$1_G__80361__$2$$=
{pointerEvents:"all"};$G__80361_G__80361__$1_G__80361__$2$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$)?$G__80361_G__80361__$1_G__80361__$2$$:$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80361_G__80361__$1_G__80361__$2$$,{transform:"translate("+(($shape__$1$jscomp$112$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1510$x$$))-$x$jscomp$1270$$)+"px, "+(($shape__$1$jscomp$112$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,
$APP.$cljs$cst$1511$y$$))-$y$jscomp$492$$)+"px)"});$G__80361_G__80361__$1_G__80361__$2$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1352$safari_17$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80361_G__80361__$1_G__80361__$2$$,{height:"100%",display:"flex",flexDirection:"column",justifyContent:$app$main$ui$workspace$shapes$text$editor$shape__GT_justify$$($shape__$1$jscomp$112$$)}):$G__80361_G__80361__$1_G__80361__$2$$;return $APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1347$safari_16$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80361_G__80361__$1_G__80361__$2$$,{position:"fixed",left:0,top:($shape__$1$jscomp$112$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1511$y$$))-$y$jscomp$492$$,"transform-origin":"top left",transform:$maybe_zoom$$!=null?"scale("+($maybe_zoom$$??"")+")":null}):$G__80361_G__80361__$1_G__80361__$2$$}();return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"text-editor",clipPath:"url(#"+
($clip_id$jscomp$2_props_80359$$??"")+")",transform:""+($APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$112$$)??""),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$2_props_80359$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1270$$,y:$y$jscomp$492$$,width:$modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$,height:$bounds$jscomp$84_height$jscomp$181$$})})}),(0,$APP.$rumext$v2$jsx$$)("foreignObject",
{x:$x$jscomp$1270$$,y:$y$jscomp$492$$,width:$modifiers$jscomp$121_text_modifier_ref$jscomp$2_width$jscomp$213$$,height:$bounds$jscomp$84_height$jscomp$181$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{style:$style$jscomp$78$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$editor$text_shape_edit_html$$,{shape:$shape__$1$jscomp$112$$},""+($shape_id$jscomp$167$$??""))})})]})};
$app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$=function($props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$){var $zoom$jscomp$83$$=$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$.zoom,$modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$=$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$.modifiers,
$shape$jscomp$1049$$=$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$.shape;if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")){$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$=
$app$main$data$helpers$get_selrect$$($props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$,$shape$jscomp$1049$$);var $selrect$jscomp$82$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$,0,null);$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$,
1,null);var $sr_height$jscomp$4_vec__80340_y$jscomp$493$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1299$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$82$$),.01);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1299$$)?$or__5025__auto__$jscomp$1299$$:$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$82$$),
.01)}())?function(){var $map__80343_width$jscomp$215$$=$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1049$$)),$height$jscomp$183_map__80343__$1$$=$APP.$cljs$core$__destructure_map$$($map__80343_width$jscomp$215$$);$map__80343_width$jscomp$215$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$183_map__80343__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$183_map__80343__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$183_map__80343__$1$$,$APP.$cljs$cst$1522$height$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__80343_width$jscomp$215$$,$height$jscomp$183_map__80343__$1$$],null)}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$82$$),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$82$$)],
null);$modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sr_height$jscomp$4_vec__80340_y$jscomp$493$$,0,null);$sr_height$jscomp$4_vec__80340_y$jscomp$493$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sr_height$jscomp$4_vec__80340_y$jscomp$493$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main viewport-selrect",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$82$$),
y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$82$$),width:$modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$,height:$sr_height$jscomp$4_vec__80340_y$jscomp$493$$,transform:$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$,style:{stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$83$$,fill:"none"}})}var $modifiers__$1$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1049$$),$APP.$cljs$cst$1810$modifiers$$],null));$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1049$$))],function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1049$$))});
var $text_modifier$jscomp$5$$=$APP.$rumext$v2$deref$$($props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$);$modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$=function(){var $G__80347__$1$$=$modifiers__$1$jscomp$18$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1049$$,$modifiers__$1$jscomp$18$$):$shape$jscomp$1049$$;return $text_modifier$jscomp$5$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($G__80347__$1$$,
$text_modifier$jscomp$5$$):$G__80347__$1$$}();$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$);var $height$jscomp$182_map__80345__$1$$=$APP.$cljs$core$__destructure_map$$($modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$);$modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$182_map__80345__$1$$,$APP.$cljs$cst$1510$x$$);$sr_height$jscomp$4_vec__80340_y$jscomp$493$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$182_map__80345__$1$$,$APP.$cljs$cst$1511$y$$);var $width$jscomp$214$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$182_map__80345__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$182_map__80345__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$182_map__80345__$1$$,
$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main viewport-selrect",x:$modifiers$jscomp$122_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1271$$,y:$sr_height$jscomp$4_vec__80340_y$jscomp$493$$,width:$width$jscomp$214$$,height:$height$jscomp$182_map__80345__$1$$,transform:$props_80336_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$107_vec__80337$$,style:{stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$83$$,fill:"none"}})};
$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$=function($JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$){if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$)){var $b$jscomp$inline_9118_vec__45417$jscomp$inline_9115$$=$APP.$app$common$types$color$hex__GT_rgb$$($JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$);$JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_9118_vec__45417$jscomp$inline_9115$$,0,null);var $g$jscomp$inline_9117$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_9118_vec__45417$jscomp$inline_9115$$,1,null);$b$jscomp$inline_9118_vec__45417$jscomp$inline_9115$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_9118_vec__45417$jscomp$inline_9115$$,2,null);$JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$=
Math.sqrt(.241*$JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$+.691*$g$jscomp$inline_9117$$+.068*$b$jscomp$inline_9118_vec__45417$jscomp$inline_9115$$)>.5?"#000000":"#ffffff"}else $JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$=null;return $JSCompiler_temp$jscomp$1519_background_color$jscomp$1_r$jscomp$inline_9116$$};
$app$main$ui$workspace$shapes$text$v2_editor$coalesce_per_tick$$=function($f$jscomp$864$$){var $scheduled_QMARK__STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);return function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($scheduled_QMARK__STAR_$$)))return null;$APP.$cljs$core$reset_BANG_$$($scheduled_QMARK__STAR_$$,!0);return $APP.$app$util$timers$asap$$(function(){$APP.$cljs$core$reset_BANG_$$($scheduled_QMARK__STAR_$$,!1);return $f$jscomp$864$$.$cljs$core$IFn$_invoke$arity$0$?
$f$jscomp$864$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$864$$()})}};
$app$main$ui$workspace$shapes$text$v2_editor$load_fonts_BANG_$$=function($fonts$jscomp$36$$){return $APP.$cljs$core$run_BANG_$$(function($p__80352_variant_id$jscomp$53$$){var $font_id$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80352_variant_id$jscomp$53$$,0,null);$p__80352_variant_id$jscomp$53$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80352_variant_id$jscomp$53$$,1,null);return $font_id$jscomp$37$$!=null?$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$37$$,
$p__80352_variant_id$jscomp$53$$):null},$fonts$jscomp$36$$)};
$app$main$ui$workspace$shapes$text$v2_editor$initialize_event_handlers$$=function($shape_id$jscomp$168$$,$content$jscomp$260$$,$editor_node_editor_ref$jscomp$1$$,$canvas_node$jscomp$1_canvas_ref$jscomp$2$$,$container_ref$jscomp$3$$,$text_color$jscomp$2$$){function $on_clipboard_change$$($event$jscomp$648$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_clipboard_style$$($event$jscomp$648$$.detail))}function $on_change$jscomp$101$$(){var $is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$=
(0,$APP.$app$main$data$workspace$texts$is_empty_QMARK_$$)($instance$jscomp$13$$);$is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$=$APP.$cljs$core$not$$($is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$);var $temp__5825__auto__$jscomp$418$$=$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($instance$jscomp$13$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$418$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape_id$jscomp$168$$,
$temp__5825__auto__$jscomp$418$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4017$update_name_QMARK_$$,!0,$APP.$cljs$cst$3140$save_undo_QMARK_$$,$is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$]))):null}function $on_style_change$jscomp$2$$($event$jscomp$647_styles$jscomp$30$$){$event$jscomp$647_styles$jscomp$30$$=$APP.$app$util$text$content$styles$get_styles_from_style_declaration$$($event$jscomp$647_styles$jscomp$30$$.detail);var $fill_color$jscomp$3_fills$jscomp$32$$=
$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$647_styles$jscomp$30$$);$fill_color$jscomp$3_fills$jscomp$32$$=$APP.$cljs$core$sequential_QMARK_$$($fill_color$jscomp$3_fills$jscomp$32$$)?$APP.$cljs$core$some$$($APP.$cljs$cst$1746$fill_color$$,$fill_color$jscomp$3_fills$jscomp$32$$):null;var $temp__5825__auto___80417$$=$APP.$rumext$v2$ref_val$$($container_ref$jscomp$3$$);$APP.$cljs$core$truth_$$($temp__5825__auto___80417$$)&&$app$util$dom$set_style_BANG_$$($temp__5825__auto___80417$$,
"--text-editor-caret-color",$APP.$cljs$core$truth_$$($fill_color$jscomp$3_fills$jscomp$32$$)?$fill_color$jscomp$3_fills$jscomp$32$$:$text_color$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_editor_styles$$($shape_id$jscomp$168$$,$event$jscomp$647_styles$jscomp$30$$))}function $on_focus$jscomp$19$$(){return $app$util$dom$set_style_BANG_$$($APP.$rumext$v2$ref_val$$($container_ref$jscomp$3$$),"opacity",1)}function $on_key_up$jscomp$2$$($event$jscomp$646$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$646$$);
return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$646$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()])):null}$editor_node_editor_ref$jscomp$1$$=$APP.$rumext$v2$ref_val$$($editor_node_editor_ref$jscomp$1$$);$canvas_node$jscomp$1_canvas_ref$jscomp$2$$=$APP.$rumext$v2$ref_val$$($canvas_node$jscomp$1_canvas_ref$jscomp$2$$);
var $default_font$jscomp$1_options$jscomp$642$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$default_font$$);$default_font$jscomp$1_options$jscomp$642$$={styleDefaults:$app$util$text$content$styles$get_style_defaults$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,$text_color$jscomp$2$$,$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null)],null),$APP.$app$common$types$text$default_root_attrs$$,$default_font$jscomp$1_options$jscomp$642$$]))),allowHTMLPaste:$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2-html-paste")};var $instance$jscomp$13$$=(0,$APP.$app$main$data$workspace$texts$create_editor$$)($editor_node_editor_ref$jscomp$1$$,
$canvas_node$jscomp$1_canvas_ref$jscomp$2$$,$default_font$jscomp$1_options$jscomp$642$$),$on_needs_layout$$=$app$main$ui$workspace$shapes$text$v2_editor$coalesce_per_tick$$(function(){var $temp__5825__auto__$jscomp$417$$=$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($instance$jscomp$13$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$417$$)?$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$v2_sync_wasm_text_layout$$($shape_id$jscomp$168$$,$temp__5825__auto__$jscomp$417$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape_id$jscomp$168$$,$temp__5825__auto__$jscomp$417$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4017$update_name_QMARK_$$,
!0,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1]))):null});$APP.$app$util$globals$document$$.addEventListener("keyup",$on_key_up$jscomp$2$$);$instance$jscomp$13$$.addEventListener("focus",$on_focus$jscomp$19$$);$instance$jscomp$13$$.addEventListener("needslayout",$on_needs_layout$$);$instance$jscomp$13$$.addEventListener("stylechange",$on_style_change$jscomp$2$$);$instance$jscomp$13$$.addEventListener("change",$on_change$jscomp$101$$);$instance$jscomp$13$$.addEventListener("clipboardchange",$on_clipboard_change$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_editor$$($instance$jscomp$13$$));$content$jscomp$260$$!=null&&(0,$APP.$app$main$data$workspace$texts$set_editor_root_BANG_$$)($instance$jscomp$13$$,$app$util$text$content$to_dom$create_root$$($content$jscomp$260$$));$instance$jscomp$13$$!=null&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$focus_editor$$());return function(){var $temp__5825__auto___80407$jscomp$inline_9120$$=
$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($instance$jscomp$13$$));if($APP.$cljs$core$truth_$$($temp__5825__auto___80407$jscomp$inline_9120$$)){var $current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$);$current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$);$current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$,
$shape_id$jscomp$168$$);$current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$);if($instance$jscomp$13$$!=null){var $generated_name_80413$jscomp$inline_9125_result$jscomp$inline_13708$$=
$instance$jscomp$13$$.root.textContent;$generated_name_80413$jscomp$inline_9125_result$jscomp$inline_13708$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($generated_name_80413$jscomp$inline_9125_result$jscomp$inline_13708$$,"")?$generated_name_80413$jscomp$inline_9125_result$jscomp$inline_13708$$:null}else $generated_name_80413$jscomp$inline_9125_result$jscomp$inline_13708$$=null;$current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$=
$content$jscomp$260$$==null||$current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$!=null&&$content$jscomp$260$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$,$APP.$app$common$types$text$generate_shape_name$$($APP.$app$common$types$text$content__GT_text$$($content$jscomp$260$$)));
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape_id$jscomp$168$$,$temp__5825__auto___80407$jscomp$inline_9120$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4017$update_name_QMARK_$$,$current_name_80412$jscomp$inline_9124_objects_80410$jscomp$inline_9122_shape_80411$jscomp$inline_9123_state_80409$jscomp$inline_9121_update_name_QMARK__80414$jscomp$inline_9126$$,
$APP.$cljs$cst$725$name$$,$generated_name_80413$jscomp$inline_9125_result$jscomp$inline_13708$$,$APP.$cljs$cst$4044$finalize_QMARK_$$,!0,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!0,$APP.$cljs$cst$4042$original_content$$,$content$jscomp$260$$])))}$app$util$dom$set_style_BANG_$$($APP.$rumext$v2$ref_val$$($container_ref$jscomp$3$$),"opacity",0);$APP.$app$util$globals$document$$.removeEventListener("keyup",$on_key_up$jscomp$2$$);$instance$jscomp$13$$.removeEventListener("focus",$on_focus$jscomp$19$$);$instance$jscomp$13$$.removeEventListener("needslayout",
$on_needs_layout$$);$instance$jscomp$13$$.removeEventListener("stylechange",$on_style_change$jscomp$2$$);$instance$jscomp$13$$.removeEventListener("change",$on_change$jscomp$101$$);$instance$jscomp$13$$.removeEventListener("clipboardchange",$on_clipboard_change$$);(0,$APP.$app$main$data$workspace$texts$dispose_BANG_$$)($instance$jscomp$13$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_editor$$(null))}};
$app$main$ui$workspace$shapes$text$v2_editor$vertical_align_editor_classes$$=function($content$jscomp$261$$,$render_wasm_QMARK_$jscomp$3$$){return $APP.$cljs$core$truth_$$($render_wasm_QMARK_$jscomp$3$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!0,!1,!1],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$261$$,
"top"),"top"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$261$$),"center"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$261$$),"bottom")],null)};
$app$main$ui$workspace$shapes$text$v2_editor$get_color_from_content$$=function($content$jscomp$262_nodes$jscomp$45$$){function $get_color$$($node$jscomp$464$$){var $or__5025__auto__$jscomp$1302$$=$APP.$cljs$core$some$$($APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$464$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1302$$)?$or__5025__auto__$jscomp$1302$$:$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$464$$)}
$content$jscomp$262_nodes$jscomp$45$$=$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$content$jscomp$262_nodes$jscomp$45$$);var $or__5025__auto__$jscomp$1301$$=$APP.$cljs$core$some$$($get_color$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80362_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__80362_SHARP_$$,$APP.$cljs$cst$1588$text$$)},$content$jscomp$262_nodes$jscomp$45$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1301$$)?
$or__5025__auto__$jscomp$1301$$:$APP.$cljs$core$some$$($get_color$$,$content$jscomp$262_nodes$jscomp$45$$)};
$app$main$ui$workspace$shapes$text$v2_editor$get_default_text_color$$=function($fill_color$jscomp$4_frame$jscomp$78_p__80364$$){var $background_color$jscomp$2_map__80365__$1$$=$APP.$cljs$core$__destructure_map$$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$);$fill_color$jscomp$4_frame$jscomp$78_p__80364$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color$jscomp$2_map__80365__$1$$,$APP.$cljs$cst$1606$frame$$);$background_color$jscomp$2_map__80365__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color$jscomp$2_map__80365__$1$$,
$APP.$cljs$cst$3779$background_color$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$)?!$APP.$app$common$files$helpers$root_QMARK_$$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$)&&$APP.$cljs$core$seq$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$)):$fill_color$jscomp$4_frame$jscomp$78_p__80364$$)?($fill_color$jscomp$4_frame$jscomp$78_p__80364$$=$APP.$cljs$core$some$$(function($p1__80363_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($p1__80363_SHARP_$$))?
$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($p1__80363_SHARP_$$):null},$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$)),$APP.$cljs$core$truth_$$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$)?$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$($fill_color$jscomp$4_frame$jscomp$78_p__80364$$):$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$($background_color$jscomp$2_map__80365__$1$$)):
$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$($background_color$jscomp$2_map__80365__$1$$)};
$app$main$ui$workspace$shapes$text$v2_editor$shape__GT_justify$$=function($content$jscomp$264_map__80387__$1_p__80386$$){$content$jscomp$264_map__80387__$1_p__80386$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$264_map__80387__$1_p__80386$$);$content$jscomp$264_map__80387__$1_p__80386$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$264_map__80387__$1_p__80386$$,$APP.$cljs$cst$1637$content$$);switch($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$264_map__80387__$1_p__80386$$),
"top")){case "center":return"center";case "top":return"flex-start";case "bottom":return"flex-end";default:return null}};
$$jscomp$scope$m743970774$0$getRangeRects$$=function($node$jscomp$465$$,$start$jscomp$251$$,$end$jscomp$109$$){const $range$jscomp$17$$=$APP.$goog$global$$.document.createRange();$range$jscomp$17$$.setStart($node$jscomp$465$$,$start$jscomp$251$$);$range$jscomp$17$$.setEnd($node$jscomp$465$$,$end$jscomp$109$$);return[...$range$jscomp$17$$.getClientRects()].filter($r$jscomp$142$$=>$r$jscomp$142$$.width>0)};
$app$util$text_position_data$parse_text_nodes$$=function($parent$jscomp$301$$,$rects$jscomp$1_textNode$jscomp$1$$,$textAlign$$){const $content$jscomp$265$$=$rects$jscomp$1_textNode$jscomp$1$$.textContent,$textSize$$=$content$jscomp$265$$.length;let $from$jscomp$32$$=0,$to$jscomp$28$$=0,$current$jscomp$59$$="",$result$jscomp$379$$=[],$prevRect$$=null,$safeguard$$=!1;for(;$to$jscomp$28$$<$textSize$$;){const $rects$jscomp$2$$=$$jscomp$scope$m743970774$0$getRangeRects$$($rects$jscomp$1_textNode$jscomp$1$$,
$from$jscomp$32$$,$to$jscomp$28$$+1),$splitByWords$$=$textAlign$$=="justify"&&$content$jscomp$265$$[$to$jscomp$28$$].trim()=="";$rects$jscomp$2$$.length>1&&$safeguard$$?($from$jscomp$32$$++,$to$jscomp$28$$++,$safeguard$$=!1):$rects$jscomp$2$$.length>1||$splitByWords$$?($result$jscomp$379$$.push({node:$parent$jscomp$301$$,position:$prevRect$$,text:$current$jscomp$59$$}),$splitByWords$$&&$to$jscomp$28$$++,$from$jscomp$32$$=$to$jscomp$28$$,$current$jscomp$59$$="",$safeguard$$=!0):($prevRect$$=$rects$jscomp$2$$[0],
$current$jscomp$59$$+=$content$jscomp$265$$[$to$jscomp$28$$],$to$jscomp$28$$+=1,$safeguard$$=!1)}$rects$jscomp$1_textNode$jscomp$1$$=$$jscomp$scope$m743970774$0$getRangeRects$$($rects$jscomp$1_textNode$jscomp$1$$,$from$jscomp$32$$,$to$jscomp$28$$);$result$jscomp$379$$.push({node:$parent$jscomp$301$$,position:$rects$jscomp$1_textNode$jscomp$1$$[0],text:$current$jscomp$59$$});return $result$jscomp$379$$};
$app$util$text_svg_position$parse_text_nodes$$=function($parent_node$jscomp$2$$,$direction$jscomp$30$$,$text_node$jscomp$1$$,$text_align$jscomp$4$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($entry$jscomp$83$$){return $entry$jscomp$83$$.position!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3766$node$$,$entry$jscomp$83$$.node,$APP.$cljs$cst$1676$position$$,
$app$util$dom$bounding_rect__GT_rect$$($entry$jscomp$83$$.position),$APP.$cljs$cst$1588$text$$,$entry$jscomp$83$$.text,$APP.$cljs$cst$1963$direction$$,$direction$jscomp$30$$],null):null}),$app$util$text_position_data$parse_text_nodes$$($parent_node$jscomp$2$$,$text_node$jscomp$1$$,$text_align$jscomp$4$$))};
$app$util$text_svg_position$resolve_font$$=function($node$jscomp$466_styles$jscomp$31$$){$node$jscomp$466_styles$jscomp$31$$=getComputedStyle($node$jscomp$466_styles$jscomp$31$$);var $font$jscomp$53$$=$node$jscomp$466_styles$jscomp$31$$.getPropertyValue("font"),$font__$1$jscomp$3$$=$APP.$cljs$core$not$$($font$jscomp$53$$)||$APP.$cljs$core$empty_QMARK_$$($font$jscomp$53$$)?""+($node$jscomp$466_styles$jscomp$31$$.getPropertyValue("font-size")??"")+" "+($node$jscomp$466_styles$jscomp$31$$.getPropertyValue("font-family")??
""):$font$jscomp$53$$,$font_id$jscomp$39$$=$node$jscomp$466_styles$jscomp$31$$.getPropertyValue("--font-id");return $APP.$promesa$core$merr$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){console.error("Cannot load font "+($font_id$jscomp$39$$??""));return $APP.$promesa$impl$promise$resolved$$(null)},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){if($APP.$app$util$globals$document$$.fonts.check($font__$1$jscomp$3$$))var $JSCompiler_temp$jscomp$1884_load_promise$jscomp$inline_9136$$=
null;else $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($app$util$text_svg_position$load_promises$$),$font__$1$jscomp$3$$)?$JSCompiler_temp$jscomp$1884_load_promise$jscomp$inline_9136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$util$text_svg_position$load_promises$$),$font__$1$jscomp$3$$):($JSCompiler_temp$jscomp$1884_load_promise$jscomp$inline_9136$$=$APP.$app$util$globals$document$$.fonts.load($font__$1$jscomp$3$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$util$text_svg_position$load_promises$$,
$APP.$cljs$core$assoc$$,$font__$1$jscomp$3$$,$JSCompiler_temp$jscomp$1884_load_promise$jscomp$inline_9136$$));return $JSCompiler_temp$jscomp$1884_load_promise$jscomp$inline_9136$$},$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$39$$)))};
$app$util$text_svg_position$process_text_node$$=function($parent_node$jscomp$3$$){var $root$jscomp$68$$=$app$util$dom$get_parent_with_selector$$($parent_node$jscomp$3$$,".text-node-html"),$paragraph$jscomp$15$$=$app$util$dom$get_parent_with_selector$$($parent_node$jscomp$3$$,".paragraph"),$shape_x$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($root$jscomp$68$$,"data-x")),$shape_y$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($root$jscomp$68$$,
"data-y")),$direction$jscomp$31$$=getComputedStyle($parent_node$jscomp$3$$).direction,$text_align$jscomp$5$$=getComputedStyle($paragraph$jscomp$15$$).textAlign;return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80405_SHARP_$$){return $app$util$text_svg_position$parse_text_nodes$$($parent_node$jscomp$3$$,$direction$jscomp$31$$,$p1__80405_SHARP_$$,$text_align$jscomp$5$$)}),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80406_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($p1__80406_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1510$x$$],null),$APP.$cljs$core$_PLUS_$$,$shape_x$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1511$y$$],null),$APP.$cljs$core$_PLUS_$$,$shape_y$$)})),$APP.$cljs$core$seq$$($parent_node$jscomp$3$$.childNodes))};
$app$util$text_svg_position$calc_text_node_positions$$=function($shape_id$jscomp$171$$){var $text_nodes$$=$APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#html-text-node-"+($shape_id$jscomp$171$$??"")),".text-node");return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$util$text_svg_position$process_text_node$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$text_nodes$$]))},
$promesa$core$all$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$util$text_svg_position$resolve_font$$,$text_nodes$$)))};
$app$util$text_svg_position$calc_position_data$$=function($shape_id$jscomp$172$$){function $transform_data$$($p__80419_text$jscomp$148$$){var $direction$jscomp$32_map__80420__$1$$=$APP.$cljs$core$__destructure_map$$($p__80419_text$jscomp$148$$),$node$jscomp$467_styles$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80420__$1$$,$APP.$cljs$cst$3766$node$$),$position$jscomp$210_position__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80420__$1$$,
$APP.$cljs$cst$1676$position$$);$p__80419_text$jscomp$148$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80420__$1$$,$APP.$cljs$cst$1588$text$$);$direction$jscomp$32_map__80420__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80420__$1$$,$APP.$cljs$cst$1963$direction$$);$node$jscomp$467_styles$jscomp$33$$=getComputedStyle($node$jscomp$467_styles$jscomp$33$$);$position$jscomp$210_position__$1$jscomp$10$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($position$jscomp$210_position__$1$jscomp$10$$,
$APP.$cljs$cst$1511$y$$,($position$jscomp$210_position__$1$jscomp$10$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$210_position__$1$jscomp$10$$,$APP.$cljs$cst$1511$y$$))+($position$jscomp$210_position__$1$jscomp$10$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$210_position__$1$jscomp$10$$,$APP.$cljs$cst$1522$height$$)));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($position$jscomp$210_position__$1$jscomp$10$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1769$text_transform$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1768$text_decoration$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1588$text$$],[""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,"font-style")??""),""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,
"text-transform")??""),""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,"font-size")??""),""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,"font-weight")??""),""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,"text-decoration")??""),""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,"letter-spacing")??""),$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($get_prop$$($node$jscomp$467_styles$jscomp$33$$,"--fills")),$direction$jscomp$32_map__80420__$1$$,""+($get_prop$$($node$jscomp$467_styles$jscomp$33$$,
"font-family")??""),$p__80419_text$jscomp$148$$]))}function $get_prop$$($styles$jscomp$32_value$jscomp$999$$,$prop$jscomp$43$$){$styles$jscomp$32_value$jscomp$999$$=$styles$jscomp$32_value$jscomp$999$$.getPropertyValue($prop$jscomp$43$$);return $styles$jscomp$32_value$jscomp$999$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$32_value$jscomp$999$$,"")?$styles$jscomp$32_value$jscomp$999$$:null}return $shape_id$jscomp$172$$!=null?$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($text_data$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($transform_data$$,
$text_data$$)},$app$util$text_svg_position$calc_text_node_positions$$($shape_id$jscomp$172$$)):null};
$app$main$ui$workspace$shapes$text$viewport_texts_html$fix_position$$=function($shape$jscomp$1052$$){var $temp__5823__auto__$jscomp$255$$=$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1052$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$255$$)){var $new_sr_shape_SINGLEQUOTE_$jscomp$12$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1052$$,$temp__5823__auto__$jscomp$255$$),$deltav$jscomp$3_old_sr$$=$shape$jscomp$1052$$?.$selrect$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1052$$,$APP.$cljs$cst$1605$selrect$$);$new_sr_shape_SINGLEQUOTE_$jscomp$12$$=$new_sr_shape_SINGLEQUOTE_$jscomp$12$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_sr_shape_SINGLEQUOTE_$jscomp$12$$,$APP.$cljs$cst$1605$selrect$$);$deltav$jscomp$3_old_sr$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($new_sr_shape_SINGLEQUOTE_$jscomp$12$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($deltav$jscomp$3_old_sr$$));
return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1052$$,$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5823__auto__$jscomp$255$$,$deltav$jscomp$3_old_sr$$)),$APP.$cljs$cst$1810$modifiers$$)}return $shape$jscomp$1052$$};
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$=function($shape$jscomp$1053$$,$content$jscomp$266$$,$editor_content$$){return $shape$jscomp$1053$$!=null&&$editor_content$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1053$$,$APP.$cljs$cst$1637$content$$,$APP.$app$common$data$txt_merge$$($content$jscomp$266$$,$editor_content$$)):$shape$jscomp$1053$$};
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_shape$$=function($p__80424$$,$node$jscomp$468$$){var $map__80425__$1$$=$APP.$cljs$core$__destructure_map$$($p__80424$$),$grow_type$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80425__$1$$,$APP.$cljs$cst$1770$grow_type$$),$id$jscomp$1032$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80425__$1$$,$APP.$cljs$cst$266$id$$),$migrate$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80425__$1$$,
$cljs$cst$5870$migrate$$);return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$){$app$common$geom$shapes$text$overlaps_position_data_QMARK_$$($map__80425__$1$$,$map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_position_data$$($id$jscomp$1032$$,$map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$));
if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$2036$auto_width$$,null],null),null),$grow_type$jscomp$10$$)){$map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$468$$,".paragraph-set"));var $height_80454_height_80456__$1_map__80426_80452__$1$$=
$APP.$cljs$core$__destructure_map$$($map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$);$map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height_80454_height_80456__$1_map__80426_80452__$1$$,$APP.$cljs$cst$290$width$$);$height_80454_height_80456__$1_map__80426_80452__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height_80454_height_80456__$1_map__80426_80452__$1$$,$APP.$cljs$cst$1522$height$$);
$map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$=$APP.$app$common$math$ceil$$($map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$);$height_80454_height_80456__$1_map__80426_80452__$1$$=$APP.$app$common$math$ceil$$($height_80454_height_80456__$1_map__80426_80452__$1$$);$APP.$app$common$math$almost_zero_QMARK_$$($map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$)||$APP.$app$common$math$almost_zero_QMARK_$$($height_80454_height_80456__$1_map__80426_80452__$1$$)||
!$APP.$cljs$core$not$$($migrate$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$resize_text$$($id$jscomp$1032$$,$map__80426_80451_position_data$jscomp$16_width_80453_width_80455__$1$$,$height_80454_height_80456__$1_map__80426_80452__$1$$))}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$clean_text_modifier$$($id$jscomp$1032$$))},$app$util$text_svg_position$calc_position_data$$($id$jscomp$1032$$))};
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$=function($map__80430__$1_p__80429$$,$node$jscomp$469$$){$map__80430__$1_p__80429$$=$APP.$cljs$core$__destructure_map$$($map__80430__$1_p__80429$$);var $grow_type$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80430__$1_p__80429$$,$APP.$cljs$cst$1770$grow_type$$),$id$jscomp$1033$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80430__$1_p__80429$$,$APP.$cljs$cst$266$id$$);return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80427_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_modifier$$($id$jscomp$1033$$,
$p1__80427_SHARP_$$))},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__80432__$1_position_data$jscomp$17_props$jscomp$393$$){$G__80432__$1_position_data$jscomp$17_props$jscomp$393$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1891$position_data$$,$G__80432__$1_position_data$jscomp$17_props$jscomp$393$$],null);if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2035$auto_height$$,
null,$APP.$cljs$cst$2036$auto_width$$,null],null),null),$grow_type$jscomp$11$$)){var $map__80431_width$jscomp$219_width__$1$jscomp$11$$=$APP.$app$util$dom$get_client_size$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$469$$,".paragraph-set")),$height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$=$APP.$cljs$core$__destructure_map$$($map__80431_width$jscomp$219_width__$1$jscomp$11$$);$map__80431_width$jscomp$219_width__$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$,$APP.$cljs$cst$1522$height$$);$map__80431_width$jscomp$219_width__$1$jscomp$11$$=$APP.$app$common$math$ceil$$($map__80431_width$jscomp$219_width__$1$jscomp$11$$);$height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$=$APP.$app$common$math$ceil$$($height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$);if($APP.$app$common$math$almost_zero_QMARK_$$($map__80431_width$jscomp$219_width__$1$jscomp$11$$)||
$APP.$app$common$math$almost_zero_QMARK_$$($height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$))return $G__80432__$1_position_data$jscomp$17_props$jscomp$393$$;$G__80432__$1_position_data$jscomp$17_props$jscomp$393$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$11$$,$APP.$cljs$cst$2036$auto_width$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80432__$1_position_data$jscomp$17_props$jscomp$393$$,$APP.$cljs$cst$290$width$$,$map__80431_width$jscomp$219_width__$1$jscomp$11$$):
$G__80432__$1_position_data$jscomp$17_props$jscomp$393$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$11$$,$APP.$cljs$cst$2035$auto_height$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$11$$,$APP.$cljs$cst$2036$auto_width$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80432__$1_position_data$jscomp$17_props$jscomp$393$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$187_height__$1$jscomp$7_map__80431__$1$$):$G__80432__$1_position_data$jscomp$17_props$jscomp$393$$}return $G__80432__$1_position_data$jscomp$17_props$jscomp$393$$},
$app$util$text_svg_position$calc_position_data$$($id$jscomp$1033$$)))};
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$=function($shape$jscomp$1059$$,$other$jscomp$203$$){var $and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$=$shape$jscomp$1059$$===$other$jscomp$203$$;return $and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$?$and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$:
($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1059$$),$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$203$$)))?($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1059$$),$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$203$$)))?($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1059$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1059$$,$APP.$cljs$cst$1510$x$$),$other$jscomp$203$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,$APP.$cljs$cst$1510$x$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$)?($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$=
$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1059$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1059$$,$APP.$cljs$cst$1511$y$$),$other$jscomp$203$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,$APP.$cljs$cst$1511$y$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$)?
($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1059$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1059$$,$APP.$cljs$cst$290$width$$),$other$jscomp$203$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,$APP.$cljs$cst$290$width$$)),
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$)?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1059$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1059$$,$APP.$cljs$cst$1522$height$$),$other$jscomp$203$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,
$APP.$cljs$cst$1522$height$$)):$and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$):$and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$):$and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$):
$and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$:$and__5023__auto__$jscomp$911_and__5023__auto____$1$jscomp$157_and__5023__auto____$2$jscomp$45_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4_or__5025__auto__$jscomp$1305$$};
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_changes_renderer$$=function($changed_texts_props_80434$$){var $text_shapes$jscomp$2$$=$changed_texts_props_80434$$["text-shapes"],$prev_text_shapes$$=$APP.$app$main$ui$hooks$use_previous$$($text_shapes$jscomp$2$$),$pending_update_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$pending_update$$=$APP.$cljs$core$_deref$$($pending_update_STAR_$$);$changed_texts_props_80434$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes$jscomp$2$$),$APP.$rumext$v2$adapt$$($pending_update$$)],function(){var $pending_shapes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$vals$$($pending_update$$));return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($text_shapes$jscomp$2$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$1035_old_shape$jscomp$inline_9140$$){var $JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$;
($JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$=$APP.$cljs$core$contains_QMARK_$$($pending_shapes$$,$id$jscomp$1035_old_shape$jscomp$inline_9140$$))||($JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes$jscomp$2$$,$id$jscomp$1035_old_shape$jscomp$inline_9140$$),$id$jscomp$1035_old_shape$jscomp$inline_9140$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($prev_text_shapes$$,$id$jscomp$1035_old_shape$jscomp$inline_9140$$),
$JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$=$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$))==null&&$APP.$cljs$core$not$$($app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$($id$jscomp$1035_old_shape$jscomp$inline_9140$$,$JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$))||$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$)==
null);return $JSCompiler_temp$jscomp$1887_new_shape$jscomp$inline_9139$$},$APP.$cljs$core$keys$$($text_shapes$jscomp$2$$)))});var $handle_update_shape$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$1060$$,$node$jscomp$471$$){var $uid$jscomp$2$$=$APP.$app$common$uuid$next$$();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($pending_update_STAR_$$,$APP.$cljs$core$assoc$$,$uid$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1060$$));
return $APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_shape$$($shape$jscomp$1060$$,$node$jscomp$471$$),function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($pending_update_STAR_$$,$APP.$cljs$core$dissoc$$,$uid$jscomp$2$$)})});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"text-changes-renderer",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$206$$,
$map__80437__$1_p__80436$$){$map__80437__$1_p__80436$$=$APP.$cljs$core$__destructure_map$$($map__80437__$1_p__80436$$);var $id$jscomp$1036$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80437__$1_p__80436$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$206$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$,{shape:$map__80437__$1_p__80436$$,"on-update":$handle_update_shape$$},"text-container-"+($id$jscomp$1036$$??"")));
return $out_arr__44124__auto__$jscomp$206$$},[],$changed_texts_props_80434$$)})};
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_modifiers_renderer$$=function($changed_texts$jscomp$1_props_80438$$){function $text_change_QMARK_$jscomp$2$$($id$jscomp$1037_old_shape$jscomp$3$$){var $new_shape$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes$jscomp$3$$,$id$jscomp$1037_old_shape$jscomp$3$$);$id$jscomp$1037_old_shape$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($prev_text_shapes$jscomp$1$$,$id$jscomp$1037_old_shape$jscomp$3$$);
return $new_shape$jscomp$24$$!=null&&$id$jscomp$1037_old_shape$jscomp$3$$!=null&&$APP.$cljs$core$not$$($app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$($id$jscomp$1037_old_shape$jscomp$3$$,$new_shape$jscomp$24$$))}var $text_shapes$jscomp$3$$=$APP.$cljs$core$update_vals$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($changed_texts$jscomp$1_props_80438$$,"text-shapes"),$app$main$ui$workspace$shapes$text$viewport_texts_html$fix_position$$),$prev_text_shapes$jscomp$1$$=
$APP.$app$main$ui$hooks$use_previous$$($text_shapes$jscomp$3$$);$changed_texts$jscomp$1_props_80438$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes$jscomp$3$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($text_shapes$jscomp$3$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($text_change_QMARK_$jscomp$2$$,$APP.$cljs$core$keys$$($text_shapes$jscomp$3$$)))});var $handle_update_shape$jscomp$1$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"text-changes-renderer",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$207$$,$map__80440__$1_p__80439$$){$map__80440__$1_p__80439$$=$APP.$cljs$core$__destructure_map$$($map__80440__$1_p__80439$$);var $id$jscomp$1038$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80440__$1_p__80439$$,
$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$207$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$,{shape:$map__80440__$1_p__80439$$,"on-update":$handle_update_shape$jscomp$1$$},"text-container-"+($id$jscomp$1038$$??"")));return $out_arr__44124__auto__$jscomp$207$$},[],$changed_texts$jscomp$1_props_80438$$)})};
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$=function($var_args$jscomp$1462$$){for(var $args__5755__auto__$jscomp$260$$=[],$len__5749__auto___80485$$=arguments.length,$i__5750__auto___80486$$=0;;)if($i__5750__auto___80486$$<$len__5749__auto___80485$$)$args__5755__auto__$jscomp$260$$.push(arguments[$i__5750__auto___80486$$]),$i__5750__auto___80486$$+=1;else break;$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<
$args__5755__auto__$jscomp$260$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$260$$.slice(0),0,null):null)};
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$){$cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$=$APP.$cljs$core$__destructure_map$$($cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$);$cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$,$APP.$cljs$cst$4044$finalize_QMARK_$$);a:{var $JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=
$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$)?$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$():$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$)){$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=
$APP.$app$render_wasm$text_editor$text_editor_get_active_shape_id$$();b:{if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $content$jscomp$inline_14707_fn_53541$jscomp$inline_14811$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_export_content;try{var $content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=$content$jscomp$inline_14707_fn_53541$jscomp$inline_14811$$()}catch($e53543$jscomp$inline_14818$$){throw $cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$=
$e53543$jscomp$inline_14818$$,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$)?$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$.$cljs$core$IFn$_invoke$arity$0$?
$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$.$cljs$core$IFn$_invoke$arity$0$():$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$():
null,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$,
$APP.$cljs$cst$2971$wasm_critical$$),$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=["WASM Error (",$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_export_content",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$,
$APP.$cljs$cst$273$code$$,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$],null),$cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$);}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$)?
$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$!==0:$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$)){$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=
$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$);$APP.$app$render_wasm$mem$free$$();$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=
JSON.parse($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$);break b}}$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=null}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$)?
$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$:$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$)&&
($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!1])),$content$jscomp$inline_14707_fn_53541$jscomp$inline_14811$$=$APP.$app$render_wasm$text_editor$get_cached_content$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$),
$APP.$cljs$core$truth_$$($content$jscomp$inline_14707_fn_53541$jscomp$inline_14811$$))){$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=$app$render_wasm$text_editor$merge_exported_texts_into_content$$($content$jscomp$inline_14707_fn_53541$jscomp$inline_14811$$,$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$render_wasm$text_editor$shape_text_contents$$,$APP.$cljs$core$assoc$$,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$,$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$);
$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2543$shape_id$$,$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$,
$APP.$cljs$cst$1637$content$$,$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$],null);break a}}$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=
null}$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$)&&($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$),$JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$,$APP.$cljs$cst$2543$shape_id$$),$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$,$APP.$cljs$cst$1637$content$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_inline_result$jscomp$inline_14702_and__5023__auto__$jscomp$inline_14703_code__52999__auto__$jscomp$inline_14815_code_num__52998__auto__$jscomp$inline_14814_read_code_fn__52997__auto__$jscomp$inline_14813_shape_id$jscomp$174_shape_id$jscomp$inline_14704_temp__5825__auto__$jscomp$420$$,
$content$jscomp$269_hint__53000__auto__$jscomp$inline_14816_json_str$jscomp$inline_14817_map__80460__$1_merged$jscomp$inline_14708_new_texts$jscomp$inline_14705_ptr$jscomp$inline_14810_texts_clj$jscomp$inline_14706$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4017$update_name_QMARK_$$,!0,$APP.$cljs$cst$4044$finalize_QMARK_$$,$cause53542$jscomp$inline_14812_finalize_QMARK_$jscomp$2_map__80459__$1_p__80458$$]))))};
$app$main$ui$workspace$shapes$text$v3_editor$text_editor$$=function($clip_id$jscomp$4_props_80461$$){var $shape$jscomp$1065$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($clip_id$jscomp$4_props_80461$$,"shape"),$shape_id$jscomp$175$$=$shape$jscomp$1065$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1065$$,$APP.$cljs$cst$266$id$$);$clip_id$jscomp$4_props_80461$$="text-edition-clip"+($shape_id$jscomp$175$$??"");var $contenteditable_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$composing_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$=$APP.$app$render_wasm$api$fonts_from_text_content$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1065$$),!1);$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$){$JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$=
$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$);$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$,"gfont-noto-sans"))?($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$=$APP.$cuerdas$core$replace$$($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$,
/gfont\-noto\-sans\-/,""),$JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$)>=3?$APP.$cuerdas$core$capital$$($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$):$APP.$cuerdas$core$upper$$($JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$)):
$JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$="Noto Color Emoji";return $JSCompiler_inline_result$jscomp$1888_font$jscomp$54_font_id$jscomp$inline_9152_lang$jscomp$inline_9153$$},$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$);var $transform$jscomp$110_vec__80462$$=function(){var $map__80470_max_width$jscomp$9_width$jscomp$222$$=$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id$jscomp$175$$),
$map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__80470_max_width$jscomp$9_width$jscomp$222$$);$map__80470_max_width$jscomp$9_width$jscomp$222$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$190$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$,$APP.$cljs$cst$1522$height$$);
$map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);var $transform$jscomp$111_vec__80471$$=$app$main$data$helpers$get_selrect$$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$,$shape$jscomp$1065$$);$map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$111_vec__80471$$,0,null);$transform$jscomp$111_vec__80471$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$111_vec__80471$$,
1,null);var $selrect_height$jscomp$2$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$),$max_height$jscomp$5_selrect_width$jscomp$2$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$);$map__80470_max_width$jscomp$9_width$jscomp$222$$=$map__80470_max_width$jscomp$9_width$jscomp$222$$>$max_height$jscomp$5_selrect_width$jscomp$2$$?$map__80470_max_width$jscomp$9_width$jscomp$222$$:
$max_height$jscomp$5_selrect_width$jscomp$2$$;$max_height$jscomp$5_selrect_width$jscomp$2$$=$height$jscomp$190$$>$selrect_height$jscomp$2$$?$height$jscomp$190$$:$selrect_height$jscomp$2$$;var $valign$jscomp$2$$=$APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1065$$)),$y$jscomp$499$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$);
return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__80470__$1_selrect$jscomp$84_selrect_transform$jscomp$3$$,$APP.$cljs$cst$1511$y$$,function(){switch($valign$jscomp$2$$){case "bottom":return $y$jscomp$499$$+($selrect_height$jscomp$2$$-$height$jscomp$190$$);case "center":return $y$jscomp$499$$+($selrect_height$jscomp$2$$-$height$jscomp$190$$)/2;default:return $y$jscomp$499$$}}(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,$map__80470_max_width$jscomp$9_width$jscomp$222$$,$APP.$cljs$cst$1522$height$$,$max_height$jscomp$5_selrect_width$jscomp$2$$])),$transform$jscomp$111_vec__80471$$],null)}(),$map__80465_x$jscomp$1275$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$110_vec__80462$$,0,null),$height$jscomp$189_map__80465__$1$$=$APP.$cljs$core$__destructure_map$$($map__80465_x$jscomp$1275$$);$map__80465_x$jscomp$1275$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$189_map__80465__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$498$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$189_map__80465__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$189_map__80465__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$189_map__80465__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$189_map__80465__$1$$,
$APP.$cljs$cst$1522$height$$);$transform$jscomp$110_vec__80462$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$110_vec__80462$$,1,null);var $on_composition_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($composing_QMARK_$$,!0);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$=
$APP.$app$render_wasm$wasm$internal_module$$._text_editor_composition_start;try{var $JSCompiler_inline_result$jscomp$1549_cause53452$jscomp$inline_9156$$=$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$()}catch($e53453$jscomp$inline_9161$$){$JSCompiler_inline_result$jscomp$1549_cause53452$jscomp$inline_9156$$=$e53453$jscomp$inline_9161$$;$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$)?$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$():null;$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_9160$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_9160$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_composition_start",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_9160$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_9159_code_num__52998__auto__$jscomp$inline_9158_fn_53451$jscomp$inline_9155_read_code_fn__52997__auto__$jscomp$inline_9157$$],
null),$JSCompiler_inline_result$jscomp$1549_cause53452$jscomp$inline_9156$$);}}else $JSCompiler_inline_result$jscomp$1549_cause53452$jscomp$inline_9156$$=null;return $JSCompiler_inline_result$jscomp$1549_cause53452$jscomp$inline_9156$$}),$on_composition_update$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$){$APP.$cljs$core$truth_$$($composing_QMARK_$$)||$APP.$cljs$core$reset_BANG_$$($composing_QMARK_$$,
!0);$cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$=$cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$.data;if($APP.$cljs$core$truth_$$($cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$)){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$app$render_wasm$text_editor$text_editor_encode_text_pre$$($cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$);
var $code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_composition_update;try{$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$()}catch($e53460$jscomp$inline_9170$$){$cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$=
$e53460$jscomp$inline_9170$$;$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$=$APP.$cljs$core$truth_$$($code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$)?
$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$():
null;$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $hint__53000__auto___53714$jscomp$inline_9169$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___53714$jscomp$inline_9169$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_composition_update",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___53714$jscomp$inline_9169$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___53713$jscomp$inline_9168_code_num__52998__auto___53712$jscomp$inline_9167_fn_53458_53709$jscomp$inline_9164_read_code_fn__52997__auto___53711$jscomp$inline_9166$$],null),$cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$);}!$APP.$cljs$core$empty_QMARK_$$($cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$)&&
$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$app$render_wasm$mem$free$$()}$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$();$APP.$app$render_wasm$api$request_render$$("text-composition")}$cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$)?
$cause53459_53710$jscomp$inline_9165_data$jscomp$501_event$jscomp$651_temp__5825__auto__$jscomp$421$$.textContent="":null}),$on_composition_end$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$){$APP.$cljs$core$reset_BANG_$$($composing_QMARK_$$,!1);$cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$=$cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$.data;
if($APP.$cljs$core$truth_$$($cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$)){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$app$render_wasm$text_editor$text_editor_encode_text_pre$$($cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$);var $code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$=
$APP.$app$render_wasm$wasm$internal_module$$._text_editor_composition_end;try{$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$()}catch($e53466$jscomp$inline_9179$$){$cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$=$e53466$jscomp$inline_9179$$;$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$=$APP.$cljs$core$truth_$$($code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$)?$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$():null;$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___53722$jscomp$inline_9178$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___53722$jscomp$inline_9178$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_composition_end",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___53722$jscomp$inline_9178$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___53721$jscomp$inline_9177_code_num__52998__auto___53720$jscomp$inline_9176_fn_53464_53717$jscomp$inline_9173_read_code_fn__52997__auto___53719$jscomp$inline_9175$$],
null),$cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$);}!$APP.$cljs$core$empty_QMARK_$$($cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$)&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$app$render_wasm$mem$free$$()}$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$();$APP.$app$render_wasm$api$request_render$$("text-composition")}$cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$=
$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$)?$cause53465_53718$jscomp$inline_9174_data$jscomp$502_event$jscomp$652_temp__5825__auto__$jscomp$422$$.textContent="":null}),$on_paste$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$);
$event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$=$event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$.clipboardData.getData("text/plain");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$)?$APP.$cljs$core$seq$$($event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$):$event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$)&&($app$render_wasm$text_editor$text_editor_insert_text$$($event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$),
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-paste"));$event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$)?$event$jscomp$653_temp__5825__auto__$jscomp$423_text$jscomp$149$$.textContent="":null}),$on_copy$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$654$$){if($APP.$cljs$core$truth_$$($app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$())&&
($APP.$app$util$dom$prevent_default$$($event$jscomp$654$$),$APP.$cljs$core$truth_$$($APP.$app$render_wasm$text_editor$text_editor_get_selection$$()))){var $text$jscomp$150$$=$app$render_wasm$text_editor$text_editor_export_selection$$();return $event$jscomp$654$$.clipboardData.setData("text/plain",$text$jscomp$150$$)}return null}),$on_cut$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$655_temp__5825__auto__$jscomp$424$$){if($APP.$cljs$core$truth_$$($app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$())){$APP.$app$util$dom$prevent_default$$($event$jscomp$655_temp__5825__auto__$jscomp$424$$);
if($APP.$cljs$core$truth_$$($APP.$app$render_wasm$text_editor$text_editor_get_selection$$())){var $text_80511$$=$app$render_wasm$text_editor$text_editor_export_selection$$();$event$jscomp$655_temp__5825__auto__$jscomp$424$$.clipboardData.setData("text/plain",$APP.$cljs$core$truth_$$($text_80511$$)?$text_80511$$:"");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($text_80511$$)?$APP.$cljs$core$seq$$($text_80511$$):$text_80511$$)&&($app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-cut"))}$event$jscomp$655_temp__5825__auto__$jscomp$424$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($event$jscomp$655_temp__5825__auto__$jscomp$424$$)?$event$jscomp$655_temp__5825__auto__$jscomp$424$$.textContent="":null}return null}),$on_key_down$jscomp$26$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$656$$){if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$914$$=
$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$914$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($composing_QMARK_$$)):$and__5023__auto__$jscomp$914$$}())){var $key$jscomp$419_temp__5825__auto__$jscomp$425$$=$event$jscomp$656$$.key,$ctrl_QMARK_$$=function(){var $or__5025__auto__$jscomp$1307$$=$event$jscomp$656$$.ctrlKey;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1307$$)?$or__5025__auto__$jscomp$1307$$:
$event$jscomp$656$$.metaKey}(),$shift_QMARK_$jscomp$36$$=$event$jscomp$656$$.shiftKey;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"Escape"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$key$jscomp$419_temp__5825__auto__$jscomp$425$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$),$APP.$cljs$core$truth_$$($key$jscomp$419_temp__5825__auto__$jscomp$425$$)?$key$jscomp$419_temp__5825__auto__$jscomp$425$$.blur():null;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($ctrl_QMARK_$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$($key$jscomp$419_temp__5825__auto__$jscomp$425$$),"a"):$ctrl_QMARK_$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_select_all$$(),$APP.$app$render_wasm$api$request_render$$("text-select-all");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"Enter"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),
$app$render_wasm$text_editor$text_editor_insert_paragraph$$(),$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-paragraph");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"Backspace"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$($ctrl_QMARK_$$),
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-delete-backward");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"Delete"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_delete_forward$cljs$0core$0IFn$0_invoke$0arity$01$$($ctrl_QMARK_$$),$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),
$APP.$app$render_wasm$api$request_render$$("text-delete-forward");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"Insert"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_toggle_overtype_mode$$(),$APP.$app$render_wasm$api$request_render$$("text-overtype-mode");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"ArrowLeft"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),
$app$render_wasm$text_editor$text_editor_move_cursor$$(0,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$36$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"ArrowRight"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(1,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$36$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"ArrowUp"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(2,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$36$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"ArrowDown"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),
$app$render_wasm$text_editor$text_editor_move_cursor$$(3,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$36$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"Home"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(4,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$36$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$419_temp__5825__auto__$jscomp$425$$,"End"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$656$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(5,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$36$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move")}return null}),$on_input$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$){var $data$jscomp$503_native_event$jscomp$2$$=
$event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$.nativeEvent;$event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$=$data$jscomp$503_native_event$jscomp$2$$.inputType;$data$jscomp$503_native_event$jscomp$2$$=$data$jscomp$503_native_event$jscomp$2$$.data;return $APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($composing_QMARK_$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$,"insertCompositionText")?
($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($data$jscomp$503_native_event$jscomp$2$$)?$APP.$cljs$core$seq$$($data$jscomp$503_native_event$jscomp$2$$):$data$jscomp$503_native_event$jscomp$2$$)&&($app$render_wasm$text_editor$text_editor_insert_text$$($data$jscomp$503_native_event$jscomp$2$$),$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-input")),$event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$=
$APP.$rumext$v2$ref_val$$($contenteditable_ref$$),$APP.$cljs$core$truth_$$($event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$)?$event$jscomp$657_input_type$jscomp$3_temp__5825__auto__$jscomp$426$$.textContent="":null):null}),$on_pointer_down$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$658_off_pt$$){$event$jscomp$658_off_pt$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$658_off_pt$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_pointer_down$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_pointer_down$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$658_off_pt$$):$app$render_wasm$text_editor$text_editor_pointer_down$$($event$jscomp$658_off_pt$$)}),$on_pointer_move$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$659_off_pt$jscomp$1$$){$event$jscomp$659_off_pt$jscomp$1$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$659_off_pt$jscomp$1$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_pointer_move$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_pointer_move$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$659_off_pt$jscomp$1$$):$app$render_wasm$text_editor$text_editor_pointer_move$$($event$jscomp$659_off_pt$jscomp$1$$)}),$on_pointer_up$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$660_off_pt$jscomp$2$$){$event$jscomp$660_off_pt$jscomp$2$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$660_off_pt$jscomp$2$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_pointer_up$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_pointer_up$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$660_off_pt$jscomp$2$$):$app$render_wasm$text_editor$text_editor_pointer_up$$($event$jscomp$660_off_pt$jscomp$2$$)}),$on_click$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$661_off_pt$jscomp$3$$){$event$jscomp$661_off_pt$jscomp$3$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$661_off_pt$jscomp$3$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$661_off_pt$jscomp$3$$):$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$($event$jscomp$661_off_pt$jscomp$3$$)}),$on_double_click$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$662_off_pt$jscomp$4$$){$event$jscomp$662_off_pt$jscomp$4$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$662_off_pt$jscomp$4$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_select_word_boundary$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_select_word_boundary$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$662_off_pt$jscomp$4$$):$app$render_wasm$text_editor$text_editor_select_word_boundary$$($event$jscomp$662_off_pt$jscomp$4$$)}),$on_focus$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$render_wasm$text_editor$text_editor_focus$$.$cljs$core$IFn$_invoke$arity$1$?$app$render_wasm$text_editor$text_editor_focus$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$175$$):
$app$render_wasm$text_editor$text_editor_focus$$($shape_id$jscomp$175$$)}),$on_blur$jscomp$34$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4044$finalize_QMARK_$$,!0],null)]));return $app$render_wasm$text_editor$text_editor_blur$$.$cljs$core$IFn$_invoke$arity$0$?
$app$render_wasm$text_editor$text_editor_blur$$.$cljs$core$IFn$_invoke$arity$0$():$app$render_wasm$text_editor$text_editor_blur$$()});$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$={pointerEvents:"all","--editor-container-width":""+($width$jscomp$221$$??"")+"px","--editor-container-height":""+($height$jscomp$189_map__80465__$1$$??"")+"px","--fallback-families":$APP.$cljs$core$seq$$($fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$)?""+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",
$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$)??""):"sourcesanspro"};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($contenteditable_ref$$)],function(){var $temp__5825__auto___80547$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___80547$$)&&$temp__5825__auto___80547$$.focus();return $on_blur$jscomp$34$$});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $timeout_id$jscomp$1$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);(function $app$main$ui$workspace$shapes$text$v3_editor$text_editor_$_schedule_blink$$(){$APP.$cljs$core$truth_$$($app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$())&&$APP.$app$render_wasm$api$request_render$$("cursor-blink");return $APP.$cljs$core$reset_BANG_$$($timeout_id$jscomp$1$$,setTimeout($app$main$ui$workspace$shapes$text$v3_editor$text_editor_$_schedule_blink$$,250))})();return function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($timeout_id$jscomp$1$$))?
clearTimeout($APP.$cljs$core$_deref$$($timeout_id$jscomp$1$$)):null}});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"text-editor",clipPath:"url(#"+($clip_id$jscomp$4_props_80461$$??"")+")",transform:""+($transform$jscomp$110_vec__80462$$??""),"data-testid":"text-editor",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$4_props_80461$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__80465_x$jscomp$1275$$,y:$y$jscomp$498$$,width:$width$jscomp$221$$,
height:$height$jscomp$189_map__80465__$1$$})})}),(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$map__80465_x$jscomp$1275$$,y:$y$jscomp$498$$,width:$width$jscomp$221$$,height:$height$jscomp$189_map__80465__$1$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$on_click$jscomp$56$$,onDoubleClick:$on_double_click$jscomp$4$$,onPointerDown:$on_pointer_down$jscomp$13$$,onPointerMove:$on_pointer_move$jscomp$9$$,onPointerUp:$on_pointer_up$jscomp$2$$,style:$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$,
className:"main_ui_workspace_shapes_text_v3_editor__text-editor",children:(0,$APP.$rumext$v2$jsx$$)("div",{onCompositionStart:$on_composition_start$$,onCut:$on_cut$$,onPaste:$on_paste$$,onInput:$on_input$jscomp$1$$,className:""+($app$main$ui$css_cursors$get_dynamic$$("text",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1065$$))??"")+" main_ui_workspace_shapes_text_v3_editor__text-editor-container",suppressContentEditableWarning:!0,onCompositionUpdate:$on_composition_update$$,
id:"text-editor-wasm-input","data-testid":"text-editor-container",onFocus:$on_focus$jscomp$20$$,onBlur:$on_blur$jscomp$34$$,ref:$contenteditable_ref$$,onCopy:$on_copy$jscomp$1$$,onKeyDown:$on_key_down$jscomp$26$$,onCompositionEnd:$on_composition_end$$,contentEditable:!0})})})]})};
$app$main$ui$workspace$viewport$actions$on_pointer_down$$=function($map__80467__$1_p__80466_type$jscomp$709$$,$selected$jscomp$189$$,$edition$jscomp$12$$,$drawing_tool$jscomp$2$$,$text_editing_QMARK_$jscomp$1$$,$node_editing_QMARK_$$,$grid_editing_QMARK_$$,$drawing_path_QMARK_$$,$create_comment_QMARK_$$,$space_QMARK_$jscomp$1$$,$panning$$,$z_QMARK_$$,$read_only_QMARK_$jscomp$24$$){$map__80467__$1_p__80466_type$jscomp$709$$=$APP.$cljs$core$__destructure_map$$($map__80467__$1_p__80466_type$jscomp$709$$);
var $id$jscomp$1040$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80467__$1_p__80466_type$jscomp$709$$,$APP.$cljs$cst$266$id$$),$blocked$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80467__$1_p__80466_type$jscomp$709$$,$APP.$cljs$cst$1623$blocked$$),$hidden$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80467__$1_p__80466_type$jscomp$709$$,$APP.$cljs$cst$1620$hidden$$);$map__80467__$1_p__80466_type$jscomp$709$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80467__$1_p__80466_type$jscomp$709$$,
$APP.$cljs$cst$139$type$$);return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1040$$),$APP.$rumext$v2$adapt$$($blocked$jscomp$3$$),$APP.$rumext$v2$adapt$$($hidden$jscomp$11$$),$APP.$rumext$v2$adapt$$($map__80467__$1_p__80466_type$jscomp$709$$),$APP.$rumext$v2$adapt$$($selected$jscomp$189$$),$APP.$rumext$v2$adapt$$($edition$jscomp$12$$),$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$2$$),$APP.$rumext$v2$adapt$$($text_editing_QMARK_$jscomp$1$$),
$APP.$rumext$v2$adapt$$($node_editing_QMARK_$$),$APP.$rumext$v2$adapt$$($grid_editing_QMARK_$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$$),$APP.$rumext$v2$adapt$$($create_comment_QMARK_$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$1$$)),$APP.$rumext$v2$adapt$$($panning$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$24$$)],function($event$jscomp$663$$){var $native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$=
$APP.$app$util$dom$get_target$$($event$jscomp$663$$),$ctrl_QMARK_$jscomp$1_editor_80517$$=$app$util$text$ui$closest_text_editor_content$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$);$APP.$cljs$core$truth_$$($ctrl_QMARK_$jscomp$1_editor_80517$$)?$ctrl_QMARK_$jscomp$1_editor_80517$$.setPointerCapture($event$jscomp$663$$.pointerId):$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$.setPointerCapture($event$jscomp$663$$.pointerId);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1308_or__5025__auto____$1$jscomp$142$$=
$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$663$$),"viewport-controls");return $or__5025__auto__$jscomp$1308_or__5025__auto____$1$jscomp$142$$?$or__5025__auto__$jscomp$1308_or__5025__auto____$1$jscomp$142$$:($or__5025__auto__$jscomp$1308_or__5025__auto____$1$jscomp$142$$=$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$663$$),"viewport-selrect"))?$or__5025__auto__$jscomp$1308_or__5025__auto____$1$jscomp$142$$:$APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$663$$),
$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".grid-layout-editor"))}())){$APP.$app$util$dom$stop_propagation$$($event$jscomp$663$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($z_QMARK_$$)))return null;$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$=$event$jscomp$663$$.nativeEvent;$ctrl_QMARK_$jscomp$1_editor_80517$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$.ctrlKey;var $meta_QMARK_$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$.metaKey,
$shift_QMARK_$jscomp$37$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$.shiftKey,$alt_QMARK_$jscomp$17$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$.altKey,$mod_QMARK_$jscomp$7$$=$APP.$app$util$keyboard$mod_QMARK_$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$),$left_click_QMARK_$$=$APP.$cljs$core$not$$($panning$$)&&$app$util$dom$left_mouse_QMARK_$$($event$jscomp$663$$),$middle_click_QMARK_$$=$APP.$cljs$core$not$$($panning$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$event$jscomp$663$$.nativeEvent.which);if($APP.$cljs$core$truth_$$($middle_click_QMARK_$$?$middle_click_QMARK_$$:$left_click_QMARK_$$?$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$1$$):$left_click_QMARK_$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$663$$),$mod_QMARK_$jscomp$7$$?($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$=$APP.$app$util$dom$get_client_position$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$),$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$=
$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$zoom$start_zooming$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80516$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$viewport$start_panning$$());if($left_click_QMARK_$$)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1953$down$$,
$ctrl_QMARK_$jscomp$1_editor_80517$$,$shift_QMARK_$jscomp$37$$,$alt_QMARK_$jscomp$17$$,$meta_QMARK_$$,null,null,null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$])),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$918$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$12$$,$id$jscomp$1040$$);return $and__5023__auto__$jscomp$918$$?$APP.$cljs$core$truth_$$($text_editing_QMARK_$jscomp$1$$)?
$text_editing_QMARK_$jscomp$1$$:$grid_editing_QMARK_$$:$and__5023__auto__$jscomp$918$$}())&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$()),$APP.$cljs$core$not$$($text_editing_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($blocked$jscomp$3$$)&&$APP.$cljs$core$not$$($hidden$jscomp$11$$)&&$APP.$cljs$core$not$$($create_comment_QMARK_$$)&&$APP.$cljs$core$not$$($drawing_path_QMARK_$$)?$APP.$cljs$core$truth_$$($node_editing_QMARK_$$)?
$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$24$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$handle_area_selection$$($shift_QMARK_$jscomp$37$$,$shift_QMARK_$jscomp$37$$&&$mod_QMARK_$jscomp$7$$)):$APP.$cljs$core$truth_$$($drawing_tool$jscomp$2$$)?$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$24$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$start_drawing$$($drawing_tool$jscomp$2$$)):
$APP.$cljs$core$not$$($id$jscomp$1040$$)||$mod_QMARK_$jscomp$7$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$selection$handle_area_selection$$($shift_QMARK_$jscomp$37$$,$shift_QMARK_$jscomp$37$$&&$mod_QMARK_$jscomp$7$$,$mod_QMARK_$jscomp$7$$)):$APP.$cljs$core$not$$($drawing_tool$jscomp$2$$)?$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$24$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1040$$,
$shift_QMARK_$jscomp$37$$)):null:null}return null})};
$app$main$ui$workspace$viewport$actions$on_move_selected$$=function($hover$jscomp$5$$,$hover_ids$jscomp$1$$,$selected$jscomp$190$$,$space_QMARK_$jscomp$2$$,$z_QMARK_$jscomp$1$$,$read_only_QMARK_$jscomp$25$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$5$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$1$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$190$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$2$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$1$$)),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$25$$)],function($bevent$jscomp$2$$){var $event$jscomp$664_mod_QMARK_$jscomp$8$$=$bevent$jscomp$2$$.nativeEvent,$shift_QMARK_$jscomp$38$$=$event$jscomp$664_mod_QMARK_$jscomp$8$$.shiftKey;$event$jscomp$664_mod_QMARK_$jscomp$8$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$664_mod_QMARK_$jscomp$8$$);return $app$util$dom$left_mouse_QMARK_$$($bevent$jscomp$2$$)&&!$event$jscomp$664_mod_QMARK_$jscomp$8$$&&
!$shift_QMARK_$jscomp$38$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$2$$))?($APP.$app$util$dom$prevent_default$$($bevent$jscomp$2$$),$APP.$app$util$dom$stop_propagation$$($bevent$jscomp$2$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$25$$)?$read_only_QMARK_$jscomp$25$$:$APP.$cljs$core$_deref$$($z_QMARK_$jscomp$1$$))?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$0$())):
null})};
$app$main$ui$workspace$viewport$actions$on_frame_select$$=function($selected$jscomp$191$$,$read_only_QMARK_$jscomp$26$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$191$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$26$$)],function($event$jscomp$665_shift_QMARK_$jscomp$39$$,$id$jscomp$1041$$){$event$jscomp$665_shift_QMARK_$jscomp$39$$=$event$jscomp$665_shift_QMARK_$jscomp$39$$.shiftKey;var $selected_QMARK_$jscomp$25$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$191$$,
$id$jscomp$1041$$),$selected_drawtool$jscomp$1$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$selected_drawing_tool$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($event$jscomp$665_shift_QMARK_$jscomp$39$$||!$selected_QMARK_$jscomp$25$$?$APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1041$$,$event$jscomp$665_shift_QMARK_$jscomp$39$$):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$selected_drawtool$jscomp$1$$==
null&&!$event$jscomp$665_shift_QMARK_$jscomp$39$$&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$26$$)?$APP.$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$0$():null]))})};$app$main$ui$workspace$viewport$actions$on_frame_enter$$=function($frame_hover$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1042$$){return $APP.$cljs$core$reset_BANG_$$($frame_hover$$,$id$jscomp$1042$$)})};
$app$main$ui$workspace$viewport$actions$on_frame_leave$$=function($frame_hover$jscomp$1$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($frame_hover$jscomp$1$$,null)})};
$app$main$ui$workspace$viewport$actions$on_click$$=function($hover$jscomp$6$$,$selected$jscomp$192$$,$edition$jscomp$13$$,$drawing_path_QMARK_$jscomp$1$$,$drawing_tool$jscomp$3$$,$space_QMARK_$jscomp$3$$,$selrect$jscomp$85$$,$z_QMARK_$jscomp$2$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$6$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$192$$),$APP.$rumext$v2$adapt$$($edition$jscomp$13$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$1$$),
$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$3$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$3$$)),$APP.$rumext$v2$adapt$$($selrect$jscomp$85$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$2$$))],function($event$jscomp$666$$){if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$=$selrect$jscomp$85$$==null;if($and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$){if($and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$=
$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$666$$),"viewport-controls"))return $and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$;$and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$=$APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$666$$),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".grid-layout-editor"));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$)?
$and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$:$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$666$$),"viewport-selrect")}return $and__5023__auto__$jscomp$919_or__5025__auto__$jscomp$1312_or__5025__auto____$1$jscomp$143$$}())){var $ctrl_QMARK_$jscomp$2$$=$event$jscomp$666$$.ctrlKey,$shift_QMARK_$jscomp$40$$=$event$jscomp$666$$.shiftKey,$alt_QMARK_$jscomp$18$$=$event$jscomp$666$$.altKey,$meta_QMARK_$jscomp$1$$=$event$jscomp$666$$.metaKey,
$hovering_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($hover$jscomp$6$$)!=null,$pt$jscomp$30_raw_pt$jscomp$1$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$666$$);$pt$jscomp$30_raw_pt$jscomp$1$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($pt$jscomp$30_raw_pt$jscomp$1$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1939$click$$,$ctrl_QMARK_$jscomp$2$$,$shift_QMARK_$jscomp$40$$,$alt_QMARK_$jscomp$18$$,
$meta_QMARK_$jscomp$1$$,null,null,null));$hovering_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$3$$))&&$APP.$cljs$core$not$$($edition$jscomp$13$$)&&$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($drawing_tool$jscomp$3$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($hover$jscomp$6$$)),
$shift_QMARK_$jscomp$40$$));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$920$$=$APP.$cljs$core$_deref$$($z_QMARK_$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$920$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$3$$))&&$APP.$cljs$core$not$$($edition$jscomp$13$$)&&$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($drawing_tool$jscomp$3$$):$and__5023__auto__$jscomp$920$$}())?$alt_QMARK_$jscomp$18$$?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$30_raw_pt$jscomp$1$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$30_raw_pt$jscomp$1$$)):null}return null})};
$app$main$ui$workspace$viewport$actions$on_double_click$$=function($hover$jscomp$7$$,$hover_ids$jscomp$2$$,$selected$jscomp$193$$,$hover_top_frame_id$$,$drawing_path_QMARK_$jscomp$2$$,$objects$jscomp$808$$,$edition$jscomp$14$$,$drawing_tool$jscomp$4$$,$z_QMARK_$jscomp$3$$,$read_only_QMARK_$jscomp$27$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$7$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)),
$APP.$rumext$v2$adapt$$($selected$jscomp$193$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_top_frame_id$$)),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($edition$jscomp$14$$),$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$4$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$3$$)),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$27$$)],function($event$jscomp$667_meta_QMARK_$jscomp$2$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$667_meta_QMARK_$jscomp$2$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$3$$)))return null;var $ctrl_QMARK_$jscomp$3$$=$event$jscomp$667_meta_QMARK_$jscomp$2$$.ctrlKey,$shift_QMARK_$jscomp$41$$=$event$jscomp$667_meta_QMARK_$jscomp$2$$.shiftKey,$alt_QMARK_$jscomp$19$$=$event$jscomp$667_meta_QMARK_$jscomp$2$$.altKey;$event$jscomp$667_meta_QMARK_$jscomp$2$$=$event$jscomp$667_meta_QMARK_$jscomp$2$$.metaKey;var $selected_id_under_cursor$$=$APP.$cljs$core$last$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$193$$,
$APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$))),$hover_shape$jscomp$2_map__80475_type$jscomp$710$$=function(){var $or__5025__auto__$jscomp$1313_or__5025__auto____$1$jscomp$144$$=$APP.$cljs$core$truth_$$($selected_id_under_cursor$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$808$$,$selected_id_under_cursor$$):null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1313_or__5025__auto____$1$jscomp$144$$))return $or__5025__auto__$jscomp$1313_or__5025__auto____$1$jscomp$144$$;
$or__5025__auto__$jscomp$1313_or__5025__auto____$1$jscomp$144$$=$APP.$cljs$core$_deref$$($hover$jscomp$7$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1313_or__5025__auto____$1$jscomp$144$$)?$or__5025__auto__$jscomp$1313_or__5025__auto____$1$jscomp$144$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$808$$,$APP.$cljs$core$first$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)))}(),$map__80475__$1$$=$APP.$cljs$core$__destructure_map$$($hover_shape$jscomp$2_map__80475_type$jscomp$710$$),
$id$jscomp$1043$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80475__$1$$,$APP.$cljs$cst$266$id$$);$hover_shape$jscomp$2_map__80475_type$jscomp$710$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80475__$1$$,$APP.$cljs$cst$139$type$$);var $editable_QMARK_$jscomp$10$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1417$circle$$,null,$APP.$cljs$cst$1612$image$$,
null,$APP.$cljs$cst$1611$rect$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$hover_shape$jscomp$2_map__80475_type$jscomp$710$$);$hover_shape$jscomp$2_map__80475_type$jscomp$710$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$is_child_QMARK_$$,$objects$jscomp$808$$,$id$jscomp$1043$$),$APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)));var $selected_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$808$$,
$hover_shape$jscomp$2_map__80475_type$jscomp$710$$),$grid_layout_id$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,$objects$jscomp$808$$),$APP.$cljs$core$reverse$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$2165$double_click$$,$ctrl_QMARK_$jscomp$3$$,
$shift_QMARK_$jscomp$41$$,$alt_QMARK_$jscomp$19$$,$event$jscomp$667_meta_QMARK_$jscomp$2$$,null,null,null));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $and__5023__auto__$jscomp$inline_9182$$=$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9182$$?$map__80475__$1$$:$and__5023__auto__$jscomp$inline_9182$$)?$editable_QMARK_$jscomp$10$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1043$$,
$edition$jscomp$14$$)&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$27$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1043$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$start_editing_selected$$()])):$selected_shape$$!=null?($APP.$cljs$core$reset_BANG_$$($hover$jscomp$7$$,$selected_shape$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected_shape$$)))):
$APP.$cljs$core$not$$($selected_shape$$)&&$grid_layout_id$$!=null&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$27$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$start_edition_mode$$($grid_layout_id$$)):null:null})})};
$app$main$ui$workspace$viewport$actions$on_context_menu$$=function($hover$jscomp$8$$,$hover_ids$jscomp$3$$,$read_only_QMARK_$jscomp$28$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$8$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$3$$)),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$28$$)],function($event$jscomp$668$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$668$$);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1314_or__5025__auto____$1$jscomp$145$$=
$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$668$$),"viewport-controls");if($or__5025__auto__$jscomp$1314_or__5025__auto____$1$jscomp$145$$)return $or__5025__auto__$jscomp$1314_or__5025__auto____$1$jscomp$145$$;$or__5025__auto__$jscomp$1314_or__5025__auto____$1$jscomp$145$$=$APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$668$$),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".grid-layout-editor"));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1314_or__5025__auto____$1$jscomp$145$$)?
$or__5025__auto__$jscomp$1314_or__5025__auto____$1$jscomp$145$$:$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$668$$),"viewport-selrect")}())){var $position$jscomp$211$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$668$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$not$$($read_only_QMARK_$jscomp$28$$)&&$APP.$cljs$core$_deref$$($hover$jscomp$8$$)!=
null?$APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1676$position$$,$position$jscomp$211$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$_deref$$($hover$jscomp$8$$),$APP.$cljs$cst$2208$hover_ids$$,$APP.$cljs$core$_deref$$($hover_ids$jscomp$3$$)],null)):$APP.$app$main$data$workspace$show_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1676$position$$,$position$jscomp$211$$],null)))})}return null})};
$app$main$ui$workspace$viewport$actions$on_menu_selected$$=function($hover$jscomp$9$$,$hover_ids$jscomp$4$$,$selected$jscomp$194$$,$read_only_QMARK_$jscomp$29$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$9$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$4$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$194$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$29$$)],function($event$jscomp$669_position$jscomp$212$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$669_position$jscomp$212$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$669_position$jscomp$212$$);if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$29$$))return null;$event$jscomp$669_position$jscomp$212$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$669_position$jscomp$212$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$event$jscomp$669_position$jscomp$212$$,
$APP.$cljs$cst$2208$hover_ids$$,$APP.$cljs$core$_deref$$($hover_ids$jscomp$4$$)],null)))})};
$app$main$ui$workspace$viewport$actions$on_pointer_up$$=function($disable_paste_ref$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$670_native_event$jscomp$9$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$670_native_event$jscomp$9$$);$APP.$app$util$dom$get_target$$($event$jscomp$670_native_event$jscomp$9$$).releasePointerCapture($event$jscomp$670_native_event$jscomp$9$$.pointerId);$event$jscomp$670_native_event$jscomp$9$$=$event$jscomp$670_native_event$jscomp$9$$.nativeEvent;
var $ctrl_QMARK_$jscomp$4$$=$event$jscomp$670_native_event$jscomp$9$$.ctrlKey,$shift_QMARK_$jscomp$42$$=$event$jscomp$670_native_event$jscomp$9$$.shiftKey,$alt_QMARK_$jscomp$20$$=$event$jscomp$670_native_event$jscomp$9$$.altKey,$meta_QMARK_$jscomp$3$$=$event$jscomp$670_native_event$jscomp$9$$.metaKey,$left_click_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$event$jscomp$670_native_event$jscomp$9$$.which),$middle_click_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$event$jscomp$670_native_event$jscomp$9$$.which);$left_click_QMARK_$jscomp$1$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1954$up$$,$ctrl_QMARK_$jscomp$4$$,$shift_QMARK_$jscomp$42$$,$alt_QMARK_$jscomp$20$$,$meta_QMARK_$jscomp$3$$,null,null,null));$middle_click_QMARK_$jscomp$1$$&&($APP.$app$util$dom$prevent_default$$($event$jscomp$670_native_event$jscomp$9$$),$APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$$,!0),$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$$,
!1)}));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$viewport$finish_panning$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$zoom$finish_zooming$$()]))})};$app$main$ui$workspace$viewport$actions$on_pointer_enter$$=function($in_viewport_ref$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($in_viewport_ref$$,!0)})};
$app$main$ui$workspace$viewport$actions$on_pointer_leave$$=function($in_viewport_ref$jscomp$1$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($in_viewport_ref$jscomp$1$$,!1)})};
$app$main$ui$workspace$viewport$actions$on_key_down$$=function(){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$671$$){var $bevent$jscomp$3$$=$event$jscomp$671$$.getBrowserEvent(),$key$jscomp$420$$=$event$jscomp$671$$.key,$ctrl_QMARK_$jscomp$5$$=$event$jscomp$671$$.ctrlKey,$shift_QMARK_$jscomp$43$$=$event$jscomp$671$$.shiftKey,$alt_QMARK_$jscomp$21$$=$event$jscomp$671$$.altKey,$meta_QMARK_$jscomp$4$$=$event$jscomp$671$$.metaKey,$mod_QMARK_$jscomp$9$$=
$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$671$$),$editing_QMARK_$jscomp$12_target$jscomp$163$$=$APP.$app$util$dom$get_target$$($event$jscomp$671$$);$editing_QMARK_$jscomp$12_target$jscomp$163$$=$app$util$text$ui$closest_text_editor_content$$($editing_QMARK_$jscomp$12_target$jscomp$163$$)!=null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("rich-text",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$12_target$jscomp$163$$,"className"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("INPUT",
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$12_target$jscomp$163$$,"tagName"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("TEXTAREA",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$12_target$jscomp$163$$,"tagName"));return $APP.$cljs$core$truth_$$($bevent$jscomp$3$$.repeat)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$keyboard$KeyboardEvent$$($APP.$cljs$cst$1953$down$$,
$key$jscomp$420$$,$shift_QMARK_$jscomp$43$$,$ctrl_QMARK_$jscomp$5$$,$alt_QMARK_$jscomp$21$$,$meta_QMARK_$jscomp$4$$,$mod_QMARK_$jscomp$9$$,$editing_QMARK_$jscomp$12_target$jscomp$163$$,$event$jscomp$671$$,null,null,null))})};
$app$main$ui$workspace$viewport$actions$on_key_up$$=function(){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$672$$){var $key$jscomp$421$$=$event$jscomp$672$$.key,$ctrl_QMARK_$jscomp$6$$=$event$jscomp$672$$.ctrlKey,$shift_QMARK_$jscomp$44$$=$event$jscomp$672$$.shiftKey,$alt_QMARK_$jscomp$22$$=$event$jscomp$672$$.altKey,$meta_QMARK_$jscomp$5$$=$event$jscomp$672$$.metaKey,$mod_QMARK_$jscomp$10$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$672$$),
$editing_QMARK_$jscomp$13_target$jscomp$164$$=$APP.$app$util$dom$get_target$$($event$jscomp$672$$);$editing_QMARK_$jscomp$13_target$jscomp$164$$=$app$util$text$ui$closest_text_editor_content$$($editing_QMARK_$jscomp$13_target$jscomp$164$$)!=null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("rich-text",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$13_target$jscomp$164$$,"className"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("INPUT",
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$13_target$jscomp$164$$,"tagName"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("TEXTAREA",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$13_target$jscomp$164$$,"tagName"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$keyboard$KeyboardEvent$$($APP.$cljs$cst$1954$up$$,$key$jscomp$421$$,$shift_QMARK_$jscomp$44$$,$ctrl_QMARK_$jscomp$6$$,
$alt_QMARK_$jscomp$22$$,$meta_QMARK_$jscomp$5$$,$mod_QMARK_$jscomp$10$$,$editing_QMARK_$jscomp$13_target$jscomp$164$$,$event$jscomp$672$$,null,null,null))})};
$app$main$ui$workspace$viewport$actions$on_pointer_move$$=function($move_stream$jscomp$1$$){var $last_position$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$673$$){var $raw_pt$jscomp$2$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$673$$),$pt$jscomp$31$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($raw_pt$jscomp$2$$),$delta$jscomp$64$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($last_position$$))?
$APP.$app$common$geom$point$subtract$$($raw_pt$jscomp$2$$,$APP.$cljs$core$_deref$$($last_position$$)):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);$move_stream$jscomp$1$$.next($pt$jscomp$31$$);$APP.$cljs$core$reset_BANG_$$($last_position$$,$raw_pt$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$PointerEvent$$($APP.$cljs$cst$2170$viewport$$,$pt$jscomp$31$$,$event$jscomp$673$$.ctrlKey,$event$jscomp$673$$.shiftKey,
$event$jscomp$673$$.altKey,$event$jscomp$673$$.metaKey,$delta$jscomp$64$$,null,null,null))})};
$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$=function($state$jscomp$1212$$,$scale$jscomp$34$$,$pt$jscomp$32$$){var $pending_QMARK_$$=$state$jscomp$1212$$.zoomRafId>0;$state$jscomp$1212$$.scale*=$scale$jscomp$34$$;$state$jscomp$1212$$.zoomPt=$pt$jscomp$32$$;return $pending_QMARK_$$?null:$state$jscomp$1212$$.zoomRafId=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $s$jscomp$588$$=$state$jscomp$1212$$.scale,$zp$$=$state$jscomp$1212$$.zoomPt;$state$jscomp$1212$$.scale=
1;$state$jscomp$1212$$.zoomPt=null;$state$jscomp$1212$$.zoomRafId=0;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$set_zoom$$.$cljs$core$IFn$_invoke$arity$2$($zp$$,$s$jscomp$588$$))})};
$app$main$ui$workspace$viewport$actions$schedule_scroll_BANG_$$=function($state$jscomp$1213$$,$zoom$jscomp$84$$,$event$jscomp$674$$,$delta_x$jscomp$5$$,$delta_y$jscomp$3$$){var $pending_QMARK_$jscomp$1$$=$state$jscomp$1213$$.rafId>0;!$APP.$app$config$check_platform_QMARK_$$()&&$event$jscomp$674$$.shiftKey?$state$jscomp$1213$$.dx+=$delta_y$jscomp$3$$/$zoom$jscomp$84$$:($state$jscomp$1213$$.dx+=$delta_x$jscomp$5$$/$zoom$jscomp$84$$,$state$jscomp$1213$$.dy+=$delta_y$jscomp$3$$/$zoom$jscomp$84$$);$pending_QMARK_$jscomp$1$$||
($state$jscomp$1213$$.rafId=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $dx$jscomp$26$$=$state$jscomp$1213$$.dx,$dy$jscomp$26$$=$state$jscomp$1213$$.dy;$state$jscomp$1213$$.dx=0;$state$jscomp$1213$$.dy=0;$state$jscomp$1213$$.rafId=0;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,function($p1__80476_SHARP_$$){return $p1__80476_SHARP_$$+
$dx$jscomp$26$$},$APP.$cljs$cst$1511$y$$,function($p1__80477_SHARP_$$){return $p1__80477_SHARP_$$+$dy$jscomp$26$$}],null)))}))};
$app$main$ui$workspace$viewport$actions$on_mouse_wheel$$=function($zoom_ref$$){var $scroll_state$$=(0,$APP.$rumext$v2$use_ref$$)({dx:0,dy:0,rafId:0,scale:1,zoomPt:null,zoomRafId:0});return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$675_event__$1$jscomp$6$$){$event$jscomp$675_event__$1$jscomp$6$$=$event$jscomp$675_event__$1$jscomp$6$$.getBrowserEvent();var $or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$=$APP.$app$util$dom$get_target$$($event$jscomp$675_event__$1$jscomp$6$$),
$mod_QMARK_$jscomp$11$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$675_event__$1$jscomp$6$$),$ctrl_QMARK_$jscomp$7$$=$event$jscomp$675_event__$1$jscomp$6$$.ctrlKey,$picking_color_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("pixel-overlay",$or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$.id),$comments_layer_QMARK_$$=$APP.$app$util$dom$is_child_QMARK_$$($APP.$goog$dom$getElement$$("comments"),$or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$),$pt$jscomp$33_raw_pt$jscomp$3$$=
$APP.$app$util$dom$get_client_position$$($event$jscomp$675_event__$1$jscomp$6$$);$pt$jscomp$33_raw_pt$jscomp$3$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($pt$jscomp$33_raw_pt$jscomp$3$$);var $delta_x$jscomp$6_norm_event$$=$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$($event$jscomp$675_event__$1$jscomp$6$$),$delta_y$jscomp$4$$=$delta_x$jscomp$6_norm_event$$.pixelY;$delta_x$jscomp$6_norm_event$$=$delta_x$jscomp$6_norm_event$$.pixelX;var $delta_zoom_scale__$1$jscomp$1$$=
$delta_y$jscomp$4$$+$delta_x$jscomp$6_norm_event$$,$scale$jscomp$35$$=1+$APP.$app$common$math$abs$$(-.0057*$delta_zoom_scale__$1$jscomp$1$$);$delta_zoom_scale__$1$jscomp$1$$=$delta_zoom_scale__$1$jscomp$1$$>0?1/$scale$jscomp$35$$:$scale$jscomp$35$$;$or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$=$APP.$app$util$dom$is_child_QMARK_$$($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$),$or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$)?
$or__5025__auto__$jscomp$inline_13710_target$jscomp$165$$:$picking_color_QMARK_$jscomp$1$$)&&($APP.$app$util$dom$prevent_default$$($event$jscomp$675_event__$1$jscomp$6$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$675_event__$1$jscomp$6$$),$ctrl_QMARK_$jscomp$7$$||$mod_QMARK_$jscomp$11$$?$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$($APP.$rumext$v2$ref_val$$($scroll_state$$),$delta_zoom_scale__$1$jscomp$1$$,$pt$jscomp$33_raw_pt$jscomp$3$$):$app$main$ui$workspace$viewport$actions$schedule_scroll_BANG_$$($APP.$rumext$v2$ref_val$$($scroll_state$$),
$APP.$rumext$v2$ref_val$$($zoom_ref$$),$event$jscomp$675_event__$1$jscomp$6$$,$delta_x$jscomp$6_norm_event$$,$delta_y$jscomp$4$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($comments_layer_QMARK_$$)?$ctrl_QMARK_$jscomp$7$$||$mod_QMARK_$jscomp$11$$:$comments_layer_QMARK_$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$675_event__$1$jscomp$6$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$675_event__$1$jscomp$6$$),$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$($APP.$rumext$v2$ref_val$$($scroll_state$$),
$delta_zoom_scale__$1$jscomp$1$$,$pt$jscomp$33_raw_pt$jscomp$3$$)):null})};
$app$main$ui$workspace$viewport$actions$on_drag_enter$$=function($comp_inst_ref$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$376$$){var $component_inst_QMARK__80554$$=$APP.$rumext$v2$ref_val$$($comp_inst_ref$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$923$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$376$$,"penpot/component");return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$923$$)?$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($e$jscomp$376$$),
"viewport-controls")&&$APP.$cljs$core$not$$($component_inst_QMARK__80554$$):$and__5023__auto__$jscomp$923$$}())){var $point_80555_viewport_coord_80556$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$376$$.clientX,$e$jscomp$376$$.clientY);$point_80555_viewport_coord_80556$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($point_80555_viewport_coord_80556$$);var $component_80559_map__80483_80557$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$),
$final_x_80562_map__80483_80558__$1$$=$APP.$cljs$core$__destructure_map$$($component_80559_map__80483_80557$$);$component_80559_map__80483_80557$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($final_x_80562_map__80483_80558__$1$$,$APP.$cljs$cst$1625$component$$);var $file_id_80560$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($final_x_80562_map__80483_80558__$1$$,$APP.$cljs$cst$1644$file_id$$),$final_y_80563_shape_80561$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($final_x_80562_map__80483_80558__$1$$,
$APP.$cljs$cst$1811$shape$$);$final_x_80562_map__80483_80558__$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point_80555_viewport_coord_80556$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($final_y_80563_shape_80561$$)/2;$final_y_80563_shape_80561$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point_80555_viewport_coord_80556$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($final_y_80563_shape_80561$$)/2;$APP.$rumext$v2$set_ref_val_BANG_$$($comp_inst_ref$$,
!0);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$instantiate_component$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id_80560$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_80559_map__80483_80557$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($final_x_80562_map__80483_80558__$1$$,$final_y_80563_shape_80561$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3929$start_move_QMARK_$$,
!0,$APP.$cljs$cst$3930$initial_point$$,$point_80555_viewport_coord_80556$$,$APP.$cljs$cst$1786$origin$$,"sidebar"],null)))}return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$376$$,"penpot/shape");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$))return $or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$;
$or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$376$$,"penpot/component");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$))return $or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$;$or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$376$$,"Files");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$))return $or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$;$or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$376$$,
"text/uri-list");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$)?$or__5025__auto__$jscomp$1316_or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$35_or__5025__auto____$3$jscomp$11$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$376$$,"text/asset-id")}())?$APP.$app$util$dom$prevent_default$$($e$jscomp$376$$):null})};
$app$main$ui$workspace$viewport$actions$on_drag_over$$=function($move_stream$jscomp$2$$){var $on_pointer_move$jscomp$10$$=$app$main$ui$workspace$viewport$actions$on_pointer_move$$($move_stream$jscomp$2$$),$on_pointer_move__$1$$=$APP.$app$util$rxops$throttle_fn$$(function($e$jscomp$377$$){return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $on_pointer_move$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$on_pointer_move$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$377$$):
$on_pointer_move$jscomp$10$$($e$jscomp$377$$)})});return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$378$$){return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$378$$,"penpot/shape");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$))return $or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$;
$or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$378$$,"penpot/component");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$))return $or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$;$or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$378$$,"Files");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$))return $or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$;$or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$378$$,
"text/uri-list");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$)?$or__5025__auto__$jscomp$1317_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$12$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$378$$,"text/asset-id")}())?($on_pointer_move__$1$$($e$jscomp$378$$),$APP.$app$util$dom$prevent_default$$($e$jscomp$378$$)):null})};
$app$main$ui$workspace$viewport$actions$on_drop$$=function($file$jscomp$181$$,$comp_inst_ref$jscomp$2$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$){$APP.$app$util$dom$prevent_default$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$);var $event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$.clientX,
$data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$.clientY);$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$);if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,
"penpot/shape"))){$data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$=$APP.$app$util$dom$dnd$get_data$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,"penpot/shape");var $data__$1$jscomp$17_final_x_lines$jscomp$7$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$)/
2;$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$)/2;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$add_shape$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,
$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()),$APP.$cljs$cst$1510$x$$,$data__$1$jscomp$17_final_x_lines$jscomp$7$$),$APP.$cljs$cst$1511$y$$,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$)))}if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,"penpot/component")))return $event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=
$data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$.nativeEvent,$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1954$up$$,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.ctrlKey,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.shiftKey,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.altKey,
$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.metaKey,null,null,null)),$APP.$rumext$v2$set_ref_val_BANG_$$($comp_inst_ref$jscomp$2$$,!1);if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,"Files")))return $data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$.dataTransfer.files),
$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$181$$),$APP.$cljs$cst$1676$position$$,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,$APP.$cljs$cst$3698$blobs$$,$APP.$cljs$core$seq$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$)],
null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$));if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,"text/uri-list")))return $data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$=$APP.$app$util$dom$dnd$get_data$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,
"text/uri-list"),$data__$1$jscomp$17_final_x_lines$jscomp$7$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$,/\n|\r\n/),$data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$=$APP.$cljs$core$filterv$$(function($p1__80495_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__80495_SHARP_$$,"http")},$data__$1$jscomp$17_final_x_lines$jscomp$7$$),$data__$1$jscomp$17_final_x_lines$jscomp$7$$=
$APP.$cljs$core$filterv$$(function($p1__80496_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__80496_SHARP_$$,"data:image/")},$data__$1$jscomp$17_final_x_lines$jscomp$7$$),$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$181$$),$APP.$cljs$cst$1676$position$$,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$],
null),$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$APP.$cljs$core$seq$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,$APP.$cljs$cst$3694$uris$$,$data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,
$APP.$cljs$cst$3698$blobs$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$webapi$data_uri__GT_blob$$,$data__$1$jscomp$17_final_x_lines$jscomp$7$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$));$data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$.dataTransfer.files);
$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$181$$),$APP.$cljs$cst$1676$position$$,$event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,$APP.$cljs$cst$3698$blobs$$,$APP.$cljs$core$seq$$($data$jscomp$504_event$jscomp$676_files$jscomp$32_shape$jscomp$1067_uris$jscomp$12$$)],
null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($event__$1$jscomp$7_final_y_params$jscomp$433_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$))})};
$app$main$ui$workspace$viewport$actions$on_paste$$=function($disable_paste_ref$jscomp$1$$,$in_viewport_ref$jscomp$2$$,$read_only_QMARK_$jscomp$30$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$30$$)],function($event$jscomp$677$$){var $disable_paste_QMARK_$$=$APP.$rumext$v2$ref_val$$($disable_paste_ref$jscomp$1$$),$in_viewport_QMARK_$jscomp$5$$=$APP.$rumext$v2$ref_val$$($in_viewport_ref$jscomp$2$$);return!$APP.$cljs$core$contains_QMARK_$$($app$main$ui$workspace$viewport$actions$invalid_paste_targets$$,
$APP.$app$util$dom$get_tag_name$$($APP.$app$util$dom$get_target$$($event$jscomp$677$$)))&&$APP.$cljs$core$not$$($disable_paste_QMARK_$$)&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$30$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$paste_from_event$$($event$jscomp$677$$,$in_viewport_QMARK_$jscomp$5$$)):null})};
$app$main$ui$workspace$viewport$debug$debug_content_bounds$$=function($children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$){var $objects$jscomp$809$$=$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$.objects,$zoom$jscomp$86$$=$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$.zoom,$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$=$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$["selected-shapes"];$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$=
$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$["hover-top-frame-id"];$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)))?
$APP.$cljs$core$first$$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$):null;$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$=$APP.$cljs$core$truth_$$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$):$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)){$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$809$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)));var $bounds$jscomp$86$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$809$$),function($p1__80478_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,
$p1__80478_SHARP_$$),$APP.$cljs$cst$1604$points$$)}),$children_PLUS_bounds_layout_bounds$jscomp$12$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape__$1$jscomp$116$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$86$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$116$$))),$shape__$1$jscomp$116$$],null)},
$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$),$grid_layout_data$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$),
$children_PLUS_bounds_layout_bounds$jscomp$12$$,$bounds$jscomp$86$$,$objects$jscomp$809$$):null;$children_PLUS_bounds_layout_bounds$jscomp$12$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?$APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_bounds$$($bounds$jscomp$86$$,$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$,$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$,
$objects$jscomp$809$$):$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?$APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_bounds$$($bounds$jscomp$86$$,$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$,$grid_layout_data$$):null;$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?
$APP.$cljs$core$flatten$$($APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_points$$($bounds$jscomp$86$$,$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$,$children$jscomp$308_hover_top_frame_id$jscomp$1_props_80480$$,$objects$jscomp$809$$)):$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)?$APP.$cljs$core$flatten$$($APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_points$$($bounds$jscomp$86$$,
$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$,$grid_layout_data$$)):null;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"debug-layout",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80479_SHARP_$$){return""+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80479_SHARP_$$)??"")+", "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80479_SHARP_$$)??
"")},$children_PLUS_bounds_layout_bounds$jscomp$12$$)),style:{stroke:"red",fill:"none"}}),(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$209$$,$p$jscomp$258$$){$out_arr__44124__auto__$jscomp$209$$.push((0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$258$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$258$$),
r:4/$zoom$jscomp$86$$,style:{fill:"red"}}));return $out_arr__44124__auto__$jscomp$209$$},[],$layout_points$jscomp$2_selected_frame_selected_shapes$jscomp$27_shape$jscomp$1068$$)})]})}return null};
$app$main$ui$workspace$viewport$debug$debug_layout_lines$$=function($bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$){var $objects$jscomp$810$$=$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$.objects,$zoom$jscomp$87$$=$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$.zoom,$children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$=$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$["selected-shapes"];$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$=
$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$["hover-top-frame-id"];$children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$)))?
$APP.$cljs$core$first$$($children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$):null;var $shape$jscomp$1069$$=$APP.$cljs$core$truth_$$($children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$)?$children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$810$$,$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($shape$jscomp$1069$$)?$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1069$$):$shape$jscomp$1069$$)){var $row_QMARK_$jscomp$14$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1069$$),$col_QMARK_$jscomp$14$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1069$$);$children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80488_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80488_SHARP_$$),$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1069$$)),$p1__80488_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$810$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1069$$))));$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$810$$),function($p1__80489_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$810$$,$p1__80489_SHARP_$$),
$APP.$cljs$cst$1604$points$$)});$children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$=$APP.$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$1069$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1069$$),$children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$,$bounds$jscomp$87_hover_top_frame_id$jscomp$2_props_80494$$,$objects$jscomp$810$$);
var $layout_bounds$jscomp$13$$=$APP.$cljs$cst$3666$layout_bounds$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"debug-layout",pointerEvents:"none",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$210$$,$map__80503_map__80503__$1_p__80499$$){var $idx$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80503_map__80503__$1_p__80499$$,
0,null);$map__80503_map__80503__$1_p__80499$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80503_map__80503__$1_p__80499$$,1,null);$map__80503_map__80503__$1_p__80499$$=$APP.$cljs$core$__destructure_map$$($map__80503_map__80503__$1_p__80499$$);var $start_p$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80503_map__80503__$1_p__80499$$,$APP.$cljs$cst$3663$start_p$$),$line_width$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80503_map__80503__$1_p__80499$$,
$APP.$cljs$cst$3801$line_width$$),$line_height$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80503_map__80503__$1_p__80499$$,$APP.$cljs$cst$1765$line_height$$),$layout_gap_row$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80503_map__80503__$1_p__80499$$,$APP.$cljs$cst$3803$layout_gap_row$$),$layout_gap_col$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80503_map__80503__$1_p__80499$$,$APP.$cljs$cst$3804$layout_gap_col$$),
$num_children$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80503_map__80503__$1_p__80499$$,$APP.$cljs$cst$3802$num_children$$);$out_arr__44124__auto__$jscomp$210$$.push(function(){var $line_width__$1$jscomp$5_points$jscomp$103$$=$row_QMARK_$jscomp$14$$?$line_width$jscomp$11$$+($num_children$jscomp$8$$-1)*$layout_gap_row$jscomp$13$$:$line_width$jscomp$11$$,$line_height__$1$jscomp$9$$=$col_QMARK_$jscomp$14$$?$line_height$jscomp$24$$+($num_children$jscomp$8$$-1)*$layout_gap_col$jscomp$13$$:
$line_height$jscomp$24$$;$line_width__$1$jscomp$5_points$jscomp$103$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$start_p$jscomp$12$$,$APP.$app$common$geom$point$add$$($start_p$jscomp$12$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$13$$,$line_width__$1$jscomp$5_points$jscomp$103$$)),$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$12$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$13$$,
$line_width__$1$jscomp$5_points$jscomp$103$$)),$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$13$$,$line_height__$1$jscomp$9$$)),$APP.$app$common$geom$point$add$$($start_p$jscomp$12$$,$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$13$$,$line_height__$1$jscomp$9$$))],null);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"layout-line",children:(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80493_SHARP_$$){return""+
($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80493_SHARP_$$)??"")+", "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80493_SHARP_$$)??"")},$line_width__$1$jscomp$5_points$jscomp$103$$)),style:{stroke:"red",strokeWidth:2/$zoom$jscomp$87$$,strokeDasharray:""+10/$zoom$jscomp$87$$+" "+5/$zoom$jscomp$87$$}})},"line-"+($idx$jscomp$131$$??""))}());return $out_arr__44124__auto__$jscomp$210$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3055$layout_lines$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$309_layout_data$jscomp$18_selected_frame$jscomp$1_selected_shapes$jscomp$28$$)))})}return null};
$app$main$ui$workspace$viewport$debug$debug_parent_bounds$$=function($hover_top_frame_id$jscomp$4_props_80527$$){var $objects$jscomp$812$$=$hover_top_frame_id$jscomp$4_props_80527$$.objects,$zoom$jscomp$90$$=$hover_top_frame_id$jscomp$4_props_80527$$.zoom,$children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$=$hover_top_frame_id$jscomp$4_props_80527$$["selected-shapes"];$hover_top_frame_id$jscomp$4_props_80527$$=$hover_top_frame_id$jscomp$4_props_80527$$["hover-top-frame-id"];$children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$)))?$APP.$cljs$core$first$$($children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$):null;
var $parent$jscomp$303$$=$APP.$cljs$core$truth_$$($children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$)?$children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$812$$,$hover_top_frame_id$jscomp$4_props_80527$$),$parent_bounds$jscomp$18$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$303$$),$bounds$jscomp$89$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$812$$),
function($p1__80526_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$812$$,$p1__80526_SHARP_$$),$APP.$cljs$cst$1604$points$$)});return $parent$jscomp$303$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$303$$))?($children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$812$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$303$$))),(0,$APP.$rumext$v2$jsx$$)("g",{className:"debug-parent-bounds",pointerEvents:"none",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$212$$,$p__80528$$){var $idx$jscomp$133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80528$$,0,null),
$child$jscomp$124$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80528$$,1,null);$out_arr__44124__auto__$jscomp$212$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$shape_parent_bound$$,{zoom:$zoom$jscomp$90$$,shape:$child$jscomp$124$$,parent:$parent$jscomp$303$$},"bound-"+($idx$jscomp$133$$??"")),function(){var $child_bounds$jscomp$32_points$jscomp$104$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$124$$);
$child_bounds$jscomp$32_points$jscomp$104$$=$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$124$$)||$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$124$$)?$APP.$app$common$geom$shapes$flex_layout$child_layout_bound_points$$.$cljs$core$IFn$_invoke$arity$6$($parent$jscomp$303$$,$child$jscomp$124$$,$parent_bounds$jscomp$18$$,$child_bounds$jscomp$32_points$jscomp$104$$,$bounds$jscomp$89$$,$objects$jscomp$812$$):
$child_bounds$jscomp$32_points$jscomp$104$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$22$$,$point$jscomp$83$$){$out_arr__44124__auto____$1$jscomp$22$$.push((0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$83$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$83$$),r:2/$zoom$jscomp$90$$,style:{fill:"red"}}));return $out_arr__44124__auto____$1$jscomp$22$$},
[],$child_bounds$jscomp$32_points$jscomp$104$$)}()]}));return $out_arr__44124__auto__$jscomp$212$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$310_selected_frame$jscomp$3_selected_shapes$jscomp$30$$))})):null};
$app$main$ui$workspace$viewport$debug$debug_grid_layout$$=function($children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$){var $objects$jscomp$813$$=$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$.objects,$zoom$jscomp$91$$=$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$.zoom,$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$=
$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$["selected-shapes"];$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$=$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$["hover-top-frame-id"];$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$),
1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$)))?$APP.$cljs$core$first$$($bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$):null;var $parent$jscomp$304$$=$APP.$cljs$core$truth_$$($bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$)?
$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$813$$,$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$),$parent_bounds$jscomp$19$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$);$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$813$$),
function($p1__80532_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$813$$,$p1__80532_SHARP_$$),$APP.$cljs$cst$1604$points$$)});if($parent$jscomp$304$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$))){$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80533_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80533_SHARP_$$),$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$)),$p1__80533_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$813$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$))));var $width$jscomp$223$$=$APP.$app$common$geom$shapes$points$width_points$$($parent_bounds$jscomp$19$$),$height$jscomp$191$$=$APP.$app$common$geom$shapes$points$height_points$$($parent_bounds$jscomp$19$$),$origin$jscomp$63$$=$APP.$app$common$geom$shapes$points$origin$$($parent_bounds$jscomp$19$$);$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$=
$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($parent$jscomp$304$$,$parent_bounds$jscomp$19$$,$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$,$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$,$objects$jscomp$813$$);$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$=$APP.$cljs$core$__destructure_map$$($bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$);
$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$,$APP.$cljs$cst$3661$row_tracks$$);$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$,
$APP.$cljs$cst$3662$column_tracks$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$213$$,$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$){var $JSCompiler_temp_const$jscomp$1893$$=$out_arr__44124__auto__$jscomp$213$$.push;$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$=
$APP.$cljs$cst$2684$distance$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$);$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$=$APP.$app$common$geom$shapes$points$start_vv$$($parent_bounds$jscomp$19$$,$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$);
$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$=$APP.$app$common$geom$point$add$$($origin$jscomp$63$$,$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$);var $end_p$jscomp$inline_9198$$=$APP.$app$common$geom$point$add$$($JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$,
$APP.$app$common$geom$shapes$points$start_hv$$($parent_bounds$jscomp$19$$,$width$jscomp$223$$));$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$=(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$),
x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9198$$),y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9198$$),style:{stroke:"red",strokeWidth:1/$zoom$jscomp$91$$}});$JSCompiler_temp_const$jscomp$1893$$.call($out_arr__44124__auto__$jscomp$213$$,$JSCompiler_inline_result$jscomp$11044_JSCompiler_inline_result$jscomp$1895_p1__80535_SHARP_$jscomp$inline_13712_row_data_start_p$jscomp$inline_9197$$);return $out_arr__44124__auto__$jscomp$213$$},
[],$bounds$jscomp$90_map__80537_row_tracks$jscomp$5_selected_frame$jscomp$4_selected_shapes$jscomp$31$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$214$$,$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$){var $JSCompiler_temp_const$jscomp$1896$$=$out_arr__44124__auto__$jscomp$214$$.push;$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$=
$APP.$cljs$cst$2684$distance$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$);$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$=$APP.$app$common$geom$shapes$points$start_hv$$($parent_bounds$jscomp$19$$,$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$);
$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$=$APP.$app$common$geom$point$add$$($origin$jscomp$63$$,$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$);var $end_p$jscomp$inline_9201$$=$APP.$app$common$geom$point$add$$($JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$,
$APP.$app$common$geom$shapes$points$start_vv$$($parent_bounds$jscomp$19$$,$height$jscomp$191$$));$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$=(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$),
x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9201$$),y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9201$$),style:{stroke:"red",strokeWidth:1/$zoom$jscomp$91$$}});$JSCompiler_temp_const$jscomp$1896$$.call($out_arr__44124__auto__$jscomp$214$$,$JSCompiler_inline_result$jscomp$11043_JSCompiler_inline_result$jscomp$1898_column_data_p1__80534_SHARP_$jscomp$inline_13714_start_p$jscomp$inline_9200$$);return $out_arr__44124__auto__$jscomp$214$$},
[],$children$jscomp$311_column_tracks$jscomp$5_hover_top_frame_id$jscomp$5_map__80537__$1_props_80536$$)]})}return null};
$app$main$ui$workspace$viewport$debug$debug_text_wasm_position_data$$=function($position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$){var $zoom$jscomp$92$$=$position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$.zoom;$position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$=$position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$["selected-shapes"];$position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$)))?$APP.$cljs$core$first$$($position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$):
null;$position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$=$APP.$cljs$core$truth_$$($position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$)?$APP.$app$render_wasm$api$calculate_position_data$$($position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$):null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$215$$,$p__80540_x$jscomp$1276$$){var $height$jscomp$192_map__80541__$1$$=
$APP.$cljs$core$__destructure_map$$($p__80540_x$jscomp$1276$$);$p__80540_x$jscomp$1276$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$192_map__80541__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$500$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$192_map__80541__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$192_map__80541__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$192_map__80541__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$192_map__80541__$1$$,$APP.$cljs$cst$1522$height$$);$out_arr__44124__auto__$jscomp$215$$.push((0,$APP.$rumext$v2$jsx$$)("rect",{x:$p__80540_x$jscomp$1276$$,y:$y$jscomp$500$$-$height$jscomp$192_map__80541__$1$$,width:$width$jscomp$224$$,height:$height$jscomp$192_map__80541__$1$$,fill:"none",strokeWidth:1/$zoom$jscomp$92$$,stroke:"red"}));return $out_arr__44124__auto__$jscomp$215$$},[],$position_data$jscomp$18_props_80538_selected_shapes$jscomp$32_selected_text$jscomp$1$$)};
$app$main$ui$workspace$viewport$drawarea$make_edit_path_ref$$=function($id$jscomp$1045$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80481_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80481_SHARP_$$,$APP.$cljs$cst$1923$edit_path$$),$id$jscomp$1045$$)},$APP.$app$main$refs$workspace_local$$)};
$app$main$ui$workspace$viewport$drawarea$generic_draw_area_STAR_$$=function($map__80484_props_80482_x$jscomp$1277$$){var $zoom$jscomp$93$$=$map__80484_props_80482_x$jscomp$1277$$.zoom;$map__80484_props_80482_x$jscomp$1277$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80484_props_80482_x$jscomp$1277$$.shape,$APP.$cljs$cst$1605$selrect$$);var $height$jscomp$193_map__80484__$1$$=$APP.$cljs$core$__destructure_map$$($map__80484_props_80482_x$jscomp$1277$$);$map__80484_props_80482_x$jscomp$1277$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$193_map__80484__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$501$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$193_map__80484__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$225$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$193_map__80484__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$193_map__80484__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$193_map__80484__$1$$,
$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__80484_props_80482_x$jscomp$1277$$)?$APP.$cljs$core$truth_$$($y$jscomp$501$$)?$APP.$cljs$core$not$$(isNaN($map__80484_props_80482_x$jscomp$1277$$))&&$APP.$cljs$core$not$$(isNaN($y$jscomp$501$$)):$y$jscomp$501$$:$map__80484_props_80482_x$jscomp$1277$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main",x:$map__80484_props_80482_x$jscomp$1277$$,y:$y$jscomp$501$$,width:$width$jscomp$225$$,height:$height$jscomp$193_map__80484__$1$$,
style:{stroke:"var(--color-accent-tertiary)",fill:"none",strokeWidth:1/$zoom$jscomp$93$$}}):null};
$app$main$ui$workspace$viewport$drawarea$path_draw_area_STAR_$$=function($props_80490$$){var $edit_path_ref_edit_path_state_shape$jscomp$1073$$=$props_80490$$.shape,$shape_id$jscomp$176$$=$edit_path_ref_edit_path_state_shape$jscomp$1073$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_ref_edit_path_state_shape$jscomp$1073$$,$APP.$cljs$cst$266$id$$);$edit_path_ref_edit_path_state_shape$jscomp$1073$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$176$$)],
function(){return $app$main$ui$workspace$viewport$drawarea$make_edit_path_ref$$($shape_id$jscomp$176$$)});$edit_path_ref_edit_path_state_shape$jscomp$1073$$=$APP.$rumext$v2$deref$$($edit_path_ref_edit_path_state_shape$jscomp$1073$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,{...$props_80490$$,state:$edit_path_ref_edit_path_state_shape$jscomp$1073$$})};
$app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$=function($props_80497$$){var $zoom$jscomp$94$$=$props_80497$$.zoom,$tool$jscomp$4$$=$props_80497$$.tool,$shape$jscomp$1074$$=$props_80497$$.shape;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"draw-area",children:[(0,$APP.$rumext$v2$jsx$$)("g",{style:{pointerEvents:"none"},children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$shapes$shape_wrapper$$,{shape:$shape$jscomp$1074$$})}),function(){switch($tool$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?
$tool$jscomp$4$$.$fqn$:null){case "path":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$drawarea$path_draw_area_STAR_$$,$props_80497$$);case "curve":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$path$path_shape$$,{shape:$shape$jscomp$1074$$,zoom:$zoom$jscomp$94$$});default:return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$drawarea$generic_draw_area_STAR_$$,$props_80497$$)}}()]})};
$app$main$ui$workspace$viewport$frame_grid$square_grid_STAR_$$=function($grid_id$jscomp$29_props_80542$$){var $zoom$jscomp$95$$=$grid_id$jscomp$29_props_80542$$.zoom,$frame$jscomp$80$$=$grid_id$jscomp$29_props_80542$$.frame,$color_value__$1$jscomp$1_grid$jscomp$17$$=$grid_id$jscomp$29_props_80542$$.grid;$grid_id$jscomp$29_props_80542$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$common$uuid$next$$()});var $map__80543_map__80543__$1_size$jscomp$157$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($color_value__$1$jscomp$1_grid$jscomp$17$$);
$map__80543_map__80543__$1_size$jscomp$157$$=$APP.$cljs$core$__destructure_map$$($map__80543_map__80543__$1_size$jscomp$157$$);$map__80543_map__80543__$1_size$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80543_map__80543__$1_size$jscomp$157$$,$APP.$cljs$cst$874$size$$);var $color_value$jscomp$7_map__80544$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($color_value__$1$jscomp$1_grid$jscomp$17$$)),
$color_opacity$jscomp$1_map__80544__$1$$=$APP.$cljs$core$__destructure_map$$($color_value$jscomp$7_map__80544$$);$color_value$jscomp$7_map__80544$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_opacity$jscomp$1_map__80544__$1$$,$APP.$cljs$cst$1298$color$$);$color_opacity$jscomp$1_map__80544__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_opacity$jscomp$1_map__80544__$1$$,$APP.$cljs$cst$1734$opacity$$);$color_value__$1$jscomp$1_grid$jscomp$17$$=$APP.$cljs$core$truth_$$($color_value$jscomp$7_map__80544$$)?
$color_value$jscomp$7_map__80544$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($color_value__$1$jscomp$1_grid$jscomp$17$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$260$value$$],null)));return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("pattern",
{id:$grid_id$jscomp$29_props_80542$$,x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80$$),width:$map__80543_map__80543__$1_size$jscomp$157$$,height:$map__80543_map__80543__$1_size$jscomp$157$$,patternUnits:"userSpaceOnUse",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:["M ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80543_map__80543__$1_size$jscomp$157$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0),
" L ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80543_map__80543__$1_size$jscomp$157$$)," "].join(""),style:{fill:"none",stroke:$color_value__$1$jscomp$1_grid$jscomp$17$$,strokeOpacity:$color_opacity$jscomp$1_map__80544__$1$$,strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$95$$)}})})}),
(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80$$),fill:["url(#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($grid_id$jscomp$29_props_80542$$),")"].join("")})]})};
$app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$=function($gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$){var $zoom$jscomp$96$$=$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$.zoom,$frame$jscomp$81$$=$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$.frame,$key$jscomp$422$$=$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$.key,$grid$jscomp$18$$=$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$.grid;$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$=
$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$18$$));$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$=$APP.$cljs$core$__destructure_map$$($gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$);var $color_value$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$,$APP.$cljs$cst$1298$color$$),$color_opacity$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$,
$APP.$cljs$cst$1734$opacity$$),$color_value__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($color_value$jscomp$8$$)?$color_value$jscomp$8$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$18$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$260$value$$],null)));$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$=
$app$common$geom$grid$grid_gutter$$($frame$jscomp$81$$,$grid$jscomp$18$$);var $gutter_QMARK_$$=$gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$!=null&&!$APP.$app$common$math$almost_zero_QMARK_$$($gutter$jscomp$5_map__80546_map__80546__$1_props_80545$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"grid",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$216$$,$map__80553_p__80549_x$jscomp$1278$$){var $idx$jscomp$134$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80553_p__80549_x$jscomp$1278$$,
0,null);$map__80553_p__80549_x$jscomp$1278$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80553_p__80549_x$jscomp$1278$$,1,null);var $height$jscomp$194_map__80553__$1$$=$APP.$cljs$core$__destructure_map$$($map__80553_p__80549_x$jscomp$1278$$);$map__80553_p__80549_x$jscomp$1278$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__80553__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$502$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__80553__$1$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__80553__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$194_map__80553__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__80553__$1$$,$APP.$cljs$cst$1522$height$$);$out_arr__44124__auto__$jscomp$216$$.push($gutter_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__80553_p__80549_x$jscomp$1278$$,y:$y$jscomp$502$$,width:$map__80553_p__80549_x$jscomp$1278$$+
$width$jscomp$226$$-$map__80553_p__80549_x$jscomp$1278$$,height:$y$jscomp$502$$+$height$jscomp$194_map__80553__$1$$-$y$jscomp$502$$,style:{fill:$color_value__$1$jscomp$2$$,strokeWidth:0,opacity:$color_opacity$jscomp$2$$}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$422$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80553_p__80549_x$jscomp$1278$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$502$$)].join("")):!$gutter_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$18$$))?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$134$$,0)?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__80553_p__80549_x$jscomp$1278$$,y1:$y$jscomp$502$$,x2:$map__80553_p__80549_x$jscomp$1278$$,y2:$y$jscomp$502$$+$height$jscomp$194_map__80553__$1$$,style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$96$$,strokeOpacity:$color_opacity$jscomp$2$$,
fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$422$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80553_p__80549_x$jscomp$1278$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$502$$),"-start"].join("")):null,(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__80553_p__80549_x$jscomp$1278$$+$width$jscomp$226$$,y1:$y$jscomp$502$$,x2:$map__80553_p__80549_x$jscomp$1278$$+$width$jscomp$226$$,y2:$y$jscomp$502$$+$height$jscomp$194_map__80553__$1$$,
style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$96$$,strokeOpacity:$color_opacity$jscomp$2$$,fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$422$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80553_p__80549_x$jscomp$1278$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$502$$),"-end"].join(""))]}):!$gutter_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$18$$))?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$134$$,0)?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__80553_p__80549_x$jscomp$1278$$,y1:$y$jscomp$502$$,x2:$map__80553_p__80549_x$jscomp$1278$$+$width$jscomp$226$$,y2:$y$jscomp$502$$,style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$96$$,strokeOpacity:$color_opacity$jscomp$2$$,fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$422$$),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80553_p__80549_x$jscomp$1278$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$502$$),"-start"].join("")):null,(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__80553_p__80549_x$jscomp$1278$$,y1:$y$jscomp$502$$+$height$jscomp$194_map__80553__$1$$,x2:$map__80553_p__80549_x$jscomp$1278$$+$width$jscomp$226$$,y2:$y$jscomp$502$$+$height$jscomp$194_map__80553__$1$$,style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$96$$,
strokeOpacity:$color_opacity$jscomp$2$$,fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$422$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80553_p__80549_x$jscomp$1278$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$502$$),"-end"].join(""))]}):null);return $out_arr__44124__auto__$jscomp$216$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$geom$grid$grid_areas$$($frame$jscomp$81$$,$grid$jscomp$18$$)))})};
$app$main$ui$workspace$viewport$frame_grid$frame_clip_area$$=function($map__80565__$1_p__80564_selrect$jscomp$86$$,$parents$jscomp$21$$){$map__80565__$1_p__80564_selrect$jscomp$86$$=$APP.$cljs$core$__destructure_map$$($map__80565__$1_p__80564_selrect$jscomp$86$$);$map__80565__$1_p__80564_selrect$jscomp$86$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80565__$1_p__80564_selrect$jscomp$86$$,$APP.$cljs$cst$1605$selrect$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($sr$jscomp$3$$,
$parent$jscomp$305$$){return!$APP.$app$common$files$helpers$root_QMARK_$$($parent$jscomp$305$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$))?$APP.$app$common$geom$rect$clip_rect$$($sr$jscomp$3$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$)):$sr$jscomp$3$$},$map__80565__$1_p__80564_selrect$jscomp$86$$,
$parents$jscomp$21$$)};
$app$main$ui$workspace$viewport$frame_grid$has_grid_QMARK_$$=function($grids$jscomp$2_map__80575__$1_p__80574$$){$grids$jscomp$2_map__80575__$1_p__80574$$=$APP.$cljs$core$__destructure_map$$($grids$jscomp$2_map__80575__$1_p__80574$$);$grids$jscomp$2_map__80575__$1_p__80574$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grids$jscomp$2_map__80575__$1_p__80574$$,$APP.$cljs$cst$2050$grids$$);return $grids$jscomp$2_map__80575__$1_p__80574$$!=null&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1932$display$$,$grids$jscomp$2_map__80575__$1_p__80574$$))};
$app$main$ui$workspace$viewport$gradients$shadow_STAR_$$=function($id$jscomp$1046_props_80577$$){var $offset$jscomp$212$$=$id$jscomp$1046_props_80577$$.offset;$id$jscomp$1046_props_80577$$=$id$jscomp$1046_props_80577$$.id;return(0,$APP.$rumext$v2$jsxs$$)("filter",{id:$id$jscomp$1046_props_80577$$,x:"-10%",y:"-10%",width:"120%",height:"120%",filterUnits:"objectBoundingBox",colorInterpolationFilters:"sRGB",children:[(0,$APP.$rumext$v2$jsx$$)("feFlood",{floodOpacity:"0",result:"BackgroundImageFix"}),
(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{"in":"SourceAlpha",type:"matrix",values:"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0"}),(0,$APP.$rumext$v2$jsx$$)("feOffset",{dy:$offset$jscomp$212$$}),(0,$APP.$rumext$v2$jsx$$)("feGaussianBlur",{stdDeviation:"1"}),(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{type:"matrix",values:"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.15 0"}),(0,$APP.$rumext$v2$jsx$$)("feBlend",{mode:"normal",in2:"BackgroundImageFix",result:$id$jscomp$1046_props_80577$$}),(0,$APP.$rumext$v2$jsx$$)("feBlend",
{mode:"normal","in":"SourceGraphic",in2:$id$jscomp$1046_props_80577$$,result:"shape"})]})};
$app$main$ui$workspace$viewport$gradients$gradient_color_handler_STAR_$$=function($props_80578$$){var $on_pointer_down$jscomp$14$$=$props_80578$$.onPointerDown,$on_pointer_move$jscomp$11$$=$props_80578$$.onPointerMove,$on_lost_pointer_capture$jscomp$8$$=$props_80578$$.onLostPointerCapture,$zoom$jscomp$99$$=$props_80578$$.zoom,$selected$jscomp$196$$=$props_80578$$.selected,$index$jscomp$564$$=$props_80578$$.index,$color$jscomp$187$$=$props_80578$$.color,$on_click$jscomp$57$$=$props_80578$$.onClick,
$on_pointer_up$jscomp$3$$=$props_80578$$.onPointerUp,$point$jscomp$84$$=$props_80578$$.point;return(0,$APP.$rumext$v2$jsxs$$)("g",{filter:"url(#gradient-drop-shadow)",style:{cursor:"pointer"},transform:$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$($props_80578$$.angle,$point$jscomp$84$$),children:[(0,$APP.$rumext$v2$jsx$$)("image",{href:"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAIAAAC0tAIdAAACvUlEQVQoFQGyAk39AeLi4gAAAAAAAB0dHQAAAAAAAOPj4wAAAAAAAB0dHQAAAAAAAOPj4wAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAB////AAAAAAAA4+PjAAAAAAAAHR0dAAAAAAAA4+PjAAAAAAAAHR0dAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAATj4+MAAAAAAAAdHR0AAAAAAADj4+MAAAAAAAAdHR0AAAAAAADj4+MAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAjScaa0cU7nIAAAAASUVORK5CYII\x3d",
x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$+12/$zoom$jscomp$99$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$,width:20.5/$zoom$jscomp$99$$,height:20.5/$zoom$jscomp$99$$}),(0,$APP.$rumext$v2$jsx$$)("rect",{width:20.5/$zoom$jscomp$99$$/2,height:20.5/$zoom$jscomp$99$$,x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$+12/$zoom$jscomp$99$$,
onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_pointer_up$jscomp$3$$,$APP.$cljs$cst$1854$to_p$$),fill:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$187$$),rx:4/$zoom$jscomp$99$$,onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_click$jscomp$57$$,$APP.$cljs$cst$1854$to_p$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_pointer_down$jscomp$14$$,
$APP.$cljs$cst$1854$to_p$$)}),$APP.$cljs$core$truth_$$($selected$jscomp$196$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{width:20.5/$zoom$jscomp$99$$+4/$zoom$jscomp$99$$,height:20.5/$zoom$jscomp$99$$+4/$zoom$jscomp$99$$,x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$+12/$zoom$jscomp$99$$-2/$zoom$jscomp$99$$,stroke:"var(--color-accent-tertiary)",fill:"transparent",strokeWidth:2/$zoom$jscomp$99$$,rx:(4+2/$zoom$jscomp$99$$)/$zoom$jscomp$99$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-
10.25/$zoom$jscomp$99$$-2/$zoom$jscomp$99$$,pointerEvents:"none"}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:20.5/$zoom$jscomp$99$$,height:20.5/$zoom$jscomp$99$$,x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$+12/$zoom$jscomp$99$$,"data-index":$index$jscomp$564$$,onPointerUp:$on_pointer_up$jscomp$3$$,"data-allow-click-modal":"colorpicker",stroke:"var(--app-white)",fill:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$187$$),
strokeWidth:2/$zoom$jscomp$99$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$8$$,rx:4/$zoom$jscomp$99$$,onClick:$on_click$jscomp$57$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$99$$,onPointerMove:$on_pointer_move$jscomp$11$$,fillOpacity:$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$187$$),onPointerDown:$on_pointer_down$jscomp$14$$,pointerEvents:"all"}),(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$),
cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$),r:2/$zoom$jscomp$99$$,fill:"var(--app-white)"})]})};
$app$main$ui$workspace$viewport$gradients$gradient_handler_transformed_STAR_$$=function($endpoint_on_pointer_enter_props_80584$$){function $endpoint_on_pointer_up$$($_position$$,$event$jscomp$679$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$679$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$679$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$679$$);$APP.$cljs$core$reset_BANG_$$($moving_point$$,null);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2204$hover$$,null)}function $endpoint_on_pointer_down$$($position$jscomp$213$$,$event$jscomp$678$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$678$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$678$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$678$$);$APP.$cljs$core$reset_BANG_$$($moving_point$$,$position$jscomp$213$$);return $APP.$cljs$core$truth_$$(function(){var $fexpr__80585$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1853$from_p$$,null,$APP.$cljs$cst$1854$to_p$$,null],null),null);return $fexpr__80585$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__80585$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$213$$):$fexpr__80585$$($position$jscomp$213$$)}())?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$select_colorpicker_gradient_stop$$(function(){var $G__80586__$1$$=$position$jscomp$213$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$213$$.$fqn$:
null;switch($G__80586__$1$$){case "from-p":return 0;case "to-p":return 1;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80586__$1$$)].join(""));}}())):null}var $to_p$jscomp$14$$=$endpoint_on_pointer_enter_props_80584$$.toP,$zoom$jscomp$100$$=$endpoint_on_pointer_enter_props_80584$$.zoom,$stops$jscomp$21$$=$endpoint_on_pointer_enter_props_80584$$.stops,$on_change_width$$=$endpoint_on_pointer_enter_props_80584$$.onChangeWidth,$on_change_start$jscomp$1$$=
$endpoint_on_pointer_enter_props_80584$$.onChangeStart,$on_change_finish$$=$endpoint_on_pointer_enter_props_80584$$.onChangeFinish,$width_p$$=$endpoint_on_pointer_enter_props_80584$$.widthP,$editing$jscomp$4$$=$endpoint_on_pointer_enter_props_80584$$.editing,$from_p$jscomp$16$$=$endpoint_on_pointer_enter_props_80584$$.fromP,$moving_point$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$angle$jscomp$40$$=90+$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($from_p$jscomp$16$$,
$to_p$jscomp$14$$),$dragging_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_offset$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handler_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5871$display_QMARK_$$,!1,$APP.$cljs$cst$195$offset$$,0,$APP.$cljs$cst$2204$hover$$,null],null)),$can_add_stop_QMARK_$jscomp$2$$=$app$main$features$use_feature$$("render-wasm/v1")?$APP.$cljs$core$count$$($stops$jscomp$21$$)<
16:!0;$endpoint_on_pointer_enter_props_80584$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($position$jscomp$214$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2204$hover$$,$position$jscomp$214$$)});var $endpoint_on_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$2204$hover$$,null)}),$points_on_pointer_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $can_add_stop_QMARK_$jscomp$2$$?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,$cljs$cst$5871$display_QMARK_$$,!0):null}),$points_on_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5871$display_QMARK_$$,!1)}),$points_on_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$APP.$app$util$dom$stop_propagation$$($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);
if($can_add_stop_QMARK_$jscomp$2$$){$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$APP.$app$util$dom$get_client_position$$($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);
var $lv_nv$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv_nv$$=$APP.$app$common$geom$point$normal_left$$($lv_nv$$);$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$APP.$app$common$math$precision$$($APP.$app$common$geom$shapes$points$project_t$$($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_p$jscomp$16$$,$to_p$jscomp$14$$],null),$lv_nv$$),2);$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$app$common$types$color$interpolate_gradient$$($stops$jscomp$21$$,$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$21$$,$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,
$e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($e$jscomp$379_new_stop$jscomp$3_offset$jscomp$213_position$jscomp$215_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$))}return null}),$points_on_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($from_p$jscomp$16$$),
$APP.$rumext$v2$adapt$$($to_p$jscomp$14$$)],function($e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$){$e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$=$APP.$app$util$dom$get_client_position$$($e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$);$e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$);
var $lv$jscomp$1_nv$jscomp$1$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv$jscomp$1_nv$jscomp$1$$=$APP.$app$common$geom$point$normal_left$$($lv$jscomp$1_nv$jscomp$1$$);$e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$=$APP.$app$common$geom$shapes$points$project_t$$($e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$from_p$jscomp$16$$,$to_p$jscomp$14$$],null),$lv$jscomp$1_nv$jscomp$1$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,$e$jscomp$380_offset$jscomp$214_position$jscomp$216_raw_pt$jscomp$5$$)}),$handle_marker_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($event$jscomp$680$$){var $index$jscomp$565$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$680$$),
"index")),$stop$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$21$$,$index$jscomp$565$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$680$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$select_colorpicker_gradient_stop$$($index$jscomp$565$$));$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$4$$,!0);return $APP.$rumext$v2$set_ref_val_BANG_$$($start_offset$jscomp$2$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$12$$))}),
$handle_marker_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$4$$))){var $index$jscomp$566$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$),
"index"));$event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$);$event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$);var $lv$jscomp$2_nv$jscomp$2$$=
$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv$jscomp$2_nv$jscomp$2$$=$APP.$app$common$geom$point$normal_left$$($lv$jscomp$2_nv$jscomp$2$$);$event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$=$APP.$app$common$geom$shapes$points$project_t$$($event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$from_p$jscomp$16$$,$to_p$jscomp$14$$],null),$lv$jscomp$2_nv$jscomp$2$$);$event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$=$APP.$app$common$math$precision$$($APP.$app$common$math$clamp$$($event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$,0,1),2);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($APP.$cljs$core$assoc_in$$($stops$jscomp$21$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$566$$,$APP.$cljs$cst$195$offset$$],null),$event$jscomp$681_offset$jscomp$215_offset__$1$jscomp$26_position$jscomp$217_raw_pt$jscomp$6$$)))}return null}),$handle_marker_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($event$jscomp$682_stops__$1$jscomp$9$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$682_stops__$1$jscomp$9$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$4$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_offset$jscomp$2$$,null);$event$jscomp$682_stops__$1$jscomp$9$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$21$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($event$jscomp$682_stops__$1$jscomp$9$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($moving_point$$)),$APP.$rumext$v2$adapt$$($from_p$jscomp$16$$),$APP.$rumext$v2$adapt$$($to_p$jscomp$14$$),$APP.$rumext$v2$adapt$$($width_p$$)],function(){var $subs$jscomp$32$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($pt$jscomp$34_y0$jscomp$inline_9207$$){var $G__80587_new_width_p_width_v$$=$APP.$cljs$core$_deref$$($moving_point$$);switch($G__80587_new_width_p_width_v$$ instanceof
$APP.$cljs$core$Keyword$$?$G__80587_new_width_p_width_v$$.$fqn$:null){case "from-p":return $APP.$cljs$core$truth_$$($on_change_start$jscomp$1$$)?$on_change_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$34_y0$jscomp$inline_9207$$):$on_change_start$jscomp$1$$($pt$jscomp$34_y0$jscomp$inline_9207$$):null;case "to-p":return $APP.$cljs$core$truth_$$($on_change_finish$$)?$on_change_finish$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_finish$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$34_y0$jscomp$inline_9207$$):
$on_change_finish$$($pt$jscomp$34_y0$jscomp$inline_9207$$):null;case "width-p":if($APP.$cljs$core$truth_$$($on_change_width$$)){$G__80587_new_width_p_width_v$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($width_p$$,$from_p$jscomp$16$$));var $distance$jscomp$9_x0$jscomp$inline_9206$$=$pt$jscomp$34_y0$jscomp$inline_9207$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$34_y0$jscomp$inline_9207$$,$APP.$cljs$cst$1510$x$$);$pt$jscomp$34_y0$jscomp$inline_9207$$=
$pt$jscomp$34_y0$jscomp$inline_9207$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$34_y0$jscomp$inline_9207$$,$APP.$cljs$cst$1511$y$$);var $x1$jscomp$inline_9208$$=$from_p$jscomp$16$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from_p$jscomp$16$$,$APP.$cljs$cst$1510$x$$),$y1$jscomp$inline_9209$$=$from_p$jscomp$16$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from_p$jscomp$16$$,$APP.$cljs$cst$1511$y$$),$x2$jscomp$inline_9210$$=$to_p$jscomp$14$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($to_p$jscomp$14$$,$APP.$cljs$cst$1510$x$$),$y2$jscomp$inline_9211$$=$to_p$jscomp$14$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($to_p$jscomp$14$$,$APP.$cljs$cst$1511$y$$);$distance$jscomp$9_x0$jscomp$inline_9206$$=$APP.$app$common$math$abs$$($distance$jscomp$9_x0$jscomp$inline_9206$$*($y2$jscomp$inline_9211$$-$y1$jscomp$inline_9209$$)+-($pt$jscomp$34_y0$jscomp$inline_9207$$*($x2$jscomp$inline_9210$$-$x1$jscomp$inline_9208$$))+$x2$jscomp$inline_9210$$*
$y1$jscomp$inline_9209$$+-($y2$jscomp$inline_9211$$*$x1$jscomp$inline_9208$$))/$APP.$app$common$geom$point$distance$$($to_p$jscomp$14$$,$from_p$jscomp$16$$);$G__80587_new_width_p_width_v$$=$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$multiply$$($G__80587_new_width_p_width_v$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($distance$jscomp$9_x0$jscomp$inline_9206$$)));return $on_change_width$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_width$$.$cljs$core$IFn$_invoke$arity$1$($G__80587_new_width_p_width_v$$):
$on_change_width$$($G__80587_new_width_p_width_v$$)}return null;default:return null}},$APP.$beicon$v2$core$map$$($APP.$app$util$mouse$get_pointer_position$$,$APP.$beicon$v2$core$filter$$(function($p1__80580_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2170$viewport$$,$p1__80580_SHARP_$$.source)},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,$APP.$app$main$store$stream$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$32$$)}});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"gradient-handlers",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$shadow_STAR_$$,{id:"gradient-drop-shadow",offset:2/$zoom$jscomp$100$$})}),function(){var $lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$=
$APP.$app$common$geom$point$normal_left$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$);var $width$jscomp$227$$=40/$zoom$jscomp$100$$;$lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$,$width$jscomp$227$$/-2)),$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,
$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$,$width$jscomp$227$$/2)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$,$width$jscomp$227$$/2)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$,$width$jscomp$227$$/-2))],null);$lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$=
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80581_SHARP_$$){return""+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80581_SHARP_$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80581_SHARP_$$)??"")},$lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$));return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$lv$jscomp$3_nv$jscomp$3_points$jscomp$105_points_str$jscomp$2$$,
"data-allow-click-modal":"colorpicker",fill:"transparent",pointerEvents:"all",onPointerEnter:$points_on_pointer_enter$$,onPointerLeave:$points_on_pointer_leave$$,onPointerDown:$points_on_pointer_down$$,onPointerMove:$points_on_pointer_move$$})}(),(0,$APP.$rumext$v2$jsx$$)("g",{filter:"url(#gradient-drop-shadow)",children:function(){var $points$jscomp$106_pu$$=$APP.$app$common$geom$point$unit$$($app$common$geom$point$normal_right$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$))),
$sc$jscomp$13$$=2/$zoom$jscomp$100$$/2;$points$jscomp$106_pu$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$106_pu$$,-$sc$jscomp$13$$)),$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$106_pu$$,$sc$jscomp$13$$)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($points$jscomp$106_pu$$,
$sc$jscomp$13$$)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($points$jscomp$106_pu$$,-$sc$jscomp$13$$))],null);return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80582_SHARP_$$){return""+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80582_SHARP_$$)??"")+", "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80582_SHARP_$$)??
"")},$points$jscomp$106_pu$$)),fill:"var(--app-white)"})}()}),$APP.$cljs$core$truth_$$($width_p$$)?(0,$APP.$rumext$v2$jsx$$)("g",{filter:"url(#gradient-drop-shadow)",children:function(){var $points$jscomp$107_pu$jscomp$1$$=$APP.$app$common$geom$point$unit$$($app$common$geom$point$normal_right$$($APP.$app$common$geom$point$subtract$$($width_p$$,$from_p$jscomp$16$$))),$sc$jscomp$14$$=2/$zoom$jscomp$100$$/2;$points$jscomp$107_pu$jscomp$1$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$107_pu$jscomp$1$$,-$sc$jscomp$14$$)),$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$107_pu$jscomp$1$$,$sc$jscomp$14$$)),$APP.$app$common$geom$point$add$$($width_p$$,$APP.$app$common$geom$point$scale$$($points$jscomp$107_pu$jscomp$1$$,$sc$jscomp$14$$)),$APP.$app$common$geom$point$add$$($width_p$$,$APP.$app$common$geom$point$scale$$($points$jscomp$107_pu$jscomp$1$$,
-$sc$jscomp$14$$))],null);return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80583_SHARP_$$){return""+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80583_SHARP_$$)??"")+", "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80583_SHARP_$$)??"")},$points$jscomp$107_pu$jscomp$1$$)),fill:"var(--app-white)"})}()}):null,$APP.$cljs$core$truth_$$($width_p$$)?
(0,$APP.$rumext$v2$jsxs$$)("g",{filter:"url(#gradient-drop-shadow)",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5872$width_p$$,$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),fill:"var(--color-accent-tertiary)",
r:6/$zoom$jscomp$100$$}):null,(0,$APP.$rumext$v2$jsx$$)("circle",{"data-allow-click-modal":"colorpicker",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),r:4/$zoom$jscomp$100$$,fill:"var(--app-white)"}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,
$cljs$cst$5872$width_p$$),"data-allow-click-modal":"colorpicker",fill:"transparent",r:15/$zoom$jscomp$100$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_down$$,$cljs$cst$5872$width_p$$),onPointerLeave:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_leave$$,$cljs$cst$5872$width_p$$),cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_enter_props_80584$$,
$cljs$cst$5872$width_p$$),pointerEvents:"all"})]}):null,(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1853$from_p$$,$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),
fill:"var(--color-accent-tertiary)",r:6/$zoom$jscomp$100$$}):null,(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),fill:"var(--app-white)",r:4/$zoom$jscomp$100$$}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,
$APP.$cljs$cst$1853$from_p$$),"data-allow-click-modal":"colorpicker",fill:"transparent",onLostPointerCapture:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,$APP.$cljs$cst$1853$from_p$$),r:20/$zoom$jscomp$100$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_down$$,$APP.$cljs$cst$1853$from_p$$),onPointerLeave:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_leave$$,$APP.$cljs$cst$1853$from_p$$),
cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_enter_props_80584$$,$APP.$cljs$cst$1853$from_p$$),pointerEvents:"all"})]}),(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1854$to_p$$,$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?(0,$APP.$rumext$v2$jsx$$)("circle",
{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),fill:"var(--color-accent-tertiary)",r:6/$zoom$jscomp$100$$}):null,(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),fill:"var(--app-white)",
r:4/$zoom$jscomp$100$$}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,$APP.$cljs$cst$1854$to_p$$),"data-allow-click-modal":"colorpicker",fill:"transparent",onLostPointerCapture:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,$APP.$cljs$cst$1853$from_p$$),r:20/$zoom$jscomp$100$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_down$$,
$APP.$cljs$cst$1854$to_p$$),onPointerLeave:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_leave$$,$APP.$cljs$cst$1854$to_p$$),cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_enter_props_80584$$,$APP.$cljs$cst$1854$to_p$$),pointerEvents:"all"})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$219$$,
$JSCompiler_temp_const$jscomp$1899_p__80588$$){var $JSCompiler_inline_result$jscomp$1901_index$jscomp$567$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1899_p__80588$$,0,null),$stop$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1899_p__80588$$,1,null);$JSCompiler_temp_const$jscomp$1899_p__80588$$=$out_arr__44124__auto__$jscomp$219$$.push;var $stop_p$jscomp$inline_9213$$=$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,
$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$13$$)));$JSCompiler_inline_result$jscomp$1901_index$jscomp$567$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_color_handler_STAR_$$,{selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing$jscomp$4$$,$JSCompiler_inline_result$jscomp$1901_index$jscomp$567$$),index:$JSCompiler_inline_result$jscomp$1901_index$jscomp$567$$,
zoom:$zoom$jscomp$100$$,angle:$angle$jscomp$40$$,onLostPointerCapture:$handle_marker_lost_pointer_capture$$,onPointerMove:$handle_marker_pointer_move$$,onPointerDown:$handle_marker_pointer_down$$,color:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$13$$),$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$13$$)],null),point:$stop_p$jscomp$inline_9213$$},
$JSCompiler_inline_result$jscomp$1901_index$jscomp$567$$);$JSCompiler_temp_const$jscomp$1899_p__80588$$.call($out_arr__44124__auto__$jscomp$219$$,$JSCompiler_inline_result$jscomp$1901_index$jscomp$567$$);return $out_arr__44124__auto__$jscomp$219$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($stops$jscomp$21$$)),$APP.$cljs$core$truth_$$($cljs$cst$5871$display_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?function(){var $p$jscomp$259$$=
$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$))));return(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$259$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$259$$),
r:4/$zoom$jscomp$100$$,fill:"var(--app-white)"})}():null]})};
$app$main$ui$workspace$viewport$gradients$gradient_handlers_impl_STAR_$$=function($props_80592_to_p$jscomp$15_transform$jscomp$113$$){var $zoom$jscomp$101$$=$props_80592_to_p$jscomp$15_transform$jscomp$113$$.zoom,$stops$jscomp$22$$=$props_80592_to_p$jscomp$15_transform$jscomp$113$$.stops,$editing$jscomp$5$$=$props_80592_to_p$jscomp$15_transform$jscomp$113$$.editing,$gradient$jscomp$28$$=$props_80592_to_p$jscomp$15_transform$jscomp$113$$.gradient,$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$=
$props_80592_to_p$jscomp$15_transform$jscomp$113$$.shape;$props_80592_to_p$jscomp$15_transform$jscomp$113$$=$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$);var $transform_inverse$jscomp$25$$=$APP.$app$common$geom$shapes$inverse_transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$);
$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$);$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$);
var $x$jscomp$1279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$503$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$,
$APP.$cljs$cst$290$width$$),$height$jscomp$195$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$,$APP.$cljs$cst$1522$height$$),$from_p$jscomp$17$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1279$$+$width$jscomp$228$$*$APP.$cljs$cst$1729$start_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$28$$),$y$jscomp$503$$+
$height$jscomp$195$$*$APP.$cljs$cst$1730$start_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$28$$)),$props_80592_to_p$jscomp$15_transform$jscomp$113$$);$props_80592_to_p$jscomp$15_transform$jscomp$113$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1279$$+$width$jscomp$228$$*$APP.$cljs$cst$1731$end_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$28$$),$y$jscomp$503$$+$height$jscomp$195$$*$APP.$cljs$cst$1732$end_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$28$$)),
$props_80592_to_p$jscomp$15_transform$jscomp$113$$);$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($props_80592_to_p$jscomp$15_transform$jscomp$113$$,$from_p$jscomp$17$$);var $gradient_length$$=$APP.$app$common$geom$point$length$$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$);$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$=
$APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$multiply$$($app$common$geom$point$normal_right$$($gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$28$$)*($gradient_length$$/($height$jscomp$195$$/2)))),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$228$$/
2));$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$app$common$geom$point$add$$($from_p$jscomp$17$$,$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$);var $change_BANG_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($changes$jscomp$333$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_gradient$$($changes$jscomp$333$$))}),
$on_change_start$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transform_inverse$jscomp$25$$),$APP.$rumext$v2$adapt$$($width$jscomp$228$$),$APP.$rumext$v2$adapt$$($height$jscomp$195$$)],function($G__80594_point$jscomp$85_start_x$jscomp$6$$){var $point__$1$jscomp$2_start_y$jscomp$5$$=$APP.$app$common$geom$point$transform$$($G__80594_point$jscomp$85_start_x$jscomp$6$$,$transform_inverse$jscomp$25$$);$G__80594_point$jscomp$85_start_x$jscomp$6$$=($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point__$1$jscomp$2_start_y$jscomp$5$$)-
$x$jscomp$1279$$)/$width$jscomp$228$$;$point__$1$jscomp$2_start_y$jscomp$5$$=($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point__$1$jscomp$2_start_y$jscomp$5$$)-$y$jscomp$503$$)/$height$jscomp$195$$;$G__80594_point$jscomp$85_start_x$jscomp$6$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1729$start_x$$,$G__80594_point$jscomp$85_start_x$jscomp$6$$,$APP.$cljs$cst$1730$start_y$$,$point__$1$jscomp$2_start_y$jscomp$5$$],null);return $change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80594_point$jscomp$85_start_x$jscomp$6$$):$change_BANG_$jscomp$1$$($G__80594_point$jscomp$85_start_x$jscomp$6$$)}),$on_change_finish$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transform_inverse$jscomp$25$$),$APP.$rumext$v2$adapt$$($width$jscomp$228$$),$APP.$rumext$v2$adapt$$($height$jscomp$195$$)],function($G__80595_end_x$jscomp$5_point$jscomp$86$$){var $end_y$jscomp$5_point__$1$jscomp$3$$=
$APP.$app$common$geom$point$transform$$($G__80595_end_x$jscomp$5_point$jscomp$86$$,$transform_inverse$jscomp$25$$);$G__80595_end_x$jscomp$5_point$jscomp$86$$=($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end_y$jscomp$5_point__$1$jscomp$3$$)-$x$jscomp$1279$$)/$width$jscomp$228$$;$end_y$jscomp$5_point__$1$jscomp$3$$=($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end_y$jscomp$5_point__$1$jscomp$3$$)-$y$jscomp$503$$)/$height$jscomp$195$$;$G__80595_end_x$jscomp$5_point$jscomp$86$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1731$end_x$$,$G__80595_end_x$jscomp$5_point$jscomp$86$$,$APP.$cljs$cst$1732$end_y$$,$end_y$jscomp$5_point__$1$jscomp$3$$],null);return $change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80595_end_x$jscomp$5_point$jscomp$86$$):$change_BANG_$jscomp$1$$($G__80595_end_x$jscomp$5_point$jscomp$86$$)}),$on_change_width$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($gradient_length$$),
$APP.$rumext$v2$adapt$$($width$jscomp$228$$),$APP.$rumext$v2$adapt$$($height$jscomp$195$$)],function($G__80596_norm_dist_point$jscomp$87$$){var $scale_factor_y$$=$gradient_length$$/($height$jscomp$195$$/2);$G__80596_norm_dist_point$jscomp$87$$=$APP.$app$common$geom$point$distance$$($G__80596_norm_dist_point$jscomp$87$$,$from_p$jscomp$17$$)/($width$jscomp$228$$/2*$scale_factor_y$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__80596_norm_dist_point$jscomp$87$$)?$APP.$app$common$math$finite_QMARK_$$($G__80596_norm_dist_point$jscomp$87$$):
$G__80596_norm_dist_point$jscomp$87$$)?($G__80596_norm_dist_point$jscomp$87$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$290$width$$,$G__80596_norm_dist_point$jscomp$87$$],null),$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80596_norm_dist_point$jscomp$87$$):$change_BANG_$jscomp$1$$($G__80596_norm_dist_point$jscomp$87$$)):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handler_transformed_STAR_$$,
{stops:$stops$jscomp$22$$,widthP:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1728$radial$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$28$$))?$gradient_vec$jscomp$1_map__80593_map__80593__$1_shape$jscomp$1075_width_p$jscomp$1_width_v$jscomp$1$$:null,zoom:$zoom$jscomp$101$$,onChangeFinish:$on_change_finish$jscomp$1$$,fromP:$from_p$jscomp$17$$,toP:$props_80592_to_p$jscomp$15_transform$jscomp$113$$,onChangeStart:$on_change_start$jscomp$2$$,editing:$editing$jscomp$5$$,
onChangeWidth:$on_change_width$jscomp$1$$})};
$app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$=function($result$jscomp$380$$,$JSCompiler_inline_result$jscomp$1904_next_fn$jscomp$5$$){var $JSCompiler_temp_const$jscomp$1902$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$,$G__80600$jscomp$inline_9215$$=$APP.$cljs$core$last$$($result$jscomp$380$$);$JSCompiler_inline_result$jscomp$1904_next_fn$jscomp$5$$=$JSCompiler_inline_result$jscomp$1904_next_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1904_next_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__80600$jscomp$inline_9215$$):
$JSCompiler_inline_result$jscomp$1904_next_fn$jscomp$5$$($G__80600$jscomp$inline_9215$$);return $JSCompiler_temp_const$jscomp$1902$$.call($APP.$cljs$core$conj$$,$result$jscomp$380$$,$JSCompiler_inline_result$jscomp$1904_next_fn$jscomp$5$$)};
$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$=function($G__80603__$1_p__80601_type$jscomp$711$$){var $map__80602__$1_value$jscomp$1000$$=$APP.$cljs$core$__destructure_map$$($G__80603__$1_p__80601_type$jscomp$711$$);$G__80603__$1_p__80601_type$jscomp$711$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80602__$1_value$jscomp$1000$$,$APP.$cljs$cst$139$type$$);$map__80602__$1_value$jscomp$1000$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80602__$1_value$jscomp$1000$$,
$APP.$cljs$cst$260$value$$);$G__80603__$1_p__80601_type$jscomp$711$$=$G__80603__$1_p__80601_type$jscomp$711$$ instanceof $APP.$cljs$core$Keyword$$?$G__80603__$1_p__80601_type$jscomp$711$$.$fqn$:null;switch($G__80603__$1_p__80601_type$jscomp$711$$){case "fixed":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__80602__$1_value$jscomp$1000$$)??"")+"PX";case "percent":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__80602__$1_value$jscomp$1000$$)??
"")+"%";case "flex":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__80602__$1_value$jscomp$1000$$)??"")+"FR";case "auto":return"AUTO";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80603__$1_p__80601_type$jscomp$711$$)].join(""));}};
$app$main$ui$workspace$viewport$grid_layout_editor$grid_edition_actions$$=function($props_80604$$){var $shape$jscomp$1077$$=$props_80604$$.shape;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_grid_layout_editor__grid-actions",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_grid_layout_editor__grid-actions-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_grid_layout_editor__grid-actions-title",
children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.title")," ",(0,$APP.$rumext$v2$jsx$$)("span",{css:$cljs$cst$5873$board_name$$,children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1077$$)})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$locate_board$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1077$$)))},
className:"main_ui_workspace_viewport_grid_layout_editor__locate-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.top-bar.locate")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$())},className:"main_ui_workspace_viewport_grid_layout_editor__done-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.top-bar.done")})]})})};
$app$main$ui$workspace$viewport$grid_layout_editor$grid_editor_frame$$=function($frame_points_origin$jscomp$64_props_80613$$){var $bounds$jscomp$91$$=$frame_points_origin$jscomp$64_props_80613$$.bounds,$width$jscomp$229$$=$frame_points_origin$jscomp$64_props_80613$$.width,$height$jscomp$196$$=$frame_points_origin$jscomp$64_props_80613$$.height,$zoom$jscomp$103$$=$frame_points_origin$jscomp$64_props_80613$$.zoom;$frame_points_origin$jscomp$64_props_80613$$=$APP.$app$common$geom$shapes$points$origin$$($bounds$jscomp$91$$);
$frame_points_origin$jscomp$64_props_80613$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_points_origin$jscomp$64_props_80613$$],null),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($p1__80607_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__80607_SHARP_$$,
$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$91$$,$width$jscomp$229$$+70/$zoom$jscomp$103$$))},function($p1__80608_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__80608_SHARP_$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$91$$,40/$zoom$jscomp$103$$))},function($p1__80609_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__80609_SHARP_$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$91$$,$width$jscomp$229$$+110/$zoom$jscomp$103$$))},
function($p1__80610_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__80610_SHARP_$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$91$$,$height$jscomp$196$$+110/$zoom$jscomp$103$$))},function($p1__80611_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__80611_SHARP_$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$91$$,40/$zoom$jscomp$103$$))}],null));return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80612_SHARP_$$){return""+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80612_SHARP_$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80612_SHARP_$$)??"")},$frame_points_origin$jscomp$64_props_80613$$)),className:"main_ui_workspace_viewport_grid_layout_editor__grid-frame"})};
$app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$=function($props_80614_rect_x$jscomp$1$$){var $rect_y$jscomp$1_start_p$jscomp$15$$=$props_80614_rect_x$jscomp$1$$["start-p"],$zoom$jscomp$104$$=$props_80614_rect_x$jscomp$1$$.zoom,$on_click$jscomp$58$$=$props_80614_rect_x$jscomp$1$$["on-click"],$icon_y_vec__80615$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_80614_rect_x$jscomp$1$$.type,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-40/$zoom$jscomp$104$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)+9/$zoom$jscomp$104$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-31/$zoom$jscomp$104$$],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-40/$zoom$jscomp$104$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-31/$zoom$jscomp$104$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)+9/$zoom$jscomp$104$$],null);$props_80614_rect_x$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__80615$$,
0,null);$rect_y$jscomp$1_start_p$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__80615$$,1,null);var $icon_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__80615$$,2,null);$icon_y_vec__80615$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__80615$$,3,null);var $handle_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$58$$)],function(){return $APP.$cljs$core$truth_$$($on_click$jscomp$58$$)?
$on_click$jscomp$58$$.$cljs$core$IFn$_invoke$arity$0$?$on_click$jscomp$58$$.$cljs$core$IFn$_invoke$arity$0$():$on_click$jscomp$58$$():null});return(0,$APP.$rumext$v2$jsxs$$)("g",{onClick:$handle_click$jscomp$5$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-plus-button",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$props_80614_rect_x$jscomp$1$$+6/$zoom$jscomp$104$$,y:$rect_y$jscomp$1_start_p$jscomp$15$$+6/$zoom$jscomp$104$$,width:28/$zoom$jscomp$104$$,height:28/$zoom$jscomp$104$$,
rx:4/$zoom$jscomp$104$$,ry:4/$zoom$jscomp$104$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-plus-shape"}),(0,$APP.$rumext$v2$jsx$$)("use",{x:$icon_x$$,y:$icon_y_vec__80615$$,width:22/$zoom$jscomp$104$$,height:22/$zoom$jscomp$104$$,href:"#icon-add",className:"main_ui_workspace_viewport_grid_layout_editor__grid-plus-icon"})]})};
$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$=function($handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$){$handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$=$APP.$cljs$core$__destructure_map$$($handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$);var $on_drag_start$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$,$cljs$cst$5874$on_drag_start$$),$on_drag_end$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$,
$cljs$cst$5875$on_drag_end$$),$on_drag_delta$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$,$cljs$cst$5876$on_drag_delta$$),$on_drag_position$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$,$cljs$cst$5877$on_drag_position$$),$dragging_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_pos_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_pos_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);
$handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_drag_start$jscomp$5$$)],function($event$jscomp$683$$){var $raw_pt$jscomp$7$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$683$$),$position$jscomp$218$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($raw_pt$jscomp$7$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$683$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$5$$,
!0);$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$$,$raw_pt$jscomp$7$$);$APP.$rumext$v2$set_ref_val_BANG_$$($current_pos_ref$$,$raw_pt$jscomp$7$$);return $APP.$cljs$core$truth_$$($on_drag_start$jscomp$5$$)?$on_drag_start$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_start$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$683$$,$position$jscomp$218$$):$on_drag_start$jscomp$5$$($event$jscomp$683$$,$position$jscomp$218$$):null});var $handle_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_drag_end$jscomp$1$$)],
function($event$jscomp$684$$){var $delta$jscomp$65_raw_pt$jscomp$8$$=$APP.$rumext$v2$ref_val$$($current_pos_ref$$),$position$jscomp$219$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($delta$jscomp$65_raw_pt$jscomp$8$$);$delta$jscomp$65_raw_pt$jscomp$8$$=$APP.$app$common$geom$point$subtract$$($delta$jscomp$65_raw_pt$jscomp$8$$,$APP.$rumext$v2$ref_val$$($start_pos_ref$$));$APP.$app$util$dom$release_pointer$$($event$jscomp$684$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$5$$,
!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$$,null);return $APP.$cljs$core$truth_$$($on_drag_end$jscomp$1$$)?$on_drag_end$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$on_drag_end$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$684$$,$position$jscomp$219$$,$delta$jscomp$65_raw_pt$jscomp$8$$):$on_drag_end$jscomp$1$$($event$jscomp$684$$,$position$jscomp$219$$,$delta$jscomp$65_raw_pt$jscomp$8$$):null}),$handle_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_drag_delta$$),
$APP.$rumext$v2$adapt$$($on_drag_position$$)],function($event$jscomp$685$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$5$$))){var $G__80621_80806_start$jscomp$253$$=$APP.$rumext$v2$ref_val$$($start_pos_ref$$),$pos$jscomp$157$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$685$$),$pt$jscomp$35$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($pos$jscomp$157$$);$APP.$rumext$v2$set_ref_val_BANG_$$($current_pos_ref$$,$pos$jscomp$157$$);$APP.$cljs$core$truth_$$($on_drag_delta$$)&&
($G__80621_80806_start$jscomp$253$$=$APP.$app$common$geom$point$subtract$$($pos$jscomp$157$$,$G__80621_80806_start$jscomp$253$$),$on_drag_delta$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_delta$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$685$$,$G__80621_80806_start$jscomp$253$$):$on_drag_delta$$($event$jscomp$685$$,$G__80621_80806_start$jscomp$253$$));return $APP.$cljs$core$truth_$$($on_drag_position$$)?$on_drag_position$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_position$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$685$$,
$pt$jscomp$35$$):$on_drag_position$$($event$jscomp$685$$,$pt$jscomp$35$$):null}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5878$handle_pointer_down$$,$handle_pointer_down$jscomp$1_map__80619__$1_p__80618$$,$cljs$cst$5879$handle_lost_pointer_capture$$,$handle_lost_pointer_capture$$,$cljs$cst$5880$handle_pointer_move$$,$handle_pointer_move$$],null)};
$app$main$ui$workspace$viewport$grid_layout_editor$resize_cell_handler$$=function($handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$){var $shape$jscomp$1078$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.shape,$x$jscomp$1280$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.x,$y$jscomp$504$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.y,$width$jscomp$230$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.width,
$height$jscomp$197$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.height,$handler$jscomp$48$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.handler,$on_set_modifiers$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$["on-set-modifiers"],$on_clear_modifiers$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$["on-clear-modifiers"],$objects$jscomp$814$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),
$cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$=$APP.$cljs$core$__destructure_map$$($handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.cell);$cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$,$APP.$cljs$cst$266$id$$);$cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1078$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$],null));$cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$=$APP.$cljs$core$__destructure_map$$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$);
var $row$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$,$APP.$cljs$cst$1656$row$$),$column$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$,$APP.$cljs$cst$216$column$$),$row_span$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$,
$APP.$cljs$cst$1657$row_span$$),$column_span$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$,$APP.$cljs$cst$1658$column_span$$);$cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$.direction;var $layout_data$jscomp$19$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$["layout-data"],
$calculate_drag_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1078$$),$APP.$rumext$v2$adapt$$($row$jscomp$35$$),$APP.$rumext$v2$adapt$$($column$jscomp$45$$),$APP.$rumext$v2$adapt$$($row_span$jscomp$13$$),$APP.$rumext$v2$adapt$$($column_span$jscomp$13$$)],function($new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$){$new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$=$APP.$app$common$geom$shapes$grid_layout$positions$get_position_grid_coord$$($layout_data$jscomp$19$$,
$new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$);var $drag_row$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$,0,null),$drag_column$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$,1,null),$new_column_span$jscomp$1_vec__80629$$=function(){var $G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$=$handler$jscomp$48$$ instanceof
$APP.$cljs$core$Keyword$$?$handler$jscomp$48$$.$fqn$:null;switch($G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$){case "top":$G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$=function(){var $x__5113__auto__$jscomp$87$$=$row$jscomp$35$$+($row_span$jscomp$13$$-1);return $x__5113__auto__$jscomp$87$$<$drag_row$$?$x__5113__auto__$jscomp$87$$:$drag_row$$}();var $new_column_span$jscomp$2_new_row_span$jscomp$3$$=$row$jscomp$35$$-$G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$+$row_span$jscomp$13$$;
return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$,$column$jscomp$45$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$,$column_span$jscomp$13$$],null);case "left":return $G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$=function(){var $x__5113__auto__$jscomp$88$$=$column$jscomp$45$$+($column_span$jscomp$13$$-1);return $x__5113__auto__$jscomp$88$$<$drag_column$$?$x__5113__auto__$jscomp$88$$:
$drag_column$$}(),$new_column_span$jscomp$2_new_row_span$jscomp$3$$=$column$jscomp$45$$-$G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$+$column_span$jscomp$13$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$35$$,$G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$,$row_span$jscomp$13$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$],null);case "bottom":return $new_column_span$jscomp$2_new_row_span$jscomp$3$$=function(){var $y__5111__auto__$jscomp$164$$=
$drag_row$$-$row$jscomp$35$$+1;return 1>$y__5111__auto__$jscomp$164$$?1:$y__5111__auto__$jscomp$164$$}(),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$35$$,$column$jscomp$45$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$,$column_span$jscomp$13$$],null);case "right":return $new_column_span$jscomp$2_new_row_span$jscomp$3$$=function(){var $y__5111__auto__$jscomp$165$$=$drag_column$$-$column$jscomp$45$$+1;return 1>$y__5111__auto__$jscomp$165$$?
1:$y__5111__auto__$jscomp$165$$}(),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$35$$,$column$jscomp$45$$,$row_span$jscomp$13$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80632__$1_new_column$jscomp$2_new_row$jscomp$2$$)].join(""));}}();$new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__80629$$,
0,null);var $new_column$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__80629$$,1,null),$new_row_span$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__80629$$,2,null);$new_column_span$jscomp$1_vec__80629$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__80629$$,3,null);$new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$=$APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($shape$jscomp$1078$$,
$row$jscomp$35$$,$column$jscomp$45$$,$new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$,$new_column$jscomp$1$$,$new_row_span$jscomp$2$$,$new_column_span$jscomp$1_vec__80629$$),$objects$jscomp$814$$);return $APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$)),
$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$)),$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($new_row$jscomp$1_position$jscomp$220_shape__$1$jscomp$117_vec__80626$$))});$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_drag_modifiers$$),
$APP.$rumext$v2$adapt$$($on_set_modifiers$$)],function($_$jscomp$3092_modifiers$jscomp$126$$,$modif_tree$jscomp$63_position$jscomp$221$$){$_$jscomp$3092_modifiers$jscomp$126$$=$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($modif_tree$jscomp$63_position$jscomp$221$$):$calculate_drag_modifiers$$($modif_tree$jscomp$63_position$jscomp$221$$);$modif_tree$jscomp$63_position$jscomp$221$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1078$$)],null),$_$jscomp$3092_modifiers$jscomp$126$$);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($APP.$cljs$core$truth_$$($on_set_modifiers$$)&&($on_set_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$on_set_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3092_modifiers$jscomp$126$$):$on_set_modifiers$$($_$jscomp$3092_modifiers$jscomp$126$$)),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modif_tree$jscomp$63_position$jscomp$221$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modif_tree$jscomp$63_position$jscomp$221$$,!1,!1,null))});var $handle_drag_end_handle_lost_pointer_capture$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_drag_modifiers$$),
$APP.$rumext$v2$adapt$$($on_clear_modifiers$$)],function($_$jscomp$3093_modifiers$jscomp$127$$,$modif_tree$jscomp$64_position$jscomp$222$$){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($_$jscomp$3093_modifiers$jscomp$127$$=$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($modif_tree$jscomp$64_position$jscomp$222$$):$calculate_drag_modifiers$$($modif_tree$jscomp$64_position$jscomp$222$$),
$modif_tree$jscomp$64_position$jscomp$222$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1078$$)],null),$_$jscomp$3093_modifiers$jscomp$127$$),$APP.$cljs$core$truth_$$($on_clear_modifiers$$)&&($on_clear_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$on_clear_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3093_modifiers$jscomp$127$$):
$on_clear_modifiers$$($_$jscomp$3093_modifiers$jscomp$127$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($modif_tree$jscomp$64_position$jscomp$222$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});
$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5877$on_drag_position$$,$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$,$cljs$cst$5875$on_drag_end$$,$handle_drag_end_handle_lost_pointer_capture$jscomp$1$$],null));var $handle_pointer_move$jscomp$1_map__80625__$1$$=$APP.$cljs$core$__destructure_map$$($handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$);
$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$1_map__80625__$1$$,$cljs$cst$5878$handle_pointer_down$$);$handle_drag_end_handle_lost_pointer_capture$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$1_map__80625__$1$$,$cljs$cst$5879$handle_lost_pointer_capture$$);$handle_pointer_move$jscomp$1_map__80625__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$1_map__80625__$1$$,
$cljs$cst$5880$handle_pointer_move$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$230$$,height:$height$jscomp$197$$,className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__80623__$1_map__80624_map__80624__$1$$,$APP.$cljs$cst$1656$row$$)?$app$main$ui$css_cursors$get_dynamic$$("scale-ns",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1078$$)):$app$main$ui$css_cursors$get_dynamic$$("scale-ew",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1078$$)),
x:$x$jscomp$1280$$,style:{fill:"transparent",strokeWidth:0},onLostPointerCapture:$handle_drag_end_handle_lost_pointer_capture$jscomp$1$$,y:$y$jscomp$504$$,onPointerMove:$handle_pointer_move$jscomp$1_map__80625__$1$$,onPointerDown:$handle_drag_position_handle_pointer_down$jscomp$2_map__80625_props_80622$$})};
$app$main$ui$workspace$viewport$grid_layout_editor$grid_cell_area_label$$=function($props_80633_text$jscomp$151$$){var $area_y$jscomp$1_cell_origin$jscomp$2$$=$props_80633_text$jscomp$151$$.origin,$area_x$jscomp$1_cell_width$jscomp$2$$=$props_80633_text$jscomp$151$$.width,$zoom$jscomp$105$$=$props_80633_text$jscomp$151$$.zoom;$props_80633_text$jscomp$151$$=$props_80633_text$jscomp$151$$.text;var $area_width$jscomp$1$$=10*$APP.$cljs$core$count$$($props_80633_text$jscomp$151$$)/$zoom$jscomp$105$$,$area_height$jscomp$1$$=
25/$zoom$jscomp$105$$;$area_x$jscomp$1_cell_width$jscomp$2$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($area_y$jscomp$1_cell_origin$jscomp$2$$)+$area_x$jscomp$1_cell_width$jscomp$2$$-$area_width$jscomp$1$$;$area_y$jscomp$1_cell_origin$jscomp$2$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($area_y$jscomp$1_cell_origin$jscomp$2$$);var $area_text_x$jscomp$1$$=$area_x$jscomp$1_cell_width$jscomp$2$$+$area_width$jscomp$1$$/2,$area_text_y$jscomp$1$$=$area_y$jscomp$1_cell_origin$jscomp$2$$+
$area_height$jscomp$1$$/2;return(0,$APP.$rumext$v2$jsxs$$)("g",{pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$area_x$jscomp$1_cell_width$jscomp$2$$,y:$area_y$jscomp$1_cell_origin$jscomp$2$$,width:$area_width$jscomp$1$$,height:$area_height$jscomp$1$$,style:{fill:"var(--grid-editor-area-background)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$area_text_x$jscomp$1$$,y:$area_text_y$jscomp$1$$,style:{fill:"var(--grid-editor-area-text)",fontFamily:"worksans",fontWeight:600,
fontSize:14/$zoom$jscomp$105$$,alignmentBaseline:"central",textAnchor:"middle"},children:$props_80633_text$jscomp$151$$})]})};
$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$=function($type$jscomp$713$$,$shape$jscomp$1080$$,$index$jscomp$568$$,$track_before$$,$track_after$$,$zoom$jscomp$107$$,$snap_pixel_QMARK_$jscomp$9$$,$on_set_modifiers$jscomp$2$$,$on_clear_modifiers$jscomp$2$$){var $start_size_before$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$start_size_after$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$handle_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1080$$),
$APP.$rumext$v2$adapt$$($track_before$$),$APP.$rumext$v2$adapt$$($track_after$$)],function(){$APP.$cljs$core$reset_BANG_$$($start_size_before$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_before$$));$APP.$cljs$core$reset_BANG_$$($start_size_after$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_after$$));var $modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$type$jscomp$713$$)?
$APP.$cljs$cst$1695$layout_grid_columns$$:$APP.$cljs$cst$1694$layout_grid_rows$$;var $G__80647$jscomp$inline_13719_shape__$1$jscomp$118$$=$track_before$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1080$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$,$index$jscomp$568$$-1],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_before$$)],null)):$shape$jscomp$1080$$;$G__80647$jscomp$inline_13719_shape__$1$jscomp$118$$=$track_after$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__80647$jscomp$inline_13719_shape__$1$jscomp$118$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$,
$index$jscomp$568$$],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_after$$)],null)):$G__80647$jscomp$inline_13719_shape__$1$jscomp$118$$;$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$=$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__80647$jscomp$inline_13719_shape__$1$jscomp$118$$,$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$));$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__80647$jscomp$inline_13719_shape__$1$jscomp$118$$)],
null),$modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modif_tree$jscomp$65_modifiers$jscomp$128_tracks_prop$jscomp$2$$,
!1,!1,null))}),$calculate_modifiers$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1080$$),$APP.$rumext$v2$adapt$$($track_before$$),$APP.$rumext$v2$adapt$$($track_after$$)],function($position$jscomp$224_shape__$1$jscomp$119$$){var $axis$jscomp$42_vec__80650$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$type$jscomp$713$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1510$x$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1511$y$$],null),$tracks_prop$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($axis$jscomp$42_vec__80650$$,0,null);$axis$jscomp$42_vec__80650$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($axis$jscomp$42_vec__80650$$,1,null);var $precision$jscomp$25$$=
$APP.$cljs$core$truth_$$($snap_pixel_QMARK_$jscomp$9$$)?$APP.$app$common$math$round$$:$APP.$cljs$core$identity$$,$delta$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$224_shape__$1$jscomp$119$$,$axis$jscomp$42_vec__80650$$)/$zoom$jscomp$107$$,$new_size_before$$=function(){var $G__80653$jscomp$inline_9217_y__5111__auto__$jscomp$166$$=$APP.$cljs$core$_deref$$($start_size_before$$)+$delta$jscomp$66$$;$G__80653$jscomp$inline_9217_y__5111__auto__$jscomp$166$$=$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$?
$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$($G__80653$jscomp$inline_9217_y__5111__auto__$jscomp$166$$):$precision$jscomp$25$$($G__80653$jscomp$inline_9217_y__5111__auto__$jscomp$166$$);return 0>$G__80653$jscomp$inline_9217_y__5111__auto__$jscomp$166$$?0:$G__80653$jscomp$inline_9217_y__5111__auto__$jscomp$166$$}(),$new_size_after$$=function(){var $G__80654$jscomp$inline_9219_y__5111__auto__$jscomp$167$$=$APP.$cljs$core$_deref$$($start_size_after$$)-$delta$jscomp$66$$;$G__80654$jscomp$inline_9219_y__5111__auto__$jscomp$167$$=
$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$?$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$($G__80654$jscomp$inline_9219_y__5111__auto__$jscomp$167$$):$precision$jscomp$25$$($G__80654$jscomp$inline_9219_y__5111__auto__$jscomp$167$$);return 0>$G__80654$jscomp$inline_9219_y__5111__auto__$jscomp$167$$?0:$G__80654$jscomp$inline_9219_y__5111__auto__$jscomp$167$$}();$position$jscomp$224_shape__$1$jscomp$119$$=function(){var $G__80655$$=$track_before$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1080$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tracks_prop$jscomp$3$$,$index$jscomp$568$$-1],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$260$value$$,$new_size_before$$],null)):$shape$jscomp$1080$$;return $track_after$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__80655$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$tracks_prop$jscomp$3$$,$index$jscomp$568$$],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$260$value$$,$new_size_after$$],null)):$G__80655$$}();return $APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$tracks_prop$jscomp$3$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$224_shape__$1$jscomp$119$$,$tracks_prop$jscomp$3$$))}),$handle_drag_position$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_modifiers$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_set_modifiers$jscomp$2$$)],function($_$jscomp$3094_modifiers$jscomp$129$$,$modif_tree$jscomp$66_position$jscomp$225$$){$_$jscomp$3094_modifiers$jscomp$129$$=$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($modif_tree$jscomp$66_position$jscomp$225$$):$calculate_modifiers$jscomp$1$$($modif_tree$jscomp$66_position$jscomp$225$$);
$modif_tree$jscomp$66_position$jscomp$225$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1080$$)],null),$_$jscomp$3094_modifiers$jscomp$129$$);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($APP.$cljs$core$truth_$$($on_set_modifiers$jscomp$2$$)&&
($on_set_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_set_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3094_modifiers$jscomp$129$$):$on_set_modifiers$jscomp$2$$($_$jscomp$3094_modifiers$jscomp$129$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modif_tree$jscomp$66_position$jscomp$225$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modif_tree$jscomp$66_position$jscomp$225$$,
!1,!1,null))}),$handle_drag_end$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_modifiers$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_clear_modifiers$jscomp$2$$)],function($_$jscomp$3095_modif_tree_80848_modifiers_80847$$,$___$1$jscomp$2087$$,$position$jscomp$226$$){$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($_$jscomp$3095_modif_tree_80848_modifiers_80847$$=$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$226$$):$calculate_modifiers$jscomp$1$$($position$jscomp$226$$),$_$jscomp$3095_modif_tree_80848_modifiers_80847$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1080$$)],null),$_$jscomp$3095_modif_tree_80848_modifiers_80847$$),$APP.$cljs$core$truth_$$($on_clear_modifiers$jscomp$2$$)&&
($on_clear_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_modifiers$jscomp$2$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($_$jscomp$3095_modif_tree_80848_modifiers_80847$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null));
$APP.$cljs$core$reset_BANG_$$($start_size_before$$,null);return $APP.$cljs$core$reset_BANG_$$($start_size_after$$,null)});return $app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5874$on_drag_start$$,$handle_drag_start$$,$cljs$cst$5876$on_drag_delta$$,$handle_drag_position$jscomp$1$$,$cljs$cst$5875$on_drag_end$$,$handle_drag_end$jscomp$1$$],null))};
$app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$=function($props_80661_vec__80665$$){var $shape$jscomp$1081$$=$props_80661_vec__80665$$.shape,$index$jscomp$569$$=$props_80661_vec__80665$$.index,$last_QMARK_$jscomp$4$$=$props_80661_vec__80665$$["last?"],$drop_QMARK_$jscomp$1$$=$props_80661_vec__80665$$["drop?"],$handle_pointer_down$jscomp$4_map__80668_track_before$jscomp$1$$=$props_80661_vec__80665$$["track-before"],$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$=
$props_80661_vec__80665$$["track-after"],$handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$=$props_80661_vec__80665$$["snap-pixel?"],$on_set_modifiers$jscomp$3$$=$props_80661_vec__80665$$["on-set-modifiers"],$on_clear_modifiers$jscomp$3$$=$props_80661_vec__80665$$["on-clear-modifiers"],$map__80664__$1_row_total_gap$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($props_80661_vec__80665$$["layout-data"]),$column_total_size$jscomp$1_start_p_resize_vec__80669$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80664__$1_row_total_gap$jscomp$1$$,
$APP.$cljs$cst$3664$column_total_size$$),$column_total_gap$jscomp$1_start_p_drop$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80664__$1_row_total_gap$jscomp$1$$,$APP.$cljs$cst$3665$column_total_gap$$),$row_total_size$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80664__$1_row_total_gap$jscomp$1$$,$APP.$cljs$cst$3669$row_total_size$$);$map__80664__$1_row_total_gap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80664__$1_row_total_gap$jscomp$1$$,
$APP.$cljs$cst$3667$row_total_gap$$);var $start_p$jscomp$16$$=$props_80661_vec__80665$$["start-p"],$type$jscomp$714$$=$props_80661_vec__80665$$.type,$zoom$jscomp$108$$=$props_80661_vec__80665$$.zoom,$bounds$jscomp$92$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1081$$);$props_80661_vec__80665$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$1081$$);var $layout_gap_row$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_80661_vec__80665$$,
0,null),$layout_gap_col$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_80661_vec__80665$$,1,null);$handle_pointer_down$jscomp$4_map__80668_track_before$jscomp$1$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$($type$jscomp$714$$,$shape$jscomp$1081$$,$index$jscomp$569$$,$handle_pointer_down$jscomp$4_map__80668_track_before$jscomp$1$$,$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$,$zoom$jscomp$108$$,$handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$,
$on_set_modifiers$jscomp$3$$,$on_clear_modifiers$jscomp$3$$);$handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($handle_pointer_down$jscomp$4_map__80668_track_before$jscomp$1$$);$handle_pointer_down$jscomp$4_map__80668_track_before$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$,$cljs$cst$5878$handle_pointer_down$$);$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$,$cljs$cst$5879$handle_lost_pointer_capture$$);$handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$,$cljs$cst$5880$handle_pointer_move$$);$column_total_size$jscomp$1_start_p_resize_vec__80669$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,
$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function(){var $x__5110__auto__$jscomp$168_y__5111__auto__$jscomp$inline_9221$$=$layout_gap_col$jscomp$14$$-10/$zoom$jscomp$108$$;$x__5110__auto__$jscomp$168_y__5111__auto__$jscomp$inline_9221$$=0>$x__5110__auto__$jscomp$168_y__5111__auto__$jscomp$inline_9221$$?0:$x__5110__auto__$jscomp$168_y__5111__auto__$jscomp$inline_9221$$;var $y__5111__auto__$jscomp$168$$=8/$zoom$jscomp$108$$;
return $x__5110__auto__$jscomp$168_y__5111__auto__$jscomp$inline_9221$$>$y__5111__auto__$jscomp$168$$?$x__5110__auto__$jscomp$168_y__5111__auto__$jscomp$inline_9221$$:$y__5111__auto__$jscomp$168$$}(),$row_total_size$jscomp$1$$+$map__80664__$1_row_total_gap$jscomp$1$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$column_total_size$jscomp$1_start_p_resize_vec__80669$$+$column_total_gap$jscomp$1_start_p_drop$$,function(){var $x__5110__auto__$jscomp$170_y__5111__auto__$jscomp$inline_9223$$=
$layout_gap_row$jscomp$14$$-10/$zoom$jscomp$108$$;$x__5110__auto__$jscomp$170_y__5111__auto__$jscomp$inline_9223$$=0>$x__5110__auto__$jscomp$170_y__5111__auto__$jscomp$inline_9223$$?0:$x__5110__auto__$jscomp$170_y__5111__auto__$jscomp$inline_9223$$;var $y__5111__auto__$jscomp$170$$=8/$zoom$jscomp$108$$;return $x__5110__auto__$jscomp$170_y__5111__auto__$jscomp$inline_9223$$>$y__5111__auto__$jscomp$170$$?$x__5110__auto__$jscomp$170_y__5111__auto__$jscomp$inline_9223$$:$y__5111__auto__$jscomp$170$$}()],
null);var $width$jscomp$232$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_total_size$jscomp$1_start_p_resize_vec__80669$$,0,null),$height$jscomp$199$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_total_size$jscomp$1_start_p_resize_vec__80669$$,1,null);$column_total_size$jscomp$1_start_p_resize_vec__80669$$=function(){var $G__80672__$1_G__80672__$2_G__80672__$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$216$column$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)?$APP.$app$common$geom$point$subtract$$($start_p$jscomp$16$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$width$jscomp$232$$/2)):$start_p$jscomp$16$$;$G__80672__$1_G__80672__$2_G__80672__$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$1656$row$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)?$APP.$app$common$geom$point$subtract$$($G__80672__$1_G__80672__$2_G__80672__$3$$,
$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$height$jscomp$199$$/2)):$G__80672__$1_G__80672__$2_G__80672__$3$$;$G__80672__$1_G__80672__$2_G__80672__$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__80672__$1_G__80672__$2_G__80672__$3$$,
$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$layout_gap_col$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$width$jscomp$232$$/2)):$G__80672__$1_G__80672__$2_G__80672__$3$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$1656$row$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__80672__$1_G__80672__$2_G__80672__$3$$,
$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$layout_gap_row$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$height$jscomp$199$$/2)):$G__80672__$1_G__80672__$2_G__80672__$3$$}();$column_total_gap$jscomp$1_start_p_drop$$=function(){var $G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,
0)?$APP.$app$common$geom$point$subtract$$($start_p$jscomp$16$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$width$jscomp$232$$/2)):$start_p$jscomp$16$$;$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$1656$row$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)?$APP.$app$common$geom$point$subtract$$($G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$,
$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$height$jscomp$199$$/2)):$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$;$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$930$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$216$column$$);return $and__5023__auto__$jscomp$930$$?$last_QMARK_$jscomp$4$$:$and__5023__auto__$jscomp$930$$}())?
$APP.$app$common$geom$point$add$$($G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$width$jscomp$232$$/2)):$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$;$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$931$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$1656$row$$);
return $and__5023__auto__$jscomp$931$$?$last_QMARK_$jscomp$4$$:$and__5023__auto__$jscomp$931$$}())?$APP.$app$common$geom$point$add$$($G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$height$jscomp$199$$/2)):$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$;$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,
$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$layout_gap_col$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,5/$zoom$jscomp$108$$)):$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$;
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$1656$row$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$569$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$layout_gap_row$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,
5/$zoom$jscomp$108$$)):$G__80673__$1_G__80673__$2_G__80673__$3_G__80673__$4_G__80673__$5$$}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($drop_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{className:"drop",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($column_total_gap$jscomp$1_start_p_drop$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($column_total_gap$jscomp$1_start_p_drop$$),width:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,
$APP.$cljs$cst$216$column$$)?10/$zoom$jscomp$108$$:$width$jscomp$232$$,height:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$1656$row$$)?10/$zoom$jscomp$108$$:$height$jscomp$199$$,fill:"var(--grid-editor-area-background)"}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$232$$,height:$height$jscomp$199$$,className:"resize-track-handler "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$714$$,$APP.$cljs$cst$216$column$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",
$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1081$$)):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1081$$)))??""),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($column_total_size$jscomp$1_start_p_resize_vec__80669$$),transform:""+($APP.$app$common$geom$matrix$transform_in$$($start_p$jscomp$16$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1081$$))??
""),style:{fill:"transparent",strokeWidth:0},onLostPointerCapture:$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($column_total_size$jscomp$1_start_p_resize_vec__80669$$),onPointerMove:$handle_pointer_move$jscomp$2_map__80668__$1_snap_pixel_QMARK_$jscomp$10$$,onPointerDown:$handle_pointer_down$jscomp$4_map__80668_track_before$jscomp$1$$})]})};
$app$main$ui$workspace$viewport$grid_layout_editor$marker_shape_d$$=function($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$){var $marker_width$$=24/$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$,$marker_h1$$=20/$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$,$marker_h2$$=10/$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$;$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$=2/$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$;var $marker_half_width$$=$marker_width$$/
2;$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$=$APP.$app$common$geom$point$subtract$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_half_width$$,($marker_h1$$+$marker_h2$$)/2));var $e$jscomp$381_vec__80678$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($p1__80674_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__80674_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_width$$,0))},function($p1__80675_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__80675_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,$marker_h1$$))},
function($p1__80676_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__80676_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-$marker_half_width$$,$marker_h2$$))},function($p1__80677_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__80677_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_half_width$$,$marker_h2$$))}],null));$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$381_vec__80678$$,
0,null);var $b$jscomp$364$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$381_vec__80678$$,1,null),$c$jscomp$315$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$381_vec__80678$$,2,null),$d$jscomp$243$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$381_vec__80678$$,3,null);$e$jscomp$381_vec__80678$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$381_vec__80678$$,4,null);var $vea$$=$APP.$app$common$geom$point$subtract$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,
$e$jscomp$381_vec__80678$$),$b1$jscomp$4_vab$$=$APP.$app$common$geom$point$subtract$$($b$jscomp$364$$,$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$),$c1$jscomp$38_vbc$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($c$jscomp$315$$,$b$jscomp$364$$),$d1$jscomp$1_vcd$$=$APP.$app$common$geom$point$subtract$$($d$jscomp$243$$,$c$jscomp$315$$),$e1$jscomp$10_vde$$=$APP.$app$common$geom$point$subtract$$($e$jscomp$381_vec__80678$$,$d$jscomp$243$$),$a1$jscomp$8_lea$$=$APP.$app$common$geom$point$length$$($vea$$),
$b2$jscomp$2_lab$$=$APP.$app$common$geom$point$length$$($b1$jscomp$4_vab$$),$c2$jscomp$27_lbc$$=$APP.$app$common$geom$point$length$$($c1$jscomp$38_vbc$jscomp$1$$),$d2$jscomp$1_lcd$$=$APP.$app$common$geom$point$length$$($d1$jscomp$1_vcd$$),$lde$$=$APP.$app$common$geom$point$length$$($e1$jscomp$10_vde$$);$a1$jscomp$8_lea$$=$APP.$app$common$geom$point$add$$($e$jscomp$381_vec__80678$$,$app$common$geom$point$resize$$($vea$$,$a1$jscomp$8_lea$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));var $a2$jscomp$4$$=
$APP.$app$common$geom$point$add$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$app$common$geom$point$resize$$($b1$jscomp$4_vab$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$b1$jscomp$4_vab$$=$APP.$app$common$geom$point$add$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$app$common$geom$point$resize$$($b1$jscomp$4_vab$$,$b2$jscomp$2_lab$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$b2$jscomp$2_lab$$=$APP.$app$common$geom$point$add$$($b$jscomp$364$$,$app$common$geom$point$resize$$($c1$jscomp$38_vbc$jscomp$1$$,
$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$c1$jscomp$38_vbc$jscomp$1$$=$APP.$app$common$geom$point$add$$($b$jscomp$364$$,$app$common$geom$point$resize$$($c1$jscomp$38_vbc$jscomp$1$$,$c2$jscomp$27_lbc$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$c2$jscomp$27_lbc$$=$APP.$app$common$geom$point$add$$($c$jscomp$315$$,$app$common$geom$point$resize$$($d1$jscomp$1_vcd$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$d1$jscomp$1_vcd$$=$APP.$app$common$geom$point$add$$($c$jscomp$315$$,$app$common$geom$point$resize$$($d1$jscomp$1_vcd$$,
$d2$jscomp$1_lcd$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$d2$jscomp$1_lcd$$=$APP.$app$common$geom$point$add$$($d$jscomp$243$$,$app$common$geom$point$resize$$($e1$jscomp$10_vde$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$e1$jscomp$10_vde$$=$APP.$app$common$geom$point$add$$($d$jscomp$243$$,$app$common$geom$point$resize$$($e1$jscomp$10_vde$$,$lde$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$=$APP.$app$common$geom$point$add$$($e$jscomp$381_vec__80678$$,
$app$common$geom$point$resize$$($vea$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$109$$));return"M"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??"")+("Q"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$)??"")+
","+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$4$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$4$$)??""))+("L"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($b1$jscomp$4_vab$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($b1$jscomp$4_vab$$)??""))+("Q"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$364$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$364$$)??
"")+","+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($b2$jscomp$2_lab$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($b2$jscomp$2_lab$$)??""))+("L"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$38_vbc$jscomp$1$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$38_vbc$jscomp$1$$)??""))+("Q"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$315$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$315$$)??
"")+","+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$27_lbc$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$27_lbc$$)??""))+("L"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($d1$jscomp$1_vcd$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($d1$jscomp$1_vcd$$)??""))+("Q"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$243$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$243$$)??
"")+","+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($d2$jscomp$1_lcd$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($d2$jscomp$1_lcd$$)??""))+("L"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($e1$jscomp$10_vde$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($e1$jscomp$10_vde$$)??""))+("Q"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$381_vec__80678$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$381_vec__80678$$)??
"")+","+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($e2$jscomp$5_marker_bradius_zoom$jscomp$109$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($e2$jscomp$5_marker_bradius_zoom$jscomp$109$$)??""))+("L"+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??""))+"Z"};
$app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$=function($props_80686_text_x$jscomp$1$$){var $center$jscomp$56$$=$props_80686_text_x$jscomp$1$$.center,$value$jscomp$1001$$=$props_80686_text_x$jscomp$1$$.value,$zoom$jscomp$110$$=$props_80686_text_x$jscomp$1$$.zoom,$shape$jscomp$1082$$=$props_80686_text_x$jscomp$1$$.shape,$handle_pointer_down$jscomp$5_index$jscomp$570_map__80687$$=$props_80686_text_x$jscomp$1$$.index,$type$jscomp$715$$=$props_80686_text_x$jscomp$1$$.type,$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$=
$props_80686_text_x$jscomp$1$$["track-before"],$handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$=$props_80686_text_x$jscomp$1$$["track-after"],$snap_pixel_QMARK_$jscomp$11$$=$props_80686_text_x$jscomp$1$$["snap-pixel?"],$on_set_modifiers$jscomp$4$$=$props_80686_text_x$jscomp$1$$["on-set-modifiers"],$on_clear_modifiers$jscomp$4$$=$props_80686_text_x$jscomp$1$$["on-clear-modifiers"];$props_80686_text_x$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$56$$);
var $text_y$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$56$$);$handle_pointer_down$jscomp$5_index$jscomp$570_map__80687$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$($type$jscomp$715$$,$shape$jscomp$1082$$,$handle_pointer_down$jscomp$5_index$jscomp$570_map__80687$$,$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$,$handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$,$zoom$jscomp$110$$,$snap_pixel_QMARK_$jscomp$11$$,
$on_set_modifiers$jscomp$4$$,$on_clear_modifiers$jscomp$4$$);$handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($handle_pointer_down$jscomp$5_index$jscomp$570_map__80687$$);$handle_pointer_down$jscomp$5_index$jscomp$570_map__80687$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$,$cljs$cst$5878$handle_pointer_down$$);$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$,$cljs$cst$5879$handle_lost_pointer_capture$$);$handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$,$cljs$cst$5880$handle_pointer_move$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:$handle_pointer_down$jscomp$5_index$jscomp$570_map__80687$$,
onLostPointerCapture:$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$,onPointerMove:$handle_pointer_move$jscomp$3_map__80687__$1_track_after$jscomp$2$$,transform:""+($APP.$app$common$geom$matrix$transform_in$$($center$jscomp$56$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1082$$))??""),className:$APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["main_ui_workspace_viewport_grid_layout_editor__grid-track-marker",
!0,$app$main$ui$css_cursors$get_dynamic$$("resize-ew",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1082$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$715$$,$APP.$cljs$cst$216$column$$),$app$main$ui$css_cursors$get_dynamic$$("resize-ns",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1082$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$715$$,$APP.$cljs$cst$1656$row$$)])),children:[(0,$APP.$rumext$v2$jsx$$)("path",
{d:$app$main$ui$workspace$viewport$grid_layout_editor$marker_shape_d$$($center$jscomp$56$$,$zoom$jscomp$110$$),className:"main_ui_workspace_viewport_grid_layout_editor__marker-shape"}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$props_80686_text_x$jscomp$1$$,y:$text_y$jscomp$1$$,width:26.26/$zoom$jscomp$110$$,height:36/$zoom$jscomp$110$$,textAnchor:"middle",dominantBaseline:"middle",className:"main_ui_workspace_viewport_grid_layout_editor__marker-text",children:""+($value$jscomp$1001$$??"")})]})};
$app$main$ui$workspace$viewport$rulers$get_ruler_params$$=function($end$jscomp$110_vbox$jscomp$43$$,$axis$jscomp$45_start$jscomp$254$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$45_start$jscomp$254$$,$APP.$cljs$cst$1510$x$$)?($axis$jscomp$45_start$jscomp$254$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$43$$),$end$jscomp$110_vbox$jscomp$43$$=$axis$jscomp$45_start$jscomp$254$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$43$$)):
($axis$jscomp$45_start$jscomp$254$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$43$$),$end$jscomp$110_vbox$jscomp$43$$=$axis$jscomp$45_start$jscomp$254$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$43$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1292$start$$,$axis$jscomp$45_start$jscomp$254$$,$APP.$cljs$cst$1293$end$$,$end$jscomp$110_vbox$jscomp$43$$],null)};
$app$main$ui$workspace$viewport$rulers$rulers_inside_path$$=function($x1$jscomp$44$$,$y1$jscomp$46$$,$x2$jscomp$41$$,$y2$jscomp$43$$,$br$$,$bw$jscomp$2$$){return"M"+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$+$br$$??"")+"Q"+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+","+($x1$jscomp$44$$+$bw$jscomp$2$$+$br$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+"L"+($x2$jscomp$41$$-$br$$)+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+"Q"+($x2$jscomp$41$$??
"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+","+($x2$jscomp$41$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$+$br$$??"")+"L"+($x2$jscomp$41$$??"")+","+($y2$jscomp$43$$-$br$$)+"Q"+($x2$jscomp$41$$??"")+","+($y2$jscomp$43$$??"")+","+($x2$jscomp$41$$-$br$$)+","+($y2$jscomp$43$$??"")+"L"+($x1$jscomp$44$$+$bw$jscomp$2$$+$br$$??"")+","+($y2$jscomp$43$$??"")+"Q"+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y2$jscomp$43$$??"")+","+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y2$jscomp$43$$-$br$$)+"Z"};
$app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$=function($clip_id$jscomp$6_props_80637$$){var $axis$jscomp$47$$=$clip_id$jscomp$6_props_80637$$.axis,$step$jscomp$34$$=$clip_id$jscomp$6_props_80637$$.step,$zoom_inverse$jscomp$5$$=$clip_id$jscomp$6_props_80637$$.zoomInverse,$offset$jscomp$216$$=$clip_id$jscomp$6_props_80637$$.offset,$vbox$jscomp$45$$=$clip_id$jscomp$6_props_80637$$.vbox;$clip_id$jscomp$6_props_80637$$=["clip-ruler-",$APP.$app$common$data$name$$($axis$jscomp$47$$)].join("");
var $map__80638_minv__$2_start$jscomp$255$$=$app$main$ui$workspace$viewport$rulers$get_ruler_params$$($vbox$jscomp$45$$,$axis$jscomp$47$$),$end$jscomp$111_map__80638__$1_maxv__$2$$=$APP.$cljs$core$__destructure_map$$($map__80638_minv__$2_start$jscomp$255$$);$map__80638_minv__$2_start$jscomp$255$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$111_map__80638__$1_maxv__$2$$,$APP.$cljs$cst$1292$start$$);$end$jscomp$111_map__80638__$1_maxv__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$111_map__80638__$1_maxv__$2$$,
$APP.$cljs$cst$1293$end$$);$map__80638_minv__$2_start$jscomp$255$$=$APP.$app$common$math$ceil$$(($map__80638_minv__$2_start$jscomp$255$$>-1E5?$map__80638_minv__$2_start$jscomp$255$$:-1E5)/$step$jscomp$34$$)*$step$jscomp$34$$+$APP.$cljs$core$mod$$($offset$jscomp$216$$,$step$jscomp$34$$);$end$jscomp$111_map__80638__$1_maxv__$2$$=$APP.$app$common$math$floor$$(($end$jscomp$111_map__80638__$1_maxv__$2$$<1E5?$end$jscomp$111_map__80638__$1_maxv__$2$$:1E5)/$step$jscomp$34$$)*$step$jscomp$34$$+$APP.$cljs$core$mod$$($offset$jscomp$216$$,
$step$jscomp$34$$);var $rulers_width$jscomp$1$$=1*$zoom_inverse$jscomp$5$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"rulers",clipPath:["url(#",$clip_id$jscomp$6_props_80637$$,")"].join(""),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$6_props_80637$$,children:function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$47$$,$APP.$cljs$cst$1510$x$$))var $x$jscomp$1284_x$jscomp$inline_9259$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+
25*$zoom_inverse$jscomp$5$$,$y$jscomp$508_y$jscomp$inline_9260$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$),$width$jscomp$236_width$jscomp$inline_9261$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)-21*$zoom_inverse$jscomp$5$$,$height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$=25*$zoom_inverse$jscomp$5$$;else $x$jscomp$1284_x$jscomp$inline_9259$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$),$y$jscomp$508_y$jscomp$inline_9260$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+25*$zoom_inverse$jscomp$5$$,$width$jscomp$236_width$jscomp$inline_9261$$=25*$zoom_inverse$jscomp$5$$,$height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)-21*$zoom_inverse$jscomp$5$$;$height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,
$x$jscomp$1284_x$jscomp$inline_9259$$,$APP.$cljs$cst$1511$y$$,$y$jscomp$508_y$jscomp$inline_9260$$,$APP.$cljs$cst$290$width$$,$width$jscomp$236_width$jscomp$inline_9261$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$],null));$x$jscomp$1284_x$jscomp$inline_9259$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$,$APP.$cljs$cst$1510$x$$);$y$jscomp$508_y$jscomp$inline_9260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$,
$APP.$cljs$cst$1511$y$$);$width$jscomp$236_width$jscomp$inline_9261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$,$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1284_x$jscomp$inline_9259$$,
y:$y$jscomp$508_y$jscomp$inline_9260$$,width:$width$jscomp$236_width$jscomp$inline_9261$$,height:$height$jscomp$203_height$jscomp$inline_9262_map__80639__$1$$})}()})}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$224$$,$JSCompiler_inline_result$jscomp$1917_step_val$$){var $JSCompiler_temp_const$jscomp$1915$$=$out_arr__44124__auto__$jscomp$224$$.push;var $map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$=
15*$zoom_inverse$jscomp$5$$;var $rulers_size$jscomp$inline_13726_text_y$jscomp$inline_9267$$=4*$zoom_inverse$jscomp$5$$;$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$47$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5881$text_x$$,$JSCompiler_inline_result$jscomp$1917_step_val$$,$cljs$cst$5882$text_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+
$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$+-1*$zoom_inverse$jscomp$5$$,$cljs$cst$5883$line_x1$$,$JSCompiler_inline_result$jscomp$1917_step_val$$,$cljs$cst$5884$line_y1$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$+2*$zoom_inverse$jscomp$5$$,$cljs$cst$5885$line_x2$$,$JSCompiler_inline_result$jscomp$1917_step_val$$,$cljs$cst$5886$line_y2$$,
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$+2*$zoom_inverse$jscomp$5$$+$rulers_size$jscomp$inline_13726_text_y$jscomp$inline_9267$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5881$text_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$+-1*
$zoom_inverse$jscomp$5$$,$cljs$cst$5882$text_y$$,$JSCompiler_inline_result$jscomp$1917_step_val$$,$cljs$cst$5883$line_x1$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$+2*$zoom_inverse$jscomp$5$$,$cljs$cst$5884$line_y1$$,$JSCompiler_inline_result$jscomp$1917_step_val$$,$cljs$cst$5885$line_x2$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$+
2*$zoom_inverse$jscomp$5$$+$rulers_size$jscomp$inline_13726_text_y$jscomp$inline_9267$$,$cljs$cst$5886$line_y2$$,$JSCompiler_inline_result$jscomp$1917_step_val$$],null);var $line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$=$APP.$cljs$core$__destructure_map$$($map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$);$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,
$cljs$cst$5881$text_x$$);$rulers_size$jscomp$inline_13726_text_y$jscomp$inline_9267$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,$cljs$cst$5882$text_y$$);var $line_x1$jscomp$inline_9268$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,$cljs$cst$5883$line_x1$$),$line_y1$jscomp$inline_9269$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,
$cljs$cst$5884$line_y1$$),$line_x2$jscomp$inline_9270$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,$cljs$cst$5885$line_x2$$);$line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,$cljs$cst$5886$line_y2$$);$JSCompiler_inline_result$jscomp$1917_step_val$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)("text",{x:$map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$,y:$rulers_size$jscomp$inline_13726_text_y$jscomp$inline_9267$$,textAnchor:"middle",transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$47$$,$APP.$cljs$cst$1511$y$$)?["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80640$jscomp$inline_9264_rulers_pos$jscomp$inline_13725_text_x$jscomp$inline_9266$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($rulers_size$jscomp$inline_13726_text_y$jscomp$inline_9267$$),
")"].join(""):null,style:{fontSize:12*$zoom_inverse$jscomp$5$$,fontFamily:"worksans",fill:"var(--layer-row-foreground-color)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1917_step_val$$-$offset$jscomp$216$$)}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$line_x1$jscomp$inline_9268$$,y1:$line_y1$jscomp$inline_9269$$,x2:$line_x2$jscomp$inline_9270$$,y2:$line_y2$jscomp$inline_9271_map__80640__$1$jscomp$inline_9265$$,style:{stroke:"var(--layer-row-foreground-color)",
strokeWidth:$rulers_width$jscomp$1$$}},["line-",$APP.$app$common$data$name$$($axis$jscomp$47$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1917_step_val$$)].join(""))]},"text-"+($APP.$app$common$data$name$$($axis$jscomp$47$$)??"")+"-"+($JSCompiler_inline_result$jscomp$1917_step_val$$??""));$JSCompiler_temp_const$jscomp$1915$$.call($out_arr__44124__auto__$jscomp$224$$,$JSCompiler_inline_result$jscomp$1917_step_val$$);return $out_arr__44124__auto__$jscomp$224$$},
[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80638_minv__$2_start$jscomp$255$$,$end$jscomp$111_map__80638__$1_maxv__$2$$+1,$step$jscomp$34$$))]})};
$app$main$ui$workspace$viewport$rulers$viewport_frame_STAR_$$=function($offset_x$jscomp$13_props_80645$$){var $JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$=$offset_x$jscomp$13_props_80645$$.zoomInverse,$step$jscomp$inline_9273_zoom$jscomp$114$$=$offset_x$jscomp$13_props_80645$$.zoom,$show_rulers$$=$offset_x$jscomp$13_props_80645$$.showRulers,$offset_y$jscomp$13$$=$offset_x$jscomp$13_props_80645$$.offsetY,$vbox$jscomp$46$$=$offset_x$jscomp$13_props_80645$$.vbox;$offset_x$jscomp$13_props_80645$$=
$offset_x$jscomp$13_props_80645$$.offsetX;var $height$jscomp$204_map__80646__$1_y2$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($vbox$jscomp$46$$),$JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$204_map__80646__$1_y2$jscomp$44$$,$APP.$cljs$cst$1510$x$$),$y1$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$204_map__80646__$1_y2$jscomp$44$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$237_x2$jscomp$42$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$204_map__80646__$1_y2$jscomp$44$$,$APP.$cljs$cst$290$width$$);$height$jscomp$204_map__80646__$1_y2$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$204_map__80646__$1_y2$jscomp$44$$,$APP.$cljs$cst$1522$height$$);$width$jscomp$237_x2$jscomp$42$$=$JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$+$width$jscomp$237_x2$jscomp$42$$;$height$jscomp$204_map__80646__$1_y2$jscomp$44$$=$y1$jscomp$47$$+$height$jscomp$204_map__80646__$1_y2$jscomp$44$$;
var $bw$jscomp$3$$=$APP.$cljs$core$truth_$$($show_rulers$$)?22*$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$:0,$br$jscomp$1$$=12/$step$jscomp$inline_9273_zoom$jscomp$114$$,$bs$jscomp$1$$=4*$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$;$JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$=(0,$APP.$rumext$v2$jsxs$$)("g",{className:"viewport-frame-background",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:0,y:0,width:1,height:1,fill:"none",strokeWidth:.1,stroke:"rgba(0,0,0,0)"}),(0,$APP.$rumext$v2$jsx$$)("path",
{d:$app$main$ui$workspace$viewport$rulers$rulers_inside_path$$($JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$,$y1$jscomp$47$$,$width$jscomp$237_x2$jscomp$42$$,$height$jscomp$204_map__80646__$1_y2$jscomp$44$$,$br$jscomp$1$$,$bw$jscomp$3$$),fill:"none",strokeWidth:$bs$jscomp$1$$,stroke:"var(--panel-border-color)"}),(0,$APP.$rumext$v2$jsx$$)("path",{d:"M"+($JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$??"")+","+($y1$jscomp$47$$??"")+"L"+($width$jscomp$237_x2$jscomp$42$$??"")+","+($y1$jscomp$47$$??
"")+"L"+($width$jscomp$237_x2$jscomp$42$$??"")+","+($height$jscomp$204_map__80646__$1_y2$jscomp$44$$??"")+"L"+($JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$??"")+","+($height$jscomp$204_map__80646__$1_y2$jscomp$44$$??"")+"Z"+($app$main$ui$workspace$viewport$rulers$rulers_inside_path$$($JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$,$y1$jscomp$47$$,$width$jscomp$237_x2$jscomp$42$$,$height$jscomp$204_map__80646__$1_y2$jscomp$44$$,$br$jscomp$1$$,$bw$jscomp$3$$)??""),fillRule:"evenodd",fill:"var(--panel-background-color)"})]});
$APP.$cljs$core$truth_$$($show_rulers$$)?($step$jscomp$inline_9273_zoom$jscomp$114$$=0<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<.008?1E4:.008<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<.015?5E3:.015<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<.04?2500:.04<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<.07?1E3:.07<$step$jscomp$inline_9273_zoom$jscomp$114$$&&
$step$jscomp$inline_9273_zoom$jscomp$114$$<.2?500:.2<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<.5?250:.5<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<1?100:1<=$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<=2?50:2<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<4?25:4<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<
6?10:6<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<15?5:15<$step$jscomp$inline_9273_zoom$jscomp$114$$&&$step$jscomp$inline_9273_zoom$jscomp$114$$<25?2:1,$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$=(0,$APP.$rumext$v2$jsxs$$)("g",{className:"viewport-frame-rulers",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$,{vbox:$vbox$jscomp$46$$,offset:$offset_x$jscomp$13_props_80645$$,step:$step$jscomp$inline_9273_zoom$jscomp$114$$,
zoomInverse:$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$,axis:$APP.$cljs$cst$1510$x$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$,{vbox:$vbox$jscomp$46$$,offset:$offset_y$jscomp$13$$,step:$step$jscomp$inline_9273_zoom$jscomp$114$$,zoomInverse:$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$,axis:$APP.$cljs$cst$1511$y$$})]})):$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$=null;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$JSCompiler_temp_const$jscomp$1918_x1$jscomp$45$$,
$JSCompiler_temp$jscomp$1919_zoom_inverse$jscomp$6$$]})};
$app$main$ui$workspace$viewport$rulers$selection_area_STAR_$$=function($JSCompiler_temp_const$jscomp$1921_props_80649$$){var $JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$=$JSCompiler_temp_const$jscomp$1921_props_80649$$.zoomInverse,$offset_y$jscomp$14$$=$JSCompiler_temp_const$jscomp$1921_props_80649$$.offsetY,$center_x$jscomp$inline_9275_vbox$jscomp$47$$=$JSCompiler_temp_const$jscomp$1921_props_80649$$.vbox,$selection_rect$$=$JSCompiler_temp_const$jscomp$1921_props_80649$$.selectionRect,
$JSCompiler_temp_const$jscomp$1920_offset_x$jscomp$14$$=$JSCompiler_temp_const$jscomp$1921_props_80649$$.offsetX;$JSCompiler_temp_const$jscomp$1921_props_80649$$=(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[(0,$APP.$rumext$v2$jsxs$$)("linearGradient",{id:"selection-gradient-start",children:[(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"0%",stopColor:"var(--panel-background-color)",stopOpacity:0}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"40%",stopColor:"var(--panel-background-color)",stopOpacity:1}),
(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"100%",stopColor:"var(--panel-background-color)",stopOpacity:1})]}),(0,$APP.$rumext$v2$jsxs$$)("linearGradient",{id:"selection-gradient-end",children:[(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"0%",stopColor:"var(--panel-background-color)",stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"60%",stopColor:"var(--panel-background-color)",stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"100%",stopColor:"var(--panel-background-color)",stopOpacity:0})]})]});
$JSCompiler_temp_const$jscomp$1920_offset_x$jscomp$14$$=(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-75*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$),width:100*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,
fill:"url('#selection-gradient-start')"}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-25,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$),width:100*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,fill:"url('#selection-gradient-end')"}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),
y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),height:22*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,style:{fill:"var(--color-accent-tertiary)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-4*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$)+
13.6*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,textAnchor:"end",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-$JSCompiler_temp_const$jscomp$1920_offset_x$jscomp$14$$)}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)+
4*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$)+13.6*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,textAnchor:"start",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-
$JSCompiler_temp_const$jscomp$1920_offset_x$jscomp$14$$)})]});$center_x$jscomp$inline_9275_vbox$jscomp$47$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$)+11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$;var $center_y$jscomp$inline_9276$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$;
$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$=(0,$APP.$rumext$v2$jsxs$$)("g",{transform:["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9275_vbox$jscomp$47$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($center_y$jscomp$inline_9276$$),")"].join(""),children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$center_x$jscomp$inline_9275_vbox$jscomp$47$$-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-11*
$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,y:$center_y$jscomp$inline_9276$$-11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,width:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),height:22*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,style:{fill:"var(--color-accent-tertiary)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$center_x$jscomp$inline_9275_vbox$jscomp$47$$-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/
2-11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$-100*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,y:$center_y$jscomp$inline_9276$$-11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,width:100*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,style:{fill:"var(--panel-background-color)",fillOpacity:.8}}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$center_x$jscomp$inline_9275_vbox$jscomp$47$$-
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),y:$center_y$jscomp$inline_9276$$-11*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,width:100*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,style:{fill:"var(--panel-background-color)",
fillOpacity:.8}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$center_x$jscomp$inline_9275_vbox$jscomp$47$$-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-15*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,y:$center_y$jscomp$inline_9276$$+4*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,textAnchor:"end",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},
children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-$offset_y$jscomp$14$$)}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$center_x$jscomp$inline_9275_vbox$jscomp$47$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2,y:$center_y$jscomp$inline_9276$$+4*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,textAnchor:"start",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$,
fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-$offset_y$jscomp$14$$)})]});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-area",children:[$JSCompiler_temp_const$jscomp$1921_props_80649$$,$JSCompiler_temp_const$jscomp$1920_offset_x$jscomp$14$$,$JSCompiler_inline_result$jscomp$1922_zoom_inverse$jscomp$7$$]})};
$app$main$ui$workspace$viewport$guides$use_guide$$=function($on_guide_change$$,$get_hover_frame$$,$zoom$jscomp$116$$,$frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$){$frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$);var $id$jscomp$1048$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$,$APP.$cljs$cst$266$id$$),$position$jscomp$231$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$,
$APP.$cljs$cst$1676$position$$),$axis$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$,$APP.$cljs$cst$2054$axis$$),$frame_id$jscomp$149$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$,$APP.$cljs$cst$1607$frame_id$$),$dragging_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$start_pos_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$state$jscomp$1215$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2204$hover$$,!1,$cljs$cst$5887$new_position$$,null,$APP.$cljs$cst$5012$new_frame_id$$,$frame_id$jscomp$149$$],null)}),$frame_id__$1$jscomp$12$$=$APP.$cljs$cst$5012$new_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1215$$));$frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id__$1$jscomp$12$$)],
function(){return $app$main$refs$object_by_id$$($frame_id__$1$jscomp$12$$)});$frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$=$APP.$rumext$v2$deref$$($frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$);var $snap_pixel_QMARK_$jscomp$14$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$snap_pixel_QMARK_$$),$read_only_QMARK_$jscomp$31$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$on_pointer_enter$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],
function(){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$set_hover_guide$$($id$jscomp$1048$$,!0));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1215$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2204$hover$$,!0)}),$on_pointer_leave$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],
function(){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$set_hover_guide$$($id$jscomp$1048$$,!1));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1215$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2204$hover$$,!1)}),$on_pointer_down$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],
function($event$jscomp$693$$){return $APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$event$jscomp$693$$.button)?($APP.$app$util$dom$capture_pointer$$($event$jscomp$693$$),$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$6$$,!0),$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$3$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$693$$)),$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),
$axis$jscomp$48$$))):null}),$on_pointer_up$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$select_keys$$($APP.$cljs$core$_deref$$($state$jscomp$1215$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5887$new_position$$,$APP.$cljs$cst$5012$new_frame_id$$],null))),$APP.$rumext$v2$adapt$$($on_guide_change$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],function(){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;
if($on_guide_change$$!=null&&$cljs$cst$5887$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1215$$))!=null){var $G__80688$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$cljs$cst$5887$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1215$$)),$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$5012$new_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1215$$))],null);
return $on_guide_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$$.$cljs$core$IFn$_invoke$arity$1$($G__80688$$):$on_guide_change$$($G__80688$$)}return null}),$on_lost_pointer_capture$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],function($event$jscomp$694$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;$APP.$app$util$dom$release_pointer$$($event$jscomp$694$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$6$$,
!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$3$$,null);$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$jscomp$1$$,null);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1215$$,$APP.$cljs$core$assoc$$,$cljs$cst$5887$new_position$$,null)}),$on_pointer_move$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($position$jscomp$231$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$116$$),$APP.$rumext$v2$adapt$$($snap_pixel_QMARK_$jscomp$14$$),
$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$),$APP.$rumext$v2$adapt$$($get_hover_frame$$)],function($current_pt$jscomp$2_event$jscomp$695$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$6$$))){var $delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$=$APP.$rumext$v2$ref_val$$($start_ref$jscomp$3$$),$new_position_new_position__$1_start_pos$jscomp$19$$=$APP.$rumext$v2$ref_val$$($start_pos_ref$jscomp$1$$);
$current_pt$jscomp$2_event$jscomp$695$$=$APP.$app$util$dom$get_client_position$$($current_pt$jscomp$2_event$jscomp$695$$);$delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$=($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_pt$jscomp$2_event$jscomp$695$$,$axis$jscomp$48$$)-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$,$axis$jscomp$48$$))/$zoom$jscomp$116$$;$new_position_new_position__$1_start_pos$jscomp$19$$=$position$jscomp$231$$!=
null?$position$jscomp$231$$+$delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$:$new_position_new_position__$1_start_pos$jscomp$19$$+$delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$;$new_position_new_position__$1_start_pos$jscomp$19$$=$APP.$cljs$core$truth_$$($snap_pixel_QMARK_$jscomp$14$$)?$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($new_position_new_position__$1_start_pos$jscomp$19$$):$new_position_new_position__$1_start_pos$jscomp$19$$;$delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($get_hover_frame$$.$cljs$core$IFn$_invoke$arity$0$?$get_hover_frame$$.$cljs$core$IFn$_invoke$arity$0$():$get_hover_frame$$(),$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1215$$,$APP.$cljs$core$assoc$$,$cljs$cst$5887$new_position$$,$new_position_new_position__$1_start_pos$jscomp$19$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5012$new_frame_id$$,
$delta$jscomp$67_new_frame_id$jscomp$1_start_pt$jscomp$2$$]))}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$cljs$cst$5853$on_pointer_enter$$,$on_pointer_enter$jscomp$13$$,$cljs$cst$5851$on_pointer_leave$$,$on_pointer_leave$jscomp$13$$,$APP.$cljs$cst$4542$on_pointer_down$$,$on_pointer_down$jscomp$15$$,$cljs$cst$5888$on_pointer_up$$,$on_pointer_up$jscomp$4$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$,$on_lost_pointer_capture$jscomp$9$$,$APP.$cljs$cst$4544$on_pointer_move$$,
$on_pointer_move$jscomp$12$$,$APP.$cljs$cst$769$state$$,$state$jscomp$1215$$,$APP.$cljs$cst$1606$frame$$,$frame$jscomp$84_frame_ref_map__80685__$1_p__80684$$],null)};
$app$main$ui$workspace$viewport$guides$guide_area_axis$$=function($pos$jscomp$158$$,$vbox$jscomp$49$$,$guide_active_area_zoom$jscomp$117$$,$frame$jscomp$85$$,$axis$jscomp$49$$){var $rulers_pos$jscomp$1$$=15/$guide_active_area_zoom$jscomp$117$$;$guide_active_area_zoom$jscomp$117$$=16/$guide_active_area_zoom$jscomp$117$$;return $frame$jscomp$85$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$49$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,
$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$117$$/2,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$85$$),$APP.$cljs$cst$290$width$$,$guide_active_area_zoom$jscomp$117$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$85$$)],null):$frame$jscomp$85$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$85$$),
$APP.$cljs$cst$1511$y$$,$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$117$$/2,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$85$$),$APP.$cljs$cst$1522$height$$,$guide_active_area_zoom$jscomp$117$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$49$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$117$$/2,$APP.$cljs$cst$1511$y$$,
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$49$$)+$rulers_pos$jscomp$1$$,$APP.$cljs$cst$290$width$$,$guide_active_area_zoom$jscomp$117$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$49$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$49$$)+$rulers_pos$jscomp$1$$,$APP.$cljs$cst$1511$y$$,$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$117$$/
2,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$49$$),$APP.$cljs$cst$1522$height$$,$guide_active_area_zoom$jscomp$117$$],null)};
$app$main$ui$workspace$viewport$guides$is_guide_inside_frame_QMARK_$$=function($guide$jscomp$12$$,$frame$jscomp$87$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$))?$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$)>=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$)&&$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$)<=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$):$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$)>=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$)&&$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$)<=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$)};
$app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$=function($disabled_guides$jscomp$1_props_80789$$){var $axis$jscomp$56$$=$disabled_guides$jscomp$1_props_80789$$.axis,$zoom$jscomp$123$$=$disabled_guides$jscomp$1_props_80789$$.zoom,$vbox$jscomp$56$$=$disabled_guides$jscomp$1_props_80789$$.vbox,$get_hover_frame$jscomp$2$$=$disabled_guides$jscomp$1_props_80789$$.getHoverFrame;$disabled_guides$jscomp$1_props_80789$$=$disabled_guides$jscomp$1_props_80789$$.disabledGuides;var $map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vbox$jscomp$56$$)],function($guide$jscomp$14_guide__$1$jscomp$2$$){$guide$jscomp$14_guide__$1$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$14_guide__$1$jscomp$2$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()),$APP.$cljs$cst$2054$axis$$,$axis$jscomp$56$$);return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$($zoom$jscomp$123$$,
$vbox$jscomp$56$$,$guide$jscomp$14_guide__$1$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$update_guides$$($guide$jscomp$14_guide__$1$jscomp$2$$)):null});$map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$=$app$main$ui$workspace$viewport$guides$use_guide$$($map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$,$get_hover_frame$jscomp$2$$,$zoom$jscomp$123$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2054$axis$$,
$axis$jscomp$56$$],null));var $frame$jscomp$89_map__80792__$1$$=$APP.$cljs$core$__destructure_map$$($map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$),$on_pointer_enter$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$cljs$cst$5853$on_pointer_enter$$),$on_pointer_leave$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$cljs$cst$5851$on_pointer_leave$$),$on_pointer_down$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,
$APP.$cljs$cst$4542$on_pointer_down$$),$on_pointer_up$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$cljs$cst$5888$on_pointer_up$$),$on_lost_pointer_capture$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$APP.$cljs$cst$4544$on_pointer_move$$);
$map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$APP.$cljs$cst$769$state$$);$frame$jscomp$89_map__80792__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$89_map__80792__$1$$,$APP.$cljs$cst$1606$frame$$);var $read_only_QMARK_$jscomp$33$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"new-guides",
children:[$APP.$cljs$core$truth_$$($disabled_guides$jscomp$1_props_80789$$)?null:function(){var $map__80793_x$jscomp$1287$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$56$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$56$$)+8/$zoom$jscomp$123$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$56$$),$APP.$cljs$cst$290$width$$,
16/$zoom$jscomp$123$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$56$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$56$$)+28/$zoom$jscomp$123$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$56$$),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$56$$),
$APP.$cljs$cst$1522$height$$,24/$zoom$jscomp$123$$],null);var $height$jscomp$207_map__80793__$1$$=$APP.$cljs$core$__destructure_map$$($map__80793_x$jscomp$1287$$);$map__80793_x$jscomp$1287$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__80793__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$511$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__80793__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__80793__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$207_map__80793__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__80793__$1$$,$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$240$$,height:$height$jscomp$207_map__80793__$1$$,className:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$33$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$56$$,$APP.$cljs$cst$1510$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",
0):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",0),x:$map__80793_x$jscomp$1287$$,onPointerUp:$on_pointer_up$jscomp$6$$,style:{fill:"none",pointerEvents:"fill"},onLostPointerCapture:$on_lost_pointer_capture$jscomp$11$$,y:$y$jscomp$511$$,onPointerMove:$on_pointer_move$jscomp$14$$,onPointerDown:$on_pointer_down$jscomp$17$$,onPointerLeave:$on_pointer_leave$jscomp$15$$,onPointerEnter:$on_pointer_enter$jscomp$15$$})}(),$APP.$cljs$core$truth_$$($cljs$cst$5887$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$)))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_STAR_$$,{guide:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2054$axis$$,$axis$jscomp$56$$,$APP.$cljs$cst$1676$position$$,$cljs$cst$5887$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($map__80792_on_guide_change$jscomp$2_state$jscomp$1217$$))],null),getHoverFrame:$get_hover_frame$jscomp$2$$,vbox:$vbox$jscomp$56$$,zoom:$zoom$jscomp$123$$,isHover:!0,hoverFrame:$frame$jscomp$89_map__80792__$1$$}):
null]})};
$app$main$data$workspace$grid_layout$shortcuts$esc_pressed$$=function(){typeof $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$==="undefined"&&($app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$=function($meta80682$$){this.$meta80682$=$meta80682$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5905$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_shortcuts_SLASH_esc_pressed$$},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_80683$$,$meta80682__$1$$){return new $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$($meta80682__$1$$)},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta80682$},
$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3102_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9290$$,$path_edit_mode_state$jscomp$1218$$){$_$jscomp$3102_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9290$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_mode_state$jscomp$1218$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$,$APP.$cljs$cst$266$id$$],null));$_$jscomp$3102_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9290$$=$APP.$cljs$core$truth_$$($_$jscomp$3102_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9290$$)?$_$jscomp$3102_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9290$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_mode_state$jscomp$1218$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null));$path_edit_mode_state$jscomp$1218$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_mode_state$jscomp$1218$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$3102_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9290$$,
$APP.$cljs$cst$4223$edit_mode$$],null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4224$draw$$,$path_edit_mode_state$jscomp$1218$$)?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$)});return new $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$viewport$hooks$setup_dom_events$$=function($zoom$jscomp$125$$,$disable_paste_ref$jscomp$2$$,$in_viewport_ref$jscomp$3$$,$workspace_read_only_QMARK_$$,$drawing_tool$jscomp$5$$,$drawing_path_QMARK_$jscomp$3$$){var $zoom_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)($zoom$jscomp$125$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($zoom$jscomp$125$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($zoom_ref$jscomp$1$$,$zoom$jscomp$125$$)});
var $on_key_down$jscomp$27$$=$app$main$ui$workspace$viewport$actions$on_key_down$$(),$on_key_up$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_key_up$$(),$on_mouse_wheel$jscomp$2$$=$app$main$ui$workspace$viewport$actions$on_mouse_wheel$$($zoom_ref$jscomp$1$$),$on_paste$jscomp$1$$=$app$main$ui$workspace$viewport$actions$on_paste$$($disable_paste_ref$jscomp$2$$,$in_viewport_ref$jscomp$3$$,$workspace_read_only_QMARK_$$),$on_pointer_down$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$5$$),
$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$3$$)],function($e$jscomp$382_parent_QMARK_$jscomp$4$$){$e$jscomp$382_parent_QMARK_$jscomp$4$$=$APP.$app$util$dom$get_parent_with_data$$($APP.$app$util$dom$get_target$$($e$jscomp$382_parent_QMARK_$jscomp$4$$),"dont-clear-path");return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($drawing_path_QMARK_$jscomp$3$$)?$APP.$cljs$core$not$$($e$jscomp$382_parent_QMARK_$jscomp$4$$):$drawing_path_QMARK_$jscomp$3$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$()):
null}),$on_blur$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$BlurEvent$$(null,null,null))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$5$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$3$$)],function(){var $key$jscomp$423$$=$APP.$goog$events$listen$$(window,"pointerdown",$on_pointer_down$jscomp$18$$);
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$5$$,$APP.$cljs$cst$3436$comments$$)?$APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$jscomp$2$$,!0):$APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$jscomp$2$$,!1);return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$423$$)}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_key_down$jscomp$27$$),$APP.$rumext$v2$adapt$$($on_key_up$jscomp$3$$),
$APP.$rumext$v2$adapt$$($on_paste$jscomp$1$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$$)],function(){var $keys$jscomp$58$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$(document,"keydown",$on_key_down$jscomp$27$$),$APP.$goog$events$listen$$(document,"keyup",$on_key_up$jscomp$3$$),$APP.$goog$events$listen$$(window,"wheel",$on_mouse_wheel$jscomp$2$$,{passive:!1}),$APP.$goog$events$listen$$(window,"paste",$on_paste$jscomp$1$$),
$APP.$goog$events$listen$$(window,"blur",$on_blur$jscomp$35$$)],null);return function(){for(var $c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$=$APP.$cljs$core$seq$$($keys$jscomp$58$$),$G__80862_chunk__80734_seq__80733__$1$$=null,$G__80861_count__80735$$=0,$i__80736$$=0;;)if($i__80736$$<$G__80861_count__80735$$){var $G__80863_key$jscomp$424$$=$G__80862_chunk__80734_seq__80733__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__80736$$);$APP.$goog$events$unlistenByKey$$($G__80863_key$jscomp$424$$);
$i__80736$$+=1}else if($c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$))$G__80862_chunk__80734_seq__80733__$1$$=$c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__80862_chunk__80734_seq__80733__$1$$)?($c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$=$APP.$cljs$core$_chunked_first$$($G__80862_chunk__80734_seq__80733__$1$$),
$G__80861_count__80735$$=$APP.$cljs$core$_chunked_rest$$($G__80862_chunk__80734_seq__80733__$1$$),$G__80862_chunk__80734_seq__80733__$1$$=$c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$,$G__80863_key$jscomp$424$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$),$c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$=$G__80861_count__80735$$,$G__80861_count__80735$$=$G__80863_key$jscomp$424$$):($G__80863_key$jscomp$424$$=
$APP.$cljs$core$first$$($G__80862_chunk__80734_seq__80733__$1$$),$APP.$goog$events$unlistenByKey$$($G__80863_key$jscomp$424$$),$c__5548__auto__$jscomp$45_seq__80733_temp__5825__auto__$jscomp$431$$=$APP.$cljs$core$next$$($G__80862_chunk__80734_seq__80733__$1$$),$G__80862_chunk__80734_seq__80733__$1$$=null,$G__80861_count__80735$$=0),$i__80736$$=0;else return null}})};
$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$=function($vport$jscomp$12$$,$viewport_ref$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vport$jscomp$12$$)],function(){var $JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$=$APP.$app$util$dom$get_parent$$($APP.$rumext$v2$ref_val$$($viewport_ref$$)),$JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$=$APP.$app$util$dom$get_client_size$$($JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$);
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$,$vport$jscomp$12$$)?($JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$,$JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$=$APP.$app$util$dom$get_client_size$$($JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$),$JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$=
$app$main$data$workspace$viewport$initialize_viewport$$($JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$),$JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$=$JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1585_param72262$jscomp$inline_9292_prnt$$)):$JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$=null;return $JSCompiler_temp$jscomp$1582_JSCompiler_temp_const$jscomp$1583_size$jscomp$158$$})};
$app$main$ui$workspace$viewport$hooks$setup_cursor$$=function($cursor$jscomp$10$$,$alt_QMARK_$jscomp$24$$,$mod_QMARK_$jscomp$12$$,$space_QMARK_$jscomp$4$$,$panning$jscomp$1$$,$drawing_tool$jscomp$6$$,$drawing_path_QMARK_$jscomp$4$$,$path_editing_QMARK_$jscomp$1$$,$z_QMARK_$jscomp$4$$,$workspace_read_only_QMARK_$jscomp$1$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($cursor$jscomp$10$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$24$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$12$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$)),$APP.$rumext$v2$adapt$$($panning$jscomp$1$$),$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$6$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($z_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$1$$)],function(){var $new_cursor_show_pen_QMARK_$$=
function(){var $or__5025__auto__$jscomp$1335$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$296$path$$);return $or__5025__auto__$jscomp$1335$$?$or__5025__auto__$jscomp$1335$$:$APP.$cljs$core$truth_$$($drawing_path_QMARK_$jscomp$4$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$2052$curve$$):$drawing_path_QMARK_$jscomp$4$$}(),$show_zoom_QMARK_$$=function(){var $and__5023__auto__$jscomp$937$$=$APP.$cljs$core$_deref$$($z_QMARK_$jscomp$4$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$937$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$))&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$12$$))&&$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$4$$)&&$APP.$cljs$core$not$$($drawing_tool$jscomp$6$$):$and__5023__auto__$jscomp$937$$}();$new_cursor_show_pen_QMARK_$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$938$$=$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$12$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$938$$)?$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$):$and__5023__auto__$jscomp$938$$}())?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$2196$zoom$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($panning$jscomp$1$$)?$panning$jscomp$1$$:$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$))?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5906$hand$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,
$APP.$cljs$cst$3436$comments$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$3436$comments$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$1606$frame$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5907$create_artboard$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$1611$rect$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5908$create_rectangle$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$1417$circle$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5909$create_ellipse$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_zoom_QMARK_$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$24$$)):$show_zoom_QMARK_$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5910$zoom_in$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_zoom_QMARK_$$)?
$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$24$$):$show_zoom_QMARK_$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5911$zoom_out$$):$APP.$cljs$core$truth_$$($new_cursor_show_pen_QMARK_$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5912$pen$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$2052$curve$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5913$pencil$$):$APP.$cljs$core$truth_$$($drawing_tool$jscomp$6$$)?
$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5914$create_shape$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$941$$=$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$24$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$941$$)?$APP.$cljs$core$not$$($path_editing_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($workspace_read_only_QMARK_$jscomp$1$$):$and__5023__auto__$jscomp$941$$}())?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$4791$duplicate$$):
$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5915$pointer_inner$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cursor$jscomp$10$$),$new_cursor_show_pen_QMARK_$$)?$APP.$cljs$core$reset_BANG_$$($cursor$jscomp$10$$,$new_cursor_show_pen_QMARK_$$):null})};
$app$main$ui$workspace$viewport$hooks$setup_keyboard$$=function($alt_STAR_$$,$mod_STAR_$$,$space_STAR_$$,$z_STAR_$$,$shift_STAR_$$){var $kbd_zoom_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$filter$$(function($kevent$$){return(0,$APP.$app$util$keyboard$minus_QMARK_$$)($kevent$$)||(0,$APP.$app$util$keyboard$underscore_QMARK_$$)($kevent$$)||
(0,$APP.$app$util$keyboard$equals_QMARK_$$)($kevent$$)||(0,$APP.$app$util$keyboard$plus_QMARK_$$)($kevent$$)},$APP.$beicon$v2$core$filter$$($app$util$keyboard$mod_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$app$main$streams$keyboard$$))))}),$kbd_shift_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$app$util$keyboard$editing_event_QMARK_$$),$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$shift_key_QMARK_$$,$APP.$app$main$streams$keyboard$$))))}),$kbd_z_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$app$util$keyboard$editing_event_QMARK_$$),$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$z_QMARK_$$,$APP.$app$main$streams$keyboard$$))))});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5578$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$alt_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5590$$,
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$space_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($kbd_z_s$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$z_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($kbd_shift_s$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$shift_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$streams$keyboard_mod$$,
function($value$jscomp$1003$$){$APP.$cljs$core$reset_BANG_$$($mod_STAR_$$,$value$jscomp$1003$$);return $value$jscomp$1003$$?null:$APP.$cljs$core$reset_BANG_$$($z_STAR_$$,!1)});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($kbd_zoom_s$$,function($kevent$jscomp$1$$){$APP.$app$util$dom$prevent_default$$($kevent$jscomp$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$keyboard$minus_QMARK_$$)($kevent$jscomp$1$$)||(0,$APP.$app$util$keyboard$underscore_QMARK_$$)($kevent$jscomp$1$$)?
$APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$0$())})};
$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$=function($page_id$jscomp$446$$,$move_stream$jscomp$3$$,$objects$jscomp$816$$,$selected$jscomp$197$$,$mod_QMARK_$jscomp$13$$,$hover$jscomp$10$$,$measure_hover$$,$hover_ids$jscomp$5$$,$hover_top_frame_id$jscomp$6$$,$hover_disabled_QMARK_$$,$focus$jscomp$20$$,$zoom$jscomp$126$$,$show_measures_QMARK_$$,$read_only_QMARK_$jscomp$34$$,$transform$jscomp$114$$){var $zoom_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)($zoom$jscomp$126$$),$mod_ref$$=(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$13$$)),
$selected_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)($selected$jscomp$197$$),$hover_disabled_ref$$=(0,$APP.$rumext$v2$use_ref$$)($hover_disabled_QMARK_$$),$focus_ref$$=(0,$APP.$rumext$v2$use_ref$$)($focus$jscomp$20$$),$transform_ref$$=(0,$APP.$rumext$v2$use_ref$$)($transform$jscomp$114$$),$read_only_ref$$=(0,$APP.$rumext$v2$use_ref$$)($read_only_QMARK_$jscomp$34$$),$last_point_ref$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$mod_str$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),
$query_point$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$446$$)],function($point$jscomp$88_rect$jscomp$48$$){var $size$jscomp$inline_13738$$=5/$APP.$rumext$v2$ref_val$$($zoom_ref$jscomp$2$$);$point$jscomp$88_rect$jscomp$48$$=$APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($point$jscomp$88_rect$jscomp$48$$,$size$jscomp$inline_13738$$,$size$jscomp$inline_13738$$);return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($hover_disabled_ref$$))?
(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$PersistentVector$EMPTY$$):$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3605$index_SLASH_query_selection$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$446$$,$APP.$cljs$cst$1611$rect$$,$point$jscomp$88_rect$jscomp$48$$,$APP.$cljs$cst$3606$include_frames_QMARK_$$,!0,$cljs$cst$5916$clip_children_QMARK_$$,
$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($mod_ref$$)),$APP.$cljs$cst$3609$using_selrect_QMARK_$$,!1],null)))}),$over_shapes_stream$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($query_point$$),$APP.$rumext$v2$adapt$$($move_stream$jscomp$3$$),$APP.$rumext$v2$adapt$$($mod_str$$)],function(){return $APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$merge_map$$($query_point$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,
$APP.$beicon$v2$core$map$$(function(){return $APP.$cljs$core$_deref$$($last_point_ref$$)},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$mod_str$$)))),$APP.$beicon$v2$core$merge_map$$($query_point$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80810_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($last_point_ref$$,$p1__80810_SHARP_$$)},$move_stream$jscomp$3$$))))}),$over_shapes_stream_debounced$$=$APP.$beicon$v2$core$debounce$$(50,$over_shapes_stream$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($zoom$jscomp$126$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($zoom_ref$jscomp$2$$,$zoom$jscomp$126$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$13$$))],function(){$mod_str$$.next($cljs$cst$5917$update$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($mod_ref$$,$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$13$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$197$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($selected_ref$jscomp$1$$,$selected$jscomp$197$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hover_disabled_QMARK_$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($hover_disabled_ref$$,$hover_disabled_QMARK_$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus$jscomp$20$$)],
function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($focus_ref$$,$focus$jscomp$20$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transform$jscomp$114$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($transform_ref$$,$transform$jscomp$114$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$34$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($read_only_ref$$,$read_only_QMARK_$jscomp$34$$)});
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$($over_shapes_stream_debounced$$,[$APP.$rumext$v2$adapt$$($objects$jscomp$816$$)],function(){return $APP.$cljs$core$reset_BANG_$$($hover_top_frame_id$jscomp$6$$,$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$816$$,$APP.$cljs$core$_deref$$($last_point_ref$$),null,$APP.$rumext$v2$ref_val$$($read_only_ref$$)))});var $sorted_ids_cache$$=(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$($over_shapes_stream$$,[$APP.$rumext$v2$adapt$$($page_id$jscomp$446$$),$APP.$rumext$v2$adapt$$($objects$jscomp$816$$),$APP.$rumext$v2$adapt$$($show_measures_QMARK_$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$34$$)],function($ids$jscomp$317$$){function $no_fill_nested_frames_QMARK_$$($id$jscomp$1051_shape$jscomp$1085$$){$id$jscomp$1051_shape$jscomp$1085$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,
$id$jscomp$1051_shape$jscomp$1085$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1051_shape$jscomp$1085$$)&&!$APP.$app$common$files$helpers$is_direct_child_of_root_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$1051_shape$jscomp$1085$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1051_shape$jscomp$1085$$,$APP.$cljs$cst$1634$fills$$))}function $grouped_QMARK_$jscomp$3$$($id$jscomp$1050$$){var $and__5023__auto__$jscomp$943$$=
$APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$id$jscomp$1050$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$943$$)?!$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$id$jscomp$1050$$):$and__5023__auto__$jscomp$943$$}function $make_sorted_ids$$($mod_QMARK___$2$$,$ids__$1$jscomp$32$$){var $sorted_ids$jscomp$1$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$helpers$hidden_parent_QMARK_$$,$objects$jscomp$816$$)),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80811_SHARP_$$){var $and__5023__auto__$jscomp$942$$=$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$34$$);
return $and__5023__auto__$jscomp$942$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$p1__80811_SHARP_$$),$APP.$cljs$cst$1623$blocked$$):$and__5023__auto__$jscomp$942$$}),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$,$objects$jscomp$816$$))),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$816$$,
$ids__$1$jscomp$32$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2087$bottom_frames_QMARK_$$,$mod_QMARK___$2$$],null)));$APP.$rumext$v2$set_ref_val_BANG_$$($sorted_ids_cache$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cached_ids$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$mod_QMARK___$2$$,$ids__$1$jscomp$32$$],null),$sorted_ids$jscomp$1$$));return $sorted_ids$jscomp$1$$}var $selected__$1$jscomp$18$$=$APP.$rumext$v2$ref_val$$($selected_ref$jscomp$1$$),
$focus__$1$jscomp$1$$=$APP.$rumext$v2$ref_val$$($focus_ref$$),$mod_QMARK___$1$$=$APP.$rumext$v2$ref_val$$($mod_ref$$),$cached_ids$$=$APP.$rumext$v2$ref_val$$($sorted_ids_cache$$),$ids__$1$jscomp$31$$=function(){var $or__5025__auto__$jscomp$1337$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cached_ids$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$mod_QMARK___$1$$,$ids$jscomp$317$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1337$$)?
$or__5025__auto__$jscomp$1337$$:$make_sorted_ids$$($mod_QMARK___$1$$,$ids$jscomp$317$$)}(),$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80812_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$816$$,$p1__80812_SHARP_$$)}),$selected__$1$jscomp$18$$),$remove_hover_QMARK__remove_hover_xf$$=
$APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($grouped_QMARK_$jscomp$3$$):$APP.$cljs$core$not$$($mod_QMARK___$1$$)?function(){var $child_parent_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80814_SHARP_$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,
$p1__80814_SHARP_$$)}),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80815_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$816$$,$p1__80815_SHARP_$$)})),$ids__$1$jscomp$31$$);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$){var $JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$);if($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=
$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$))&&
!$APP.$app$common$types$component$instance_head_QMARK_$$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$)&&!$APP.$app$common$types$component$main_instance_QMARK_$$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$))return $JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$;
$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$);
$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$)?
!$APP.$cljs$core$contains_QMARK_$$($child_parent_QMARK_$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$):$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$;
if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$))var $JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$=$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$;
else{if($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1"))if($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=
$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$)))if($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=
!$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$18$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$)){$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=
$APP.$cljs$core$_deref$$($last_point_ref$$);if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$);var $fn_54073$jscomp$inline_13747$$=
$APP.$app$render_wasm$wasm$internal_module$$._intersect_position_in_shape;try{$JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$=$fn_54073$jscomp$inline_13747$$($buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$[0],$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$[1],
$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$[2],$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$[3],$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$))}catch($e54075$jscomp$inline_13753$$){throw $JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$=
$e54075$jscomp$inline_13753$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$=$APP.$cljs$core$truth_$$($buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$)?
$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$.$cljs$core$IFn$_invoke$arity$0$?$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$.$cljs$core$IFn$_invoke$arity$0$():$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$():
null,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$,$APP.$cljs$cst$2971$wasm_critical$$),$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=
["WASM Error (",$APP.$app$common$data$name$$($buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_intersect_position_in_shape",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$,$APP.$cljs$cst$273$code$$,$buffer$jscomp$inline_13745_code__52999__auto__$jscomp$inline_13751_code_num__52998__auto__$jscomp$inline_13750_p1__80816_SHARP__read_code_fn__52997__auto__$jscomp$inline_13749$$],
null),$JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$);}$JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$,1)}else $JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$=
!1;$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$=!$JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$}$JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$=
$JSCompiler_temp$jscomp$10959_JSCompiler_temp$jscomp$10960_JSCompiler_temp$jscomp$10961_and__5023__auto__$jscomp$inline_9294_hint__53000__auto__$jscomp$inline_13752_obj$jscomp$inline_13741_or__5025__auto__$jscomp$1338_or__5025__auto____$1$jscomp$149_position$jscomp$inline_13744$$}return $JSCompiler_inline_result$jscomp$10962_JSCompiler_temp$jscomp$10958_cause54074$jscomp$inline_13748_result$jscomp$inline_13746$$})}():null,$hover_shape$jscomp$3_remove_measure_xf$$=$APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($grouped_QMARK_$jscomp$3$$):$APP.$cljs$core$not$$($mod_QMARK___$1$$)?function(){var $child_parent_QMARK_$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80818_SHARP_$$){return $APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,
$p1__80818_SHARP_$$))}),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80819_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$816$$,$p1__80819_SHARP_$$)})),$ids__$1$jscomp$31$$);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80820_SHARP_$$){var $and__5023__auto__$jscomp$945$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$p1__80820_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$945$$)?
!$APP.$cljs$core$contains_QMARK_$$($child_parent_QMARK_$jscomp$1$$,$p1__80820_SHARP_$$):$and__5023__auto__$jscomp$945$$})}():null;$remove_hover_QMARK__remove_hover_xf$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($measure_hover_shape_remove_measure_QMARK__selected_with_parents$$,$remove_hover_QMARK__remove_hover_xf$$,$ids__$1$jscomp$31$$);$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($measure_hover_shape_remove_measure_QMARK__selected_with_parents$$,
$hover_shape$jscomp$3_remove_measure_xf$$,$ids__$1$jscomp$31$$);$hover_shape$jscomp$3_remove_measure_xf$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80822_SHARP_$$){var $or__5025__auto__$jscomp$1339$$=$APP.$cljs$core$empty_QMARK_$$($focus__$1$jscomp$1$$);return $or__5025__auto__$jscomp$1339$$?$or__5025__auto__$jscomp$1339$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,
$focus__$1$jscomp$1$$),$APP.$cljs$core$cons$$($p1__80822_SHARP_$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$816$$,$p1__80822_SHARP_$$)))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80821_SHARP_$$){return $APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?$no_fill_nested_frames_QMARK_$$($p1__80821_SHARP_$$):$mod_QMARK___$1$$},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($remove_hover_QMARK__remove_hover_xf$$,$ids__$1$jscomp$31$$)))));$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$=
$APP.$cljs$core$truth_$$($show_measures_QMARK_$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80824_SHARP_$$){var $or__5025__auto__$jscomp$1340$$=$APP.$cljs$core$empty_QMARK_$$($focus__$1$jscomp$1$$);return $or__5025__auto__$jscomp$1340$$?$or__5025__auto__$jscomp$1340$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,
$focus__$1$jscomp$1$$),$APP.$cljs$core$cons$$($p1__80824_SHARP_$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$816$$,$p1__80824_SHARP_$$)))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80823_SHARP_$$){return $APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?$no_fill_nested_frames_QMARK_$$($p1__80823_SHARP_$$):$mod_QMARK___$1$$},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($measure_hover_shape_remove_measure_QMARK__selected_with_parents$$,$ids__$1$jscomp$31$$))))):
null;$APP.$cljs$core$reset_BANG_$$($hover$jscomp$10$$,$hover_shape$jscomp$3_remove_measure_xf$$);$APP.$cljs$core$reset_BANG_$$($measure_hover$$,$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,$APP.$rumext$v2$ref_val$$($transform_ref$$))?$APP.$cljs$core$reset_BANG_$$($hover_ids$jscomp$5$$,$ids__$1$jscomp$31$$):null},function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($sorted_ids_cache$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)})};
$app$main$ui$workspace$viewport$hooks$setup_viewport_modifiers$$=function($modifiers$jscomp$132_modifiers__$1$jscomp$21$$,$objects$jscomp$817$$){var $root_frame_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$817$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$app$common$types$shape_tree$get_root_shapes$$($objects$jscomp$817$$))});$modifiers$jscomp$132_modifiers__$1$jscomp$21$$=$APP.$cljs$core$select_keys$$($modifiers$jscomp$132_modifiers__$1$jscomp$21$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($root_frame_ids$$,$APP.$app$common$uuid$zero$$));$APP.$app$main$ui$workspace$shapes$frame$dynamic_modifiers$use_dynamic_modifiers$$($objects$jscomp$817$$,$APP.$app$util$globals$document$$,$modifiers$jscomp$132_modifiers__$1$jscomp$21$$)};
$app$main$ui$workspace$viewport$hooks$inside_vbox$$=function($vbox$jscomp$58$$,$frame$jscomp$90_objects$jscomp$818$$,$and__5023__auto__$jscomp$948_frame_id$jscomp$151$$){$frame$jscomp$90_objects$jscomp$818$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$90_objects$jscomp$818$$,$and__5023__auto__$jscomp$948_frame_id$jscomp$151$$);return($and__5023__auto__$jscomp$948_frame_id$jscomp$151$$=$frame$jscomp$90_objects$jscomp$818$$!=null)?$app$common$geom$shapes$intersect$overlaps_QMARK_$$($frame$jscomp$90_objects$jscomp$818$$,
$vbox$jscomp$58$$):$and__5023__auto__$jscomp$948_frame_id$jscomp$151$$};
$app$main$ui$workspace$viewport$hooks$setup_active_frames$$=function($objects$jscomp$819$$,$hover_ids$jscomp$6$$,$selected$jscomp$198$$,$active_frames$jscomp$2$$,$zoom$jscomp$127$$,$transform$jscomp$115$$,$vbox$jscomp$59$$){var $all_frames$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$819$$)],function(){return $app$common$types$shape_tree$get_root_frames_ids$$($objects$jscomp$819$$)}),$selected_frames$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$198$$)],
function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$198$$,$all_frames$jscomp$1$$)}),$xf_selected_frame$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$root_frame_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80849_SHARP_$$){return $APP.$app$common$files$helpers$get_shape_id_root_frame$$($objects$jscomp$819$$,$p1__80849_SHARP_$$)})),
$selected_shapes_frames$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$198$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xf_selected_frame$$,$selected$jscomp$198$$)}),$active_selection$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$115$$,$APP.$cljs$cst$1798$move$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frames$jscomp$1$$),
1)?$APP.$cljs$core$first$$($selected_frames$jscomp$1$$):null,$last_hover_ids$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))],function(){return $APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))?$APP.$cljs$core$reset_BANG_$$($last_hover_ids$$,$APP.$cljs$core$set$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))):
null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$819$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$198$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$127$$),$APP.$rumext$v2$adapt$$($transform$jscomp$115$$),$APP.$rumext$v2$adapt$$($vbox$jscomp$59$$)],function(){var $hover_ids_QMARK_$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80850_SHARP_$$){return $APP.$app$common$files$helpers$get_shape_id_root_frame$$($objects$jscomp$819$$,
$p1__80850_SHARP_$$)},$APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))),$new_active_frames_new_active_frames__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$1052$$){return $zoom$jscomp$127$$>1.3||($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,$transform$jscomp$115$$)||$zoom$jscomp$127$$>=
.25)&&($APP.$cljs$core$contains_QMARK_$$($hover_ids_QMARK_$$,$id$jscomp$1052$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($last_hover_ids$$),$id$jscomp$1052$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1052$$,$active_selection$$)||$APP.$cljs$core$contains_QMARK_$$($selected_shapes_frames$$,$id$jscomp$1052$$)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$hooks$inside_vbox$$,
$vbox$jscomp$59$$,$objects$jscomp$819$$))),$all_frames$jscomp$1$$);$new_active_frames_new_active_frames__$1$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3054$disable_frame_thumbnails$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$all_frames$jscomp$1$$):$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3067$force_frame_thumbnails$$)?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$new_active_frames_new_active_frames__$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($active_frames$jscomp$2$$),
$new_active_frames_new_active_frames__$1$$)?$APP.$cljs$core$reset_BANG_$$($active_frames$jscomp$2$$,$new_active_frames_new_active_frames__$1$$):null})};
$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$=function($path_editing_QMARK_$jscomp$2$$,$drawing_path_QMARK_$jscomp$5$$,$text_editing_QMARK_$jscomp$2$$,$grid_editing_QMARK_$jscomp$1$$){$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$5918$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_workspace$$,$APP.$app$main$data$workspace$shortcuts$shortcuts$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$5$$),
$APP.$rumext$v2$adapt$$($grid_editing_QMARK_$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($grid_editing_QMARK_$jscomp$1$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$5919$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_grid$$,$app$main$data$workspace$grid_layout$shortcuts$shortcuts$$)),function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$5919$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_grid$$))}):
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($drawing_path_QMARK_$jscomp$5$$)?$drawing_path_QMARK_$jscomp$5$$:$path_editing_QMARK_$jscomp$2$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$5920$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_path$$,$APP.$app$main$data$workspace$path$shortcuts$shortcuts$$)),function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$5920$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_path$$))}):
$APP.$cljs$core$truth_$$($text_editing_QMARK_$jscomp$2$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$5921$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_text$$,$APP.$app$main$data$workspace$text$shortcuts$shortcuts$$)),function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$5921$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_text$$))}):
null})};
$app$main$ui$workspace$viewport$outline$outline$$=function($props_80704_props__$1$jscomp$104_zoom$jscomp$128$$){var $outline_type_shape$jscomp$1086$$=$props_80704_props__$1$jscomp$104_zoom$jscomp$128$$.shape,$modifier$jscomp$8_transform$jscomp$116$$=$props_80704_props__$1$jscomp$104_zoom$jscomp$128$$.modifier;$props_80704_props__$1$jscomp$104_zoom$jscomp$128$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_80704_props__$1$jscomp$104_zoom$jscomp$128$$.zoom,1);var $shape__$1$jscomp$120$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($outline_type_shape$jscomp$1086$$,
$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$8_transform$jscomp$116$$));$modifier$jscomp$8_transform$jscomp$116$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$120$$);var $objects$jscomp$820$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$color$jscomp$188$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1342$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$820$$,
$shape__$1$jscomp$120$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1342$$)?$or__5025__auto__$jscomp$1342$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape__$1$jscomp$120$$)}())?"var(--assets-component-hightlight)":"var(--color-accent-tertiary)",$x$jscomp$1288$$=$shape__$1$jscomp$120$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$512$$=$shape__$1$jscomp$120$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$241$$=$shape__$1$jscomp$120$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$290$width$$),$height$jscomp$208$$=$shape__$1$jscomp$120$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1522$height$$),$selrect$jscomp$87$$=$shape__$1$jscomp$120$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1605$selrect$$),
$type$jscomp$719$$=$shape__$1$jscomp$120$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$139$type$$),$content$jscomp$270$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1637$content$$),$path_QMARK_$jscomp$7$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$120$$),$path_data$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path_QMARK_$jscomp$7$$),
$APP.$rumext$v2$adapt$$($content$jscomp$270$$)],function(){return $path_QMARK_$jscomp$7$$&&$content$jscomp$270$$!=null?$content$jscomp$270$$.toString():null}),$border_attrs$$=$APP.$app$main$ui$shapes$attrs$get_border_props$$($shape__$1$jscomp$120$$);$outline_type_shape$jscomp$1086$$=function(){switch($type$jscomp$719$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$719$$.$fqn$:null){case "circle":return"ellipse";case "path":return"path";default:return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,
"d")!=null?"path":"rect"}}();$props_80704_props__$1$jscomp$104_zoom$jscomp$128$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({fill:"none",stroke:$color$jscomp$188$$,strokeWidth:1/$props_80704_props__$1$jscomp$104_zoom$jscomp$128$$,pointerEvents:"none",transform:$modifier$jscomp$8_transform$jscomp$116$$},function(){switch($type$jscomp$719$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$719$$.$fqn$:null){case "circle":return{cx:$x$jscomp$1288$$+$width$jscomp$241$$/2,cy:$y$jscomp$512$$+
$height$jscomp$208$$/2,rx:$width$jscomp$241$$/2,ry:$height$jscomp$208$$/2};case "path":return{d:$path_data$$,transform:null};default:var $x__$1$jscomp$30$$=$selrect$jscomp$87$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$87$$,$APP.$cljs$cst$1510$x$$),$y__$1$jscomp$3$$=$selrect$jscomp$87$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$87$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$46$$=$selrect$jscomp$87$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$87$$,
$APP.$cljs$cst$290$width$$),$h$jscomp$187$$=$selrect$jscomp$87$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$87$$,$APP.$cljs$cst$1522$height$$);return{x:$x__$1$jscomp$30$$,y:$y__$1$jscomp$3$$,width:$w$jscomp$46$$,height:$h$jscomp$187$$,rx:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,"rx"),ry:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,"ry"),d:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,
"d")}}}());return(0,$APP.$rumext$v2$create_element$$)($outline_type_shape$jscomp$1086$$,$props_80704_props__$1$jscomp$104_zoom$jscomp$128$$)};
$app$main$ui$workspace$viewport$outline$shape_outlines$$=function($props_80719$$){function $edition_QMARK_$jscomp$2$$($o$jscomp$277$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$15$$,$o$jscomp$277$$)}var $selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$=function(){var $or__5025__auto__$jscomp$1343$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,"selected");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1343$$)?
$or__5025__auto__$jscomp$1343$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}(),$hover$jscomp$11$$=function(){var $or__5025__auto__$jscomp$1344$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,"hover");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1344$$)?$or__5025__auto__$jscomp$1344$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}(),$highlighted$jscomp$5$$=function(){var $or__5025__auto__$jscomp$1345$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,
"highlighted");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1345$$)?$or__5025__auto__$jscomp$1345$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}(),$edition$jscomp$15$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,"edition"),$zoom$jscomp$130$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,"zoom"),$modifiers$jscomp$134_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,
"modifiers"),$lookup$jscomp$20$$=$APP.$app$common$data$getf$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80719$$,"objects"));$selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($edition_QMARK_$jscomp$2$$),
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($lookup$jscomp$20$$)),$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$,$hover$jscomp$11$$)),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($edition_QMARK_$jscomp$2$$),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($lookup$jscomp$20$$)),$highlighted$jscomp$5$$);$modifiers$jscomp$134_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$=
$APP.$cljs$core$select_keys$$($modifiers$jscomp$134_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$));$modifiers$jscomp$134_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$=$APP.$app$main$ui$hooks$use_equal_memo$$($modifiers$jscomp$134_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$);$selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$=$APP.$app$main$ui$hooks$use_equal_memo$$($selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$);
return(0,$APP.$rumext$v2$jsx$$)("g",{className:"outlines blurrable",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_render$$,{shapes:$selected$jscomp$199_shapes$jscomp$230_shapes__$1$jscomp$37$$,zoom:$zoom$jscomp$130$$,modifiers:$modifiers$jscomp$134_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$})})};
$app$main$ui$workspace$viewport$interactions$on_pointer_down$$=function($event$jscomp$700$$,$index$jscomp$574$$,$id$jscomp$1053_map__80791__$1_p__80790$$){$id$jscomp$1053_map__80791__$1_p__80790$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1053_map__80791__$1_p__80790$$);$id$jscomp$1053_map__80791__$1_p__80790$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1053_map__80791__$1_p__80790$$,$APP.$cljs$cst$266$id$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$700$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1053_map__80791__$1_p__80790$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$start_edit_interaction$$($index$jscomp$574$$))};
$app$main$ui$workspace$viewport$interactions$connect_to_shape$$=function($orig_rect_orig_shape$jscomp$1_orig_y$$,$dest_shape$jscomp$8_orig_pos$jscomp$4$$){$orig_rect_orig_shape$jscomp$1_orig_y$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$);var $dest_rect_dest_y$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$8_orig_pos$jscomp$4$$),$orig_x_orig_x_left$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$),
$orig_x_right$$=$orig_x_orig_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$),$dest_pos_orig_x_center$$=$orig_x_orig_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$)/2,$dest_x_dest_x_left$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$),$dest_x_right$$=$dest_x_dest_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$),
$dest_x_center$$=$dest_x_dest_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$)/2;$dest_shape$jscomp$8_orig_pos$jscomp$4$$=$orig_x_right$$<=$dest_x_dest_x_left$$?$APP.$cljs$cst$258$right$$:$orig_x_orig_x_left$$>=$dest_x_right$$?$APP.$cljs$cst$257$left$$:$dest_pos_orig_x_center$$<=$dest_x_center$$?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$258$right$$;$dest_pos_orig_x_center$$=$orig_x_right$$<=$dest_x_dest_x_left$$?$APP.$cljs$cst$257$left$$:$orig_x_orig_x_left$$>=
$dest_x_right$$?$APP.$cljs$cst$258$right$$:$dest_pos_orig_x_center$$<=$dest_x_center$$?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$258$right$$;$orig_x_orig_x_left$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dest_shape$jscomp$8_orig_pos$jscomp$4$$,$APP.$cljs$cst$258$right$$)?$orig_x_right$$:$orig_x_orig_x_left$$;$dest_x_dest_x_left$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dest_pos_orig_x_center$$,$APP.$cljs$cst$258$right$$)?$dest_x_right$$:$dest_x_dest_x_left$$;$orig_rect_orig_shape$jscomp$1_orig_y$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$)/2;$dest_rect_dest_y$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$)/2;return new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dest_shape$jscomp$8_orig_pos$jscomp$4$$,
$orig_x_orig_x_left$$,$orig_rect_orig_shape$jscomp$1_orig_y$$,$dest_pos_orig_x_center$$,$dest_x_dest_x_left$$,$dest_rect_dest_y$$],null)};
$app$main$ui$workspace$viewport$interactions$connect_to_point$$=function($dest_x$jscomp$1_orig_shape$jscomp$2$$,$dest_point_dest_y$jscomp$1$$){var $orig_rect$jscomp$1_orig_y$jscomp$1$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($dest_x$jscomp$1_orig_shape$jscomp$2$$),$orig_x$jscomp$1_orig_x_left$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$),$orig_x_right$jscomp$1$$=$orig_x$jscomp$1_orig_x_left$jscomp$1$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$),
$dest_pos$jscomp$1_orig_x_center$jscomp$1$$=$orig_x$jscomp$1_orig_x_left$jscomp$1$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$)/2;$dest_x$jscomp$1_orig_shape$jscomp$2$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($dest_point_dest_y$jscomp$1$$);$dest_point_dest_y$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($dest_point_dest_y$jscomp$1$$);var $orig_pos$jscomp$5$$=$orig_x_right$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?
$APP.$cljs$cst$258$right$$:$orig_x$jscomp$1_orig_x_left$jscomp$1$$>=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$257$left$$:$dest_pos$jscomp$1_orig_x_center$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$;$dest_pos$jscomp$1_orig_x_center$jscomp$1$$=$orig_x_right$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$257$left$$:$orig_x$jscomp$1_orig_x_left$jscomp$1$$>=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$258$right$$:
$dest_pos$jscomp$1_orig_x_center$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$;$orig_x$jscomp$1_orig_x_left$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orig_pos$jscomp$5$$,$APP.$cljs$cst$258$right$$)?$orig_x_right$jscomp$1$$:$orig_x$jscomp$1_orig_x_left$jscomp$1$$;$orig_rect$jscomp$1_orig_y$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$)/
2;return new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$orig_pos$jscomp$5$$,$orig_x$jscomp$1_orig_x_left$jscomp$1$$,$orig_rect$jscomp$1_orig_y$jscomp$1$$,$dest_pos$jscomp$1_orig_x_center$jscomp$1$$,$dest_x$jscomp$1_orig_shape$jscomp$2$$,$dest_point_dest_y$jscomp$1$$],null)};
$app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$=function($icon_pdata_props_80796$$){var $x$jscomp$1289$$=$icon_pdata_props_80796$$.x,$action_type$jscomp$3$$=$icon_pdata_props_80796$$.actionType,$y$jscomp$513$$=$icon_pdata_props_80796$$.y,$zoom$jscomp$131$$=$icon_pdata_props_80796$$.zoom,$stroke$jscomp$35$$=$icon_pdata_props_80796$$.stroke,$arrow_dir$$=$icon_pdata_props_80796$$.arrowDir;$icon_pdata_props_80796$$=function(){switch($action_type$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?
$action_type$jscomp$3$$.$fqn$:null){case "navigate":switch($arrow_dir$$ instanceof $APP.$cljs$core$Keyword$$?$arrow_dir$$.$fqn$:null){case "right":return"M -6.5 0 L 5.5 0 M 6.715 0.715 L -0.5 -6.5 M 6.715 -0.715 L -0.365 6.635";case "left":return"M 6.5 0 l -12 0 m -0.715 0.715 l 6.5 -6.9 m -6 6 l 6 6.35";default:return null}case "open-overlay":return"M-5 -5 h7 v7 h-7 z M2 -2 h3.5 v7 h-7 v-2.5";case "toggle-overlay":return"M-5 -5 h7 v7 h-7 z M2 -2 h3.5 v7 h-7 v-2.5";case "close-overlay":return"M -5 -5 L 5 5 M -5 5 L 5 -5";
case "prev-screen":switch($arrow_dir$$ instanceof $APP.$cljs$core$Keyword$$?$arrow_dir$$.$fqn$:null){case "left":return"M -6.5 0 l 12 0 l -6 -6 m 6 6 l -6 6";case "right":return"M 6.5 0 l -12 0 l 6 -6 m -6 6 l 6 6";default:return null}case "open-url":return"M1 -5 L 3 -7 L 7 -3 L 1 3 L -1 1M-1 5 L -3 7 L -7 3 L -1 -3 L 1 -1";default:return null}}();var $inv_zoom$jscomp$1$$=1/$zoom$jscomp$131$$;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("circle",
{cx:0,cy:0,r:$action_type$jscomp$3$$!=null?11:4,fill:$stroke$jscomp$35$$,transform:["scale(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),") translate(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$131$$*$x$jscomp$1289$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$131$$*$y$jscomp$513$$),")"].join("")}),$APP.$cljs$core$truth_$$($icon_pdata_props_80796$$)?
(0,$APP.$rumext$v2$jsx$$)("path",{fill:$stroke$jscomp$35$$,strokeWidth:2,stroke:"var(--app-white)",d:$icon_pdata_props_80796$$,transform:["scale(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),") translate(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$131$$*$x$jscomp$1289$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$131$$*$y$jscomp$513$$),
")"].join("")}):null]})};
$app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$=function($orig_x$jscomp$2_props_80802$$){var $dest_point$jscomp$1_orig_y$jscomp$2$$=$orig_x$jscomp$2_props_80802$$.destPoint,$action_type$jscomp$4$$=$orig_x$jscomp$2_props_80802$$.actionType,$zoom$jscomp$132$$=$orig_x$jscomp$2_props_80802$$.zoom,$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$=$orig_x$jscomp$2_props_80802$$.selected,$index$jscomp$575$$=$orig_x$jscomp$2_props_80802$$.index,$is_selected$jscomp$10$$=$orig_x$jscomp$2_props_80802$$.isSelected,
$dest_shape$jscomp$9$$=$orig_x$jscomp$2_props_80802$$.destShape,$dest_x$jscomp$2_level$jscomp$63$$=$orig_x$jscomp$2_props_80802$$.level,$orig_shape$jscomp$3$$=$orig_x$jscomp$2_props_80802$$.origShape,$dest_y$jscomp$2_vec__80807$$=$APP.$cljs$core$truth_$$($dest_shape$jscomp$9$$)?$app$main$ui$workspace$viewport$interactions$connect_to_shape$$($orig_shape$jscomp$3$$,$dest_shape$jscomp$9$$):$APP.$cljs$core$truth_$$($dest_point$jscomp$1_orig_y$jscomp$2$$)?$app$main$ui$workspace$viewport$interactions$connect_to_point$$($orig_shape$jscomp$3$$,
$dest_point$jscomp$1_orig_y$jscomp$2$$):$app$main$ui$workspace$viewport$interactions$connect_to_point$$($orig_shape$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($orig_shape$jscomp$3$$))+100/$zoom$jscomp$132$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($orig_shape$jscomp$3$$))-
50/$zoom$jscomp$132$$+$dest_x$jscomp$2_level$jscomp$63$$*32/$zoom$jscomp$132$$],null)),$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__80807$$,0,null);$orig_x$jscomp$2_props_80802$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__80807$$,1,null);$dest_point$jscomp$1_orig_y$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__80807$$,2,null);var $arrow_dir$jscomp$1_dest_pos$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__80807$$,3,null);$dest_x$jscomp$2_level$jscomp$63$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__80807$$,4,null);$dest_y$jscomp$2_vec__80807$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__80807$$,5,null);$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$,$APP.$cljs$cst$258$right$$)?
100:-100)/$zoom$jscomp$132$$;var $dest_dx$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arrow_dir$jscomp$1_dest_pos$jscomp$2$$,$APP.$cljs$cst$258$right$$)?100:-100)/$zoom$jscomp$132$$;$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["M",$orig_x$jscomp$2_props_80802$$,$dest_point$jscomp$1_orig_y$jscomp$2$$,"C",$orig_x$jscomp$2_props_80802$$+
$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$,$dest_point$jscomp$1_orig_y$jscomp$2$$,$dest_x$jscomp$2_level$jscomp$63$$+$dest_dx$$,$dest_y$jscomp$2_vec__80807$$,$dest_x$jscomp$2_level$jscomp$63$$,$dest_y$jscomp$2_vec__80807$$],null));$arrow_dir$jscomp$1_dest_pos$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arrow_dir$jscomp$1_dest_pos$jscomp$2$$,$APP.$cljs$cst$257$left$$)?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$;$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$=
$dest_shape$jscomp$9$$!=null&&$APP.$cljs$core$contains_QMARK_$$($incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$9$$));$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$=$APP.$cljs$core$truth_$$($is_selected$jscomp$10$$)?"var(--color-accent-tertiary)":$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$?"var(--color-accent-quaternary)":"var(--df-secondary)";return $APP.$cljs$core$not$$($is_selected$jscomp$10$$)?
(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:function($p1__80800_SHARP_$$){return $app$main$ui$workspace$viewport$interactions$on_pointer_down$$($p1__80800_SHARP_$$,$index$jscomp$575$$,$orig_shape$jscomp$3$$)},children:[(0,$APP.$rumext$v2$jsx$$)("path",{stroke:$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$,fill:"none",pointerEvents:"visible",strokeWidth:2/$zoom$jscomp$132$$,d:$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$}),$APP.$cljs$core$not$$($dest_shape$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,
{index:$index$jscomp$575$$,x:$dest_x$jscomp$2_level$jscomp$63$$,y:$dest_y$jscomp$2_vec__80807$$,stroke:$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$,actionType:$action_type$jscomp$4$$,arrowDir:$arrow_dir$jscomp$1_dest_pos$jscomp$2$$,zoom:$zoom$jscomp$132$$}):null]}):(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:function($p1__80801_SHARP_$$){return $app$main$ui$workspace$viewport$interactions$on_pointer_down$$($p1__80801_SHARP_$$,$index$jscomp$575$$,$orig_shape$jscomp$3$$)},children:[(0,$APP.$rumext$v2$jsx$$)("path",
{stroke:$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$,fill:"none",pointerEvents:"visible",strokeWidth:2/$zoom$jscomp$132$$,d:$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$}),$APP.$cljs$core$truth_$$($dest_shape$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$outline$$,{zoom:$zoom$jscomp$132$$,shape:$dest_shape$jscomp$9$$,color:$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,
{index:$index$jscomp$575$$,x:$orig_x$jscomp$2_props_80802$$,y:$dest_point$jscomp$1_orig_y$jscomp$2$$,stroke:$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$,zoom:$zoom$jscomp$132$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,{index:$index$jscomp$575$$,x:$dest_x$jscomp$2_level$jscomp$63$$,y:$dest_y$jscomp$2_vec__80807$$,stroke:$incoming_QMARK__selected$jscomp$200_stroke_color$jscomp$1$$,actionType:$action_type$jscomp$4$$,arrowDir:$arrow_dir$jscomp$1_dest_pos$jscomp$2$$,
zoom:$zoom$jscomp$132$$})]})};
$app$main$ui$workspace$viewport$interactions$interaction_handle_STAR_$$=function($handle_x_props_80826$$){var $zoom$jscomp$133$$=$handle_x_props_80826$$.zoom,$index$jscomp$576$$=$handle_x_props_80826$$.index,$shape$jscomp$1089$$=$handle_x_props_80826$$.shape,$handle_y_shape_rect$jscomp$1$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1089$$);$handle_x_props_80826$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$);
$handle_y_shape_rect$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$)/2;return(0,$APP.$rumext$v2$jsx$$)("g",{onPointerDown:function($p1__80825_SHARP_$$){return $app$main$ui$workspace$viewport$interactions$on_pointer_down$$($p1__80825_SHARP_$$,$index$jscomp$576$$,$shape$jscomp$1089$$)},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,
{x:$handle_x_props_80826$$,y:$handle_y_shape_rect$jscomp$1$$,stroke:"var(--color-accent-tertiary)",actionType:$APP.$cljs$cst$1941$navigate$$,arrowDir:$APP.$cljs$cst$258$right$$,zoom:$zoom$jscomp$133$$})})};
$app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$=function($marker_y_position$jscomp$234_props_80827$$){function $start_move_position$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$start_move_overlay_pos$$($index$jscomp$577$$))}var $index$jscomp$577$$=$marker_y_position$jscomp$234_props_80827$$.index,$objects$jscomp$822$$=$marker_y_position$jscomp$234_props_80827$$.objects,$dest_shape$jscomp$10_dest_shape__$1$$=
$marker_y_position$jscomp$234_props_80827$$.destShape,$page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$=$marker_y_position$jscomp$234_props_80827$$.pageId,$marker_x_orig_shape$jscomp$4$$=$marker_y_position$jscomp$234_props_80827$$.origShape,$is_hover_disabled$$=$marker_y_position$jscomp$234_props_80827$$.isHoverDisabled;$marker_y_position$jscomp$234_props_80827$$=$marker_y_position$jscomp$234_props_80827$$.position;if($APP.$cljs$core$truth_$$($dest_shape$jscomp$10_dest_shape__$1$$)){var $orig_frame$jscomp$2_width$jscomp$242$$=
$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$822$$,$marker_x_orig_shape$jscomp$4$$);$marker_x_orig_shape$jscomp$4$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($orig_frame$jscomp$2_width$jscomp$242$$)+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($marker_y_position$jscomp$234_props_80827$$);$marker_y_position$jscomp$234_props_80827$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($orig_frame$jscomp$2_width$jscomp$242$$)+
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($marker_y_position$jscomp$234_props_80827$$);$orig_frame$jscomp$2_width$jscomp$242$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$);var $height$jscomp$209$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$),$dest_x$jscomp$3$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$),$dest_y$jscomp$3$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$),
$shape_wrapper$jscomp$21$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$822$$)],function(){return $APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$822$$)}),$dest_shape_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$);$page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$),
$APP.$rumext$v2$adapt$$($dest_shape_id$$)],function(){return $APP.$app$main$refs$workspace_thumbnail_by_id$$($dest_shape_id$$)});$page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$=$APP.$rumext$v2$deref$$($page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$);$dest_shape$jscomp$10_dest_shape__$1$$=$page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($dest_shape$jscomp$10_dest_shape__$1$$,$APP.$cljs$cst$5161$thumbnail$$,$page_id$jscomp$447_thumbnail_data_thumbnail_data_ref$$):
$dest_shape$jscomp$10_dest_shape__$1$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:$start_move_position$$,onPointerEnter:function(){return $APP.$cljs$core$reset_BANG_$$($is_hover_disabled$$,!0)},onPointerLeave:function(){return $APP.$cljs$core$reset_BANG_$$($is_hover_disabled$$,!1)},children:[(0,$APP.$rumext$v2$jsx$$)("g",{transform:$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_x_orig_shape$jscomp$4$$-
$dest_x$jscomp$3$$,$marker_y_position$jscomp$234_props_80827$$-$dest_y$jscomp$3$$)),children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$render_thumbnails$$),{value:!0,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$embed$context$$),{value:!1,children:(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$21$$,{shape:$dest_shape$jscomp$10_dest_shape__$1$$})})})}),(0,$APP.$rumext$v2$jsx$$)("path",{stroke:"var(--color-accent-tertiary)",
fill:"var(--app-black)",fillOpacity:.5,strokeWidth:1,d:"M"+($marker_x_orig_shape$jscomp$4$$??"")+" "+($marker_y_position$jscomp$234_props_80827$$??"")+" h "+($orig_frame$jscomp$2_width$jscomp$242$$??"")+" v "+($height$jscomp$209$$??"")+" h -"+($orig_frame$jscomp$2_width$jscomp$242$$??"")+" zM"+($marker_x_orig_shape$jscomp$4$$??"")+" "+($marker_y_position$jscomp$234_props_80827$$??"")+" l "+($orig_frame$jscomp$2_width$jscomp$242$$??"")+" "+($height$jscomp$209$$??"")+" M"+($marker_x_orig_shape$jscomp$4$$??
"")+" "+($marker_y_position$jscomp$234_props_80827$$+$height$jscomp$209$$??"")+" l "+($orig_frame$jscomp$2_width$jscomp$242$$??"")+" -"+($height$jscomp$209$$??"")+" "}),(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$marker_x_orig_shape$jscomp$4$$+$orig_frame$jscomp$2_width$jscomp$242$$/2,cy:$marker_y_position$jscomp$234_props_80827$$+$height$jscomp$209$$/2,r:8,fill:"var(--color-accent-tertiary)"})]})}return null};
$app$main$ui$workspace$viewport$interactions$interactions_STAR_$$=function($active_shapes_props_80831$$){function $calc_level$$($index$jscomp$578$$,$interactions$jscomp$24$$){return $APP.$cljs$core$count$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80830_SHARP_$$){return $APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__80830_SHARP_$$)==null},$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($interactions$jscomp$24$$,0,$index$jscomp$578$$)))}
var $zoom$jscomp$134$$=$active_shapes_props_80831$$.zoom,$selected$jscomp$201$$=$active_shapes_props_80831$$.selected,$objects$jscomp$823$$=$active_shapes_props_80831$$.objects,$current_transform$$=$active_shapes_props_80831$$.currentTransform,$page_id$jscomp$448$$=$active_shapes_props_80831$$.pageId,$is_hover_disabled$jscomp$1$$=$active_shapes_props_80831$$.isHoverDisabled;$active_shapes_props_80831$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80829_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($p1__80829_SHARP_$$))})),$APP.$cljs$core$vals$$($objects$jscomp$823$$));var $selected_shapes$jscomp$34$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$823$$)),
$selected$jscomp$201$$),$draw_interaction_to_map__80832$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$viewport$interactions$interactions_ref$$),$first_selected$jscomp$2_map__80832__$1$$=$APP.$cljs$core$__destructure_map$$($draw_interaction_to_map__80832$$),$editing_interaction_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__80832__$1$$,$APP.$cljs$cst$4311$editing_interaction_index$$);$draw_interaction_to_map__80832$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__80832__$1$$,
$APP.$cljs$cst$4313$draw_interaction_to$$);var $draw_interaction_to_frame$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__80832__$1$$,$APP.$cljs$cst$4314$draw_interaction_to_frame$$),$move_overlay_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__80832__$1$$,$APP.$cljs$cst$4317$move_overlay_to$$),$move_overlay_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__80832__$1$$,$APP.$cljs$cst$4318$move_overlay_index$$);
$first_selected$jscomp$2_map__80832__$1$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$34$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"interactions",children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"non-selected",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$227$$,$shape$jscomp$1090$$){$out_arr__44124__auto__$jscomp$227$$.push($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$23$$,
$JSCompiler_temp_const$jscomp$1926_p__80834$$){var $JSCompiler_inline_result$jscomp$1928_index$jscomp$579$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1926_p__80834$$,0,null),$interaction$jscomp$54$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1926_p__80834$$,1,null);$JSCompiler_temp_const$jscomp$1926_p__80834$$=$out_arr__44124__auto____$1$jscomp$23$$.push;var $dest_shape$jscomp$inline_9299$$=$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$destination_QMARK_$$($interaction$jscomp$54$$))?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$823$$,$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$54$$)):null,$selected_QMARK_$jscomp$inline_9300$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$201$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)),$level$jscomp$inline_9301$$=$calc_level$$($JSCompiler_inline_result$jscomp$1928_index$jscomp$579$$,$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$));
$JSCompiler_inline_result$jscomp$1928_index$jscomp$579$$=$selected_QMARK_$jscomp$inline_9300$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,{zoom:$zoom$jscomp$134$$,selected:$selected$jscomp$201$$,index:$JSCompiler_inline_result$jscomp$1928_index$jscomp$579$$,isSelected:!1,destShape:$dest_shape$jscomp$inline_9299$$,level:$level$jscomp$inline_9301$$,origShape:$shape$jscomp$1090$$,actionType:$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$54$$)},
"non-selected-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)??"")+"-"+($JSCompiler_inline_result$jscomp$1928_index$jscomp$579$$??""));$JSCompiler_temp_const$jscomp$1926_p__80834$$.call($out_arr__44124__auto____$1$jscomp$23$$,$JSCompiler_inline_result$jscomp$1928_index$jscomp$579$$);return $out_arr__44124__auto____$1$jscomp$23$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$))));
return $out_arr__44124__auto__$jscomp$227$$},[],$active_shapes_props_80831$$)}),(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selected",children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($draw_interaction_to_map__80832$$)?$first_selected$jscomp$2_map__80832__$1$$:$draw_interaction_to_map__80832$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,{index:null,origShape:$first_selected$jscomp$2_map__80832__$1$$,destPoint:$draw_interaction_to_map__80832$$,
destShape:$draw_interaction_to_frame$$,isSelected:!0,actionType:$APP.$cljs$cst$1941$navigate$$,zoom:$zoom$jscomp$134$$},"interactive"):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$228$$,$shape$jscomp$1091$$){$out_arr__44124__auto__$jscomp$228$$.push($APP.$cljs$core$seq$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$24$$,
$JSCompiler_temp_const$jscomp$1929_p__80838$$){var $JSCompiler_temp$jscomp$1931_index$jscomp$580$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1929_p__80838$$,0,null),$interaction$jscomp$55$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1929_p__80838$$,1,null);$JSCompiler_temp_const$jscomp$1929_p__80838$$=$out_arr__44124__auto____$1$jscomp$24$$.push;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1931_index$jscomp$580$$,
$editing_interaction_index$$))$JSCompiler_temp$jscomp$1931_index$jscomp$580$$=null;else{var $dest_shape$jscomp$inline_9303$$=$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$destination_QMARK_$$($interaction$jscomp$55$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$823$$,$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$)):null,$level$jscomp$inline_9304$$=$calc_level$$($JSCompiler_temp$jscomp$1931_index$jscomp$580$$,$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$));
$JSCompiler_temp$jscomp$1931_index$jscomp$580$$=(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,{index:$JSCompiler_temp$jscomp$1931_index$jscomp$580$$,level:$level$jscomp$inline_9304$$,origShape:$shape$jscomp$1091$$,destShape:$dest_shape$jscomp$inline_9303$$,selected:$selected$jscomp$201$$,isSelected:!0,actionType:$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),zoom:$zoom$jscomp$134$$}),
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),$APP.$cljs$cst$1946$open_overlay$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),$APP.$cljs$cst$1944$toggle_overlay$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),
$APP.$cljs$cst$1673$manual$$)?$move_overlay_to$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($move_overlay_index$$,$JSCompiler_temp$jscomp$1931_index$jscomp$580$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$,{pageId:$page_id$jscomp$448$$,index:$JSCompiler_temp$jscomp$1931_index$jscomp$580$$,origShape:$shape$jscomp$1091$$,destShape:$dest_shape$jscomp$inline_9303$$,position:$move_overlay_to$$,objects:$objects$jscomp$823$$,isHoverDisabled:$is_hover_disabled$jscomp$1$$}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$,{pageId:$page_id$jscomp$448$$,index:$JSCompiler_temp$jscomp$1931_index$jscomp$580$$,origShape:$shape$jscomp$1091$$,destShape:$dest_shape$jscomp$inline_9303$$,position:$APP.$cljs$cst$1970$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),objects:$objects$jscomp$823$$,isHoverDisabled:$is_hover_disabled$jscomp$1$$}):null]},"interaction-path-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)??
"")+"-"+($JSCompiler_temp$jscomp$1931_index$jscomp$580$$??""))}$JSCompiler_temp_const$jscomp$1929_p__80838$$.call($out_arr__44124__auto____$1$jscomp$24$$,$JSCompiler_temp$jscomp$1931_index$jscomp$580$$);return $out_arr__44124__auto____$1$jscomp$24$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))):$APP.$cljs$core$truth_$$(function(){var $JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$;
if($APP.$cljs$core$truth_$$($shape$jscomp$1091$$)){if($JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$=!$app$common$files$helpers$unframed_shape_QMARK_$$($shape$jscomp$1091$$))$JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1798$move$$,
null,$APP.$cljs$cst$2863$rotate$$,null],null),null),$JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$=$JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$.$cljs$core$IFn$_invoke$arity$1$($current_transform$$):
$JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$($current_transform$$),$JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$=$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$)}else $JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$=
$shape$jscomp$1091$$;return $JSCompiler_inline_result$jscomp$1934_JSCompiler_temp$jscomp$1932_JSCompiler_temp$jscomp$1933_fexpr__80843$jscomp$inline_9306$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_handle_STAR_$$,{index:null,shape:$shape$jscomp$1091$$,selected:$selected$jscomp$201$$,zoom:$zoom$jscomp$134$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)):null);return $out_arr__44124__auto__$jscomp$228$$},[],$selected_shapes$jscomp$34$$)]})]})};
$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$=function($brx_img_width$jscomp$1_map__80851_viewport_node$$,$canvas$jscomp$16_offset$jscomp$217$$,$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$,$zoom_context_zoom_view_context$$,$last_picked_color$$,$client_x$jscomp$2_x$jscomp$1290$$,$client_y_y$jscomp$514$$){$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$=$APP.$rumext$v2$ref_val$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$);
if($APP.$cljs$core$truth_$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$)){var $bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$=$APP.$goog$dom$getElement$$("picker-detail");if($APP.$cljs$core$truth_$$($bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$)){$APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($zoom_context_zoom_view_context$$))||$APP.$rumext$v2$set_ref_val_BANG_$$($zoom_context_zoom_view_context$$,$bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$.getContext("2d"));
$brx_img_width$jscomp$1_map__80851_viewport_node$$=$APP.$app$util$dom$get_bounding_rect$$($brx_img_width$jscomp$1_map__80851_viewport_node$$);$bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$=$APP.$cljs$core$__destructure_map$$($brx_img_width$jscomp$1_map__80851_viewport_node$$);$brx_img_width$jscomp$1_map__80851_viewport_node$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$,$APP.$cljs$cst$257$left$$);
$bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$,$APP.$cljs$cst$1562$top$$);$client_x$jscomp$2_x$jscomp$1290$$=$APP.$app$common$math$floor$$($client_x$jscomp$2_x$jscomp$1290$$-$brx_img_width$jscomp$1_map__80851_viewport_node$$);$client_y_y$jscomp$514$$=$APP.$app$common$math$floor$$($client_y_y$jscomp$514$$-$bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$);
$brx_img_width$jscomp$1_map__80851_viewport_node$$=$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$.width;$bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$=$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$.height;$zoom_context_zoom_view_context$$=$APP.$rumext$v2$ref_val$$($zoom_context_zoom_view_context$$);var $sx$jscomp$12$$=$client_x$jscomp$2_x$jscomp$1290$$-32,$sy$jscomp$11$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$)?
$client_y_y$jscomp$514$$:$client_y_y$jscomp$514$$-17;$APP.$cljs$core$truth_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom_context_zoom_view_context$$,"imageSmoothingEnabled"))&&$APP.$app$util$object$set_BANG_$$($zoom_context_zoom_view_context$$,"imageSmoothingEnabled",!1);$zoom_context_zoom_view_context$$.clearRect(0,0,260,140);$zoom_context_zoom_view_context$$.drawImage($canvas$jscomp$16_offset$jscomp$217$$,$sx$jscomp$12$$,$sy$jscomp$11$$,65,35,0,0,260,140);if($client_x$jscomp$2_x$jscomp$1290$$>=
0&&$client_x$jscomp$2_x$jscomp$1290$$<$brx_img_width$jscomp$1_map__80851_viewport_node$$&&$client_y_y$jscomp$514$$>=0&&$client_y_y$jscomp$514$$<$bry_img_height$jscomp$1_map__80851__$1_temp__5825__auto____$1$jscomp$25$$){$canvas$jscomp$16_offset$jscomp$217$$=($client_y_y$jscomp$514$$*$brx_img_width$jscomp$1_map__80851_viewport_node$$+$client_x$jscomp$2_x$jscomp$1290$$)*4;$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$=$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$.data;
var $color$jscomp$189$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$,0+$canvas$jscomp$16_offset$jscomp$217$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$,1+$canvas$jscomp$16_offset$jscomp$217$$),
255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$,2+$canvas$jscomp$16_offset$jscomp$217$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$432$$,3+$canvas$jscomp$16_offset$jscomp$217$$),255)],null);$APP.$rumext$v2$set_ref_val_BANG_$$($last_picked_color$$,$color$jscomp$189$$);
return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$pick_color$$($color$jscomp$189$$))})}}}return null};
$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay$$=function($handle_pointer_down_picker_props_80852$$){var $vport$jscomp$13$$=$handle_pointer_down_picker_props_80852$$.vport,$viewport_node$jscomp$1$$=$APP.$rumext$v2$ref_val$$($handle_pointer_down_picker_props_80852$$["viewport-ref"]),$canvas$jscomp$17$$=$app$main$ui$workspace$viewport$pixel_overlay$get_offscreen_canvas$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$13$$),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$13$$)),
$canvas_context$jscomp$1$$=$canvas$jscomp$17$$.getContext("2d",{willReadFrequently:!0}),$canvas_image_data$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$zoom_view_context$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_picked_color$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$initial_mouse_pos$$=(0,$APP.$rumext$v2$use_ref$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,0],null)),$update_str$$=$APP.$beicon$v2$core$subject$$(),$handle_keydown$jscomp$3$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$701$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$701$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$701$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$701$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$stop_picker$$()),$APP.$app$main$data$modal$disallow_click_outside_BANG_$$()):null});$handle_pointer_down_picker_props_80852$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$702$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$702$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$702$$);var $color$jscomp$190$$=$APP.$rumext$v2$ref_val$$($last_picked_color$jscomp$1$$);return $color$jscomp$190$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$5922$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color$$($color$jscomp$190$$),
$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$702$$.shiftKey)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$5922$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$702$$.shiftKey)]))});var $handle_pointer_up_picker$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$703$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$703$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$703$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($cljs$cst$5922$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$stop_picker$$()]));return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()}),$handle_draw_picker_canvas$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $svg_node$jscomp$1$$=
$APP.$goog$dom$getElement$$("render"),$fonts$jscomp$39$$=$app$main$fonts$get_node_fonts$$($svg_node$jscomp$1$$),$result$jscomp$381$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3766$node$$,$svg_node$jscomp$1$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$13$$),$APP.$cljs$cst$828$result$$,"image-bitmap"],null);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($image_bitmap_image_data$jscomp$3$$){$canvas_context$jscomp$1$$.drawImage($image_bitmap_image_data$jscomp$3$$,
0,0);$image_bitmap_image_data$jscomp$3$$=$canvas_context$jscomp$1$$.getImageData(0,0,$canvas$jscomp$17$$.width,$canvas$jscomp$17$$.height);var $map__80856__$1_my$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($APP.$rumext$v2$ref_val$$($initial_mouse_pos$$)),$mx$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80856__$1_my$jscomp$2$$,$APP.$cljs$cst$1510$x$$);$map__80856__$1_my$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80856__$1_my$jscomp$2$$,$APP.$cljs$cst$1511$y$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($canvas_image_data$jscomp$1$$,$image_bitmap_image_data$jscomp$3$$);return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$($viewport_node$jscomp$1$$,$canvas$jscomp$17$$,$canvas_image_data$jscomp$1$$,$zoom_view_context$jscomp$1$$,$last_picked_color$jscomp$1$$,$mx$jscomp$2$$,$map__80856__$1_my$jscomp$2$$)},$APP.$beicon$v2$core$mapcat$$($app$main$rasterizer$render_node$$,$APP.$beicon$v2$core$map$$(function($styles$jscomp$34$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$381$$,
$APP.$cljs$cst$2940$styles$$,$styles$jscomp$34$$)},$APP.$app$main$fonts$render_font_styles_cached$$($fonts$jscomp$39$$))))}),$handle_svg_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $update_str$$.next($cljs$cst$5917$update$$)}),$handle_mouse_enter$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$1$$)],function($event$jscomp$704$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$event$jscomp$704$$.clientX,$APP.$cljs$cst$1511$y$$,$event$jscomp$704$$.clientY],null))}),$handle_pointer_move_picker$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$1$$)],function($event$jscomp$705$$){return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$($viewport_node$jscomp$1$$,$canvas$jscomp$17$$,$canvas_image_data$jscomp$1$$,$zoom_view_context$jscomp$1$$,
$last_picked_color$jscomp$1$$,$event$jscomp$705$$.clientX,$event$jscomp$705$$.clientY)});$APP.$cljs$core$truth_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_context$jscomp$1$$,"imageSmoothingEnabled"))&&$APP.$app$util$object$set_BANG_$$($canvas_context$jscomp$1$$,"imageSmoothingEnabled",!1);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$433$$=$APP.$goog$dom$getElement$$("pixel-overlay");return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$433$$)?
$temp__5825__auto__$jscomp$433$$.focus():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$110$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$handle_keydown$jscomp$3$$);return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$110$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$25$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_draw_picker_canvas$$,
$APP.$beicon$v2$core$debounce$$(10,$update_str$$));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$25$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $svg_node$jscomp$2$$=$APP.$goog$dom$getElement$$("render"),$observer$jscomp$9$$=new MutationObserver($handle_svg_change$$);$observer$jscomp$9$$.observe($svg_node$jscomp$2$$,{attributes:!0,childList:!0,subtree:!0,characterData:!0});$handle_svg_change$$.$cljs$core$IFn$_invoke$arity$0$?$handle_svg_change$$.$cljs$core$IFn$_invoke$arity$0$():
$handle_svg_change$$();return function(){return $observer$jscomp$9$$.disconnect()}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$111$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"pointermove",function($e$jscomp$383$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$e$jscomp$383$$.clientX,$APP.$cljs$cst$1511$y$$,$e$jscomp$383$$.clientY],null))});
return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$111$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{id:"pixel-overlay",tabIndex:0,onPointerDown:$handle_pointer_down_picker_props_80852$$,onPointerUp:$handle_pointer_up_picker$$,onPointerMove:$handle_pointer_move_picker$$,onMouseEnter:$handle_mouse_enter$$,className:""+($APP.$app$main$ui$css_cursors$get_static$$("picker")??"")+" main_ui_workspace_viewport_pixel_overlay__pixel-overlay"})};
$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$=function($brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$,$canvas$jscomp$18_offset$jscomp$218$$,$canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$,$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,$last_picked_color$jscomp$2$$,$canvas_x_client_x$jscomp$3$$,$canvas_y_client_y$jscomp$1$$){$canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$=$APP.$rumext$v2$ref_val$$($canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$);
if($APP.$cljs$core$truth_$$($canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$)){var $bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$=$APP.$goog$dom$getElement$$("picker-detail");if($APP.$cljs$core$truth_$$($bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$)){$APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$))||$APP.$rumext$v2$set_ref_val_BANG_$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,
$bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$.getContext("2d"));$brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$=$APP.$app$util$dom$get_bounding_rect$$($brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$);$bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$=$APP.$cljs$core$__destructure_map$$($brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$);$brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$,$APP.$cljs$cst$257$left$$);$bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$,$APP.$cljs$cst$1562$top$$);$canvas_x_client_x$jscomp$3$$=$APP.$app$common$math$floor$$($canvas_x_client_x$jscomp$3$$-
$brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$)*$APP.$app$render_wasm$api$dpr$$;$canvas_y_client_y$jscomp$1$$=$APP.$app$common$math$floor$$($canvas_y_client_y$jscomp$1$$-$bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$)*$APP.$app$render_wasm$api$dpr$$;$brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$=$canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$.width;$bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$=
$canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$.height;$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$=$APP.$rumext$v2$ref_val$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$);var $sx$jscomp$13$$=$canvas_x_client_x$jscomp$3$$-32,$sy$jscomp$12$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$)?$canvas_y_client_y$jscomp$1$$:$canvas_y_client_y$jscomp$1$$-17;$APP.$cljs$core$truth_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,
"imageSmoothingEnabled"))&&$APP.$app$util$object$set_BANG_$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,"imageSmoothingEnabled",!1);$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$.clearRect(0,0,260,140);$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$.drawImage($canvas$jscomp$18_offset$jscomp$218$$,$sx$jscomp$13$$,$sy$jscomp$12$$,65,35,0,0,260,140);if($canvas_x_client_x$jscomp$3$$>=0&&$canvas_x_client_x$jscomp$3$$<$brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$&&
$canvas_y_client_y$jscomp$1$$>=0&&$canvas_y_client_y$jscomp$1$$<$bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$){$canvas$jscomp$18_offset$jscomp$218$$=(($bry$jscomp$1_img_height$jscomp$2_map__80869__$1_temp__5825__auto____$1$jscomp$26$$-$canvas_y_client_y$jscomp$1$$-1)*$brx$jscomp$1_img_width$jscomp$2_map__80869_viewport_node$jscomp$2$$+$canvas_x_client_x$jscomp$3$$)*4;$canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$=$canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$.data;
var $color$jscomp$191$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$,0+$canvas$jscomp$18_offset$jscomp$218$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$,
1+$canvas$jscomp$18_offset$jscomp$218$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$,2+$canvas$jscomp$18_offset$jscomp$218$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data$jscomp$2_rgba$jscomp$13_temp__5825__auto__$jscomp$434$$,3+$canvas$jscomp$18_offset$jscomp$218$$),255)],null);$APP.$rumext$v2$set_ref_val_BANG_$$($last_picked_color$jscomp$2$$,
$color$jscomp$191$$);return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$pick_color$$($color$jscomp$191$$))})}}}return null};
$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_wasm_STAR_$$=function($handle_pointer_down_picker$jscomp$1_props_80874$$){var $viewport_node$jscomp$3$$=$APP.$rumext$v2$ref_val$$($handle_pointer_down_picker$jscomp$1_props_80874$$.viewportRef),$canvas$jscomp$19$$=$APP.$rumext$v2$ref_val$$($handle_pointer_down_picker$jscomp$1_props_80874$$.canvasRef),$canvas_context$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$canvas_image_data$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$zoom_view_context$jscomp$3$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$last_picked_color$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$initial_mouse_pos$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,0],null)),$update_str$jscomp$1$$=$APP.$beicon$v2$core$subject$$(),$handle_keydown$jscomp$4$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$706$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$706$$))?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$706$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$706$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$stop_picker$$()),$APP.$app$main$data$modal$disallow_click_outside_BANG_$$()):null});$handle_pointer_down_picker$jscomp$1_props_80874$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$707$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$707$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$707$$);var $color$jscomp$192$$=$APP.$rumext$v2$ref_val$$($last_picked_color$jscomp$3$$);return $color$jscomp$192$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$5922$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color$$($color$jscomp$192$$),$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$707$$.shiftKey)])):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$5922$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$707$$.shiftKey)]))});var $handle_pointer_up_picker$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$708$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$708$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$708$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($cljs$cst$5922$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$stop_picker$$()]));return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()}),$handle_draw_picker_canvas$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($canvas_context$jscomp$2$$)],
function(){var $image_data$jscomp$5_temp__5825__auto__$jscomp$435$$=$APP.$rumext$v2$ref_val$$($canvas_context$jscomp$2$$);if($APP.$cljs$core$truth_$$($image_data$jscomp$5_temp__5825__auto__$jscomp$435$$)){var $mx$jscomp$3_width$jscomp$247$$=$canvas$jscomp$19$$.width,$height$jscomp$214_map__80875__$1_my$jscomp$3$$=$canvas$jscomp$19$$.height,$buffer$jscomp$81$$=new Uint8ClampedArray($mx$jscomp$3_width$jscomp$247$$*$height$jscomp$214_map__80875__$1_my$jscomp$3$$*4);$image_data$jscomp$5_temp__5825__auto__$jscomp$435$$.readPixels(0,
0,$mx$jscomp$3_width$jscomp$247$$,$height$jscomp$214_map__80875__$1_my$jscomp$3$$,$image_data$jscomp$5_temp__5825__auto__$jscomp$435$$.RGBA,$image_data$jscomp$5_temp__5825__auto__$jscomp$435$$.UNSIGNED_BYTE,$buffer$jscomp$81$$);$image_data$jscomp$5_temp__5825__auto__$jscomp$435$$=new ImageData($buffer$jscomp$81$$,$mx$jscomp$3_width$jscomp$247$$,$height$jscomp$214_map__80875__$1_my$jscomp$3$$);$height$jscomp$214_map__80875__$1_my$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($APP.$rumext$v2$ref_val$$($initial_mouse_pos$jscomp$1$$));
$mx$jscomp$3_width$jscomp$247$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$214_map__80875__$1_my$jscomp$3$$,$APP.$cljs$cst$1510$x$$);$height$jscomp$214_map__80875__$1_my$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$214_map__80875__$1_my$jscomp$3$$,$APP.$cljs$cst$1511$y$$);$APP.$rumext$v2$set_ref_val_BANG_$$($canvas_image_data$jscomp$3$$,$image_data$jscomp$5_temp__5825__auto__$jscomp$435$$);return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$($viewport_node$jscomp$3$$,
$canvas$jscomp$19$$,$canvas_image_data$jscomp$3$$,$zoom_view_context$jscomp$3$$,$last_picked_color$jscomp$3$$,$mx$jscomp$3_width$jscomp$247$$,$height$jscomp$214_map__80875__$1_my$jscomp$3$$)}return null}),$handle_canvas_changed$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $update_str$jscomp$1$$.next($cljs$cst$5917$update$$)}),$handle_mouse_enter$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$3$$)],
function($event$jscomp$709$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$event$jscomp$709$$.clientX,$APP.$cljs$cst$1511$y$$,$event$jscomp$709$$.clientY],null))}),$handle_pointer_move_picker$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$3$$)],function($event$jscomp$710$$){return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$($viewport_node$jscomp$3$$,
$canvas$jscomp$19$$,$canvas_image_data$jscomp$3$$,$zoom_view_context$jscomp$3$$,$last_picked_color$jscomp$3$$,$event$jscomp$710$$.clientX,$event$jscomp$710$$.clientY)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($canvas$jscomp$19$$)],function(){var $context$jscomp$31$$=$canvas$jscomp$19$$.getContext("webgl2",{willReadFrequently:!0,preserveDrawingBuffer:!0});return $APP.$rumext$v2$set_ref_val_BANG_$$($canvas_context$jscomp$2$$,$context$jscomp$31$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$436$$=
$APP.$goog$dom$getElement$$("pixel-overlay");return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$436$$)?$temp__5825__auto__$jscomp$436$$.focus():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$112$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$handle_keydown$jscomp$4$$);return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$112$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$26$$=
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_draw_picker_canvas$jscomp$1$$,$APP.$beicon$v2$core$debounce$$(10,$update_str$jscomp$1$$));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$26$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$handle_canvas_changed$$.$cljs$core$IFn$_invoke$arity$0$?$handle_canvas_changed$$.$cljs$core$IFn$_invoke$arity$0$():$handle_canvas_changed$$();$APP.$app$util$globals$document$$.addEventListener("penpot:wasm:render",
$handle_canvas_changed$$);return function(){return $APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:render",$handle_canvas_changed$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$113$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"pointermove",function($e$jscomp$384$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,
$e$jscomp$384$$.clientX,$APP.$cljs$cst$1511$y$$,$e$jscomp$384$$.clientY],null))});return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$113$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{id:"pixel-overlay",tabIndex:0,onPointerDown:$handle_pointer_down_picker$jscomp$1_props_80874$$,onPointerUp:$handle_pointer_up_picker$jscomp$1$$,onPointerMove:$handle_pointer_move_picker$jscomp$1$$,onMouseEnter:$handle_mouse_enter$jscomp$1$$,className:""+($APP.$app$main$ui$css_cursors$get_static$$("picker")??
"")+" main_ui_workspace_viewport_pixel_overlay__pixel-overlay"})};
$app$main$ui$workspace$viewport$presence$active_cursors$$=function($props_80873_sessions$jscomp$1_sessions__$1$$){var $page_id$jscomp$449$$=$props_80873_sessions$jscomp$1_sessions__$1$$["page-id"],$counter$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$profiles$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$);$props_80873_sessions$jscomp$1_sessions__$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_presence$$);var $zoom$jscomp$136$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$);
$props_80873_sessions$jscomp$1_sessions__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80872_SHARP_$$){return 5E3>=$APP.$cljs$core$inst_ms_STAR_$$($APP.$app$common$time$now$$())-$APP.$cljs$core$inst_ms$$($APP.$cljs$cst$3410$updated_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__80872_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80871_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$449$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80871_SHARP_$$))},
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2163$point$$,$APP.$cljs$core$vals$$($props_80873_sessions$jscomp$1_sessions__$1$$))));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$(null,function(){var $sem$jscomp$10$$=$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($counter$jscomp$6$$,$APP.$cljs$core$inc$$)});return function(){return $APP.$beicon$v2$core$_dispose$$($sem$jscomp$10$$)}});
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$229$$,$session$jscomp$6$$){$out_arr__44124__auto__$jscomp$229$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$presence$session_cursor$$,{session:$session$jscomp$6$$,zoom:$zoom$jscomp$136$$,profile:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$6$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$6$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$6$$)??
"")));return $out_arr__44124__auto__$jscomp$229$$},[],$props_80873_sessions$jscomp$1_sessions__$1$$)};
$app$main$ui$workspace$viewport$selection$selection_rect$$=function($on_move_selected$jscomp$6_props_80886$$){var $rect$jscomp$49_x__$1$jscomp$31$$=$on_move_selected$jscomp$6_props_80886$$.rect,$zoom$jscomp$138$$=$on_move_selected$jscomp$6_props_80886$$.zoom,$transform$jscomp$118$$=$on_move_selected$jscomp$6_props_80886$$.transform,$color$jscomp$193$$=$on_move_selected$jscomp$6_props_80886$$.color,$on_context_menu$jscomp$23$$=$on_move_selected$jscomp$6_props_80886$$["on-context-menu"];$on_move_selected$jscomp$6_props_80886$$=
$on_move_selected$jscomp$6_props_80886$$["on-move-selected"];var $x$jscomp$1292$$=$rect$jscomp$49_x__$1$jscomp$31$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$516$$=$rect$jscomp$49_x__$1$jscomp$31$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$248$$=$rect$jscomp$49_x__$1$jscomp$31$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,
$APP.$cljs$cst$290$width$$),$height$jscomp$215$$=$rect$jscomp$49_x__$1$jscomp$31$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,$APP.$cljs$cst$1522$height$$),$vec__80887_vec__80890$$=$width$jscomp$248$$<10/$zoom$jscomp$138$$?function(){var $width_SINGLEQUOTE_$jscomp$2$$=10/$zoom$jscomp$138$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1292$$-($width_SINGLEQUOTE_$jscomp$2$$-$width$jscomp$248$$)/
2,$width_SINGLEQUOTE_$jscomp$2$$],null)}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1292$$,$width$jscomp$248$$],null);$rect$jscomp$49_x__$1$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80887_vec__80890$$,0,null);var $width__$1$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80887_vec__80890$$,1,null);$vec__80887_vec__80890$$=$height$jscomp$215$$<10/$zoom$jscomp$138$$?function(){var $height_SINGLEQUOTE_$jscomp$2$$=
10/$zoom$jscomp$138$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$y$jscomp$516$$-($height_SINGLEQUOTE_$jscomp$2$$-$height$jscomp$215$$)/2,$height_SINGLEQUOTE_$jscomp$2$$],null)}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$y$jscomp$516$$,$height$jscomp$215$$],null);var $y__$1$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80887_vec__80890$$,0,null),$height__$1$jscomp$8$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80887_vec__80890$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("rect",{width:function(){var $y__5111__auto__$jscomp$187$$=10/$zoom$jscomp$138$$;return $width__$1$jscomp$12$$>$y__5111__auto__$jscomp$187$$?$width__$1$jscomp$12$$:$y__5111__auto__$jscomp$187$$}(),height:function(){var $y__5111__auto__$jscomp$188$$=10/$zoom$jscomp$138$$;return $height__$1$jscomp$8$$>$y__5111__auto__$jscomp$188$$?$height__$1$jscomp$8$$:$y__5111__auto__$jscomp$188$$}(),
className:"main viewport-selrect",x:$rect$jscomp$49_x__$1$jscomp$31$$,transform:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($transform$jscomp$118$$),onContextMenu:$on_context_menu$jscomp$23$$,style:{stroke:$color$jscomp$193$$,strokeWidth:1/$zoom$jscomp$138$$,fill:"none"},y:$y__$1$jscomp$4$$,onPointerDown:$on_move_selected$jscomp$6_props_80886$$})};
$app$main$ui$workspace$viewport$selection$calculate_handlers$$=function($height$jscomp$216_selection$jscomp$17$$,$path_QMARK_$jscomp$8_shape$jscomp$1092$$,$small_width_QMARK__zoom$jscomp$139$$){var $JSCompiler_temp$jscomp$1498_x$jscomp$1293$$=$height$jscomp$216_selection$jscomp$17$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$216_selection$jscomp$17$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$517$$=$height$jscomp$216_selection$jscomp$17$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$216_selection$jscomp$17$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$249$$=$height$jscomp$216_selection$jscomp$17$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$216_selection$jscomp$17$$,$APP.$cljs$cst$290$width$$);$height$jscomp$216_selection$jscomp$17$$=$height$jscomp$216_selection$jscomp$17$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$216_selection$jscomp$17$$,$APP.$cljs$cst$1522$height$$);var $threshold_small$$=25/$small_width_QMARK__zoom$jscomp$139$$,$threshold_tiny_tiny_height_QMARK_$$=
10/$small_width_QMARK__zoom$jscomp$139$$;$small_width_QMARK__zoom$jscomp$139$$=$width$jscomp$249$$<=$threshold_small$$;var $tiny_width_QMARK_$$=$width$jscomp$249$$<=$threshold_tiny_tiny_height_QMARK_$$,$small_height_QMARK_$$=$height$jscomp$216_selection$jscomp$17$$<=$threshold_small$$;$threshold_tiny_tiny_height_QMARK_$$=$height$jscomp$216_selection$jscomp$17$$<=$threshold_tiny_tiny_height_QMARK_$$;var $vertical_line_QMARK_$jscomp$1$$=($path_QMARK_$jscomp$8_shape$jscomp$1092$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($path_QMARK_$jscomp$8_shape$jscomp$1092$$))&&
$tiny_width_QMARK_$$,$align$jscomp$6$$=$small_width_QMARK__zoom$jscomp$139$$||$small_height_QMARK_$$?$cljs$cst$5923$outside$$:$cljs$cst$5924$inside$$,$result$jscomp$382$$=[{type:$APP.$cljs$cst$1788$rotation$$,position:$APP.$cljs$cst$1883$top_left$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$,cy:$y$jscomp$517$$}},{type:$APP.$cljs$cst$1788$rotation$$,position:$APP.$cljs$cst$1884$top_right$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+$width$jscomp$249$$,cy:$y$jscomp$517$$}},{type:$APP.$cljs$cst$1788$rotation$$,
position:$APP.$cljs$cst$1885$bottom_right$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+$width$jscomp$249$$,cy:$y$jscomp$517$$+$height$jscomp$216_selection$jscomp$17$$}},{type:$APP.$cljs$cst$1788$rotation$$,position:$APP.$cljs$cst$1886$bottom_left$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$,cy:$y$jscomp$517$$+$height$jscomp$216_selection$jscomp$17$$}}];$path_QMARK_$jscomp$8_shape$jscomp$1092$$&&$threshold_tiny_tiny_height_QMARK_$$||$result$jscomp$382$$.push({type:$cljs$cst$5925$resize_side$$,
position:$APP.$cljs$cst$1562$top$$,props:{x:$small_width_QMARK__zoom$jscomp$139$$?$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+($width$jscomp$249$$-$threshold_small$$)/2:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$,y:$y$jscomp$517$$,length:$small_width_QMARK__zoom$jscomp$139$$?$threshold_small$$:$width$jscomp$249$$,angle:0,align:$align$jscomp$6$$,"show-handler":$tiny_width_QMARK_$$}},{type:$cljs$cst$5925$resize_side$$,position:$APP.$cljs$cst$1563$bottom$$,props:{x:$small_width_QMARK__zoom$jscomp$139$$?
$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+($width$jscomp$249$$+$threshold_small$$)/2:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+$width$jscomp$249$$,y:$y$jscomp$517$$+$height$jscomp$216_selection$jscomp$17$$,length:$small_width_QMARK__zoom$jscomp$139$$?$threshold_small$$:$width$jscomp$249$$,angle:180,align:$align$jscomp$6$$,"show-handler":$tiny_width_QMARK_$$}});$vertical_line_QMARK_$jscomp$1$$||$result$jscomp$382$$.push({type:$cljs$cst$5925$resize_side$$,position:$APP.$cljs$cst$258$right$$,props:{x:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+
$width$jscomp$249$$,y:$small_height_QMARK_$$?$y$jscomp$517$$+($height$jscomp$216_selection$jscomp$17$$-$threshold_small$$)/2:$y$jscomp$517$$,length:$small_height_QMARK_$$?$threshold_small$$:$height$jscomp$216_selection$jscomp$17$$,angle:90,align:$align$jscomp$6$$,"show-handler":$threshold_tiny_tiny_height_QMARK_$$}},{type:$cljs$cst$5925$resize_side$$,position:$APP.$cljs$cst$257$left$$,props:{x:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$,y:$small_height_QMARK_$$?$y$jscomp$517$$+($height$jscomp$216_selection$jscomp$17$$+
$threshold_small$$)/2:$y$jscomp$517$$+$height$jscomp$216_selection$jscomp$17$$,length:$small_height_QMARK_$$?$threshold_small$$:$height$jscomp$216_selection$jscomp$17$$,angle:270,align:$align$jscomp$6$$,"show-handler":$threshold_tiny_tiny_height_QMARK_$$}});$tiny_width_QMARK_$$||$threshold_tiny_tiny_height_QMARK_$$?$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$=null:($result$jscomp$382$$.push({type:$cljs$cst$5926$resize_point$$,position:$APP.$cljs$cst$1883$top_left$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$,
cy:$y$jscomp$517$$,align:$align$jscomp$6$$}},{type:$cljs$cst$5926$resize_point$$,position:$APP.$cljs$cst$1884$top_right$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+$width$jscomp$249$$,cy:$y$jscomp$517$$,align:$align$jscomp$6$$}},{type:$cljs$cst$5926$resize_point$$,position:$APP.$cljs$cst$1885$bottom_right$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$+$width$jscomp$249$$,cy:$y$jscomp$517$$+$height$jscomp$216_selection$jscomp$17$$,align:$align$jscomp$6$$}},{type:$cljs$cst$5926$resize_point$$,
position:$APP.$cljs$cst$1886$bottom_left$$,props:{cx:$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$,cy:$y$jscomp$517$$+$height$jscomp$216_selection$jscomp$17$$,align:$align$jscomp$6$$}}),$JSCompiler_temp$jscomp$1498_x$jscomp$1293$$=$result$jscomp$382$$);return $JSCompiler_temp$jscomp$1498_x$jscomp$1293$$};
$app$main$ui$workspace$viewport$selection$rotation_handler$$=function($props_80893_size$jscomp$159$$){var $on_rotate$$=$props_80893_size$jscomp$159$$["on-rotate"],$transform$jscomp$119$$=$props_80893_size$jscomp$159$$.transform,$rotation$jscomp$21$$=$props_80893_size$jscomp$159$$.rotation,$cx$jscomp$22_x$jscomp$1294$$=$props_80893_size$jscomp$159$$.cx,$cy$jscomp$23_y$jscomp$518$$=$props_80893_size$jscomp$159$$.cy,$position$jscomp$235$$=$props_80893_size$jscomp$159$$.position;$props_80893_size$jscomp$159$$=
20/$props_80893_size$jscomp$159$$.zoom;var $delta_x$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$235$$,$APP.$cljs$cst$1883$top_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$235$$,$APP.$cljs$cst$1886$bottom_left$$)?$props_80893_size$jscomp$159$$:0,$angle$jscomp$41_delta_y$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1883$top_left$$,$position$jscomp$235$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1884$top_right$$,
$position$jscomp$235$$)?$props_80893_size$jscomp$159$$:0;$cx$jscomp$22_x$jscomp$1294$$-=$delta_x$jscomp$7$$;$cy$jscomp$23_y$jscomp$518$$-=$angle$jscomp$41_delta_y$jscomp$5$$;$angle$jscomp$41_delta_y$jscomp$5$$=function(){var $G__80894__$1$$=$position$jscomp$235$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$235$$.$fqn$:null;switch($G__80894__$1$$){case "top-left":return 0;case "top-right":return 90;case "bottom-right":return 180;case "bottom-left":return 270;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80894__$1$$)].join(""));}}();return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$props_80893_size$jscomp$159$$,height:$props_80893_size$jscomp$159$$,className:$app$main$ui$css_cursors$get_dynamic$$("rotate",$rotation$jscomp$21$$+$angle$jscomp$41_delta_y$jscomp$5$$),x:$cx$jscomp$22_x$jscomp$1294$$,transform:""+($transform$jscomp$119$$??""),fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1299$handlers$$)?"blue":"none",strokeWidth:0,y:$cy$jscomp$23_y$jscomp$518$$,
onPointerDown:$on_rotate$$})};
$app$main$ui$workspace$viewport$selection$resize_point_handler$$=function($position$jscomp$236_props_80895$$){var $JSCompiler_temp$jscomp$1937_on_resize$jscomp$1$$=$position$jscomp$236_props_80895$$["on-resize"],$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$=$position$jscomp$236_props_80895$$.align,$offset_x$jscomp$inline_9328_zoom$jscomp$141$$=$position$jscomp$236_props_80895$$.zoom,$cx_SINGLEQUOTE___$1$jscomp$inline_9331_transform$jscomp$120$$=$position$jscomp$236_props_80895$$.transform,$rotation$jscomp$22$$=
$position$jscomp$236_props_80895$$.rotation,$cursor$jscomp$11_scale_text$jscomp$1$$=$position$jscomp$236_props_80895$$["scale-text"],$JSCompiler_temp_const$jscomp$1936_color$jscomp$194$$=$position$jscomp$236_props_80895$$.color,$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$=$position$jscomp$236_props_80895$$.cx,$cy$jscomp$24$$=$position$jscomp$236_props_80895$$.cy;$position$jscomp$236_props_80895$$=$position$jscomp$236_props_80895$$.position;$cursor$jscomp$11_scale_text$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$236_props_80895$$,$APP.$cljs$cst$1883$top_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$236_props_80895$$,$APP.$cljs$cst$1885$bottom_right$$)?$cursor$jscomp$11_scale_text$jscomp$1$$?$app$main$ui$css_cursors$get_dynamic$$("scale-nesw",$rotation$jscomp$22$$):$app$main$ui$css_cursors$get_dynamic$$("resize-nesw",$rotation$jscomp$22$$):$cursor$jscomp$11_scale_text$jscomp$1$$?$app$main$ui$css_cursors$get_dynamic$$("scale-nwse",
$rotation$jscomp$22$$):$app$main$ui$css_cursors$get_dynamic$$("resize-nwse",$rotation$jscomp$22$$);var $cy_SINGLEQUOTE__pt$jscomp$36$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$,$cy$jscomp$24$$),$cx_SINGLEQUOTE___$1$jscomp$inline_9331_transform$jscomp$120$$),$cx_SINGLEQUOTE__offset_y$jscomp$inline_9329$$=$cy_SINGLEQUOTE__pt$jscomp$36$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cy_SINGLEQUOTE__pt$jscomp$36$$,
$APP.$cljs$cst$1510$x$$);$cy_SINGLEQUOTE__pt$jscomp$36$$=$cy_SINGLEQUOTE__pt$jscomp$36$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cy_SINGLEQUOTE__pt$jscomp$36$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_temp_const$jscomp$1936_color$jscomp$194$$=(0,$APP.$rumext$v2$jsx$$)("circle",{r:4/$offset_x$jscomp$inline_9328_zoom$jscomp$141$$,style:{fillOpacity:"1",strokeWidth:"1px",vectorEffect:"non-scaling-stroke"},fill:"var(--app-white)",stroke:$JSCompiler_temp_const$jscomp$1936_color$jscomp$194$$,
cx:$cx_SINGLEQUOTE__offset_y$jscomp$inline_9329$$,cy:$cy_SINGLEQUOTE__pt$jscomp$36$$});$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$,$cljs$cst$5923$outside$$)?($align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$=10/$offset_x$jscomp$inline_9328_zoom$jscomp$141$$,$offset_x$jscomp$inline_9328_zoom$jscomp$141$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$236_props_80895$$,$APP.$cljs$cst$1884$top_right$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$236_props_80895$$,$APP.$cljs$cst$1885$bottom_right$$)?0:-$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$,$cx_SINGLEQUOTE__offset_y$jscomp$inline_9329$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$236_props_80895$$,$APP.$cljs$cst$1886$bottom_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$236_props_80895$$,$APP.$cljs$cst$1885$bottom_right$$)?0:-$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$,
$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$+$offset_x$jscomp$inline_9328_zoom$jscomp$141$$,$cy$jscomp$24$$+$cx_SINGLEQUOTE__offset_y$jscomp$inline_9329$$),$cx_SINGLEQUOTE___$1$jscomp$inline_9331_transform$jscomp$120$$),$cx_SINGLEQUOTE___$1$jscomp$inline_9331_transform$jscomp$120$$=
$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$,$APP.$cljs$cst$1510$x$$),$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$=$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$,
$APP.$cljs$cst$1511$y$$),$JSCompiler_temp$jscomp$1937_on_resize$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)("rect",{width:$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$,height:$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9327$$,className:$cursor$jscomp$11_scale_text$jscomp$1$$,x:$cx_SINGLEQUOTE___$1$jscomp$inline_9331_transform$jscomp$120$$,transform:$rotation$jscomp$22$$!=null?"rotate("+($rotation$jscomp$22$$??"")+", "+($cx_SINGLEQUOTE___$1$jscomp$inline_9331_transform$jscomp$120$$??
"")+", "+($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$??"")+")":null,style:{fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1299$handlers$$)?"red":"none",strokeWidth:0},"data-position":$APP.$cljs$core$name$$($position$jscomp$236_props_80895$$),y:$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9332_pt__$1$jscomp$inline_9330$$,onPointerDown:$JSCompiler_temp$jscomp$1937_on_resize$jscomp$1$$})):$JSCompiler_temp$jscomp$1937_on_resize$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)("circle",
{"data-x":$cx_SINGLEQUOTE__offset_y$jscomp$inline_9329$$,cy:$cy_SINGLEQUOTE__pt$jscomp$36$$,className:$cursor$jscomp$11_scale_text$jscomp$1$$,style:{fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1299$handlers$$)?"red":"none",strokeWidth:0},"data-position":$APP.$cljs$core$name$$($position$jscomp$236_props_80895$$),"data-y":$cy_SINGLEQUOTE__pt$jscomp$36$$,r:10/$offset_x$jscomp$inline_9328_zoom$jscomp$141$$,onPointerDown:$JSCompiler_temp$jscomp$1937_on_resize$jscomp$1$$,cx:$cx_SINGLEQUOTE__offset_y$jscomp$inline_9329$$});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"resize-handler",children:[$JSCompiler_temp_const$jscomp$1936_color$jscomp$194$$,$JSCompiler_temp$jscomp$1937_on_resize$jscomp$1$$]})};
$app$main$ui$workspace$viewport$selection$resize_side_handler$$=function($offset_y$jscomp$17_props_80898_target_y$$){var $x$jscomp$1295$$=$offset_y$jscomp$17_props_80898_target_y$$.x,$on_resize$jscomp$2$$=$offset_y$jscomp$17_props_80898_target_y$$["on-resize"],$y$jscomp$519$$=$offset_y$jscomp$17_props_80898_target_y$$.y,$zoom$jscomp$142$$=$offset_y$jscomp$17_props_80898_target_y$$.zoom,$shape_type$jscomp$9$$=$offset_y$jscomp$17_props_80898_target_y$$["shape-type"],$show_handler$$=$offset_y$jscomp$17_props_80898_target_y$$["show-handler"],
$transform$jscomp$121_transform_str$jscomp$1$$=$offset_y$jscomp$17_props_80898_target_y$$.transform,$cursor$jscomp$12_rotation$jscomp$23$$=$offset_y$jscomp$17_props_80898_target_y$$.rotation,$on_double_click$jscomp$6_scale_text$jscomp$2$$=$offset_y$jscomp$17_props_80898_target_y$$["scale-text"],$color$jscomp$195$$=$offset_y$jscomp$17_props_80898_target_y$$.color,$angle$jscomp$42$$=$offset_y$jscomp$17_props_80898_target_y$$.angle,$shape_id$jscomp$178$$=$offset_y$jscomp$17_props_80898_target_y$$["shape-id"],
$length$jscomp$61$$=$offset_y$jscomp$17_props_80898_target_y$$.length,$position$jscomp$237$$=$offset_y$jscomp$17_props_80898_target_y$$.position,$height$jscomp$217$$=8/$zoom$jscomp$142$$;$offset_y$jscomp$17_props_80898_target_y$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset_y$jscomp$17_props_80898_target_y$$.align,$cljs$cst$5923$outside$$)?-$height$jscomp$217$$:-($height$jscomp$217$$/2);$offset_y$jscomp$17_props_80898_target_y$$=$y$jscomp$519$$+$offset_y$jscomp$17_props_80898_target_y$$;
$transform$jscomp$121_transform_str$jscomp$1$$=""+($APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$121_transform_str$jscomp$1$$,$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$42$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1295$$,$y$jscomp$519$$)))??"");$cursor$jscomp$12_rotation$jscomp$23$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$237$$,$APP.$cljs$cst$257$left$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$237$$,$APP.$cljs$cst$258$right$$)?$on_double_click$jscomp$6_scale_text$jscomp$2$$?$app$main$ui$css_cursors$get_dynamic$$("scale-ew",$cursor$jscomp$12_rotation$jscomp$23$$):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",$cursor$jscomp$12_rotation$jscomp$23$$):$on_double_click$jscomp$6_scale_text$jscomp$2$$?$app$main$ui$css_cursors$get_dynamic$$("scale-ns",$cursor$jscomp$12_rotation$jscomp$23$$):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",
$cursor$jscomp$12_rotation$jscomp$23$$);$on_double_click$jscomp$6_scale_text$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$178$$),$APP.$rumext$v2$adapt$$($position$jscomp$237$$),$APP.$rumext$v2$adapt$$($shape_type$jscomp$9$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$9$$,$APP.$cljs$cst$1588$text$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$237$$,$APP.$cljs$cst$258$right$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$178$$],null),function($p1__80896_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80896_SHARP_$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$2036$auto_width$$)})):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$237$$,
$APP.$cljs$cst$1563$bottom$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$178$$],null),function($p1__80897_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80897_SHARP_$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$2035$auto_height$$)})):null:null});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"resize-handler",children:[$show_handler$$?(0,$APP.$rumext$v2$jsx$$)("circle",{r:4/$zoom$jscomp$142$$,style:{fillOpacity:1,stroke:$color$jscomp$195$$,strokeWidth:"1px",fill:"var(--app-white)",vectorEffect:"non-scaling-stroke"},"data-position":$APP.$cljs$core$name$$($position$jscomp$237$$),cx:$x$jscomp$1295$$+$length$jscomp$61$$/2,cy:$y$jscomp$519$$,transform:$transform$jscomp$121_transform_str$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{onDoubleClick:$on_double_click$jscomp$6_scale_text$jscomp$2$$,
width:$length$jscomp$61$$,height:$height$jscomp$217$$,className:$cursor$jscomp$12_rotation$jscomp$23$$,x:$x$jscomp$1295$$,transform:$transform$jscomp$121_transform_str$jscomp$1$$,style:{fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1299$handlers$$)?"yellow":"none",strokeWidth:0},"data-position":$APP.$cljs$core$name$$($position$jscomp$237$$),y:$offset_y$jscomp$17_props_80898_target_y$$,onPointerDown:$on_resize$jscomp$2$$})]})};
$app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$=function($props_80899_transform_type$$){var $zoom$jscomp$143$$=$props_80899_transform_type$$.zoom,$color$jscomp$196$$=$props_80899_transform_type$$.color,$disabled$jscomp$20$$=$props_80899_transform_type$$.disabled,$on_context_menu$jscomp$24$$=$props_80899_transform_type$$.onContextMenu,$on_move_selected$jscomp$7$$=$props_80899_transform_type$$.onMoveSelected,$selrect$jscomp$88_shape$jscomp$1093$$=$props_80899_transform_type$$.shape,
$selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);$props_80899_transform_type$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$current_transform$$);$selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$=$app$main$data$helpers$get_selrect$$($selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$,$selrect$jscomp$88_shape$jscomp$1093$$);$selrect$jscomp$88_shape$jscomp$1093$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$,
0,null);$selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$,1,null);return $selrect$jscomp$88_shape$jscomp$1093$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_80899_transform_type$$,$APP.$cljs$cst$1798$move$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_80899_transform_type$$,$APP.$cljs$cst$2863$rotate$$)?null:(0,$APP.$rumext$v2$jsx$$)("g",
{className:"controls",pointerEvents:$disabled$jscomp$20$$?"none":"visible",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$selection_rect$$,{rect:$selrect$jscomp$88_shape$jscomp$1093$$,transform:$selrect_transform$jscomp$4_transform$jscomp$122_vec__80900$$,zoom:$zoom$jscomp$143$$,color:$color$jscomp$196$$,"on-move-selected":$on_move_selected$jscomp$7$$,"on-context-menu":$on_context_menu$jscomp$24$$})})};
$app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$=function($props_80903_transform_type$jscomp$1$$){var $on_resize$jscomp$3$$=$props_80903_transform_type$jscomp$1$$.onResize,$on_rotate$jscomp$1$$=$props_80903_transform_type$jscomp$1$$.onRotate,$zoom$jscomp$144$$=$props_80903_transform_type$jscomp$1$$.zoom,$color$jscomp$197$$=$props_80903_transform_type$jscomp$1$$.color,$disabled$jscomp$21$$=$props_80903_transform_type$jscomp$1$$.disabled,$shape$jscomp$1094$$=$props_80903_transform_type$jscomp$1$$.shape,
$selrect_transform$jscomp$5_vec__80904$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);$props_80903_transform_type$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$current_transform$$);var $read_only_QMARK_$jscomp$35$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$layout$jscomp$27_selrect$jscomp$89$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_layout$$),$scale_text_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$27_selrect$jscomp$89$$,
$APP.$cljs$cst$3716$scale_text$$);$selrect_transform$jscomp$5_vec__80904$$=$app$main$data$helpers$get_selrect$$($selrect_transform$jscomp$5_vec__80904$$,$shape$jscomp$1094$$);$layout$jscomp$27_selrect$jscomp$89$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$5_vec__80904$$,0,null);var $transform$jscomp$123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$5_vec__80904$$,1,null),$rotation$jscomp$24$$=$APP.$cljs$core$mod$$($APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,
0),$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1094$$))),360),$flip_x$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1094$$,$APP.$cljs$cst$1879$flip_x$$),$flip_y$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1094$$,$APP.$cljs$cst$1880$flip_y$$),$half_flip_QMARK_$$=function(){var $or__5025__auto__$jscomp$1349$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$10$$)?$APP.$cljs$core$not$$($flip_y$jscomp$10$$):
$flip_x$jscomp$10$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1349$$)?$or__5025__auto__$jscomp$1349$$:$APP.$cljs$core$truth_$$($flip_y$jscomp$10$$)?$APP.$cljs$core$not$$($flip_x$jscomp$10$$):$flip_y$jscomp$10$$}();return $read_only_QMARK_$jscomp$35$$||!$APP.$cljs$core$not$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1094$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_80903_transform_type$jscomp$1$$,$APP.$cljs$cst$1798$move$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_80903_transform_type$jscomp$1$$,
$APP.$cljs$cst$2863$rotate$$)?null:(0,$APP.$rumext$v2$jsx$$)("g",{className:"controls",pointerEvents:$disabled$jscomp$21$$?"none":"visible",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$230$$,$handler$jscomp$50$$){$out_arr__44124__auto__$jscomp$230$$.push(function(){var $G__80907__$1_type$jscomp$720$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handler$jscomp$50$$,"type"),$position$jscomp$238_props__$1$jscomp$105$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handler$jscomp$50$$,"position"),$props$jscomp$425$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handler$jscomp$50$$,"props"),$rotation__$1$jscomp$1$$=$half_flip_QMARK_$$&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$238_props__$1$jscomp$105$$,$APP.$cljs$cst$1883$top_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$238_props__$1$jscomp$105$$,$APP.$cljs$cst$1885$bottom_right$$))?
$rotation$jscomp$24$$-90:$half_flip_QMARK_$$&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$238_props__$1$jscomp$105$$,$APP.$cljs$cst$1884$top_right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$238_props__$1$jscomp$105$$,$APP.$cljs$cst$1886$bottom_left$$))?$rotation$jscomp$24$$+90:$rotation$jscomp$24$$;$position$jscomp$238_props__$1$jscomp$105$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({zoom:$zoom$jscomp$144$$,"shape-type":$shape$jscomp$1094$$?.type??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1094$$,$APP.$cljs$cst$139$type$$),transform:$transform$jscomp$123$$,rotation:$rotation__$1$jscomp$1$$,"scale-text":$scale_text_QMARK_$$,color:$color$jscomp$197$$,key:""+($APP.$cljs$core$name$$($G__80907__$1_type$jscomp$720$$)??"")+"-"+($APP.$cljs$core$name$$($position$jscomp$238_props__$1$jscomp$105$$)??""),"shape-id":$shape$jscomp$1094$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1094$$,$APP.$cljs$cst$266$id$$),
position:$position$jscomp$238_props__$1$jscomp$105$$,"on-resize":$on_resize$jscomp$3$$,"on-rotate":$on_rotate$jscomp$1$$},$props$jscomp$425$$);$G__80907__$1_type$jscomp$720$$=$G__80907__$1_type$jscomp$720$$ instanceof $APP.$cljs$core$Keyword$$?$G__80907__$1_type$jscomp$720$$.$fqn$:null;switch($G__80907__$1_type$jscomp$720$$){case "rotation":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$selection$rotation_handler$$,$position$jscomp$238_props__$1$jscomp$105$$);case "resize-point":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$selection$resize_point_handler$$,
$position$jscomp$238_props__$1$jscomp$105$$);case "resize-side":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$selection$resize_side_handler$$,$position$jscomp$238_props__$1$jscomp$105$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80907__$1_type$jscomp$720$$)].join(""));}}());return $out_arr__44124__auto__$jscomp$230$$},[],$app$main$ui$workspace$viewport$selection$calculate_handlers$$($layout$jscomp$27_selrect$jscomp$89$$,
$shape$jscomp$1094$$,$zoom$jscomp$144$$))})};
$app$main$ui$workspace$viewport$selection$text_edition_selection$$=function($props_80908_shape$jscomp$1095$$){var $zoom$jscomp$145$$=$props_80908_shape$jscomp$1095$$.zoom,$color$jscomp$198$$=$props_80908_shape$jscomp$1095$$.color;$props_80908_shape$jscomp$1095$$=$props_80908_shape$jscomp$1095$$.shape;var $x$jscomp$1296$$=$props_80908_shape$jscomp$1095$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80908_shape$jscomp$1095$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$520$$=$props_80908_shape$jscomp$1095$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80908_shape$jscomp$1095$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$250$$=$props_80908_shape$jscomp$1095$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80908_shape$jscomp$1095$$,$APP.$cljs$cst$290$width$$),$height$jscomp$218$$=$props_80908_shape$jscomp$1095$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80908_shape$jscomp$1095$$,$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("g",
{className:"controls",children:(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main",x:$x$jscomp$1296$$,y:$y$jscomp$520$$,transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($props_80908_shape$jscomp$1095$$),width:$width$jscomp$250$$,height:$height$jscomp$218$$,pointerEvents:"visible",style:{stroke:$color$jscomp$198$$,strokeWidth:.5/$zoom$jscomp$145$$,strokeOpacity:1,fill:"none"}})})};
$app$main$ui$workspace$viewport$selection$multiple_handlers_STAR_$$=function($disabled$jscomp$22_props_80909$$){var $shapes$jscomp$231$$=$disabled$jscomp$22_props_80909$$.shapes,$zoom$jscomp$146$$=$disabled$jscomp$22_props_80909$$.zoom,$selected$jscomp$202$$=$disabled$jscomp$22_props_80909$$.selected,$color$jscomp$199$$=$disabled$jscomp$22_props_80909$$.color;$disabled$jscomp$22_props_80909$$=$disabled$jscomp$22_props_80909$$.disabled;var $shape$jscomp$1096$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$231$$)],
function(){return $APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$231$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1616$multiple$$))}),$on_resize$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$202$$),$APP.$rumext$v2$adapt$$($shape$jscomp$1096$$)],function($event$jscomp$713_position$jscomp$239$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$713_position$jscomp$239$$)?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$713_position$jscomp$239$$),$event$jscomp$713_position$jscomp$239$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$713_position$jscomp$239$$),"position")),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$start_resize$$($event$jscomp$713_position$jscomp$239$$,$selected$jscomp$202$$,$shape$jscomp$1096$$))):
null}),$on_rotate$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$231$$)],function($event$jscomp$714$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$714$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$714$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$start_rotate$$($shapes$jscomp$231$$))):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$,
{shape:$shape$jscomp$1096$$,zoom:$zoom$jscomp$146$$,color:$color$jscomp$199$$,disabled:$disabled$jscomp$22_props_80909$$,onResize:$on_resize$jscomp$4$$,onRotate:$on_rotate$jscomp$2$$})};
$app$main$ui$workspace$viewport$selection$multiple_selection_STAR_$$=function($on_move_selected$jscomp$8_props_80910$$){var $shapes$jscomp$232$$=$on_move_selected$jscomp$8_props_80910$$.shapes,$zoom$jscomp$147$$=$on_move_selected$jscomp$8_props_80910$$.zoom,$color$jscomp$200$$=$on_move_selected$jscomp$8_props_80910$$.color,$disabled$jscomp$23$$=$on_move_selected$jscomp$8_props_80910$$.disabled,$on_context_menu$jscomp$25$$=$on_move_selected$jscomp$8_props_80910$$.onContextMenu;$on_move_selected$jscomp$8_props_80910$$=
$on_move_selected$jscomp$8_props_80910$$.onMoveSelected;var $shape$jscomp$1097$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$232$$)],function(){return $APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$232$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1616$multiple$$))});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$,
{shape:$shape$jscomp$1097$$,zoom:$zoom$jscomp$147$$,color:$color$jscomp$200$$,disabled:$disabled$jscomp$23$$,onMoveSelected:$on_move_selected$jscomp$8_props_80910$$,onContextMenu:$on_context_menu$jscomp$25$$})};
$app$main$ui$workspace$viewport$selection$single_handlers_STAR_$$=function($on_resize$jscomp$5_props_80914$$){var $zoom$jscomp$148$$=$on_resize$jscomp$5_props_80914$$.zoom,$color$jscomp$201$$=$on_resize$jscomp$5_props_80914$$.color,$disabled$jscomp$24$$=$on_resize$jscomp$5_props_80914$$.disabled,$shape$jscomp$1098$$=$on_resize$jscomp$5_props_80914$$.shape,$shape_id$jscomp$179$$=$shape$jscomp$1098$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1098$$,$APP.$cljs$cst$266$id$$),
$grow_type$jscomp$12$$=$shape$jscomp$1098$$?.$grow_type$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1098$$,$APP.$cljs$cst$1770$grow_type$$),$shape_type$jscomp$10$$=$shape$jscomp$1098$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1098$$,$APP.$cljs$cst$139$type$$);$on_resize$jscomp$5_props_80914$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$179$$),$APP.$rumext$v2$adapt$$($shape$jscomp$1098$$),
$APP.$rumext$v2$adapt$$($grow_type$jscomp$12$$),$APP.$rumext$v2$adapt$$($shape_type$jscomp$10$$)],function($event$jscomp$715_position$jscomp$240$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$715_position$jscomp$240$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$715_position$jscomp$240$$),$event$jscomp$715_position$jscomp$240$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$715_position$jscomp$240$$),
"position")),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$10$$,$APP.$cljs$cst$1588$text$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$12$$,$APP.$cljs$cst$2036$auto_width$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$715_position$jscomp$240$$,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$715_position$jscomp$240$$,$APP.$cljs$cst$257$left$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$179$$],null),function($p1__80911_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80911_SHARP_$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$2035$auto_height$$),$cljs$cst$5927$last_resize_direction$$,$APP.$cljs$cst$1909$horizontal$$)})):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$10$$,$APP.$cljs$cst$1588$text$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$12$$,$APP.$cljs$cst$2035$auto_height$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$715_position$jscomp$240$$,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$715_position$jscomp$240$$,$APP.$cljs$cst$257$left$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$179$$],null),function($p1__80912_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80912_SHARP_$$,$cljs$cst$5927$last_resize_direction$$,$APP.$cljs$cst$1909$horizontal$$)})):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$10$$,$APP.$cljs$cst$1588$text$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$12$$,$APP.$cljs$cst$2035$auto_height$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$715_position$jscomp$240$$,
$APP.$cljs$cst$1562$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$715_position$jscomp$240$$,$APP.$cljs$cst$1563$bottom$$))&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$179$$],null),function($p1__80913_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80913_SHARP_$$,
$cljs$cst$5927$last_resize_direction$$,$APP.$cljs$cst$1910$vertical$$)})),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$start_resize$$($event$jscomp$715_position$jscomp$240$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_id$jscomp$179$$]),$shape$jscomp$1098$$))):null});var $on_rotate$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1098$$)],function($event$jscomp$716$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$716$$)?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$716$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$start_rotate$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1098$$],null)))):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$,{shape:$shape$jscomp$1098$$,zoom:$zoom$jscomp$148$$,color:$color$jscomp$201$$,disabled:$disabled$jscomp$24$$,
onRotate:$on_rotate$jscomp$3$$,onResize:$on_resize$jscomp$5_props_80914$$})};$app$main$ui$workspace$viewport$selection$single_selection_STAR_$$=function($props_80915$$){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$,{shape:$props_80915$$.shape,zoom:$props_80915$$.zoom,color:$props_80915$$.color,disabled:$props_80915$$.disabled,onMoveSelected:$props_80915$$.onMoveSelected,onContextMenu:$props_80915$$.onContextMenu})};
$app$main$ui$workspace$viewport$selection$area_STAR_$$=function($on_move_selected$jscomp$10_props_80916$$){var $edition$jscomp$16$$=$on_move_selected$jscomp$10_props_80916$$.edition,$shapes$jscomp$233$$=$on_move_selected$jscomp$10_props_80916$$.shapes,$zoom$jscomp$150$$=$on_move_selected$jscomp$10_props_80916$$.zoom,$disabled$jscomp$26$$=$on_move_selected$jscomp$10_props_80916$$.disabled,$on_context_menu$jscomp$27$$=$on_move_selected$jscomp$10_props_80916$$.onContextMenu;$on_move_selected$jscomp$10_props_80916$$=
$on_move_selected$jscomp$10_props_80916$$.onMoveSelected;var $total$jscomp$22$$=$APP.$cljs$core$count$$($shapes$jscomp$233$$),$shape$jscomp$1100$$=$APP.$cljs$core$first$$($shapes$jscomp$233$$),$shape_id$jscomp$180$$=$shape$jscomp$1100$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1100$$,$APP.$cljs$cst$266$id$$),$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);
var $and__5023__auto__$jscomp$inline_9334$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total$jscomp$22$$,1);$and__5023__auto__$jscomp$inline_9334$$?($JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$,$shape$jscomp$1100$$),$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$)?$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1100$$)):$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$=$and__5023__auto__$jscomp$inline_9334$$;$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$)?"var(--assets-component-hightlight)":"var(--color-accent-tertiary)";return $total$jscomp$22$$>1?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$multiple_selection_STAR_$$,{shapes:$shapes$jscomp$233$$,zoom:$zoom$jscomp$150$$,color:$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$,disabled:$disabled$jscomp$26$$,
onMoveSelected:$on_move_selected$jscomp$10_props_80916$$,onContextMenu:$on_context_menu$jscomp$27$$}):$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1100$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$16$$,$shape_id$jscomp$180$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$text_edition_selection$$,{shape:$shape$jscomp$1100$$,zoom:$zoom$jscomp$150$$,color:$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$}):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$16$$,$shape_id$jscomp$180$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$single_selection_STAR_$$,{shape:$shape$jscomp$1100$$,zoom:$zoom$jscomp$150$$,color:$JSCompiler_inline_result$jscomp$1938_color$jscomp$203_objects$jscomp$825_or__5025__auto__$jscomp$inline_9335$$,disabled:$disabled$jscomp$26$$,onMoveSelected:$on_move_selected$jscomp$10_props_80916$$,onContextMenu:$on_context_menu$jscomp$27$$})};
$app$main$ui$workspace$viewport$selection$handlers_STAR_$$=function($disabled$jscomp$27_props_80917$$){var $shapes$jscomp$234$$=$disabled$jscomp$27_props_80917$$.shapes,$zoom$jscomp$151$$=$disabled$jscomp$27_props_80917$$.zoom,$selected$jscomp$203$$=$disabled$jscomp$27_props_80917$$.selected;$disabled$jscomp$27_props_80917$$=$disabled$jscomp$27_props_80917$$.disabled;var $total$jscomp$23$$=$APP.$cljs$core$count$$($shapes$jscomp$234$$),$shape$jscomp$1101$$=$APP.$cljs$core$first$$($shapes$jscomp$234$$),
$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);var $and__5023__auto__$jscomp$inline_9337$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total$jscomp$23$$,1);$and__5023__auto__$jscomp$inline_9337$$?($JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$,
$shape$jscomp$1101$$),$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$)?$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1101$$)):$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$=
$and__5023__auto__$jscomp$inline_9337$$;$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$)?"var(--assets-component-hightlight)":"var(--color-accent-tertiary)";return $total$jscomp$23$$>1?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$multiple_handlers_STAR_$$,{shapes:$shapes$jscomp$234$$,
selected:$selected$jscomp$203$$,zoom:$zoom$jscomp$151$$,color:$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$,disabled:$disabled$jscomp$27_props_80917$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$single_handlers_STAR_$$,{shape:$shape$jscomp$1101$$,zoom:$zoom$jscomp$151$$,color:$JSCompiler_inline_result$jscomp$1939_color$jscomp$204_objects$jscomp$826_or__5025__auto__$jscomp$inline_9338$$,disabled:$disabled$jscomp$27_props_80917$$})};
$app$main$ui$workspace$viewport$snap_distances$half_point$$=function($c2$jscomp$28_coord$jscomp$19$$,$sr1$jscomp$2$$,$sr2$jscomp$2$$){var $c1$jscomp$39$$=Math.max($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1524$y1$$:$APP.$cljs$cst$1523$x1$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr2$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,
$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1524$y1$$:$APP.$cljs$cst$1523$x1$$));$c2$jscomp$28_coord$jscomp$19$$=Math.min($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1526$y2$$:$APP.$cljs$cst$1525$x2$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr2$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,
$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1526$y2$$:$APP.$cljs$cst$1525$x2$$));return $c1$jscomp$39$$+($c2$jscomp$28_coord$jscomp$19$$-$c1$jscomp$39$$)/2};
$app$main$ui$workspace$viewport$snap_distances$shape_distance_segment_STAR_$$=function($props_80919_sr2$jscomp$3$$){var $sr1$jscomp$3$$=$props_80919_sr2$jscomp$3$$.sr1,$coord$jscomp$20$$=$props_80919_sr2$jscomp$3$$.coord,$zoom$jscomp$152$$=$props_80919_sr2$jscomp$3$$.zoom;$props_80919_sr2$jscomp$3$$=$props_80919_sr2$jscomp$3$$.sr2;var $from_c$$=Math.min($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,
$coord$jscomp$20$$)?$APP.$cljs$cst$1525$x2$$:$APP.$cljs$cst$1526$y2$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80919_sr2$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$APP.$cljs$cst$1525$x2$$:$APP.$cljs$cst$1526$y2$$)),$to_c$$=Math.max($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$APP.$cljs$cst$1523$x1$$:
$APP.$cljs$cst$1524$y1$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80919_sr2$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$APP.$cljs$cst$1523$x1$$:$APP.$cljs$cst$1524$y1$$)),$distance$jscomp$10$$=$to_c$$-$from_c$$,$distance_str$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($distance$jscomp$10$$),$half_point$$=$app$main$ui$workspace$viewport$snap_distances$half_point$$($coord$jscomp$20$$,
$sr1$jscomp$3$$,$props_80919_sr2$jscomp$3$$),$width$jscomp$251$$=$APP.$cljs$core$count$$($distance_str$$)*(6/$zoom$jscomp$152$$)+6/$zoom$jscomp$152$$+6/$zoom$jscomp$152$$*2;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"distance-segment",children:[function(){var $point$jscomp$90_x$jscomp$1297$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_c$$+$distance$jscomp$10$$/2,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,
$APP.$cljs$cst$1510$x$$)?$half_point$$-10/$zoom$jscomp$152$$:$half_point$$+5/$zoom$jscomp$152$$],null),$vec__80920_y$jscomp$521$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$point$jscomp$90_x$jscomp$1297$$:$APP.$cljs$core$reverse$$($point$jscomp$90_x$jscomp$1297$$);$point$jscomp$90_x$jscomp$1297$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80920_y$jscomp$521$$,0,null);$vec__80920_y$jscomp$521$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80920_y$jscomp$521$$,
1,null);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1510$x$$)?$point$jscomp$90_x$jscomp$1297$$-$width$jscomp$251$$/2:$point$jscomp$90_x$jscomp$1297$$,y:$vec__80920_y$jscomp$521$$-20/$zoom$jscomp$152$$/2-($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1510$x$$)?2/$zoom$jscomp$152$$:0),width:$width$jscomp$251$$,
height:20/$zoom$jscomp$152$$,rx:4/$zoom$jscomp$152$$,fill:"var(--color-accent-quaternary)"}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1510$x$$)?$point$jscomp$90_x$jscomp$1297$$:$point$jscomp$90_x$jscomp$1297$$+$width$jscomp$251$$/2,y:$vec__80920_y$jscomp$521$$+20/$zoom$jscomp$152$$/2+-(6/$zoom$jscomp$152$$)-($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1510$x$$)?2/$zoom$jscomp$152$$:
0),fontSize:12/$zoom$jscomp$152$$,fill:"var(--app-white)",textAnchor:"middle",children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($distance$jscomp$10$$)})]})}(),function(){var $p1$jscomp$87_x1$jscomp$48$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_c$$+2/$zoom$jscomp$152$$,$half_point$$+5/$zoom$jscomp$152$$],null),$p2$jscomp$68_x2$jscomp$45$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$from_c$$+2/$zoom$jscomp$152$$,$half_point$$-5/$zoom$jscomp$152$$],null),$vec__80924_y1$jscomp$50$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$p1$jscomp$87_x1$jscomp$48$$:$APP.$cljs$core$reverse$$($p1$jscomp$87_x1$jscomp$48$$);$p1$jscomp$87_x1$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80924_y1$jscomp$50$$,0,null);$vec__80924_y1$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80924_y1$jscomp$50$$,
1,null);var $vec__80927_y2$jscomp$47$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$p2$jscomp$68_x2$jscomp$45$$:$APP.$cljs$core$reverse$$($p2$jscomp$68_x2$jscomp$45$$);$p2$jscomp$68_x2$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80927_y2$jscomp$47$$,0,null);$vec__80927_y2$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80927_y2$jscomp$47$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("line",
{x1:$p1$jscomp$87_x1$jscomp$48$$,y1:$vec__80924_y1$jscomp$50$$,x2:$p2$jscomp$68_x2$jscomp$45$$,y2:$vec__80927_y2$jscomp$47$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$152$$)}})}(),function(){var $p1$jscomp$88_x1$jscomp$49$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_c$$-2/$zoom$jscomp$152$$,$half_point$$+5/$zoom$jscomp$152$$],null),$p2$jscomp$69_x2$jscomp$46$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_c$$-2/$zoom$jscomp$152$$,$half_point$$-5/$zoom$jscomp$152$$],null),$vec__80930_y1$jscomp$51$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$p1$jscomp$88_x1$jscomp$49$$:$APP.$cljs$core$reverse$$($p1$jscomp$88_x1$jscomp$49$$);$p1$jscomp$88_x1$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80930_y1$jscomp$51$$,0,null);$vec__80930_y1$jscomp$51$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80930_y1$jscomp$51$$,1,null);var $vec__80933_y2$jscomp$48$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$p2$jscomp$69_x2$jscomp$46$$:$APP.$cljs$core$reverse$$($p2$jscomp$69_x2$jscomp$46$$);$p2$jscomp$69_x2$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80933_y2$jscomp$48$$,0,null);$vec__80933_y2$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80933_y2$jscomp$48$$,
1,null);return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$p1$jscomp$88_x1$jscomp$49$$,y1:$vec__80930_y1$jscomp$51$$,x2:$p2$jscomp$69_x2$jscomp$46$$,y2:$vec__80933_y2$jscomp$48$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$152$$)}})}(),function(){var $p1$jscomp$89_x1$jscomp$50$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_c$$+2/$zoom$jscomp$152$$,$half_point$$],null),
$p2$jscomp$70_x2$jscomp$47$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_c$$-2/$zoom$jscomp$152$$,$half_point$$],null),$vec__80936_y1$jscomp$52$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$p1$jscomp$89_x1$jscomp$50$$:$APP.$cljs$core$reverse$$($p1$jscomp$89_x1$jscomp$50$$);$p1$jscomp$89_x1$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80936_y1$jscomp$52$$,0,null);
$vec__80936_y1$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80936_y1$jscomp$52$$,1,null);var $vec__80939_y2$jscomp$49$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$coord$jscomp$20$$)?$p2$jscomp$70_x2$jscomp$47$$:$APP.$cljs$core$reverse$$($p2$jscomp$70_x2$jscomp$47$$);$p2$jscomp$70_x2$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80939_y2$jscomp$49$$,0,null);$vec__80939_y2$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80939_y2$jscomp$49$$,
1,null);return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$p1$jscomp$89_x1$jscomp$50$$,y1:$vec__80936_y1$jscomp$52$$,x2:$p2$jscomp$70_x2$jscomp$47$$,y2:$vec__80939_y2$jscomp$49$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$152$$)}})}()]})};
$app$main$ui$workspace$viewport$snap_distances$calculate_segments$$=function($coord$jscomp$23$$,$selrect$jscomp$91$$,$lt_shapes_selection_segments$$,$gt_shapes$$){function $show_distance_QMARK_$$($p1__80950_SHARP_$$){return $check_in_set$$($p1__80950_SHARP_$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$min_distance$$]))}function $show_candidate_QMARK_$$($p1__80947_SHARP_$$){return $check_in_set$$($p1__80947_SHARP_$$,$distances$jscomp$1$$)}function $check_in_set$$($value$jscomp$1004$$,
$number_set$jscomp$1$$){return $APP.$cljs$core$some$$(function($p1__80946_SHARP_$$){return $APP.$app$common$math$abs$$($value$jscomp$1004$$-$p1__80946_SHARP_$$)<=1.5},$number_set$jscomp$1$$)}function $get_shapes_match$$($pred_QMARK_$jscomp$5$$,$shapes$jscomp$235$$){return $APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($pred_QMARK_$jscomp$5$$,$APP.$cljs$core$first$$),$APP.$app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__80942_SHARP_$$,$p2__80943_SHARP_$$){var $dist$jscomp$inline_9347_sr1$jscomp$inline_9343$$=
$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p1__80942_SHARP_$$),$sr2$jscomp$inline_9344$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p2__80943_SHARP_$$),$c1$jscomp$inline_9345$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1523$x1$$:$APP.$cljs$cst$1524$y1$$,$c2$jscomp$inline_9346$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1525$x2$$:
$APP.$cljs$cst$1526$y2$$;$dist$jscomp$inline_9347_sr1$jscomp$inline_9343$$=$c1$jscomp$inline_9345$$.$cljs$core$IFn$_invoke$arity$1$($sr2$jscomp$inline_9344$$)-$c2$jscomp$inline_9346$$.$cljs$core$IFn$_invoke$arity$1$($dist$jscomp$inline_9347_sr1$jscomp$inline_9343$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dist$jscomp$inline_9347_sr1$jscomp$inline_9343$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p1__80942_SHARP_$$,$p2__80943_SHARP_$$],null)],null)},function($p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$,$p2__80945_SHARP__s1c1$jscomp$inline_9356$$){var $s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$);$p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p2__80945_SHARP__s1c1$jscomp$inline_9356$$);
var $c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1524$y1$$:$APP.$cljs$cst$1523$x1$$,$c2$jscomp$inline_9355$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1526$y2$$:$APP.$cljs$cst$1525$x2$$;$p2__80945_SHARP__s1c1$jscomp$inline_9356$$=$c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$.$cljs$core$IFn$_invoke$arity$1$($s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$);
$s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$=$c2$jscomp$inline_9355$$.$cljs$core$IFn$_invoke$arity$1$($s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$);$c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$=$c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$.$cljs$core$IFn$_invoke$arity$1$($p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$);$p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$=$c2$jscomp$inline_9355$$.$cljs$core$IFn$_invoke$arity$1$($p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$);
return $c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$>=$p2__80945_SHARP__s1c1$jscomp$inline_9356$$&&$c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$<=$s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$||$p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$>=$p2__80945_SHARP__s1c1$jscomp$inline_9356$$&&$p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$<=$s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$||$p2__80945_SHARP__s1c1$jscomp$inline_9356$$>=$c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$&&
$p2__80945_SHARP__s1c1$jscomp$inline_9356$$<=$p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$||$s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$>=$c1$jscomp$inline_9354_s2c1$jscomp$inline_9358$$&&$s1c2$jscomp$inline_9357_sr1$jscomp$inline_9352$$<=$p1__80944_SHARP__s2c2$jscomp$inline_9359_sr2$jscomp$inline_9353$$},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1605$selrect$$),$shapes$jscomp$235$$)))}
function $distance_to_selrect$$($G__80955_shape$jscomp$1102_sr$jscomp$5$$){$G__80955_shape$jscomp$1102_sr$jscomp$5$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__80955_shape$jscomp$1102_sr$jscomp$5$$);$G__80955_shape$jscomp$1102_sr$jscomp$5$$=($coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($G__80955_shape$jscomp$1102_sr$jscomp$5$$):$coord$jscomp$23$$($G__80955_shape$jscomp$1102_sr$jscomp$5$$))<=($coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?
$coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$91$$):$coord$jscomp$23$$($selrect$jscomp$91$$))?$app$common$geom$shapes$distance_selrect$$($G__80955_shape$jscomp$1102_sr$jscomp$5$$,$selrect$jscomp$91$$):$app$common$geom$shapes$distance_selrect$$($selrect$jscomp$91$$,$G__80955_shape$jscomp$1102_sr$jscomp$5$$);return $coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($G__80955_shape$jscomp$1102_sr$jscomp$5$$):$coord$jscomp$23$$($G__80955_shape$jscomp$1102_sr$jscomp$5$$)}
var $distance_coincidences_distances_xf_other_shapes_segments$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($distance_to_selrect$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$pos_QMARK_$$)),$lt_distances$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$distance_coincidences_distances_xf_other_shapes_segments$$,
$lt_shapes_selection_segments$$),$gt_distances$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$distance_coincidences_distances_xf_other_shapes_segments$$,$gt_shapes$$),$distances$jscomp$1$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($lt_distances$$,$gt_distances$$);$distance_coincidences_distances_xf_other_shapes_segments$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($get_shapes_match$$($show_candidate_QMARK_$$,
$lt_shapes_selection_segments$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$get_shapes_match$$($show_candidate_QMARK_$$,$gt_shapes$$)]));var $distance_candidates$$=$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$distance_coincidences_distances_xf_other_shapes_segments$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80948_SHARP_$$){return $check_in_set$$($p1__80948_SHARP_$$,
$lt_distances$$)},$gt_distances$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80949_SHARP_$$){return $check_in_set$$($p1__80949_SHARP_$$,$gt_distances$$)},$lt_distances$$)])),$min_distance$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$distance_candidates$$);$distance_coincidences_distances_xf_other_shapes_segments$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80952_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1605$selrect$$,
$p1__80952_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80951_SHARP_$$){return $show_distance_QMARK_$$($APP.$cljs$core$first$$($p1__80951_SHARP_$$))},$distance_coincidences_distances_xf_other_shapes_segments$$)));$lt_shapes_selection_segments$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80954_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$selrect$jscomp$91$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p1__80954_SHARP_$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80953_SHARP_$$){return $show_distance_QMARK_$$($distance_to_selrect$$($p1__80953_SHARP_$$))},$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($lt_shapes_selection_segments$$,$gt_shapes$$)));return $APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($distance_coincidences_distances_xf_other_shapes_segments$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$lt_shapes_selection_segments$$]))};
$app$main$ui$workspace$viewport$snap_distances$query_worker$$=function($page_id$jscomp$450$$,$coord$jscomp$24_gt_side$$,$lt_side_p__80956$$){function $query_side$$($rect$jscomp$50_side$jscomp$5$$){$rect$jscomp$50_side$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($areas$jscomp$3$$,$rect$jscomp$50_side$jscomp$5$$);return $APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$50_side$jscomp$5$$)>0&&$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$50_side$jscomp$5$$)>
0?$APP.$app$main$snap$select_shapes_area$$($page_id$jscomp$450$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92$$),$selected$jscomp$204$$,$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$rect$jscomp$50_side$jscomp$5$$):(0,$APP.$beicon$v2$core$of$$)(null)}var $selrect$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lt_side_p__80956$$,0,null),$selected$jscomp$204$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lt_side_p__80956$$,
1,null),$frame$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lt_side_p__80956$$,2,null);$lt_side_p__80956$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$24_gt_side$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$1562$top$$;$coord$jscomp$24_gt_side$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$24_gt_side$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$1563$bottom$$;var $bounds$jscomp$95_vbox$jscomp$61$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$),$frame_sr$jscomp$1$$=$APP.$app$common$files$helpers$root_QMARK_$$($frame$jscomp$92$$)?null:$frame$jscomp$92$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$92$$,$APP.$cljs$cst$1605$selrect$$);$bounds$jscomp$95_vbox$jscomp$61$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$clip_rect$$($frame_sr$jscomp$1$$,$bounds$jscomp$95_vbox$jscomp$61$$),$bounds$jscomp$95_vbox$jscomp$61$$);
var $areas$jscomp$3$$=$APP.$app$common$geom$shapes$get_areas$$($bounds$jscomp$95_vbox$jscomp$61$$,$selrect$jscomp$92$$);return $APP.$beicon$v2$core$combine_latest$$($query_side$$($lt_side_p__80956$$),$query_side$$($coord$jscomp$24_gt_side$$))};
$app$main$ui$workspace$viewport$snap_distances$shape_distance$$=function($props_80960_segments_to_display$jscomp$1$$){var $frame$jscomp$93$$=$props_80960_segments_to_display$jscomp$1$$.frame,$selrect$jscomp$93$$=$props_80960_segments_to_display$jscomp$1$$.selrect,$page_id$jscomp$451$$=$props_80960_segments_to_display$jscomp$1$$["page-id"],$zoom$jscomp$153$$=$props_80960_segments_to_display$jscomp$1$$.zoom,$coord$jscomp$25$$=$props_80960_segments_to_display$jscomp$1$$.coord,$selected$jscomp$205$$=
$props_80960_segments_to_display$jscomp$1$$.selected,$subject$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$lt_shapes_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$lt_shapes$jscomp$1$$=$APP.$cljs$core$_deref$$($lt_shapes_STAR_$$),$gt_shapes_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$gt_shapes$jscomp$1$$=$APP.$cljs$core$_deref$$($gt_shapes_STAR_$$);$props_80960_segments_to_display$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($lt_shapes$jscomp$1$$),$APP.$rumext$v2$adapt$$($gt_shapes$jscomp$1$$),$APP.$rumext$v2$adapt$$($selrect$jscomp$93$$)],function(){return $app$main$ui$workspace$viewport$snap_distances$calculate_segments$$($coord$jscomp$25$$,$selrect$jscomp$93$$,$lt_shapes$jscomp$1$$,$gt_shapes$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$451$$)],function(){var $sub$jscomp$27$$=
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($gt_shapes__$1_p__80961$$){var $lt_shapes__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gt_shapes__$1_p__80961$$,0,null);$gt_shapes__$1_p__80961$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gt_shapes__$1_p__80961$$,1,null);$APP.$cljs$core$reset_BANG_$$($lt_shapes_STAR_$$,$lt_shapes__$1$$);return $APP.$cljs$core$reset_BANG_$$($gt_shapes_STAR_$$,$gt_shapes__$1_p__80961$$)},$APP.$beicon$v2$core$switch_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$snap_distances$query_worker$$,
$page_id$jscomp$451$$,$coord$jscomp$25$$),$APP.$beicon$v2$core$throttle$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$subject$jscomp$1$$)));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$27$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selrect$jscomp$93$$)],function(){return $subject$jscomp$1$$.next(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$93$$,$selected$jscomp$205$$,
$frame$jscomp$93$$],null))});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$231$$,$p__80965_sr2$jscomp$6$$){var $sr1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80965_sr2$jscomp$6$$,0,null);$p__80965_sr2$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80965_sr2$jscomp$6$$,1,null);$out_arr__44124__auto__$jscomp$231$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$shape_distance_segment_STAR_$$,
{sr1:$sr1$jscomp$6$$,sr2:$p__80965_sr2$jscomp$6$$,coord:$coord$jscomp$25$$,zoom:$zoom$jscomp$153$$},""+($sr1$jscomp$6$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$6$$,$APP.$cljs$cst$1510$x$$)??"")+"-"+($sr1$jscomp$6$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$6$$,$APP.$cljs$cst$1511$y$$)??"")+"-"+($p__80965_sr2$jscomp$6$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p__80965_sr2$jscomp$6$$,$APP.$cljs$cst$1510$x$$)??"")+"-"+($p__80965_sr2$jscomp$6$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p__80965_sr2$jscomp$6$$,$APP.$cljs$cst$1511$y$$)??"")));return $out_arr__44124__auto__$jscomp$231$$},[],$props_80960_segments_to_display$jscomp$1$$)};
$app$main$ui$workspace$viewport$snap_distances$snap_distances$$=function($props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$){var $page_id$jscomp$452$$=$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$["page-id"],$zoom$jscomp$154$$=$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$.zoom,$selected$jscomp$206$$=$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$.selected;$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$=$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$["selected-shapes"];
var $frame$jscomp$94_frame_id$jscomp$152$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$));$frame$jscomp$94_frame_id$jscomp$152$$=$APP.$rumext$v2$deref$$($app$main$refs$object_by_id$$($frame$jscomp$94_frame_id$jscomp$152$$));$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$);return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$94_frame_id$jscomp$152$$)?
null:(0,$APP.$rumext$v2$jsxs$$)("g",{className:"distance",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$shape_distance$$,{selrect:$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$,"page-id":$page_id$jscomp$452$$,frame:$frame$jscomp$94_frame_id$jscomp$152$$,zoom:$zoom$jscomp$154$$,coord:$APP.$cljs$cst$1510$x$$,selected:$selected$jscomp$206$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$shape_distance$$,{selrect:$props_80969_selected_shapes$jscomp$35_selrect$jscomp$94$$,
"page-id":$page_id$jscomp$452$$,frame:$frame$jscomp$94_frame_id$jscomp$152$$,zoom:$zoom$jscomp$154$$,coord:$APP.$cljs$cst$1511$y$$,selected:$selected$jscomp$206$$})]})};
$app$main$ui$workspace$viewport$snap_points$snap_point_STAR_$$=function($props_80970_x$jscomp$1298$$){var $zoom$jscomp$155$$=$props_80970_x$jscomp$1298$$.zoom,$map__80971__$1_y$jscomp$522$$=$APP.$cljs$core$__destructure_map$$($props_80970_x$jscomp$1298$$.point);$props_80970_x$jscomp$1298$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80971__$1_y$jscomp$522$$,$APP.$cljs$cst$1510$x$$);$map__80971__$1_y$jscomp$522$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80971__$1_y$jscomp$522$$,
$APP.$cljs$cst$1511$y$$);var $cross_width$$=3/$zoom$jscomp$155$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("line",{x1:$props_80970_x$jscomp$1298$$-$cross_width$$,y1:$map__80971__$1_y$jscomp$522$$-$cross_width$$,x2:$props_80970_x$jscomp$1298$$+$cross_width$$,y2:$map__80971__$1_y$jscomp$522$$+$cross_width$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$155$$)}}),(0,$APP.$rumext$v2$jsx$$)("line",
{x1:$props_80970_x$jscomp$1298$$-$cross_width$$,y1:$map__80971__$1_y$jscomp$522$$+$cross_width$$,x2:$props_80970_x$jscomp$1298$$+$cross_width$$,y2:$map__80971__$1_y$jscomp$522$$-$cross_width$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$155$$)}})]})};
$app$main$ui$workspace$viewport$snap_points$snap_line_STAR_$$=function($point$jscomp$92_props_80972$$){var $zoom$jscomp$156$$=$point$jscomp$92_props_80972$$.zoom,$snap$jscomp$3$$=$point$jscomp$92_props_80972$$.snap;$point$jscomp$92_props_80972$$=$point$jscomp$92_props_80972$$.point;return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($snap$jscomp$3$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($snap$jscomp$3$$),x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$92_props_80972$$),
y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$92_props_80972$$),style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$156$$)},opacity:.6})};
$app$main$ui$workspace$viewport$snap_points$get_snap$$=function($coord$jscomp$26$$,$shapes$jscomp$236$$,$page_id$jscomp$453$$,$remove_snap$$,$zoom$jscomp$157$$){var $bounds$jscomp$96$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$236$$),$frame_id$jscomp$153$$=$APP.$app$main$snap$snap_frame_id$$($shapes$jscomp$236$$);return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__80977$$){var $frame_id__$1$jscomp$13$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80977$$,0,null),$point$jscomp$93$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80977$$,1,null);return $APP.$beicon$v2$core$map$$(function($p1__80976_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$93$$,$p1__80976_SHARP_$$,$coord$jscomp$26$$],null)},$APP.$beicon$v2$core$map$$(function($p1__80975_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2159$pt$$,
$p1__80975_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__80974_SHARP_$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$second$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80974_SHARP_$$]))},$app$main$snap$get_snap_points$$($page_id$jscomp$453$$,$frame_id__$1$jscomp$13$$,$remove_snap$$,$zoom$jscomp$157$$,$point$jscomp$93$$,$coord$jscomp$26$$))))},$APP.$beicon$v2$core$merge_map$$(function($bounds__$1$jscomp$6$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80973_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$153$$,$p1__80973_SHARP_$$],null)},$APP.$app$common$geom$snap$rect__GT_snap_points$$($bounds__$1$jscomp$6$$))},(0,$APP.$beicon$v2$core$of$$)($bounds$jscomp$96$$))))};
$app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$=function($p__80982$$){var $point$jscomp$94$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80982$$,0,null),$snaps$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80982$$,1,null),$coord$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80982$$,2,null);return $APP.$cljs$core$cons$$($point$jscomp$94$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80981_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80981_SHARP_$$,
$coord$jscomp$28$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$94$$,$coord$jscomp$28$$))},$snaps$$))};
$app$main$ui$workspace$viewport$snap_points$process_snap_lines$$=function($snaps$jscomp$1$$,$coord$jscomp$29$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($minv$jscomp$1_p__80991$$){var $fixedv$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minv$jscomp$1_p__80991$$,0,null),$maxv$jscomp$1_vec__80995$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minv$jscomp$1_p__80991$$,1,null);$minv$jscomp$1_p__80991$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($maxv$jscomp$1_vec__80995$$,
0,null);$maxv$jscomp$1_vec__80995$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($maxv$jscomp$1_vec__80995$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashMap$fromArrays$$([$coord$jscomp$29$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$29$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1511$y$$:$APP.$cljs$cst$1510$x$$],[$fixedv$$,$minv$jscomp$1_p__80991$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$coord$jscomp$29$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$29$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1511$y$$:$APP.$cljs$cst$1510$x$$],[$fixedv$$,$maxv$jscomp$1_vec__80995$$])],null)},$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80990_SHARP_$$,$p2__80989_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$p2__80989_SHARP_$$),
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$p2__80989_SHARP_$$)],null)},$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80988_SHARP_$$,$p2__80987_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$29$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1511$y$$:$APP.$cljs$cst$1510$x$$,$p2__80987_SHARP_$$)},$APP.$cljs$core$group_by$$($coord$jscomp$29$$,$APP.$cljs$core$flatten$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80986_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__80986_SHARP_$$,2),$coord$jscomp$29$$)},$snaps$jscomp$1$$)])))))))};
$app$main$ui$workspace$viewport$snap_points$snap_feedback_STAR_$$=function($modifiers$jscomp$135_props_80998$$){var $shapes$jscomp$237$$=$modifiers$jscomp$135_props_80998$$.shapes,$zoom$jscomp$158$$=$modifiers$jscomp$135_props_80998$$.zoom,$remove_snap$jscomp$1$$=$modifiers$jscomp$135_props_80998$$.removeSnap,$page_id$jscomp$454$$=$modifiers$jscomp$135_props_80998$$.pageId;$modifiers$jscomp$135_props_80998$$=$modifiers$jscomp$135_props_80998$$.modifiers;var $state$jscomp$1219$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$subject$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$snap_points$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$),$APP.$cljs$core$_deref$$($state$jscomp$1219$$)),$snap_lines$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$viewport$snap_points$process_snap_lines$$($APP.$cljs$core$_deref$$($state$jscomp$1219$$),$APP.$cljs$cst$1510$x$$),$app$main$ui$workspace$viewport$snap_points$process_snap_lines$$($APP.$cljs$core$_deref$$($state$jscomp$1219$$),$APP.$cljs$cst$1511$y$$)));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$28$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($data$jscomp$505_rs$jscomp$3$$){$data$jscomp$505_rs$jscomp$3$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80999$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80999$$,0,null);var $snaps$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80999$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80999$$,2,null);return $APP.$cljs$core$count$$($snaps$jscomp$2$$)>0},$data$jscomp$505_rs$jscomp$3$$);return $APP.$cljs$core$reset_BANG_$$($state$jscomp$1219$$,$data$jscomp$505_rs$jscomp$3$$)},
$APP.$beicon$v2$core$map$$(function($result$jscomp$383$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$concat_vec$$,$APP.$cljs$core$seq$$($result$jscomp$383$$))},$APP.$beicon$v2$core$switch_map$$(function($p__81003_shapes__$1$jscomp$38$$){var $map__81004__$1_zoom__$1$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($p__81003_shapes__$1$jscomp$38$$);$p__81003_shapes__$1$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81004__$1_zoom__$1$jscomp$4$$,
$APP.$cljs$cst$1614$shapes$$);var $page_id__$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81004__$1_zoom__$1$jscomp$4$$,$APP.$cljs$cst$2043$page_id$$),$remove_snap__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81004__$1_zoom__$1$jscomp$4$$,$cljs$cst$5928$remove_snap$$);$map__81004__$1_zoom__$1$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81004__$1_zoom__$1$jscomp$4$$,$APP.$cljs$cst$2196$zoom$$);return $APP.$beicon$v2$core$combine_latest$$($app$main$ui$workspace$viewport$snap_points$get_snap$$($APP.$cljs$cst$1510$x$$,
$p__81003_shapes__$1$jscomp$38$$,$page_id__$1$jscomp$25$$,$remove_snap__$1$$,$map__81004__$1_zoom__$1$jscomp$4$$),$app$main$ui$workspace$viewport$snap_points$get_snap$$($APP.$cljs$cst$1511$y$$,$p__81003_shapes__$1$jscomp$38$$,$page_id__$1$jscomp$25$$,$remove_snap__$1$$,$map__81004__$1_zoom__$1$jscomp$4$$))},$subject$jscomp$2$$)));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$28$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$237$$),
$APP.$rumext$v2$adapt$$($remove_snap$jscomp$1$$),$APP.$rumext$v2$adapt$$($modifiers$jscomp$135_props_80998$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$454$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$158$$)],function(){return $subject$jscomp$2$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1614$shapes$$,$shapes$jscomp$237$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$454$$,$cljs$cst$5928$remove_snap$$,$remove_snap$jscomp$1$$,$APP.$cljs$cst$2196$zoom$$,$zoom$jscomp$158$$],null))});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"snap-feedback",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$232$$,$p__81006_to_point$jscomp$2$$){var $from_point$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81006_to_point$jscomp$2$$,0,null);$p__81006_to_point$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81006_to_point$jscomp$2$$,1,null);$out_arr__44124__auto__$jscomp$232$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_line_STAR_$$,
{snap:$from_point$jscomp$3$$,point:$p__81006_to_point$jscomp$2$$,zoom:$zoom$jscomp$158$$},["line-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from_point$jscomp$3$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from_point$jscomp$3$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p__81006_to_point$jscomp$2$$)),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p__81006_to_point$jscomp$2$$)),"-"].join("")));return $out_arr__44124__auto__$jscomp$232$$},[],$snap_lines$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$233$$,$point$jscomp$95$$){$out_arr__44124__auto__$jscomp$233$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_point_STAR_$$,{point:$point$jscomp$95$$,
zoom:$zoom$jscomp$158$$},["point-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$95$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$95$$))].join("")));return $out_arr__44124__auto__$jscomp$233$$},[],$snap_points$jscomp$2$$)]})};
$app$main$ui$workspace$viewport$path_actions$check_enabled$$=function($content$jscomp$271$$,$is_curve_QMARK__selected_points$jscomp$8$$){if($APP.$cljs$core$truth_$$($content$jscomp$271$$)){var $segments$jscomp$16_segments_selected_QMARK_$$=$APP.$app$common$types$path$segment$get_segments_with_points$$($content$jscomp$271$$,$is_curve_QMARK__selected_points$jscomp$8$$),$num_segments$$=$APP.$cljs$core$count$$($segments$jscomp$16_segments_selected_QMARK_$$),$num_points$$=$APP.$cljs$core$count$$($is_curve_QMARK__selected_points$jscomp$8$$),
$points_selected_QMARK_$$=$APP.$cljs$core$seq$$($is_curve_QMARK__selected_points$jscomp$8$$);$segments$jscomp$16_segments_selected_QMARK_$$=$APP.$cljs$core$seq$$($segments$jscomp$16_segments_selected_QMARK_$$);var $max_segments$$=$num_points$$*($num_points$$-1)/2;$is_curve_QMARK__selected_points$jscomp$8$$=$APP.$cljs$core$some$$(function($p1__81005_SHARP_$$){return $app$common$types$path$segment$is_curve_QMARK_$$($content$jscomp$271$$,$p1__81005_SHARP_$$)},$is_curve_QMARK__selected_points$jscomp$8$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$5309$make_corner$$,$points_selected_QMARK_$$?$is_curve_QMARK__selected_points$jscomp$8$$:$points_selected_QMARK_$$,$APP.$cljs$cst$5315$make_curve$$,$points_selected_QMARK_$$&&$APP.$cljs$core$not$$($is_curve_QMARK__selected_points$jscomp$8$$),$APP.$cljs$cst$5316$add_node$$,$segments$jscomp$16_segments_selected_QMARK_$$,$cljs$cst$5929$remove_node$$,$points_selected_QMARK_$$,$APP.$cljs$cst$5313$merge_nodes$$,$segments$jscomp$16_segments_selected_QMARK_$$,
$APP.$cljs$cst$5308$join_nodes$$,$points_selected_QMARK_$$&&$num_points$$>=2&&$num_segments$$<$max_segments$$,$APP.$cljs$cst$5314$separate_nodes$$,$segments$jscomp$16_segments_selected_QMARK_$$],null)}return null};
$app$main$ui$workspace$viewport$path_actions$path_actions_STAR_$$=function($edit_mode$jscomp$3_props_81012$$){var $on_select_draw_mode_shape$jscomp$1103$$=$edit_mode$jscomp$3_props_81012$$.shape,$map__81013__$1_snap_toggled$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($edit_mode$jscomp$3_props_81012$$.state);$edit_mode$jscomp$3_props_81012$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81013__$1_snap_toggled$jscomp$4$$,$APP.$cljs$cst$4223$edit_mode$$);var $selected_points$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81013__$1_snap_toggled$jscomp$4$$,$APP.$cljs$cst$4241$selected_points$$);$map__81013__$1_snap_toggled$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81013__$1_snap_toggled$jscomp$4$$,$APP.$cljs$cst$4202$snap_toggled$$);var $content$jscomp$272$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($on_select_draw_mode_shape$jscomp$1103$$),$enabled_buttons$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$272$$),
$APP.$rumext$v2$adapt$$($selected_points$jscomp$9$$)],function(){return $app$main$ui$workspace$viewport$path_actions$check_enabled$$($content$jscomp$272$$,$selected_points$jscomp$9$$)});$on_select_draw_mode_shape$jscomp$1103$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$4224$draw$$))});var $on_select_edit_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$1798$move$$))}),
$on_add_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5316$add_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5316$add_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$add_node$$()):null}),$on_remove_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cljs$cst$5929$remove_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($cljs$cst$5929$remove_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$remove_nodes$$)):null}),$on_merge_nodes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5313$merge_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5313$merge_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$merge_nodes$$)):null}),$on_join_nodes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5308$join_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5308$join_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$join_nodes$$)):null}),$on_separate_nodes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5314$separate_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5314$separate_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$separate_nodes$$)):null}),$on_make_corner$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5309$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5309$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$0$()):null}),$on_make_curve$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5315$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5315$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$0$()):null}),$on_toggle_snap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$toggle_snap$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-dont-clear-path":!0,className:"main_ui_workspace_viewport_path_actions__sub-actions",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:[(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.draw-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5310$draw_nodes$$)])),onClick:$on_select_draw_mode_shape$jscomp$1103$$,className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$3_props_81012$$,
$APP.$cljs$cst$4224$draw$$)?"main_ui_workspace_viewport_path_actions__is-toggled":"")+" main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$pentool_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.move-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5317$move_nodes$$)])),
onClick:$on_select_edit_mode$$,className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$3_props_81012$$,$APP.$cljs$cst$1798$move$$)?"main_ui_workspace_viewport_path_actions__is-toggled":"")+" main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$move_icon$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5316$add_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.add-node",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5316$add_node$$)])),onClick:$on_add_node$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$add_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($cljs$cst$5929$remove_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.delete-node",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5311$delete_node$$)])),onClick:$on_remove_node$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$remove_icon$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5313$merge_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.merge-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5313$merge_nodes$$)])),onClick:$on_merge_nodes$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",
children:$app$main$ui$workspace$viewport$path_actions$merge_nodes_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5308$join_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.join-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5308$join_nodes$$)])),onClick:$on_join_nodes$$,
className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$join_nodes_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5314$separate_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.separate-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5314$separate_nodes$$)])),
onClick:$on_separate_nodes$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$separate_nodes_icon$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5309$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.make-corner",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5309$make_corner$$)])),onClick:$on_make_corner$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$to_corner_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5315$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.make-curve",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5315$make_curve$$)])),onClick:$on_make_curve$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$to_curve_icon$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.snap-nodes",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5312$snap_nodes$$)])),onClick:$on_toggle_snap$$,className:($APP.$cljs$core$truth_$$($map__81013__$1_snap_toggled$jscomp$4$$)?"main_ui_workspace_viewport_path_actions__is-toggled":"")+" main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$snap_nodes_icon$$})})]})};
$app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$=function(){var $on_close$jscomp$41$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$set_options_mode$$($APP.$cljs$cst$3732$design$$),$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!1)]))}),
$render_context_lost_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$render_context_lost_QMARK_$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_top_bar__viewport-actions",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_top_bar__viewport-actions-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_top_bar__viewport-actions-title",children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,
{tagName:"span",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($render_context_lost_QMARK_$jscomp$1$$)?"workspace.top-bar.webgl-context-lost":"workspace.top-bar.view-only")})}),$APP.$cljs$core$truth_$$($render_context_lost_QMARK_$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",onClick:function(){return location.reload()},children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.top-bar.webgl-context-lost.reload")}):
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_close$jscomp$41$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.top-bar.read-only.done")})]})})};
$app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$=function($class$$jscomp$81_props_81017$$){var $edit_path_state$jscomp$1$$=$class$$jscomp$81_props_81017$$.editPathState,$shape$jscomp$1104$$=$class$$jscomp$81_props_81017$$.shape;$class$$jscomp$81_props_81017$$="main_ui_workspace_viewport_top_bar__viewport-actions-path "+($APP.$cljs$core$contains_QMARK_$$($class$$jscomp$81_props_81017$$.layout,$APP.$cljs$cst$2211$rulers$$)?"":"main_ui_workspace_viewport_top_bar__viewport-actions-no-rulers");
return(0,$APP.$rumext$v2$jsx$$)("div",{className:$class$$jscomp$81_props_81017$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$path_actions$path_actions_STAR_$$,{shape:$shape$jscomp$1104$$,state:$edit_path_state$jscomp$1$$})})};$app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$=function($props_81018$$){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_edition_actions$$,{shape:$props_81018$$.shape})};
$app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$=function($props_81019_vbox$jscomp$62$$){var $zoom$jscomp$160$$=$props_81019_vbox$jscomp$62$$.zoom;$props_81019_vbox$jscomp$62$$=$props_81019_vbox$jscomp$62$$.vbox;var $custom_alpha_page$jscomp$172$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page$$),$custom_color$$=$APP.$cljs$cst$2059$pixel_grid_color$$.$cljs$core$IFn$_invoke$arity$1$($custom_alpha_page$jscomp$172$$);$custom_alpha_page$jscomp$172$$=$APP.$cljs$cst$2060$pixel_grid_opacity$$.$cljs$core$IFn$_invoke$arity$1$($custom_alpha_page$jscomp$172$$);
var $debug_QMARK_$jscomp$1$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3071$pixel_grid$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"pixel-grid",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("pattern",{id:"pixel-grid",viewBox:"0 0 1 1",width:1,height:1,patternUnits:"userSpaceOnUse",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:"M 1 0 L 0 0 0 1",style:{fill:"none",stroke:$debug_QMARK_$jscomp$1$$?"red":$APP.$cljs$core$truth_$$($custom_color$$)?$custom_color$$:
"var(--status-color-info-500)",strokeOpacity:$debug_QMARK_$jscomp$1$$?1:$custom_alpha_page$jscomp$172$$!=null?$custom_alpha_page$jscomp$172$$:.2,strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$160$$)}})})}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($props_81019_vbox$jscomp$62$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($props_81019_vbox$jscomp$62$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($props_81019_vbox$jscomp$62$$),
height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($props_81019_vbox$jscomp$62$$),fill:"url(#pixel-grid)",style:{pointerEvents:"none"}})]})};
$app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$=function($pos_x$jscomp$7_props_81020_zoom$jscomp$161$$){var $tooltip$jscomp$1$$=$pos_x$jscomp$7_props_81020_zoom$jscomp$161$$.tooltip;$pos_x$jscomp$7_props_81020_zoom$jscomp$161$$=$pos_x$jscomp$7_props_81020_zoom$jscomp$161$$.zoom;var $G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$=$app$main$ui$hooks$use_rxsub$$();$G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$=$G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$==
null?null:$APP.$app$common$geom$point$divide$$($G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($pos_x$jscomp$7_props_81020_zoom$jscomp$161$$,$pos_x$jscomp$7_props_81020_zoom$jscomp$161$$));$pos_x$jscomp$7_props_81020_zoom$jscomp$161$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$)-100;$G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$)+30;return(0,$APP.$rumext$v2$jsx$$)("g",{transform:["translate(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos_x$jscomp$7_props_81020_zoom$jscomp$161$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81021$jscomp$inline_9361_coords$jscomp$4_pos_y$jscomp$7$$),")"].join(""),children:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{width:200,height:100,style:{textAlign:"center"},
children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$tooltip$jscomp$1$$})})})};
$app$main$ui$workspace$viewport$widgets$frame_flow_STAR_$$=function($is_selected$jscomp$12_props_81032$$){var $zoom$jscomp$165$$=$is_selected$jscomp$12_props_81032$$.zoom,$on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$=$is_selected$jscomp$12_props_81032$$.onFrameSelect,$flow_name_frame$jscomp$96$$=$is_selected$jscomp$12_props_81032$$.frame,$on_frame_enter$jscomp$2$$=$is_selected$jscomp$12_props_81032$$.onFrameEnter,$on_frame_leave$jscomp$2$$=$is_selected$jscomp$12_props_81032$$.onFrameLeave,
$flow$jscomp$11_on_pointer_enter$jscomp$17$$=$is_selected$jscomp$12_props_81032$$.flow;$is_selected$jscomp$12_props_81032$$=$is_selected$jscomp$12_props_81032$$.isSelected;var $pos$jscomp$163_x$jscomp$1299$$=$flow_name_frame$jscomp$96$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flow_name_frame$jscomp$96$$,$APP.$cljs$cst$1510$x$$),$on_pointer_leave$jscomp$17_y$jscomp$523$$=$flow_name_frame$jscomp$96$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flow_name_frame$jscomp$96$$,
$APP.$cljs$cst$1511$y$$);$pos$jscomp$163_x$jscomp$1299$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$163_x$jscomp$1299$$,$on_pointer_leave$jscomp$17_y$jscomp$523$$-35/$zoom$jscomp$165$$);var $frame_id$jscomp$156$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow_name_frame$jscomp$96$$);$flow_name_frame$jscomp$96$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$11_on_pointer_enter$jscomp$17$$);$on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$156$$),$APP.$rumext$v2$adapt$$($on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$)],function($event$jscomp$720$$){var $params$jscomp$435$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1366$section$$,"interactions",$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$156$$],null);return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$720$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$720$$),
$APP.$app$util$dom$stop_propagation$$($event$jscomp$720$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$435$$])))):null});$flow$jscomp$11_on_pointer_enter$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$156$$),$APP.$rumext$v2$adapt$$($on_frame_enter$jscomp$2$$)],
function(){return $APP.$cljs$core$fn_QMARK_$$($on_frame_enter$jscomp$2$$)?$on_frame_enter$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_enter$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$156$$):$on_frame_enter$jscomp$2$$($frame_id$jscomp$156$$):null});$on_pointer_leave$jscomp$17_y$jscomp$523$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$156$$),$APP.$rumext$v2$adapt$$($on_frame_leave$jscomp$2$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_frame_leave$jscomp$2$$)?
$on_frame_leave$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$156$$):$on_frame_leave$jscomp$2$$($frame_id$jscomp$156$$):null});return(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:0,y:-15,width:1E5,height:24,transform:$app$main$ui$workspace$viewport$utils$text_transform$$($pos$jscomp$163_x$jscomp$1299$$,$zoom$jscomp$165$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_widgets__frame-flow-badge-wrapper",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{onPointerDown:$on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$,onPointerEnter:$flow$jscomp$11_on_pointer_enter$jscomp$17$$,onPointerLeave:$on_pointer_leave$jscomp$17_y$jscomp$523$$,className:"main_ui_workspace_viewport_widgets__frame-flow-badge-content "+($APP.$cljs$core$truth_$$($is_selected$jscomp$12_props_81032$$)?"main_ui_workspace_viewport_widgets__selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"play",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$flow_name_frame$jscomp$96$$})]})})})};
$app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$=function($props_81033$$){var $zoom$jscomp$166$$=$props_81033$$.zoom,$selected$jscomp$209$$=$props_81033$$.selected,$on_frame_select$jscomp$3$$=$props_81033$$.onFrameSelect,$on_frame_enter$jscomp$3$$=$props_81033$$.onFrameEnter,$objects$jscomp$830$$=$props_81033$$.objects,$on_frame_leave$jscomp$3$$=$props_81033$$.onFrameLeave;return(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-flows",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$235$$,
$JSCompiler_temp_const$jscomp$1949_p__81034$$){var $JSCompiler_inline_result$jscomp$1951_flow_id$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1949_p__81034$$,0,null),$flow$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1949_p__81034$$,1,null);$JSCompiler_temp_const$jscomp$1949_p__81034$$=$out_arr__44124__auto__$jscomp$235$$.push;var $frame$jscomp$inline_9372$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$830$$,
$APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$12$$)),$frame_id$jscomp$inline_9373$$=$frame$jscomp$inline_9372$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$inline_9372$$,$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$1951_flow_id$jscomp$12$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_flow_STAR_$$,{flow:$flow$jscomp$12$$,frame:$frame$jscomp$inline_9372$$,isSelected:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$209$$,
$frame_id$jscomp$inline_9373$$),zoom:$zoom$jscomp$166$$,onFrameEnter:$on_frame_enter$jscomp$3$$,onFrameLeave:$on_frame_leave$jscomp$3$$,onFrameSelect:$on_frame_select$jscomp$3$$},""+($frame_id$jscomp$inline_9373$$??"")+"-"+($JSCompiler_inline_result$jscomp$1951_flow_id$jscomp$12$$??""));$JSCompiler_temp_const$jscomp$1949_p__81034$$.call($out_arr__44124__auto__$jscomp$235$$,$JSCompiler_inline_result$jscomp$1951_flow_id$jscomp$12$$);return $out_arr__44124__auto__$jscomp$235$$},[],$props_81033$$.flows)})};
$app$main$ui$workspace$viewport$widgets$button_add_STAR_$$=function($map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$){var $icon_sz_zoom$jscomp$167$$=$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$.zoom,$on_click$jscomp$59$$=$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$.onClick;$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$.shape);var $height$jscomp$219_map__81039__$1_rect_sz$$=
$APP.$cljs$core$__destructure_map$$($map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$),$rect_y$jscomp$3_x2$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$219_map__81039__$1_rect_sz$$,$APP.$cljs$cst$1525$x2$$);$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$219_map__81039__$1_rect_sz$$,$APP.$cljs$cst$1526$y2$$);$height$jscomp$219_map__81039__$1_rect_sz$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$219_map__81039__$1_rect_sz$$,
$APP.$cljs$cst$1522$height$$);var $center_x$jscomp$2_icon_x$jscomp$1$$=$rect_y$jscomp$3_x2$jscomp$48$$+22/$icon_sz_zoom$jscomp$167$$,$center_y$jscomp$2_icon_y$jscomp$1$$=$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$-$height$jscomp$219_map__81039__$1_rect_sz$$/2;$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$=$center_x$jscomp$2_icon_x$jscomp$1$$-16/$icon_sz_zoom$jscomp$167$$;$rect_y$jscomp$3_x2$jscomp$48$$=$center_y$jscomp$2_icon_y$jscomp$1$$-16/$icon_sz_zoom$jscomp$167$$;$height$jscomp$219_map__81039__$1_rect_sz$$=
32/$icon_sz_zoom$jscomp$167$$;var $rect_r$$=8/$icon_sz_zoom$jscomp$167$$;$center_x$jscomp$2_icon_x$jscomp$1$$-=8/$icon_sz_zoom$jscomp$167$$;$center_y$jscomp$2_icon_y$jscomp$1$$-=8/$icon_sz_zoom$jscomp$167$$;$icon_sz_zoom$jscomp$167$$=16/$icon_sz_zoom$jscomp$167$$;var $handle_click$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$59$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$59$$)?$on_click$jscomp$59$$.$cljs$core$IFn$_invoke$arity$0$?
$on_click$jscomp$59$$.$cljs$core$IFn$_invoke$arity$0$():$on_click$jscomp$59$$():null});return(0,$APP.$rumext$v2$jsxs$$)("g",{onClick:$handle_click$jscomp$6$$,className:"main_ui_workspace_viewport_widgets__button-add-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__81039_props_81038_rect_x$jscomp$3_y2$jscomp$50$$,y:$rect_y$jscomp$3_x2$jscomp$48$$,width:$height$jscomp$219_map__81039__$1_rect_sz$$,height:$height$jscomp$219_map__81039__$1_rect_sz$$,rx:$rect_r$$,ry:$rect_r$$}),(0,$APP.$rumext$v2$jsx$$)("use",
{x:$center_x$jscomp$2_icon_x$jscomp$1$$,y:$center_y$jscomp$2_icon_y$jscomp$1$$,width:$icon_sz_zoom$jscomp$167$$,height:$icon_sz_zoom$jscomp$167$$,href:"#icon-add",className:"main_ui_workspace_viewport_widgets__button-add-icon"})]})};
$app$main$ui$workspace$viewport_wasm$apply_modifiers_to_objects$$=function($objects$jscomp$831$$,$modifiers$jscomp$136$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objs$jscomp$20$$,$p__81040_t$jscomp$102$$){var $id$jscomp$1055$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81040_t$jscomp$102$$,0,null);$p__81040_t$jscomp$102$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81040_t$jscomp$102$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($objs$jscomp$20$$,
$id$jscomp$1055$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($objs$jscomp$20$$,$id$jscomp$1055$$,$APP.$app$common$geom$shapes$apply_transform$$,$p__81040_t$jscomp$102$$):$objs$jscomp$20$$},$objects$jscomp$831$$,$modifiers$jscomp$136$$)};
$app$main$ui$workspace$viewport_wasm$apply_wasm_modifiers_to_ids$$=function($objects$jscomp$833$$,$wasm_modifiers$jscomp$1$$,$id_set$$){return $APP.$cljs$core$empty_QMARK_$$($wasm_modifiers$jscomp$1$$)||$APP.$cljs$core$empty_QMARK_$$($id_set$$)?$objects$jscomp$833$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objs$jscomp$21$$,$id$jscomp$1056$$){var $temp__5823__auto__$jscomp$256$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($wasm_modifiers$jscomp$1$$,$id$jscomp$1056$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$256$$)?$APP.$cljs$core$contains_QMARK_$$($objs$jscomp$21$$,$id$jscomp$1056$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($objs$jscomp$21$$,$id$jscomp$1056$$,$APP.$app$common$geom$shapes$apply_transform$$,$temp__5823__auto__$jscomp$256$$):$objs$jscomp$21$$:$objs$jscomp$21$$},$objects$jscomp$833$$,$id_set$$)};
$app$main$ui$workspace$viewport_wasm$outline_wasm_source_ids$$=function($base_objects$jscomp$3$$,$G__81045_selected$jscomp$211$$,$highlighted$jscomp$6$$,$edition$jscomp$18$$,$hover_ids$jscomp$7$$,$G__81045__$1_hover$jscomp$12$$,$G__81045__$2_frame_hover$jscomp$2$$){var $G__81045__$3_outlined_frame_id$$=$APP.$cljs$core$last$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($G__81045_selected$jscomp$211$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81044_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$3$$,
$p1__81044_SHARP_$$))},$hover_ids$jscomp$7$$)));$G__81045_selected$jscomp$211$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$truth_$$($G__81045_selected$jscomp$211$$)?$G__81045_selected$jscomp$211$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$),$APP.$cljs$core$truth_$$($highlighted$jscomp$6$$)?$highlighted$jscomp$6$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$),
$APP.$cljs$core$truth_$$($hover_ids$jscomp$7$$)?$hover_ids$jscomp$7$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$);$G__81045__$1_hover$jscomp$12$$=$APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__81045__$1_hover$jscomp$12$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__81045_selected$jscomp$211$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__81045__$1_hover$jscomp$12$$)):$G__81045_selected$jscomp$211$$;$G__81045__$2_frame_hover$jscomp$2$$=
$APP.$cljs$core$uuid_QMARK_$$($G__81045__$2_frame_hover$jscomp$2$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__81045__$1_hover$jscomp$12$$,$G__81045__$2_frame_hover$jscomp$2$$):$G__81045__$1_hover$jscomp$12$$;$G__81045__$3_outlined_frame_id$$=$APP.$cljs$core$uuid_QMARK_$$($G__81045__$3_outlined_frame_id$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__81045__$2_frame_hover$jscomp$2$$,$G__81045__$3_outlined_frame_id$$):$G__81045__$2_frame_hover$jscomp$2$$;return $APP.$cljs$core$uuid_QMARK_$$($edition$jscomp$18$$)?
$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($G__81045__$3_outlined_frame_id$$,$edition$jscomp$18$$):$G__81045__$3_outlined_frame_id$$};
$app$main$ui$workspace$viewport_wasm$viewport_STAR_$$=function($props_81047$$){var $palete_size$$=$props_81047$$.paleteSize,$selected$jscomp$212$$=$props_81047$$.selected,$layout$jscomp$30$$=$props_81047$$.layout,$file$jscomp$182$$=$props_81047$$.file,$page$jscomp$173$$=$props_81047$$.page,$wglobal$jscomp$1$$=$props_81047$$.wglobal,$map__81048$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_local$$),$map__81048__$1$$=$APP.$cljs$core$__destructure_map$$($map__81048$$),$edition$jscomp$19$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$2199$edition$$),$selrect$jscomp$95$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$1605$selrect$$),$zoom_inverse$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$3577$zoom_inverse$$),$panning$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$4452$panning$$),$zoom$jscomp$168$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$2196$zoom$$),$transform$jscomp$124$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$1289$transform$$),$vbox$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$1925$vbox$$),$edit_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$1923$edit_path$$),$highlighted$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,
$APP.$cljs$cst$4295$highlighted$$),$vport$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81048__$1$$,$APP.$cljs$cst$2203$vport$$),$map__81049__$1$$=$APP.$cljs$core$__destructure_map$$($wglobal$jscomp$1$$),$options_mode$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81049__$1$$,$APP.$cljs$cst$2200$options_mode$$),$tooltip$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81049__$1$$,$APP.$cljs$cst$2946$tooltip$$),$show_distances_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81049__$1$$,$APP.$cljs$cst$4493$show_distances_QMARK_$$),$preview_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81049__$1$$,$APP.$cljs$cst$5020$preview_id$$),$picking_color_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81049__$1$$,$APP.$cljs$cst$4130$picking_color_QMARK_$$),$permissions$jscomp$37$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$),$read_only_QMARK_$jscomp$36$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$drawing$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$focus$jscomp$23$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$wasm_modifiers$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),$workspace_editor_state$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$),$file_id$jscomp$435$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$182$$,
$APP.$cljs$cst$266$id$$),$vern$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$182$$,$APP.$cljs$cst$2577$vern$$),$objects$jscomp$834$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$173$$,$APP.$cljs$cst$1631$objects$$),$page_id$jscomp$456$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$173$$,$APP.$cljs$cst$266$id$$),$background$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$173$$,$APP.$cljs$cst$2058$background$$,
"#E8E9EA"),$guides$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$173$$,$APP.$cljs$cst$2057$guides$$),$base_objects$jscomp$4$$=$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$834$$,$focus$jscomp$23$$),$objects_modified$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$4$$),$APP.$rumext$v2$adapt$$($wasm_modifiers$jscomp$2$$)],function(){return $app$main$ui$workspace$viewport_wasm$apply_modifiers_to_objects$$($base_objects$jscomp$4$$,
$APP.$cljs$core$select_keys$$($wasm_modifiers$jscomp$2$$,$selected$jscomp$212$$))}),$selected_shapes$jscomp$36$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects_modified$$)),$selected$jscomp$212$$)),$alt_QMARK_$jscomp$25$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$shift_QMARK_$jscomp$46$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$mod_QMARK_$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$space_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$z_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$cursor$jscomp$13$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5915$pointer_inner$$)),$hover_ids$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$hover$jscomp$13$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$measure_hover$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_disabled_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$hover_top_frame_id$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame_hover$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$active_frames$jscomp$3$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$canvas_init_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$initialized_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$vec__81050$$=$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$(),$viewport_ref$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81050$$,0,null),$on_viewport_ref$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81050$$,
1,null),$canvas_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(null),$text_editor_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_vern_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$prev_hover_grid_shown_QMARK__ref$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$disable_paste_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$in_viewport_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$move_stream$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),
$guide_frame$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$)),$APP.$rumext$v2$adapt$$($base_objects$jscomp$4$$)],function(){var $parent_id$jscomp$109$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$root_frame_QMARK_$$,$base_objects$jscomp$4$$),$APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$));return $parent_id$jscomp$109$$!=
null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$4$$,$parent_id$jscomp$109$$):null}),$outline_wasm_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$4$$),$APP.$rumext$v2$adapt$$($selected$jscomp$212$$),$APP.$rumext$v2$adapt$$($highlighted$jscomp$7$$),$APP.$rumext$v2$adapt$$($edition$jscomp$19$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$13$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$))],function(){return $app$main$ui$workspace$viewport_wasm$outline_wasm_source_ids$$($base_objects$jscomp$4$$,$selected$jscomp$212$$,$highlighted$jscomp$7$$,$edition$jscomp$19$$,$APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$),$APP.$cljs$core$_deref$$($hover$jscomp$13$$),$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$))}),$objects_for_outlines$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$4$$),
$APP.$rumext$v2$adapt$$($wasm_modifiers$jscomp$2$$),$APP.$rumext$v2$adapt$$($outline_wasm_ids$$)],function(){return $APP.$cljs$core$seq$$($wasm_modifiers$jscomp$2$$)?$app$main$ui$workspace$viewport_wasm$apply_wasm_modifiers_to_ids$$($base_objects$jscomp$4$$,$wasm_modifiers$jscomp$2$$,$outline_wasm_ids$$):$base_objects$jscomp$4$$}),$zoom__$1$jscomp$5$$=$APP.$app$common$math$finite$$($zoom$jscomp$168$$,1),$drawing_tool$jscomp$7$$=$APP.$cljs$cst$2197$tool$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$5$$),
$drawing_obj$$=$APP.$cljs$cst$2198$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$5$$),$selected_frames$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1607$frame_id$$),$selected_shapes$jscomp$36$$),$selected_frame$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frames$jscomp$2$$),1)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$4$$,
$APP.$cljs$core$first$$($selected_frames$jscomp$2$$)):null,$edit_path_state$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path$$,$edition$jscomp$19$$),$edit_path_mode$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_state$jscomp$2$$,$APP.$cljs$cst$4223$edit_mode$$),$path_editing_QMARK_$jscomp$3$$=$edit_path_state$jscomp$2$$!=null,$path_drawing_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_mode$$,$APP.$cljs$cst$4224$draw$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing_obj$$,$APP.$cljs$cst$139$type$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2052$curve$$,$drawing_tool$jscomp$7$$),$editing_shape$jscomp$1$$=$APP.$cljs$core$truth_$$($edition$jscomp$19$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$4$$,$edition$jscomp$19$$):null,$editing_shape__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_shape$jscomp$1$$),
$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($base_objects$jscomp$4$$)],function(){return $path_editing_QMARK_$jscomp$3$$?$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($editing_shape$jscomp$1$$,$base_objects$jscomp$4$$):$editing_shape$jscomp$1$$}),$create_comment_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3436$comments$$,$drawing_tool$jscomp$7$$),$text_editing_QMARK_$jscomp$3$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$1$$),
$grid_editing_QMARK_$jscomp$2$$=$APP.$cljs$core$truth_$$($edition$jscomp$19$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$4$$,$edition$jscomp$19$$):$edition$jscomp$19$$,$mode_inspect_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$3$$,$APP.$cljs$cst$2672$inspect$$),$page_transition_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$),$context_loss_overlay_QMARK_$$=
$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$context_loss_overlay_QMARK_$$),$on_click$jscomp$60$$=$app$main$ui$workspace$viewport$actions$on_click$$($hover$jscomp$13$$,$selected$jscomp$212$$,$edition$jscomp$19$$,$path_drawing_QMARK_$$,$drawing_tool$jscomp$7$$,$space_QMARK_$jscomp$5$$,$selrect$jscomp$95$$,$z_QMARK_$jscomp$5$$),$on_context_menu$jscomp$29$$=$app$main$ui$workspace$viewport$actions$on_context_menu$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$read_only_QMARK_$jscomp$36$$),$on_double_click$jscomp$7$$=
$app$main$ui$workspace$viewport$actions$on_double_click$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$selected$jscomp$212$$,$hover_top_frame_id$jscomp$7$$,$path_drawing_QMARK_$$,$base_objects$jscomp$4$$,$edition$jscomp$19$$,$drawing_tool$jscomp$7$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$36$$),$comp_inst_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_drag_enter$jscomp$8$$=$app$main$ui$workspace$viewport$actions$on_drag_enter$$($comp_inst_ref$jscomp$3$$),$on_drag_over$jscomp$2$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($move_stream$jscomp$4$$),
$on_drag_end$jscomp$2$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($comp_inst_ref$jscomp$3$$),$on_drop$jscomp$19$$=$app$main$ui$workspace$viewport$actions$on_drop$$($file$jscomp$182$$,$comp_inst_ref$jscomp$3$$),$on_pointer_down$jscomp$22$$=$app$main$ui$workspace$viewport$actions$on_pointer_down$$($APP.$cljs$core$_deref$$($hover$jscomp$13$$),$selected$jscomp$212$$,$edition$jscomp$19$$,$drawing_tool$jscomp$7$$,$text_editing_QMARK_$jscomp$3$$,$path_editing_QMARK_$jscomp$3$$,$grid_editing_QMARK_$jscomp$2$$,
$path_drawing_QMARK_$$,$create_comment_QMARK_$jscomp$1$$,$space_QMARK_$jscomp$5$$,$panning$jscomp$2$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$36$$),$on_pointer_up$jscomp$8$$=$app$main$ui$workspace$viewport$actions$on_pointer_up$$($disable_paste_ref$jscomp$3$$),$on_pointer_enter$jscomp$18$$=$app$main$ui$workspace$viewport$actions$on_pointer_enter$$($in_viewport_ref$jscomp$4$$),$on_pointer_leave$jscomp$18$$=$app$main$ui$workspace$viewport$actions$on_pointer_leave$$($in_viewport_ref$jscomp$4$$),
$on_pointer_move$jscomp$16$$=$app$main$ui$workspace$viewport$actions$on_pointer_move$$($move_stream$jscomp$4$$),$on_move_selected$jscomp$11$$=$app$main$ui$workspace$viewport$actions$on_move_selected$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$selected$jscomp$212$$,$space_QMARK_$jscomp$5$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$36$$),$on_menu_selected$$=$app$main$ui$workspace$viewport$actions$on_menu_selected$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$selected$jscomp$212$$,$read_only_QMARK_$jscomp$36$$),
$on_frame_enter$jscomp$4$$=$app$main$ui$workspace$viewport$actions$on_frame_enter$$($frame_hover$jscomp$3$$),$on_frame_leave$jscomp$4$$=$app$main$ui$workspace$viewport$actions$on_frame_leave$$($frame_hover$jscomp$3$$),$on_frame_select$jscomp$4$$=$app$main$ui$workspace$viewport$actions$on_frame_select$$($selected$jscomp$212$$,$read_only_QMARK_$jscomp$36$$),$disable_events_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3436$comments$$),$show_comments_QMARK_$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$7$$,$APP.$cljs$cst$3436$comments$$),$show_gradient_handlers_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$212$$),1),$show_grids_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3725$display_guides$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_frame_outline_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$124$$,
$APP.$cljs$cst$1798$move$$)&&$APP.$cljs$core$not$$($panning$jscomp$2$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_outlines_QMARK_$$=$transform$jscomp$124$$==null&&$APP.$cljs$core$not$$($panning$jscomp$2$$)&&$APP.$cljs$core$not$$($edition$jscomp$19$$)&&$APP.$cljs$core$not$$($drawing_obj$$)&&$APP.$cljs$core$not$$(function(){var $fexpr__81053$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$3436$comments$$,
null,$APP.$cljs$cst$2052$curve$$,null],null),null);return $fexpr__81053$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__81053$$.$cljs$core$IFn$_invoke$arity$1$($drawing_tool$jscomp$7$$):$fexpr__81053$$($drawing_tool$jscomp$7$$)}())&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_pixel_grid_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3717$show_pixel_grid$$)&&$zoom__$1$jscomp$5$$>=8&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_text_editor_QMARK_$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$1$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$1$$))&&$APP.$cljs$core$not$$($page_transition_QMARK_$$):$editing_shape__$1$jscomp$1$$,$has_grid_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$962$$=$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$)!=null;return $and__5023__auto__$jscomp$962$$?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$834$$,
$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$)):$and__5023__auto__$jscomp$962$$}(),$hover_grid_QMARK_$$=$APP.$cljs$core$truth_$$($has_grid_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$has_grid_QMARK_$jscomp$1$$,$show_grid_editor_QMARK_$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$1$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$1$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$):$editing_shape__$1$jscomp$1$$,
$show_presence_QMARK_$$=$APP.$cljs$core$truth_$$($page_id$jscomp$456$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$page_id$jscomp$456$$,$show_prototypes_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$3$$,$APP.$cljs$cst$3731$prototype$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_selection_handlers_QMARK_$$=$APP.$cljs$core$seq$$($selected$jscomp$212$$)&&$APP.$cljs$core$not$$($show_text_editor_QMARK_$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),
$show_snap_distance_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3724$dynamic_alignment$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$124$$,$APP.$cljs$cst$1798$move$$)&&$APP.$cljs$core$seq$$($selected$jscomp$212$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_snap_points_QMARK_$$=function(){var $and__5023__auto__$jscomp$966_and__5023__auto____$1$jscomp$159$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3724$dynamic_alignment$$)||
$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3720$snap_guides$$);return $and__5023__auto__$jscomp$966_and__5023__auto____$1$jscomp$159$$?($and__5023__auto__$jscomp$966_and__5023__auto____$1$jscomp$159$$=$APP.$cljs$core$truth_$$($drawing_obj$$)?$drawing_obj$$:$transform$jscomp$124$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$966_and__5023__auto____$1$jscomp$159$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$and__5023__auto__$jscomp$966_and__5023__auto____$1$jscomp$159$$):
$and__5023__auto__$jscomp$966_and__5023__auto____$1$jscomp$159$$}(),$show_selrect_QMARK_$$=$APP.$cljs$core$truth_$$($selrect$jscomp$95$$)?$APP.$cljs$core$empty_QMARK_$$($drawing$jscomp$5$$)&&!$text_editing_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($page_transition_QMARK_$$):$selrect$jscomp$95$$,$show_measures_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$=$APP.$cljs$core$not$$($transform$jscomp$124$$);return $and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$?
($and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$=!$path_editing_QMARK_$jscomp$3$$)?($and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$=$APP.$cljs$core$truth_$$($show_distances_QMARK_$$)?$show_distances_QMARK_$$:$mode_inspect_QMARK_$jscomp$1$$?$mode_inspect_QMARK_$jscomp$1$$:$read_only_QMARK_$jscomp$36$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$)?
$APP.$cljs$core$not$$($page_transition_QMARK_$$):$and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$):$and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$:$and__5023__auto__$jscomp$968_and__5023__auto____$1$jscomp$160_and__5023__auto____$2$jscomp$46$$}(),$show_artboard_names_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$3722$display_artboard_names$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),
$hide_ui_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$4825$hide_ui$$),$show_rulers_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$APP.$cljs$cst$2211$rulers$$)&&!$hide_ui_QMARK_$$,$disabled_guides_QMARK_$$=$APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$)?$drawing_tool$jscomp$7$$:$APP.$cljs$core$truth_$$($transform$jscomp$124$$)?$transform$jscomp$124$$:$path_drawing_QMARK_$$||$path_editing_QMARK_$jscomp$3$$||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,
$APP.$cljs$cst$3721$lock_guides$$),$single_select_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$36$$),1),$first_shape$jscomp$12$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$36$$),$show_add_variant_QMARK_$$=function(){if($single_select_QMARK_$$){var $or__5025__auto__$jscomp$1363$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($first_shape$jscomp$12$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1363$$)?
$or__5025__auto__$jscomp$1363$$:$APP.$app$common$types$component$is_variant_QMARK_$$($first_shape$jscomp$12$$)}return $single_select_QMARK_$$}(),$show_scrollbar_QMARK_$$=$APP.$cljs$core$not$$($page_transition_QMARK_$$),$add_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($first_shape$jscomp$12$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$)))}),
$show_padding_QMARK_$$=$transform$jscomp$124$$==null&&$single_select_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$),$APP.$cljs$cst$1606$frame$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$),$APP.$cljs$cst$1660$flex$$)&&$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$)===
0,$show_margin_QMARK_$$=$transform$jscomp$124$$==null&&$single_select_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$5$$),$APP.$cljs$cst$1660$flex$$)&&$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$)===0,$selecting_first_level_frame_QMARK_$$=$single_select_QMARK_$$&&$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$),
$offset_x$jscomp$17$$=$selecting_first_level_frame_QMARK_$$?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$):$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$5$$),$offset_y$jscomp$18$$=$selecting_first_level_frame_QMARK_$$?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$12$$):$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$5$$),$rule_area_size$jscomp$1$$=22/$zoom__$1$jscomp$5$$,
$preview_blend$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_preview_blend$$),$shapes_loading_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$shapes_loading_QMARK_$$),$transition_image_url$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$456$$)],function(){var $temp__5825__auto__$jscomp$438$$=$APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$6$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$438$$)){var $timeout_id_ref$$=$APP.$cljs$core$volatile_BANG_$$(null),$unmounted_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1),$modal_shown_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1),$show_unavailable$$=function(){var $JSCompiler_inline_result$jscomp$1952_or__5025__auto__$jscomp$inline_9375$$=$APP.$cljs$core$_deref$$($unmounted_QMARK_$$);$JSCompiler_inline_result$jscomp$1952_or__5025__auto__$jscomp$inline_9375$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1952_or__5025__auto__$jscomp$inline_9375$$)?
$JSCompiler_inline_result$jscomp$1952_or__5025__auto__$jscomp$inline_9375$$:$APP.$cljs$core$_deref$$($modal_shown_QMARK_$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1952_or__5025__auto__$jscomp$inline_9375$$))return null;$APP.$cljs$core$_vreset_BANG_$$($modal_shown_QMARK_$$,!0);$APP.$cljs$core$reset_BANG_$$($canvas_init_QMARK_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5930$webgl_unavailable$$],null)))},$try_init$$=function $app$main$ui$workspace$viewport_wasm$viewport_STAR__$_try_init$$($retries$jscomp$2$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($unmounted_QMARK_$$)))return null;try{var $init_QMARK_$$=$APP.$app$render_wasm$api$init_canvas_context$$($temp__5825__auto__$jscomp$438$$)}catch($e81054$jscomp$inline_9377$$){console.error("Error initializing canvas context:",$e81054$jscomp$inline_9377$$),$init_QMARK_$$=
!1}return $APP.$cljs$core$truth_$$($init_QMARK_$$)?$APP.$cljs$core$reset_BANG_$$($canvas_init_QMARK_$$,!0):$retries$jscomp$2$$>0?$APP.$cljs$core$vreset_BANG_$$($timeout_id_ref$$,setTimeout(function(){return $app$main$ui$workspace$viewport_wasm$viewport_STAR__$_try_init$$($retries$jscomp$2$$-1)},200)):$show_unavailable$$()};$APP.$cljs$core$reset_BANG_$$($canvas_init_QMARK_$$,!1);$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($ready_QMARK_$jscomp$2$$){return $APP.$cljs$core$truth_$$($ready_QMARK_$jscomp$2$$)?
$try_init$$(3):null},$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$module$$));return function(){$APP.$cljs$core$_vreset_BANG_$$($unmounted_QMARK_$$,!0);var $temp__5825__auto___81069__$1$$=$APP.$cljs$core$_deref$$($timeout_id_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___81069__$1$$)&&clearTimeout($temp__5825__auto___81069__$1$$);return $APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)}}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_text_editor_QMARK_$$),
$APP.$rumext$v2$adapt$$($workspace_editor_state$jscomp$1$$),$APP.$rumext$v2$adapt$$($edition$jscomp$19$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($initialized_QMARK_$$))],function(){var $active_editor_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($workspace_editor_state$jscomp$1$$,$edition$jscomp$19$$);if($APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($show_text_editor_QMARK_$$)){if($APP.$cljs$core$truth_$$($active_editor_state$$)){var $and__5023__auto____$2$jscomp$47$$=
$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);return $APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$47$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$and__5023__auto____$2$jscomp$47$$}return $active_editor_state$$}return $show_text_editor_QMARK_$$}())){var $content$jscomp$273_dimension$jscomp$1$$=$app$util$text_editor$export_content$$($active_editor_state$$.getCurrentContent());$APP.$app$render_wasm$api$use_shape$$($edition$jscomp$19$$);$APP.$app$render_wasm$api$set_shape_text_content$$($edition$jscomp$19$$,
$content$jscomp$273_dimension$jscomp$1$$);$content$jscomp$273_dimension$jscomp$1$$=$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$00$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$resize_text_editor$$($edition$jscomp$19$$,$content$jscomp$273_dimension$jscomp$1$$));return $APP.$app$render_wasm$api$request_render$$("content")}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vport$jscomp$14$$)],
function(){var $JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);$JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):
$JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$)){$JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$14$$);
var $code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$14$$),$fn_54324$jscomp$inline_13758_hint__53000__auto__$jscomp$inline_13763$$=$APP.$app$render_wasm$wasm$internal_module$$._resize_viewbox;try{$fn_54324$jscomp$inline_13758_hint__53000__auto__$jscomp$inline_13763$$($JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$,
$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$)}catch($e54326$jscomp$inline_13764$$){throw $JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$=$e54326$jscomp$inline_13764$$,$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$)?$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$():null,$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_54324$jscomp$inline_13758_hint__53000__auto__$jscomp$inline_13763$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54324$jscomp$inline_13758_hint__53000__auto__$jscomp$inline_13763$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_resize_viewbox",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54324$jscomp$inline_13758_hint__53000__auto__$jscomp$inline_13763$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_13762_code_num__52998__auto__$jscomp$inline_13761_height$jscomp$inline_13757_read_code_fn__52997__auto__$jscomp$inline_13760$$],
null),$JSCompiler_inline_result$jscomp$1953_and__5023__auto__$jscomp$inline_9379_cause54325$jscomp$inline_13759_width$jscomp$inline_13756$$);}return $APP.$app$render_wasm$api$set_view_box$$($zoom__$1$jscomp$5$$,$vbox$jscomp$63$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($preview_blend$$)],function(){var $and__5023__auto__$jscomp$inline_9381$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9381$$)?$preview_blend$$:$and__5023__auto__$jscomp$inline_9381$$)?$APP.$app$render_wasm$api$request_render$$("with-effect"):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($vern$jscomp$4$$),$APP.$rumext$v2$adapt$$($zoom__$1$jscomp$5$$),$APP.$rumext$v2$adapt$$($vbox$jscomp$63$$),$APP.$rumext$v2$adapt$$($background$jscomp$13$$)],
function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))){if($APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($initialized_QMARK_$$)))return $APP.$rumext$v2$set_ref_val_BANG_$$($last_vern_ref$$,$vern$jscomp$4$$),$app$render_wasm$api$start_initial_load_transition_BANG_$$($background$jscomp$13$$),$APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_objects$jscomp$4$$,$zoom__$1$jscomp$5$$,$vbox$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2058$background$$,
$background$jscomp$13$$,$APP.$cljs$cst$3093$on_shapes_ready$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_page_position_data$cljs$0core$0IFn$0_invoke$0arity$02$$())}])),$APP.$cljs$core$reset_BANG_$$($initialized_QMARK_$$,!0);if($vern$jscomp$4$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($vern$jscomp$4$$,$APP.$rumext$v2$ref_val$$($last_vern_ref$$)))return $APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_objects$jscomp$4$$,
$zoom__$1$jscomp$5$$,$vbox$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2058$background$$,$background$jscomp$13$$])),$APP.$rumext$v2$set_ref_val_BANG_$$($last_vern_ref$$,$vern$jscomp$4$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus$jscomp$23$$)],function(){return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$973$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$973$$)?
$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$and__5023__auto__$jscomp$973$$}())?$APP.$app$util$timers$asap$$(function(){if($APP.$cljs$core$empty_QMARK_$$($focus$jscomp$23$$)){var $JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_focus_mode;try{$JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$()}catch($e54252$jscomp$inline_9389$$){$JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$=
$e54252$jscomp$inline_9389$$;var $code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$=$APP.$cljs$core$truth_$$($code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$)?
$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$():
null;$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54937$jscomp$inline_9388$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54937$jscomp$inline_9388$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_focus_mode",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54937$jscomp$inline_9388$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54936$jscomp$inline_9387_code_num__52998__auto___54935$jscomp$inline_9386_read_code_fn__52997__auto___54934$jscomp$inline_9385$$],null),$JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$);}$JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$=$APP.$app$render_wasm$api$request_render$$("clear-focus-mode")}else $JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$=
$app$render_wasm$api$set_focus_mode$$($focus$jscomp$23$$);return $JSCompiler_temp$jscomp$1646_cause54251_54933$jscomp$inline_9384_fn_54250_54932$jscomp$inline_9383$$}):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($background$jscomp$13$$)],function(){var $JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);
$JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$;
if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$)){$JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$=$APP.$app$render_wasm$serializers$color$hex__GT_u32argb$$($background$jscomp$13$$,1);var $code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_canvas_background;try{$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$($JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$)}catch($e54280$jscomp$inline_13774$$){$JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$=
$e54280$jscomp$inline_13774$$;$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$=$APP.$cljs$core$truth_$$($code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$)?
$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$():
null;$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $hint__53000__auto___54969$jscomp$inline_13773$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54969$jscomp$inline_13773$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_canvas_background",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54969$jscomp$inline_13773$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54968$jscomp$inline_13772_code_num__52998__auto___54967$jscomp$inline_13771_fn_54278_54964$jscomp$inline_13768_read_code_fn__52997__auto___54966$jscomp$inline_13770$$],null),$JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$);
}$JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$=$APP.$app$render_wasm$api$request_render$$("set-canvas-background")}else $JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$=null;return $JSCompiler_inline_result$jscomp$1955_JSCompiler_temp$jscomp$10984_and__5023__auto__$jscomp$inline_9391_cause54279_54965$jscomp$inline_13769_rgba$jscomp$inline_13767$$});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($hover_grid_QMARK_$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))){var $and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$=$APP.$cljs$core$not$$($hover_grid_QMARK_$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$?
$APP.$rumext$v2$ref_val$$($prev_hover_grid_shown_QMARK__ref$$):$and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$)){$and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$=$APP.$app$render_wasm$wasm$internal_module$$._hide_grid;try{$and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$()}catch($e54389$jscomp$inline_13782$$){$and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$=
$e54389$jscomp$inline_13782$$;var $code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$=$APP.$cljs$core$truth_$$($code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$)?
$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$():
null;$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___55195$jscomp$inline_13781$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55195$jscomp$inline_13781$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_hide_grid",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55195$jscomp$inline_13781$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___55194$jscomp$inline_13780_code_num__52998__auto___55193$jscomp$inline_13779_read_code_fn__52997__auto___55192$jscomp$inline_13778$$],null),$and__5023__auto__$jscomp$inline_9393_cause54388_55191$jscomp$inline_13777_fn_54387_55190$jscomp$inline_13776$$);}$APP.$app$render_wasm$api$request_render$$("clear-grid")}return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_hover_grid_shown_QMARK__ref$$,$hover_grid_QMARK_$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),
$APP.$rumext$v2$adapt$$($has_grid_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($hover_grid_QMARK_$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_grid_QMARK_$jscomp$1$$)?$hover_grid_QMARK_$$:$has_grid_QMARK_$jscomp$1$$)?$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$):$cljs$cst$5931$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_wasm_SLASH_no_grid_hover_id$$)],function(){var $JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$=
$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$)?$hover_grid_QMARK_$$:$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$)){$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$=
$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$);$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$=$APP.$app$common$uuid$get_u32$$($JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$);var $code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$=
$APP.$app$render_wasm$wasm$internal_module$$._show_grid;try{$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$($JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$[0],$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$[1],
$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$[2],$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$[3])}catch($e54384$jscomp$inline_13792$$){$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$=
$e54384$jscomp$inline_13792$$;$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$=$APP.$cljs$core$truth_$$($code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$)?
$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$():
null;$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $hint__53000__auto___55187$jscomp$inline_13791$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55187$jscomp$inline_13791$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_show_grid",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55187$jscomp$inline_13791$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55186$jscomp$inline_13790_code_num__52998__auto___55185$jscomp$inline_13789_fn_54382_55182$jscomp$inline_13786_read_code_fn__52997__auto___55184$jscomp$inline_13788$$],null),$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$);
}$JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$=$APP.$app$render_wasm$api$request_render$$("show-grid")}else $JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$=null;return $JSCompiler_temp$jscomp$10983_and__5023__auto__$jscomp$inline_9395_buffer_55181$jscomp$inline_13785_cause54383_55183$jscomp$inline_13787_id$jscomp$inline_13784$$});
$app$main$ui$workspace$viewport$hooks$setup_dom_events$$($zoom__$1$jscomp$5$$,$disable_paste_ref$jscomp$3$$,$in_viewport_ref$jscomp$4$$,$read_only_QMARK_$jscomp$36$$,$drawing_tool$jscomp$7$$,$path_drawing_QMARK_$$);$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$($vport$jscomp$14$$,$viewport_ref$jscomp$3$$);$app$main$ui$workspace$viewport$hooks$setup_cursor$$($cursor$jscomp$13$$,$alt_QMARK_$jscomp$25$$,$mod_QMARK_$jscomp$14$$,$space_QMARK_$jscomp$5$$,$panning$jscomp$2$$,$drawing_tool$jscomp$7$$,
$path_drawing_QMARK_$$,$path_editing_QMARK_$jscomp$3$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$36$$);$app$main$ui$workspace$viewport$hooks$setup_keyboard$$($alt_QMARK_$jscomp$25$$,$mod_QMARK_$jscomp$14$$,$space_QMARK_$jscomp$5$$,$z_QMARK_$jscomp$5$$,$shift_QMARK_$jscomp$46$$);$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$($page_id$jscomp$456$$,$move_stream$jscomp$4$$,$base_objects$jscomp$4$$,$selected$jscomp$212$$,$mod_QMARK_$jscomp$14$$,$hover$jscomp$13$$,$measure_hover$jscomp$1$$,
$hover_ids$jscomp$8$$,$hover_top_frame_id$jscomp$7$$,$APP.$cljs$core$_deref$$($hover_disabled_QMARK_$jscomp$1$$),$focus$jscomp$23$$,$zoom__$1$jscomp$5$$,$show_measures_QMARK_$jscomp$1$$,$read_only_QMARK_$jscomp$36$$,$transform$jscomp$124$$);$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$($path_editing_QMARK_$jscomp$3$$,$path_drawing_QMARK_$$,$text_editing_QMARK_$jscomp$3$$,$grid_editing_QMARK_$jscomp$2$$);$app$main$ui$workspace$viewport$hooks$setup_active_frames$$($base_objects$jscomp$4$$,
$hover_ids$jscomp$8$$,$selected$jscomp$212$$,$active_frames$jscomp$3$$,$zoom__$1$jscomp$5$$,$transform$jscomp$124$$,$vbox$jscomp$63$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--zoom":$zoom__$1$jscomp$5$$},"data-testid":"viewport",className:"main_ui_workspace_viewport_wasm__viewport",children:[$preview_id$$!=null?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$36$$)?$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$37$$):$read_only_QMARK_$jscomp$36$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$,{}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$hide_ui_QMARK_$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$top_toolbar_STAR_$$,{layout:$layout$jscomp$30$$}),$path_editing_QMARK_$jscomp$3$$&&$single_select_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$,{shape:$editing_shape__$1$jscomp$1$$,editPathState:$edit_path_state$jscomp$2$$,
layout:$layout$jscomp$30$$}):null,$grid_editing_QMARK_$jscomp$2$$&&$single_select_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$,{shape:$editing_shape__$1$jscomp$1$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_wasm__viewport-overlays",children:[$show_comments_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comments_layer_STAR_$$,{vbox:$vbox$jscomp$63$$,pageId:$page_id$jscomp$456$$,
fileId:$file_id$jscomp$435$$,vport:$vport$jscomp$14$$,zoom:$zoom__$1$jscomp$5$$}):null,$APP.$cljs$core$truth_$$($picking_color_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_wasm_STAR_$$,{viewportRef:$viewport_ref$jscomp$3$$,canvasRef:$canvas_ref$jscomp$6$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("canvas",{id:"render","data-testid":"canvas-wasm-shapes",ref:$canvas_ref$jscomp$6$$,width:$APP.$app$render_wasm$api$dpr$$*$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$14$$,
0),height:$APP.$app$render_wasm$api$dpr$$*$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$14$$,0),style:{backgroundColor:$background$jscomp$13$$,pointerEvents:"none"},className:"main_ui_workspace_viewport_wasm__render-shapes"},"render"+($page_id$jscomp$456$$??"")),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$979$$=$APP.$cljs$core$truth_$$($page_transition_QMARK_$$)?$page_transition_QMARK_$$:$context_loss_overlay_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$979$$)?
$transition_image_url$$!=null:$and__5023__auto__$jscomp$979$$}())?(0,$APP.$rumext$v2$jsx$$)("img",{"data-testid":"canvas-wasm-transition",src:$transition_image_url$$,draggable:!1,style:{position:"absolute",inset:0,width:"100%",height:"100%",objectFit:"cover",pointerEvents:"none",filter:"blur(4px)"}}):null,(0,$APP.$rumext$v2$jsxs$$)("svg",{onDoubleClick:$on_double_click$jscomp$7$$,onDragEnter:$on_drag_enter$jscomp$8$$,xmlns:"http://www.w3.org/2000/svg",className:"viewport-controls "+(""+($APP.$cljs$core$_deref$$($cursor$jscomp$13$$)??
"")+(($APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$)?" drawing":null)??"")+" main_ui_workspace_viewport_wasm__viewport-controls"),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:"clip-handlers",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$63$$)+$rule_area_size$jscomp$1$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$63$$)+$rule_area_size$jscomp$1$$,width:function(){var $y__5111__auto__$jscomp$191$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$63$$)-$rule_area_size$jscomp$1$$;return 0>$y__5111__auto__$jscomp$191$$?0:$y__5111__auto__$jscomp$191$$}(),height:function(){var $y__5111__auto__$jscomp$192$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$63$$)-$rule_area_size$jscomp$1$$;return 0>$y__5111__auto__$jscomp$192$$?0:$y__5111__auto__$jscomp$192$$}()})})}),(0,$APP.$rumext$v2$jsxs$$)("g",{style:{pointerEvents:$APP.$cljs$core$truth_$$($disable_events_QMARK_$$?
$disable_events_QMARK_$$:$shapes_loading_QMARK_$$)?"none":"auto"},children:[$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$$)?$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v3_editor$text_editor$$,{shape:$editing_shape__$1$jscomp$1$$,"canvas-ref":$canvas_ref$jscomp$6$$,ref:$text_editor_ref$$}):$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"text-editor/v2")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v2_editor$text_editor$$,{shape:$editing_shape__$1$jscomp$1$$,"canvas-ref":$canvas_ref$jscomp$6$$,ref:$text_editor_ref$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$editor$text_editor_svg$$,{shape:$editing_shape__$1$jscomp$1$$,ref:$text_editor_ref$$}):null,$show_frame_outline_QMARK_$$?function(){var $outlined_frame_id$jscomp$1$$=$APP.$cljs$core$last$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$212$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81046_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$4$$,$p1__81046_SHARP_$$))},$APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$)))),$outlined_frame$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$834$$,$outlined_frame_id$jscomp$1$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines$$,{objects:$objects_for_outlines$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$outlined_frame_id$jscomp$1$$]),zoom:$zoom__$1$jscomp$5$$}),$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($outlined_frame$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"ghost-outline blurrable",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines$$,
{objects:$objects_for_outlines$$,selected:$selected$jscomp$212$$,zoom:$zoom__$1$jscomp$5$$})}):null]})}():null,$show_outlines_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines$$,{objects:$objects_for_outlines$$,selected:$selected$jscomp$212$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($hover$jscomp$13$$)),$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$)]),highlighted:$highlighted$jscomp$7$$,
edition:$edition$jscomp$19$$,zoom:$zoom__$1$jscomp$5$$}):null,$APP.$cljs$core$truth_$$($show_selection_handlers_QMARK_$$?$selected_shapes$jscomp$36$$:$show_selection_handlers_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$area_STAR_$$,{shapes:$selected_shapes$jscomp$36$$,zoom:$zoom__$1$jscomp$5$$,edition:$edition$jscomp$19$$,disabled:function(){if($APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$))return $drawing_tool$jscomp$7$$;if($APP.$cljs$core$truth_$$($edition$jscomp$19$$))return $edition$jscomp$19$$;
var $or__5025__auto____$2$jscomp$38$$=$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$5$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$2$jscomp$38$$)?$or__5025__auto____$2$jscomp$38$$:$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$14$$)}(),onMoveSelected:$on_move_selected$jscomp$11$$,onContextMenu:$on_menu_selected$$}):null,$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$,{shape:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$4$$,
$edition$jscomp$19$$),zoom:$zoom__$1$jscomp$5$$}):null,$APP.$cljs$core$truth_$$($show_measures_QMARK_$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement$$,{bounds:$vbox$jscomp$63$$,"selected-shapes":$selected_shapes$jscomp$36$$,frame:$selected_frame$jscomp$5$$,"hover-shape":$APP.$cljs$core$_deref$$($measure_hover$jscomp$1$$),zoom:$zoom__$1$jscomp$5$$}):null,$show_padding_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_control$$,{frame:$first_shape$jscomp$12$$,
hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$),zoom:$zoom__$1$jscomp$5$$,"alt?":$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$25$$),"shift?":$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$46$$),"on-move-selected":$on_move_selected$jscomp$11$$,"on-context-menu":$on_menu_selected$$}):null,$show_padding_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_control$$,{frame:$first_shape$jscomp$12$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$),zoom:$zoom__$1$jscomp$5$$,
"alt?":$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$25$$),"shift?":$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$46$$),"on-move-selected":$on_move_selected$jscomp$11$$,"on-context-menu":$on_menu_selected$$}):null,$show_margin_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_control$$,{shape:$first_shape$jscomp$12$$,parent:$selected_frame$jscomp$5$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$),zoom:$zoom__$1$jscomp$5$$,"alt?":$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$25$$),
"shift?":$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$46$$)}):null,$APP.$cljs$core$truth_$$($shapes_loading_QMARK_$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_titles_STAR_$$,{objects:$objects_modified$$,selected:$selected$jscomp$212$$,zoom:$zoom__$1$jscomp$5$$,isShowArtboardNames:$show_artboard_names_QMARK_$$,onFrameEnter:$on_frame_enter$jscomp$4$$,onFrameLeave:$on_frame_leave$jscomp$4$$,onFrameSelect:$on_frame_select$jscomp$4$$,focus:$focus$jscomp$23$$}),$show_prototypes_QMARK_$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$,{flows:$APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$173$$),objects:$objects_modified$$,selected:$selected$jscomp$212$$,zoom:$zoom__$1$jscomp$5$$,onFrameEnter:$on_frame_enter$jscomp$4$$,onFrameLeave:$on_frame_leave$jscomp$4$$,onFrameSelect:$on_frame_select$jscomp$4$$}):null,$drawing_obj$$&&$APP.$app$common$types$shape$shape_QMARK_$$($drawing_obj$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$,
{shape:$drawing_obj$$,zoom:$zoom__$1$jscomp$5$$,tool:$drawing_tool$jscomp$7$$}):null,$show_grids_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$frame_grid$frame_grid_STAR_$$,{zoom:$zoom__$1$jscomp$5$$,selected:$selected$jscomp$212$$,transform:$transform$jscomp$124$$,focus:$focus$jscomp$23$$}):null,$show_pixel_grid_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$,{vbox:$vbox$jscomp$63$$,zoom:$zoom__$1$jscomp$5$$}):null,$APP.$cljs$core$truth_$$($show_snap_points_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_points_STAR_$$,{layout:$layout$jscomp$30$$,transform:$transform$jscomp$124$$,drawing:$drawing_obj$$,zoom:$zoom__$1$jscomp$5$$,pageId:$page_id$jscomp$456$$,selected:$selected$jscomp$212$$,objects:$objects_modified$$,focus:$focus$jscomp$23$$}):null,$show_snap_distance_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$snap_distances$$,{layout:$layout$jscomp$30$$,zoom:$zoom__$1$jscomp$5$$,transform:$transform$jscomp$124$$,
selected:$selected$jscomp$212$$,"selected-shapes":$selected_shapes$jscomp$36$$,"page-id":$page_id$jscomp$456$$}):null,$APP.$cljs$core$truth_$$($tooltip$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$,{zoom:$zoom__$1$jscomp$5$$,tooltip:$tooltip$jscomp$2$$}):null,$APP.$cljs$core$truth_$$($show_selrect_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$selection_rect_STAR_$$,{data:$selrect$jscomp$95$$,zoom:$zoom__$1$jscomp$5$$}):
null,$APP.$cljs$core$truth_$$($show_presence_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$presence$active_cursors$$,{"page-id":$page_id$jscomp$456$$}):null,$hide_ui_QMARK_$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers$$,{zoom:$zoom__$1$jscomp$5$$,"zoom-inverse":$zoom_inverse$jscomp$9$$,vbox:$vbox$jscomp$63$$,"selected-shapes":$selected_shapes$jscomp$36$$,"offset-x":$offset_x$jscomp$17$$,"offset-y":$offset_y$jscomp$18$$,"show-rulers?":$show_rulers_QMARK_$jscomp$1$$}),
$show_rulers_QMARK_$jscomp$1$$&&$show_grids_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$viewport_guides_STAR_$$,{zoom:$zoom__$1$jscomp$5$$,vbox:$vbox$jscomp$63$$,guides:$guides$jscomp$11$$,hoverFrame:$guide_frame$$,disabledGuides:$disabled_guides_QMARK_$$,modifiers:$wasm_modifiers$jscomp$2$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3060$layout_drop_zones$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_drop_zones$$,
{"selected-shapes":$selected_shapes$jscomp$36$$,objects:$base_objects$jscomp$4$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$5$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3059$layout_content_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_content_bounds$$,{"selected-shapes":$selected_shapes$jscomp$36$$,objects:$base_objects$jscomp$4$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),
zoom:$zoom__$1$jscomp$5$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3055$layout_lines$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_layout_lines$$,{"selected-shapes":$selected_shapes$jscomp$36$$,objects:$base_objects$jscomp$4$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$5$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3061$parent_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_parent_bounds$$,
{"selected-shapes":$selected_shapes$jscomp$36$$,objects:$base_objects$jscomp$4$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$5$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3053$grid_layout$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_grid_layout$$,{"selected-shapes":$selected_shapes$jscomp$36$$,objects:$base_objects$jscomp$4$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),
zoom:$zoom__$1$jscomp$5$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3069$text_outline$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_text_wasm_position_data$$,{"selected-shapes":$selected_shapes$jscomp$36$$,objects:$base_objects$jscomp$4$$,zoom:$zoom__$1$jscomp$5$$}):null,$show_selection_handlers_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-handlers",clipPath:"url(#clip-handlers)",children:[$text_editing_QMARK_$jscomp$3$$?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$1$$)?
$path_editing_QMARK_$jscomp$3$$:$editing_shape__$1$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,{shape:$editing_shape__$1$jscomp$1$$,state:$edit_path_state$jscomp$2$$,zoom:$zoom__$1$jscomp$5$$}):$APP.$cljs$core$truth_$$($selected_shapes$jscomp$36$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$handlers_STAR_$$,{selected:$selected$jscomp$212$$,shapes:$selected_shapes$jscomp$36$$,zoom:$zoom__$1$jscomp$5$$,disabled:$APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$)?
$drawing_tool$jscomp$7$$:$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$5$$)}):null,$show_prototypes_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interactions_STAR_$$,{selected:$selected$jscomp$212$$,pageId:$page_id$jscomp$456$$,zoom:$zoom__$1$jscomp$5$$,objects:$objects_modified$$,currentTransform:$transform$jscomp$124$$,isHoverDisabled:$hover_disabled_QMARK_$jscomp$1$$}):null]}):null,$show_gradient_handlers_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handlers_STAR_$$,
{id:$APP.$cljs$core$first$$($selected$jscomp$212$$),zoom:$zoom__$1$jscomp$5$$}):null,$APP.$cljs$core$truth_$$($show_add_variant_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$button_add_STAR_$$,{shape:$first_shape$jscomp$12$$,zoom:$zoom__$1$jscomp$5$$,onClick:$add_variant$$}):null,(0,$APP.$rumext$v2$jsx$$)("g",{className:"grid-layout-editor",clipPath:"url(#clip-handlers)",children:$APP.$cljs$core$truth_$$($show_grid_editor_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$editor$$,
{zoom:$zoom__$1$jscomp$5$$,objects:$objects_modified$$,shape:function(){var $or__5025__auto__$jscomp$1369$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects_modified$$,$edition$jscomp$19$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1369$$)?$or__5025__auto__$jscomp$1369$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects_modified$$,$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$))}(),"view-only":$APP.$cljs$core$not$$($show_grid_editor_QMARK_$$)}):null}),
$show_scrollbar_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("g",{className:"scrollbar-wrapper",clipPath:"url(#clip-handlers)",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$scroll_bars$viewport_scrollbars_STAR_$$,{objects:$base_objects$jscomp$4$$,zoom:$zoom__$1$jscomp$5$$,vbox:$vbox$jscomp$63$$,bottomPadding:$APP.$cljs$core$truth_$$($palete_size$$)?$palete_size$$+8:null})}):null]})],id:"viewport-controls",viewBox:$app$main$ui$workspace$viewport$utils$format_viewbox$$($vbox$jscomp$63$$),
onPointerUp:$on_pointer_up$jscomp$8$$,onContextMenu:$on_context_menu$jscomp$29$$,onDrop:$on_drop$jscomp$19$$,preserveAspectRatio:"xMidYMid meet",style:{touchAction:"none"},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",onDragOver:$on_drag_over$jscomp$2$$,onDragEnd:$on_drag_end$jscomp$2$$,onClick:$on_click$jscomp$60$$,onPointerMove:$on_pointer_move$jscomp$16$$,ref:$on_viewport_ref$$,onPointerDown:$on_pointer_down$jscomp$22$$,onPointerLeave:$on_pointer_leave$jscomp$18$$,onPointerEnter:$on_pointer_enter$jscomp$18$$},
["viewport",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$456$$)].join(""))]})};
$app$main$ui$workspace$viewport$apply_modifiers_to_selected$$=function($selected$jscomp$213$$,$objects$jscomp$835$$,$text_modifiers$jscomp$4$$,$modifiers$jscomp$138$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects__$1$jscomp$41$$,$id$jscomp$1057$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($objects__$1$jscomp$41$$,$id$jscomp$1057$$,function($G__81056__$1_shape$jscomp$1108$$){$G__81056__$1_shape$jscomp$1108$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__81056__$1_shape$jscomp$1108$$)&&
$APP.$cljs$core$contains_QMARK_$$($text_modifiers$jscomp$4$$,$id$jscomp$1057$$)?$APP.$app$main$data$workspace$modifiers$apply_text_modifier$$($G__81056__$1_shape$jscomp$1108$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_modifiers$jscomp$4$$,$id$jscomp$1057$$)):$G__81056__$1_shape$jscomp$1108$$;return $APP.$cljs$core$contains_QMARK_$$($modifiers$jscomp$138$$,$id$jscomp$1057$$)?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__81056__$1_shape$jscomp$1108$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$138$$,$id$jscomp$1057$$),$APP.$cljs$cst$1810$modifiers$$)):$G__81056__$1_shape$jscomp$1108$$})},$objects$jscomp$835$$,$selected$jscomp$213$$)};
$app$main$ui$workspace$viewport$viewport_classic_STAR_$$=function($props_81064$$){var $palete_size$jscomp$1$$=$props_81064$$.paleteSize,$selected$jscomp$214$$=$props_81064$$.selected,$layout$jscomp$31$$=$props_81064$$.layout,$file$jscomp$183$$=$props_81064$$.file,$page$jscomp$174$$=$props_81064$$.page,$wglobal$jscomp$2$$=$props_81064$$.wglobal,$map__81071$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_local$$),$map__81071__$1$$=$APP.$cljs$core$__destructure_map$$($map__81071$$),$edition$jscomp$20$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$2199$edition$$),$selrect$jscomp$96$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$1605$selrect$$),$zoom_inverse$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$3577$zoom_inverse$$),$panning$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$4452$panning$$),$zoom$jscomp$169$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$2196$zoom$$),$transform$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$1289$transform$$),$vbox$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$1925$vbox$$),$edit_path$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$1923$edit_path$$),$highlighted$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,
$APP.$cljs$cst$4295$highlighted$$),$vport$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81071__$1$$,$APP.$cljs$cst$2203$vport$$),$map__81072__$1$$=$APP.$cljs$core$__destructure_map$$($wglobal$jscomp$2$$),$options_mode$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81072__$1$$,$APP.$cljs$cst$2200$options_mode$$),$tooltip$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81072__$1$$,$APP.$cljs$cst$2946$tooltip$$),$preview_id$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81072__$1$$,$APP.$cljs$cst$5020$preview_id$$),$show_distances_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81072__$1$$,$APP.$cljs$cst$4493$show_distances_QMARK_$$),$picking_color_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81072__$1$$,$APP.$cljs$cst$4130$picking_color_QMARK_$$),$vbox_SINGLEQUOTE_$jscomp$1$$=$rumext$v2$use_debounce$$($vbox$jscomp$64$$),$permissions$jscomp$38$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$),$read_only_QMARK_$jscomp$37$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$drawing$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$focus$jscomp$24$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$file_id$jscomp$436$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$183$$,$APP.$cljs$cst$266$id$$),$vern$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$183$$,
$APP.$cljs$cst$2577$vern$$),$page_id$jscomp$457$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$174$$,$APP.$cljs$cst$266$id$$),$objects$jscomp$836$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$174$$,$APP.$cljs$cst$1631$objects$$),$background$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$174$$,$APP.$cljs$cst$2058$background$$,"#E8E9EA"),$base_objects$jscomp$5$$=$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$836$$,
$focus$jscomp$24$$),$modifiers$jscomp$139$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$text_modifiers$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_text_modifier$$),$objects_modified$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$5$$),$APP.$rumext$v2$adapt$$($text_modifiers$jscomp$5$$),$APP.$rumext$v2$adapt$$($modifiers$jscomp$139$$)],function(){return $app$main$ui$workspace$viewport$apply_modifiers_to_selected$$($selected$jscomp$214$$,
$base_objects$jscomp$5$$,$text_modifiers$jscomp$5$$,$modifiers$jscomp$139$$)}),$selected_shapes$jscomp$37$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects_modified$jscomp$1$$)),$selected$jscomp$214$$)),$alt_QMARK_$jscomp$26$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$shift_QMARK_$jscomp$47$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$mod_QMARK_$jscomp$15$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$space_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$z_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$cursor$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$5915$pointer_inner$$)}),$hover_ids$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$hover$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$measure_hover$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_disabled_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$hover_top_frame_id$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame_hover$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$active_frames$jscomp$4$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$vec__81073$$=$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$(),$viewport_ref$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81073$$,0,null),$on_viewport_ref$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81073$$,1,null),$canvas_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(null),$disable_paste_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),
$in_viewport_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$move_stream$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$guide_frame$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$9$$)),$APP.$rumext$v2$adapt$$($base_objects$jscomp$5$$)],function(){var $parent_id$jscomp$110$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$root_frame_QMARK_$$,
$base_objects$jscomp$5$$),$APP.$cljs$core$_deref$$($hover_ids$jscomp$9$$));return $parent_id$jscomp$110$$!=null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$parent_id$jscomp$110$$):null}),$zoom__$1$jscomp$6$$=$APP.$app$common$math$finite$$($zoom$jscomp$169$$,1),$drawing_tool$jscomp$8$$=$APP.$cljs$cst$2197$tool$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$6$$),$drawing_obj$jscomp$1$$=$APP.$cljs$cst$2198$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$6$$),
$selected_frames$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1607$frame_id$$),$selected_shapes$jscomp$37$$),$selected_frame$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frames$jscomp$3$$),1)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$APP.$cljs$core$first$$($selected_frames$jscomp$3$$)):
null,$edit_path_state$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path$jscomp$1$$,$edition$jscomp$20$$),$edit_path_mode$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_state$jscomp$3$$,$APP.$cljs$cst$4223$edit_mode$$),$path_editing_QMARK_$jscomp$4$$=$edit_path_state$jscomp$3$$!=null,$path_drawing_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_mode$jscomp$1$$,$APP.$cljs$cst$4224$draw$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing_obj$jscomp$1$$,$APP.$cljs$cst$139$type$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2052$curve$$,$drawing_tool$jscomp$8$$),$editing_shape$jscomp$2$$=$APP.$cljs$core$truth_$$($edition$jscomp$20$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$edition$jscomp$20$$):null,$editing_shape__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_shape$jscomp$2$$),
$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($base_objects$jscomp$5$$)],function(){return $path_editing_QMARK_$jscomp$4$$?$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($editing_shape$jscomp$2$$,$base_objects$jscomp$5$$):$editing_shape$jscomp$2$$}),$create_comment_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3436$comments$$,$drawing_tool$jscomp$8$$),$text_editing_QMARK_$jscomp$4$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$2$$),
$grid_editing_QMARK_$jscomp$3$$=$APP.$cljs$core$truth_$$($edition$jscomp$20$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$edition$jscomp$20$$):$edition$jscomp$20$$,$mode_inspect_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$4$$,$APP.$cljs$cst$2672$inspect$$),$on_click$jscomp$61$$=$app$main$ui$workspace$viewport$actions$on_click$$($hover$jscomp$14$$,$selected$jscomp$214$$,$edition$jscomp$20$$,
$path_drawing_QMARK_$jscomp$1$$,$drawing_tool$jscomp$8$$,$space_QMARK_$jscomp$6$$,$selrect$jscomp$96$$,$z_QMARK_$jscomp$6$$),$on_context_menu$jscomp$30$$=$app$main$ui$workspace$viewport$actions$on_context_menu$$($hover$jscomp$14$$,$hover_ids$jscomp$9$$,$read_only_QMARK_$jscomp$37$$),$on_double_click$jscomp$8$$=$app$main$ui$workspace$viewport$actions$on_double_click$$($hover$jscomp$14$$,$hover_ids$jscomp$9$$,$selected$jscomp$214$$,$hover_top_frame_id$jscomp$8$$,$path_drawing_QMARK_$jscomp$1$$,$base_objects$jscomp$5$$,
$edition$jscomp$20$$,$drawing_tool$jscomp$8$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$37$$),$comp_inst_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_drag_enter$jscomp$9$$=$app$main$ui$workspace$viewport$actions$on_drag_enter$$($comp_inst_ref$jscomp$4$$),$on_drag_over$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($move_stream$jscomp$5$$),$on_drag_end$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($comp_inst_ref$jscomp$4$$),$on_drop$jscomp$20$$=$app$main$ui$workspace$viewport$actions$on_drop$$($file$jscomp$183$$,
$comp_inst_ref$jscomp$4$$),$on_pointer_down$jscomp$23$$=$app$main$ui$workspace$viewport$actions$on_pointer_down$$($APP.$cljs$core$_deref$$($hover$jscomp$14$$),$selected$jscomp$214$$,$edition$jscomp$20$$,$drawing_tool$jscomp$8$$,$text_editing_QMARK_$jscomp$4$$,$path_editing_QMARK_$jscomp$4$$,$grid_editing_QMARK_$jscomp$3$$,$path_drawing_QMARK_$jscomp$1$$,$create_comment_QMARK_$jscomp$2$$,$space_QMARK_$jscomp$6$$,$panning$jscomp$3$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$37$$),$on_pointer_up$jscomp$9$$=
$app$main$ui$workspace$viewport$actions$on_pointer_up$$($disable_paste_ref$jscomp$4$$),$on_pointer_enter$jscomp$19$$=$app$main$ui$workspace$viewport$actions$on_pointer_enter$$($in_viewport_ref$jscomp$5$$),$on_pointer_leave$jscomp$19$$=$app$main$ui$workspace$viewport$actions$on_pointer_leave$$($in_viewport_ref$jscomp$5$$),$on_pointer_move$jscomp$17$$=$app$main$ui$workspace$viewport$actions$on_pointer_move$$($move_stream$jscomp$5$$),$on_move_selected$jscomp$12$$=$app$main$ui$workspace$viewport$actions$on_move_selected$$($hover$jscomp$14$$,
$hover_ids$jscomp$9$$,$selected$jscomp$214$$,$space_QMARK_$jscomp$6$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$37$$),$on_menu_selected$jscomp$1$$=$app$main$ui$workspace$viewport$actions$on_menu_selected$$($hover$jscomp$14$$,$hover_ids$jscomp$9$$,$selected$jscomp$214$$,$read_only_QMARK_$jscomp$37$$),$on_frame_enter$jscomp$5$$=$app$main$ui$workspace$viewport$actions$on_frame_enter$$($frame_hover$jscomp$4$$),$on_frame_leave$jscomp$5$$=$app$main$ui$workspace$viewport$actions$on_frame_leave$$($frame_hover$jscomp$4$$),
$on_frame_select$jscomp$5$$=$app$main$ui$workspace$viewport$actions$on_frame_select$$($selected$jscomp$214$$,$read_only_QMARK_$jscomp$37$$),$disable_events_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3436$comments$$),$show_comments_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$8$$,$APP.$cljs$cst$3436$comments$$),$show_gradient_handlers_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$214$$),
1),$show_grids_QMARK_$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3725$display_guides$$),$show_frame_outline_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$125$$,$APP.$cljs$cst$1798$move$$),$show_outlines_QMARK_$jscomp$1$$=$transform$jscomp$125$$==null&&$APP.$cljs$core$not$$($edition$jscomp$20$$)&&$APP.$cljs$core$not$$($drawing_obj$jscomp$1$$)&&$APP.$cljs$core$not$$(function(){var $fexpr__81086$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2052$curve$$,null],null),null);return $fexpr__81086$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__81086$$.$cljs$core$IFn$_invoke$arity$1$($drawing_tool$jscomp$8$$):$fexpr__81086$$($drawing_tool$jscomp$8$$)}()),$show_pixel_grid_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3717$show_pixel_grid$$)&&$zoom__$1$jscomp$6$$>=8,$show_text_editor_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$2$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$2$$)):$editing_shape__$1$jscomp$2$$,$hover_grid_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$984$$=$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$)!=null;return $and__5023__auto__$jscomp$984$$?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$836$$,$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$)):
$and__5023__auto__$jscomp$984$$}(),$show_grid_editor_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$2$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$2$$):$editing_shape__$1$jscomp$2$$,$show_prototypes_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$4$$,$APP.$cljs$cst$3731$prototype$$),$show_selection_handlers_QMARK_$jscomp$1$$=$APP.$cljs$core$seq$$($selected$jscomp$214$$)&&
$APP.$cljs$core$not$$($show_text_editor_QMARK_$jscomp$1$$),$show_snap_distance_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3724$dynamic_alignment$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$125$$,$APP.$cljs$cst$1798$move$$)&&$APP.$cljs$core$seq$$($selected$jscomp$214$$),$show_snap_points_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$986$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3724$dynamic_alignment$$)||
$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3720$snap_guides$$);return $and__5023__auto__$jscomp$986$$?$APP.$cljs$core$truth_$$($drawing_obj$jscomp$1$$)?$drawing_obj$jscomp$1$$:$transform$jscomp$125$$:$and__5023__auto__$jscomp$986$$}(),$show_selrect_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($selrect$jscomp$96$$)?$APP.$cljs$core$empty_QMARK_$$($drawing$jscomp$6$$)&&!$text_editing_QMARK_$jscomp$4$$:$selrect$jscomp$96$$,$show_measures_QMARK_$jscomp$2$$=function(){var $and__5023__auto__$jscomp$988_and__5023__auto____$1$jscomp$162$$=
$APP.$cljs$core$not$$($transform$jscomp$125$$);return $and__5023__auto__$jscomp$988_and__5023__auto____$1$jscomp$162$$?($and__5023__auto__$jscomp$988_and__5023__auto____$1$jscomp$162$$=!$path_editing_QMARK_$jscomp$4$$)?$APP.$cljs$core$truth_$$($show_distances_QMARK_$jscomp$1$$)?$show_distances_QMARK_$jscomp$1$$:$mode_inspect_QMARK_$jscomp$2$$?$mode_inspect_QMARK_$jscomp$2$$:$read_only_QMARK_$jscomp$37$$:$and__5023__auto__$jscomp$988_and__5023__auto____$1$jscomp$162$$:$and__5023__auto__$jscomp$988_and__5023__auto____$1$jscomp$162$$}(),
$show_artboard_names_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3722$display_artboard_names$$),$hide_ui_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$4825$hide_ui$$),$show_rulers_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$2211$rulers$$)&&!$hide_ui_QMARK_$jscomp$1$$,$disabled_guides_QMARK_$jscomp$1$$=function(){if($APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$))return $drawing_tool$jscomp$8$$;
if($APP.$cljs$core$truth_$$($transform$jscomp$125$$))return $transform$jscomp$125$$;if($path_drawing_QMARK_$jscomp$1$$)return $path_drawing_QMARK_$jscomp$1$$;if($path_editing_QMARK_$jscomp$4$$)return $path_editing_QMARK_$jscomp$4$$;var $or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$=$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$6$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$))return $or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$;
$or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$=$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$15$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$)?$or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31$$,$APP.$cljs$cst$3721$lock_guides$$)}(),$single_select_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$37$$),
1),$first_shape$jscomp$13$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$37$$),$show_add_variant_QMARK_$jscomp$1$$=function(){if($single_select_QMARK_$jscomp$1$$){var $or__5025__auto__$jscomp$1373$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($first_shape$jscomp$13$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1373$$)?$or__5025__auto__$jscomp$1373$$:$APP.$app$common$types$component$is_variant_QMARK_$$($first_shape$jscomp$13$$)}return $single_select_QMARK_$jscomp$1$$}(),
$show_padding_QMARK_$jscomp$1$$=$transform$jscomp$125$$==null&&$single_select_QMARK_$jscomp$1$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$),$APP.$cljs$cst$1606$frame$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$),$APP.$cljs$cst$1660$flex$$)&&$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$)===
0,$show_margin_QMARK_$jscomp$1$$=$transform$jscomp$125$$==null&&$single_select_QMARK_$jscomp$1$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$6$$),$APP.$cljs$cst$1660$flex$$)&&$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$)===0,$selecting_first_level_frame_QMARK_$jscomp$1$$=$single_select_QMARK_$jscomp$1$$&&$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$),
$offset_x$jscomp$18$$=$selecting_first_level_frame_QMARK_$jscomp$1$$?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$):$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$6$$),$offset_y$jscomp$19$$=$selecting_first_level_frame_QMARK_$jscomp$1$$?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$):$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$6$$),$rule_area_size$jscomp$2$$=22/$zoom__$1$jscomp$6$$,
$add_variant$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($first_shape$jscomp$13$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$)))});$app$main$ui$workspace$viewport$hooks$setup_dom_events$$($zoom__$1$jscomp$6$$,$disable_paste_ref$jscomp$4$$,
$in_viewport_ref$jscomp$5$$,$read_only_QMARK_$jscomp$37$$,$drawing_tool$jscomp$8$$,$path_drawing_QMARK_$jscomp$1$$);$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$($vport$jscomp$15$$,$viewport_ref$jscomp$4$$);$app$main$ui$workspace$viewport$hooks$setup_cursor$$($cursor$jscomp$14$$,$alt_QMARK_$jscomp$26$$,$mod_QMARK_$jscomp$15$$,$space_QMARK_$jscomp$6$$,$panning$jscomp$3$$,$drawing_tool$jscomp$8$$,$path_drawing_QMARK_$jscomp$1$$,$path_editing_QMARK_$jscomp$4$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$37$$);
$app$main$ui$workspace$viewport$hooks$setup_keyboard$$($alt_QMARK_$jscomp$26$$,$mod_QMARK_$jscomp$15$$,$space_QMARK_$jscomp$6$$,$z_QMARK_$jscomp$6$$,$shift_QMARK_$jscomp$47$$);$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$($page_id$jscomp$457$$,$move_stream$jscomp$5$$,$base_objects$jscomp$5$$,$selected$jscomp$214$$,$mod_QMARK_$jscomp$15$$,$hover$jscomp$14$$,$measure_hover$jscomp$2$$,$hover_ids$jscomp$9$$,$hover_top_frame_id$jscomp$8$$,$APP.$cljs$core$_deref$$($hover_disabled_QMARK_$jscomp$2$$),
$focus$jscomp$24$$,$zoom__$1$jscomp$6$$,$show_measures_QMARK_$jscomp$2$$,$read_only_QMARK_$jscomp$37$$,$transform$jscomp$125$$);$app$main$ui$workspace$viewport$hooks$setup_viewport_modifiers$$($modifiers$jscomp$139$$,$base_objects$jscomp$5$$);$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$($path_editing_QMARK_$jscomp$4$$,$path_drawing_QMARK_$jscomp$1$$,$text_editing_QMARK_$jscomp$4$$,$grid_editing_QMARK_$jscomp$3$$);$app$main$ui$workspace$viewport$hooks$setup_active_frames$$($base_objects$jscomp$5$$,
$hover_ids$jscomp$9$$,$selected$jscomp$214$$,$active_frames$jscomp$4$$,$zoom__$1$jscomp$6$$,$transform$jscomp$125$$,$vbox$jscomp$64$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--zoom":$zoom__$1$jscomp$6$$},"data-testid":"viewport",className:"main_ui_workspace_viewport__viewport",children:[$preview_id$jscomp$1$$!=null?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$37$$)?$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$38$$):
$read_only_QMARK_$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$,{}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$hide_ui_QMARK_$jscomp$1$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$top_toolbar_STAR_$$,{layout:$layout$jscomp$31$$}),$path_editing_QMARK_$jscomp$4$$&&$single_select_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$,{shape:$editing_shape__$1$jscomp$2$$,
editPathState:$edit_path_state$jscomp$3$$,layout:$layout$jscomp$31$$}):null,$grid_editing_QMARK_$jscomp$3$$&&$single_select_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$,{shape:$editing_shape__$1$jscomp$2$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport__viewport-overlays",children:[(0,$APP.$rumext$v2$jsx$$)("svg",{style:{top:0,left:0,position:"fixed",width:"100%",height:"100%",opacity:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3076$html_text$$)?
null:0},children:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:0,y:0,width:"100%",height:"100%",children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3076$html_text$$)?null:"none",opacity:.6},children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$991$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$38$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$991$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$37$$):
$and__5023__auto__$jscomp$991$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_texts$$,{"page-id":$page_id$jscomp$457$$,objects:$objects$jscomp$836$$,modifiers:$modifiers$jscomp$139$$,edition:$edition$jscomp$20$$},"viewport-texts-"+($page_id$jscomp$457$$??"")+"-"+($vern$jscomp$5$$??"")):null})})}),$show_comments_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comments_layer_STAR_$$,{vbox:$vbox$jscomp$64$$,pageId:$page_id$jscomp$457$$,
fileId:$file_id$jscomp$436$$,vport:$vport$jscomp$15$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($picking_color_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay$$,{vport:$vport$jscomp$15$$,vbox:$vbox$jscomp$64$$,layout:$layout$jscomp$31$$,"viewport-ref":$viewport_ref$jscomp$4$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("svg",{"xmlns:penpot":"https://penpot.app/xmlns",width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$15$$,
0),xmlns:"http://www.w3.org/2000/svg",height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$15$$,0),className:"main_ui_workspace_viewport__render-shapes",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsxs$$)("linearGradient",{id:"frame-placeholder-gradient",children:[(0,$APP.$rumext$v2$jsx$$)("animateTransform",{attributeName:"gradientTransform",type:"translate",from:"-1 0",to:"1 0",dur:"2s",repeatCount:"indefinite"}),(0,$APP.$rumext$v2$jsx$$)("stop",
{offset:"0%",stopColor:["color-mix(in srgb-linear, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$14$$)," 90%, #777)"].join(""),stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"50%",stopColor:["color-mix(in srgb-linear, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$14$$)," 80%, #777)"].join(""),stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"100%",stopColor:["color-mix(in srgb-linear, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$14$$),
" 90%, #777)"].join(""),stopOpacity:1})]})}),$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3072$show_export_metadata$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$export$0$export_page$$,{page:$page$jscomp$174$$}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$64$$,0),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$64$$,0),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$64$$,
0),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$64$$,0),fill:$background$jscomp$14$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_vbox$$),{value:$vbox_SINGLEQUOTE_$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),{value:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3072$show_export_metadata$$),children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$shapes$root_shape$$,
{objects:$base_objects$jscomp$5$$,"active-frames":$APP.$cljs$core$_deref$$($active_frames$jscomp$4$$),"disable-thumbnails":$preview_id$jscomp$1$$!=null},$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$457$$))})})],id:"render",viewBox:$app$main$ui$workspace$viewport$utils$format_viewbox$$($vbox$jscomp$64$$),preserveAspectRatio:"xMidYMid meet",style:{backgroundColor:$background$jscomp$14$$,pointerEvents:"none"},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none"},"viewport-svg-"+
($page_id$jscomp$457$$??"")+"-"+($vern$jscomp$5$$??"")),(0,$APP.$rumext$v2$jsxs$$)("svg",{onDoubleClick:$on_double_click$jscomp$8$$,onDragEnter:$on_drag_enter$jscomp$9$$,xmlns:"http://www.w3.org/2000/svg",className:"viewport-controls "+(""+($APP.$cljs$core$_deref$$($cursor$jscomp$14$$)??"")+(($APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$)?" drawing":null)??"")+" main_ui_workspace_viewport__viewport-controls"),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",
{id:"clip-handlers",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)+$rule_area_size$jscomp$2$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)+$rule_area_size$jscomp$2$$,width:function(){var $y__5111__auto__$jscomp$193$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)-$rule_area_size$jscomp$2$$;return 0>$y__5111__auto__$jscomp$193$$?0:$y__5111__auto__$jscomp$193$$}(),
height:function(){var $y__5111__auto__$jscomp$194$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)-$rule_area_size$jscomp$2$$;return 0>$y__5111__auto__$jscomp$194$$?0:$y__5111__auto__$jscomp$194$$}()})})}),(0,$APP.$rumext$v2$jsxs$$)("g",{style:{pointerEvents:$disable_events_QMARK_$jscomp$1$$?"none":"auto"},children:[$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$jscomp$1$$)?$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"text-editor/v2")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v2_editor$text_editor$$,{shape:$editing_shape__$1$jscomp$2$$,"canvas-ref":$canvas_ref$jscomp$7$$,modifiers:$modifiers$jscomp$139$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$editor$text_editor_svg$$,{shape:$editing_shape__$1$jscomp$2$$,modifiers:$modifiers$jscomp$139$$}):null,$show_frame_outline_QMARK_$jscomp$1$$?function(){var $outlined_frame_id$jscomp$2$$=$APP.$cljs$core$last$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$214$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81062_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$p1__81062_SHARP_$$))},$APP.$cljs$core$_deref$$($hover_ids$jscomp$9$$)))),$outlined_frame$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$836$$,$outlined_frame_id$jscomp$2$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines$$,{objects:$base_objects$jscomp$5$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$outlined_frame_id$jscomp$2$$]),zoom:$zoom__$1$jscomp$6$$,modifiers:$modifiers$jscomp$139$$}),$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($outlined_frame$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"ghost-outline",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines$$,
{objects:$base_objects$jscomp$5$$,selected:$selected$jscomp$214$$,zoom:$zoom__$1$jscomp$6$$})}):null]})}():null,$show_outlines_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines$$,{objects:$base_objects$jscomp$5$$,selected:$selected$jscomp$214$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($hover$jscomp$14$$)),$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$)]),
highlighted:$highlighted$jscomp$8$$,edition:$edition$jscomp$20$$,zoom:$zoom__$1$jscomp$6$$,modifiers:$modifiers$jscomp$139$$}):null,$APP.$cljs$core$truth_$$($show_selection_handlers_QMARK_$jscomp$1$$?$selected_shapes$jscomp$37$$:$show_selection_handlers_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$area_STAR_$$,{shapes:$selected_shapes$jscomp$37$$,zoom:$zoom__$1$jscomp$6$$,edition:$edition$jscomp$20$$,disabled:function(){if($APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$))return $drawing_tool$jscomp$8$$;
if($APP.$cljs$core$truth_$$($edition$jscomp$20$$))return $edition$jscomp$20$$;var $or__5025__auto____$2$jscomp$40$$=$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$2$jscomp$40$$)?$or__5025__auto____$2$jscomp$40$$:$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$15$$)}(),onMoveSelected:$on_move_selected$jscomp$12$$,onContextMenu:$on_menu_selected$jscomp$1$$}):null,$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$,
{shape:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$edition$jscomp$20$$),zoom:$zoom__$1$jscomp$6$$,modifiers:$modifiers$jscomp$139$$}):null,$APP.$cljs$core$truth_$$($show_measures_QMARK_$jscomp$2$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement$$,{bounds:$vbox$jscomp$64$$,"selected-shapes":$selected_shapes$jscomp$37$$,frame:$selected_frame$jscomp$6$$,"hover-shape":$APP.$cljs$core$_deref$$($measure_hover$jscomp$2$$),zoom:$zoom__$1$jscomp$6$$}):
null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$993_and__5023__auto____$1$jscomp$163$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$125$$,$APP.$cljs$cst$1798$move$$);return $and__5023__auto__$jscomp$993_and__5023__auto____$1$jscomp$163$$?($and__5023__auto__$jscomp$993_and__5023__auto____$1$jscomp$163$$=$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$26$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$993_and__5023__auto____$1$jscomp$163$$)?$APP.$cljs$core$seq$$($selected_shapes$jscomp$37$$):
$and__5023__auto__$jscomp$993_and__5023__auto____$1$jscomp$163$$):$and__5023__auto__$jscomp$993_and__5023__auto____$1$jscomp$163$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement$$,{bounds:$vbox$jscomp$64$$,"selected-shapes":$selected_shapes$jscomp$37$$,frame:$selected_frame$jscomp$6$$,"hover-shape":$APP.$cljs$core$_deref$$($hover$jscomp$14$$),zoom:$zoom__$1$jscomp$6$$}):null,function(){var $state_var$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(typeof $app$$!==
"undefined"&&typeof $app$main$$!=="undefined"&&typeof $app$main$store$$!=="undefined"&&typeof $APP.$app$main$store$state$$!=="undefined"?new $APP.$cljs$core$Var$$(function(){return $APP.$app$main$store$state$$},$APP.$cljs$core$with_meta$$($cljs$cst$5932$app_DOT_main_DOT_store_SLASH_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$269$cljs_DOT_analyzer_SLASH_no_resolve$$,!0],null)),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,
$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1479$arglists$$,$APP.$cljs$cst$1480$doc$$,$APP.$cljs$cst$171$test$$],[$cljs$cst$5933$app_DOT_main_DOT_store$$,$APP.$cljs$cst$44$state$$,"app/main/store.cljs",15,1,71,71,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$($APP.$app$main$store$state$$)?$APP.$app$main$store$state$$.$cljs$lang$test$:null])):null),$duplicated_info$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($state_var$$)),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3612$duplicated$$],null));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$994_and__5023__auto____$1$jscomp$164$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$125$$,$APP.$cljs$cst$1798$move$$);return $and__5023__auto__$jscomp$994_and__5023__auto____$1$jscomp$164$$?($and__5023__auto__$jscomp$994_and__5023__auto____$1$jscomp$164$$=
$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$26$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$994_and__5023__auto____$1$jscomp$164$$)?$duplicated_info$$:$and__5023__auto__$jscomp$994_and__5023__auto____$1$jscomp$164$$):$and__5023__auto__$jscomp$994_and__5023__auto____$1$jscomp$164$$}())?(0,$APP.$rumext$v2$jsx$$)("g",{className:"duplicated-distance",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$distance_display$$,{from:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($duplicated_info$$,
$cljs$cst$5934$selrect_original$$),to:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($duplicated_info$$,$cljs$cst$5935$selrect_duplicated$$),zoom:$zoom__$1$jscomp$6$$,bounds:$vbox$jscomp$64$$})}):null}(),$show_padding_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_control$$,{frame:$first_shape$jscomp$13$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$),zoom:$zoom__$1$jscomp$6$$,"alt?":$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$26$$),"shift?":$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$47$$),
"on-move-selected":$on_move_selected$jscomp$12$$,"on-context-menu":$on_menu_selected$jscomp$1$$}):null,$show_padding_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_control$$,{frame:$first_shape$jscomp$13$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$),zoom:$zoom__$1$jscomp$6$$,"alt?":$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$26$$),"shift?":$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$47$$),"on-move-selected":$on_move_selected$jscomp$12$$,"on-context-menu":$on_menu_selected$jscomp$1$$}):
null,$show_margin_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_control$$,{shape:$first_shape$jscomp$13$$,parent:$selected_frame$jscomp$6$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$),zoom:$zoom__$1$jscomp$6$$,"alt?":$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$26$$),"shift?":$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$47$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_titles_STAR_$$,{objects:$base_objects$jscomp$5$$,
selected:$selected$jscomp$214$$,zoom:$zoom__$1$jscomp$6$$,isShowArtboardNames:$show_artboard_names_QMARK_$jscomp$1$$,onFrameEnter:$on_frame_enter$jscomp$5$$,onFrameLeave:$on_frame_leave$jscomp$5$$,onFrameSelect:$on_frame_select$jscomp$5$$,focus:$focus$jscomp$24$$}),$show_prototypes_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$,{flows:$APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$174$$),objects:$objects_modified$jscomp$1$$,
selected:$selected$jscomp$214$$,zoom:$zoom__$1$jscomp$6$$,onFrameEnter:$on_frame_enter$jscomp$5$$,onFrameLeave:$on_frame_leave$jscomp$5$$,onFrameSelect:$on_frame_select$jscomp$5$$}):null,$drawing_obj$jscomp$1$$&&$APP.$app$common$types$shape$shape_QMARK_$$($drawing_obj$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$,{shape:$drawing_obj$jscomp$1$$,zoom:$zoom__$1$jscomp$6$$,tool:$drawing_tool$jscomp$8$$}):null,$show_grids_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$frame_grid$frame_grid_STAR_$$,
{zoom:$zoom__$1$jscomp$6$$,selected:$selected$jscomp$214$$,transform:$transform$jscomp$125$$,focus:$focus$jscomp$24$$}):null,$show_pixel_grid_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$,{vbox:$vbox$jscomp$64$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($show_snap_points_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_points_STAR_$$,{layout:$layout$jscomp$31$$,transform:$transform$jscomp$125$$,
drawing:$drawing_obj$jscomp$1$$,zoom:$zoom__$1$jscomp$6$$,pageId:$page_id$jscomp$457$$,selected:$selected$jscomp$214$$,objects:$objects_modified$jscomp$1$$,focus:$focus$jscomp$24$$}):null,$show_snap_distance_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$snap_distances$$,{layout:$layout$jscomp$31$$,zoom:$zoom__$1$jscomp$6$$,transform:$transform$jscomp$125$$,selected:$selected$jscomp$214$$,"selected-shapes":$selected_shapes$jscomp$37$$,"page-id":$page_id$jscomp$457$$}):
null,$APP.$cljs$core$truth_$$($tooltip$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$,{zoom:$zoom__$1$jscomp$6$$,tooltip:$tooltip$jscomp$3$$}):null,$APP.$cljs$core$truth_$$($show_selrect_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$selection_rect_STAR_$$,{data:$selrect$jscomp$96$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($show_add_variant_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$button_add_STAR_$$,
{shape:$first_shape$jscomp$13$$,zoom:$zoom__$1$jscomp$6$$,onClick:$add_variant$jscomp$1$$}):null,$APP.$cljs$core$truth_$$($page_id$jscomp$457$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$presence$active_cursors$$,{"page-id":$page_id$jscomp$457$$}):null,$hide_ui_QMARK_$jscomp$1$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers$$,{zoom:$zoom__$1$jscomp$6$$,"zoom-inverse":$zoom_inverse$jscomp$10$$,vbox:$vbox$jscomp$64$$,"selected-shapes":$selected_shapes$jscomp$37$$,
"offset-x":$offset_x$jscomp$18$$,"offset-y":$offset_y$jscomp$19$$,"show-rulers?":$show_rulers_QMARK_$jscomp$2$$}),$show_rulers_QMARK_$jscomp$2$$&&$show_grids_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$viewport_guides_STAR_$$,{zoom:$zoom__$1$jscomp$6$$,vbox:$vbox$jscomp$64$$,guides:$APP.$cljs$cst$2057$guides$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$174$$),hoverFrame:$guide_frame$jscomp$1$$,disabledGuides:$disabled_guides_QMARK_$jscomp$1$$,modifiers:$modifiers$jscomp$139$$}):
null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3060$layout_drop_zones$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_drop_zones$$,{"selected-shapes":$selected_shapes$jscomp$37$$,objects:$base_objects$jscomp$5$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3059$layout_content_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_content_bounds$$,
{"selected-shapes":$selected_shapes$jscomp$37$$,objects:$base_objects$jscomp$5$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3055$layout_lines$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_layout_lines$$,{"selected-shapes":$selected_shapes$jscomp$37$$,objects:$base_objects$jscomp$5$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),
zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3061$parent_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_parent_bounds$$,{"selected-shapes":$selected_shapes$jscomp$37$$,objects:$base_objects$jscomp$5$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3053$grid_layout$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_grid_layout$$,
{"selected-shapes":$selected_shapes$jscomp$37$$,objects:$base_objects$jscomp$5$$,"hover-top-frame-id":$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$6$$}):null,$show_selection_handlers_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-handlers",clipPath:"url(#clip-handlers)",children:[$text_editing_QMARK_$jscomp$4$$?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$2$$)?$path_editing_QMARK_$jscomp$4$$:$editing_shape__$1$jscomp$2$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,{shape:$editing_shape__$1$jscomp$2$$,state:$edit_path_state$jscomp$3$$,zoom:$zoom__$1$jscomp$6$$}):$APP.$cljs$core$truth_$$($selected_shapes$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$handlers_STAR_$$,{selected:$selected$jscomp$214$$,shapes:$selected_shapes$jscomp$37$$,zoom:$zoom__$1$jscomp$6$$,disabled:$APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$)?$drawing_tool$jscomp$8$$:
$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$6$$)}):null,$show_prototypes_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interactions_STAR_$$,{selected:$selected$jscomp$214$$,pageId:$page_id$jscomp$457$$,zoom:$zoom__$1$jscomp$6$$,objects:$objects_modified$jscomp$1$$,currentTransform:$transform$jscomp$125$$,isHoverDisabled:$hover_disabled_QMARK_$jscomp$2$$}):null]}):null,$show_gradient_handlers_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handlers_STAR_$$,
{id:$APP.$cljs$core$first$$($selected$jscomp$214$$),zoom:$zoom__$1$jscomp$6$$}):null,(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid-layout-editor",clipPath:"url(#clip-handlers)",children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_grid_editor_QMARK_$jscomp$1$$)?$show_grid_editor_QMARK_$jscomp$1$$:$hover_grid_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$editor$$,{zoom:$zoom__$1$jscomp$6$$,objects:$base_objects$jscomp$5$$,modifiers:$modifiers$jscomp$139$$,
shape:function(){var $or__5025__auto__$jscomp$1377$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$edition$jscomp$20$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1377$$)?$or__5025__auto__$jscomp$1377$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$5$$,$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$))}(),"view-only":$APP.$cljs$core$not$$($show_grid_editor_QMARK_$jscomp$1$$)}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$236$$,
$frame$jscomp$98$$){$out_arr__44124__auto__$jscomp$236$$.push($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$98$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$98$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$20$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$98$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$98$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$editor$$,{zoom:$zoom__$1$jscomp$6$$,objects:$base_objects$jscomp$5$$,modifiers:$modifiers$jscomp$139$$,shape:$frame$jscomp$98$$,"view-only":!0},"viewport-frame-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$98$$)??"")):null);return $out_arr__44124__auto__$jscomp$236$$},[],$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$836$$))]}),
(0,$APP.$rumext$v2$jsx$$)("g",{className:"scrollbar-wrapper",clipPath:"url(#clip-handlers)",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$scroll_bars$viewport_scrollbars_STAR_$$,{objects:$base_objects$jscomp$5$$,zoom:$zoom__$1$jscomp$6$$,vbox:$vbox$jscomp$64$$,bottomPadding:$APP.$cljs$core$truth_$$($palete_size$jscomp$1$$)?$palete_size$jscomp$1$$+8:null})})]})],viewBox:$app$main$ui$workspace$viewport$utils$format_viewbox$$($vbox$jscomp$64$$),onPointerUp:$on_pointer_up$jscomp$9$$,
onContextMenu:$on_context_menu$jscomp$30$$,onDrop:$on_drop$jscomp$20$$,preserveAspectRatio:"xMidYMid meet",style:{touchAction:"none"},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",onDragOver:$on_drag_over$jscomp$3$$,onDragEnd:$on_drag_end$jscomp$3$$,onClick:$on_click$jscomp$61$$,onPointerMove:$on_pointer_move$jscomp$17$$,ref:$on_viewport_ref$jscomp$1$$,onPointerDown:$on_pointer_down$jscomp$23$$,onPointerLeave:$on_pointer_leave$jscomp$19$$,onPointerEnter:$on_pointer_enter$jscomp$19$$},"viewport-controls-"+
($page_id$jscomp$457$$??"")+"-"+($vern$jscomp$5$$??""))]})};
$app$main$ui$workspace$viewport$viewport_STAR_$$=function($props_81107$$){var $page$jscomp$175_page_id$jscomp$458$$=$props_81107$$.page,$vern$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81107$$.file,$APP.$cljs$cst$2577$vern$$);$page$jscomp$175_page_id$jscomp$458$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$175_page_id$jscomp$458$$,$APP.$cljs$cst$266$id$$);var $render_wasm_QMARK_$jscomp$8$$=$app$main$features$use_feature$$("render-wasm/v1");return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,
{children:$render_wasm_QMARK_$jscomp$8$$?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport_wasm$viewport_STAR_$$,$props_81107$$):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$viewport_classic_STAR_$$,$props_81107$$)},"viewport-"+($page$jscomp$175_page_id$jscomp$458$$??"")+"-"+($vern$jscomp$6$$??""))};
$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_dashboard_recent$$()]))};
$app$main$ui$workspace$webgl_unavailable_modal$webgl_unavailable_modal_STAR_$$=function(){function $handle_keydown$jscomp$5$$($event$jscomp$721$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$721$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$721$$),$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$()):null}$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key$jscomp$425$$=$APP.$goog$events$listen$$(document,
"keydown",$handle_keydown$jscomp$5$$);return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$425$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_webgl_unavailable_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_webgl_unavailable_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsxs$$)("header",{className:"main_ui_workspace_webgl_unavailable_modal__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$,className:"main_ui_workspace_webgl_unavailable_modal__modal-close-btn",icon:"close",variant:"action",size:"medium","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"title-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.title")})]}),
(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_workspace_webgl_unavailable_modal__modal-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.message")}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_workspace_webgl_unavailable_modal__modal-divider"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"p",typography:"body-medium",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.troubleshooting.before"),(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://help.penpot.app/user-guide/first-steps/troubleshooting-webgl/",target:"_blank",rel:"noopener noreferrer",className:"main_ui_workspace_webgl_unavailable_modal__link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.troubleshooting.link")}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.troubleshooting.after")]})]}),
(0,$APP.$rumext$v2$jsxs$$)("footer",{className:"main_ui_workspace_webgl_unavailable_modal__modal-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$,variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.cta-dashboard")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{to:"https://help.penpot.app/user-guide/first-steps/troubleshooting-webgl/",
target:"_blank",variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.cta-troubleshooting")})]})]})})};
$app$main$ui$workspace$workspace_content_STAR_$$=function($props_81109_wglobal$jscomp$3$$){var $layout$jscomp$32$$=$props_81109_wglobal$jscomp$3$$.layout,$file$jscomp$185$$=$props_81109_wglobal$jscomp$3$$.file,$page$jscomp$176$$=$props_81109_wglobal$jscomp$3$$.page;$props_81109_wglobal$jscomp$3$$=$props_81109_wglobal$jscomp$3$$.wglobal;var $palete_size$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected$jscomp$215$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),
$page_id$jscomp$459$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$176$$,$APP.$cljs$cst$266$id$$),$vport$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_vport$$),$map__81117__$1_options_mode$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($props_81109_wglobal$jscomp$3$$);$map__81117__$1_options_mode$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81117__$1_options_mode$jscomp$5$$,$APP.$cljs$cst$2200$options_mode$$);var $drawing$jscomp$7$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$colorpalette_QMARK_$$=$APP.$cljs$cst$3715$colorpalette$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$32$$),$textpalette_QMARK_$$=$APP.$cljs$cst$3740$textpalette$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$32$$),$hide_ui_QMARK_$jscomp$2$$=$APP.$cljs$cst$4825$hide_ui$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$32$$),$node_ref$jscomp$5_on_resize$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vport$jscomp$16$$)],
function($resize_type$jscomp$4$$,$size$jscomp$160$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($vport$jscomp$16$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$160$$,$vport$jscomp$16$$):$vport$jscomp$16$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$viewport$update_viewport_size$$($resize_type$jscomp$4$$,$size$jscomp$160$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$viewport$sync_wasm_workspace_viewport$$()])):
null}),$on_resize_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($size$jscomp$161$$){return $APP.$cljs$core$reset_BANG_$$($palete_size$jscomp$2$$,$size$jscomp$161$$)});$node_ref$jscomp$5_on_resize$jscomp$6$$=$app$main$ui$hooks$resize$use_resize_observer$$($node_ref$jscomp$5_on_resize$jscomp$6$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$hide_ui_QMARK_$jscomp$2$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$palette$palette_STAR_$$,
{layout:$layout$jscomp$32$$,onChangeSize:$on_resize_palette$$}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$node_ref$jscomp$5_on_resize$jscomp$6$$,className:"main_ui_workspace__workspace-content",children:(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_workspace__workspace-viewport",children:[$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$5936$coordinates$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$coordinates$coordinates_STAR_$$,{isColorpalette:$colorpalette_QMARK_$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3064$history_overlay$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace__history-debug-overlay",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$reinitialize_undo$$)},children:"CLEAR"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$,{})]}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$viewport_STAR_$$,{file:$file$jscomp$185$$,
page:$page$jscomp$176$$,wglobal:$props_81109_wglobal$jscomp$3$$,selected:$selected$jscomp$215$$,layout:$layout$jscomp$32$$,paleteSize:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$997$$=$APP.$cljs$core$truth_$$($colorpalette_QMARK_$$)?$colorpalette_QMARK_$$:$textpalette_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$997$$)?$APP.$cljs$core$not$$($hide_ui_QMARK_$jscomp$2$$):$and__5023__auto__$jscomp$997$$}())?$APP.$cljs$core$_deref$$($palete_size$jscomp$2$$):
null})]})},"workspace-"+($page_id$jscomp$459$$??"")),$APP.$cljs$core$truth_$$($hide_ui_QMARK_$jscomp$2$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sidebar_STAR_$$,{layout:$layout$jscomp$32$$,fileId:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$185$$,$APP.$cljs$cst$266$id$$),pageId:$page_id$jscomp$459$$,file:$file$jscomp$185$$,selected:$selected$jscomp$215$$,section:$map__81117__$1_options_mode$jscomp$5$$,drawingTool:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing$jscomp$7$$,
$APP.$cljs$cst$2197$tool$$)})]})};$app$main$ui$workspace$workspace_loader_STAR_$$=function(){return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),className:"main_ui_workspace__workspace-loader",overlay:!0,fileLoading:!0})};
$app$main$ui$workspace$make_team_ref$$=function($team_id$jscomp$146$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1221_teams$jscomp$16$$){$state$jscomp$1221_teams$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1221_teams$jscomp$16$$,$APP.$cljs$cst$2173$teams$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1221_teams$jscomp$16$$,$team_id$jscomp$146$$)},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$make_file_ref$$=function($file_id$jscomp$437$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$,$APP.$cljs$cst$1917$current_file_id$$),$file_id$jscomp$437$$)?($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$,
$APP.$cljs$cst$1916$files$$),$file$jscomp$186_files$jscomp$33_state$jscomp$1222$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$,$file_id$jscomp$437$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$,$APP.$cljs$cst$142$data$$),$cljs$cst$5937$app_DOT_main_DOT_ui_DOT_workspace_SLASH_has_data$$,$APP.$cljs$core$contains_QMARK_$$($file$jscomp$186_files$jscomp$33_state$jscomp$1222$$,
$APP.$cljs$cst$142$data$$))):null},$APP.$app$main$store$state$$,$APP.$cljs$core$_EQ_$$)};
$app$main$ui$workspace$make_page_ref$$=function($file_id$jscomp$438$$,$page_id$jscomp$460$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1223$$){var $current_page_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1223$$,$APP.$cljs$cst$1918$current_page_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_page_id$jscomp$8$$,$page_id$jscomp$460$$)?$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1223$$,
$file_id$jscomp$438$$,$page_id$jscomp$460$$):null},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$workspace_inner_STAR_$$=function($props_81134_wglobal$jscomp$4$$){var $file_id$jscomp$439$$=$props_81134_wglobal$jscomp$4$$.fileId,$layout$jscomp$33$$=$props_81134_wglobal$jscomp$4$$.layout,$file$jscomp$187$$=$props_81134_wglobal$jscomp$4$$.file,$page_id$jscomp$461$$=$props_81134_wglobal$jscomp$4$$.pageId;$props_81134_wglobal$jscomp$4$$=$props_81134_wglobal$jscomp$4$$.wglobal;var $page$jscomp$177_page_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$439$$),
$APP.$rumext$v2$adapt$$($page_id$jscomp$461$$)],function(){return $app$main$ui$workspace$make_page_ref$$($file_id$jscomp$439$$,$page_id$jscomp$461$$)});$page$jscomp$177_page_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($page$jscomp$177_page_ref$jscomp$1$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key$jscomp$426$$=$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"blur",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$workspace_focus_lost$$())});
return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$key$jscomp$426$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$439$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$461$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$initialize_page$$($file_id$jscomp$439$$,$page_id$jscomp$461$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$pages$finalize_page$$($file_id$jscomp$439$$,
$page_id$jscomp$461$$))}});return $page$jscomp$177_page_ref$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_content_STAR_$$,{file:$file$jscomp$187$$,page:$page$jscomp$177_page_ref$jscomp$1$$,wglobal:$props_81134_wglobal$jscomp$4$$,layout:$layout$jscomp$33$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_loader_STAR_$$,{})};
$APP.$app$main$ui$workspace$workspace_page_STAR_$$=function($props_81197$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$workspace_STAR_$$,$props_81197$$)};
$cljs$core$CHAR_MAP$$={"]":"_RBRACK_","'":"_SINGLEQUOTE_","\x3d":"_EQ_",'"':"_DOUBLEQUOTE_","!":"_BANG_","*":"_STAR_","%":"_PERCENT_","|":"_BAR_","~":"_TILDE_","/":"_SLASH_","\\":"_BSLASH_","-":"_","?":"_QMARK_","\x26":"_AMPERSAND_",":":"_COLON_","\x3c":"_LT_","{":"_LBRACE_","}":"_RBRACE_","[":"_LBRACK_","#":"_SHARP_","^":"_CARET_","+":"_PLUS_","@":"_CIRCA_","\x3e":"_GT_"};$cljs$core$js_reserved_arr$$="arguments abstract await boolean break byte case catch char class const continue debugger default delete do double else enum export extends final finally float for function goto if implements import in instanceof int interface let long native new package private protected public return short static super switch synchronized this throw throws transient try typeof var void volatile while with yield methods null constructor".split(" ");
$cljs$core$js_reserved$$=null;$cljs$core$NS_CACHE$$=null;$cljs$tools$reader$READ_EOF$$={};$cljs$tools$reader$READ_FINISHED$$={};$cljs$tools$reader$_STAR_read_delim_STAR_$$=!1;$cljs$tools$reader$_STAR_suppress_read_STAR_$$=!1;$cljs$tools$reader$NO_MATCH$$={};$cljs$tools$reader$arg_env$$=null;$cljs$tools$reader$gensym_env$$=null;$app$$={};$app$main$$={};$app$main$store$$={};$cljs$core$Namespace$$.prototype.$getName$=function(){return this.name};$cljs$core$Namespace$$.prototype.toString=function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.name)};
$cljs$core$Namespace$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function($_$jscomp$160$$,$other$jscomp$119$$){return $other$jscomp$119$$ instanceof $cljs$core$Namespace$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.name,$other$jscomp$119$$.name):!1};$cljs$core$Namespace$$.prototype.$cljs$core$IHash$_hash$arity$1$=function(){return $APP.$cljs$core$hash$$(this.name)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$TaggedLiteral$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$131$$,$other$jscomp$118$$){return $other$jscomp$118$$ instanceof $cljs$core$TaggedLiteral$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.tag,$other$jscomp$118$$.tag)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.form,$other$jscomp$118$$.form)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return 31*$APP.$cljs$core$hash$$(this.tag)+$APP.$cljs$core$hash$$(this.form)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this$$jscomp$133$$,$v$jscomp$78$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$v$jscomp$78$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$134$$,$v$jscomp$79$$,$not_found$jscomp$60$$){switch($v$jscomp$79$$ instanceof $APP.$cljs$core$Keyword$$?$v$jscomp$79$$.$fqn$:null){case "tag":return this.tag;case "form":return this.form;default:return $not_found$jscomp$60$$}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($o$jscomp$132$$,$writer$jscomp$59$$,$opts$jscomp$56$$){$APP.$cljs$core$_write$$($writer$jscomp$59$$,["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.tag)," "].join(""));return $APP.$cljs$core$pr_writer$$(this.form,$writer$jscomp$59$$,$opts$jscomp$56$$)};
var $app$common$files$helpers$get_root_frame$$=function $app$common$files$helpers$get_root_frame$$($objects$jscomp$33$$,$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$){$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$=$APP.$cljs$core$truth_$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$33$$,$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$))?$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$:
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$33$$,$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$),$APP.$cljs$cst$1607$frame_id$$);$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$33$$,$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$);if($APP.$app$common$files$helpers$root_QMARK_$$($G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$)||
$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$==null)return null;if($APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$))return $G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$;$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$);return $app$common$files$helpers$get_root_frame$$.$cljs$core$IFn$_invoke$arity$2$?
$app$common$files$helpers$get_root_frame$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$33$$,$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$):$app$common$files$helpers$get_root_frame$$($objects$jscomp$33$$,$G__46787_frame$jscomp$4_frame_id$jscomp$1_shape_id$jscomp$8$$)},$malli$error$_push_in$$=function $malli$error$_push_in$$($a$jscomp$261$$,$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$,$G__35270_first__35263_p__35260$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$){var $JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$=
$APP.$cljs$core$seq$$($G__35270_first__35263_p__35260$$);$G__35270_first__35263_p__35260$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$);var $seq__35262__$1$$=$APP.$cljs$core$next$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$),$v_SINGLEQUOTE_$jscomp$2$$=$malli$error$_get$$($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$,$G__35270_first__35263_p__35260$$);
$JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$=$APP.$cljs$core$truth_$$($a$jscomp$261$$)?$a$jscomp$261$$:$APP.$cljs$core$sequential_QMARK_$$($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$)?$APP.$cljs$core$PersistentVector$EMPTY$$:$APP.$cljs$core$record_QMARK_$$($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$)?$APP.$cljs$core$PersistentArrayMap$EMPTY$$:$APP.$cljs$core$empty$$($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__35270_first__35263_p__35260$$)?$APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)):$G__35270_first__35263_p__35260$$)?$a$jscomp$261$$:$APP.$cljs$core$truth_$$($G__35270_first__35263_p__35260$$)?($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$=$malli$error$_get$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,
$G__35270_first__35263_p__35260$$),$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$=$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$?$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$,$v_SINGLEQUOTE_$jscomp$2$$,$seq__35262__$1$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$):$malli$error$_push_in$$($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$,
$v_SINGLEQUOTE_$jscomp$2$$,$seq__35262__$1$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$),$APP.$cljs$core$int_QMARK_$$($G__35270_first__35263_p__35260$$)&&$APP.$cljs$core$sequential_QMARK_$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)&&$G__35270_first__35263_p__35260$$>$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)&&($G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$=
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35270_first__35263_p__35260$$-$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$),null),$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$),
$JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$=$JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$==null||$APP.$cljs$core$seq_QMARK_$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)?$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$),
$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$)),$JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$==null||$APP.$cljs$core$associative_QMARK_$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,$G__35270_first__35263_p__35260$$,
$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$):$APP.$cljs$core$set_QMARK_$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$):$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$list$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vec$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$),
$G__35270_first__35263_p__35260$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$))):$APP.$cljs$core$map_QMARK_$$($a$jscomp$261$$)?($G__35270_first__35263_p__35260$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$887$malli_SLASH_error$$],null),$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$?$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,
$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$,$G__35270_first__35263_p__35260$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$):$malli$error$_push_in$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,$G__35226$jscomp$inline_14799_G__35264$jscomp$inline_13147_v$jscomp$216_y$jscomp$inline_14798$$,$G__35270_first__35263_p__35260$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$)):$APP.$cljs$core$truth_$$($APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$)))?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$,$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$):$APP.$cljs$core$vector_QMARK_$$($APP.$cljs$core$not_empty$$($JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$))?$JSCompiler_temp$jscomp$14741_a_SINGLEQUOTE__seq__35262_x_SINGLEQUOTE_$jscomp$inline_14584$$:$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$10956_e$jscomp$175$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$,!0],null))},$app$common$types$token$update_token_value_references$$=function $app$common$types$token$update_token_value_references$$($value$jscomp$430$$,$old_name$$,$new_name$$){return typeof $value$jscomp$430$$==="string"?$APP.$cuerdas$core$replace$$($value$jscomp$430$$,$APP.$cljs$core$re_pattern$$(["\\{",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($old_name$$,".","\\.")),"\\}"].join("")),["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($new_name$$),"}"].join("")):$APP.$cljs$core$map_QMARK_$$($value$jscomp$430$$)?$APP.$app$common$data$update_vals$$($value$jscomp$430$$,function($p1__49068_SHARP_$$){return $app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$($p1__49068_SHARP_$$,
$old_name$$,$new_name$$):$app$common$types$token$update_token_value_references$$($p1__49068_SHARP_$$,$old_name$$,$new_name$$)}):$APP.$cljs$core$sequential_QMARK_$$($value$jscomp$430$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49069_SHARP_$$){return $app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$($p1__49069_SHARP_$$,$old_name$$,$new_name$$):$app$common$types$token$update_token_value_references$$($p1__49069_SHARP_$$,
$old_name$$,$new_name$$)},$value$jscomp$430$$):$value$jscomp$430$$},$app$common$path_names$build_tree_node$$=function $app$common$path_names$build_tree_node$$($segment_name$$,$remaining_segments$jscomp$1$$,$separator$jscomp$10$$,$is_leaf_QMARK__parent_path$jscomp$1$$,$depth$jscomp$12$$){var $current_path$$=$APP.$cljs$core$truth_$$($is_leaf_QMARK__parent_path$jscomp$1$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($is_leaf_QMARK__parent_path$jscomp$1$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($segment_name$$)].join(""):
$segment_name$$,$leaf_segment$$=($is_leaf_QMARK__parent_path$jscomp$1$$=$APP.$cljs$core$seq$$($remaining_segments$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$(function($remaining_segment_name_segment$jscomp$41$$){$remaining_segment_name_segment$jscomp$41$$=$APP.$cljs$core$first$$($APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($remaining_segment_name_segment$jscomp$41$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,
$separator$jscomp$10$$])));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($segment_name$$,$remaining_segment_name_segment$jscomp$41$$)},$remaining_segments$jscomp$1$$))?$APP.$cljs$core$first$$($remaining_segments$jscomp$1$$):null;return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$725$name$$,$segment_name$$,$APP.$cljs$cst$296$path$$,$current_path$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$12$$,$APP.$cljs$cst$1999$leaf$$,$leaf_segment$$,$APP.$cljs$cst$342$children$$,
$is_leaf_QMARK__parent_path$jscomp$1$$?null:function(){var $grouped_elements$$=$app$common$path_names$sort_and_group_segments$$($remaining_segments$jscomp$1$$,$separator$jscomp$10$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49128_remaining_child_segments$$){var $child_segment_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49128_remaining_child_segments$$,0,null);$p__49128_remaining_child_segments$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49128_remaining_child_segments$$,
1,null);var $G__49138$$=$depth$jscomp$12$$+1;return $app$common$path_names$build_tree_node$$.$cljs$core$IFn$_invoke$arity$5$?$app$common$path_names$build_tree_node$$.$cljs$core$IFn$_invoke$arity$5$($child_segment_name$$,$p__49128_remaining_child_segments$$,$separator$jscomp$10$$,$current_path$$,$G__49138$$):$app$common$path_names$build_tree_node$$($child_segment_name$$,$p__49128_remaining_child_segments$$,$separator$jscomp$10$$,$current_path$$,$G__49138$$)},$grouped_elements$$)}()],null)},$app$main$data$persistence$run_persistence_task$$=
function $app$main$data$persistence$run_persistence_task$$(){typeof $app$main$data$persistence$run_persistence_task_55357$$==="undefined"&&($app$main$data$persistence$run_persistence_task_55357$$=function($meta55358$$){this.$meta55358$=$meta55358$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$run_persistence_task_55357$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$run_persistence_task_55357$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3161$app_DOT_main_DOT_data_DOT_persistence_SLASH_run_persistence_task$$},$app$main$data$persistence$run_persistence_task_55357$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55359$$,$meta55358__$1$$){return new $app$main$data$persistence$run_persistence_task_55357$$($meta55358__$1$$)},$app$main$data$persistence$run_persistence_task_55357$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55358$},$app$main$data$persistence$run_persistence_task_55357$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$run_persistence_task_55357$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1658_queue$jscomp$1_stoper_s$$,$state$jscomp$191$$,$stream$jscomp$28$$){$_$jscomp$1658_queue$jscomp$1_stoper_s$$=$APP.$cljs$cst$1484$queue$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2178$persistence$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$191$$));var $temp__5823__auto__$jscomp$156$$=$APP.$cljs$core$peek$$($_$jscomp$1658_queue$jscomp$1_stoper_s$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$156$$)?($_$jscomp$1658_queue$jscomp$1_stoper_s$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3161$app_DOT_main_DOT_data_DOT_persistence_SLASH_run_persistence_task$$),$stream$jscomp$28$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3158$app_DOT_main_DOT_data_DOT_persistence_SLASH_error$$),
$stream$jscomp$28$$)),$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"run-persistence-task"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3146$commit_id$$,""+($temp__5823__auto__$jscomp$156$$??"")],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1),$APP.$beicon$v2$core$take_until$$($_$jscomp$1658_queue$jscomp$1_stoper_s$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$persist_commit$$($temp__5823__auto__$jscomp$156$$)),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$discard_commit$$($temp__5823__auto__$jscomp$156$$),
$app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$persistence$run_persistence_task$$())},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__55356_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$156$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55356_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3160$app_DOT_main_DOT_data_DOT_persistence_SLASH_commit_persisted$$),$stream$jscomp$28$$)))))))):(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$update_status$$($APP.$cljs$cst$3151$saved$$))});return new $app$main$data$persistence$run_persistence_task_55357$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$JSCompiler_prototypeAlias$$=$cljs$tools$reader$impl$utils$ReaderConditional$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$$,$k__5324__auto__$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$$,$k24311$$,$else__5326__auto__$$){switch($k24311$$ instanceof $APP.$cljs$core$Keyword$$?$k24311$$.$fqn$:null){case "splicing?":return this.$splicing_QMARK_$;case "form":return this.form;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k24311$$,$else__5326__auto__$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$$,$f__5344__auto__$$,$init__5345__auto__$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$$,$p__24327_v__5348__auto__$$){var $k__5347__auto__$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__24327_v__5348__auto__$$,0,null);$p__24327_v__5348__auto__$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__24327_v__5348__auto__$$,
1,null);return $f__5344__auto__$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$$,$k__5347__auto__$$,$p__24327_v__5348__auto__$$):$f__5344__auto__$$($ret__5346__auto__$$,$k__5347__auto__$$,$p__24327_v__5348__auto__$$)},$init__5345__auto__$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$$,$writer__5339__auto__$$,$opts__5340__auto__$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$$,function($keyval__5342__auto__$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$$,$keyval__5342__auto__$$)},"#cljs.tools.reader.impl.utils.ReaderConditional{",", ","}",$opts__5340__auto__$$,
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$178$splicing_QMARK_$$,this.$splicing_QMARK_$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$179$form$$,this.form],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$178$splicing_QMARK_$$,$APP.$cljs$cst$179$form$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,this.form,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$=this.$__hash$;return $h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$!=null?$h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$:this.$__hash$=$h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$=-209062840^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this24312$$,$other24313$$){return $other24313$$!=null&&this.constructor===$other24313$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$splicing_QMARK_$,$other24313$$.$splicing_QMARK_$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.form,$other24313$$.form)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other24313$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$$,$k__5334__auto__$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$178$splicing_QMARK_$$,null,$APP.$cljs$cst$179$form$$,null],null),null),$k__5334__auto__$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$$):new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,this.form,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$$,$k24311$jscomp$1$$){switch($k24311$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k24311$jscomp$1$$.$fqn$:null){case "splicing?":case "form":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k24311$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$$,$k__5332__auto__$$,$G__24310$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$178$splicing_QMARK_$$,$k__5332__auto__$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$178$splicing_QMARK_$$,$k__5332__auto__$$))?new $cljs$tools$reader$impl$utils$ReaderConditional$$($G__24310$jscomp$1$$,
this.form,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$179$form$$,$k__5332__auto__$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$179$form$$,$k__5332__auto__$$))?new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,$G__24310$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,
this.form,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$$,$G__24310$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$178$splicing_QMARK_$$,this.$splicing_QMARK_$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$179$form$$,this.form,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$$,$G__24310$jscomp$2$$){return new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,this.form,$G__24310$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$$,$entry__5329__auto__$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$819$$,$writer$jscomp$60$$,$opts$jscomp$57$$){$APP.$cljs$core$_write$$($writer$jscomp$60$$,["#?",$APP.$cljs$core$truth_$$(this.$splicing_QMARK_$)?"@":null].join(""));return $APP.$cljs$core$pr_writer$$(this.form,$writer$jscomp$60$$,$opts$jscomp$57$$)};
var $app$main$data$workspace$texts$update_text_modifier$$=function $app$main$data$workspace$texts$update_text_modifier$$($id$jscomp$627$$,$props$jscomp$196$$){var $cur_event$jscomp$6$$=Symbol();typeof $app$main$data$workspace$texts$update_text_modifier_70295$$==="undefined"&&($app$main$data$workspace$texts$update_text_modifier_70295$$=function($id$jscomp$628$$,$props$jscomp$197$$,$cur_event$jscomp$7$$,$meta70296$$){this.id=$id$jscomp$628$$;this.props=$props$jscomp$197$$;this.$cur_event$=$cur_event$jscomp$7$$;
this.$meta70296$=$meta70296$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4026$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier$$},$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70297$$,$meta70296__$1$$){return new $app$main$data$workspace$texts$update_text_modifier_70295$$(this.id,this.props,this.$cur_event$,$meta70296__$1$$)},$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70296$},$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($G__70299__$jscomp$2182$$,$state$jscomp$581$$){$G__70299__$jscomp$2182$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$581$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2238$workspace_text_modifier$$,this.id],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),
this.props),$APP.$cljs$cst$4025$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id);return $APP.$cljs$cst$4027$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$581$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70299__$jscomp$2182$$,
$APP.$cljs$cst$4027$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$,this.$cur_event$):$G__70299__$jscomp$2182$$},$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_modifier_70295$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2183_stopper$jscomp$18$$,$state$jscomp$582$$,$stream$jscomp$61$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4027$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$582$$),
this.$cur_event$)?($_$jscomp$2183_stopper$jscomp$18$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3895$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),$stream$jscomp$61$$),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2183_stopper$jscomp$18$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$commit_update_text_modifier$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(50,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4026$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier$$),$stream$jscomp$61$$))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$update_text_modifier$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$texts$update_text_modifier$$.$cljs$core$IFn$_invoke$arity$2$(this.id,this.props):$app$main$data$workspace$texts$update_text_modifier$$(this.id,
this.props))),(0,$APP.$beicon$v2$core$of$$)(function($p1__70294_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70294_SHARP_$$,$APP.$cljs$cst$4027$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4025$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$]))}))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$texts$update_text_modifier_70295$$($id$jscomp$627$$,
$props$jscomp$196$$,$cur_event$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$worker$ask_buffered_BANG_$$=function $app$main$worker$ask_buffered_BANG_$$($var_args$jscomp$1146$$){switch(arguments.length){case 1:return $app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($message$jscomp$77$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$77$$,null):$APP.$beicon$v2$core$empty$$()};
$app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($message$jscomp$78$$,$transfer$jscomp$11$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$78$$,$transfer$jscomp$11$$):$APP.$beicon$v2$core$empty$$()};$app$main$worker$ask_buffered_BANG_$$.$cljs$lang$maxFixedArity$=2;
var $app$common$types$tokens_lib$get_tokens_of_unknown_type$$=function $app$common$types$tokens_lib$get_tokens_of_unknown_type$$($decoded_json$jscomp$7$$,$json_format$jscomp$1_p__50089$$){var $map__50090__$1$$=$APP.$cljs$core$__destructure_map$$($json_format$jscomp$1_p__50089$$);$json_format$jscomp$1_p__50089$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50090__$1$$,$APP.$cljs$cst$2135$json_format$$,$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$($decoded_json$jscomp$7$$));
var $parent_path$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50090__$1$$,$APP.$cljs$cst$2117$parent_path$$,""),$process_token_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50090__$1$$,$APP.$cljs$cst$2136$process_token_type$$,$APP.$cljs$core$identity$$),$type_key$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($json_format$jscomp$1_p__50089$$,$APP.$cljs$cst$2132$json_format_SLASH_dtcg$$)?"$type":"type";return $APP.$cljs$core$reduce_kv$$(function($unknown_tokens$$,
$k$jscomp$603_nested_unknown_tokens$$,$v$jscomp$538$$){var $child_path$jscomp$2$$=$APP.$cljs$core$empty_QMARK_$$($parent_path$jscomp$5$$)?$APP.$cljs$core$name$$($k$jscomp$603_nested_unknown_tokens$$):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($parent_path$jscomp$5$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$603_nested_unknown_tokens$$)].join("");if($APP.$cljs$core$map_QMARK_$$($v$jscomp$538$$)&&!$APP.$cljs$core$contains_QMARK_$$($v$jscomp$538$$,$type_key$$))return $k$jscomp$603_nested_unknown_tokens$$=
function(){var $G__50092$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__50090__$1$$,$APP.$cljs$cst$2117$parent_path$$,$child_path$jscomp$2$$);return $app$common$types$tokens_lib$get_tokens_of_unknown_type$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$tokens_lib$get_tokens_of_unknown_type$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$538$$,$G__50092$$):$app$common$types$tokens_lib$get_tokens_of_unknown_type$$($v$jscomp$538$$,$G__50092$$)}(),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$unknown_tokens$$,
$k$jscomp$603_nested_unknown_tokens$$]));var $token_type_str$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$538$$,$type_key$$);return function(){var $G__50093$$=$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($token_type_str$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($token_type_str$$);return $process_token_type$$.$cljs$core$IFn$_invoke$arity$1$?
$process_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__50093$$):$process_token_type$$($G__50093$$)}()==null&&$token_type_str$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($unknown_tokens$$,$child_path$jscomp$2$$,$token_type_str$$):$unknown_tokens$$},null,$decoded_json$jscomp$7$$)},$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$=function $app$common$logic$libraries$generate_sync_shape_inverse_recursive$$($changes$jscomp$121$$,$container$jscomp$52$$,$shape_inst$jscomp$7$$,
$component$jscomp$68$$,$library$jscomp$21$$,$file$jscomp$55$$,$libraries$jscomp$51$$,$shape_main$jscomp$7$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$,$initial_root_QMARK_$jscomp$3$$){function $check_local$$($change$jscomp$23$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$23$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$23$$,
$APP.$cljs$cst$3540$local_change_QMARK_$$,!0):$change$jscomp$23$$}function $moved$jscomp$1$$($changes__$2$jscomp$18$$,$G__66584_child_inst$jscomp$7$$,$child_main$jscomp$7$$){var $G__66583$$=$APP.$app$common$data$index_of$$($children_main$jscomp$1$$,$child_main$jscomp$7$$);$G__66584_child_inst$jscomp$7$$=$APP.$app$common$data$index_of$$($children_inst$jscomp$1$$,$G__66584_child_inst$jscomp$7$$);return $APP.$app$common$logic$libraries$move_shape$$.$cljs$core$IFn$_invoke$arity$6$?$APP.$app$common$logic$libraries$move_shape$$.$cljs$core$IFn$_invoke$arity$6$($changes__$2$jscomp$18$$,
$child_main$jscomp$7$$,$G__66583$$,$G__66584_child_inst$jscomp$7$$,$component_container$jscomp$2$$,!1):$APP.$app$common$logic$libraries$move_shape$$($changes__$2$jscomp$18$$,$child_main$jscomp$7$$,$G__66583$$,$G__66584_child_inst$jscomp$7$$,$component_container$jscomp$2$$,!1)}function $swapped$jscomp$1$$($changes__$2$jscomp$17$$,$child_inst$jscomp$6$$,$child_main$jscomp$6$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$6$$),
$container$jscomp$52$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Match slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3536$child_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$6$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$6$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3538$child_main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$6$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$6$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $changes__$2$jscomp$17$$}function $both$jscomp$1$$($changes__$2$jscomp$16$$,$child_inst$jscomp$5$$,$child_main$jscomp$5$$){return $app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$?$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$($changes__$2$jscomp$16$$,
$container$jscomp$52$$,$child_inst$jscomp$5$$,$component$jscomp$68$$,$library$jscomp$21$$,$file$jscomp$55$$,$libraries$jscomp$51$$,$child_main$jscomp$5$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$,$initial_root_QMARK_$jscomp$3$$):$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$($changes__$2$jscomp$16$$,$container$jscomp$52$$,$child_inst$jscomp$5$$,$component$jscomp$68$$,$library$jscomp$21$$,$file$jscomp$55$$,$libraries$jscomp$51$$,$child_main$jscomp$5$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$,
$initial_root_QMARK_$jscomp$3$$)}function $only_main$jscomp$1$$($changes__$2$jscomp$15$$,$child_main$jscomp$4$$){return $APP.$app$common$logic$libraries$remove_shape$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$remove_shape$$.$cljs$core$IFn$_invoke$arity$4$($changes__$2$jscomp$15$$,$child_main$jscomp$4$$,$component_container$jscomp$2$$,!1):$APP.$app$common$logic$libraries$remove_shape$$($changes__$2$jscomp$15$$,$child_main$jscomp$4$$,$component_container$jscomp$2$$,!1)}function $only_inst$jscomp$1$$($changes__$2$jscomp$14$$,
$child_inst$jscomp$4$$){var $G__66563$$=$APP.$app$common$data$index_of$$($children_inst$jscomp$1$$,$child_inst$jscomp$4$$);return $app$common$logic$libraries$add_shape_to_main$$.$cljs$core$IFn$_invoke$arity$8$?$app$common$logic$libraries$add_shape_to_main$$.$cljs$core$IFn$_invoke$arity$8$($changes__$2$jscomp$14$$,$child_inst$jscomp$4$$,$G__66563$$,$component$jscomp$68$$,$component_container$jscomp$2$$,$container$jscomp$52$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$):$app$common$logic$libraries$add_shape_to_main$$($changes__$2$jscomp$14$$,
$child_inst$jscomp$4$$,$G__66563$$,$component$jscomp$68$$,$component_container$jscomp$2$$,$container$jscomp$52$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$)}$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$),$container$jscomp$52$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync shape inverse recursive"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$))],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1625$component$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$68$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);if($shape_main$jscomp$7$$==null)return $changes$jscomp$121$$;var $component_container$jscomp$2$$=$APP.$app$common$types$file$get_component_container$$($library$jscomp$21$$,$component$jscomp$68$$),$set_remote_synced_QMARK_$jscomp$1$$=$APP.$cljs$core$not$$($initial_root_QMARK_$jscomp$3$$),
$changes__$1$jscomp$28_changes__$2$jscomp$13$$=function(){var $G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$=$APP.$app$common$logic$libraries$update_attrs$$.$cljs$core$IFn$_invoke$arity$7$?$APP.$app$common$logic$libraries$update_attrs$$.$cljs$core$IFn$_invoke$arity$7$($changes$jscomp$121$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$root_main$jscomp$3$$,$root_inst$jscomp$3$$,$component_container$jscomp$2$$,!1):$APP.$app$common$logic$libraries$update_attrs$$($changes$jscomp$121$$,
$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$root_main$jscomp$3$$,$root_inst$jscomp$3$$,$component_container$jscomp$2$$,!1);var $G__66550$jscomp$inline_13315_G__66556$jscomp$inline_13314$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3535$reset_touched_QMARK_$$,!0],null);$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$=$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$?$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,
$shape_inst$jscomp$7$$,$shape_main$jscomp$7$$,$container$jscomp$52$$,$G__66550$jscomp$inline_13315_G__66556$jscomp$inline_13314$$):$APP.$app$common$logic$libraries$change_touched$$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_inst$jscomp$7$$,$shape_main$jscomp$7$$,$container$jscomp$52$$,$G__66550$jscomp$inline_13315_G__66556$jscomp$inline_13314$$);$G__66550$jscomp$inline_13315_G__66556$jscomp$inline_13314$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3539$copy_touched_QMARK_$$,!0],null);$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$=$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$?$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,
$G__66550$jscomp$inline_13315_G__66556$jscomp$inline_13314$$):$APP.$app$common$logic$libraries$change_touched$$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$G__66550$jscomp$inline_13315_G__66556$jscomp$inline_13314$$);$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$7$$)?
$app$common$logic$libraries$update_flex_child_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$logic$libraries$update_flex_child_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$app$common$logic$libraries$update_flex_child_main_attrs$$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,
$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$;$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$7$$)?$app$common$logic$libraries$update_grid_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$?
$app$common$logic$libraries$update_grid_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$app$common$logic$libraries$update_grid_main_attrs$$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,
$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$;$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$=$APP.$cljs$core$truth_$$($initial_root_QMARK_$jscomp$3$$)?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,
$shape_inst$jscomp$7$$,$container$jscomp$52$$,null):$APP.$app$common$logic$libraries$change_remote_synced$$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_inst$jscomp$7$$,$container$jscomp$52$$,null):$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$;return $set_remote_synced_QMARK_$jscomp$1$$?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_inst$jscomp$7$$,$container$jscomp$52$$,!0):$APP.$app$common$logic$libraries$change_remote_synced$$($G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$,$shape_inst$jscomp$7$$,$container$jscomp$52$$,!0):$G__66545__$1_G__66545__$2_G__66545__$3_G__66545__$4_G__66546$jscomp$inline_13312_G__66552$jscomp$inline_13313$$}(),
$children_inst$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66521_SHARP_$$){return $APP.$app$common$types$container$get_shape$$($container$jscomp$52$$,$p1__66521_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$)),$children_main$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66522_SHARP_$$){return $APP.$app$common$types$container$get_shape$$($component_container$jscomp$2$$,$p1__66522_SHARP_$$)},
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$7$$));$changes__$1$jscomp$28_changes__$2$jscomp$13$$=$APP.$app$common$logic$libraries$compare_children$$.$cljs$core$IFn$_invoke$arity$15$?$APP.$app$common$logic$libraries$compare_children$$.$cljs$core$IFn$_invoke$arity$15$($changes__$1$jscomp$28_changes__$2$jscomp$13$$,$shape_inst$jscomp$7$$,$children_inst$jscomp$1$$,$children_main$jscomp$1$$,$container$jscomp$52$$,$component_container$jscomp$2$$,$file$jscomp$55$$,$libraries$jscomp$51$$,
$only_inst$jscomp$1$$,$only_main$jscomp$1$$,$both$jscomp$1$$,$swapped$jscomp$1$$,$moved$jscomp$1$$,!0,!0):$APP.$app$common$logic$libraries$compare_children$$($changes__$1$jscomp$28_changes__$2$jscomp$13$$,$shape_inst$jscomp$7$$,$children_inst$jscomp$1$$,$children_main$jscomp$1$$,$container$jscomp$52$$,$component_container$jscomp$2$$,$file$jscomp$55$$,$libraries$jscomp$51$$,$only_inst$jscomp$1$$,$only_main$jscomp$1$$,$both$jscomp$1$$,$swapped$jscomp$1$$,$moved$jscomp$1$$,!0,!0);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes__$1$jscomp$28_changes__$2$jscomp$13$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$mapv$$,$check_local$$)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$,$check_local$$))},$app$main$data$workspace$libraries$duplicate_component$$=function $app$main$data$workspace$libraries$duplicate_component$$($var_args$jscomp$1272$$){switch(arguments.length){case 2:return $app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],
arguments[1]);case 3:return $app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$2$=function($library_id$jscomp$31$$,$component_id$jscomp$49$$){return $app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$3$($library_id$jscomp$31$$,$component_id$jscomp$49$$,$APP.$app$common$uuid$next$$())};
$app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$3$=function($library_id$jscomp$32$$,$component_id$jscomp$50$$,$new_component_id$jscomp$4$$){typeof $app$main$data$workspace$libraries$duplicate_component_69559$$==="undefined"&&($app$main$data$workspace$libraries$duplicate_component_69559$$=function($library_id$jscomp$33$$,$component_id$jscomp$51$$,$new_component_id$jscomp$5$$,$meta69560$$){this.$library_id$=$library_id$jscomp$33$$;this.$component_id$=$component_id$jscomp$51$$;
this.$new_component_id$=$new_component_id$jscomp$5$$;this.$meta69560$=$meta69560$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$duplicate_component_69559$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_component_69559$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3925$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_component$$},
$app$main$data$workspace$libraries$duplicate_component_69559$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69561$$,$meta69560__$1$$){return new $app$main$data$workspace$libraries$duplicate_component_69559$$(this.$library_id$,this.$component_id$,this.$new_component_id$,$meta69560__$1$$)},$app$main$data$workspace$libraries$duplicate_component_69559$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69560$},$app$main$data$workspace$libraries$duplicate_component_69559$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_component_69559$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$,$changes$jscomp$209_state$jscomp$505_vec__69562$$){$it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$=$APP.$app$main$data$helpers$lookup_libraries$$($changes$jscomp$209_state$jscomp$505_vec__69562$$);$it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$,this.$library_id$);$changes$jscomp$209_state$jscomp$505_vec__69562$$=$app$common$logic$libraries$generate_duplicate_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,null),$it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$,this.$component_id$,this.$new_component_id$);$it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$209_state$jscomp$505_vec__69562$$,0,null);$changes$jscomp$209_state$jscomp$505_vec__69562$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$209_state$jscomp$505_vec__69562$$,1,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$193_libraries$jscomp$69_library$jscomp$23_main_instance$jscomp$1$$)],null)],null)),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$209_state$jscomp$505_vec__69562$$))});return new $app$main$data$workspace$libraries$duplicate_component_69559$$($library_id$jscomp$32$$,$component_id$jscomp$50$$,$new_component_id$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$duplicate_component$$.$cljs$lang$maxFixedArity$=3;
var $app$main$data$workspace$texts$update_position_data$$=function $app$main$data$workspace$texts$update_position_data$$($id$jscomp$633$$,$position_data$jscomp$10$$){var $cur_event$jscomp$8$$=Symbol();typeof $app$main$data$workspace$texts$update_position_data_70327$$==="undefined"&&($app$main$data$workspace$texts$update_position_data_70327$$=function($id$jscomp$634$$,$position_data$jscomp$11$$,$cur_event$jscomp$9$$,$meta70328$$){this.id=$id$jscomp$634$$;this.$position_data$=$position_data$jscomp$11$$;
this.$cur_event$=$cur_event$jscomp$9$$;this.$meta70328$=$meta70328$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$},
$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70329$$,$meta70328__$1$$){return new $app$main$data$workspace$texts$update_position_data_70327$$(this.id,this.$position_data$,this.$cur_event$,$meta70328__$1$$)},$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70328$},$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2189_state__$1$jscomp$27$$,$state$jscomp$587$$){$_$jscomp$2189_state__$1$jscomp$27$$=$APP.$cljs$core$assoc_in$$($state$jscomp$587$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2238$workspace_text_modifier$$,this.id,$APP.$cljs$cst$1891$position_data$$],null),this.$position_data$);
return $APP.$cljs$cst$4032$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2189_state__$1$jscomp$27$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2189_state__$1$jscomp$27$$,$APP.$cljs$cst$4032$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$,this.$cur_event$):$APP.$cljs$core$assoc_in$$($_$jscomp$2189_state__$1$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$,this.id],null),this.$position_data$)},$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_position_data_70327$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2190_stopper$jscomp$19$$,$state$jscomp$588$$,$stream$jscomp$62$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4032$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$588$$),
this.$cur_event$)?($_$jscomp$2190_stopper$jscomp$19$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3895$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),$stream$jscomp$62$$),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2190_stopper$jscomp$19$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$commit_position_data$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(50,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$),$stream$jscomp$62$$))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$update_position_data$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$texts$update_position_data$$.$cljs$core$IFn$_invoke$arity$2$(this.id,this.$position_data$):$app$main$data$workspace$texts$update_position_data$$(this.id,
this.$position_data$)))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$texts$update_position_data_70327$$($id$jscomp$633$$,$position_data$jscomp$10$$,$cur_event$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$texts$resize_text$$=function $app$main$data$workspace$texts$resize_text$$($id$jscomp$625$$,$new_width$jscomp$5$$,$new_height$jscomp$5$$){var $cur_event$jscomp$4$$=Symbol();typeof $app$main$data$workspace$texts$resize_text_70264$$==="undefined"&&
($app$main$data$workspace$texts$resize_text_70264$$=function($id$jscomp$626$$,$new_width$jscomp$6$$,$new_height$jscomp$6$$,$cur_event$jscomp$5$$,$meta70265$$){this.id=$id$jscomp$626$$;this.$new_width$=$new_width$jscomp$6$$;this.$new_height$=$new_height$jscomp$6$$;this.$cur_event$=$cur_event$jscomp$5$$;this.$meta70265$=$meta70265$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$resize_text_70264$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$resize_text_70264$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4021$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text$$},$app$main$data$workspace$texts$resize_text_70264$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70266$$,$meta70265__$1$$){return new $app$main$data$workspace$texts$resize_text_70264$$(this.id,this.$new_width$,this.$new_height$,this.$cur_event$,$meta70265__$1$$)},
$app$main$data$workspace$texts$resize_text_70264$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70265$},$app$main$data$workspace$texts$resize_text_70264$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$resize_text_70264$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__70267__$jscomp$2178$$,$state$jscomp$577$$){$G__70267__$jscomp$2178$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$577$$,
$APP.$cljs$cst$4020$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$assoc$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),this.id,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$new_width$,this.$new_height$],null));return $APP.$cljs$cst$4022$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$577$$)==
null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70267__$jscomp$2178$$,$APP.$cljs$cst$4022$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$,this.$cur_event$):$G__70267__$jscomp$2178$$},$app$main$data$workspace$texts$resize_text_70264$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$resize_text_70264$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2179_stopper$jscomp$17$$,
$state$jscomp$578$$,$stream$jscomp$60$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4022$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$578$$),this.$cur_event$)?($_$jscomp$2179_stopper$jscomp$17$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3895$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),$stream$jscomp$60$$),
$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2179_stopper$jscomp$17$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$commit_resize_text$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(50,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4021$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text$$),$stream$jscomp$60$$))))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$resize_text$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$texts$resize_text$$.$cljs$core$IFn$_invoke$arity$3$(this.id,this.$new_width$,this.$new_height$):$app$main$data$workspace$texts$resize_text$$(this.id,this.$new_width$,this.$new_height$))),(0,$APP.$beicon$v2$core$of$$)(function($p1__70263_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70263_SHARP_$$,$APP.$cljs$cst$4020$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4022$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$]))}))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$texts$resize_text_70264$$($id$jscomp$625$$,$new_width$jscomp$5$$,$new_height$jscomp$5$$,$cur_event$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69004$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69006$$,$meta69005__$1$$){return new $app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69004$$(this.handler,this.ids,this.shape,this.resize,this.$normalize_proportion_lock$,$meta69005__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69005$};$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2048$$,$state$jscomp$455$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$455$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null),$APP.$cljs$cst$1799$resize$$)};$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2049_stopper$jscomp$11$$,$state$jscomp$456$$,$resize_events_stream_stream$jscomp$47$$){var $self__$jscomp$4594$$=this;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4594$$.shape)))return $APP.$beicon$v2$core$empty$$();var $initial_position$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);$_$jscomp$2049_stopper$jscomp$11$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($resize_events_stream_stream$jscomp$47$$,
null);var $layout$jscomp$10$$=$APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$456$$),$page_id$jscomp$168$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$456$$),$focus$jscomp$12$$=$APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$456$$),$zoom$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$456$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$2196$zoom$$,1),$objects$jscomp$478$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$456$$,$page_id$jscomp$168$$),$shape_ids$jscomp$4$$=$APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$not$$,$APP.$cljs$cst$1623$blocked$$,$APP.$app$common$data$getf$$($objects$jscomp$478$$)),$self__$jscomp$4594$$.ids);if($APP.$cljs$core$empty_QMARK_$$($shape_ids$jscomp$4$$))return $APP.$beicon$v2$core$empty$$();
var $shapes$jscomp$92$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$478$$),$shape_ids$jscomp$4$$);$resize_events_stream_stream$jscomp$47$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$(function($p1__68936_SHARP_$$){return $self__$jscomp$4594$$.resize.$cljs$core$IFn$_invoke$arity$5$?$self__$jscomp$4594$$.resize.$cljs$core$IFn$_invoke$arity$5$($self__$jscomp$4594$$.shape,$initial_position$$,$layout$jscomp$10$$,$objects$jscomp$478$$,$p1__68936_SHARP_$$):
$self__$jscomp$4594$$.resize($self__$jscomp$4594$$.shape,$initial_position$$,$layout$jscomp$10$$,$objects$jscomp$478$$,$p1__68936_SHARP_$$)},$APP.$beicon$v2$core$switch_map$$(function($p__69048$$){var $point$jscomp$61$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69048$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69048$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69048$$,2,null);return $APP.$beicon$v2$core$map$$(function($p1__68935_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__69048$$,
$p1__68935_SHARP_$$)},$APP.$app$main$snap$closest_snap_point$$($page_id$jscomp$168$$,$shapes$jscomp$92$$,$objects$jscomp$478$$,$layout$jscomp$10$$,$zoom$jscomp$21$$,$focus$jscomp$12$$,$point$jscomp$61$$))},$APP.$beicon$v2$core$map$$($self__$jscomp$4594$$.$normalize_proportion_lock$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$sub$jscomp$inline_5572$$,$APP.$sub$jscomp$inline_5575$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$app$main$streams$mouse_position$$))))));
var $modifiers_stream$$=$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$456$$,"render-wasm/v1")?$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2049_stopper$jscomp$11$$,$APP.$beicon$v2$core$mapcat$$(function($modif_tree$jscomp$53_modifiers$jscomp$80$$){$modif_tree$jscomp$53_modifiers$jscomp$80$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($shape_ids$jscomp$4$$,$modif_tree$jscomp$53_modifiers$jscomp$80$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modif_tree$jscomp$53_modifiers$jscomp$80$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3821$ignore_constraints$$,$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$10$$,$APP.$cljs$cst$3716$scale_text$$)])))},$resize_events_stream_stream$jscomp$47$$)),$APP.$beicon$v2$core$map$$(function($p1__68937_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$main$data$workspace$modifiers$create_modif_tree$$($shape_ids$jscomp$4$$,$p1__68937_SHARP_$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3821$ignore_constraints$$,$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$10$$,$APP.$cljs$cst$3716$scale_text$$)]))},$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2049_stopper$jscomp$11$$,$resize_events_stream_stream$jscomp$47$$)))):$APP.$beicon$v2$core$take_until$$($_$jscomp$2049_stopper$jscomp$11$$,$APP.$beicon$v2$core$mapcat$$(function($JSCompiler_inline_result$jscomp$10980_modif_tree$jscomp$inline_13364_modifiers$jscomp$81$$){$JSCompiler_inline_result$jscomp$10980_modif_tree$jscomp$inline_13364_modifiers$jscomp$81$$=
$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($shape_ids$jscomp$4$$,$JSCompiler_inline_result$jscomp$10980_modif_tree$jscomp$inline_13364_modifiers$jscomp$81$$);var $ignore_constraints$jscomp$inline_13365$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$10$$,$APP.$cljs$cst$3716$scale_text$$);$JSCompiler_inline_result$jscomp$10980_modif_tree$jscomp$inline_13364_modifiers$jscomp$81$$=$APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_inline_result$jscomp$10980_modif_tree$jscomp$inline_13364_modifiers$jscomp$81$$,
$ignore_constraints$jscomp$inline_13365$$,!1,null);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_inline_result$jscomp$10980_modif_tree$jscomp$inline_13364_modifiers$jscomp$81$$)},$resize_events_stream_stream$jscomp$47$$));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$mapcat$$(function(){return $modifiers_stream$$},$APP.$beicon$v2$core$take_until$$($_$jscomp$2049_stopper$jscomp$11$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__68940_SHARP_$$){return $p1__68940_SHARP_$$>
10/$zoom$jscomp$21$$},$APP.$beicon$v2$core$map$$(function($p1__68939_SHARP_$$){return $APP.$app$common$geom$point$length$$($p1__68939_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__68938_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__68938_SHARP_$$,$initial_position$$)},$APP.$app$main$streams$mouse_position$$)))))),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$456$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$()):
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$app$main$data$workspace$transforms$finish_transform$$()))};
var $cljs$cst$5680$dragging$$=new $APP.$cljs$core$Keyword$$(null,"dragging","dragging",1185097613),$cljs$cst$5534$bin_char$$=new $APP.$cljs$core$Keyword$$(null,"bin-char","bin-char",-1662780697),$cljs$cst$5922$mouse_down_picker$$=new $APP.$cljs$core$Keyword$$(null,"mouse-down-picker","mouse-down-picker",-418905630),$cljs$cst$5693$set_alignment$$=new $APP.$cljs$core$Keyword$$(null,"set-alignment","set-alignment",-2128681649),$cljs$cst$5908$create_rectangle$$=new $APP.$cljs$core$Keyword$$(null,"create-rectangle",
"create-rectangle",-773298875),$cljs$cst$5907$create_artboard$$=new $APP.$cljs$core$Keyword$$(null,"create-artboard","create-artboard",-183459146),$cljs$cst$5754$localized_date_time$$=new $APP.$cljs$core$Keyword$$(null,"localized-date-time","localized-date-time",358812429),$cljs$cst$5930$webgl_unavailable$$=new $APP.$cljs$core$Keyword$$(null,"webgl-unavailable","webgl-unavailable",2080127405),$cljs$cst$5504$paren$$=new $APP.$cljs$core$Keyword$$(null,"paren","paren",-294107600),$cljs$cst$5872$width_p$$=
new $APP.$cljs$core$Keyword$$(null,"width-p","width-p",371756625),$cljs$cst$5734$focused_id_STAR_$$=new $APP.$cljs$core$Keyword$$(null,"focused-id*","focused-id*",664819594),$cljs$cst$5781$all_selected_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"all-selected?","all-selected?",998306472),$cljs$cst$5577$active_tokens$$=new $APP.$cljs$core$Keyword$$(null,"active-tokens","active-tokens",1939368755),$cljs$cst$5886$line_y2$$=new $APP.$cljs$core$Keyword$$(null,"line-y2","line-y2",1362883497),$cljs$cst$5884$line_y1$$=
new $APP.$cljs$core$Keyword$$(null,"line-y1","line-y1",-790998869),$cljs$cst$5883$line_x1$$=new $APP.$cljs$core$Keyword$$(null,"line-x1","line-x1",-1747192142),$cljs$cst$5885$line_x2$$=new $APP.$cljs$core$Keyword$$(null,"line-x2","line-x2",678649845),$cljs$cst$5630$multi_assets_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"multi-assets?","multi-assets?",-1126822393),$cljs$cst$5638$backends$$=new $APP.$cljs$core$Keyword$$(null,"backends","backends",-1041162533),$cljs$cst$5909$create_ellipse$$=new $APP.$cljs$core$Keyword$$(null,
"create-ellipse","create-ellipse",-403794363),$cljs$cst$5448$start_production$$=new $APP.$cljs$core$Keyword$$(null,"start-production","start-production",687546537),$cljs$cst$5511$reader$$=new $APP.$cljs$core$Symbol$$(null,"reader","reader",1810192380,null),$cljs$cst$5685$presets$$=new $APP.$cljs$core$Keyword$$(null,"presets","presets",-345857391),$cljs$cst$5824$zip$$=new $APP.$cljs$core$Keyword$$(null,"zip","zip",678448180),$cljs$cst$5523$DQUOTE$$=new $APP.$cljs$core$Keyword$$(null,"DQUOTE","DQUOTE",
-571169808),$cljs$cst$5647$rename_typography$$=new $APP.$cljs$core$Keyword$$(null,"rename-typography","rename-typography",-1476102726),$cljs$cst$5689$full_name$$=new $APP.$cljs$core$Keyword$$(null,"full-name","full-name",408178550),$cljs$cst$5924$inside$$=new $APP.$cljs$core$Keyword$$(null,"inside","inside",1972503011),$cljs$cst$5469$msg_cache$$=new $APP.$cljs$core$Keyword$$(null,"msg-cache","msg-cache",-733775070),$cljs$cst$5927$last_resize_direction$$=new $APP.$cljs$core$Keyword$$(null,"last-resize-direction",
"last-resize-direction",-1738384379),$cljs$cst$5657$rect_render$$=new $APP.$cljs$core$Keyword$$(null,"rect-render","rect-render",164934616),$cljs$cst$5642$is_asset_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"is-asset?","is-asset?",-448531872),$cljs$cst$5665$num_items$$=new $APP.$cljs$core$Keyword$$(null,"num-items","num-items",-887909266),$cljs$cst$5625$on_asset_click$$=new $APP.$cljs$core$Keyword$$(null,"on-asset-click","on-asset-click",1164784669),$cljs$cst$5458$string_ci$$=new $APP.$cljs$core$Keyword$$(null,
"string-ci","string-ci",374631805),$cljs$cst$5621$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_list_style$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.assets","list-style","app.main.data.workspace.assets/list-style",-1347397902),$cljs$cst$5739$layer$$=new $APP.$cljs$core$Keyword$$(null,"layer","layer",-1601820589),$cljs$cst$5849$empty_themes$$=new $APP.$cljs$core$Keyword$$(null,"empty-themes","empty-themes",-1383438187),$cljs$cst$5512$pending_forms$$=new $APP.$cljs$core$Symbol$$(null,
"pending-forms","pending-forms",-1225172071,null),$cljs$cst$5632$open_groups$$=new $APP.$cljs$core$Keyword$$(null,"open-groups","open-groups",1010222446),$cljs$cst$5820$left_sidebar$$=new $APP.$cljs$core$Keyword$$(null,"left-sidebar","left-sidebar",-1413634357),$cljs$cst$5576$applied_token$$=new $APP.$cljs$core$Keyword$$(null,"applied-token","applied-token",-1808287379),$cljs$cst$5698$easing_ease_in_out$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease-in-out","easing-ease-in-out",33260603),$cljs$cst$5934$selrect_original$$=
new $APP.$cljs$core$Keyword$$(null,"selrect-original","selrect-original",-1319150208),$cljs$cst$5686$vert$$=new $APP.$cljs$core$Keyword$$(null,"vert","vert",-360932977),$cljs$cst$5822$coce$$=new $APP.$cljs$core$Keyword$$(null,"coce","coce",-1135173234),$cljs$cst$5594$on_clear_selection$$=new $APP.$cljs$core$Keyword$$(null,"on-clear-selection","on-clear-selection",-1065562127),$cljs$cst$5656$shape_link$$=new $APP.$cljs$core$Keyword$$(null,"shape-link","shape-link",-1110484325),$cljs$cst$5530$hide_tag$$=
new $APP.$cljs$core$Keyword$$(null,"hide-tag","hide-tag",1347642501),$cljs$cst$5587$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_color_tab$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker","color-tab","app.main.ui.workspace.colorpicker/color-tab",-1957999841),$cljs$cst$5505$alt_or_ord$$=new $APP.$cljs$core$Keyword$$(null,"alt-or-ord","alt-or-ord",310249425),$cljs$cst$5470$nodes$$=new $APP.$cljs$core$Keyword$$(null,"nodes","nodes",-2099585805),$cljs$cst$5639$multiple_variants$$=
new $APP.$cljs$core$Keyword$$(null,"multiple-variants","multiple-variants",-1555709443),$cljs$cst$5664$show_search$$=new $APP.$cljs$core$Keyword$$(null,"show-search","show-search",266138187),$cljs$cst$5658$shape_list$$=new $APP.$cljs$core$Keyword$$(null,"shape-list","shape-list",-226178330),$cljs$cst$5629$force_open_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"force-open?","force-open?",514305058),$cljs$cst$5748$bassics$$=new $APP.$cljs$core$Keyword$$(null,"bassics","bassics",1660356961),$cljs$cst$5572$cljs_DOT_spec_DOT_alpha$$=
new $APP.$cljs$core$Symbol$$(null,"cljs.spec.alpha","cljs.spec.alpha",505122844,null),$cljs$cst$5782$selected_pred$$=new $APP.$cljs$core$Keyword$$(null,"selected-pred","selected-pred",-1733167808),$cljs$cst$5843$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_typography_SLASH_set_base_font_size$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.typography","set-base-font-size","app.main.data.workspace.tokens.typography/set-base-font-size",196229846),$cljs$cst$5466$next_stack$$=new $APP.$cljs$core$Keyword$$(null,
"next-stack","next-stack",-481930728),$cljs$cst$5554$optimize$$=new $APP.$cljs$core$Keyword$$(null,"optimize","optimize",-1912349448),$cljs$cst$5596$path_filter$$=new $APP.$cljs$core$Keyword$$(null,"path-filter","path-filter",352001580),$cljs$cst$5600$disable_booleans$$=new $APP.$cljs$core$Keyword$$(null,"disable-booleans","disable-booleans",1692419768),$cljs$cst$5704$option_highlighted_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"option-highlighted?","option-highlighted?",2074036831),$cljs$cst$5868$selrect_width$$=
new $APP.$cljs$core$Keyword$$(null,"selrect-width","selrect-width",-24370965),$cljs$cst$5525$CR$$=new $APP.$cljs$core$Keyword$$(null,"CR","CR",-1654295403),$cljs$cst$5539$defined_as$$=new $APP.$cljs$core$Keyword$$(null,"defined-as","defined-as",-474679152),$cljs$cst$5854$mouse_pos$$=new $APP.$cljs$core$Keyword$$(null,"mouse-pos","mouse-pos",370762057),$cljs$cst$5544$dec_val$$=new $APP.$cljs$core$Keyword$$(null,"dec-val","dec-val",-1263870894),$cljs$cst$5627$selected_full$$=new $APP.$cljs$core$Keyword$$(null,
"selected-full","selected-full",-948180416),$cljs$cst$5714$stroke_circle$$=new $APP.$cljs$core$Keyword$$(null,"stroke-circle","stroke-circle",-305167974),$cljs$cst$5427$paths$$=new $APP.$cljs$core$Keyword$$(null,"paths","paths",-1807389588),$cljs$cst$5517$LF$$=new $APP.$cljs$core$Keyword$$(null,"LF","LF",1177033158),$cljs$cst$5830$ready_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ready?","ready?",-105765697),$cljs$cst$5650$is_indirect$$=new $APP.$cljs$core$Keyword$$(null,"is-indirect","is-indirect",
-518601596),$cljs$cst$5708$absolute_position$$=new $APP.$cljs$core$Keyword$$(null,"absolute-position","absolute-position",397125855),$cljs$cst$5864$margin_num$$=new $APP.$cljs$core$Keyword$$(null,"margin-num","margin-num",-23910265),$cljs$cst$5783$allowed_shape_attributes$$=new $APP.$cljs$core$Keyword$$(null,"allowed-shape-attributes","allowed-shape-attributes",-11621484),$cljs$cst$5520$SP$$=new $APP.$cljs$core$Keyword$$(null,"SP","SP",124290284),$cljs$cst$5721$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_add_frame_grid$$=
new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","add-frame-grid","app.main.data.workspace.grid/add-frame-grid",-1083498650),$cljs$cst$5785$attribute_labels$$=new $APP.$cljs$core$Keyword$$(null,"attribute-labels","attribute-labels",-1728954592),$cljs$cst$5444$regexp$$=new $APP.$cljs$core$Keyword$$(null,"regexp","regexp",-541372782),$cljs$cst$5631$on_ungroup$$=new $APP.$cljs$core$Keyword$$(null,"on-ungroup","on-ungroup",-1285143350),$cljs$cst$5579$sidebar$$=new $APP.$cljs$core$Keyword$$(null,
"sidebar","sidebar",35784458),$cljs$cst$5786$on_update_shape_all$$=new $APP.$cljs$core$Keyword$$(null,"on-update-shape-all","on-update-shape-all",421199428),$cljs$cst$5641$on_key_down$$=new $APP.$cljs$core$Keyword$$(null,"on-key-down","on-key-down",-1374733765),$cljs$cst$5547$repetition$$=new $APP.$cljs$core$Keyword$$(null,"repetition","repetition",1938392115),$cljs$cst$5746$sub_sec$$=new $APP.$cljs$core$Keyword$$(null,"sub-sec","sub-sec",1680069611),$cljs$cst$5873$board_name$$=new $APP.$cljs$core$Keyword$$(null,
"board-name","board-name",-677515056),$cljs$cst$5468$negative_listeners$$=new $APP.$cljs$core$Keyword$$(null,"negative-listeners","negative-listeners",55241092),$cljs$cst$5899$l2_y2$$=new $APP.$cljs$core$Keyword$$(null,"l2-y2","l2-y2",1349041214),$cljs$cst$5900$l2_y1$$=new $APP.$cljs$core$Keyword$$(null,"l2-y1","l2-y1",503329823),$cljs$cst$5483$listeners$$=new $APP.$cljs$core$Keyword$$(null,"listeners","listeners",394544445),$cljs$cst$5702$centerh$$=new $APP.$cljs$core$Keyword$$(null,"centerh","centerh",
463637087),$cljs$cst$5701$centerv$$=new $APP.$cljs$core$Keyword$$(null,"centerv","centerv",-45511012),$cljs$cst$5827$is_open_STAR_$$=new $APP.$cljs$core$Keyword$$(null,"is-open*","is-open*",-1513780270),$cljs$cst$5769$matching_aliases$$=new $APP.$cljs$core$Keyword$$(null,"matching-aliases","matching-aliases",-889687368),$cljs$cst$5592$ordering$$=new $APP.$cljs$core$Keyword$$(null,"ordering","ordering",1096406705),$cljs$cst$5761$attribute$$=new $APP.$cljs$core$Keyword$$(null,"attribute","attribute",
-2074029119),$cljs$cst$5848$themes_overview$$=new $APP.$cljs$core$Keyword$$(null,"themes-overview","themes-overview",1335300928),$cljs$cst$5819$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_sitemap_collapsed$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar","sitemap-collapsed","app.main.ui.workspace.sidebar/sitemap-collapsed",-1053391535),$cljs$cst$5877$on_drag_position$$=new $APP.$cljs$core$Keyword$$(null,"on-drag-position","on-drag-position",1447756755),$cljs$cst$5552$low$$=
new $APP.$cljs$core$Keyword$$(null,"low","low",-1601362409),$cljs$cst$5451$expecting$$=new $APP.$cljs$core$Keyword$$(null,"expecting","expecting",-57706705),$cljs$cst$5651$open_menu$$=new $APP.$cljs$core$Keyword$$(null,"open-menu","open-menu",1078280881),$cljs$cst$5568$standard$$=new $APP.$cljs$core$Keyword$$(null,"standard","standard",-1769206695),$cljs$cst$5510$read_string_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"read-string*","read-string*",1046768315,null),$cljs$cst$5889$l2_x2$$=new $APP.$cljs$core$Keyword$$(null,
"l2-x2","l2-x2",-962595741),$cljs$cst$5897$l2_x1$$=new $APP.$cljs$core$Keyword$$(null,"l2-x1","l2-x1",1119885113),$cljs$cst$5633$on_group$$=new $APP.$cljs$core$Keyword$$(null,"on-group","on-group",1496733713),$cljs$cst$5711$stroke_arrow$$=new $APP.$cljs$core$Keyword$$(null,"stroke-arrow","stroke-arrow",-1800437183),$cljs$cst$5920$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_path$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","path","app.main.ui.workspace.viewport.hooks/path",
1642934739),$cljs$cst$5561$ebnf$$=new $APP.$cljs$core$Keyword$$(null,"ebnf","ebnf",31967825),$cljs$cst$5806$tokens_SLASH_remapping_confirmation$$=new $APP.$cljs$core$Keyword$$("tokens","remapping-confirmation","tokens/remapping-confirmation",-1629837152),$cljs$cst$5812$new_node_name$$=new $APP.$cljs$core$Keyword$$(null,"new-node-name","new-node-name",-842262898),$cljs$cst$5591$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker",
"colorpicker","app.main.ui.workspace.colorpicker/colorpicker",1197429294),$cljs$cst$5645$visible_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"visible?","visible?",2129863715),$cljs$cst$5462$neg$$=new $APP.$cljs$core$Keyword$$(null,"neg","neg",1800032960),$cljs$cst$5574$on_token_change$$=new $APP.$cljs$core$Keyword$$(null,"on-token-change","on-token-change",-504087325),$cljs$cst$5646$editable_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"editable?","editable?",-1805477333),$cljs$cst$5816$tokens_SLASH_export$$=
new $APP.$cljs$core$Keyword$$("tokens","export","tokens/export",-125347700),$cljs$cst$5717$stroke_squared$$=new $APP.$cljs$core$Keyword$$(null,"stroke-squared","stroke-squared",1558407903),$cljs$cst$5879$handle_lost_pointer_capture$$=new $APP.$cljs$core$Keyword$$(null,"handle-lost-pointer-capture","handle-lost-pointer-capture",-895460559),$cljs$cst$5661$search_text$$=new $APP.$cljs$core$Keyword$$(null,"search-text","search-text",1559451259),$cljs$cst$5485$results$$=new $APP.$cljs$core$Keyword$$(null,
"results","results",-1134170113),$cljs$cst$5681$maybe_dragging$$=new $APP.$cljs$core$Keyword$$(null,"maybe-dragging","maybe-dragging",-1551372643),$cljs$cst$5779$applied_refs$$=new $APP.$cljs$core$Keyword$$(null,"applied-refs","applied-refs",-956375371),$cljs$cst$5733$focused_id$$=new $APP.$cljs$core$Keyword$$(null,"focused-id","focused-id",-788291297),$cljs$cst$5836$prev_token$$=new $APP.$cljs$core$Keyword$$(null,"prev-token","prev-token",2072559436),$cljs$cst$5715$stroke_diamond$$=new $APP.$cljs$core$Keyword$$(null,
"stroke-diamond","stroke-diamond",1245033185),$cljs$cst$5619$app_DOT_main_DOT_data_DOT_workspace_DOT_history_SLASH_initialize_history$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.history","initialize-history","app.main.data.workspace.history/initialize-history",-627816697),$cljs$cst$5601$disable_flatten$$=new $APP.$cljs$core$Keyword$$(null,"disable-flatten","disable-flatten",570467597),$cljs$cst$5537$char_val$$=new $APP.$cljs$core$Keyword$$(null,"char-val","char-val",1408617933),$cljs$cst$5712$stroke_triangle$$=
new $APP.$cljs$core$Keyword$$(null,"stroke-triangle","stroke-triangle",850121987),$cljs$cst$5875$on_drag_end$$=new $APP.$cljs$core$Keyword$$(null,"on-drag-end","on-drag-end",520272671),$cljs$cst$5447$grammar$$=new $APP.$cljs$core$Keyword$$(null,"grammar","grammar",1881328267),$cljs$cst$5533$hide_tag_rule$$=new $APP.$cljs$core$Keyword$$(null,"hide-tag-rule","hide-tag-rule",150267589),$cljs$cst$5719$token_colors$$=new $APP.$cljs$core$Keyword$$(null,"token-colors","token-colors",-1209312666),$cljs$cst$5876$on_drag_delta$$=
new $APP.$cljs$core$Keyword$$(null,"on-drag-delta","on-drag-delta",-81646512),$cljs$cst$5828$toggle_dropdown$$=new $APP.$cljs$core$Keyword$$(null,"toggle-dropdown","toggle-dropdown",291806362),$cljs$cst$5865$hover_v_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hover-v?","hover-v?",284060266),$cljs$cst$5787$all_attr_labels$$=new $APP.$cljs$core$Keyword$$(null,"all-attr-labels","all-attr-labels",-1560265704),$cljs$cst$5740$ignore$$=new $APP.$cljs$core$Keyword$$(null,"ignore","ignore",-1631542033),$cljs$cst$5516$LWSP$$=
new $APP.$cljs$core$Keyword$$(null,"LWSP","LWSP",782998598),$cljs$cst$5773$old_name$$=new $APP.$cljs$core$Keyword$$(null,"old-name","old-name",1289683869),$cljs$cst$5931$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_wasm_SLASH_no_grid_hover_id$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport-wasm","no-grid-hover-id","app.main.ui.workspace.viewport-wasm/no-grid-hover-id",83390537),$cljs$cst$5553$high$$=new $APP.$cljs$core$Keyword$$(null,"high","high",2027297808),$cljs$cst$5531$whitespace$$=
new $APP.$cljs$core$Keyword$$(null,"whitespace","whitespace",-1340035483),$cljs$cst$5788$horizontal_attr_labels$$=new $APP.$cljs$core$Keyword$$(null,"horizontal-attr-labels","horizontal-attr-labels",641068751),$cljs$cst$5550$hex_val$$=new $APP.$cljs$core$Keyword$$(null,"hex-val","hex-val",1267737401),$cljs$cst$5453$enlive$$=new $APP.$cljs$core$Keyword$$(null,"enlive","enlive",1679023921),$cljs$cst$5838$indexed$$=new $APP.$cljs$core$Keyword$$(null,"indexed","indexed",390758624),$cljs$cst$5755$snapshots$$=
new $APP.$cljs$core$Keyword$$(null,"snapshots","snapshots",941363956),$cljs$cst$5850$prev_type$$=new $APP.$cljs$core$Keyword$$(null,"prev-type","prev-type",212113111),$cljs$cst$5863$hover_h_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hover-h?","hover-h?",1568370393),$cljs$cst$5532$element$$=new $APP.$cljs$core$Keyword$$(null,"element","element",1974019749),$cljs$cst$5826$color_result$$=new $APP.$cljs$core$Keyword$$(null,"color-result","color-result",-859632008),$cljs$cst$5835$token_description$$=
new $APP.$cljs$core$Keyword$$(null,"token-description","token-description",-1559156482),$cljs$cst$5936$coordinates$$=new $APP.$cljs$core$Keyword$$(null,"coordinates","coordinates",-1225332668),$cljs$cst$5575$disable_image$$=new $APP.$cljs$core$Keyword$$(null,"disable-image","disable-image",-1920778139),$cljs$cst$5615$show_menu$$=new $APP.$cljs$core$Keyword$$(null,"show-menu","show-menu",14072792),$cljs$cst$5858$resize_negate_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"resize-negate?","resize-negate?",
-1130986046),$cljs$cst$5495$lookahead$$=new $APP.$cljs$core$Keyword$$(null,"lookahead","lookahead",-400102393),$cljs$cst$5790$is_selected_inside_layout$$=new $APP.$cljs$core$Keyword$$(null,"is-selected-inside-layout","is-selected-inside-layout",-932422043),$cljs$cst$5895$l3_y2$$=new $APP.$cljs$core$Keyword$$(null,"l3-y2","l3-y2",-331288200),$cljs$cst$5894$l3_y1$$=new $APP.$cljs$core$Keyword$$(null,"l3-y1","l3-y1",-159671272),$cljs$cst$5891$l3_x2$$=new $APP.$cljs$core$Keyword$$(null,"l3-x2","l3-x2",
-949175405),$cljs$cst$5892$l3_x1$$=new $APP.$cljs$core$Keyword$$(null,"l3-x1","l3-x1",-228486922),$cljs$cst$5912$pen$$=new $APP.$cljs$core$Keyword$$(null,"pen","pen",2006675445),$cljs$cst$5501$hide_nt$$=new $APP.$cljs$core$Keyword$$(null,"hide-nt","hide-nt",-228813845),$cljs$cst$5684$clip_content$$=new $APP.$cljs$core$Keyword$$(null,"clip-content","clip-content",-1393212533),$cljs$cst$5465$node_builder$$=new $APP.$cljs$core$Keyword$$(null,"node-builder","node-builder",-1956562605),$cljs$cst$5759$locked_by$$=
new $APP.$cljs$core$Keyword$$(null,"locked-by","locked-by",-545502839),$cljs$cst$5570$cljs_DOT_spec_DOT_alpha_SLASH__STAR_runtime_asserts_STAR_$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","*runtime-asserts*","cljs.spec.alpha/*runtime-asserts*",-1060443587,null),$cljs$cst$5590$color_selection$$=new $APP.$cljs$core$Keyword$$(null,"color-selection","color-selection",923516039),$cljs$cst$5765$containers_count$$=new $APP.$cljs$core$Keyword$$(null,"containers-count","containers-count",-2090453936),
$cljs$cst$5614$nudge_option$$=new $APP.$cljs$core$Keyword$$(null,"nudge-option","nudge-option",-726591721),$cljs$cst$5764$referenced_token_name$$=new $APP.$cljs$core$Keyword$$(null,"referenced-token-name","referenced-token-name",462027675),$cljs$cst$5760$own$$=new $APP.$cljs$core$Keyword$$(null,"own","own",-286380473),$cljs$cst$5536$NUM$$=new $APP.$cljs$core$Keyword$$(null,"NUM","NUM",-218662260),$cljs$cst$5696$easing_ease_in$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease-in","easing-ease-in",
-842794625),$cljs$cst$5438$ord$$=new $APP.$cljs$core$Keyword$$(null,"ord","ord",1142548323),$cljs$cst$5847$theme_info$$=new $APP.$cljs$core$Keyword$$(null,"theme-info","theme-info",1015163604),$cljs$cst$5449$NOT$$=new $APP.$cljs$core$Keyword$$(null,"NOT","NOT",-1689245341),$cljs$cst$5459$char$$=new $APP.$cljs$core$Keyword$$(null,"char","char",-641587586),$cljs$cst$5937$app_DOT_main_DOT_ui_DOT_workspace_SLASH_has_data$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace","has-data","app.main.ui.workspace/has-data",
-1439290016),$cljs$cst$5660$operation$$=new $APP.$cljs$core$Keyword$$(null,"operation","operation",-1267664310),$cljs$cst$5720$library_colors$$=new $APP.$cljs$core$Keyword$$(null,"library-colors","library-colors",-1244860886),$cljs$cst$5653$matrix_render$$=new $APP.$cljs$core$Keyword$$(null,"matrix-render","matrix-render",278382090),$cljs$cst$5663$filters$$=new $APP.$cljs$core$Keyword$$(null,"filters","filters",974726919),$cljs$cst$5700$show_more_options$$=new $APP.$cljs$core$Keyword$$(null,"show-more-options",
"show-more-options",-1066587564),$cljs$cst$5851$on_pointer_leave$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-leave","on-pointer-leave",253985380),$cljs$cst$5861$resize_type$$=new $APP.$cljs$core$Keyword$$(null,"resize-type","resize-type",-1850768191),$cljs$cst$5551$dec_char$$=new $APP.$cljs$core$Keyword$$(null,"dec-char","dec-char",-646625154),$cljs$cst$5840$tokens_SLASH_boolean$$=new $APP.$cljs$core$Keyword$$("tokens","boolean","tokens/boolean",1104647026),$cljs$cst$5584$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$=
new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker.libraries","id","app.main.ui.workspace.colorpicker.libraries/id",-2085412349),$cljs$cst$5856$hover_value$$=new $APP.$cljs$core$Keyword$$(null,"hover-value","hover-value",1679488403),$cljs$cst$5771$total_references$$=new $APP.$cljs$core$Keyword$$(null,"total-references","total-references",1857252869),$cljs$cst$5548$rulename_left$$=new $APP.$cljs$core$Keyword$$(null,"rulename-left","rulename-left",-1824251564),$cljs$cst$5780$alias_refs$$=
new $APP.$cljs$core$Keyword$$(null,"alias-refs","alias-refs",665806110),$cljs$cst$5705$preview_complete_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"preview-complete?","preview-complete?",-1244024070),$cljs$cst$5541$hex_char$$=new $APP.$cljs$core$Keyword$$(null,"hex-char","hex-char",764443568),$cljs$cst$5687$variants_help_modal$$=new $APP.$cljs$core$Keyword$$(null,"variants-help-modal","variants-help-modal",1413487149),$cljs$cst$5486$full_results$$=new $APP.$cljs$core$Keyword$$(null,"full-results",
"full-results",-1500225407),$cljs$cst$5500$rule$$=new $APP.$cljs$core$Keyword$$(null,"rule","rule",729973257),$cljs$cst$5710$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_menus_DOT_shadow_SLASH_index$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar.options.menus.shadow","index","app.main.ui.workspace.sidebar.options.menus.shadow/index",-1426814770),$cljs$cst$5844$change_view$$=new $APP.$cljs$core$Keyword$$(null,"change-view","change-view",-1206699831),$cljs$cst$5497$Epsilon$$=
new $APP.$cljs$core$Keyword$$(null,"Epsilon","Epsilon",133418452),$cljs$cst$5626$on_rename_group$$=new $APP.$cljs$core$Keyword$$(null,"on-rename-group","on-rename-group",-1516017186),$cljs$cst$5807$remap_data$$=new $APP.$cljs$core$Keyword$$(null,"remap-data","remap-data",-916716403),$cljs$cst$5506$factor$$=new $APP.$cljs$core$Keyword$$(null,"factor","factor",-2103172748),$cljs$cst$5903$rect_width$$=new $APP.$cljs$core$Keyword$$(null,"rect-width","rect-width",1414450590),$cljs$cst$5585$delete_stop$$=
new $APP.$cljs$core$Keyword$$(null,"delete-stop","delete-stop",-1177718181),$cljs$cst$5923$outside$$=new $APP.$cljs$core$Keyword$$(null,"outside","outside",-13164995),$cljs$cst$5628$on_assets_delete$$=new $APP.$cljs$core$Keyword$$(null,"on-assets-delete","on-assets-delete",-1367349600),$cljs$cst$5709$color_row$$=new $APP.$cljs$core$Keyword$$(null,"color-row","color-row",804190296),$cljs$cst$5798$on_context_menu$$=new $APP.$cljs$core$Keyword$$(null,"on-context-menu","on-context-menu",-1330744340),
$cljs$cst$5643$navigate_to_library$$=new $APP.$cljs$core$Keyword$$(null,"navigate-to-library","navigate-to-library",184349536),$cljs$cst$5914$create_shape$$=new $APP.$cljs$core$Keyword$$(null,"create-shape","create-shape",-897512870),$cljs$cst$5904$rect_height$$=new $APP.$cljs$core$Keyword$$(null,"rect-height","rect-height",1948275951),$cljs$cst$5691$render$$=new $APP.$cljs$core$Keyword$$(null,"render","render",-1408033454),$cljs$cst$5768$total_alias_refs$$=new $APP.$cljs$core$Keyword$$(null,"total-alias-refs",
"total-alias-refs",369704626),$cljs$cst$5496$negative_lookahead$$=new $APP.$cljs$core$Keyword$$(null,"negative-lookahead","negative-lookahead",874382387),$cljs$cst$5871$display_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"display?","display?",-1189123617),$cljs$cst$5814$grouped_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"grouped?","grouped?",531080948),$cljs$cst$5668$is_open$$=new $APP.$cljs$core$Keyword$$(null,"is-open","is-open",1660707069),$cljs$cst$5928$remove_snap$$=new $APP.$cljs$core$Keyword$$(null,
"remove-snap","remove-snap",-526912307),$cljs$cst$5538$num_val$$=new $APP.$cljs$core$Keyword$$(null,"num-val","num-val",1497434478),$cljs$cst$5424$rgb$$=new $APP.$cljs$core$Keyword$$(null,"rgb","rgb",1432123467),$cljs$cst$5457$rep$$=new $APP.$cljs$core$Keyword$$(null,"rep","rep",-1226820564),$cljs$cst$5599$shortcut$$=new $APP.$cljs$core$Keyword$$(null,"shortcut","shortcut",-431647697),$cljs$cst$5526$OCTET$$=new $APP.$cljs$core$Keyword$$(null,"OCTET","OCTET",-743420682),$cljs$cst$5911$zoom_out$$=new $APP.$cljs$core$Keyword$$(null,
"zoom-out","zoom-out",681508467),$cljs$cst$5604$is_empty$$=new $APP.$cljs$core$Keyword$$(null,"is-empty","is-empty",-1040302908),$cljs$cst$5743$control$$=new $APP.$cljs$core$Keyword$$(null,"control","control",1892578036),$cljs$cst$5744$translation$$=new $APP.$cljs$core$Keyword$$(null,"translation","translation",-701621547),$cljs$cst$5846$edit_theme$$=new $APP.$cljs$core$Keyword$$(null,"edit-theme","edit-theme",1508129664),$cljs$cst$5612$v2_info_shown$$=new $APP.$cljs$core$Keyword$$(null,"v2-info-shown",
"v2-info-shown",1459219808),$cljs$cst$5598$for_design_tab_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"for-design-tab?","for-design-tab?",-900372392),$cljs$cst$5565$input_format$$=new $APP.$cljs$core$Keyword$$(null,"input-format","input-format",-422703481),$cljs$cst$5527$ALPHA$$=new $APP.$cljs$core$Keyword$$(null,"ALPHA","ALPHA",-1463859144),$cljs$cst$5929$remove_node$$=new $APP.$cljs$core$Keyword$$(null,"remove-node","remove-node",-1450759511),$cljs$cst$5595$delete_events$$=new $APP.$cljs$core$Keyword$$(null,
"delete-events","delete-events",-1125716977),$cljs$cst$5528$CHAR$$=new $APP.$cljs$core$Keyword$$(null,"CHAR","CHAR",-1280338086),$cljs$cst$5605$library_file_ids$$=new $APP.$cljs$core$Keyword$$(null,"library-file-ids","library-file-ids",65064728),$cljs$cst$5731$searchable$$=new $APP.$cljs$core$Keyword$$(null,"searchable","searchable",1089311247),$cljs$cst$5613$v2_info$$=new $APP.$cljs$core$Keyword$$(null,"v2-info","v2-info",1679610198),$cljs$cst$5659$modify$$=new $APP.$cljs$core$Keyword$$(null,"modify",
"modify",-1261040869),$cljs$cst$5853$on_pointer_enter$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-enter","on-pointer-enter",199832041),$cljs$cst$5454$epsilon$$=new $APP.$cljs$core$Keyword$$(null,"epsilon","epsilon",-730158570),$cljs$cst$5794$submenu_offset$$=new $APP.$cljs$core$Keyword$$(null,"submenu-offset","submenu-offset",1888650638),$cljs$cst$5566$allow_namespaced_nts$$=new $APP.$cljs$core$Keyword$$(null,"allow-namespaced-nts","allow-namespaced-nts",-507534966),$cljs$cst$5834$token_value$$=
new $APP.$cljs$core$Keyword$$(null,"token-value","token-value",1433419008),$cljs$cst$5725$show_advanced_options$$=new $APP.$cljs$core$Keyword$$(null,"show-advanced-options","show-advanced-options",-561220032),$cljs$cst$5467$generation$$=new $APP.$cljs$core$Keyword$$(null,"generation","generation",-2132542044),$cljs$cst$5833$error_SLASH_unknown_error$$=new $APP.$cljs$core$Keyword$$("error","unknown-error","error/unknown-error",843694167),$cljs$cst$5620$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_ordering$$=
new $APP.$cljs$core$Keyword$$("app.main.data.workspace.assets","ordering","app.main.data.workspace.assets/ordering",-515349399),$cljs$cst$5738$measure$$=new $APP.$cljs$core$Keyword$$(null,"measure","measure",-1857519826),$cljs$cst$5747$sec$$=new $APP.$cljs$core$Keyword$$(null,"sec","sec",-1580376553),$cljs$cst$5766$total_applied_refs$$=new $APP.$cljs$core$Keyword$$(null,"total-applied-refs","total-applied-refs",1091146793),$cljs$cst$5450$char_range$$=new $APP.$cljs$core$Keyword$$(null,"char-range",
"char-range",1443391389),$cljs$cst$5888$on_pointer_up$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-up","on-pointer-up",385194E3),$cljs$cst$5455$plus$$=new $APP.$cljs$core$Keyword$$(null,"plus","plus",211540661),$cljs$cst$5762$token_alias$$=new $APP.$cljs$core$Keyword$$(null,"token-alias","token-alias",2012298055),$cljs$cst$5767$matching_applied$$=new $APP.$cljs$core$Keyword$$(null,"matching-applied","matching-applied",-1367639331),$cljs$cst$5789$vertical_attr_labels$$=new $APP.$cljs$core$Keyword$$(null,
"vertical-attr-labels","vertical-attr-labels",1255704246),$cljs$cst$5589$checked$$=new $APP.$cljs$core$Keyword$$(null,"checked","checked",-50955819),$cljs$cst$5818$tokens_SLASH_settings$$=new $APP.$cljs$core$Keyword$$("tokens","settings","tokens/settings",150998605),$cljs$cst$5622$thumbs$$=new $APP.$cljs$core$Keyword$$(null,"thumbs","thumbs",-1134286339),$cljs$cst$5426$expand_token_sets$$=new $APP.$cljs$core$Keyword$$(null,"expand-token-sets","expand-token-sets",1253386),$cljs$cst$5832$reference$$=
new $APP.$cljs$core$Keyword$$(null,"reference","reference",-1711695023),$cljs$cst$5869$selrect_height$$=new $APP.$cljs$core$Keyword$$(null,"selrect-height","selrect-height",1129317331),$cljs$cst$5774$new_name$$=new $APP.$cljs$core$Keyword$$(null,"new-name","new-name",1288355058),$cljs$cst$5679$idle$$=new $APP.$cljs$core$Keyword$$(null,"idle","idle",-2007156861),$cljs$cst$5791$submenu$$=new $APP.$cljs$core$Keyword$$(null,"submenu","submenu",2142563344),$cljs$cst$5737$layout_item$$=new $APP.$cljs$core$Keyword$$(null,
"layout-item","layout-item",-1207087322),$cljs$cst$5857$rect_data$$=new $APP.$cljs$core$Keyword$$(null,"rect-data","rect-data",627750614),$cljs$cst$5906$hand$$=new $APP.$cljs$core$Keyword$$(null,"hand","hand",791601933),$cljs$cst$5452$hiccup$$=new $APP.$cljs$core$Keyword$$(null,"hiccup","hiccup",1218876238),$cljs$cst$5749$empty_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"empty?","empty?",-1564122972),$cljs$cst$5499$rule_separator$$=new $APP.$cljs$core$Keyword$$(null,"rule-separator","rule-separator",
1539322213),$cljs$cst$5529$BIT$$=new $APP.$cljs$core$Keyword$$(null,"BIT","BIT",-1854474115),$cljs$cst$5699$is_column$$=new $APP.$cljs$core$Keyword$$(null,"is-column","is-column",1610131457),$cljs$cst$5718$all_colors$$=new $APP.$cljs$core$Keyword$$(null,"all-colors","all-colors",541687080),$cljs$cst$5815$tokens_SLASH_themes$$=new $APP.$cljs$core$Keyword$$("tokens","themes","tokens/themes",31381800),$cljs$cst$5484$full_listeners$$=new $APP.$cljs$core$Keyword$$(null,"full-listeners","full-listeners",
50621827),$cljs$cst$5692$is_col_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"is-col?","is-col?",-405323997),$cljs$cst$5810$tokens_SLASH_rename_node$$=new $APP.$cljs$core$Keyword$$("tokens","rename-node","tokens/rename-node",1328536617),$cljs$cst$5519$DIGIT$$=new $APP.$cljs$core$Keyword$$(null,"DIGIT","DIGIT",341251338),$cljs$cst$5925$resize_side$$=new $APP.$cljs$core$Keyword$$(null,"resize-side","resize-side",-532712885),$cljs$cst$5878$handle_pointer_down$$=new $APP.$cljs$core$Keyword$$(null,"handle-pointer-down",
"handle-pointer-down",761659029),$cljs$cst$5695$easing_ease$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease","easing-ease",-1909581280),$cljs$cst$5809$on_rename$$=new $APP.$cljs$core$Keyword$$(null,"on-rename","on-rename",2102721909),$cljs$cst$5775$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_bulk_remap_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.remapping","bulk-remap-tokens","app.main.data.workspace.tokens.remapping/bulk-remap-tokens",-1620752236),
$cljs$cst$5571$dynamic$$=new $APP.$cljs$core$Keyword$$(null,"dynamic","dynamic",704819571),$cljs$cst$5706$static$$=new $APP.$cljs$core$Keyword$$(null,"static","static",1214358571),$cljs$cst$5690$listing_thumbs_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"listing-thumbs?","listing-thumbs?",1714462360),$cljs$cst$5763$source_token_id$$=new $APP.$cljs$core$Keyword$$(null,"source-token-id","source-token-id",-86861571),$cljs$cst$5860$initial_value$$=new $APP.$cljs$core$Keyword$$(null,"initial-value","initial-value",
470619381),$cljs$cst$5918$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","workspace","app.main.ui.workspace.viewport.hooks/workspace",1534742616),$cljs$cst$5603$tokens_SLASH_import_from_library$$=new $APP.$cljs$core$Keyword$$("tokens","import-from-library","tokens/import-from-library",2060878099),$cljs$cst$5648$detail_open_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"detail-open?","detail-open?",-1192975497),
$cljs$cst$5602$deletable_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"deletable?","deletable?",2134719819),$cljs$cst$5522$CTL$$=new $APP.$cljs$core$Keyword$$(null,"CTL","CTL",-9995632),$cljs$cst$5555$memory$$=new $APP.$cljs$core$Keyword$$(null,"memory","memory",-1449401430),$cljs$cst$5703$selected_blend_mode$$=new $APP.$cljs$core$Keyword$$(null,"selected-blend-mode","selected-blend-mode",67585278),$cljs$cst$5694$easing_linear$$=new $APP.$cljs$core$Keyword$$(null,"easing-linear","easing-linear",-1638484978),
$cljs$cst$5428$token_type$$=new $APP.$cljs$core$Keyword$$(null,"token-type","token-type",-835337612),$cljs$cst$5728$focusable_ids$$=new $APP.$cljs$core$Keyword$$(null,"focusable-ids","focusable-ids",806934951),$cljs$cst$5688$from_pos$$=new $APP.$cljs$core$Keyword$$(null,"from-pos","from-pos",1141953080),$cljs$cst$5494$end_of_string$$=new $APP.$cljs$core$Keyword$$(null,"end-of-string","end-of-string",1567354241),$cljs$cst$5667$current_match_idx$$=new $APP.$cljs$core$Keyword$$(null,"current-match-idx",
"current-match-idx",-711161636),$cljs$cst$5901$rect_x$$=new $APP.$cljs$core$Keyword$$(null,"rect-x","rect-x",2027933546),$cljs$cst$5902$rect_y$$=new $APP.$cljs$core$Keyword$$(null,"rect-y","rect-y",-234175138),$cljs$cst$5831$recalculate$$=new $APP.$cljs$core$Keyword$$(null,"recalculate","recalculate",633935398),$cljs$cst$5456$star$$=new $APP.$cljs$core$Keyword$$(null,"star","star",279424429),$cljs$cst$5770$token_aliases$$=new $APP.$cljs$core$Keyword$$(null,"token-aliases","token-aliases",-1660509197),
$cljs$cst$5855$on_move_selected$$=new $APP.$cljs$core$Keyword$$(null,"on-move-selected","on-move-selected",117316753),$cljs$cst$5921$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_text$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","text","app.main.ui.workspace.viewport.hooks/text",409069194),$cljs$cst$5581$hsl_saturation$$=new $APP.$cljs$core$Keyword$$(null,"hsl-saturation","hsl-saturation",-612594896),$cljs$cst$5607$connected_to$$=new $APP.$cljs$core$Keyword$$(null,
"connected-to","connected-to",-1930163150),$cljs$cst$5637$input_class$$=new $APP.$cljs$core$Keyword$$(null,"input-class","input-class",-62053138),$cljs$cst$5654$cells_render$$=new $APP.$cljs$core$Keyword$$(null,"cells-render","cells-render",-828771788),$cljs$cst$5874$on_drag_start$$=new $APP.$cljs$core$Keyword$$(null,"on-drag-start","on-drag-start",-47712205),$cljs$cst$5461$look$$=new $APP.$cljs$core$Keyword$$(null,"look","look",-539441433),$cljs$cst$5811$tokens_in_active_set$$=new $APP.$cljs$core$Keyword$$(null,
"tokens-in-active-set","tokens-in-active-set",569743731),$cljs$cst$5616$app_DOT_main_DOT_ui_DOT_workspace_DOT_color_palette_ctx_menu_SLASH_id$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.color-palette-ctx-menu","id","app.main.ui.workspace.color-palette-ctx-menu/id",-1642411096),$cljs$cst$5640$name_input_ref$$=new $APP.$cljs$core$Keyword$$(null,"name-input-ref","name-input-ref",-188911910),$cljs$cst$5841$tokens_SLASH_other$$=new $APP.$cljs$core$Keyword$$("tokens","other","tokens/other",-552061926),
$cljs$cst$5666$replace_text$$=new $APP.$cljs$core$Keyword$$(null,"replace-text","replace-text",-137527916),$cljs$cst$5464$fail_index$$=new $APP.$cljs$core$Keyword$$(null,"fail-index","fail-index",248726923),$cljs$cst$5742$esc$$=new $APP.$cljs$core$Keyword$$(null,"esc","esc",-1671924121),$cljs$cst$5852$gap_type$$=new $APP.$cljs$core$Keyword$$(null,"gap-type","gap-type",-691516251),$cljs$cst$5919$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_grid$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks",
"grid","app.main.ui.workspace.viewport.hooks/grid",-1939984239),$cljs$cst$5813$active_theme_paths$$=new $APP.$cljs$core$Keyword$$(null,"active-theme-paths","active-theme-paths",283904967),$cljs$cst$5882$text_y$$=new $APP.$cljs$core$Keyword$$(null,"text-y","text-y",-1680264360),$cljs$cst$5881$text_x$$=new $APP.$cljs$core$Keyword$$(null,"text-x","text-x",-1791964043),$cljs$cst$5507$rules_or_parser$$=new $APP.$cljs$core$Keyword$$(null,"rules-or-parser","rules-or-parser",-314380386),$cljs$cst$5722$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_remove_frame_grid$$=
new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","remove-frame-grid","app.main.data.workspace.grid/remove-frame-grid",-1269415708),$cljs$cst$5933$app_DOT_main_DOT_store$$=new $APP.$cljs$core$Symbol$$(null,"app.main.store","app.main.store",-1614373036,null),$cljs$cst$5716$stroke_rounded$$=new $APP.$cljs$core$Keyword$$(null,"stroke-rounded","stroke-rounded",-1649675426),$cljs$cst$5917$update$$=new $APP.$cljs$core$Keyword$$(null,"update","update",1045576396),$cljs$cst$5880$handle_pointer_move$$=
new $APP.$cljs$core$Keyword$$(null,"handle-pointer-move","handle-pointer-move",1990039805),$cljs$cst$5896$l1_y2$$=new $APP.$cljs$core$Keyword$$(null,"l1-y2","l1-y2",1399825048),$cljs$cst$5893$l1_y1$$=new $APP.$cljs$core$Keyword$$(null,"l1-y1","l1-y1",-946090345),$cljs$cst$5913$pencil$$=new $APP.$cljs$core$Keyword$$(null,"pencil","pencil",-217778832),$cljs$cst$5890$l1_x2$$=new $APP.$cljs$core$Keyword$$(null,"l1-x2","l1-x2",-1981212693),$cljs$cst$5898$l1_x1$$=new $APP.$cljs$core$Keyword$$(null,"l1-x1",
"l1-x1",867974042),$cljs$cst$5825$folder$$=new $APP.$cljs$core$Keyword$$(null,"folder","folder",1515881736),$cljs$cst$5741$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_shapes_DOT_multiple_SLASH_not_found$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar.options.shapes.multiple","not-found","app.main.ui.workspace.sidebar.options.shapes.multiple/not-found",-1070649517),$cljs$cst$5617$collapse_left_sidebar$$=new $APP.$cljs$core$Keyword$$(null,"collapse-left-sidebar","collapse-left-sidebar",
-1883177143),$cljs$cst$5867$align_center$$=new $APP.$cljs$core$Keyword$$(null,"align-center","align-center",-99300755),$cljs$cst$5634$multi_colors_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"multi-colors?","multi-colors?",-2136724074),$cljs$cst$5823$unknown_tokens$$=new $APP.$cljs$core$Keyword$$(null,"unknown-tokens","unknown-tokens",-366587692),$cljs$cst$5915$pointer_inner$$=new $APP.$cljs$core$Keyword$$(null,"pointer-inner","pointer-inner",1173575841),$cljs$cst$5440$hi$$=new $APP.$cljs$core$Keyword$$(null,
"hi","hi",-1821422114),$cljs$cst$5546$alternation$$=new $APP.$cljs$core$Keyword$$(null,"alternation","alternation",-1162147630),$cljs$cst$5859$resize_axis$$=new $APP.$cljs$core$Keyword$$(null,"resize-axis","resize-axis",-1746101927),$cljs$cst$5441$parser1$$=new $APP.$cljs$core$Keyword$$(null,"parser1","parser1",-439601422),$cljs$cst$5442$parser2$$=new $APP.$cljs$core$Keyword$$(null,"parser2","parser2",1013754688),$cljs$cst$5535$rulename_right$$=new $APP.$cljs$core$Keyword$$(null,"rulename-right",
"rulename-right",1125609193),$cljs$cst$5508$cljs_DOT_tools_DOT_reader_SLASH_read_string_STAR_$$=new $APP.$cljs$core$Symbol$$("cljs.tools.reader","read-string*","cljs.tools.reader/read-string*",1492661621,null),$cljs$cst$5597$name_group_dialog$$=new $APP.$cljs$core$Keyword$$(null,"name-group-dialog","name-group-dialog",1853050356),$cljs$cst$5829$get_selected_id$$=new $APP.$cljs$core$Keyword$$(null,"get-selected-id","get-selected-id",1885455750),$cljs$cst$5549$rulelist$$=new $APP.$cljs$core$Keyword$$(null,
"rulelist","rulelist",-1871218473),$cljs$cst$5443$parsers$$=new $APP.$cljs$core$Keyword$$(null,"parsers","parsers",-804353827),$cljs$cst$5460$nt$$=new $APP.$cljs$core$Keyword$$(null,"nt","nt",-835425781),$cljs$cst$5439$lo$$=new $APP.$cljs$core$Keyword$$(null,"lo","lo",-931799889),$cljs$cst$5578$color_origin$$=new $APP.$cljs$core$Keyword$$(null,"color-origin","color-origin",-216238828),$cljs$cst$5736$constraint$$=new $APP.$cljs$core$Keyword$$(null,"constraint","constraint",1725147424),$cljs$cst$5492$instaparse_DOT_gll_SLASH_end_index$$=
new $APP.$cljs$core$Keyword$$("instaparse.gll","end-index","instaparse.gll/end-index",-1851404441),$cljs$cst$5772$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_remap_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.remapping","remap-tokens","app.main.data.workspace.tokens.remapping/remap-tokens",-1766049516),$cljs$cst$5793$no_selectable$$=new $APP.$cljs$core$Keyword$$(null,"no-selectable","no-selectable",-504485148),$cljs$cst$5723$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_frame_grid$$=
new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","set-frame-grid","app.main.data.workspace.grid/set-frame-grid",577735205),$cljs$cst$5580$hover_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hover?","hover?",-1201331489),$cljs$cst$5735$more_options$$=new $APP.$cljs$core$Keyword$$(null,"more-options","more-options",1399478268),$cljs$cst$5757$snapshot$$=new $APP.$cljs$core$Keyword$$(null,"snapshot","snapshot",-1274785710),$cljs$cst$5515$HTAB$$=new $APP.$cljs$core$Keyword$$(null,"HTAB","HTAB",
11392612),$cljs$cst$5471$trace_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"trace?","trace?",1730690679),$cljs$cst$5745$sc$$=new $APP.$cljs$core$Keyword$$(null,"sc","sc",1148023032),$cljs$cst$5817$tokens_SLASH_import$$=new $APP.$cljs$core$Keyword$$("tokens","import","tokens/import",-1680554363),$cljs$cst$5713$stroke_rectangle$$=new $APP.$cljs$core$Keyword$$(null,"stroke-rectangle","stroke-rectangle",-1801371204),$cljs$cst$5935$selrect_duplicated$$=new $APP.$cljs$core$Keyword$$(null,"selrect-duplicated",
"selrect-duplicated",-729086709),$cljs$cst$5513$output_format$$=new $APP.$cljs$core$Keyword$$(null,"output-format","output-format",-1826382676),$cljs$cst$5562$unhide$$=new $APP.$cljs$core$Keyword$$(null,"unhide","unhide",-413983695),$cljs$cst$5445$reduction_type$$=new $APP.$cljs$core$Keyword$$(null,"reduction-type","reduction-type",-488293450),$cljs$cst$5862$hover_all_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hover-all?","hover-all?",1343012409),$cljs$cst$5518$VCHAR$$=new $APP.$cljs$core$Keyword$$(null,
"VCHAR","VCHAR",1962437706),$cljs$cst$5624$asset_name$$=new $APP.$cljs$core$Keyword$$(null,"asset-name","asset-name",-1412454368),$cljs$cst$5662$search_scope$$=new $APP.$cljs$core$Keyword$$(null,"search-scope","search-scope",-202937614),$cljs$cst$5644$on_name_blur$$=new $APP.$cljs$core$Keyword$$(null,"on-name-blur","on-name-blur",64241635),$cljs$cst$5652$debug_panel$$=new $APP.$cljs$core$Keyword$$(null,"debug-panel","debug-panel",-1624930518),$cljs$cst$5524$WSP$$=new $APP.$cljs$core$Keyword$$(null,
"WSP","WSP",-1046948716),$cljs$cst$5845$create_theme$$=new $APP.$cljs$core$Keyword$$(null,"create-theme","create-theme",279233432),$cljs$cst$5732$search_input_ref$$=new $APP.$cljs$core$Keyword$$(null,"search-input-ref","search-input-ref",290307476),$cljs$cst$5837$composite$$=new $APP.$cljs$core$Keyword$$(null,"composite","composite",-257118970),$cljs$cst$5491$instaparse_DOT_gll_SLASH_start_index$$=new $APP.$cljs$core$Keyword$$("instaparse.gll","start-index","instaparse.gll/start-index",404653620),
$cljs$cst$5724$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_default_grid$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","set-default-grid","app.main.data.workspace.grid/set-default-grid",1437308643),$cljs$cst$5542$rulename$$=new $APP.$cljs$core$Keyword$$(null,"rulename","rulename",948914160),$cljs$cst$5842$tokens_SLASH_string$$=new $APP.$cljs$core$Keyword$$("tokens","string","tokens/string",-576029544),$cljs$cst$5683$show_in_viewer$$=new $APP.$cljs$core$Keyword$$(null,"show-in-viewer",
"show-in-viewer",1111782209),$cljs$cst$5655$points_render$$=new $APP.$cljs$core$Keyword$$(null,"points-render","points-render",-2103762292),$cljs$cst$5758$iso_date$$=new $APP.$cljs$core$Keyword$$(null,"iso-date","iso-date",-1889998156),$cljs$cst$5682$expand_border_radius$$=new $APP.$cljs$core$Keyword$$(null,"expand-border-radius","expand-border-radius",-352780098),$cljs$cst$5795$popup$$=new $APP.$cljs$core$Keyword$$(null,"popup","popup",635890211),$cljs$cst$5514$CRLF$$=new $APP.$cljs$core$Keyword$$(null,
"CRLF","CRLF",11418756),$cljs$cst$5545$concatenation$$=new $APP.$cljs$core$Keyword$$(null,"concatenation","concatenation",-951369614),$cljs$cst$5910$zoom_in$$=new $APP.$cljs$core$Keyword$$(null,"zoom-in","zoom-in",1242180949),$cljs$cst$5543$bin_val$$=new $APP.$cljs$core$Keyword$$(null,"bin-val","bin-val",1705209105),$cljs$cst$5567$auto_whitespace$$=new $APP.$cljs$core$Keyword$$(null,"auto-whitespace","auto-whitespace",741152317),$cljs$cst$5635$on_delete_group$$=new $APP.$cljs$core$Keyword$$(null,
"on-delete-group","on-delete-group",1508715928),$cljs$cst$5905$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_shortcuts_SLASH_esc_pressed$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.shortcuts","esc-pressed","app.main.data.workspace.grid-layout.shortcuts/esc-pressed",-1690439930),$cljs$cst$5498$opt_whitespace$$=new $APP.$cljs$core$Keyword$$(null,"opt-whitespace","opt-whitespace",1115207927),$cljs$cst$5926$resize_point$$=new $APP.$cljs$core$Keyword$$(null,"resize-point",
"resize-point",-1472965451),$cljs$cst$5729$nodes_ref$$=new $APP.$cljs$core$Keyword$$(null,"nodes-ref","nodes-ref",-1499462517),$cljs$cst$5521$HEXDIG$$=new $APP.$cljs$core$Keyword$$(null,"HEXDIG","HEXDIG",-200221072),$cljs$cst$5540$option$$=new $APP.$cljs$core$Keyword$$(null,"option","option",65132272),$cljs$cst$5870$migrate$$=new $APP.$cljs$core$Keyword$$(null,"migrate","migrate",-207110743),$cljs$cst$5422$hsl_l$$=new $APP.$cljs$core$Keyword$$(null,"hsl-l","hsl-l",-1679291119),$cljs$cst$5583$recent$$=
new $APP.$cljs$core$Keyword$$(null,"recent","recent",449517715),$cljs$cst$5423$hsl_s$$=new $APP.$cljs$core$Keyword$$(null,"hsl-s","hsl-s",113070461),$cljs$cst$5421$hsb$$=new $APP.$cljs$core$Keyword$$(null,"hsb","hsb",-753472031),$cljs$cst$5623$last_path$$=new $APP.$cljs$core$Keyword$$(null,"last-path","last-path",-143957020),$cljs$cst$5425$hsl$$=new $APP.$cljs$core$Keyword$$(null,"hsl","hsl",-1282948596),$cljs$cst$5730$on_enter$$=new $APP.$cljs$core$Keyword$$(null,"on-enter","on-enter",-928988216),
$cljs$cst$5792$on_delete_token$$=new $APP.$cljs$core$Keyword$$(null,"on-delete-token","on-delete-token",-1548486919),$cljs$cst$5509$cljs_DOT_tools_DOT_reader$$=new $APP.$cljs$core$Symbol$$(null,"cljs.tools.reader","cljs.tools.reader",-831293977,null),$cljs$cst$5916$clip_children_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"clip-children?","clip-children?",-1668191047),$cljs$cst$5588$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_hsb_mode$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker",
"hsb-mode","app.main.ui.workspace.colorpicker/hsb-mode",-859331609),$cljs$cst$5586$direct_color$$=new $APP.$cljs$core$Keyword$$(null,"direct-color","direct-color",1226799117),$cljs$cst$5866$padding_num$$=new $APP.$cljs$core$Keyword$$(null,"padding-num","padding-num",-747769845),$cljs$cst$5636$renaming$$=new $APP.$cljs$core$Keyword$$(null,"renaming","renaming",619763182),$cljs$cst$5821$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_history_sidebar$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar",
"history-sidebar","app.main.ui.workspace.sidebar/history-sidebar",214720554),$cljs$cst$5697$easing_ease_out$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease-out","easing-ease-out",-82935390),$cljs$cst$5887$new_position$$=new $APP.$cljs$core$Keyword$$(null,"new-position","new-position",-102281521),$cljs$cst$5932$app_DOT_main_DOT_store_SLASH_state$$=new $APP.$cljs$core$Symbol$$("app.main.store","state","app.main.store/state",-1030608881,null),$cljs$cst$5502$inside_comment$$=new $APP.$cljs$core$Keyword$$(null,
"inside-comment","inside-comment",1258069708),$cljs$cst$5799$selected_inside_layout_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"selected-inside-layout?","selected-inside-layout?",-1748414769),$cljs$cst$5707$static_position$$=new $APP.$cljs$core$Keyword$$(null,"static-position","static-position",-2066619638),$cljs$cst$5573$_STAR_runtime_asserts_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"*runtime-asserts*","*runtime-asserts*",1632801956,null),$cljs$cst$5593$title_button$$=new $APP.$cljs$core$Keyword$$(null,
"title-button","title-button",-634326965),$cljs$cst$5606$connected_to_names$$=new $APP.$cljs$core$Keyword$$(null,"connected-to-names","connected-to-names",-2033861740),$cljs$cst$5493$instaparse_SLASH_failure$$=new $APP.$cljs$core$Keyword$$("instaparse","failure","instaparse/failure",1422918607),$cljs$cst$5808$on_remap$$=new $APP.$cljs$core$Keyword$$(null,"on-remap","on-remap",143137190);$APP.$JSCompiler_prototypeAlias$$=$instaparse$auto_flatten_seq$AutoFlattenSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($self$jscomp$85$$,$key$jscomp$401$$){return this.v.$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$401$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($self$jscomp$86$$,$key$jscomp$402$$,$not_found$jscomp$84$$){return this.v.$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$402$$,$not_found$jscomp$84$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$meta$$(this.v)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return $APP.$cljs$core$next$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return this.$hashcode$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($self$jscomp$91$$,$other$jscomp$201$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$hashcode$,$APP.$cljs$core$hash$$($other$jscomp$201$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$cnt$,$APP.$cljs$core$count$$($other$jscomp$201$$))&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$cnt$,0)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$(this),
$other$jscomp$201$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$with_meta$$($instaparse$auto_flatten_seq$EMPTY$$,$APP.$cljs$core$meta$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$first$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return $APP.$cljs$core$rest$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){if(!$APP.$cljs$core$truth_$$(this.$cached_seq$)){if(this.$dirty$){var $JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$=this.v;$JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$)>0?$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$,$instaparse$auto_flatten_seq$delve$$($JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0],null))):null}else $JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$=$APP.$cljs$core$seq$$(this.v);this.$cached_seq$=$JSCompiler_temp$jscomp$1711_v$jscomp$inline_8568$$}return this.$cached_seq$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($self$jscomp$96$$,$metamap$$){return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($APP.$cljs$core$with_meta$$(this.v,$metamap$$),this.$premix_hashcode$,this.$hashcode$,this.$cnt$,this.$dirty$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($self$jscomp$97$$,$o$jscomp$272$$){return $APP.$cljs$core$cons$$($o$jscomp$272$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$=function($phc_self$jscomp$98$$,$obj$jscomp$213$$){if($obj$jscomp$213$$==null)return this;if($APP.$cljs$core$truth_$$($instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$213$$):$instaparse$auto_flatten_seq$afs_QMARK_$$($obj$jscomp$213$$))){if(this.$cnt$===0)return $obj$jscomp$213$$;if($APP.$cljs$core$count$$($obj$jscomp$213$$)<=
32){$phc_self$jscomp$98$$=$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$(this,$obj$jscomp$213$$):$instaparse$auto_flatten_seq$hash_cat$$(this,$obj$jscomp$213$$);var $new_cnt$$=this.$cnt$+$APP.$cljs$core$count$$($obj$jscomp$213$$),$JSCompiler_temp_const$jscomp$1714$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(this.v,$obj$jscomp$213$$),$or__5025__auto__$jscomp$inline_8570$$=this.$dirty$;return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($JSCompiler_temp_const$jscomp$1714$$,
$phc_self$jscomp$98$$,$APP.$cljs$core$mix_collection_hash$$($phc_self$jscomp$98$$,$new_cnt$$),$new_cnt$$,$or__5025__auto__$jscomp$inline_8570$$?$or__5025__auto__$jscomp$inline_8570$$:$obj$jscomp$213$$.$dirty$)}$phc_self$jscomp$98$$=$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$(this,$obj$jscomp$213$$):$instaparse$auto_flatten_seq$hash_cat$$(this,$obj$jscomp$213$$);$new_cnt$$=this.$cnt$+$APP.$cljs$core$count$$($obj$jscomp$213$$);
return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.v,$obj$jscomp$213$$),$phc_self$jscomp$98$$,$APP.$cljs$core$mix_collection_hash$$($phc_self$jscomp$98$$,$new_cnt$$),$new_cnt$$,!0)}$phc_self$jscomp$98$$=(0,$APP.$cljs$core$imul$$)(31,this.$premix_hashcode$)+$APP.$cljs$core$hash$$($obj$jscomp$213$$);$new_cnt$$=this.$cnt$+1;return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.v,
$obj$jscomp$213$$),$phc_self$jscomp$98$$,$APP.$cljs$core$mix_collection_hash$$($phc_self$jscomp$98$$,$new_cnt$$),$new_cnt$$,this.$dirty$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($afs$$,$writer$jscomp$170$$,$opts$jscomp$307$$){return $APP.$cljs$core$_pr_writer$$($APP.$cljs$core$seq$$(this),$writer$jscomp$170$$,$opts$jscomp$307$$)};
var $instaparse$auto_flatten_seq$EMPTY$$=$instaparse$auto_flatten_seq$auto_flatten_seq$$($APP.$cljs$core$PersistentVector$EMPTY$$),$instaparse$auto_flatten_seq$flat_vec_helper$$=function $instaparse$auto_flatten_seq$flat_vec_helper$$($G__75664_G__75666_acc$jscomp$154$$,$G__75665_G__75667_v$jscomp$642$$){for(;;)if($APP.$cljs$core$seq$$($G__75665_G__75667_v$jscomp$642$$)){var $fst$jscomp$2$$=$APP.$cljs$core$first$$($G__75665_G__75667_v$jscomp$642$$);$instaparse$auto_flatten_seq$afs_QMARK_$$($fst$jscomp$2$$)?
($G__75664_G__75666_acc$jscomp$154$$=$instaparse$auto_flatten_seq$flat_vec_helper$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$auto_flatten_seq$flat_vec_helper$$.$cljs$core$IFn$_invoke$arity$2$($G__75664_G__75666_acc$jscomp$154$$,$fst$jscomp$2$$):$instaparse$auto_flatten_seq$flat_vec_helper$$($G__75664_G__75666_acc$jscomp$154$$,$fst$jscomp$2$$),$G__75665_G__75667_v$jscomp$642$$=$APP.$cljs$core$next$$($G__75665_G__75667_v$jscomp$642$$)):($G__75664_G__75666_acc$jscomp$154$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__75664_G__75666_acc$jscomp$154$$,
$fst$jscomp$2$$),$G__75665_G__75667_v$jscomp$642$$=$APP.$cljs$core$next$$($G__75665_G__75667_v$jscomp$642$$))}else return $G__75664_G__75666_acc$jscomp$154$$};$APP.$JSCompiler_prototypeAlias$$=$instaparse$auto_flatten_seq$FlattenOnDemandVector$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($self$jscomp$103$$,$key$jscomp$403$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$403$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($self$jscomp$104$$,$key$jscomp$404$$,$not_found$jscomp$85$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$404$$,$not_found$jscomp$85$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($self$jscomp$106$$,$f$jscomp$851$$,$init$jscomp$60$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IKVReduce$_kv_reduce$arity$3$(null,$f$jscomp$851$$,$init$jscomp$60$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($self$jscomp$107$$,$i$jscomp$515$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IIndexed$_nth$arity$2$(null,$i$jscomp$515$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($self$jscomp$108$$,$i$jscomp$516$$,$not_found$jscomp$86$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IIndexed$_nth$arity$3$(null,$i$jscomp$516$$,$not_found$jscomp$86$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($self$jscomp$109$$,$i$jscomp$517$$,$val$jscomp$201$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IVector$_assoc_n$arity$3$(null,$i$jscomp$517$$,$val$jscomp$201$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$(this.flat))?$APP.$cljs$core$meta$$($APP.$cljs$core$_deref$$(this.flat)):$APP.$cljs$core$meta$$($APP.$cljs$core$_deref$$(this.v))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IStack$_peek$arity$1$(null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IStack$_pop$arity$1$(null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){if(this.$cnt$>0){var $JSCompiler_temp$jscomp$10637_rev$jscomp$inline_13392$$=$JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this);$JSCompiler_temp$jscomp$10637_rev$jscomp$inline_13392$$=$APP.$cljs$core$_rseq$$($JSCompiler_temp$jscomp$10637_rev$jscomp$inline_13392$$)}else $JSCompiler_temp$jscomp$10637_rev$jscomp$inline_13392$$=null;return $JSCompiler_temp$jscomp$10637_rev$jscomp$inline_13392$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return this.$hashcode$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($self$jscomp$116$$,$other$jscomp$202$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$hashcode$,$APP.$cljs$core$hash$$($other$jscomp$202$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$cnt$,$APP.$cljs$core$count$$($other$jscomp$202$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$other$jscomp$202$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$with_meta$$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$meta$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($self$jscomp$118$$,$i$jscomp$518$$,$val$jscomp$202$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$i$jscomp$518$$,$val$jscomp$202$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($self$jscomp$119$$,$k$jscomp$672$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$(null,$k$jscomp$672$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($self$jscomp$121$$,$metamap$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$(this.flat))?new $instaparse$auto_flatten_seq$FlattenOnDemandVector$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$(this.v)),this.$hashcode$,this.$cnt$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$($APP.$cljs$core$_deref$$(this.flat),$metamap$jscomp$1$$))):
new $instaparse$auto_flatten_seq$FlattenOnDemandVector$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$($APP.$cljs$core$_deref$$(this.v),$metamap$jscomp$1$$)),this.$hashcode$,this.$cnt$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$(this.flat)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($self$jscomp$122$$,$obj$jscomp$214$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$obj$jscomp$214$$)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$31$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7331$$,$args75637$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args75637$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($arg$jscomp$33$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IFn$_invoke$arity$2$(null,$arg$jscomp$33$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($arg$jscomp$34$$,$not_found$jscomp$87$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IFn$_invoke$arity$3$(null,$arg$jscomp$34$$,$not_found$jscomp$87$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IComparable$_compare$arity$2$=function($self$jscomp$125$$,$that$$){return $APP.$cljs$core$_compare$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$that$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($v$jscomp$646$$,$writer$jscomp$171$$,$opts$jscomp$308$$){return $APP.$cljs$core$_pr_writer$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$writer$jscomp$171$$,$opts$jscomp$308$$)};var $instaparse$print$paren_for_compound$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$print$paren_for_tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$594$cat$$,null,$cljs$cst$5438$ord$$,null,$APP.$cljs$cst$717$alt$$,null],null),null));var $instaparse$reduction$raw_non_terminal_reduction$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null),$instaparse$reduction$reduction_types$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5452$hiccup$$,function($key$jscomp$405$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$key$jscomp$405$$],null)},$cljs$cst$5453$enlive$$,function($key$jscomp$406$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5453$enlive$$,$APP.$cljs$cst$302$key$$,$key$jscomp$406$$],null)}],null),$instaparse$reduction$node_builders$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5453$enlive$$,function($tag$jscomp$90$$,$item$jscomp$119$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$tag$jscomp$90$$,$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$List$$(null,$item$jscomp$119$$,null,1,null)],null)},$cljs$cst$5452$hiccup$$,function($tag$jscomp$91$$,
$item$jscomp$120$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tag$jscomp$91$$,$item$jscomp$120$$],null)}],null);var $instaparse$combinators_source$Epsilon$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5454$epsilon$$],null),$instaparse$combinators_source$alt$$=function $instaparse$combinators_source$alt$$($var_args$jscomp$1420$$){for(var $args__5755__auto__$jscomp$246$$=[],$len__5749__auto___75885$$=arguments.length,$i__5750__auto___75886$$=0;;)if($i__5750__auto___75886$$<$len__5749__auto___75885$$)$args__5755__auto__$jscomp$246$$.push(arguments[$i__5750__auto___75886$$]),
$i__5750__auto___75886$$+=1;else break;return $instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$246$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$246$$.slice(0),0,null):null)};
$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$=function($parsers$jscomp$7$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$instaparse$combinators_source$Epsilon$$),$parsers$jscomp$7$$)?$instaparse$combinators_source$Epsilon$$:$instaparse$reduction$singleton_QMARK_$$($parsers$jscomp$7$$)?$APP.$cljs$core$first$$($parsers$jscomp$7$$):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,$parsers$jscomp$7$$],null)};$instaparse$combinators_source$alt$$.$cljs$lang$maxFixedArity$=0;$instaparse$combinators_source$alt$$.$cljs$lang$applyTo$=function($seq75814$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq75814$$))};
var $instaparse$combinators_source$ord$$=function $instaparse$combinators_source$ord$$($var_args$jscomp$1421$$){switch(arguments.length){case 0:return $instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$0$();default:for(var $args_arr__5774__auto__$jscomp$106$$=[],$len__5749__auto___75889$$=arguments.length,$i__5750__auto___75890$$=0;;)if($i__5750__auto___75890$$<$len__5749__auto___75889$$)$args_arr__5774__auto__$jscomp$106$$.push(arguments[$i__5750__auto___75890$$]),$i__5750__auto___75890$$+=
1;else break;return $instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$106$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$106$$.slice(1),0,null):null)}};$instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $instaparse$combinators_source$Epsilon$$};
$instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$variadic$=function($JSCompiler_temp$jscomp$1725_parser1$jscomp$2$$,$parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$){$parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1725_parser1$jscomp$2$$,$instaparse$combinators_source$Epsilon$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$instaparse$combinators_source$Epsilon$$]),
$parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$):$parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$;$APP.$cljs$core$seq$$($parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$)&&($parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$ord$$,$parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$),$JSCompiler_temp$jscomp$1725_parser1$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5438$ord$$,$cljs$cst$5441$parser1$$,$JSCompiler_temp$jscomp$1725_parser1$jscomp$2$$,$cljs$cst$5442$parser2$$,$parser2$jscomp$inline_8605_parsers$jscomp$8_parsers__$1$$],null));return $JSCompiler_temp$jscomp$1725_parser1$jscomp$2$$};
$instaparse$combinators_source$ord$$.$cljs$lang$applyTo$=function($seq75820_seq75820__$1$$){var $G__75821$$=$APP.$cljs$core$first$$($seq75820_seq75820__$1$$);$seq75820_seq75820__$1$$=$APP.$cljs$core$next$$($seq75820_seq75820__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__75821$$,$seq75820_seq75820__$1$$)};$instaparse$combinators_source$ord$$.$cljs$lang$maxFixedArity$=1;
var $instaparse$combinators_source$cat$$=function $instaparse$combinators_source$cat$$($var_args$jscomp$1422$$){for(var $args__5755__auto__$jscomp$247$$=[],$len__5749__auto___75892$$=arguments.length,$i__5750__auto___75893$$=0;;)if($i__5750__auto___75893$$<$len__5749__auto___75892$$)$args__5755__auto__$jscomp$247$$.push(arguments[$i__5750__auto___75893$$]),$i__5750__auto___75893$$+=1;else break;return $instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$247$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$247$$.slice(0),0,null):null)};
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$=function($parsers$jscomp$9_parsers__$1$jscomp$1$$){if($APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$instaparse$combinators_source$Epsilon$$),$parsers$jscomp$9_parsers__$1$jscomp$1$$))return $instaparse$combinators_source$Epsilon$$;$parsers$jscomp$9_parsers__$1$jscomp$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$instaparse$combinators_source$Epsilon$$]),
$parsers$jscomp$9_parsers__$1$jscomp$1$$);return $instaparse$reduction$singleton_QMARK_$$($parsers$jscomp$9_parsers__$1$jscomp$1$$)?$APP.$cljs$core$first$$($parsers$jscomp$9_parsers__$1$jscomp$1$$):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,$parsers$jscomp$9_parsers__$1$jscomp$1$$],null)};$instaparse$combinators_source$cat$$.$cljs$lang$maxFixedArity$=0;$instaparse$combinators_source$cat$$.$cljs$lang$applyTo$=function($seq75828$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq75828$$))};
var $instaparse$combinators_source$unhide_content$$=function $instaparse$combinators_source$unhide_content$$($parser$jscomp$31$$){var $parser__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2345$hide$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$31$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$31$$,$APP.$cljs$cst$2345$hide$$):$parser$jscomp$31$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser__$1$$,
$APP.$cljs$cst$646$parser$$,function(){var $G__75832$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$);return $instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$($G__75832$$):$instaparse$combinators_source$unhide_content$$($G__75832$$)}()):$APP.$cljs$core$truth_$$($cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser__$1$$,
$cljs$cst$5443$parsers$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$unhide_content$$,$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$),$cljs$cst$5438$ord$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($parser__$1$$,$cljs$cst$5441$parser1$$,function(){var $G__75834$$=$cljs$cst$5441$parser1$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$);
return $instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$($G__75834$$):$instaparse$combinators_source$unhide_content$$($G__75834$$)}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5442$parser2$$,function(){var $G__75835$$=$cljs$cst$5442$parser2$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$);return $instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$?
$instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$($G__75835$$):$instaparse$combinators_source$unhide_content$$($G__75835$$)}()])):$parser__$1$$},$instaparse$combinators_source$auto_whitespace_parser$$=function $instaparse$combinators_source$auto_whitespace_parser$$($parser$jscomp$32$$,$ws_parser$$){var $G__75869_G__75869__$1$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$);$G__75869_G__75869__$1$$=$G__75869_G__75869__$1$$ instanceof $APP.$cljs$core$Keyword$$?
$G__75869_G__75869__$1$$.$fqn$:null;switch($G__75869_G__75869__$1$$){case "nt":case "epsilon":return $parser$jscomp$32$$;case "opt":case "plus":case "star":case "rep":case "look":case "neg":return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($parser$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$646$parser$$],null),$instaparse$combinators_source$auto_whitespace_parser$$,$ws_parser$$);case "alt":case "cat":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$32$$,
$cljs$cst$5443$parsers$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75868_SHARP_$$){return $instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$($p1__75868_SHARP_$$,$ws_parser$$):$instaparse$combinators_source$auto_whitespace_parser$$($p1__75868_SHARP_$$,$ws_parser$$)},$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$)));case "ord":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($parser$jscomp$32$$,
$cljs$cst$5441$parser1$$,function(){var $G__75870$$=$cljs$cst$5441$parser1$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$);return $instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$($G__75870$$,$ws_parser$$):$instaparse$combinators_source$auto_whitespace_parser$$($G__75870$$,$ws_parser$$)}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5442$parser2$$,
function(){var $G__75872$$=$cljs$cst$5442$parser2$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$);return $instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$($G__75872$$,$ws_parser$$):$instaparse$combinators_source$auto_whitespace_parser$$($G__75872$$,$ws_parser$$)}()]));case "string":case "string-ci":case "regexp":return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ws_parser$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$32$$,$APP.$cljs$cst$5446$red$$)])),$APP.$cljs$cst$5446$red$$,$APP.$cljs$cst$5446$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$)):$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ws_parser$$,
$parser$jscomp$32$$]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75869_G__75869__$1$$)].join(""));}};/*

 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
$APP.$JSCompiler_prototypeAlias$$=$instaparse$gll$Failure$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$35$$,$k__5324__auto__$jscomp$35$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$35$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$35$$,$k76714$$,$else__5326__auto__$jscomp$35$$){switch($k76714$$ instanceof $APP.$cljs$core$Keyword$$?$k76714$$.$fqn$:null){case "index":return this.index;case "reason":return this.reason;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k76714$$,$else__5326__auto__$jscomp$35$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$35$$,$f__5344__auto__$jscomp$35$$,$init__5345__auto__$jscomp$35$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$35$$,$p__76726_v__5348__auto__$jscomp$35$$){var $k__5347__auto__$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76726_v__5348__auto__$jscomp$35$$,0,null);$p__76726_v__5348__auto__$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76726_v__5348__auto__$jscomp$35$$,
1,null);return $f__5344__auto__$jscomp$35$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$35$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$35$$,$k__5347__auto__$jscomp$35$$,$p__76726_v__5348__auto__$jscomp$35$$):$f__5344__auto__$jscomp$35$$($ret__5346__auto__$jscomp$35$$,$k__5347__auto__$jscomp$35$$,$p__76726_v__5348__auto__$jscomp$35$$)},$init__5345__auto__$jscomp$35$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$35$$,$writer__5339__auto__$jscomp$35$$,$opts__5340__auto__$jscomp$35$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$35$$,function($keyval__5342__auto__$jscomp$35$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$35$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$35$$,$keyval__5342__auto__$jscomp$35$$)},"#instaparse.gll.Failure{",
", ","}",$opts__5340__auto__$jscomp$35$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,this.index],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$984$reason$$,this.reason],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$984$reason$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$gll$Failure$$(this.index,this.reason,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$=this.$__hash$;return $h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$!=null?$h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$:this.$__hash$=$h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$=-1140991288^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this76715$$,$other76716$$){return $other76716$$!=null&&this.constructor===$other76716$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.index,$other76716$$.index)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.reason,$other76716$$.reason)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other76716$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$35$$,$k__5334__auto__$jscomp$35$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,null,$APP.$cljs$cst$984$reason$$,null],null),null),$k__5334__auto__$jscomp$35$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$35$$):new $instaparse$gll$Failure$$(this.index,this.reason,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$35$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$35$$,$k76714$jscomp$1$$){switch($k76714$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k76714$jscomp$1$$.$fqn$:null){case "index":case "reason":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k76714$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$35$$,$k__5332__auto__$jscomp$35$$,$G__76713$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1795$index$$,$k__5332__auto__$jscomp$35$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1795$index$$,$k__5332__auto__$jscomp$35$$))?
new $instaparse$gll$Failure$$($G__76713$jscomp$1$$,this.reason,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$984$reason$$,$k__5332__auto__$jscomp$35$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$984$reason$$,$k__5332__auto__$jscomp$35$$))?new $instaparse$gll$Failure$$(this.index,$G__76713$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $instaparse$gll$Failure$$(this.index,this.reason,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$35$$,$G__76713$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1795$index$$,this.index,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$984$reason$$,this.reason,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$35$$,$G__76713$jscomp$2$$){return new $instaparse$gll$Failure$$(this.index,this.reason,$G__76713$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$35$$,$entry__5329__auto__$jscomp$35$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$35$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$35$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$35$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$35$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($fail$jscomp$2$$,$writer$jscomp$172$$){var $fail__$1$$=this;return $APP.$cljs$core$_write$$($writer$jscomp$172$$,function(){var $sb__5670__auto__$jscomp$9$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__76738_76880$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__76739_76881$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=
!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$10$$){return $sb__5670__auto__$jscomp$9$$.append($x__5671__auto__$jscomp$10$$)};try{$instaparse$failure$pprint_failure$$($fail__$1$$)}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__76739_76881$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__76738_76880$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$9$$)}())};
var $instaparse$gll$failure_type$$=$APP.$cljs$core$type$$(new $instaparse$gll$Failure$$(null,null,null,null,null));$APP.$JSCompiler_prototypeAlias$$=$instaparse$gll$Tramp$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$36$$,$k__5324__auto__$jscomp$36$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$36$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$36$$,$k76743$$,$else__5326__auto__$jscomp$36$$){switch($k76743$$ instanceof $APP.$cljs$core$Keyword$$?$k76743$$.$fqn$:null){case "grammar":return this.$grammar$;case "text":return this.text;case "segment":return this.segment;case "fail-index":return this.$fail_index$;case "node-builder":return this.$node_builder$;case "stack":return this.stack;case "next-stack":return this.$next_stack$;case "generation":return this.$generation$;
case "negative-listeners":return this.$negative_listeners$;case "msg-cache":return this.$msg_cache$;case "nodes":return this.$nodes$;case "success":return this.$success$;case "failure":return this.$failure$;case "trace?":return this.$trace_QMARK_$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k76743$$,$else__5326__auto__$jscomp$36$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$36$$,$f__5344__auto__$jscomp$36$$,$init__5345__auto__$jscomp$36$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$36$$,$p__76748_v__5348__auto__$jscomp$36$$){var $k__5347__auto__$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76748_v__5348__auto__$jscomp$36$$,0,null);$p__76748_v__5348__auto__$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76748_v__5348__auto__$jscomp$36$$,
1,null);return $f__5344__auto__$jscomp$36$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$36$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$36$$,$k__5347__auto__$jscomp$36$$,$p__76748_v__5348__auto__$jscomp$36$$):$f__5344__auto__$jscomp$36$$($ret__5346__auto__$jscomp$36$$,$k__5347__auto__$jscomp$36$$,$p__76748_v__5348__auto__$jscomp$36$$)},$init__5345__auto__$jscomp$36$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$36$$,$writer__5339__auto__$jscomp$36$$,$opts__5340__auto__$jscomp$36$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$36$$,function($keyval__5342__auto__$jscomp$36$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$36$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$36$$,$keyval__5342__auto__$jscomp$36$$)},"#instaparse.gll.Tramp{",
", ","}",$opts__5340__auto__$jscomp$36$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5447$grammar$$,this.$grammar$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1588$text$$,this.text],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1861$segment$$,this.segment],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5464$fail_index$$,this.$fail_index$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5465$node_builder$$,this.$node_builder$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3685$stack$$,
this.stack],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5466$next_stack$$,this.$next_stack$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5467$generation$$,this.$generation$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5468$negative_listeners$$,this.$negative_listeners$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5469$msg_cache$$,this.$msg_cache$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5470$nodes$$,this.$nodes$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2344$success$$,this.$success$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$847$failure$$,
this.$failure$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5471$trace_QMARK_$$,this.$trace_QMARK_$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,14,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5447$grammar$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$1861$segment$$,$cljs$cst$5464$fail_index$$,$cljs$cst$5465$node_builder$$,$APP.$cljs$cst$3685$stack$$,$cljs$cst$5466$next_stack$$,$cljs$cst$5467$generation$$,$cljs$cst$5468$negative_listeners$$,$cljs$cst$5469$msg_cache$$,
$cljs$cst$5470$nodes$$,$APP.$cljs$cst$2344$success$$,$APP.$cljs$cst$847$failure$$,$cljs$cst$5471$trace_QMARK_$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 14+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$=this.$__hash$;return $h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$!=null?$h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$:this.$__hash$=$h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$=166878148^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this76744$$,$other76745$$){return $other76745$$!=null&&this.constructor===$other76745$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$grammar$,$other76745$$.$grammar$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.text,$other76745$$.text)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.segment,$other76745$$.segment)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$fail_index$,
$other76745$$.$fail_index$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$node_builder$,$other76745$$.$node_builder$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.stack,$other76745$$.stack)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$next_stack$,$other76745$$.$next_stack$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$generation$,$other76745$$.$generation$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$negative_listeners$,
$other76745$$.$negative_listeners$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$msg_cache$,$other76745$$.$msg_cache$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$nodes$,$other76745$$.$nodes$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$success$,$other76745$$.$success$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$failure$,$other76745$$.$failure$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$trace_QMARK_$,$other76745$$.$trace_QMARK_$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other76745$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$36$$,$k__5334__auto__$jscomp$36$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,14,[$cljs$cst$5469$msg_cache$$,null,$cljs$cst$5468$negative_listeners$$,null,$cljs$cst$5467$generation$$,null,$APP.$cljs$cst$847$failure$$,null,$cljs$cst$5464$fail_index$$,null,$cljs$cst$5447$grammar$$,null,$APP.$cljs$cst$2344$success$$,
null,$cljs$cst$5470$nodes$$,null,$cljs$cst$5465$node_builder$$,null,$APP.$cljs$cst$1861$segment$$,null,$APP.$cljs$cst$3685$stack$$,null,$cljs$cst$5471$trace_QMARK_$$,null,$cljs$cst$5466$next_stack$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$k__5334__auto__$jscomp$36$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$36$$):
new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$36$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$36$$,$k76743$jscomp$1$$){switch($k76743$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k76743$jscomp$1$$.$fqn$:null){case "grammar":case "text":case "segment":case "fail-index":case "node-builder":case "stack":case "next-stack":case "generation":case "negative-listeners":case "msg-cache":case "nodes":case "success":case "failure":case "trace?":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,
$k76743$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$36$$,$k__5332__auto__$jscomp$36$$,$G__76742$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5447$grammar$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5447$grammar$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$($G__76742$jscomp$1$$,
this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1588$text$$,
$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,$G__76742$jscomp$1$$,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1861$segment$$,
$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1861$segment$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,$G__76742$jscomp$1$$,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5464$fail_index$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5464$fail_index$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,$G__76742$jscomp$1$$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5465$node_builder$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5465$node_builder$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,$G__76742$jscomp$1$$,this.stack,this.$next_stack$,this.$generation$,
this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3685$stack$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$3685$stack$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,
this.text,this.segment,this.$fail_index$,this.$node_builder$,$G__76742$jscomp$1$$,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5466$next_stack$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5466$next_stack$$,
$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,$G__76742$jscomp$1$$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5467$generation$$,
$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5467$generation$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,$G__76742$jscomp$1$$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5468$negative_listeners$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5468$negative_listeners$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,$G__76742$jscomp$1$$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5469$msg_cache$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5469$msg_cache$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,
this.$generation$,this.$negative_listeners$,$G__76742$jscomp$1$$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5470$nodes$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5470$nodes$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,
this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,$G__76742$jscomp$1$$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2344$success$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2344$success$$,
$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,$G__76742$jscomp$1$$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$847$failure$$,
$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$847$failure$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,$G__76742$jscomp$1$$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5471$trace_QMARK_$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5471$trace_QMARK_$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,$G__76742$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$36$$,$G__76742$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$5447$grammar$$,this.$grammar$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1588$text$$,this.text,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1861$segment$$,this.segment,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5464$fail_index$$,
this.$fail_index$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5465$node_builder$$,this.$node_builder$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$3685$stack$$,this.stack,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5466$next_stack$$,this.$next_stack$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5467$generation$$,this.$generation$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5468$negative_listeners$$,this.$negative_listeners$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5469$msg_cache$$,
this.$msg_cache$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5470$nodes$$,this.$nodes$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2344$success$$,this.$success$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$847$failure$$,this.$failure$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5471$trace_QMARK_$$,this.$trace_QMARK_$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$36$$,$G__76742$jscomp$2$$){return new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,$G__76742$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$36$$,$entry__5329__auto__$jscomp$36$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$36$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$36$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$36$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$36$$)};
$APP.$JSCompiler_prototypeAlias$$=$instaparse$gll$Node$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$37$$,$k__5324__auto__$jscomp$37$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$37$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$37$$,$k76760$$,$else__5326__auto__$jscomp$37$$){switch($k76760$$ instanceof $APP.$cljs$core$Keyword$$?$k76760$$.$fqn$:null){case "listeners":return this.$listeners$;case "full-listeners":return this.$full_listeners$;case "results":return this.results;case "full-results":return this.$full_results$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k76760$$,$else__5326__auto__$jscomp$37$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$37$$,$f__5344__auto__$jscomp$37$$,$init__5345__auto__$jscomp$37$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$37$$,$p__76765_v__5348__auto__$jscomp$37$$){var $k__5347__auto__$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76765_v__5348__auto__$jscomp$37$$,0,null);$p__76765_v__5348__auto__$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__76765_v__5348__auto__$jscomp$37$$,
1,null);return $f__5344__auto__$jscomp$37$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$37$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$37$$,$k__5347__auto__$jscomp$37$$,$p__76765_v__5348__auto__$jscomp$37$$):$f__5344__auto__$jscomp$37$$($ret__5346__auto__$jscomp$37$$,$k__5347__auto__$jscomp$37$$,$p__76765_v__5348__auto__$jscomp$37$$)},$init__5345__auto__$jscomp$37$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$37$$,$writer__5339__auto__$jscomp$37$$,$opts__5340__auto__$jscomp$37$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$37$$,function($keyval__5342__auto__$jscomp$37$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$37$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$37$$,$keyval__5342__auto__$jscomp$37$$)},"#instaparse.gll.Node{",
", ","}",$opts__5340__auto__$jscomp$37$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5483$listeners$$,this.$listeners$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5484$full_listeners$$,this.$full_listeners$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5485$results$$,this.results],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5486$full_results$$,this.$full_results$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,4,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5483$listeners$$,$cljs$cst$5484$full_listeners$$,$cljs$cst$5485$results$$,$cljs$cst$5486$full_results$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 4+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$=this.$__hash$;return $h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$!=null?$h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$:this.$__hash$=$h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$=-1610074144^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this76761$$,$other76762$$){return $other76762$$!=null&&this.constructor===$other76762$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$listeners$,$other76762$$.$listeners$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$full_listeners$,$other76762$$.$full_listeners$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.results,$other76762$$.results)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$full_results$,
$other76762$$.$full_results$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other76762$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$37$$,$k__5334__auto__$jscomp$37$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$5486$full_results$$,null,$cljs$cst$5484$full_listeners$$,null,$cljs$cst$5483$listeners$$,null,$cljs$cst$5485$results$$,null],null),null),$k__5334__auto__$jscomp$37$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$37$$):new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$37$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$37$$,$k76760$jscomp$1$$){switch($k76760$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k76760$jscomp$1$$.$fqn$:null){case "listeners":case "full-listeners":case "results":case "full-results":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k76760$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$37$$,$k__5332__auto__$jscomp$37$$,$G__76759$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5483$listeners$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5483$listeners$$,$k__5332__auto__$jscomp$37$$))?
new $instaparse$gll$Node$$($G__76759$jscomp$1$$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5484$full_listeners$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5484$full_listeners$$,$k__5332__auto__$jscomp$37$$))?new $instaparse$gll$Node$$(this.$listeners$,
$G__76759$jscomp$1$$,this.results,this.$full_results$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5485$results$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5485$results$$,$k__5332__auto__$jscomp$37$$))?new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,$G__76759$jscomp$1$$,
this.$full_results$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5486$full_results$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5486$full_results$$,$k__5332__auto__$jscomp$37$$))?new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,$G__76759$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$37$$,$G__76759$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$5483$listeners$$,this.$listeners$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5484$full_listeners$$,this.$full_listeners$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5485$results$$,this.results,
null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5486$full_results$$,this.$full_results$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$37$$,$G__76759$jscomp$2$$){return new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,$G__76759$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$37$$,$entry__5329__auto__$jscomp$37$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$37$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$37$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$37$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$37$$)};
var $instaparse$gll$merge_negative_listeners$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge_with$$,$APP.$cljs$core$into$$),$instaparse$gll$CatListener$$=function $instaparse$gll$CatListener$$($results_so_far$$,$parser_sequence$$,$node_key$jscomp$11$$,$tramp$jscomp$20$$){return function($JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$){var $JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$);$JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$,$APP.$cljs$cst$828$result$$);$JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$,
$APP.$cljs$cst$1795$index$$);$JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$$,$JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$);if($APP.$cljs$core$seq$$($parser_sequence$$)){$JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$,$APP.$cljs$core$first$$($parser_sequence$$)],null);var $G__76816$jscomp$inline_8639$$=$APP.$cljs$core$next$$($parser_sequence$$);$JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$=$instaparse$gll$CatListener$$.$cljs$core$IFn$_invoke$arity$4$?$instaparse$gll$CatListener$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$,
$G__76816$jscomp$inline_8639$$,$node_key$jscomp$11$$,$tramp$jscomp$20$$):$instaparse$gll$CatListener$$($JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$,$G__76816$jscomp$inline_8639$$,$node_key$jscomp$11$$,$tramp$jscomp$20$$);$JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$=$instaparse$gll$push_listener$$($tramp$jscomp$20$$,$JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$,
$JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$)}else $JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$=$instaparse$gll$push_result$$($tramp$jscomp$20$$,$node_key$jscomp$11$$,$instaparse$gll$make_success$$($JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$,$JSCompiler_temp_const$jscomp$1734_continue_index_map__76814__$1$$));
return $JSCompiler_inline_result$jscomp$1735_JSCompiler_temp$jscomp$1733_new_results_so_far_parsed_result_result$jscomp$350$$}},$instaparse$gll$CatFullListener$$=function $instaparse$gll$CatFullListener$$($results_so_far$jscomp$1$$,$parser_sequence$jscomp$1$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$){return function($parsed_result$jscomp$1_result$jscomp$351$$){var $continue_index$jscomp$1_map__76819__$1$$=$APP.$cljs$core$__destructure_map$$($parsed_result$jscomp$1_result$jscomp$351$$);$parsed_result$jscomp$1_result$jscomp$351$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$1_map__76819__$1$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$1_map__76819__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$1_map__76819__$1$$,$APP.$cljs$cst$1795$index$$);var $new_results_so_far$jscomp$1$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$1$$,$parsed_result$jscomp$1_result$jscomp$351$$);return $instaparse$reduction$singleton_QMARK_$$($parser_sequence$jscomp$1$$)?
$instaparse$gll$push_full_listener$$($tramp$jscomp$21$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$1_map__76819__$1$$,$APP.$cljs$core$first$$($parser_sequence$jscomp$1$$)],null),function(){var $G__76821$$=$APP.$cljs$core$next$$($parser_sequence$jscomp$1$$);return $instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$?$instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$($new_results_so_far$jscomp$1$$,
$G__76821$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$):$instaparse$gll$CatFullListener$$($new_results_so_far$jscomp$1$$,$G__76821$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$)}()):$APP.$cljs$core$seq$$($parser_sequence$jscomp$1$$)?$instaparse$gll$push_listener$$($tramp$jscomp$21$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$1_map__76819__$1$$,$APP.$cljs$core$first$$($parser_sequence$jscomp$1$$)],null),function(){var $G__76825$$=
$APP.$cljs$core$next$$($parser_sequence$jscomp$1$$);return $instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$?$instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$($new_results_so_far$jscomp$1$$,$G__76825$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$):$instaparse$gll$CatFullListener$$($new_results_so_far$jscomp$1$$,$G__76825$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$)}()):$instaparse$gll$push_result$$($tramp$jscomp$21$$,$node_key$jscomp$12$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$1$$,
$continue_index$jscomp$1_map__76819__$1$$))}},$instaparse$gll$PlusListener$$=function $instaparse$gll$PlusListener$$($results_so_far$jscomp$2$$,$parser$jscomp$38$$,$prev_index$jscomp$2$$,$node_key$jscomp$13$$,$tramp$jscomp$22$$){return function($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$){var $continue_index$jscomp$2_map__76828__$1$$=$APP.$cljs$core$__destructure_map$$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$);$new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$2_map__76828__$1$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$2_map__76828__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$2_map__76828__$1$$,$APP.$cljs$cst$1795$index$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$2_map__76828__$1$$,$prev_index$jscomp$2$$))return $APP.$cljs$core$count$$($results_so_far$jscomp$2$$)===0?$instaparse$gll$push_result$$($tramp$jscomp$22$$,
$node_key$jscomp$13$$,$instaparse$gll$make_success$$(null,$continue_index$jscomp$2_map__76828__$1$$)):null;$new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$2$$,$new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$);$instaparse$gll$push_listener$$($tramp$jscomp$22$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$2_map__76828__$1$$,
$parser$jscomp$38$$],null),$instaparse$gll$PlusListener$$.$cljs$core$IFn$_invoke$arity$5$?$instaparse$gll$PlusListener$$.$cljs$core$IFn$_invoke$arity$5$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$,$parser$jscomp$38$$,$continue_index$jscomp$2_map__76828__$1$$,$node_key$jscomp$13$$,$tramp$jscomp$22$$):$instaparse$gll$PlusListener$$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$,$parser$jscomp$38$$,$continue_index$jscomp$2_map__76828__$1$$,$node_key$jscomp$13$$,
$tramp$jscomp$22$$));return $instaparse$gll$push_result$$($tramp$jscomp$22$$,$node_key$jscomp$13$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$352$$,$continue_index$jscomp$2_map__76828__$1$$))}},$instaparse$gll$PlusFullListener$$=function $instaparse$gll$PlusFullListener$$($results_so_far$jscomp$3$$,$parser$jscomp$39$$,$prev_index$jscomp$3$$,$node_key$jscomp$14$$,$tramp$jscomp$23$$){return function($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$){var $continue_index$jscomp$3_map__76829__$1$$=
$APP.$cljs$core$__destructure_map$$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$);$new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__76829__$1$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$3_map__76829__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__76829__$1$$,$APP.$cljs$cst$1795$index$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__76829__$1$$,
$prev_index$jscomp$3$$))return $APP.$cljs$core$count$$($results_so_far$jscomp$3$$)===0?$instaparse$gll$push_result$$($tramp$jscomp$23$$,$node_key$jscomp$14$$,$instaparse$gll$make_success$$(null,$continue_index$jscomp$3_map__76829__$1$$)):null;$new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$3$$,$new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__76829__$1$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$23$$)))?$instaparse$gll$push_result$$($tramp$jscomp$23$$,$node_key$jscomp$14$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$,$continue_index$jscomp$3_map__76829__$1$$)):$instaparse$gll$push_listener$$($tramp$jscomp$23$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$3_map__76829__$1$$,
$parser$jscomp$39$$],null),$instaparse$gll$PlusFullListener$$.$cljs$core$IFn$_invoke$arity$5$?$instaparse$gll$PlusFullListener$$.$cljs$core$IFn$_invoke$arity$5$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$,$parser$jscomp$39$$,$continue_index$jscomp$3_map__76829__$1$$,$node_key$jscomp$14$$,$tramp$jscomp$23$$):$instaparse$gll$PlusFullListener$$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$353$$,$parser$jscomp$39$$,$continue_index$jscomp$3_map__76829__$1$$,
$node_key$jscomp$14$$,$tramp$jscomp$23$$))}},$instaparse$gll$RepListener$$=function $instaparse$gll$RepListener$$($results_so_far$jscomp$4$$,$n_results_so_far$$,$parser$jscomp$40$$,$m$jscomp$223$$,$n$jscomp$300$$,$prev_index$jscomp$4$$,$node_key$jscomp$15$$,$tramp$jscomp$24$$){return function($continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$){$continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$=$APP.$cljs$core$__destructure_map$$($continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$);
var $new_results_so_far$jscomp$4_parsed_result$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$,$APP.$cljs$cst$1795$index$$);$new_results_so_far$jscomp$4_parsed_result$jscomp$4$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$4$$,
$new_results_so_far$jscomp$4_parsed_result$jscomp$4$$);var $new_n_results_so_far$$=$n_results_so_far$$+1;$m$jscomp$223$$<=$new_n_results_so_far$$&&$new_n_results_so_far$$<=$n$jscomp$300$$&&$instaparse$gll$push_result$$($tramp$jscomp$24$$,$node_key$jscomp$15$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$4_parsed_result$jscomp$4$$,$continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$));return $new_n_results_so_far$$<$n$jscomp$300$$?$instaparse$gll$push_listener$$($tramp$jscomp$24$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$,$parser$jscomp$40$$],null),$instaparse$gll$RepListener$$.$cljs$core$IFn$_invoke$arity$8$?$instaparse$gll$RepListener$$.$cljs$core$IFn$_invoke$arity$8$($new_results_so_far$jscomp$4_parsed_result$jscomp$4$$,$new_n_results_so_far$$,$parser$jscomp$40$$,$m$jscomp$223$$,$n$jscomp$300$$,$continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$,$node_key$jscomp$15$$,
$tramp$jscomp$24$$):$instaparse$gll$RepListener$$($new_results_so_far$jscomp$4_parsed_result$jscomp$4$$,$new_n_results_so_far$$,$parser$jscomp$40$$,$m$jscomp$223$$,$n$jscomp$300$$,$continue_index$jscomp$4_map__76830__$1_result$jscomp$354$$,$node_key$jscomp$15$$,$tramp$jscomp$24$$)):null}},$instaparse$gll$RepFullListener$$=function $instaparse$gll$RepFullListener$$($results_so_far$jscomp$5$$,$n_results_so_far$jscomp$1$$,$parser$jscomp$41$$,$m$jscomp$224$$,$n$jscomp$301$$,$prev_index$jscomp$5$$,$node_key$jscomp$16$$,
$tramp$jscomp$25$$){return function($continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$){$continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$=$APP.$cljs$core$__destructure_map$$($continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$);var $new_results_so_far$jscomp$5_parsed_result$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$,$APP.$cljs$cst$1795$index$$);$new_results_so_far$jscomp$5_parsed_result$jscomp$5$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$5$$,$new_results_so_far$jscomp$5_parsed_result$jscomp$5$$);var $new_n_results_so_far$jscomp$1$$=$n_results_so_far$jscomp$1$$+1;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$25$$)))?$m$jscomp$224$$<=$new_n_results_so_far$jscomp$1$$&&$new_n_results_so_far$jscomp$1$$<=$n$jscomp$301$$?$instaparse$gll$push_result$$($tramp$jscomp$25$$,$node_key$jscomp$16$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$5_parsed_result$jscomp$5$$,$continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$)):null:$new_n_results_so_far$jscomp$1$$<$n$jscomp$301$$?$instaparse$gll$push_listener$$($tramp$jscomp$25$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$,$parser$jscomp$41$$],null),$instaparse$gll$RepFullListener$$.$cljs$core$IFn$_invoke$arity$8$?$instaparse$gll$RepFullListener$$.$cljs$core$IFn$_invoke$arity$8$($new_results_so_far$jscomp$5_parsed_result$jscomp$5$$,$new_n_results_so_far$jscomp$1$$,$parser$jscomp$41$$,$m$jscomp$224$$,$n$jscomp$301$$,$continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$,
$node_key$jscomp$16$$,$tramp$jscomp$25$$):$instaparse$gll$RepFullListener$$($new_results_so_far$jscomp$5_parsed_result$jscomp$5$$,$new_n_results_so_far$jscomp$1$$,$parser$jscomp$41$$,$m$jscomp$224$$,$n$jscomp$301$$,$continue_index$jscomp$5_map__76831__$1_result$jscomp$355$$,$node_key$jscomp$16$$,$tramp$jscomp$25$$)):null}};var $instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$=$APP.$cljs$cst$205$default$$,$instaparse$cfg$single_quoted_string$$=$APP.$cljs$core$re_pattern$$(/'[^'\\]*(?:\\.[^'\\]*)*'/),$instaparse$cfg$single_quoted_regexp$$=$APP.$cljs$core$re_pattern$$(/#'[^'\\]*(?:\\.[^'\\]*)*'/),$instaparse$cfg$double_quoted_string$$=$APP.$cljs$core$re_pattern$$(/"[^"\\]*(?:\\.[^"\\]*)*"/),$instaparse$cfg$double_quoted_regexp$$=$APP.$cljs$core$re_pattern$$(/#"[^"\\]*(?:\\.[^"\\]*)*"/),$instaparse$cfg$inside_comment$$=
/(?:(?!(?:\(\*|\*\)))[\s\S])*/,$instaparse$cfg$ws$$=$APP.$cljs$core$re_pattern$$("[,\\s]*"),$instaparse$cfg$opt_whitespace$$=$instaparse$combinators_source$hide$$($instaparse$combinators_source$nt$$($cljs$cst$5498$opt_whitespace$$)),$instaparse$cfg$non_terminal$$=$APP.$cljs$core$re_pattern$$("[^, \\r\\t\\n\x3c\x3e(){}\\[\\]+*?:\x3d|'\"#\x26!;./]+"),$instaparse$cfg$non_terminal_namespace_allowed$$=$APP.$cljs$core$re_pattern$$("[^, \\r\\t\\n\x3c\x3e(){}\\[\\]+*?:\x3d|'\"#\x26!;/.][^, \\r\\t\\n\x3c\x3e(){}\\[\\]+*?:\x3d|'\"#\x26!;]*"),
$instaparse$cfg$cfg$$=$instaparse$cfg$make_cfg$$(!1),$instaparse$cfg$cfg_allow_namespaced_nts$$=$instaparse$cfg$make_cfg$$(!0),$read_string_STAR__77141$$=$APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return $cljs$tools$reader$read_string_STAR_$$},$cljs$cst$5508$cljs_DOT_tools_DOT_reader_SLASH_read_string_STAR_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1478$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,
$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1479$arglists$$,$APP.$cljs$cst$1480$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$5509$cljs_DOT_tools_DOT_reader$$,$cljs$cst$5510$read_string_STAR_$$,"cljs/tools/reader.cljs",20,1,306,306,$APP.$cljs$core$list$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$with_meta$$($cljs$cst$5511$reader$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$97$not_native$$],null)),$APP.$cljs$cst$602$_$$,$APP.$cljs$cst$277$opts$$,$cljs$cst$5512$pending_forms$$],null)),null,$APP.$cljs$core$truth_$$($cljs$tools$reader$read_string_STAR_$$)?$cljs$tools$reader$read_string_STAR_$$.$cljs$lang$test$:null]))),$instaparse$cfg$build_rule$$=function $instaparse$cfg$build_rule$$($tree$jscomp$20$$){for(;;){var $G__76933_G__76933__$1_alt_or_ord_vec__76934$$=$APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):
$APP.$cljs$core$first$$($tree$jscomp$20$$);$G__76933_G__76933__$1_alt_or_ord_vec__76934$$=$G__76933_G__76933__$1_alt_or_ord_vec__76934$$ instanceof $APP.$cljs$core$Keyword$$?$G__76933_G__76933__$1_alt_or_ord_vec__76934$$.$fqn$:null;switch($G__76933_G__76933__$1_alt_or_ord_vec__76934$$){case "rule":$G__76933_G__76933__$1_alt_or_ord_vec__76934$$=$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$);
var $nt$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$,0,null);$G__76933_G__76933__$1_alt_or_ord_vec__76934$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$($nt$jscomp$2$$):$APP.$cljs$core$first$$($nt$jscomp$2$$),
$cljs$cst$5501$hide_nt$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $G__76937$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($nt$jscomp$2$$):$APP.$cljs$core$fnext$$($nt$jscomp$2$$);return $APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($G__76937$$):
$APP.$cljs$core$fnext$$($G__76937$$)}()),$instaparse$combinators_source$hide_tag$$($instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$):$instaparse$cfg$build_rule$$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$))],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($nt$jscomp$2$$):$APP.$cljs$core$fnext$$($nt$jscomp$2$$)),$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$):$instaparse$cfg$build_rule$$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$)],null);case "nt":return $instaparse$combinators_source$nt$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$)));case "alt":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$alt$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$)));case "ord":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$ord$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$)));case "paren":$tree$jscomp$20$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);continue;case "hide":return $instaparse$combinators_source$hide$$(function(){var $G__76941$$=
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76941$$):$instaparse$cfg$build_rule$$($G__76941$$)}());case "cat":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$cat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,
$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$)));case "string":return $instaparse$cfg$string_PLUS_$$($instaparse$cfg$process_string$$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$)),!1);case "regexp":return $instaparse$combinators_source$regexp$$($instaparse$cfg$process_regexp$$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$)));case "opt":return $instaparse$combinators_source$opt$$(function(){var $G__76945$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76945$$):
$instaparse$cfg$build_rule$$($G__76945$$)}());case "star":return $instaparse$combinators_source$star$$(function(){var $G__76946$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76946$$):$instaparse$cfg$build_rule$$($G__76946$$)}());case "plus":return $instaparse$combinators_source$plus$$(function(){var $G__76947$$=
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76947$$):$instaparse$cfg$build_rule$$($G__76947$$)}());case "look":return $instaparse$combinators_source$look$$(function(){var $G__76949$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76949$$):$instaparse$cfg$build_rule$$($G__76949$$)}());case "neg":return $instaparse$combinators_source$neg$$(function(){var $G__76950$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):
$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__76950$$):$instaparse$cfg$build_rule$$($G__76950$$)}());case "epsilon":return $instaparse$combinators_source$Epsilon$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76933_G__76933__$1_alt_or_ord_vec__76934$$)].join(""));}break}},$instaparse$cfg$seq_nt$$=function $instaparse$cfg$seq_nt$$($parser$jscomp$61$$){for(;;){var $G__76951_G__76951__$1$$=
$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$);$G__76951_G__76951__$1$$=$G__76951_G__76951__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76951_G__76951__$1$$.$fqn$:null;switch($G__76951_G__76951__$1$$){case "nt":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$)],null);case "string":case "string-ci":case "char":case "regexp":case "epsilon":return $APP.$cljs$core$PersistentVector$EMPTY$$;
case "opt":case "plus":case "star":case "look":case "neg":case "rep":$parser$jscomp$61$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$);continue;case "alt":case "cat":return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5443$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$)]));case "ord":return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5441$parser1$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$),$cljs$cst$5442$parser2$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$)],null)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76951_G__76951__$1$$)].join(""));}break}};var $instaparse$transform$enlive_transform$$=function $instaparse$transform$enlive_transform$$($transform_map$$,$parse_tree$$){var $G__76847$jscomp$inline_8678_transform$jscomp$105$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$);$G__76847$jscomp$inline_8678_transform$jscomp$105$$=$transform_map$$.$cljs$core$IFn$_invoke$arity$1$?$transform_map$$.$cljs$core$IFn$_invoke$arity$1$($G__76847$jscomp$inline_8678_transform$jscomp$105$$):$transform_map$$($G__76847$jscomp$inline_8678_transform$jscomp$105$$);
return $APP.$cljs$core$truth_$$($G__76847$jscomp$inline_8678_transform$jscomp$105$$)?$instaparse$transform$merge_meta$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($G__76847$jscomp$inline_8678_transform$jscomp$105$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$enlive_transform$$,$transform_map$$),$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$))),$APP.$cljs$core$meta$$($parse_tree$$)):
$APP.$cljs$core$truth_$$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parse_tree$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$enlive_transform$$,$transform_map$$),$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$))):$parse_tree$$},$instaparse$transform$hiccup_transform$$=
function $instaparse$transform$hiccup_transform$$($transform_map$jscomp$1$$,$parse_tree$jscomp$1$$){if($APP.$cljs$core$sequential_QMARK_$$($parse_tree$jscomp$1$$)&&$APP.$cljs$core$seq$$($parse_tree$jscomp$1$$)){var $G__76857$jscomp$inline_8680_temp__5823__auto__$jscomp$229$$=$APP.$cljs$core$first$$($parse_tree$jscomp$1$$);$G__76857$jscomp$inline_8680_temp__5823__auto__$jscomp$229$$=$transform_map$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$transform_map$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__76857$jscomp$inline_8680_temp__5823__auto__$jscomp$229$$):
$transform_map$jscomp$1$$($G__76857$jscomp$inline_8680_temp__5823__auto__$jscomp$229$$);return $APP.$cljs$core$truth_$$($G__76857$jscomp$inline_8680_temp__5823__auto__$jscomp$229$$)?$instaparse$transform$merge_meta$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($G__76857$jscomp$inline_8680_temp__5823__auto__$jscomp$229$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$hiccup_transform$$,$transform_map$jscomp$1$$),
$APP.$cljs$core$next$$($parse_tree$jscomp$1$$))),$APP.$cljs$core$meta$$($parse_tree$jscomp$1$$)):$APP.$cljs$core$with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($parse_tree$jscomp$1$$)],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$hiccup_transform$$,$transform_map$jscomp$1$$),
$APP.$cljs$core$next$$($parse_tree$jscomp$1$$))),$APP.$cljs$core$meta$$($parse_tree$jscomp$1$$))}return $parse_tree$jscomp$1$$},$instaparse$transform$transform$$=function $instaparse$transform$transform$$($JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$,$parse_tree$jscomp$2$$){if(typeof $parse_tree$jscomp$2$$==="string")$JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$=$parse_tree$jscomp$2$$;else{var $JSCompiler_inline_result$jscomp$1740_and__5023__auto__$jscomp$inline_8682$$=($JSCompiler_inline_result$jscomp$1740_and__5023__auto__$jscomp$inline_8682$$=
$APP.$cljs$core$map_QMARK_$$($parse_tree$jscomp$2$$))?$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$jscomp$2$$):$JSCompiler_inline_result$jscomp$1740_and__5023__auto__$jscomp$inline_8682$$;$JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1740_and__5023__auto__$jscomp$inline_8682$$)?$instaparse$transform$enlive_transform$$($JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$,$parse_tree$jscomp$2$$):$APP.$cljs$core$vector_QMARK_$$($parse_tree$jscomp$2$$)&&
$APP.$cljs$core$first$$($parse_tree$jscomp$2$$)instanceof $APP.$cljs$core$Keyword$$?$instaparse$transform$hiccup_transform$$($JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$,$parse_tree$jscomp$2$$):$APP.$cljs$core$sequential_QMARK_$$($parse_tree$jscomp$2$$)?$APP.$cljs$core$with_meta$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$transform$$,$JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$),$parse_tree$jscomp$2$$),
$APP.$cljs$core$meta$$($parse_tree$jscomp$2$$)):$parse_tree$jscomp$2$$ instanceof $instaparse$gll$Failure$$?$parse_tree$jscomp$2$$:$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid parse-tree, not recognized as either enlive or hiccup format."]))}return $JSCompiler_temp$jscomp$1739_transform_map$jscomp$2$$};var $instaparse$abnf$abnf_core$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5514$CRLF$$,$cljs$cst$5515$HTAB$$,$cljs$cst$5516$LWSP$$,$cljs$cst$5517$LF$$,$cljs$cst$5518$VCHAR$$,$cljs$cst$5519$DIGIT$$,$cljs$cst$5520$SP$$,$cljs$cst$5521$HEXDIG$$,$cljs$cst$5522$CTL$$,$cljs$cst$5523$DQUOTE$$,$cljs$cst$5524$WSP$$,$cljs$cst$5525$CR$$,$cljs$cst$5526$OCTET$$,$cljs$cst$5527$ALPHA$$,$cljs$cst$5528$CHAR$$,$cljs$cst$5529$BIT$$],[$instaparse$combinators_source$string$$("\r\n"),$instaparse$combinators_source$string$$("\t"),
$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$string$$("\t")])),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$("\r\n"),
$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$string$$("\t")]))])))])),$instaparse$combinators_source$string$$("\n"),$instaparse$combinators_source$regexp$$("[\\u0021-\\u007E]"),$instaparse$combinators_source$regexp$$("[0-9]"),$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$regexp$$("[0-9a-fA-F]"),$instaparse$combinators_source$regexp$$("[\\u0000-\\u001F|\\u007F]"),
$instaparse$combinators_source$string$$('"'),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$string$$("\t")])),$instaparse$combinators_source$string$$("\r"),$instaparse$combinators_source$regexp$$("[\\u0000-\\u00FF]"),$instaparse$combinators_source$regexp$$("[a-zA-Z]"),$instaparse$combinators_source$regexp$$("[\\u0001-\\u007F]"),$instaparse$combinators_source$regexp$$("[01]")]),
$instaparse$abnf$abnf_parser$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5462$neg$$,$APP.$cljs$cst$1608$group$$,$cljs$cst$5530$hide_tag$$,$cljs$cst$5531$whitespace$$,$cljs$cst$5532$element$$,$cljs$cst$5533$hide_tag_rule$$,$cljs$cst$5461$look$$,$cljs$cst$5534$bin_char$$,$cljs$cst$5500$rule$$,$cljs$cst$5535$rulename_right$$,$cljs$cst$5519$DIGIT$$,$cljs$cst$5536$NUM$$,$cljs$cst$5537$char_val$$,$cljs$cst$5538$num_val$$,$APP.$cljs$cst$2345$hide$$,$cljs$cst$5539$defined_as$$,$cljs$cst$5521$HEXDIG$$,
$cljs$cst$5540$option$$,$cljs$cst$5541$hex_char$$,$cljs$cst$5542$rulename$$,$cljs$cst$5543$bin_val$$,$cljs$cst$5544$dec_val$$,$cljs$cst$5545$concatenation$$,$cljs$cst$5546$alternation$$,$cljs$cst$5444$regexp$$,$cljs$cst$5547$repetition$$,$cljs$cst$5548$rulename_left$$,$cljs$cst$5549$rulelist$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$716$repeat$$,$cljs$cst$5550$hex_val$$,$cljs$cst$5551$dec_char$$,$cljs$cst$5507$rules_or_parser$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"!"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5532$element$$],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5462$neg$$],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"("],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5546$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,")"],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,
"\x3c"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5548$rulename_left$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3e"],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),
null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("\\s+(?:;.*?\\u000D?\\u000A\\s*)*"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,
$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5531$whitespace$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5535$rulename_right$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$1608$group$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$2345$hide$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5540$option$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5537$char_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5538$num_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5461$look$$],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5462$neg$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5444$regexp$$],null),null,1,null),2,null),3,null),4,null),5,null),6,null),7,null),8,null),9,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,
$APP.$cljs$cst$561$raw$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5530$hide_tag$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,
$cljs$cst$5539$defined_as$$,$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5546$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,
null),4,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5533$hide_tag_rule$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x26"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5532$element$$],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5461$look$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"0"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"1"],null),null,1,null),2,null)],null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5534$bin_char$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5548$rulename_left$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5539$defined_as$$,$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5546$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],
null),null,1,null),2,null),3,null),4,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5500$rule$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5542$rulename$$,$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5535$rulename_right$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[0-9]"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5519$DIGIT$$],null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5536$NUM$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,'"',$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5456$star$$,$APP.$cljs$cst$646$parser$$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[\\u0020-\\u0021\\u0023-\\u007E]"),$APP.$cljs$core$PersistentArrayMap$EMPTY$$]))],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,'"',$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,null)],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"'",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5456$star$$,$APP.$cljs$cst$646$parser$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[\\u0020-\\u0026(-~]"),
$APP.$cljs$core$PersistentArrayMap$EMPTY$$]))],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"'",$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,null)],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5537$char_val$$],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"%",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5543$bin_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5544$dec_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5550$hex_val$$],
null),null,1,null),2,null),3,null)],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3c"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5546$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3e"],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2345$hide$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,
"\x3d"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3d/"],null),null,1,null),2,null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5539$defined_as$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[0-9a-fA-F]"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)])),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"["],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5546$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"]"],null),null,1,null),2,null),$APP.$cljs$cst$2345$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5540$option$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5521$HEXDIG$$],null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,
$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5541$hex_char$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[a-zA-Z][-a-zA-Z0-9]*"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"b",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5534$bin_char$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,".",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5534$bin_char$$],null),null,1,null),2,null)],null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,
$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"-"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5534$bin_char$$],null),null,1,null),2,null)],null),null,1,null),2,null)],null)],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5543$bin_val$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"d",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5551$dec_char$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,".",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5551$dec_char$$],null),null,1,null),2,null)],null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"-"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5551$dec_char$$],null),null,1,null),2,null)],null),null,1,null),2,null)],null)],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5544$dec_val$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5547$repetition$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5456$star$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5531$whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5547$repetition$$],null),null,1,null),2,null)],null)],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5545$concatenation$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5545$concatenation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5456$star$$,
$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"/"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$],null),null,1,null),2,null),3,null),$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5545$concatenation$$],null),null,1,null),2,null)],null)],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5546$alternation$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("#'[^'\\\\]*(?:\\\\.[^'\\\\]*)*'"),
$APP.$cljs$core$PersistentArrayMap$EMPTY$$])),new $APP.$cljs$core$List$$(null,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$('#\\"[^\\"\\\\]*(?:\\\\.[^\\"\\\\]*)*\\"'),$APP.$cljs$core$PersistentArrayMap$EMPTY$$])),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,
$cljs$cst$5444$regexp$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$716$repeat$$],null)],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5532$element$$],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,
$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5547$repetition$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5542$rulename$$,$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5548$rulename_left$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5498$opt_whitespace$$,$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5500$rule$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5533$hide_tag_rule$$],null),null,1,null),2,null)],null)],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("\\s*(?:;.*?(?:\\u000D?\\u000A\\s*|$))*"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5498$opt_whitespace$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5536$NUM$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,
$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5536$NUM$$],null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,
"*"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5536$NUM$$],null)],null),null,1,null),2,null),3,null)],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,
$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$716$repeat$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"x",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5541$hex_char$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,".",$APP.$cljs$cst$2345$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5541$hex_char$$],null),null,1,null),2,null)],null)],null),
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"-"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5541$hex_char$$],
null),null,1,null),2,null)],null),null,1,null),2,null)],null)],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5550$hex_val$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5455$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5519$DIGIT$$],null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5445$reduction_type$$,$cljs$cst$5452$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5551$dec_char$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5443$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5549$rulelist$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5460$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5546$alternation$$],null),null,1,null),2,null),$APP.$cljs$cst$5446$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5445$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)]),$instaparse$abnf$get_char_combinator$$=function $instaparse$abnf$get_char_combinator$$($var_args$jscomp$1428$$){for(var $args__5755__auto__$jscomp$249$$=
[],$len__5749__auto___77595$$=arguments.length,$i__5750__auto___77596$$=0;;)if($i__5750__auto___77596$$<$len__5749__auto___77595$$)$args__5755__auto__$jscomp$249$$.push(arguments[$i__5750__auto___77596$$]),$i__5750__auto___77596$$+=1;else break;return $instaparse$abnf$get_char_combinator$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$249$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$249$$.slice(0),0,null):null)};
$instaparse$abnf$get_char_combinator$$.$cljs$core$IFn$_invoke$arity$variadic$=function($nums$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("-",$APP.$cljs$core$second$$($nums$$))){var $lo$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nums$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nums$$,1,null);var $hi$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nums$$,2,null);return $instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$($lo$jscomp$9$$,
$hi$jscomp$11$$)}return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$cat$$,function(){return function $instaparse$abnf$iter__77528$$($s__77529$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__77529__$2_temp__5825__auto__$jscomp$345$$=$APP.$cljs$core$seq$$($s__77529$$);if($s__77529__$2_temp__5825__auto__$jscomp$345$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__77529__$2_temp__5825__auto__$jscomp$345$$)){var $JSCompiler_inline_result$jscomp$1741_c__5501__auto__$jscomp$45$$=
$APP.$cljs$core$_chunked_first$$($s__77529__$2_temp__5825__auto__$jscomp$345$$),$size__5502__auto__$jscomp$45$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1741_c__5501__auto__$jscomp$45$$),$b__77531_n$jscomp$304$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$45$$);a:{for(var $i__77530$jscomp$inline_8684$$=0;;)if($i__77530$jscomp$inline_8684$$<$size__5502__auto__$jscomp$45$$){var $n$jscomp$inline_8685$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1741_c__5501__auto__$jscomp$45$$,
$i__77530$jscomp$inline_8684$$);$b__77531_n$jscomp$304$$.add($instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$inline_8685$$,$n$jscomp$inline_8685$$));$i__77530$jscomp$inline_8684$$+=1}else{$JSCompiler_inline_result$jscomp$1741_c__5501__auto__$jscomp$45$$=!0;break a}$JSCompiler_inline_result$jscomp$1741_c__5501__auto__$jscomp$45$$=void 0}return $JSCompiler_inline_result$jscomp$1741_c__5501__auto__$jscomp$45$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77531_n$jscomp$304$$),
$instaparse$abnf$iter__77528$$($APP.$cljs$core$_chunked_rest$$($s__77529__$2_temp__5825__auto__$jscomp$345$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77531_n$jscomp$304$$),null)}$b__77531_n$jscomp$304$$=$APP.$cljs$core$first$$($s__77529__$2_temp__5825__auto__$jscomp$345$$);return $APP.$cljs$core$cons$$($instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$($b__77531_n$jscomp$304$$,$b__77531_n$jscomp$304$$),$instaparse$abnf$iter__77528$$($APP.$cljs$core$rest$$($s__77529__$2_temp__5825__auto__$jscomp$345$$)))}return null}},
null,null)}($nums$$)}())};$instaparse$abnf$get_char_combinator$$.$cljs$lang$maxFixedArity$=0;$instaparse$abnf$get_char_combinator$$.$cljs$lang$applyTo$=function($seq77523$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq77523$$))};
var $instaparse$abnf$parse_int$$=parseInt,$instaparse$abnf$abnf_transformer$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5462$neg$$,$cljs$cst$5533$hide_tag_rule$$,$cljs$cst$5461$look$$,$cljs$cst$5534$bin_char$$,$cljs$cst$5500$rule$$,$cljs$cst$5535$rulename_right$$,$cljs$cst$5536$NUM$$,$cljs$cst$5537$char_val$$,$APP.$cljs$cst$2345$hide$$,$cljs$cst$5540$option$$,$cljs$cst$5541$hex_char$$,$cljs$cst$5543$bin_val$$,$cljs$cst$5544$dec_val$$,$cljs$cst$5545$concatenation$$,$cljs$cst$5546$alternation$$,
$cljs$cst$5444$regexp$$,$cljs$cst$5547$repetition$$,$cljs$cst$5548$rulename_left$$,$APP.$cljs$cst$716$repeat$$,$cljs$cst$5550$hex_val$$,$cljs$cst$5551$dec_char$$],[$instaparse$combinators_source$neg$$,function($tag$jscomp$93$$,$rule$jscomp$4$$){return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$tag$jscomp$93$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($rule$jscomp$4$$,$APP.$cljs$cst$5446$red$$,$instaparse$reduction$raw_non_terminal_reduction$$)])},$instaparse$combinators_source$look$$,
function(){function $G__77610$$($var_args$jscomp$1429$$){var $G__77611__i_cs$jscomp$5$$=null;if(arguments.length>0){$G__77611__i_cs$jscomp$5$$=0;for(var $G__77611__a$$=Array(arguments.length-0);$G__77611__i_cs$jscomp$5$$<$G__77611__a$$.length;)$G__77611__a$$[$G__77611__i_cs$jscomp$5$$]=arguments[$G__77611__i_cs$jscomp$5$$+0],++$G__77611__i_cs$jscomp$5$$;$G__77611__i_cs$jscomp$5$$=new $APP.$cljs$core$IndexedSeq$$($G__77611__a$$,0,null)}return $G__77610__delegate$$.call(this,$G__77611__i_cs$jscomp$5$$)}
function $G__77610__delegate$$($G__77545_cs$jscomp$4$$){$G__77545_cs$jscomp$4$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77545_cs$jscomp$4$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$($G__77545_cs$jscomp$4$$,2):$instaparse$abnf$parse_int$$($G__77545_cs$jscomp$4$$,2)}$G__77610$$.$cljs$lang$maxFixedArity$=0;$G__77610$$.$cljs$lang$applyTo$=function($arglist__77612_cs$jscomp$6$$){$arglist__77612_cs$jscomp$6$$=
$APP.$cljs$core$seq$$($arglist__77612_cs$jscomp$6$$);return $G__77610__delegate$$($arglist__77612_cs$jscomp$6$$)};$G__77610$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77610__delegate$$;return $G__77610$$}(),$APP.$cljs$core$hash_map$$,function(){function $G__77613$$($var_args$jscomp$1430$$){var $G__77614__i_rest__77543_SHARP_$jscomp$1$$=null;if(arguments.length>0){$G__77614__i_rest__77543_SHARP_$jscomp$1$$=0;for(var $G__77614__a$$=Array(arguments.length-0);$G__77614__i_rest__77543_SHARP_$jscomp$1$$<
$G__77614__a$$.length;)$G__77614__a$$[$G__77614__i_rest__77543_SHARP_$jscomp$1$$]=arguments[$G__77614__i_rest__77543_SHARP_$jscomp$1$$+0],++$G__77614__i_rest__77543_SHARP_$jscomp$1$$;$G__77614__i_rest__77543_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__77614__a$$,0,null)}return $G__77613__delegate$$.call(this,$G__77614__i_rest__77543_SHARP_$jscomp$1$$)}function $G__77613__delegate$$($rest__77543_SHARP_$$){return $APP.$cljs$core$truth_$$(!1)?$instaparse$combinators_source$nt$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$string$upper_case$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$rest__77543_SHARP_$$)))):$instaparse$combinators_source$nt$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$rest__77543_SHARP_$$)))}$G__77613$$.$cljs$lang$maxFixedArity$=0;$G__77613$$.$cljs$lang$applyTo$=function($arglist__77615_rest__77543_SHARP_$jscomp$2$$){$arglist__77615_rest__77543_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__77615_rest__77543_SHARP_$jscomp$2$$);return $G__77613__delegate$$($arglist__77615_rest__77543_SHARP_$jscomp$2$$)};
$G__77613$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77613__delegate$$;return $G__77613$$}(),function(){function $G__77616$$($var_args$jscomp$1431$$){var $G__77617__i_rest__77544_SHARP_$jscomp$1$$=null;if(arguments.length>0){$G__77617__i_rest__77544_SHARP_$jscomp$1$$=0;for(var $G__77617__a$$=Array(arguments.length-0);$G__77617__i_rest__77544_SHARP_$jscomp$1$$<$G__77617__a$$.length;)$G__77617__a$$[$G__77617__i_rest__77544_SHARP_$jscomp$1$$]=arguments[$G__77617__i_rest__77544_SHARP_$jscomp$1$$+0],
++$G__77617__i_rest__77544_SHARP_$jscomp$1$$;$G__77617__i_rest__77544_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__77617__a$$,0,null)}return $G__77616__delegate$$.call(this,$G__77617__i_rest__77544_SHARP_$jscomp$1$$)}function $G__77616__delegate$$($G__77547_rest__77544_SHARP_$$){$G__77547_rest__77544_SHARP_$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77547_rest__77544_SHARP_$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$($G__77547_rest__77544_SHARP_$$):
$instaparse$abnf$parse_int$$($G__77547_rest__77544_SHARP_$$)}$G__77616$$.$cljs$lang$maxFixedArity$=0;$G__77616$$.$cljs$lang$applyTo$=function($arglist__77618_rest__77544_SHARP_$jscomp$2$$){$arglist__77618_rest__77544_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__77618_rest__77544_SHARP_$jscomp$2$$);return $G__77616__delegate$$($arglist__77618_rest__77544_SHARP_$jscomp$2$$)};$G__77616$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77616__delegate$$;return $G__77616$$}(),function(){function $G__77619$$($var_args$jscomp$1432$$){var $G__77620__i_cs$jscomp$8$$=
null;if(arguments.length>0){$G__77620__i_cs$jscomp$8$$=0;for(var $G__77620__a$$=Array(arguments.length-0);$G__77620__i_cs$jscomp$8$$<$G__77620__a$$.length;)$G__77620__a$$[$G__77620__i_cs$jscomp$8$$]=arguments[$G__77620__i_cs$jscomp$8$$+0],++$G__77620__i_cs$jscomp$8$$;$G__77620__i_cs$jscomp$8$$=new $APP.$cljs$core$IndexedSeq$$($G__77620__a$$,0,null)}return $G__77619__delegate$$.call(this,$G__77620__i_cs$jscomp$8$$)}function $G__77619__delegate$$($cs$jscomp$7$$){return $instaparse$cfg$string_PLUS_$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$cs$jscomp$7$$),!0)}$G__77619$$.$cljs$lang$maxFixedArity$=0;$G__77619$$.$cljs$lang$applyTo$=function($arglist__77621_cs$jscomp$9$$){$arglist__77621_cs$jscomp$9$$=$APP.$cljs$core$seq$$($arglist__77621_cs$jscomp$9$$);return $G__77619__delegate$$($arglist__77621_cs$jscomp$9$$)};$G__77619$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77619__delegate$$;return $G__77619$$}(),$instaparse$combinators_source$hide$$,$instaparse$combinators_source$opt$$,function(){function $G__77622$$($var_args$jscomp$1433$$){var $G__77624__i_cs$jscomp$11$$=
null;if(arguments.length>0){$G__77624__i_cs$jscomp$11$$=0;for(var $G__77624__a$$=Array(arguments.length-0);$G__77624__i_cs$jscomp$11$$<$G__77624__a$$.length;)$G__77624__a$$[$G__77624__i_cs$jscomp$11$$]=arguments[$G__77624__i_cs$jscomp$11$$+0],++$G__77624__i_cs$jscomp$11$$;$G__77624__i_cs$jscomp$11$$=new $APP.$cljs$core$IndexedSeq$$($G__77624__a$$,0,null)}return $G__77622__delegate$$.call(this,$G__77624__i_cs$jscomp$11$$)}function $G__77622__delegate$$($G__77548_cs$jscomp$10$$){$G__77548_cs$jscomp$10$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77548_cs$jscomp$10$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$($G__77548_cs$jscomp$10$$,16):$instaparse$abnf$parse_int$$($G__77548_cs$jscomp$10$$,16)}$G__77622$$.$cljs$lang$maxFixedArity$=0;$G__77622$$.$cljs$lang$applyTo$=function($arglist__77625_cs$jscomp$12$$){$arglist__77625_cs$jscomp$12$$=$APP.$cljs$core$seq$$($arglist__77625_cs$jscomp$12$$);
return $G__77622__delegate$$($arglist__77625_cs$jscomp$12$$)};$G__77622$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77622__delegate$$;return $G__77622$$}(),$instaparse$abnf$get_char_combinator$$,$instaparse$abnf$get_char_combinator$$,$instaparse$combinators_source$cat$$,$instaparse$combinators_source$alt$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$regexp$$,$instaparse$cfg$process_regexp$$),function(){function $G__77628__2$$($repeat$$,$element$jscomp$79$$){return $APP.$cljs$core$empty_QMARK_$$($repeat$$)?
$instaparse$combinators_source$star$$($element$jscomp$79$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($repeat$$),2)?$instaparse$combinators_source$rep$$($cljs$cst$5552$low$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),$cljs$cst$5553$high$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),$element$jscomp$79$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5552$low$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),1)?$instaparse$combinators_source$plus$$($element$jscomp$79$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5553$high$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),1)?$instaparse$combinators_source$opt$$($element$jscomp$79$$):$instaparse$combinators_source$rep$$(function(){var $or__5025__auto__$jscomp$1060$$=$cljs$cst$5552$low$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1060$$)?$or__5025__auto__$jscomp$1060$$:0}(),function(){var $or__5025__auto__$jscomp$1061$$=$cljs$cst$5553$high$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1061$$)?$or__5025__auto__$jscomp$1061$$:Infinity}(),$element$jscomp$79$$)}var $G__77628$$=null;$G__77628$$=function($repeat$jscomp$1$$,$element$jscomp$80$$){switch(arguments.length){case 1:return $repeat$jscomp$1$$;case 2:return $G__77628__2$$.call(this,$repeat$jscomp$1$$,$element$jscomp$80$$)}throw Error("Invalid arity: "+arguments.length);};$G__77628$$.$cljs$core$IFn$_invoke$arity$1$=function($element$jscomp$78$$){return $element$jscomp$78$$};
$G__77628$$.$cljs$core$IFn$_invoke$arity$2$=$G__77628__2$$;return $G__77628$$}(),function(){function $G__77630$$($var_args$jscomp$1434$$){var $G__77631__i_rest__77541_SHARP_$jscomp$1$$=null;if(arguments.length>0){$G__77631__i_rest__77541_SHARP_$jscomp$1$$=0;for(var $G__77631__a$$=Array(arguments.length-0);$G__77631__i_rest__77541_SHARP_$jscomp$1$$<$G__77631__a$$.length;)$G__77631__a$$[$G__77631__i_rest__77541_SHARP_$jscomp$1$$]=arguments[$G__77631__i_rest__77541_SHARP_$jscomp$1$$+0],++$G__77631__i_rest__77541_SHARP_$jscomp$1$$;
$G__77631__i_rest__77541_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__77631__a$$,0,null)}return $G__77630__delegate$$.call(this,$G__77631__i_rest__77541_SHARP_$jscomp$1$$)}function $G__77630__delegate$$($rest__77541_SHARP_$$){return $APP.$cljs$core$truth_$$(!1)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$string$upper_case$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$rest__77541_SHARP_$$))):$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$rest__77541_SHARP_$$))}$G__77630$$.$cljs$lang$maxFixedArity$=0;$G__77630$$.$cljs$lang$applyTo$=function($arglist__77632_rest__77541_SHARP_$jscomp$2$$){$arglist__77632_rest__77541_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__77632_rest__77541_SHARP_$jscomp$2$$);return $G__77630__delegate$$($arglist__77632_rest__77541_SHARP_$jscomp$2$$)};$G__77630$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77630__delegate$$;return $G__77630$$}(),function(){function $G__77633$$($var_args$jscomp$1435$$){var $G__77637__i_items$jscomp$54$$=
null;if(arguments.length>0){$G__77637__i_items$jscomp$54$$=0;for(var $G__77637__a$$=Array(arguments.length-0);$G__77637__i_items$jscomp$54$$<$G__77637__a$$.length;)$G__77637__a$$[$G__77637__i_items$jscomp$54$$]=arguments[$G__77637__i_items$jscomp$54$$+0],++$G__77637__i_items$jscomp$54$$;$G__77637__i_items$jscomp$54$$=new $APP.$cljs$core$IndexedSeq$$($G__77637__a$$,0,null)}return $G__77633__delegate$$.call(this,$G__77637__i_items$jscomp$54$$)}function $G__77633__delegate$$($items$jscomp$53$$){var $G__77550$$=
$APP.$cljs$core$count$$($items$jscomp$53$$);switch($G__77550$$){case 1:return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($items$jscomp$53$$),"*")?$APP.$cljs$core$PersistentArrayMap$EMPTY$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5552$low$$,$APP.$cljs$core$first$$($items$jscomp$53$$),$cljs$cst$5553$high$$,$APP.$cljs$core$first$$($items$jscomp$53$$)],null);case 2:return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($items$jscomp$53$$),
"*")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5553$high$$,$APP.$cljs$core$second$$($items$jscomp$53$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5552$low$$,$APP.$cljs$core$first$$($items$jscomp$53$$)],null);case 3:return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5552$low$$,$APP.$cljs$core$first$$($items$jscomp$53$$),$cljs$cst$5553$high$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($items$jscomp$53$$,2)],null);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77550$$)].join(""));}}$G__77633$$.$cljs$lang$maxFixedArity$=0;$G__77633$$.$cljs$lang$applyTo$=function($arglist__77638_items$jscomp$55$$){$arglist__77638_items$jscomp$55$$=$APP.$cljs$core$seq$$($arglist__77638_items$jscomp$55$$);return $G__77633__delegate$$($arglist__77638_items$jscomp$55$$)};$G__77633$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77633__delegate$$;return $G__77633$$}(),$instaparse$abnf$get_char_combinator$$,function(){function $G__77639$$($var_args$jscomp$1436$$){var $G__77641__i_cs$jscomp$14$$=
null;if(arguments.length>0){$G__77641__i_cs$jscomp$14$$=0;for(var $G__77641__a$$=Array(arguments.length-0);$G__77641__i_cs$jscomp$14$$<$G__77641__a$$.length;)$G__77641__a$$[$G__77641__i_cs$jscomp$14$$]=arguments[$G__77641__i_cs$jscomp$14$$+0],++$G__77641__i_cs$jscomp$14$$;$G__77641__i_cs$jscomp$14$$=new $APP.$cljs$core$IndexedSeq$$($G__77641__a$$,0,null)}return $G__77639__delegate$$.call(this,$G__77641__i_cs$jscomp$14$$)}function $G__77639__delegate$$($G__77553_cs$jscomp$13$$){$G__77553_cs$jscomp$13$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77553_cs$jscomp$13$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$($G__77553_cs$jscomp$13$$):$instaparse$abnf$parse_int$$($G__77553_cs$jscomp$13$$)}$G__77639$$.$cljs$lang$maxFixedArity$=0;$G__77639$$.$cljs$lang$applyTo$=function($arglist__77643_cs$jscomp$15$$){$arglist__77643_cs$jscomp$15$$=$APP.$cljs$core$seq$$($arglist__77643_cs$jscomp$15$$);
return $G__77639__delegate$$($arglist__77643_cs$jscomp$15$$)};$G__77639$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__77639__delegate$$;return $G__77639$$}()]);var $instaparse$repeat$failure_signal$$=new $instaparse$gll$Failure$$(null,null,null,null,null),$instaparse$repeat$get_end$$=function $instaparse$repeat$get_end$$($var_args$jscomp$1438$$){switch(arguments.length){case 1:return $instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$1$=function($parse$jscomp$5$$){var $end$jscomp$102_vec__76850$$=$instaparse$viz$span$$($parse$jscomp$5$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$102_vec__76850$$,0,null);$end$jscomp$102_vec__76850$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$102_vec__76850$$,1,null);return $APP.$cljs$core$truth_$$($end$jscomp$102_vec__76850$$)?$APP.$cljs$core$fix$$($end$jscomp$102_vec__76850$$):$APP.$cljs$core$count$$($parse$jscomp$5$$)};
$instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$2$=function($parse$jscomp$6$$,$index$jscomp$452$$){var $end$jscomp$103_vec__76853$$=$instaparse$viz$span$$($parse$jscomp$6$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$103_vec__76853$$,0,null);$end$jscomp$103_vec__76853$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$103_vec__76853$$,1,null);return $APP.$cljs$core$truth_$$($end$jscomp$103_vec__76853$$)?$APP.$cljs$core$fix$$($end$jscomp$103_vec__76853$$):
$index$jscomp$452$$+$APP.$cljs$core$count$$($parse$jscomp$6$$)};$instaparse$repeat$get_end$$.$cljs$lang$maxFixedArity$=2;var $instaparse$core$parse$$=function $instaparse$core$parse$$($var_args$jscomp$1444$$){for(var $args__5755__auto__$jscomp$251$$=[],$len__5749__auto___78006$$=arguments.length,$i__5750__auto___78007$$=0;;)if($i__5750__auto___78007$$<$len__5749__auto___78006$$)$args__5755__auto__$jscomp$251$$.push(arguments[$i__5750__auto___78007$$]),$i__5750__auto___78007$$+=1;else break;return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$251$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$251$$.slice(2),0,null):null)};
$instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,$p__77931_start_production$jscomp$5$$){var $JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$=$APP.$cljs$core$__destructure_map$$($p__77931_start_production$jscomp$5$$);
$p__77931_start_production$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,$APP.$cljs$cst$1292$start$$,$cljs$cst$5448$start_production$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$));var $build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,
$APP.$cljs$cst$2125$partial$$,!1),$JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,$cljs$cst$5554$optimize$$,!1),$fail_index$jscomp$inline_14650_unhide$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,$cljs$cst$5562$unhide$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,
$APP.$cljs$cst$144$trace$$,!1);$G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$=$instaparse$core$unhide_parser$$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$,$fail_index$jscomp$inline_14650_unhide$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2328$total$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$))?($JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$=
$cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$),$G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$=$cljs$cst$5513$output_format$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$),$JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$=$instaparse$reduction$node_builders$$.$cljs$core$IFn$_invoke$arity$1$?
$instaparse$reduction$node_builders$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$):$instaparse$reduction$node_builders$$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$),$G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$=$instaparse$gll$parse$$($JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$,
$p__77931_start_production$jscomp$5$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,$build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$),$G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$ instanceof $instaparse$gll$Failure$$?($fail_index$jscomp$inline_14650_unhide$jscomp$1$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$),
$JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$=$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$($JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,$fail_index$jscomp$inline_14650_unhide$jscomp$1$$,
$JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$),$instaparse$gll$start_parser$$($JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$,$instaparse$combinators_source$nt$$($p__77931_start_production$jscomp$5$$),$build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$),$build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$=$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$,
null),$APP.$cljs$core$truth_$$($build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$)?$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$=$APP.$cljs$core$first$$($build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$):($build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$=
$instaparse$gll$build_node_with_meta$$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,$cljs$cst$5493$instaparse_SLASH_failure$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,0,$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$)),$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$=
$instaparse$gll$build_node_with_meta$$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$,$p__77931_start_production$jscomp$5$$,$build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$,0,$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$))),$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$=
$APP.$cljs$core$with_meta$$($JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$,$APP.$cljs$core$meta$$($JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$)])))):
$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$=$G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$)?$APP.$cljs$core$not$$($build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$):
$JSCompiler_temp_const$jscomp$11022_optimize_QMARK__tramp$jscomp$inline_14651$$)?($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$=$instaparse$repeat$try_repeating_parse_strategy$$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,$p__77931_start_production$jscomp$5$$),$APP.$cljs$core$truth_$$($instaparse$core$failure_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$instaparse$core$failure_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$):$instaparse$core$failure_QMARK_$$($JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$))?$instaparse$gll$parse$$($cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$),$p__77931_start_production$jscomp$5$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,
$build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$):$JSCompiler_inline_result$jscomp$11023_options$jscomp$603_result$jscomp$361$$):$instaparse$gll$parse$$($cljs$cst$5447$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__77934$jscomp$inline_13497_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14647$$),$p__77931_start_production$jscomp$5$$,$JSCompiler_inline_result$jscomp$inline_14649_JSCompiler_temp$jscomp$inline_14648_JSCompiler_temp$jscomp$inline_14653_text$jscomp$126$$,
$build_failure_node$jscomp$inline_14654_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14652$$)};$instaparse$core$parse$$.$cljs$lang$maxFixedArity$=2;
$instaparse$core$parse$$.$cljs$lang$applyTo$=function($G__77930_seq77928$$){var $G__77929$$=$APP.$cljs$core$first$$($G__77930_seq77928$$),$seq77928__$1_seq77928__$2$$=$APP.$cljs$core$next$$($G__77930_seq77928$$);$G__77930_seq77928$$=$APP.$cljs$core$first$$($seq77928__$1_seq77928__$2$$);$seq77928__$1_seq77928__$2$$=$APP.$cljs$core$next$$($seq77928__$1_seq77928__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__77929$$,$G__77930_seq77928$$,$seq77928__$1_seq77928__$2$$)};
$APP.$JSCompiler_prototypeAlias$$=$instaparse$core$Parser$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$39$$,$k__5324__auto__$jscomp$39$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$39$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$39$$,$k77947$$,$else__5326__auto__$jscomp$39$$){switch($k77947$$ instanceof $APP.$cljs$core$Keyword$$?$k77947$$.$fqn$:null){case "grammar":return this.$grammar$;case "start-production":return this.$start_production$;case "output-format":return this.$output_format$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k77947$$,$else__5326__auto__$jscomp$39$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$39$$,$f__5344__auto__$jscomp$39$$,$init__5345__auto__$jscomp$39$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$39$$,$p__77953_v__5348__auto__$jscomp$39$$){var $k__5347__auto__$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77953_v__5348__auto__$jscomp$39$$,0,null);$p__77953_v__5348__auto__$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77953_v__5348__auto__$jscomp$39$$,
1,null);return $f__5344__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$39$$,$k__5347__auto__$jscomp$39$$,$p__77953_v__5348__auto__$jscomp$39$$):$f__5344__auto__$jscomp$39$$($ret__5346__auto__$jscomp$39$$,$k__5347__auto__$jscomp$39$$,$p__77953_v__5348__auto__$jscomp$39$$)},$init__5345__auto__$jscomp$39$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$39$$,$writer__5339__auto__$jscomp$39$$,$opts__5340__auto__$jscomp$39$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$39$$,function($keyval__5342__auto__$jscomp$39$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$39$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$39$$,$keyval__5342__auto__$jscomp$39$$)},"#instaparse.core.Parser{",
", ","}",$opts__5340__auto__$jscomp$39$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5447$grammar$$,this.$grammar$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5448$start_production$$,this.$start_production$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5513$output_format$$,this.$output_format$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,3,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5447$grammar$$,$cljs$cst$5448$start_production$$,$cljs$cst$5513$output_format$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 3+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$=this.$__hash$;return $h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$!=null?$h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$:this.$__hash$=$h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$=-360509877^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this77948$$,$other77949$$){return $other77949$$!=null&&this.constructor===$other77949$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$grammar$,$other77949$$.$grammar$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_production$,$other77949$$.$start_production$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$output_format$,$other77949$$.$output_format$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$other77949$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$39$$,$k__5334__auto__$jscomp$39$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5448$start_production$$,null,$cljs$cst$5447$grammar$$,null,$cljs$cst$5513$output_format$$,null],null),null),$k__5334__auto__$jscomp$39$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),
this.$__meta$),$k__5334__auto__$jscomp$39$$):new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$39$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$39$$,$k77947$jscomp$1$$){switch($k77947$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k77947$jscomp$1$$.$fqn$:null){case "grammar":case "start-production":case "output-format":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k77947$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$39$$,$k__5332__auto__$jscomp$39$$,$G__77946$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5447$grammar$$,$k__5332__auto__$jscomp$39$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5447$grammar$$,$k__5332__auto__$jscomp$39$$))?
new $instaparse$core$Parser$$($G__77946$jscomp$1$$,this.$start_production$,this.$output_format$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5448$start_production$$,$k__5332__auto__$jscomp$39$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5448$start_production$$,$k__5332__auto__$jscomp$39$$))?new $instaparse$core$Parser$$(this.$grammar$,
$G__77946$jscomp$1$$,this.$output_format$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5513$output_format$$,$k__5332__auto__$jscomp$39$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5513$output_format$$,$k__5332__auto__$jscomp$39$$))?new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,$G__77946$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$39$$,$G__77946$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$5447$grammar$$,this.$grammar$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5448$start_production$$,this.$start_production$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5513$output_format$$,this.$output_format$,
null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$39$$,$G__77946$jscomp$2$$){return new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,$G__77946$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$39$$,$entry__5329__auto__$jscomp$39$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$39$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$39$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$39$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$39$$)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$32$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 3:return this.$cljs$core$IFn$_invoke$arity$3$(arguments[1],arguments[2],arguments[3]);case 5:return this.$cljs$core$IFn$_invoke$arity$5$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 7:return this.$cljs$core$IFn$_invoke$arity$7$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],
arguments[7]);case 9:return this.$cljs$core$IFn$_invoke$arity$9$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);case 11:return this.$cljs$core$IFn$_invoke$arity$11$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11]);case 13:return this.$cljs$core$IFn$_invoke$arity$13$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],
arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13]);case 15:return this.$cljs$core$IFn$_invoke$arity$15$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15]);case 17:return this.$cljs$core$IFn$_invoke$arity$17$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],
arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17]);case 19:return this.$cljs$core$IFn$_invoke$arity$19$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19]);case 21:return this.$cljs$core$IFn$_invoke$arity$21$(arguments[1],
arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20],arguments[21]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7416$$,$args77951$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args77951$$)))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($text$jscomp$128$$){return $instaparse$core$parse$$(this,$text$jscomp$128$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$3$=function($text$jscomp$129$$,$key1$jscomp$3$$,$val1$jscomp$7$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$129$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key1$jscomp$3$$,$val1$jscomp$7$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$5$=function($text$jscomp$130$$,$key1$jscomp$4$$,$val1$jscomp$8$$,$key2$jscomp$3$$,$val2$jscomp$7$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$130$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key1$jscomp$4$$,$val1$jscomp$8$$,$key2$jscomp$3$$,$val2$jscomp$7$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$7$=function($text$jscomp$131$$,$key1$jscomp$5$$,$val1$jscomp$9$$,$key2$jscomp$4$$,$val2$jscomp$8$$,$key3$jscomp$1$$,$val3$jscomp$1$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$131$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key1$jscomp$5$$,$val1$jscomp$9$$,$key2$jscomp$4$$,$val2$jscomp$8$$,$key3$jscomp$1$$,$val3$jscomp$1$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$9$=function($text$jscomp$132$$,$a$jscomp$420$$,$b$jscomp$343$$,$c$jscomp$305$$,$d$jscomp$236$$,$e$jscomp$343$$,$f$jscomp$856$$,$g$jscomp$144$$,$h$jscomp$170$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$132$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$420$$,$b$jscomp$343$$,$c$jscomp$305$$,$d$jscomp$236$$,$e$jscomp$343$$,$f$jscomp$856$$,$g$jscomp$144$$,$h$jscomp$170$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$11$=function($text$jscomp$133$$,$a$jscomp$421$$,$b$jscomp$344$$,$c$jscomp$306$$,$d$jscomp$237$$,$e$jscomp$344$$,$f$jscomp$857$$,$g$jscomp$145$$,$h$jscomp$171$$,$i$jscomp$521$$,$j$jscomp$115$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$133$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$421$$,$b$jscomp$344$$,$c$jscomp$306$$,$d$jscomp$237$$,$e$jscomp$344$$,$f$jscomp$857$$,
$g$jscomp$145$$,$h$jscomp$171$$,$i$jscomp$521$$,$j$jscomp$115$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$13$=function($text$jscomp$134$$,$a$jscomp$422$$,$b$jscomp$345$$,$c$jscomp$307$$,$d$jscomp$238$$,$e$jscomp$345$$,$f$jscomp$858$$,$g$jscomp$146$$,$h$jscomp$172$$,$i$jscomp$522$$,$j$jscomp$116$$,$k$jscomp$684$$,$l$jscomp$104$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$134$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$422$$,$b$jscomp$345$$,$c$jscomp$307$$,$d$jscomp$238$$,
$e$jscomp$345$$,$f$jscomp$858$$,$g$jscomp$146$$,$h$jscomp$172$$,$i$jscomp$522$$,$j$jscomp$116$$,$k$jscomp$684$$,$l$jscomp$104$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$15$=function($text$jscomp$135$$,$a$jscomp$423$$,$b$jscomp$346$$,$c$jscomp$308$$,$d$jscomp$239$$,$e$jscomp$346$$,$f$jscomp$859$$,$g$jscomp$147$$,$h$jscomp$173$$,$i$jscomp$523$$,$j$jscomp$117$$,$k$jscomp$685$$,$l$jscomp$105$$,$m$jscomp$232$$,$n$jscomp$306$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$135$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$423$$,$b$jscomp$346$$,
$c$jscomp$308$$,$d$jscomp$239$$,$e$jscomp$346$$,$f$jscomp$859$$,$g$jscomp$147$$,$h$jscomp$173$$,$i$jscomp$523$$,$j$jscomp$117$$,$k$jscomp$685$$,$l$jscomp$105$$,$m$jscomp$232$$,$n$jscomp$306$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$17$=function($text$jscomp$136$$,$a$jscomp$424$$,$b$jscomp$347$$,$c$jscomp$309$$,$d$jscomp$240$$,$e$jscomp$347$$,$f$jscomp$860$$,$g$jscomp$148$$,$h$jscomp$174$$,$i$jscomp$524$$,$j$jscomp$118$$,$k$jscomp$686$$,$l$jscomp$106$$,$m$jscomp$233$$,$n$jscomp$307$$,$o$jscomp$273$$,$p$jscomp$253$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$136$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$424$$,
$b$jscomp$347$$,$c$jscomp$309$$,$d$jscomp$240$$,$e$jscomp$347$$,$f$jscomp$860$$,$g$jscomp$148$$,$h$jscomp$174$$,$i$jscomp$524$$,$j$jscomp$118$$,$k$jscomp$686$$,$l$jscomp$106$$,$m$jscomp$233$$,$n$jscomp$307$$,$o$jscomp$273$$,$p$jscomp$253$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$19$=function($text$jscomp$137$$,$a$jscomp$425$$,$b$jscomp$348$$,$c$jscomp$310$$,$d$jscomp$241$$,$e$jscomp$348$$,$f$jscomp$861$$,$g$jscomp$149$$,$h$jscomp$175$$,$i$jscomp$525$$,$j$jscomp$119$$,$k$jscomp$687$$,$l$jscomp$107$$,$m$jscomp$234$$,$n$jscomp$308$$,$o$jscomp$274$$,$p$jscomp$254$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$137$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$425$$,
$b$jscomp$348$$,$c$jscomp$310$$,$d$jscomp$241$$,$e$jscomp$348$$,$f$jscomp$861$$,$g$jscomp$149$$,$h$jscomp$175$$,$i$jscomp$525$$,$j$jscomp$119$$,$k$jscomp$687$$,$l$jscomp$107$$,$m$jscomp$234$$,$n$jscomp$308$$,$o$jscomp$274$$,$p$jscomp$254$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$21$=function($text$jscomp$138$$,$a$jscomp$426$$,$b$jscomp$349$$,$c$jscomp$311$$,$d$jscomp$242$$,$e$jscomp$349$$,$f$jscomp$862$$,$g$jscomp$150$$,$h$jscomp$176$$,$i$jscomp$526$$,$j$jscomp$120$$,$k$jscomp$688$$,$l$jscomp$108$$,$m$jscomp$235$$,$n$jscomp$309$$,$o$jscomp$275$$,$p$jscomp$255$$,$q$jscomp$40$$,$r$jscomp$128$$,$s$jscomp$576$$,$more$jscomp$52$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($instaparse$core$parse$$,
this,$text$jscomp$138$$,$a$jscomp$426$$,$b$jscomp$349$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c$jscomp$311$$,$d$jscomp$242$$,$e$jscomp$349$$,$f$jscomp$862$$,$g$jscomp$150$$,$h$jscomp$176$$,$i$jscomp$526$$,$j$jscomp$120$$,$k$jscomp$688$$,$l$jscomp$108$$,$m$jscomp$235$$,$n$jscomp$309$$,$o$jscomp$275$$,$p$jscomp$255$$,$q$jscomp$40$$,$r$jscomp$128$$,$s$jscomp$576$$,$more$jscomp$52$$]))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($parser$jscomp$77$$,$writer$jscomp$173$$){return $APP.$cljs$core$_write$$($writer$jscomp$173$$,$instaparse$print$Parser__GT_str$$(this))};var $instaparse$core$standard_whitespace_parsers$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5568$standard$$,$instaparse$core$parser$$("whitespace \x3d #'\\s+'"),$APP.$cljs$cst$5569$comma$$,$instaparse$core$parser$$("whitespace \x3d #'[,\\s]+'")],null);var $app$util$simple_math$parser$$=$instaparse$core$parser$$("opt-expr \x3d '' | expr\n     expr \x3d term (\x3cspaces\x3e ('+'|'-') \x3cspaces\x3e expr)* |\n            ('+'|'-'|'*'|'/') \x3cspaces\x3e factor\n     term \x3d factor (\x3cspaces\x3e ('*'|'/') \x3cspaces\x3e term)*\n     factor \x3d number | ('(' \x3cspaces\x3e expr \x3cspaces\x3e ')')\n     number \x3d #'[0-9]*[.,]?[0-9]+%?'\n     spaces \x3d ' '*"),$app$util$simple_math$interpret$$=function $app$util$simple_math$interpret$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,
$init_value$$){var $G__78032_token$jscomp$120_value__$1$jscomp$36$$=$APP.$cljs$core$first$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$),$args$jscomp$262$$=$APP.$cljs$core$rest$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$);switch($G__78032_token$jscomp$120_value__$1$jscomp$36$$ instanceof $APP.$cljs$core$Keyword$$?$G__78032_token$jscomp$120_value__$1$jscomp$36$$.$fqn$:null){case "opt-expr":if($APP.$cljs$core$empty_QMARK_$$($args$jscomp$262$$))return null;
$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,$init_value$$):$app$util$simple_math$interpret$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,$init_value$$);
case "expr":if($APP.$cljs$core$truth_$$($APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$("+-*/",$APP.$cljs$core$first$$($args$jscomp$262$$)))){var $G__78040_G__78050_operator$$=$APP.$cljs$core$first$$($args$jscomp$262$$);$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=function(){var $G__78030$$=$APP.$cljs$core$second$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78030$$,
$init_value$$):$app$util$simple_math$interpret$$($G__78030$$,$init_value$$)}();$G__78032_token$jscomp$120_value__$1$jscomp$36$$=$G__78040_G__78050_operator$$;switch($G__78032_token$jscomp$120_value__$1$jscomp$36$$){case "+":return $init_value$$+$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;case "-":return 0-$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;case "*":return $init_value$$*$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;
case "/":return $init_value$$/$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78032_token$jscomp$120_value__$1$jscomp$36$$)].join(""));}}else{$G__78032_token$jscomp$120_value__$1$jscomp$36$$=$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=function(){var $G__78033$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?
$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78033$$,$init_value$$):$app$util$simple_math$interpret$$($G__78033$$,$init_value$$)}();for(var $rest_expr$$=$APP.$cljs$core$rest$$($args$jscomp$262$$);;){if($APP.$cljs$core$empty_QMARK_$$($rest_expr$$))return $G__78032_token$jscomp$120_value__$1$jscomp$36$$;$G__78040_G__78050_operator$$=$APP.$cljs$core$first$$($rest_expr$$);$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=function(){var $G__78037$$=
$APP.$cljs$core$second$$($rest_expr$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78037$$,$init_value$$):$app$util$simple_math$interpret$$($G__78037$$,$init_value$$)}();var $G__78081_G__78083_G__78087_G__78089_rest_expr__$1$$=$APP.$cljs$core$rest$$($APP.$cljs$core$rest$$($rest_expr$$));switch($G__78040_G__78050_operator$$){case "+":$G__78032_token$jscomp$120_value__$1$jscomp$36$$+=$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;
$rest_expr$$=$G__78081_G__78083_G__78087_G__78089_rest_expr__$1$$;continue;case "-":$G__78032_token$jscomp$120_value__$1$jscomp$36$$-=$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;$rest_expr$$=$G__78081_G__78083_G__78087_G__78089_rest_expr__$1$$;continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78040_G__78050_operator$$)].join(""));}break}}break;case "term":$G__78032_token$jscomp$120_value__$1$jscomp$36$$=
$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=function(){var $G__78045$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78045$$,$init_value$$):$app$util$simple_math$interpret$$($G__78045$$,$init_value$$)}();for($rest_expr$$=$APP.$cljs$core$rest$$($args$jscomp$262$$);;){if($APP.$cljs$core$empty_QMARK_$$($rest_expr$$))return $G__78032_token$jscomp$120_value__$1$jscomp$36$$;
$G__78040_G__78050_operator$$=$APP.$cljs$core$first$$($rest_expr$$);$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=function(){var $G__78048$$=$APP.$cljs$core$second$$($rest_expr$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78048$$,$init_value$$):$app$util$simple_math$interpret$$($G__78048$$,$init_value$$)}();$G__78081_G__78083_G__78087_G__78089_rest_expr__$1$$=
$APP.$cljs$core$rest$$($APP.$cljs$core$rest$$($rest_expr$$));switch($G__78040_G__78050_operator$$){case "*":$G__78032_token$jscomp$120_value__$1$jscomp$36$$*=$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;$rest_expr$$=$G__78081_G__78083_G__78087_G__78089_rest_expr__$1$$;continue;case "/":$G__78032_token$jscomp$120_value__$1$jscomp$36$$/=$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$;$rest_expr$$=$G__78081_G__78083_G__78087_G__78089_rest_expr__$1$$;
continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78040_G__78050_operator$$)].join(""));}break}break;case "factor":if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($args$jscomp$262$$),"("))return $G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=$APP.$cljs$core$second$$($args$jscomp$262$$),$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,
$init_value$$):$app$util$simple_math$interpret$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,$init_value$$);$G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,
$init_value$$):$app$util$simple_math$interpret$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,$init_value$$);case "number":return $G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$=$APP.$cuerdas$core$replace$$($APP.$cljs$core$first$$($args$jscomp$262$$),",","."),$APP.$cuerdas$core$ends_with_QMARK_$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,"%")?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$,
"%",""))/100*$init_value$$:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($G__78027_G__78051_G__78053_second_value_tree$jscomp$24_value$jscomp$786_value_str$$);default:throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["Unknown token",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78032_token$jscomp$120_value__$1$jscomp$36$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$262$$)].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2252$validation$$,$APP.$cljs$cst$275$hint$$,["Unknown token",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78032_token$jscomp$120_value__$1$jscomp$36$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$262$$)].join("")],null),null])),null);}};var $app$main$ui$components$numeric_input$numeric_input_STAR_$$=(0,$APP.$rumext$v2$forward_ref$$)(function($props_78100_props__$1$jscomp$71$$,$external_ref$jscomp$1_handle_key_down$jscomp$5$$){var $value_str$jscomp$1$$=$props_78100_props__$1$jscomp$71$$.value,$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$=$props_78100_props__$1$jscomp$71$$.min,$handle_blur$jscomp$1_max_value$jscomp$3$$=$props_78100_props__$1$jscomp$71$$.max,$handle_focus$jscomp$1_step_value$$=$props_78100_props__$1$jscomp$71$$.step,
$wrap_value_QMARK_$$=$props_78100_props__$1$jscomp$71$$["data-wrap"],$on_change$jscomp$35$$=$props_78100_props__$1$jscomp$71$$.onChange,$on_blur$jscomp$7$$=$props_78100_props__$1$jscomp$71$$.onBlur,$on_focus$jscomp$4$$=$props_78100_props__$1$jscomp$71$$.onFocus,$title$jscomp$31$$=$props_78100_props__$1$jscomp$71$$.title,$default$$jscomp$90$$=$props_78100_props__$1$jscomp$71$$["default"],$nillable_QMARK_$$=$props_78100_props__$1$jscomp$71$$.nillable,$class$$jscomp$57$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_78100_props__$1$jscomp$71$$.className,
""),$min_value__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$),$max_value__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($handle_blur$jscomp$1_max_value$jscomp$3$$),$step_value__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($handle_focus$jscomp$1_step_value$$,1),$default$__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($default$$jscomp$90$$,
$APP.$cljs$core$truth_$$($nillable_QMARK_$$)?null:0),$integer_QMARK_$$=$props_78100_props__$1$jscomp$71$$.integer,$select_on_focus_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_78100_props__$1$jscomp$71$$.selectOnFocus,!0);$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)();var $ref$jscomp$48$$=$APP.$cljs$core$truth_$$($external_ref$jscomp$1_handle_key_down$jscomp$5$$)?$external_ref$jscomp$1_handle_key_down$jscomp$5$$:$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$,
$value$jscomp$788$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$value_str$jscomp$1$$)?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($value_str$jscomp$1$$,$default$__$1$$):null,$dirty_ref$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$last_value_STAR_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$($value$jscomp$788$$),$parse_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min_value__$1$$),
$APP.$rumext$v2$adapt$$($max_value__$1$$),$APP.$rumext$v2$adapt$$($value$jscomp$788$$),$APP.$rumext$v2$adapt$$($nillable_QMARK_$$),$APP.$rumext$v2$adapt$$($default$__$1$$),$APP.$rumext$v2$adapt$$($integer_QMARK_$$)],function(){var $G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $APP.$cljs$core$truth_$$($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$)?($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$=
$app$util$simple_math$expr_eval$$($APP.$cuerdas$core$strip_suffix$$($APP.$app$util$dom$get_value$$($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$),"."),$value$jscomp$788$$),$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$))?($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$=$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($integer_QMARK_$$)?
$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$):$G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$,-1073741824),1.0737418235E9),$G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$=$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($min_value__$1$$))?$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$,
$min_value__$1$$):$G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$,$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($max_value__$1$$))?$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$,$max_value__$1$$):$G__78102_G__78103$jscomp$inline_13499_new_value$jscomp$10_temp__5825__auto__$jscomp$347$$):$APP.$cljs$core$truth_$$($nillable_QMARK_$$)?$default$__$1$$:
$value$jscomp$788$$):null}),$update_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($new_value$jscomp$11$$){var $temp__5825__auto__$jscomp$348$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$348$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$348$$,$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($new_value$jscomp$11$$)):null}),$apply_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$35$$),
$APP.$rumext$v2$adapt$$($update_input$$),$APP.$rumext$v2$adapt$$($value$jscomp$788$$)],function($event$jscomp$291$$,$new_value$jscomp$12$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$$,!1);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$12$$,$value$jscomp$788$$)&&$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$35$$)&&($on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$12$$,$event$jscomp$291$$):
$on_change$jscomp$35$$($new_value$jscomp$12$$,$event$jscomp$291$$));return $update_input$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$12$$):$update_input$$($new_value$jscomp$12$$)}),$set_delta$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wrap_value_QMARK_$$),$APP.$rumext$v2$adapt$$($min_value__$1$$),$APP.$rumext$v2$adapt$$($max_value__$1$$),$APP.$rumext$v2$adapt$$($parse_value$$),$APP.$rumext$v2$adapt$$($apply_value$$)],
function($event$jscomp$292$$,$up_QMARK_$jscomp$1$$,$down_QMARK_$jscomp$1$$){var $current_value$jscomp$5$$=$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$(),$current_value__$1_new_value__$1_new_value__$2$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$702$$=$APP.$cljs$core$not$$($current_value$jscomp$5$$);return $and__5023__auto__$jscomp$702$$?$APP.$cljs$core$truth_$$($down_QMARK_$jscomp$1$$)?$max_value__$1$$:$down_QMARK_$jscomp$1$$:
$and__5023__auto__$jscomp$702$$}())?$max_value__$1$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$703$$=$APP.$cljs$core$not$$($current_value$jscomp$5$$);return $and__5023__auto__$jscomp$703$$?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$min_value__$1$$:$up_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$703$$}())?$min_value__$1$$:$APP.$cljs$core$not$$($current_value$jscomp$5$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($default$__$1$$,0):$current_value$jscomp$5$$;
if($APP.$cljs$core$truth_$$($current_value__$1_new_value__$1_new_value__$2$$)){var $new_value$jscomp$13$$=$current_value__$1_new_value__$1_new_value__$2$$+($event$jscomp$292$$.shiftKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$step_value__$1$$*10:$step_value__$1$$*-10:$event$jscomp$292$$.altKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$step_value__$1$$*.1:$step_value__$1$$*-.1:$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$step_value__$1$$:-$step_value__$1$$);$current_value__$1_new_value__$1_new_value__$2$$=
$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($wrap_value_QMARK_$$)){var $and__5023__auto____$1$jscomp$119_and__5023__auto____$2$jscomp$38$$=$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($max_value__$1$$,$min_value__$1$$);return $and__5023__auto____$1$jscomp$119_and__5023__auto____$2$jscomp$38$$?($and__5023__auto____$1$jscomp$119_and__5023__auto____$2$jscomp$38$$=$new_value$jscomp$13$$>$max_value__$1$$)?$up_QMARK_$jscomp$1$$:$and__5023__auto____$1$jscomp$119_and__5023__auto____$2$jscomp$38$$:
$and__5023__auto____$1$jscomp$119_and__5023__auto____$2$jscomp$38$$}return $wrap_value_QMARK_$$}())?$new_value$jscomp$13$$-$max_value__$1$$+$min_value__$1$$-$step_value__$1$$:$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($wrap_value_QMARK_$$)){var $and__5023__auto____$1$jscomp$120_and__5023__auto____$2$jscomp$39$$=$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($max_value__$1$$,$min_value__$1$$);return $and__5023__auto____$1$jscomp$120_and__5023__auto____$2$jscomp$39$$?
($and__5023__auto____$1$jscomp$120_and__5023__auto____$2$jscomp$39$$=$new_value$jscomp$13$$<$min_value__$1$$)?$down_QMARK_$jscomp$1$$:$and__5023__auto____$1$jscomp$120_and__5023__auto____$2$jscomp$39$$:$and__5023__auto____$1$jscomp$120_and__5023__auto____$2$jscomp$39$$}return $wrap_value_QMARK_$$}())?$new_value$jscomp$13$$-$min_value__$1$$+$max_value__$1$$+$step_value__$1$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$706$$=$APP.$app$common$math$finite_QMARK_$$($min_value__$1$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$706$$)?$new_value$jscomp$13$$<$min_value__$1$$:$and__5023__auto__$jscomp$706$$}())?$min_value__$1$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$707$$=$APP.$app$common$math$finite_QMARK_$$($max_value__$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$707$$)?$new_value$jscomp$13$$>$max_value__$1$$:$and__5023__auto__$jscomp$707$$}())?$max_value__$1$$:$new_value$jscomp$13$$;$current_value__$1_new_value__$1_new_value__$2$$=
$APP.$cljs$core$truth_$$($integer_QMARK_$$)?$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($current_value__$1_new_value__$1_new_value__$2$$):$current_value__$1_new_value__$1_new_value__$2$$;return $apply_value$$.$cljs$core$IFn$_invoke$arity$2$?$apply_value$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$292$$,$current_value__$1_new_value__$1_new_value__$2$$):$apply_value$$($event$jscomp$292$$,$current_value__$1_new_value__$1_new_value__$2$$)}return null});$external_ref$jscomp$1_handle_key_down$jscomp$5$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_delta$$),$APP.$rumext$v2$adapt$$($apply_value$$),$APP.$rumext$v2$adapt$$($update_input$$),$APP.$rumext$v2$adapt$$($parse_value$$)],function($event$jscomp$293$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$$,!0);var $up_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$293$$),$down_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$293$$),$enter_QMARK_$jscomp$1$$=
(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$293$$),$esc_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$293$$),$node$jscomp$399$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($up_QMARK_$jscomp$2$$)?$up_QMARK_$jscomp$2$$:$down_QMARK_$jscomp$2$$)&&($set_delta$$.$cljs$core$IFn$_invoke$arity$3$?$set_delta$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$293$$,$up_QMARK_$jscomp$2$$,$down_QMARK_$jscomp$2$$):$set_delta$$($event$jscomp$293$$,
$up_QMARK_$jscomp$2$$,$down_QMARK_$jscomp$2$$));$APP.$cljs$core$reset_BANG_$$($last_value_STAR_$$,$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$());$APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$1$$)&&$APP.$app$util$dom$blur_BANG_$$($node$jscomp$399$$);return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$2$$)?($update_input$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$$.$cljs$core$IFn$_invoke$arity$1$($value_str$jscomp$1$$):$update_input$$($value_str$jscomp$1$$),
$APP.$app$util$dom$blur_BANG_$$($node$jscomp$399$$)):null});$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($parse_value$$)],function(){return $APP.$cljs$core$reset_BANG_$$($last_value_STAR_$$,$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$())});var $handle_mouse_wheel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_delta$$)],
function($event$jscomp$294$$){var $G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);if($APP.$cljs$core$truth_$$($G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$)&&$APP.$cljs$core$truth_$$($app$util$dom$active_QMARK_$$($G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$294$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$294$$);$G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$=
$app$util$dom$get_delta_position$$($event$jscomp$294$$);$G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$=$APP.$cljs$core$__destructure_map$$($G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$);var $G__78108_y$jscomp$465$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$,$APP.$cljs$cst$1511$y$$);$G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$=$G__78108_y$jscomp$465$$<0;$G__78108_y$jscomp$465$$=
$G__78108_y$jscomp$465$$>0;return $set_delta$$.$cljs$core$IFn$_invoke$arity$3$?$set_delta$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$294$$,$G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$,$G__78108_y$jscomp$465$$):$set_delta$$($event$jscomp$294$$,$G__78107_map__78105_map__78105__$1_temp__5825__auto__$jscomp$349$$,$G__78108_y$jscomp$465$$)}return null});$handle_blur$jscomp$1_max_value$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($parse_value$$),
$APP.$rumext$v2$adapt$$($apply_value$$),$APP.$rumext$v2$adapt$$($update_input$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$7$$)],function($event$jscomp$295$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$$))){var $new_value_78112_or__5025__auto__$jscomp$inline_13501$$=$APP.$cljs$core$_deref$$($last_value_STAR_$$);$new_value_78112_or__5025__auto__$jscomp$inline_13501$$=$APP.$cljs$core$truth_$$($new_value_78112_or__5025__auto__$jscomp$inline_13501$$)?$new_value_78112_or__5025__auto__$jscomp$inline_13501$$:
$default$__$1$$;$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable_QMARK_$$)?$nillable_QMARK_$$:$new_value_78112_or__5025__auto__$jscomp$inline_13501$$)?$apply_value$$.$cljs$core$IFn$_invoke$arity$2$?$apply_value$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$295$$,$new_value_78112_or__5025__auto__$jscomp$inline_13501$$):$apply_value$$($event$jscomp$295$$,$new_value_78112_or__5025__auto__$jscomp$inline_13501$$):$update_input$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$$.$cljs$core$IFn$_invoke$arity$1$($new_value_78112_or__5025__auto__$jscomp$inline_13501$$):
$update_input$$($new_value_78112_or__5025__auto__$jscomp$inline_13501$$);return $APP.$cljs$core$fn_QMARK_$$($on_blur$jscomp$7$$)?$on_blur$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$295$$):$on_blur$jscomp$7$$($event$jscomp$295$$):null}return null});var $handle_unmount$$=$app$main$ui$hooks$use_ref_callback$$($handle_blur$jscomp$1_max_value$jscomp$3$$),$on_click$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$296_target$jscomp$142$$){$event$jscomp$296_target$jscomp$142$$=
$APP.$app$util$dom$get_target$$($event$jscomp$296_target$jscomp$142$$);var $node$jscomp$401$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $node$jscomp$401$$!=null&&$APP.$cljs$core$not$$($APP.$app$util$dom$child_QMARK_$$($node$jscomp$401$$,$event$jscomp$296_target$jscomp$142$$))?$APP.$app$util$dom$blur_BANG_$$($node$jscomp$401$$):null});$handle_focus$jscomp$1_step_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$4$$),$APP.$rumext$v2$adapt$$($select_on_focus_QMARK_$$)],
function($event$jscomp$297$$){$APP.$cljs$core$reset_BANG_$$($last_value_STAR_$$,$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$());var $target$jscomp$143$$=$APP.$app$util$dom$get_target$$($event$jscomp$297$$);$APP.$cljs$core$truth_$$($on_focus$jscomp$4$$)&&($APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$$,!0),$on_focus$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$297$$):
$on_focus$jscomp$4$$($event$jscomp$297$$));return $APP.$cljs$core$truth_$$($select_on_focus_QMARK_$$)?($APP.$app$util$dom$select_text_BANG_$$($target$jscomp$143$$),$target$jscomp$143$$.addEventListener("mouseup",$APP.$app$util$dom$prevent_default$$,{once:!0})):null});$props_78100_props__$1$jscomp$71$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props_78100_props__$1$jscomp$71$$),
"selectOnFocus"),"nillable"),"integer"),"value"),"onChange",$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$),"className",$class$$jscomp$57$$),"type","text"),"ref",$ref$jscomp$48$$),"defaultValue",$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$788$$)),"title",$title$jscomp$31$$),"onKeyDown",$external_ref$jscomp$1_handle_key_down$jscomp$5$$),"onBlur",$handle_blur$jscomp$1_max_value$jscomp$3$$),"onFocus",$handle_focus$jscomp$1_step_value$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$788$$)],function(){var $temp__5825__auto__$jscomp$350$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$350$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$350$$,$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$788$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_unmount$$)],
function(){return $handle_unmount$$});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $keys$jscomp$56$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"pointerdown",$on_click$jscomp$35$$),$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"click",$on_click$jscomp$35$$)],null);return function(){return $APP.$cljs$core$run_BANG_$$($APP.$goog$events$unlistenByKey$$,
$keys$jscomp$56$$)}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_mouse_wheel$$)],function(){var $temp__5825__auto__$jscomp$351$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$351$$)){var $key$jscomp$407$$=$APP.$goog$events$listen$$($temp__5825__auto__$jscomp$351$$,"wheel",$handle_mouse_wheel$$,{passive:!1});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$407$$)}}return null});
return(0,$APP.$rumext$v2$create_element$$)("input",$props_78100_props__$1$jscomp$71$$)});var $app$main$ui$components$color_input$color_input_STAR_$$=(0,$APP.$rumext$v2$forward_ref$$)(function($class$__$1$jscomp$9_props_76699$$,$external_ref$jscomp$2_handle_key_down$jscomp$6$$){var $aria_label$jscomp$8$$=void 0,$on_change$jscomp$36$$=void 0,$aria_label__$1_select_on_focus$$=void 0,$on_focus$jscomp$5$$=void 0,$value$jscomp$789$$=void 0,$on_blur$jscomp$8$$=void 0,$class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$=void 0,$props$jscomp$315_props__$1$jscomp$72$$=void 0;({value:$value$jscomp$789$$,
onChange:$on_change$jscomp$36$$,onBlur:$on_blur$jscomp$8$$,onFocus:$on_focus$jscomp$5$$,selectOnFocus:$aria_label__$1_select_on_focus$$,className:$class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$,"aria-label":$aria_label$jscomp$8$$,...$props$jscomp$315_props__$1$jscomp$72$$}=$class$__$1$jscomp$9_props_76699$$);var $select_on_focus_QMARK_$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($aria_label__$1_select_on_focus$$,!0);$class$__$1$jscomp$9_props_76699$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$,
"color-input");$aria_label__$1_select_on_focus$$=function(){var $or__5025__auto__$jscomp$1069$$=$aria_label$jscomp$8$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1069$$)?$or__5025__auto__$jscomp$1069$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color")}();$class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)();var $ref$jscomp$50$$=$APP.$cljs$core$truth_$$($external_ref$jscomp$2_handle_key_down$jscomp$6$$)?$external_ref$jscomp$2_handle_key_down$jscomp$6$$:
$class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$,$dirty_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$parse_value$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $input_node$jscomp$3$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);try{var $status$jscomp$inline_13507_value__$1$jscomp$37$$=$APP.$app$common$types$color$prepend_hash$$($APP.$app$common$types$color$parse$$($APP.$app$common$types$color$expand_hex$$($APP.$app$util$dom$get_value$$($input_node$jscomp$3$$))));
$input_node$jscomp$3$$!=null&&($input_node$jscomp$3$$.setCustomValidity(""),$input_node$jscomp$3$$.reportValidity());return $status$jscomp$inline_13507_value__$1$jscomp$37$$}catch($e76706$$){return $status$jscomp$inline_13507_value__$1$jscomp$37$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.invalid-color"),$input_node$jscomp$3$$!=null&&($input_node$jscomp$3$$.setCustomValidity($status$jscomp$inline_13507_value__$1$jscomp$37$$),$input_node$jscomp$3$$.reportValidity()),null}}),
$update_input$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($new_value$jscomp$14$$){return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($ref$jscomp$50$$),$app$common$types$color$remove_hash$$($new_value$jscomp$14$$))}),$apply_value$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$36$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$1$$)],function($new_value$jscomp$15$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$1$$,
!1);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($new_value$jscomp$15$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$remove_hash$$($new_value$jscomp$15$$),$value$jscomp$789$$):$new_value$jscomp$15$$)?($APP.$cljs$core$truth_$$($on_change$jscomp$36$$)&&($on_change$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$15$$):$on_change$jscomp$36$$($new_value$jscomp$15$$)),$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$15$$):$update_input$jscomp$1$$($new_value$jscomp$15$$)):null});$external_ref$jscomp$2_handle_key_down$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$1$$)],function($event$jscomp$298$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$1$$,!0);var $input_node$jscomp$5$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);
if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$298$$))){var $value__$1$jscomp$38$$=$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$jscomp$1$$();$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$38$$):$update_input$jscomp$1$$($value__$1$jscomp$38$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$298$$);
return $APP.$app$util$dom$blur_BANG_$$($input_node$jscomp$5$$)}return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$298$$))?($update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$789$$):$update_input$jscomp$1$$($value$jscomp$789$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$298$$),$APP.$app$util$dom$blur_BANG_$$($input_node$jscomp$5$$)):null});var $on_click$jscomp$36$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$299_target$jscomp$144$$){$event$jscomp$299_target$jscomp$144$$=
$APP.$app$util$dom$get_target$$($event$jscomp$299_target$jscomp$144$$);var $current$jscomp$54$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);return $current$jscomp$54$$!=null&&$APP.$cljs$core$not$$($current$jscomp$54$$.contains($event$jscomp$299_target$jscomp$144$$))?$APP.$app$util$dom$blur_BANG_$$($current$jscomp$54$$):null}),$on_mouse_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$300$$){return $APP.$app$util$dom$prevent_default$$($event$jscomp$300$$)});$class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$301$$){var $target$jscomp$145$$=$APP.$app$util$dom$get_target$$($event$jscomp$301$$);$APP.$cljs$core$truth_$$($on_focus$jscomp$5$$)&&($on_focus$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$on_focus$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus$jscomp$5$$());return $APP.$cljs$core$truth_$$($select_on_focus_QMARK_$jscomp$1$$)?($APP.$app$util$dom$get_target$$($event$jscomp$301$$).select(),$target$jscomp$145$$.addEventListener("mouseup",
$on_mouse_up$$,{once:!0})):null});var $handle_blur$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($parse_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($apply_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$1$$)],function(){var $new_value$jscomp$16$$=$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$jscomp$1$$();$APP.$cljs$core$truth_$$($new_value$jscomp$16$$)?$apply_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$apply_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$16$$):$apply_value$jscomp$1$$($new_value$jscomp$16$$):$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$789$$):$update_input$jscomp$1$$($value$jscomp$789$$);return $APP.$cljs$core$truth_$$($on_blur$jscomp$8$$)?$on_blur$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$8$$():null}),$handle_blur__$1$$=
$app$main$ui$hooks$use_ref_callback$$($handle_blur$jscomp$2$$);$props$jscomp$315_props__$1$jscomp$72$$={...$props$jscomp$315_props__$1$jscomp$72$$,className:$class$__$1$jscomp$9_props_76699$$,type:"text",ref:$ref$jscomp$50$$,"aria-label":$aria_label__$1_select_on_focus$$,defaultValue:$value$jscomp$789$$,onKeyDown:$external_ref$jscomp$2_handle_key_down$jscomp$6$$,onBlur:$handle_blur__$1$$,onFocus:$class$$jscomp$58_handle_focus$jscomp$2_local_ref$jscomp$3$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$789$$)],
function(){var $temp__5825__auto__$jscomp$352$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$352$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$352$$,$value$jscomp$789$$):null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$jscomp$1$$))?$handle_blur__$1$$.$cljs$core$IFn$_invoke$arity$0$?$handle_blur__$1$$.$cljs$core$IFn$_invoke$arity$0$():
$handle_blur__$1$$():null}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$6$$=$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"pointerdown",$on_click$jscomp$36$$),$key2$jscomp$5$$=$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"click",$on_click$jscomp$36$$);return function(){$APP.$goog$events$unlistenByKey$$($key1$jscomp$6$$);return $APP.$goog$events$unlistenByKey$$($key2$jscomp$5$$)}});return(0,$APP.$rumext$v2$create_element$$)("input",
$props$jscomp$315_props__$1$jscomp$72$$)});var $app$main$ui$workspace$colorpicker$shortcuts$shortcuts$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5585$delete_stop$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$supr$$(),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["del","backspace"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$2947$overwrite$$,!0,$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}],null)],null)]));var $app$main$ui$workspace$colorpicker$picking_color_QMARK_$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4130$picking_color_QMARK_$$,$APP.$app$main$refs$workspace_global$$),$app$main$ui$workspace$colorpicker$picked_color$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4135$picked_color$$,$APP.$app$main$refs$workspace_global$$),$app$main$ui$workspace$colorpicker$picked_color_select$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4132$picked_color_select$$,
$APP.$app$main$refs$workspace_global$$),$app$main$ui$workspace$colorpicker$viewport$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2203$vport$$,$APP.$app$main$refs$workspace_local$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$17$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$17$$,$APP.$cljs$cst$2239$colorpicker$$,$app$main$ui$workspace$colorpicker$colorpicker_modal$$)});var $app$main$ui$workspace$sidebar$assets$common$assets_filters$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$workspace$sidebar$assets$common$assets_toggle_ordering$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$workspace$sidebar$assets$common$assets_toggle_list_style$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4533$open_QMARK_$$,!1,$APP.$cljs$cst$1562$top$$,
null,$APP.$cljs$cst$257$left$$,null],null);var $app$main$ui$workspace$context_menu$menu_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2205$context_menu$$,$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$context_menu$shape_context_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($disable_booleans$jscomp$1_props$jscomp$317_props_77558$$){var $disable_flatten$jscomp$1_map__77562__$1$$=$APP.$cljs$core$__destructure_map$$($disable_booleans$jscomp$1_props$jscomp$317_props_77558$$.mdata);
$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disable_flatten$jscomp$1_map__77562__$1$$,$cljs$cst$5600$disable_booleans$$);$disable_flatten$jscomp$1_map__77562__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disable_flatten$jscomp$1_map__77562__$1$$,$cljs$cst$5601$disable_flatten$$);var $objects$jscomp$769$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$shape_ids$jscomp$107_shapes$jscomp$197$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);$shape_ids$jscomp$107_shapes$jscomp$197$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$769$$),$shape_ids$jscomp$107_shapes$jscomp$197$$);var $is_not_variant_container_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77557_SHARP_$$){return $APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__77557_SHARP_$$))},
$shape_ids$jscomp$107_shapes$jscomp$197$$);$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$={shapes:$shape_ids$jscomp$107_shapes$jscomp$197$$,objects:$objects$jscomp$769$$,disableBooleans:$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$,disableFlatten:$disable_flatten$jscomp$1_map__77562__$1$$};return $APP.$cljs$core$empty_QMARK_$$($shape_ids$jscomp$107_shapes$jscomp$197$$)?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_edit_STAR_$$,
$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_layer_position_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),$APP.$cljs$core$truth_$$($is_not_variant_container_QMARK_$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_flip_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$):null,(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_thumbnail_STAR_$$,
$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_rename_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_group_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_focus_mode_menu_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_path_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_layer_options_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_prototype_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),$APP.$cljs$core$truth_$$($is_not_variant_container_QMARK_$$)?
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_layout_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$):null,(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_component_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_guides_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_delete_STAR_$$,
$disable_booleans$jscomp$1_props$jscomp$317_props_77558$$)]})}),$app$main$ui$workspace$context_menu$guide_color_presets$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"#ff3277 #4dabf7 #51cf66 #fcc419 #ff922b #cc5de8 #ffffff #868e96".split(" "),null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$18$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$18$$,$cljs$cst$5603$tokens_SLASH_import_from_library$$,$app$main$ui$workspace$tokens$import_from_library$import_modal_library_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$19$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$19$$,$APP.$cljs$cst$3971$libraries_dialog$$,$app$main$ui$workspace$libraries$libraries_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$20$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$20$$,$cljs$cst$5613$v2_info$$,$app$main$ui$workspace$libraries$v2_info_dialog$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$21$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$21$$,$cljs$cst$5614$nudge_option$$,$app$main$ui$workspace$nudge$nudge_modal$$)});var $app$main$ui$workspace$color_palette$palette_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_77920_size$jscomp$142$$){var $selected$jscomp$145$$=$props_77920_size$jscomp$142$$.selected,$color$jscomp$154$$=$props_77920_size$jscomp$142$$.color;$props_77920_size$jscomp$142$$=$props_77920_size$jscomp$142$$.size;var $select_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$154$$),$APP.$rumext$v2$adapt$$($selected$jscomp$145$$)],
function($event$jscomp$339$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($color$jscomp$154$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$apply_color_from_palette$$($color$jscomp$154$$,$event$jscomp$339$$.altKey),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,$cljs$cst$5583$recent$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-color",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"color-palette",$APP.$cljs$cst$3933$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,$APP.$cljs$cst$208$file$$)],null)):null]))}),$title$jscomp$34$$=$app$util$color$get_color_name$$($color$jscomp$154$$);return(0,$APP.$rumext$v2$jsxs$$)("button",{title:$title$jscomp$34$$,"aria-label":$title$jscomp$34$$,
type:"button",onClick:$select_color$$,className:"main_ui_workspace_color_palette__color-cell "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$154$$)==null?"main_ui_workspace_color_palette__is-not-library-color":"")+" "+($props_77920_size$jscomp$142$$<=64?"main_ui_workspace_color_palette__no-text":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color$jscomp$154$$,size:"medium"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$color_bullet$color_name$$,
{color:$color$jscomp$154$$,size:$props_77920_size$jscomp$142$$,origin:$APP.$cljs$cst$4751$palette$$})]})}),$app$main$ui$workspace$color_palette$palette_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_77927_search_open_QMARK_$$){var $selected$jscomp$146$$=$props_77927_search_open_QMARK_$$.selected,$width$jscomp$189_width__$1$jscomp$8$$=$props_77927_search_open_QMARK_$$.width,$colors$jscomp$15$$=$props_77927_search_open_QMARK_$$.colors,$size$jscomp$143$$=$props_77927_search_open_QMARK_$$.size,
$state$jscomp$1172$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5615$show_menu$$,!1],null)}),$search_term_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$search_term$jscomp$4$$=$APP.$cljs$core$_deref$$($search_term_STAR_$jscomp$1$$),$search_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$props_77927_search_open_QMARK_$$=$APP.$cljs$core$_deref$$($search_open_STAR_$$);
var $has_colors_QMARK_$$=$APP.$cljs$core$seq$$($colors$jscomp$15$$),$filtered_colors$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$15$$),$APP.$rumext$v2$adapt$$($search_term$jscomp$4$$)],function(){return $APP.$cljs$core$empty_QMARK_$$($search_term$jscomp$4$$)?$colors$jscomp$15$$:$APP.$cljs$core$filterv$$(function($or__5025__auto__$jscomp$inline_8837_p1__77925_SHARP_$$){$or__5025__auto__$jscomp$inline_8837_p1__77925_SHARP_$$=$app$util$color$get_color_name$$($or__5025__auto__$jscomp$inline_8837_p1__77925_SHARP_$$);
return $app$util$strings$matches_search$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8837_p1__77925_SHARP_$$)?$or__5025__auto__$jscomp$inline_8837_p1__77925_SHARP_$$:"",$search_term$jscomp$4$$)},$colors$jscomp$15$$)}),$on_search_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__77926_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,$p1__77926_SHARP_$$)}),$on_toggle_search$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($search_open_STAR_$$))&&
$APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,"");return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($search_open_STAR_$$,$APP.$cljs$core$not$$)}),$on_search_clear$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,"");return $APP.$cljs$core$reset_BANG_$$($search_open_STAR_$$,!1)}),$offset_step$$=$size$jscomp$143$$<=64?40:72,$search_width_show_arrows_QMARK_$$=$APP.$cljs$core$not$$($has_colors_QMARK_$$)?
0:$APP.$cljs$core$truth_$$($props_77927_search_open_QMARK_$$)?192:32;$width$jscomp$189_width__$1$jscomp$8$$-=$size$jscomp$143$$<=64?164+$search_width_show_arrows_QMARK_$$:132+$search_width_show_arrows_QMARK_$$;var $offset$jscomp$206_visible$jscomp$1$$=$width$jscomp$189_width__$1$jscomp$8$$/$offset_step$$|0,$on_scroll_visible__$1$$=($search_width_show_arrows_QMARK_$$=$APP.$cljs$core$count$$($filtered_colors$$)>$offset$jscomp$206_visible$jscomp$1$$)?($width$jscomp$189_width__$1$jscomp$8$$-48)/$offset_step$$|
0:$offset$jscomp$206_visible$jscomp$1$$;$offset$jscomp$206_visible$jscomp$1$$=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($state$jscomp$1172$$),0);var $max_offset$jscomp$2$$=$APP.$cljs$core$count$$($filtered_colors$$)-$on_scroll_visible__$1$$,$container$jscomp$83$$=(0,$APP.$rumext$v2$use_ref$$)(null),$bullet_size$$=$size$jscomp$143$$<=64?"32":$size$jscomp$143$$<=72?"28":"32",$color_cell_width$$=$size$jscomp$143$$<=64?32:64,$on_left_arrow_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$2$$),
$APP.$rumext$v2$adapt$$($on_scroll_visible__$1$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1172$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$22_x__5110__auto__$jscomp$137$$){return $offset__$1$jscomp$22_x__5110__auto__$jscomp$137$$>0?(--$offset__$1$jscomp$22_x__5110__auto__$jscomp$137$$,$offset__$1$jscomp$22_x__5110__auto__$jscomp$137$$>0?$offset__$1$jscomp$22_x__5110__auto__$jscomp$137$$:0):$offset__$1$jscomp$22_x__5110__auto__$jscomp$137$$})}),
$on_right_arrow_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_scroll_visible__$1$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1172$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$23_y__5114__auto__$jscomp$76$$){return $offset__$1$jscomp$23_y__5114__auto__$jscomp$76$$<$max_offset$jscomp$2$$?($offset__$1$jscomp$23_y__5114__auto__$jscomp$76$$+=
1,$max_offset$jscomp$2$$<$offset__$1$jscomp$23_y__5114__auto__$jscomp$76$$?$max_offset$jscomp$2$$:$offset__$1$jscomp$23_y__5114__auto__$jscomp$76$$):$offset__$1$jscomp$23_y__5114__auto__$jscomp$76$$})});$on_scroll_visible__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$2$$)],function($event$jscomp$340_event__$1$jscomp$4$$){$event$jscomp$340_event__$1$jscomp$4$$=$event$jscomp$340_event__$1$jscomp$4$$.nativeEvent;return $event$jscomp$340_event__$1$jscomp$4$$.deltaY+
$event$jscomp$340_event__$1$jscomp$4$$.deltaX>0?$on_right_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$?$on_right_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$340_event__$1$jscomp$4$$):$on_right_arrow_click$$($event$jscomp$340_event__$1$jscomp$4$$):$on_left_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$?$on_left_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$340_event__$1$jscomp$4$$):$on_left_arrow_click$$($event$jscomp$340_event__$1$jscomp$4$$)});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1172$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$83$$),"clientWidth"))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($width$jscomp$189_width__$1$jscomp$8$$),$APP.$rumext$v2$adapt$$($filtered_colors$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1172$$)))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1172$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,0):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($has_colors_QMARK_$$)],function(){if($has_colors_QMARK_$$)return null;$APP.$cljs$core$reset_BANG_$$($search_open_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,
"")});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--bullet-size":""+($bullet_size$$??"")+"px","--color-cell-width":""+($color_cell_width$$??"")+"px"},className:"main_ui_workspace_color_palette__color-palette "+($size$jscomp$143$$<64?"main_ui_workspace_color_palette__no-text":""),children:[$has_colors_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:($APP.$cljs$core$truth_$$($props_77927_search_open_QMARK_$$)?"main_ui_workspace_color_palette__palette-search":"")+" "+($APP.$cljs$core$not$$($props_77927_search_open_QMARK_$$)?
"main_ui_workspace_color_palette__palette-search-collapsed":""),children:[$APP.$cljs$core$truth_$$($props_77927_search_open_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_search_change$jscomp$1$$,onClear:$on_search_clear$$,value:$search_term$jscomp$4$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.search"),autoFocus:!0}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",icon:"search",onClick:$on_toggle_search$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.search")})]}):null,$search_width_show_arrows_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$206_visible$jscomp$1$$,0),onClick:$on_left_arrow_click$$,className:"main_ui_workspace_color_palette__left-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$container$jscomp$83$$,onWheel:$on_scroll_visible__$1$$,className:"main_ui_workspace_color_palette__color-palette-content",children:$APP.$cljs$core$empty_QMARK_$$($filtered_colors$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"absolute",left:"50%",top:"50%",transform:"translate(-50%, -50%)"},className:"main_ui_workspace_color_palette__color-palette-empty",children:$APP.$cljs$core$empty_QMARK_$$($search_term$jscomp$4$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-palette"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.not-found")}):(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"relative",maxWidth:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$189_width__$1$jscomp$8$$),"px"].join(""),right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset_step$$*$offset$jscomp$206_visible$jscomp$1$$),"px"].join("")},className:"main_ui_workspace_color_palette__color-palette-inside",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$127$$,
$item$jscomp$124_p__77971$$){var $idx$jscomp$116$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$124_p__77971$$,0,null);$item$jscomp$124_p__77971$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$124_p__77971$$,1,null);$out_arr__44124__auto__$jscomp$127$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$color_palette$palette_item_STAR_$$,{color:$item$jscomp$124_p__77971$$,size:$size$jscomp$143$$,selected:$selected$jscomp$146$$},$idx$jscomp$116$$));
return $out_arr__44124__auto__$jscomp$127$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$filtered_colors$$))})}),$search_width_show_arrows_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$206_visible$jscomp$1$$,$max_offset$jscomp$2$$),onClick:$on_right_arrow_click$$,className:"main_ui_workspace_color_palette__right-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null]})}),
$app$main$ui$workspace$color_palette$color_palette_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_77989_props__$1$jscomp$75$$){var $selected$jscomp$147$$=$props_77989_props__$1$jscomp$75$$.selected,$file_id$jscomp$379$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$147$$,$cljs$cst$5583$recent$$))return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$recent_colors_palette_STAR_$$,
$props_77989_props__$1$jscomp$75$$);$props_77989_props__$1$jscomp$75$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$147$$,$APP.$cljs$cst$208$file$$)?{...$props_77989_props__$1$jscomp$75$$,fileId:$file_id$jscomp$379$$}:{...$props_77989_props__$1$jscomp$75$$,fileId:$selected$jscomp$147$$};return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$file_color_palette_STAR_$$,$props_77989_props__$1$jscomp$75$$)});var $app$main$ui$workspace$color_palette_ctx_menu$xf_COLON_sample_colors$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(7));var $app$main$ui$workspace$text_palette$text_palette_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78084_size$jscomp$146$$){var $selected$jscomp$150$$=$props_78084_size$jscomp$146$$.selected,$width$jscomp$191$$=$props_78084_size$jscomp$146$$.width;$props_78084_size$jscomp$146$$=$props_78084_size$jscomp$146$$.size;var $selected_ids$jscomp$9$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),$file_typographies$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),
$libraries$jscomp$142$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$current_file_id$jscomp$15$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette$palette_STAR_$$,{currentFileId:$current_file_id$jscomp$15$$,selectedIds:$selected_ids$jscomp$9$$,fileTypographies:$file_typographies$jscomp$1$$,libraries:$libraries$jscomp$142$$,width:$width$jscomp$191$$,selected:$selected$jscomp$150$$,size:$props_78084_size$jscomp$146$$})});var $app$main$ui$workspace$palette$ref_COLON_viewport$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2203$vport$$,$APP.$app$main$refs$workspace_local$$);var $app$main$ui$workspace$main_menu$help_info_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($plugins_QMARK__props_78131$$){var $on_close$jscomp$19$$=$plugins_QMARK__props_78131$$.onClose,$layout$jscomp$16$$=$plugins_QMARK__props_78131$$.layout,$nav_to_helpc_center$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-help-center-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://help.penpot.app")}),$nav_to_community$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-community-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://community.penpot.app")}),$nav_to_youtube$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-tutorials-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://www.youtube.com/c/Penpot")}),$nav_to_templates$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-libraries-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/libraries-templates")}),$nav_to_github$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-github-repository-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://github.com/penpot/penpot")}),$nav_to_terms$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-terms-service-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/terms")}),$nav_to_feedback$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_feedback$$())});
$plugins_QMARK__props_78131$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime");var $mcp_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1236$mcp$$),$show_shortcuts$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$16$$)],function(){$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$16$$,$cljs$cst$5617$collapse_left_sidebar$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5617$collapse_left_sidebar$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$2950$shortcuts$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"))}),$show_release_notes$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$345$$){var $version$jscomp$24$$=$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"show-release-notes",$APP.$cljs$cst$2289$version$$,$version$jscomp$24$$],null)));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$version$jscomp$24$$]));return $event$jscomp$345$$.altKey&&$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$345$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1222$onboarding$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5373$release_notes$$,$APP.$cljs$cst$2289$version$$,
$version$jscomp$24$$],null)))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,onClose:$on_close$jscomp$19$$,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu "+($plugins_QMARK__props_78131$$||$mcp_QMARK_$$?"":"main_ui_workspace_main_menu__pos-final-5")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($plugins_QMARK__props_78131$$,$mcp_QMARK_$$)?"main_ui_workspace_main_menu__pos-final-6":"")+
" "+($plugins_QMARK__props_78131$$&&$mcp_QMARK_$$?"main_ui_workspace_main_menu__pos-final-7":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_helpc_center$$,onKeyDown:function($event$jscomp$346$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$346$$))?$nav_to_helpc_center$$.$cljs$core$IFn$_invoke$arity$1$?
$nav_to_helpc_center$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$346$$):$nav_to_helpc_center$$($event$jscomp$346$$):null},id:"file-menu-help-center",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$nav_to_community$$,onKeyDown:function($event$jscomp$347$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$347$$))?$nav_to_community$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_community$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$347$$):$nav_to_community$$($event$jscomp$347$$):null},id:"file-menu-community",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.community")})}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_youtube$$,onKeyDown:function($event$jscomp$348$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$348$$))?$nav_to_youtube$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_youtube$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$348$$):$nav_to_youtube$$($event$jscomp$348$$):
null},id:"file-menu-youtube",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.tutorials")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$show_release_notes$jscomp$1$$,onKeyDown:function($event$jscomp$349$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$349$$))?
$show_release_notes$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$show_release_notes$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$349$$):$show_release_notes$jscomp$1$$($event$jscomp$349$$):null},id:"file-menu-release-notes",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.release-notes")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_templates$$,onKeyDown:function($event$jscomp$350$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$350$$))?$nav_to_templates$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_templates$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$350$$):$nav_to_templates$$($event$jscomp$350$$):null},id:"file-menu-templates",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.libraries-and-templates")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_github$$,onKeyDown:function($event$jscomp$351$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$351$$))?
$nav_to_github$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_github$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$351$$):$nav_to_github$$($event$jscomp$351$$):null},id:"file-menu-github",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.github-repo")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$nav_to_terms$$,onKeyDown:function($event$jscomp$352$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$352$$))?$nav_to_terms$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_terms$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$352$$):$nav_to_terms$$($event$jscomp$352$$):null},id:"file-menu-terms",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.terms-of-service")})}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$show_shortcuts$$,onKeyDown:function($event$jscomp$353$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$353$$))?$show_shortcuts$$.$cljs$core$IFn$_invoke$arity$1$?$show_shortcuts$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$353$$):$show_shortcuts$$($event$jscomp$353$$):
null},id:"file-menu-shortcuts",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("label.shortcuts")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4867$show_shortcuts$$})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1227$user_feedback$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_feedback$$,onKeyDown:function($event$jscomp$354$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$354$$))?$nav_to_feedback$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_feedback$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$354$$):$nav_to_feedback$$($event$jscomp$354$$):null},id:"file-menu-feedback",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__feedback main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.give-feedback")})}):null]})}),$app$main$ui$workspace$main_menu$preferences_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78134_renderer$jscomp$1$$){var $toggle_theme$$=$props_78134_renderer$jscomp$1$$.toggleTheme,$profile$jscomp$67$$=$props_78134_renderer$jscomp$1$$.profile,$toggle_render$$=$props_78134_renderer$jscomp$1$$.toggleRender,$on_close$jscomp$20$$=$props_78134_renderer$jscomp$1$$.onClose,
$layout$jscomp$17$$=$props_78134_renderer$jscomp$1$$.layout,$toggle_flag$$=$props_78134_renderer$jscomp$1$$.toggleFlag;$props_78134_renderer$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1103$$=$APP.$cljs$cst$3105$renderer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$67$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1103$$)?$or__5025__auto__$jscomp$1103$$:$APP.$cljs$cst$1538$svg$$}();var $show_nudge_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5614$nudge_option$$],null))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-4",onClose:$on_close$jscomp$20$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onKeyDown:function($event$jscomp$355$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$355$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$355$$):$toggle_flag$$($event$jscomp$355$$):null},"data-testid":"scale-text",id:"file-menu-scale-text",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$17$$,
$APP.$cljs$cst$3716$scale_text$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-scale-content"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-scale-content")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$1902$scale$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onKeyDown:function($event$jscomp$356$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$356$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$356$$):$toggle_flag$$($event$jscomp$356$$):null},"data-testid":"snap-ruler-guides",id:"file-menu-snap-ruler-guides",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$17$$,
$APP.$cljs$cst$3723$snap_ruler_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-snap-ruler-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-snap-ruler-guides")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4812$toggle_snap_ruler_guide$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_flag$$,
className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$357$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$357$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$357$$):$toggle_flag$$($event$jscomp$357$$):null},"data-testid":"snap-guides",id:"file-menu-snap-guides",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$17$$,$APP.$cljs$cst$3720$snap_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-snap-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-snap-guides")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4848$toggle_snap_guides$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$358$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$358$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$358$$):$toggle_flag$$($event$jscomp$358$$):null},"data-testid":"dynamic-alignment",id:"file-menu-dynamic-alignment",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$17$$,$APP.$cljs$cst$3724$dynamic_alignment$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-dynamic-alignment"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-dynamic-alignment")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4860$toggle_alignment$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$359$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$359$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$359$$):$toggle_flag$$($event$jscomp$359$$):null},"data-testid":"snap-pixel-grid",id:"file-menu-pixel-grid",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$17$$,$APP.$cljs$cst$2210$snap_pixel_grid$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-snap-pixel-grid"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-snap-pixel-grid")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$2210$snap_pixel_grid$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$show_nudge_options$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$360$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$360$$))?$show_nudge_options$$.$cljs$core$IFn$_invoke$arity$1$?$show_nudge_options$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$360$$):$show_nudge_options$$($event$jscomp$360$$):null},"data-testid":"snap-pixel-grid",id:"file-menu-nudge",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.nudge-title")})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_theme$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$361$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$361$$))?$toggle_theme$$.$cljs$core$IFn$_invoke$arity$1$?
$toggle_theme$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$361$$):$toggle_theme$$($event$jscomp$361$$):null},"data-testid":"toggle-theme",id:"file-menu-toggle-theme",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:function(){switch($APP.$cljs$cst$3184$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$67$$)){case "dark":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-light-theme");case "light":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-system-theme");
case "system":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-dark-theme");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-light-theme")}}()}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4874$toggle_theme$$})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1198$render_switch$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$toggle_render$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$362$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$362$$))?$toggle_render$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_render$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$362$$):$toggle_render$$($event$jscomp$362$$):null},children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_78134_renderer$jscomp$1$$,$APP.$cljs$cst$3104$wasm$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-webgl"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-webgl")})}):null]})}),$app$main$ui$workspace$main_menu$view_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78140_read_only_QMARK_$jscomp$11$$){var $on_close$jscomp$21$$=
$props_78140_read_only_QMARK_$jscomp$11$$.onClose,$layout$jscomp$18$$=$props_78140_read_only_QMARK_$jscomp$11$$.layout,$toggle_flag$jscomp$1$$=$props_78140_read_only_QMARK_$jscomp$11$$.toggleFlag;$props_78140_read_only_QMARK_$jscomp$11$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);var $toggle_color_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1563$bottom$$;
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3740$textpalette$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3715$colorpalette$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu")]))}),$toggle_text_palette$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1563$bottom$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3715$colorpalette$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3740$textpalette$$),
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu")]))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-3",onClose:$on_close$jscomp$21$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$363$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$363$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$363$$):$toggle_flag$jscomp$1$$($event$jscomp$363$$):null},"data-testid":"rulers",id:"file-menu-rulers",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,
$APP.$cljs$cst$2211$rulers$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-rules"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-rules")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4871$toggle_rulers$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$364$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$364$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$364$$):$toggle_flag$jscomp$1$$($event$jscomp$364$$):null},"data-testid":"display-guides",id:"file-menu-guides",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,$APP.$cljs$cst$3725$display_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-guides")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4826$toggle_guides$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$365$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$365$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$365$$):$toggle_flag$jscomp$1$$($event$jscomp$365$$):null},"data-testid":"lock-guides",id:"file-menu-lock-guides",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,$APP.$cljs$cst$3721$lock_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.unlock-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.lock-guides")})}),$props_78140_read_only_QMARK_$jscomp$11$$?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_color_palette$$,onKeyDown:function($event$jscomp$366$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$366$$))?$toggle_color_palette$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_color_palette$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$366$$):$toggle_color_palette$$($event$jscomp$366$$):null},id:"file-menu-color-palette",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,$APP.$cljs$cst$3715$colorpalette$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-palette"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-palette")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4808$toggle_colorpalette$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_text_palette$$,onKeyDown:function($event$jscomp$367$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$367$$))?$toggle_text_palette$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_text_palette$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$367$$):$toggle_text_palette$$($event$jscomp$367$$):null},id:"file-menu-text-palette",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,$APP.$cljs$cst$3740$textpalette$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-textpalette"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-textpalette")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4853$toggle_textpalette$$})]})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$368$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$368$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$368$$):$toggle_flag$jscomp$1$$($event$jscomp$368$$):null},"data-testid":"display-artboard-names",id:"file-menu-artboards",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,$APP.$cljs$cst$3722$display_artboard_names$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-artboard-names"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-artboard-names")})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$369$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$369$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$369$$):$toggle_flag$jscomp$1$$($event$jscomp$369$$):null},"data-testid":"show-pixel-grid",id:"file-menu-pixel-grid",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18$$,$APP.$cljs$cst$3717$show_pixel_grid$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-pixel-grid"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-pixel-grid")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$3717$show_pixel_grid$$})]}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$370$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$370$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$370$$):$toggle_flag$jscomp$1$$($event$jscomp$370$$):
null},"data-testid":"hide-ui",id:"file-menu-hide-ui",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide-ui")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4825$hide_ui$$})]})]})}),$app$main$ui$workspace$main_menu$edit_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($can_edit$jscomp$3_perms$jscomp$1_props_78152$$){var $on_close$jscomp$22$$=
$can_edit$jscomp$3_perms$jscomp$1_props_78152$$.onClose;$can_edit$jscomp$3_perms$jscomp$1_props_78152$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);$can_edit$jscomp$3_perms$jscomp$1_props_78152$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($can_edit$jscomp$3_perms$jscomp$1_props_78152$$);var $select_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_all$$())}),
$find$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$22$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4793$find$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3734$force_QMARK_$$,!0],null)))}),
$find_and_replace$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$22$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4534$find_and_replace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3734$force_QMARK_$$,
!0],null)))}),$undo$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$undo$$)}),$redo$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$redo$$)});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-2",onClose:$on_close$jscomp$22$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$select_all$$,onKeyDown:function($event$jscomp$371$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$371$$))?
$select_all$$.$cljs$core$IFn$_invoke$arity$1$?$select_all$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$371$$):$select_all$$($event$jscomp$371$$):null},id:"file-menu-select-all",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.select-all")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4843$select_all$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$find$jscomp$4$$,onKeyDown:function($event$jscomp$372$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$372$$))?$find$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$find$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$372$$):$find$jscomp$4$$($event$jscomp$372$$):null},id:"file-menu-find",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.find")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4793$find$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$find_and_replace$$,onKeyDown:function($event$jscomp$373$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$373$$))?
$find_and_replace$$.$cljs$core$IFn$_invoke$arity$1$?$find_and_replace$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$373$$):$find_and_replace$$($event$jscomp$373$$):null},id:"file-menu-find-and-replace",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.find-and-replace")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4534$find_and_replace$$})]}),
$APP.$cljs$core$truth_$$($can_edit$jscomp$3_perms$jscomp$1_props_78152$$)?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$undo$jscomp$6$$,onKeyDown:function($event$jscomp$374$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$374$$))?$undo$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$undo$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$374$$):
$undo$jscomp$6$$($event$jscomp$374$$):null},id:"file-menu-undo",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.undo")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4850$undo$$})]}):null,$APP.$cljs$core$truth_$$($can_edit$jscomp$3_perms$jscomp$1_props_78152$$)?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$redo$jscomp$1$$,onKeyDown:function($event$jscomp$375$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$375$$))?$redo$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$redo$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$375$$):$redo$jscomp$1$$($event$jscomp$375$$):null},id:"file-menu-redo",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.redo")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4822$redo$$})]}):null]})}),$app$main$ui$workspace$main_menu$plugins_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_close$jscomp$24_props_78167$$){var $open_plugins$$=$on_close$jscomp$24_props_78167$$.openPlugins;$on_close$jscomp$24_props_78167$$=$on_close$jscomp$24_props_78167$$.onClose;
if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")){var $plugins$jscomp$1$$=$APP.$app$plugins$register$plugins_list$$(),$user_can_edit_QMARK_$jscomp$3$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$)),$permissions_peek$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$plugins_permissions_peek$$);return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-5 main_ui_workspace_main_menu__plugins",onClose:$on_close$jscomp$24_props_78167$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$open_plugins$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$384$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$384$$))?
$open_plugins$$.$cljs$core$IFn$_invoke$arity$1$?$open_plugins$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$384$$):$open_plugins$$($event$jscomp$384$$):null},"data-testid":"open-plugins",id:"file-menu-open-plugins",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.menu.plugins-manager")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$3197$plugins$$})]}),
$APP.$app$common$data$not_empty_QMARK_$$($plugins$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$134$$,$map__78172_p__78168$$){var $idx$jscomp$119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__78172_p__78168$$,0,null);$map__78172_p__78168$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__78172_p__78168$$,1,null);
var $map__78172__$1$$=$APP.$cljs$core$__destructure_map$$($map__78172_p__78168$$),$plugin_id$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78172__$1$$,$APP.$cljs$cst$1720$plugin_id$$),$name$jscomp$444$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78172__$1$$,$APP.$cljs$cst$725$name$$),$host$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78172__$1$$,$APP.$cljs$cst$744$host$$),$permissions$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78172__$1$$,
$APP.$cljs$cst$1722$permissions$$);$out_arr__44124__auto__$jscomp$134$$.push(function(){var $is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($permissions_peek$$,$plugin_id$jscomp$14$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1104$$)?$or__5025__auto__$jscomp$1104$$:$permissions$jscomp$32$$}();$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$=
$APP.$cljs$core$contains_QMARK_$$($is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$,"content:write")||$APP.$cljs$core$contains_QMARK_$$($is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$,"library:write");var $can_open_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($user_can_edit_QMARK_$jscomp$3$$)?$user_can_edit_QMARK_$jscomp$3$$:!$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$;$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_open_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($name$jscomp$444$$),$APP.$rumext$v2$adapt$$($host$jscomp$15$$),$APP.$rumext$v2$adapt$$($map__78172__$1$$),$APP.$rumext$v2$adapt$$($user_can_edit_QMARK_$jscomp$3$$)],function($event$jscomp$385$$){return $APP.$cljs$core$truth_$$($can_open_QMARK_$jscomp$1$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"start-plugin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu",$APP.$cljs$cst$725$name$$,$name$jscomp$444$$,$APP.$cljs$cst$744$host$$,$host$jscomp$15$$],null))),$APP.$app$main$data$plugins$open_plugin_BANG_$$($map__78172__$1$$,$user_can_edit_QMARK_$jscomp$3$$)):$APP.$app$util$dom$stop_propagation$$($event$jscomp$385$$)});var $on_key_down$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_open_QMARK_$jscomp$1$$),
$APP.$rumext$v2$adapt$$($name$jscomp$444$$),$APP.$rumext$v2$adapt$$($host$jscomp$15$$),$APP.$rumext$v2$adapt$$($map__78172__$1$$),$APP.$rumext$v2$adapt$$($user_can_edit_QMARK_$jscomp$3$$)],function($event$jscomp$386$$){return $APP.$cljs$core$truth_$$($can_open_QMARK_$jscomp$1$$)&&$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$386$$))?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"start-plugin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu",$APP.$cljs$cst$725$name$$,$name$jscomp$444$$,$APP.$cljs$cst$744$host$$,$host$jscomp$15$$],null))),$APP.$app$main$data$plugins$open_plugin_BANG_$$($map__78172__$1$$,$user_can_edit_QMARK_$jscomp$3$$)):null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$39_permissions__$1$jscomp$2$$,
className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item "+($APP.$cljs$core$not$$($can_open_QMARK_$jscomp$1$$)?"main_ui_workspace_main_menu__disabled":""),onKeyDown:$on_key_down$jscomp$12$$,children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$name$jscomp$444$$}),$APP.$cljs$core$truth_$$($can_open_QMARK_$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.error.need-editor"),
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"help",className:"main_ui_workspace_main_menu__item-icon"})})]},"plugins-menu-"+($idx$jscomp$119$$??""))}());return $out_arr__44124__auto__$jscomp$134$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($plugins$jscomp$1$$))]})}return null});var $app$main$data$workspace$history$initialize_history_78249$$;var $app$main$ui$workspace$presence$session_widget$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($profile__$1$jscomp$5_props_78253$$){var $index$jscomp$475$$=$profile__$1$jscomp$5_props_78253$$.index,$color$jscomp$160$$=$profile__$1$jscomp$5_props_78253$$.color;$profile__$1$jscomp$5_props_78253$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($profile__$1$jscomp$5_props_78253$$.profile,$APP.$cljs$cst$1298$color$$,$color$jscomp$160$$);var $full_name$$=$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$5_props_78253$$);
return(0,$APP.$rumext$v2$jsx$$)("li",{style:{zIndex:""+(2+-1*$index$jscomp$475$$),backgroundColor:$color$jscomp$160$$},title:$full_name$$,className:"main_ui_workspace_presence__session-icon",children:(0,$APP.$rumext$v2$jsx$$)("img",{alt:$full_name$$,style:{backgroundColor:$color$jscomp$160$$},src:$APP.$app$config$resolve_profile_photo_url$$($profile__$1$jscomp$5_props_78253$$)})})}),$app$main$ui$workspace$presence$active_sessions_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){var $profiles$jscomp$3$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$),$presence$jscomp$4_sessions$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_presence$$);$presence$jscomp$4_sessions$$=$APP.$cljs$core$vals$$($presence$jscomp$4_sessions$$);var $num_sessions$$=$APP.$cljs$core$count$$($presence$jscomp$4_sessions$$),$avatar_count$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_sessions$$,3)?3:2,$open_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$open_QMARK_$jscomp$9$$=
$APP.$cljs$core$_deref$$($open_STAR_$jscomp$2$$)&&$num_sessions$$>3,$on_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$2$$,!0);return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$("users-close"))})}),$on_close$jscomp$26$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$2$$,
!1)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$open_QMARK_$jscomp$9$$?(0,$APP.$rumext$v2$jsx$$)("button",{id:"users-close",onClick:$on_close$jscomp$26$$,onBlur:$on_close$jscomp$26$$,className:"main_ui_workspace_presence__active-users-opened",children:(0,$APP.$rumext$v2$jsx$$)("ul",{"data-testid":"active-users-list",className:"main_ui_workspace_presence__active-users-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$135$$,
$session$jscomp$3$$){$out_arr__44124__auto__$jscomp$135$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$presence$session_widget$$,{color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$3$$),index:0,profile:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$3$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$3$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$3$$)??"")));return $out_arr__44124__auto__$jscomp$135$$},
[],$presence$jscomp$4_sessions$$)})}):null,(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_open$jscomp$1$$,className:"main_ui_workspace_presence__active-users",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{"data-testid":"active-users-list",className:"main_ui_workspace_presence__active-users-list",children:[$num_sessions$$>3?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_presence__users-num",children:"+"+(1+($num_sessions$$-3))}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$136$$,
$p__78255_session$jscomp$4$$){var $index$jscomp$476$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78255_session$jscomp$4$$,0,null);$p__78255_session$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78255_session$jscomp$4$$,1,null);$out_arr__44124__auto__$jscomp$136$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$presence$session_widget$$,{color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($p__78255_session$jscomp$4$$),index:$index$jscomp$476$$,
profile:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$3$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p__78255_session$jscomp$4$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p__78255_session$jscomp$4$$)??"")));return $out_arr__44124__auto__$jscomp$136$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($avatar_count$$,$presence$jscomp$4_sessions$$)))]})})]})});var $app$main$ui$workspace$right_header$zoom_widget_workspace$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($open_QMARK_$jscomp$10_props_78260$$){var $on_zoom_reset$jscomp$1$$=$open_QMARK_$jscomp$10_props_78260$$["on-zoom-reset"],$zoom$jscomp$65_zoom__$1$$=$open_QMARK_$jscomp$10_props_78260$$.zoom,$on_zoom_fit$jscomp$1$$=$open_QMARK_$jscomp$10_props_78260$$["on-zoom-fit"],$on_zoom_selected$$=$open_QMARK_$jscomp$10_props_78260$$["on-zoom-selected"],$on_decrease$jscomp$1$$=$open_QMARK_$jscomp$10_props_78260$$["on-decrease"],
$on_increase$jscomp$1$$=$open_QMARK_$jscomp$10_props_78260$$["on-increase"],$open_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$open_QMARK_$jscomp$10_props_78260$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$3$$);var $open_dropdown$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$407$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$407$$);return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$3$$,!0)}),$close_dropdown$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$408$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$408$$);return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$3$$,!1)}),$on_increase__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_increase$jscomp$1$$)],function($event$jscomp$409$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$409$$);return $on_increase$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$on_increase$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_increase$jscomp$1$$()}),$on_decrease__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_decrease$jscomp$1$$)],function($event$jscomp$410$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$410$$);return $on_decrease$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_decrease$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_decrease$jscomp$1$$()});$zoom$jscomp$65_zoom__$1$$=$APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom$jscomp$65_zoom__$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$267$precision$$,0],null));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$open_dropdown$jscomp$3$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom"),className:"main_ui_workspace_right_header__zoom-widget "+($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$10_props_78260$$)?"main_ui_workspace_right_header__selected":""),children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_right_header__label",children:$zoom$jscomp$65_zoom__$1$$})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$open_QMARK_$jscomp$10_props_78260$$,"on-close":$close_dropdown$jscomp$3$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_right_header__dropdown",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_right_header__basic-zoom-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_right_header__zoom-btns",
children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.decrease-zoom"),onClick:$on_decrease__$1$jscomp$1$$,icon:"remove"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_right_header__zoom-text",children:$zoom$jscomp$65_zoom__$1$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.increase-zoom"),
onClick:$on_increase__$1$jscomp$1$$,icon:"add"})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_zoom_reset$jscomp$1$$,className:"main_ui_workspace_right_header__reset-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.reset-zoom")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_zoom_fit$jscomp$1$$,className:"main_ui_workspace_right_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-fit-all"),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_right_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$137$$,$sc$jscomp$11$$){$out_arr__44124__auto__$jscomp$137$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_right_header__shortcut-key",children:$sc$jscomp$11$$},["zoom-fit-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sc$jscomp$11$$)].join("")));return $out_arr__44124__auto__$jscomp$137$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4806$fit_all$$)))})]}),
(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_zoom_selected$$,className:"main_ui_workspace_right_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-selected"),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_right_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$138$$,$sc$jscomp$12$$){$out_arr__44124__auto__$jscomp$138$$.push((0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_right_header__shortcut-key",children:$sc$jscomp$12$$},["zoom-selected-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sc$jscomp$12$$)].join("")));return $out_arr__44124__auto__$jscomp$138$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4856$zoom_selected$$)))})]})]})})]})});var $app$main$ui$workspace$sidebar$assets$groups$schema_COLON_group_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GroupForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null)],null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$22$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$22$$,$cljs$cst$5597$name_group_dialog$$,$app$main$ui$workspace$sidebar$assets$groups$name_group_dialog$$)});var $app$main$ui$workspace$sidebar$assets$colors$colors_group$$=function $app$main$ui$workspace$sidebar$assets$colors$colors_group$$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$){$group_open_QMARK__map__78285_map__78285__$1_props_78284$$=$APP.$rumext$v2$util$wrap_props$$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$);$group_open_QMARK__map__78285_map__78285__$1_props_78284$$=$APP.$cljs$core$__destructure_map$$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$);
var $groups$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$APP.$cljs$cst$4382$groups$$),$on_asset_click$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5625$on_asset_click$$),$on_rename_group$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5626$on_rename_group$$),
$selected_full$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5627$selected_full$$),$on_assets_delete$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5628$on_assets_delete$$),$force_open_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5629$force_open_QMARK_$$),
$selected$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$APP.$cljs$cst$1921$selected$$),$file_id$jscomp$388$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$APP.$cljs$cst$1644$file_id$$),$multi_assets_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5630$multi_assets_QMARK_$$),
$on_ungroup$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5631$on_ungroup$$),$local_QMARK_$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$APP.$cljs$cst$3693$local_QMARK_$$),$colors$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$APP.$cljs$cst$2212$colors$$),
$open_groups$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5632$open_groups$$),$prefix$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$APP.$cljs$cst$971$prefix$$),$on_clear_selection$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5594$on_clear_selection$$),
$on_group$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5633$on_group$$),$multi_colors_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5634$multi_colors_QMARK_$$),$on_delete_group$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78285_map__78285__$1_props_78284$$,$cljs$cst$5635$on_delete_group$$);
$group_open_QMARK__map__78285_map__78285__$1_props_78284$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_groups$$,$prefix$jscomp$68$$)===!1?!1:$force_open_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_groups$$,$prefix$jscomp$68$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$68$$,"")?!0:!1);var $dragging_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$6$$),
$selected_paths$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_full$jscomp$3$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$("")),$selected_full$jscomp$3$$)}),$move_color$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$libraries$rename_color$$,$file_id$jscomp$388$$)),$on_drag_enter$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$6$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$68$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$5$$)],function($event$jscomp$423$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$($event$jscomp$423$$,
$dragging_STAR_$jscomp$6$$,$prefix$jscomp$68$$,$selected_paths$jscomp$5$$)}),$on_drag_leave$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$6$$)],function($event$jscomp$424$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$424$$,$dragging_STAR_$jscomp$6$$)}),$on_drop$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$6$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$68$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$3$$),$APP.$rumext$v2$adapt$$($move_color$jscomp$1$$)],function($event$jscomp$425$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$($event$jscomp$425$$,$dragging_STAR_$jscomp$6$$,$prefix$jscomp$68$$,$selected_paths$jscomp$5$$,$selected_full$jscomp$3$$,$move_color$jscomp$1$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$3$$,
onDragLeave:$on_drag_leave$jscomp$3$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$6$$,className:"main_ui_workspace_sidebar_assets_colors__colors-group",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,{fileId:$file_id$jscomp$388$$,section:$APP.$cljs$cst$2212$colors$$,path:$prefix$jscomp$68$$,isGroupOpen:$group_open_QMARK__map__78285_map__78285__$1_props_78284$$,onRename:$on_rename_group$$,onUngroup:$on_ungroup$jscomp$1$$,
onDeleteGroup:$on_delete_group$jscomp$1$$}),$group_open_QMARK__map__78285_map__78285__$1_props_78284$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[function(){var $colors__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$6$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$3$$,onDragLeave:$on_drag_leave$jscomp$3$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$6$$,
className:"main_ui_workspace_sidebar_assets_colors__asset-list",children:[$dragging_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__grid-placeholder",children:" "}):null,$APP.$cljs$core$empty_QMARK_$$($colors__$1$jscomp$5$$)&&$groups$jscomp$6$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__drop-space"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$139$$,
$color$jscomp$162$$){$out_arr__44124__auto__$jscomp$139$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$color_item$$,{"selected-full":$selected_full$jscomp$3$$,"on-assets-delete":$on_assets_delete$jscomp$1$$,selected:$selected$jscomp$155$$,color:$color$jscomp$162$$,"file-id":$file_id$jscomp$388$$,"multi-assets?":$multi_assets_QMARK_$jscomp$1$$,"local?":$local_QMARK_$jscomp$6$$,colors:$colors__$1$jscomp$5$$,"move-color":$move_color$jscomp$1$$,"on-group":$on_group$jscomp$1$$,
"on-clear-selection":$on_clear_selection$jscomp$2$$,"multi-colors?":$multi_colors_QMARK_$jscomp$1$$,"selected-paths":$selected_paths$jscomp$5$$,"on-asset-click":$on_asset_click$jscomp$1$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$162$$)??"")));return $out_arr__44124__auto__$jscomp$139$$},[],$colors__$1$jscomp$5$$)]})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$140$$,$content$jscomp$246_p__78287$$){var $path_item$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$246_p__78287$$,0,null);$content$jscomp$246_p__78287$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$246_p__78287$$,1,null);$out_arr__44124__auto__$jscomp$140$$.push($APP.$cljs$core$empty_QMARK_$$($path_item$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$colors_group$$,{"selected-full":$selected_full$jscomp$3$$,"on-assets-delete":$on_assets_delete$jscomp$1$$,"force-open?":$force_open_QMARK_$$,
selected:$selected$jscomp$155$$,"file-id":$file_id$jscomp$388$$,"multi-assets?":$multi_assets_QMARK_$jscomp$1$$,"on-ungroup":$on_ungroup$jscomp$1$$,"local?":$local_QMARK_$jscomp$6$$,colors:$colors$jscomp$21$$,"open-groups":$open_groups$$,prefix:$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$68$$,$path_item$$),"on-group":$on_group$jscomp$1$$,"on-clear-selection":$on_clear_selection$jscomp$2$$,"multi-colors?":$multi_colors_QMARK_$jscomp$1$$,"on-delete-group":$on_delete_group$jscomp$1$$,
groups:$content$jscomp$246_p__78287$$,"on-asset-click":$on_asset_click$jscomp$1$$,"on-rename-group":$on_rename_group$$},"group-"+($path_item$$??"")));return $out_arr__44124__auto__$jscomp$140$$},[],$groups$jscomp$6$$)]}):null]})};var $app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2574$is_local$$,!1],null)),$app$main$ui$workspace$sidebar$assets$components$count_leaves$$=function $app$main$ui$workspace$sidebar$assets$components$count_leaves$$($m$jscomp$237$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$157$$,$_$jscomp$3005$$,$v$jscomp$664$$){return $APP.$cljs$core$map_QMARK_$$($v$jscomp$664$$)?
$acc$jscomp$157$$+($app$main$ui$workspace$sidebar$assets$components$count_leaves$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$workspace$sidebar$assets$components$count_leaves$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$664$$):$app$main$ui$workspace$sidebar$assets$components$count_leaves$$($v$jscomp$664$$)):$APP.$cljs$core$vector_QMARK_$$($v$jscomp$664$$)?$acc$jscomp$157$$+$APP.$cljs$core$count$$($v$jscomp$664$$):$acc$jscomp$157$$},0,$m$jscomp$237$$)},$app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$=
function $app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$($group_open_QMARK_$jscomp$1_props_78311$$){var $on_group_combine_variants$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78311$$.onGroupCombineVariants,$groups$jscomp$8$$=$group_open_QMARK_$jscomp$1_props_78311$$.groups,$on_asset_click$jscomp$4$$=$group_open_QMARK_$jscomp$1_props_78311$$.onAssetClick,$on_rename_group$jscomp$2$$=$group_open_QMARK_$jscomp$1_props_78311$$.onRenameGroup,$selected_full$jscomp$6$$=$group_open_QMARK_$jscomp$1_props_78311$$.selectedFull,
$selected$jscomp$158$$=$group_open_QMARK_$jscomp$1_props_78311$$.selected,$file_id$jscomp$392$$=$group_open_QMARK_$jscomp$1_props_78311$$.fileId,$cancel_rename$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78311$$.cancelRename,$is_listing_thumbs$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78311$$.isListingThumbs,$count_variants$$=$group_open_QMARK_$jscomp$1_props_78311$$.countVariants,$is_force_open$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78311$$.isForceOpen,$on_ungroup$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78311$$.onUngroup,
$on_context_menu$jscomp$5$$=$group_open_QMARK_$jscomp$1_props_78311$$.onContextMenu,$renaming$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78311$$.renaming,$open_groups$jscomp$2$$=$group_open_QMARK_$jscomp$1_props_78311$$.openGroups,$prefix$jscomp$69$$=$group_open_QMARK_$jscomp$1_props_78311$$.prefix,$do_rename$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78311$$.doRename,$is_local$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78311$$.isLocal,$on_group$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78311$$.onGroup,
$on_drag_start$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78311$$.onDragStart,$on_delete_group$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78311$$.onDeleteGroup;$group_open_QMARK_$jscomp$1_props_78311$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_groups$jscomp$2$$,$prefix$jscomp$69$$)===!1?!1:$is_force_open$jscomp$1$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_groups$jscomp$2$$,$prefix$jscomp$69$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$69$$,
"")?!0:!1);var $dragging_STAR_$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$6$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$8$$),$selected_paths$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_full$jscomp$6$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$("")),$selected_full$jscomp$6$$)}),$components$jscomp$13$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$8$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$)),$can_combine_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($groups$jscomp$8$$),$APP.$rumext$v2$adapt$$($components$jscomp$13$$)],function(){if($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)){var $and__5023__auto____$1$jscomp$130_and__5023__auto____$2$jscomp$42$$=
$app$main$ui$workspace$sidebar$assets$components$count_leaves$$($groups$jscomp$8$$)>1;return $and__5023__auto____$1$jscomp$130_and__5023__auto____$2$jscomp$42$$?($and__5023__auto____$1$jscomp$130_and__5023__auto____$2$jscomp$42$$=$cljs$core$not_any_QMARK_$$($APP.$app$common$types$component$is_variant_QMARK_$$,$components$jscomp$13$$))?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2063$main_instance_page$$,
$components$jscomp$13$$)):$and__5023__auto____$1$jscomp$130_and__5023__auto____$2$jscomp$42$$:$and__5023__auto____$1$jscomp$130_and__5023__auto____$2$jscomp$42$$}return $is_local$jscomp$3$$}),$on_drag_enter$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$8$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$69$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$7$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],
function($event$jscomp$436$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?$APP.$cljs$cst$2574$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$3$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$($event$jscomp$436$$,$dragging_STAR_$jscomp$8$$,$prefix$jscomp$69$$,$selected_paths$jscomp$7$$):null}),$on_drag_leave$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$8$$),
$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$437$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?$APP.$cljs$cst$2574$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$3$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$437$$,
$dragging_STAR_$jscomp$8$$):null}),$on_drop$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$8$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$69$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$6$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$438$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?
$APP.$cljs$cst$2574$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$3$$)?$app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$($event$jscomp$438$$,$dragging_STAR_$jscomp$8$$,$prefix$jscomp$69$$,$selected_paths$jscomp$7$$,$selected_full$jscomp$6$$,$APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$5$$,
onDragLeave:$on_drag_leave$jscomp$5$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$8$$,className:"main_ui_workspace_sidebar_assets_components__component-group",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,{path:$prefix$jscomp$69$$,section:$APP.$cljs$cst$1638$components$$,onUngroup:$on_ungroup$jscomp$3$$,onGroupCombineVariants:$on_group_combine_variants$jscomp$1$$,isCanCombine:$can_combine_QMARK_$$,onDeleteGroup:$on_delete_group$jscomp$3$$,
onRename:$on_rename_group$jscomp$2$$,isGroupOpen:$group_open_QMARK_$jscomp$1_props_78311$$,fileId:$file_id$jscomp$392$$}),$group_open_QMARK_$jscomp$1_props_78311$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$5$$,onDragLeave:$on_drag_leave$jscomp$5$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$8$$,className:($APP.$cljs$core$truth_$$($is_listing_thumbs$jscomp$1$$)?"main_ui_workspace_sidebar_assets_components__component-group-grid":
"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$jscomp$1$$)?"main_ui_workspace_sidebar_assets_components__component-group-list":""),children:[$dragging_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_components__component-group-placeholder",children:" "}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$754_and__5023__auto____$1$jscomp$131$$=$APP.$cljs$core$empty_QMARK_$$($components$jscomp$13$$);return $and__5023__auto__$jscomp$754_and__5023__auto____$1$jscomp$131$$?
($and__5023__auto__$jscomp$754_and__5023__auto____$1$jscomp$131$$=$groups$jscomp$8$$!=null)?$is_local$jscomp$3$$:$and__5023__auto__$jscomp$754_and__5023__auto____$1$jscomp$131$$:$and__5023__auto__$jscomp$754_and__5023__auto____$1$jscomp$131$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_components__component-group-drop-space "+($APP.$cljs$core$not$$($dragging_QMARK_$jscomp$6$$)?"main_ui_workspace_sidebar_assets_components__component-group-drop-space-small":"")}):
null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$141$$,$component$jscomp$126$$){var $JSCompiler_temp_const$jscomp$1780$$=$out_arr__44124__auto__$jscomp$141$$.push;var $G__78321$jscomp$inline_8841_JSCompiler_inline_result$jscomp$1782$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$126$$);$G__78321$jscomp$inline_8841_JSCompiler_inline_result$jscomp$1782$$=$count_variants$$.$cljs$core$IFn$_invoke$arity$1$?$count_variants$$.$cljs$core$IFn$_invoke$arity$1$($G__78321$jscomp$inline_8841_JSCompiler_inline_result$jscomp$1782$$):
$count_variants$$($G__78321$jscomp$inline_8841_JSCompiler_inline_result$jscomp$1782$$);$JSCompiler_temp_const$jscomp$1780$$.call($out_arr__44124__auto__$jscomp$141$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_item_STAR_$$,{isLocal:$is_local$jscomp$3$$,selected:$selected$jscomp$158$$,onGroup:$on_group$jscomp$3$$,onAssetClick:$on_asset_click$jscomp$4$$,doRename:$do_rename$jscomp$3$$,component:$component$jscomp$126$$,cancelRename:$cancel_rename$jscomp$1$$,numVariants:$G__78321$jscomp$inline_8841_JSCompiler_inline_result$jscomp$1782$$,
onContextMenu:$on_context_menu$jscomp$5$$,isListingThumbs:$is_listing_thumbs$jscomp$1$$,renaming:$renaming$jscomp$1$$,onDragStart:$on_drag_start$jscomp$3$$,fileId:$file_id$jscomp$392$$,selectedFull:$selected_full$jscomp$6$$,selectedPaths:$selected_paths$jscomp$7$$},"component-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$126$$)??"")));return $out_arr__44124__auto__$jscomp$141$$},[],$components$jscomp$13$$)]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$142$$,
$content$jscomp$247_p__78322$$){var $path_item$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$247_p__78322$$,0,null);$content$jscomp$247_p__78322$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$247_p__78322$$,1,null);$out_arr__44124__auto__$jscomp$142$$.push($APP.$cljs$core$empty_QMARK_$$($path_item$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$,{isLocal:$is_local$jscomp$3$$,
selected:$selected$jscomp$158$$,onRenameGroup:$on_rename_group$jscomp$2$$,onAssetClick:$on_asset_click$jscomp$4$$,prefix:$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$69$$,$path_item$jscomp$1$$),isForceOpen:$is_force_open$jscomp$1$$,doRename:$do_rename$jscomp$3$$,countVariants:$count_variants$$,cancelRename:$cancel_rename$jscomp$1$$,onContextMenu:$on_context_menu$jscomp$5$$,isListingThumbs:$is_listing_thumbs$jscomp$1$$,onUngroup:$on_ungroup$jscomp$3$$,onGroupCombineVariants:$on_group_combine_variants$jscomp$1$$,
openGroups:$open_groups$jscomp$2$$,onDeleteGroup:$on_delete_group$jscomp$3$$,renaming:$renaming$jscomp$1$$,onDragStart:$on_drag_start$jscomp$3$$,fileId:$file_id$jscomp$392$$,groups:$content$jscomp$247_p__78322$$,selectedFull:$selected_full$jscomp$6$$},$path_item$jscomp$1$$));return $out_arr__44124__auto__$jscomp$142$$},[],$groups$jscomp$8$$)]}):null]})};var $shadow$js$shim$module$0react_virtualized$$=shadow$bridge("react-virtualized");var $app$main$ui$workspace$sidebar$options$menus$typography$font_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78355_style$jscomp$72$$){var $is_current$$=$props_78355_style$jscomp$72$$.isCurrent,$on_click$jscomp$41$$=$props_78355_style$jscomp$72$$.onClick,$font$jscomp$44$$=$props_78355_style$jscomp$72$$.font;$props_78355_style$jscomp$72$$=$props_78355_style$jscomp$72$$.style;var $item_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(),$on_click__$1$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$44$$)],function(){return $on_click$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$44$$):$on_click$jscomp$41$$($font$jscomp$44$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_current$$)],function(){if($APP.$cljs$core$truth_$$($is_current$$)){var $element$jscomp$81$$=$APP.$rumext$v2$ref_val$$($item_ref$jscomp$5$$);
return $APP.$cljs$core$truth_$$($app$util$dom$is_in_viewport_QMARK_$$($element$jscomp$81$$))?null:$element$jscomp$81$$!=null?$element$jscomp$81$$.scrollIntoView(!1):null}return null});return(0,$APP.$rumext$v2$jsx$$)("div",{style:$props_78355_style$jscomp$72$$,ref:$item_ref$jscomp$5$$,onClick:$on_click__$1$jscomp$2$$,className:"main_ui_workspace_sidebar_options_menus_typography__font-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-item "+
($APP.$cljs$core$truth_$$($is_current$$)?"main_ui_workspace_sidebar_options_menus_typography__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__font-item-label",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$44$$)}),$APP.$cljs$core$truth_$$($is_current$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s"}):null]})})}),$app$main$ui$workspace$sidebar$options$menus$typography$typography_advanced_options$$=
$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__78397_name_input_ref_props_78396$$){$map__78397_name_input_ref_props_78396$$=$APP.$rumext$v2$util$wrap_props$$($map__78397_name_input_ref_props_78396$$);var $map__78397__$1_typography$jscomp$32$$=$APP.$cljs$core$__destructure_map$$($map__78397_name_input_ref_props_78396$$);$map__78397_name_input_ref_props_78396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$cljs$cst$5640$name_input_ref$$);
var $on_key_down$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$cljs$cst$5641$on_key_down$$),$on_change$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$APP.$cljs$cst$4157$on_change$$),$is_asset_QMARK__show_actions_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$cljs$cst$5642$is_asset_QMARK_$$),$navigate_to_library$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,
$cljs$cst$5643$navigate_to_library$$),$on_name_blur$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$cljs$cst$5644$on_name_blur$$),$visible_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$cljs$cst$5645$visible_QMARK_$$),$file_id$jscomp$394$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$APP.$cljs$cst$1644$file_id$$),$on_close$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,
$APP.$cljs$cst$4994$on_close$$),$local_QMARK_$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$APP.$cljs$cst$3693$local_QMARK_$$),$editable_QMARK_$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$cljs$cst$5646$editable_QMARK_$$);$map__78397__$1_typography$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78397__$1_typography$jscomp$32$$,$APP.$cljs$cst$1981$typography$$);
var $ref$jscomp$51$$=(0,$APP.$rumext$v2$use_ref$$)(null),$font_data$jscomp$12$$=$APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)),$typography_id$jscomp$8$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$);$is_asset_QMARK__show_actions_QMARK_$$=$APP.$cljs$core$truth_$$($is_asset_QMARK__show_actions_QMARK_$$)?$editable_QMARK_$jscomp$8$$:$is_asset_QMARK__show_actions_QMARK_$$;
var $on_delete$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography_id$jscomp$8$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$394$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$28$$)],function(){$on_close$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$28$$();var $undo_id$jscomp$101$$=Symbol();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$101$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$delete_typography$$($typography_id$jscomp$8$$),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$394$$,$file_id$jscomp$394$$,$APP.$cljs$cst$2215$typographies$$,$typography_id$jscomp$8$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$101$$)]))}),$on_duplicate$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$394$$),
$APP.$rumext$v2$adapt$$($typography_id$jscomp$8$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_typography$$($file_id$jscomp$394$$,$typography_id$jscomp$8$$))});$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($visible_QMARK_$jscomp$1$$)],
function(){var $temp__5825__auto__$jscomp$362$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$51$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$362$$)?$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$1$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$362$$,!1):null:null});return $APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$ref$jscomp$51$$,className:"main_ui_workspace_sidebar_options_menus_typography__advanced-options-wrapper",
children:$editable_QMARK_$jscomp$8$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$),
fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)},className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample-input",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$map__78397_name_input_ref_props_78396$$,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$),
maxLength:255,onKeyDown:$on_key_down$jscomp$14$$,onBlur:$on_name_blur$$,className:"main_ui_workspace_sidebar_options_menus_typography__adv-typography-name"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__action-btns",children:[$APP.$cljs$core$truth_$$($is_asset_QMARK__show_actions_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),onClick:$on_duplicate$jscomp$2$$,icon:"clipboard"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),onClick:$on_delete$jscomp$10$$,icon:"delete"})]}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$28$$,icon:"tick"})]})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$,{values:$map__78397__$1_typography$jscomp$32$$,onChange:$on_change$jscomp$51$$,showRecent:!1})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-info-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_typography__typography-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)},className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$),className:"main_ui_workspace_sidebar_options_menus_typography__typography-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-font",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$12$$)}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$28$$,icon:"menu"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.font-style")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.font-size")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.line-height")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.letter-spacing")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.text-transform")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($map__78397__$1_typography$jscomp$32$$)})]}),$APP.$cljs$core$truth_$$($local_QMARK_$jscomp$7$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",onClick:$navigate_to_library$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.go-to-edit")})]})}):null});var $app$main$ui$workspace$sidebar$assets$typographies$lens_COLON_typography_section_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($gstate$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5647$rename_typography$$,$cljs$cst$5647$rename_typography$$.$cljs$core$IFn$_invoke$arity$1$($gstate$$),$APP.$cljs$cst$3915$edit_typography$$,$APP.$cljs$cst$3915$edit_typography$$.$cljs$core$IFn$_invoke$arity$1$($gstate$$)],null)},$APP.$app$main$refs$workspace_global$$,
$APP.$cljs$core$_EQ_$$),$app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$=function $app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$($group_open_QMARK_$jscomp$2_props_78412$$){var $groups$jscomp$10$$=$group_open_QMARK_$jscomp$2_props_78412$$.groups,$on_asset_click$jscomp$7$$=$group_open_QMARK_$jscomp$2_props_78412$$["on-asset-click"],$on_rename_group$jscomp$4$$=$group_open_QMARK_$jscomp$2_props_78412$$["on-rename-group"],$selected_full$jscomp$9$$=$group_open_QMARK_$jscomp$2_props_78412$$["selected-full"],
$force_open_QMARK_$jscomp$1$$=$group_open_QMARK_$jscomp$2_props_78412$$["force-open?"],$handle_change$jscomp$7$$=$group_open_QMARK_$jscomp$2_props_78412$$["handle-change"],$selected$jscomp$163$$=$group_open_QMARK_$jscomp$2_props_78412$$.selected,$file_id$jscomp$397$$=$group_open_QMARK_$jscomp$2_props_78412$$["file-id"],$is_read_only$jscomp$2$$=$group_open_QMARK_$jscomp$2_props_78412$$["is-read-only"],$file$jscomp$164$$=$group_open_QMARK_$jscomp$2_props_78412$$.file,$on_ungroup$jscomp$5$$=$group_open_QMARK_$jscomp$2_props_78412$$["on-ungroup"],
$local_QMARK_$jscomp$10$$=$group_open_QMARK_$jscomp$2_props_78412$$["local?"],$on_context_menu$jscomp$9$$=$group_open_QMARK_$jscomp$2_props_78412$$["on-context-menu"],$local_data$$=$group_open_QMARK_$jscomp$2_props_78412$$["local-data"],$open_groups$jscomp$4$$=$group_open_QMARK_$jscomp$2_props_78412$$["open-groups"],$prefix$jscomp$70$$=$group_open_QMARK_$jscomp$2_props_78412$$.prefix,$editing_id$jscomp$2$$=$group_open_QMARK_$jscomp$2_props_78412$$["editing-id"],$renaming_id$jscomp$1$$=$group_open_QMARK_$jscomp$2_props_78412$$["renaming-id"],
$on_delete_group$jscomp$5$$=$group_open_QMARK_$jscomp$2_props_78412$$["on-delete-group"];$group_open_QMARK_$jscomp$2_props_78412$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_groups$jscomp$4$$,$prefix$jscomp$70$$)===!1?!1:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_groups$jscomp$4$$,$prefix$jscomp$70$$,!0);var $dragging_STAR_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$8$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$10$$),
$selected_paths$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_full$jscomp$9$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$("")),$selected_full$jscomp$9$$)}),$move_typography$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$397$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$libraries$rename_typography$$,$file_id$jscomp$397$$)),$on_drag_enter$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$10$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$70$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$9$$)],function($event$jscomp$460$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$($event$jscomp$460$$,
$dragging_STAR_$jscomp$10$$,$prefix$jscomp$70$$,$selected_paths$jscomp$9$$)}),$on_drag_leave$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$10$$)],function($event$jscomp$461$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$461$$,$dragging_STAR_$jscomp$10$$)}),$on_drop$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$10$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$70$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$9$$),$APP.$rumext$v2$adapt$$($move_typography$jscomp$1$$)],function($event$jscomp$462$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$($event$jscomp$462$$,$dragging_STAR_$jscomp$10$$,$prefix$jscomp$70$$,$selected_paths$jscomp$9$$,$selected_full$jscomp$9$$,$move_typography$jscomp$1$$)}),$add_typography_to_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$397$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$70$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$397$$,$APP.$cljs$cst$2215$typographies$$,!0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$397$$,$prefix$jscomp$70$$)]))});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$7$$,
onDragLeave:$on_drag_leave$jscomp$7$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$10$$,className:"main_ui_workspace_sidebar_assets_typographies__typographies-group",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,{fileId:$file_id$jscomp$397$$,section:$APP.$cljs$cst$2215$typographies$$,path:$prefix$jscomp$70$$,isGroupOpen:$group_open_QMARK_$jscomp$2_props_78412$$,onRename:$on_rename_group$jscomp$4$$,onUngroup:$on_ungroup$jscomp$5$$,
onDeleteGroup:$on_delete_group$jscomp$5$$,onAdd:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($local_QMARK_$jscomp$10$$)?$APP.$cljs$core$not$$($is_read_only$jscomp$2$$):$local_QMARK_$jscomp$10$$)?$add_typography_to_group$$:null}),$APP.$cljs$core$truth_$$($group_open_QMARK_$jscomp$2_props_78412$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[function(){var $typographies$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$10$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$7$$,onDragLeave:$on_drag_leave$jscomp$7$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$10$$,className:"main_ui_workspace_sidebar_assets_typographies__assets-list",children:[$dragging_QMARK_$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_typographies__grid-placeholder",children:" "}):null,$APP.$cljs$core$empty_QMARK_$$($typographies$jscomp$7$$)&&$groups$jscomp$10$$!=
null?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_typographies__drop-space"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$145$$,$map__78415__$1_p__78414$$){$map__78415__$1_p__78414$$=$APP.$cljs$core$__destructure_map$$($map__78415__$1_p__78414$$);var $id$jscomp$944$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78415__$1_p__78414$$,$APP.$cljs$cst$266$id$$);$out_arr__44124__auto__$jscomp$145$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typography_item$$,
{"selected-full":$selected_full$jscomp$9$$,"handle-change":$handle_change$jscomp$7$$,selected:$selected$jscomp$163$$,"rename?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5647$rename_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$$),$id$jscomp$944$$),"file-id":$file_id$jscomp$397$$,"local?":$local_QMARK_$jscomp$10$$,"on-context-menu":$on_context_menu$jscomp$9$$,"editing-id":$editing_id$jscomp$2$$,typography:$map__78415__$1_p__78414$$,"renaming-id":$renaming_id$jscomp$1$$,
"selected-paths":$selected_paths$jscomp$9$$,"move-typography":$move_typography$jscomp$1$$,"on-asset-click":$on_asset_click$jscomp$7$$},"typography-"+($id$jscomp$944$$??"")));return $out_arr__44124__auto__$jscomp$145$$},[],$typographies$jscomp$7$$)]})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$146$$,$content$jscomp$248_p__78416$$){var $path_item$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$248_p__78416$$,
0,null);$content$jscomp$248_p__78416$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$248_p__78416$$,1,null);$out_arr__44124__auto__$jscomp$146$$.push($APP.$cljs$core$empty_QMARK_$$($path_item$jscomp$2$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$,{"selected-full":$selected_full$jscomp$9$$,"force-open?":$force_open_QMARK_$jscomp$1$$,"handle-change":$handle_change$jscomp$7$$,selected:$selected$jscomp$163$$,"file-id":$file_id$jscomp$397$$,
"is-read-only":$is_read_only$jscomp$2$$,"on-ungroup":$on_ungroup$jscomp$5$$,file:$file$jscomp$164$$,"local?":$local_QMARK_$jscomp$10$$,"on-context-menu":$on_context_menu$jscomp$9$$,"local-data":$local_data$$,"open-groups":$open_groups$jscomp$4$$,prefix:$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$70$$,$path_item$jscomp$2$$),"editing-id":$editing_id$jscomp$2$$,"renaming-id":$renaming_id$jscomp$1$$,"on-delete-group":$on_delete_group$jscomp$5$$,groups:$content$jscomp$248_p__78416$$,"on-asset-click":$on_asset_click$jscomp$7$$,
"on-rename-group":$on_rename_group$jscomp$4$$},"group-"+($path_item$jscomp$2$$??"")));return $out_arr__44124__auto__$jscomp$146$$},[],$groups$jscomp$10$$)]}):null]})};var $app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_open_status$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$4496$open_status$$],null)),$APP.$app$main$store$state$$),$app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4495$workspace_assets$$,$APP.$cljs$cst$1921$selected$$],null)),$APP.$app$main$store$state$$);var $app$main$ui$workspace$sidebar$assets$assets_libraries_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($libraries$jscomp$144_props_78512$$){var $filters$jscomp$9$$=$libraries$jscomp$144_props_78512$$.filters,$file_id$jscomp$405$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$files$jscomp$28$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$);$libraries$jscomp$144_props_78512$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$28$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$405$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78511_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78511_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$168$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($file$jscomp$168$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1630$pages_index$$)},
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78510_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$405$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78510_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5650$is_indirect$$,$APP.$cljs$core$vals$$($APP.$app$main$refs$select_libraries$$($files$jscomp$28$$,$file_id$jscomp$405$$))))))});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$147$$,
$file$jscomp$169$$){$out_arr__44124__auto__$jscomp$147$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$,{file:$file$jscomp$169$$,isLocal:!1,isDefaultOpen:!1,filters:$filters$jscomp$9$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$169$$)??"")));return $out_arr__44124__auto__$jscomp$147$$},[],$libraries$jscomp$144_props_78512$$)}),$app$main$ui$workspace$sidebar$assets$ref_COLON_local_library$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file$jscomp$170$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($file$jscomp$170$$,
$APP.$cljs$cst$142$data$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1630$pages_index$$)},$APP.$app$main$refs$file$$),$app$main$ui$workspace$sidebar$assets$session_filters_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$main$ui$workspace$sidebar$assets$assets_toolbox_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78528_size$jscomp$148$$){var $file_id$jscomp$406$$=$props_78528_size$jscomp$148$$.fileId;
$props_78528_size$jscomp$148$$=$props_78528_size$jscomp$148$$.size;var $read_only_QMARK_$jscomp$20$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$filters_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $JSCompiler_temp_const$jscomp$1787$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$11024_or__5025__auto__$jscomp$inline_8857$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$session_filters_STAR_$$),
$file_id$jscomp$406$$);$JSCompiler_temp_const$jscomp$11024_or__5025__auto__$jscomp$inline_8857$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$11024_or__5025__auto__$jscomp$inline_8857$$)?$JSCompiler_temp_const$jscomp$11024_or__5025__auto__$jscomp$inline_8857$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2513$term$$,"",$APP.$cljs$cst$1366$section$$,"all"],null);var $JSCompiler_inline_result$jscomp$11025_or__5025__auto__$jscomp$inline_13525$$=$cljs$cst$5620$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_ordering$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$);
$JSCompiler_inline_result$jscomp$11025_or__5025__auto__$jscomp$inline_13525$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11025_or__5025__auto__$jscomp$inline_13525$$)?$JSCompiler_inline_result$jscomp$11025_or__5025__auto__$jscomp$inline_13525$$:$APP.$cljs$cst$5153$asc$$;var $or__5025__auto__$jscomp$inline_13527$$=$cljs$cst$5621$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_list_style$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$);return $JSCompiler_temp_const$jscomp$1787$$.call($APP.$cljs$core$assoc$$,
$JSCompiler_temp_const$jscomp$11024_or__5025__auto__$jscomp$inline_8857$$,$cljs$cst$5592$ordering$$,$JSCompiler_inline_result$jscomp$11025_or__5025__auto__$jscomp$inline_13525$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5649$list_style$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13527$$)?$or__5025__auto__$jscomp$inline_13527$$:$cljs$cst$5622$thumbs$$,$cljs$cst$5651$open_menu$$,!1]))}),$filters$jscomp$11$$=$APP.$cljs$core$_deref$$($filters_STAR_$$),
$term$jscomp$9$$=$APP.$cljs$cst$2513$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$list_style$jscomp$3$$=$APP.$cljs$cst$5649$list_style$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$menu_open_QMARK_$$=$cljs$cst$5651$open_menu$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$section$jscomp$29$$=$APP.$cljs$cst$1366$section$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$ordering$jscomp$3$$=$cljs$cst$5592$ordering$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),
$reverse_sort_QMARK_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2698$desc$$,$ordering$jscomp$3$$),$libs$jscomp$1_shared_QMARK_$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$num_libs$$=$APP.$cljs$core$count$$($libs$jscomp$1_shared_QMARK_$jscomp$7$$),$file$jscomp$172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libs$jscomp$1_shared_QMARK_$jscomp$7$$,$file_id$jscomp$406$$);$libs$jscomp$1_shared_QMARK_$jscomp$7$$=$APP.$cljs$cst$2182$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$172$$);
var $components$jscomp$16$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$172$$)],function(){return $APP.$app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$172$$))}),$toggle_ordering$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ordering$jscomp$3$$)],function(){var $new_value$jscomp$21$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ordering$jscomp$3$$,
$APP.$cljs$cst$5153$asc$$)?$APP.$cljs$cst$2698$desc$$:$APP.$cljs$cst$5153$asc$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5592$ordering$$,$new_value$jscomp$21$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$cljs$cst$5620$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_ordering$$,$new_value$jscomp$21$$)}),$toggle_list_style$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($list_style$jscomp$3$$)],
function(){var $new_value$jscomp$22$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($list_style$jscomp$3$$,$cljs$cst$5622$thumbs$$)?$APP.$cljs$cst$201$list$$:$cljs$cst$5622$thumbs$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5649$list_style$$,$new_value$jscomp$22$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$cljs$cst$5621$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_list_style$$,
$new_value$jscomp$22$$)}),$on_search_term_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$467$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clear_assets_section_open$$());return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2513$term$$,$event$jscomp$467$$)}),$on_section_filter_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$468_value$jscomp$809$$){var $or__5025__auto__$jscomp$inline_8867$$=
$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$468_value$jscomp$809$$));$event$jscomp$468_value$jscomp$809$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8867$$)?$or__5025__auto__$jscomp$inline_8867$$:$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_current_target$$($event$jscomp$468_value$jscomp$809$$),"data-testid");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clear_assets_section_open$$());return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($filters_STAR_$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1366$section$$,$event$jscomp$468_value$jscomp$809$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5651$open_menu$$,!1]))}),$show_libraries_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$406$$)],function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3971$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$406$$],null))}),$on_open_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$update$$,$cljs$cst$5651$open_menu$$,$APP.$cljs$core$not$$)}),$on_menu_close$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,
$cljs$cst$5651$open_menu$$,!1)}),$options$jscomp$612$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_section_filter_change$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.box-filter-all"),$APP.$cljs$cst$266$id$$,"all",$APP.$cljs$cst$2402$handler$$,
$on_section_filter_change$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components"),$APP.$cljs$cst$266$id$$,"components",$APP.$cljs$cst$2402$handler$$,$on_section_filter_change$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),$APP.$cljs$cst$266$id$$,"colors",$APP.$cljs$cst$2402$handler$$,
$on_section_filter_change$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography"),$APP.$cljs$cst$266$id$$,"typographies",$APP.$cljs$cst$2402$handler$$,$on_section_filter_change$$],null)],null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$406$$),$APP.$rumext$v2$adapt$$($term$jscomp$9$$),$APP.$rumext$v2$adapt$$($section$jscomp$29$$)],
function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$main$ui$workspace$sidebar$assets$session_filters_STAR_$$,$APP.$cljs$core$assoc$$,$file_id$jscomp$406$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2513$term$$,$term$jscomp$9$$,$APP.$cljs$cst$1366$section$$,$section$jscomp$29$$],null))});return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_workspace_sidebar_assets__assets-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets__assets-header",
children:[$read_only_QMARK_$jscomp$20$$?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_libs$$,1)&&$APP.$cljs$core$empty_QMARK_$$($components$jscomp$16$$)&&$APP.$cljs$core$not$$($libs$jscomp$1_shared_QMARK_$jscomp$7$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$show_libraries_dialog$jscomp$1$$,"data-testid":"libraries",className:"main_ui_workspace_sidebar_assets__add-library-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.add-library")}):
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$show_libraries_dialog$jscomp$1$$,"data-testid":"libraries",className:"main_ui_workspace_sidebar_assets__libraries-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.manage-library")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets__search-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_search_term_change$$,value:$term$jscomp$9$$,
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.search"),children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_open_menu$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.filter"),className:"main_ui_workspace_sidebar_assets__section-button "+($APP.$cljs$core$truth_$$($menu_open_QMARK_$$)?"main_ui_workspace_sidebar_assets__opened":""),children:$APP.$app$main$ui$icons$filter_icon$$})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,
{selected:$section$jscomp$29$$,width:$props_78528_size$jscomp$148$$,top:158,onClose:$on_menu_close$jscomp$1$$,fixed:!0,minWidth:!0,show:$menu_open_QMARK_$$,selectable:!0,options:$options$jscomp$612$$,left:18}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.sort"),onClick:$toggle_ordering$$,icon:$reverse_sort_QMARK_$jscomp$3$$?"asc-sort":"desc-sort"})]})]}),
(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$workspace$sidebar$assets$common$assets_filters$$),{value:$filters$jscomp$11$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$workspace$sidebar$assets$common$assets_toggle_ordering$$),{value:$toggle_ordering$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$workspace$sidebar$assets$common$assets_toggle_list_style$$),{value:$toggle_list_style$jscomp$2$$,children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$assets_local_library_STAR_$$,{filters:$filters$jscomp$11$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$assets_libraries_STAR_$$,{filters:$filters$jscomp$11$$})]})})})})]})});var $app$main$ui$workspace$sidebar$debug_shape_info$display_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$2044$component_root$$,$APP.$cljs$cst$2045$main_instance$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$1510$x$$,
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$1787$transform_inverse$$],null),$app$main$ui$workspace$sidebar$debug_shape_info$remove_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2046$remote_synced$$,null,$APP.$cljs$cst$725$name$$,null],null),null),$app$main$ui$workspace$sidebar$debug_shape_info$custom_renderer$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$1787$transform_inverse$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1614$shapes$$],[$cljs$cst$5653$matrix_render$$,$cljs$cst$5654$cells_render$$,$cljs$cst$5655$points_render$$,$cljs$cst$5656$shape_link$$,$cljs$cst$5653$matrix_render$$,$cljs$cst$5656$shape_link$$,
$cljs$cst$5656$shape_link$$,$cljs$cst$5657$rect_render$$,$cljs$cst$5658$shape_list$$]);var $app$main$ui$workspace$sidebar$history$workspace_undo$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3563$workspace_undo$$,$APP.$app$main$store$state$$);var $app$main$ui$workspace$sidebar$layers$ref_COLON_highlighted_shapes$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($local$jscomp$30$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$30$$,$APP.$cljs$cst$4295$highlighted$$))},$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$sidebar$layers$ref_COLON_shape_for_rename$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4423$shape_for_rename$$),
$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$sidebar$layers$layers_tree_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78486_root$jscomp$66_shapes__$1$jscomp$32$$){var $is_filtered$jscomp$2$$=$props_78486_root$jscomp$66_shapes__$1$jscomp$32$$.isFiltered,$objects$jscomp$780$$=$props_78486_root$jscomp$66_shapes__$1$jscomp$32$$.objects,$parent_size$jscomp$3$$=$props_78486_root$jscomp$66_shapes__$1$jscomp$32$$.parentSize,$selected$jscomp$170$$=$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$(),
$highlighted$jscomp$3$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_highlighted_shapes$$);$props_78486_root$jscomp$66_shapes__$1$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$780$$,$APP.$app$common$uuid$zero$$);var $rename_id$jscomp$3$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_shape_for_rename$$),$shapes$jscomp$198$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_78486_root$jscomp$66_shapes__$1$jscomp$32$$,
$APP.$cljs$cst$1614$shapes$$);$props_78486_root$jscomp$66_shapes__$1$jscomp$32$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$198$$),$APP.$rumext$v2$adapt$$($objects$jscomp$780$$)],function(){for(var $G__78541_G__78544_counter$jscomp$5$$=0,$G__78542_G__78545_shapes__$1$jscomp$33$$=$APP.$cljs$core$seq$$($shapes$jscomp$198$$),$G__78543_G__78546_result$jscomp$365$$=$APP.$cljs$core$List$EMPTY$$;;){var $obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$=
$APP.$cljs$core$first$$($G__78542_G__78545_shapes__$1$jscomp$33$$);if($APP.$cljs$core$truth_$$($obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$))$obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$780$$,$obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$),$APP.$cljs$core$truth_$$($obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$)?
($obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$.__$__counter=$G__78541_G__78544_counter$jscomp$5$$,$G__78541_G__78544_counter$jscomp$5$$+=1,$G__78542_G__78545_shapes__$1$jscomp$33$$=$APP.$cljs$core$rest$$($G__78542_G__78545_shapes__$1$jscomp$33$$),$G__78543_G__78546_result$jscomp$365$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78543_G__78546_result$jscomp$365$$,$obj$jscomp$220_temp__5823__auto__$jscomp$234_temp__5823__auto____$1$jscomp$16$$)):($G__78541_G__78544_counter$jscomp$5$$+=
1,$G__78542_G__78545_shapes__$1$jscomp$33$$=$APP.$cljs$core$rest$$($G__78542_G__78545_shapes__$1$jscomp$33$$));else return $G__78543_G__78546_result$jscomp$365$$}});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"layer-item",className:"main_ui_workspace_sidebar_layers__element-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$156$$,$obj$jscomp$221$$){$out_arr__44124__auto__$jscomp$156$$.push($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$221$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$frame_wrapper_STAR_$$,{selected:$selected$jscomp$170$$,index:$obj$jscomp$221$$.__$__counter,isSortable:!0,parentSize:$parent_size$jscomp$3$$,highlighted:$highlighted$jscomp$3$$,objects:$objects$jscomp$780$$,isFiltered:$is_filtered$jscomp$2$$,item:$obj$jscomp$221$$,depth:-1,renameId:$rename_id$jscomp$3$$},""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$221$$,$APP.$cljs$cst$266$id$$)??"")):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,
{selected:$selected$jscomp$170$$,index:$obj$jscomp$221$$.__$__counter,isSortable:!0,parentSize:$parent_size$jscomp$3$$,highlighted:$highlighted$jscomp$3$$,objects:$objects$jscomp$780$$,isFiltered:$is_filtered$jscomp$2$$,item:$obj$jscomp$221$$,depth:-1,renameId:$rename_id$jscomp$3$$},""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$221$$,$APP.$cljs$cst$266$id$$)??"")));return $out_arr__44124__auto__$jscomp$156$$},[],$props_78486_root$jscomp$66_shapes__$1$jscomp$32$$)})})}),$app$main$ui$workspace$sidebar$layers$filters_tree_STAR_$$,
$p1__78497_SHARP_$jscomp$inline_8884$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78498_root$jscomp$67$$){var $objects$jscomp$782$$=$props_78498_root$jscomp$67$$.objects,$parent_size$jscomp$4$$=$props_78498_root$jscomp$67$$.parentSize,$selected$jscomp$171$$=$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$(),$highlighted$jscomp$4$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_highlighted_shapes$$);$props_78498_root$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$782$$,
$APP.$app$common$uuid$zero$$);return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_layers__element-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$157$$,$JSCompiler_temp_const$jscomp$1804_p__78501$$){var $JSCompiler_inline_result$jscomp$1806_index$jscomp$484$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1804_p__78501$$,0,null),$id$jscomp$955$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1804_p__78501$$,
1,null);$JSCompiler_temp_const$jscomp$1804_p__78501$$=$out_arr__44124__auto__$jscomp$157$$.push;var $temp__5825__auto__$jscomp$inline_8882$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$782$$,$id$jscomp$955$$);$JSCompiler_inline_result$jscomp$1806_index$jscomp$484$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_8882$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,{selected:$selected$jscomp$171$$,index:$JSCompiler_inline_result$jscomp$1806_index$jscomp$484$$,
isSortable:!1,parentSize:$parent_size$jscomp$4$$,highlighted:$highlighted$jscomp$4$$,objects:$objects$jscomp$782$$,isFiltered:!0,item:$temp__5825__auto__$jscomp$inline_8882$$,depth:-1},$id$jscomp$955$$):null;$JSCompiler_temp_const$jscomp$1804_p__78501$$.call($out_arr__44124__auto__$jscomp$157$$,$JSCompiler_inline_result$jscomp$1806_index$jscomp$484$$);return $out_arr__44124__auto__$jscomp$157$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_78498_root$jscomp$67$$)))})});
$app$main$ui$workspace$sidebar$layers$filters_tree_STAR_$$=$rumext$v2$throttle$$($p1__78497_SHARP_$jscomp$inline_8884$$,50);
var $app$main$ui$workspace$sidebar$layers$ref_COLON_layers_search$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4537$layers_search$$),$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$sidebar$layers$layers_toolbox_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78537_size_parent$$){function $on_render_container$$($element$jscomp$82_observer$jscomp$7$$){var $temp__5825__auto__$jscomp$368$$=$APP.$rumext$v2$ref_val$$($lazy_load_ref$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$368$$)){if($element$jscomp$82_observer$jscomp$7$$!=null&&$APP.$cljs$core$_deref$$($observer_var$$)==null)return $element$jscomp$82_observer$jscomp$7$$=new IntersectionObserver($intersection_callback$$,{root:$element$jscomp$82_observer$jscomp$7$$}),$element$jscomp$82_observer$jscomp$7$$.observe($temp__5825__auto__$jscomp$368$$),$APP.$cljs$core$reset_BANG_$$($observer_var$$,$element$jscomp$82_observer$jscomp$7$$);if($element$jscomp$82_observer$jscomp$7$$==
null&&$APP.$cljs$core$_deref$$($observer_var$$)!=null)return $APP.$cljs$core$_deref$$($observer_var$$).disconnect(),$APP.$cljs$core$reset_BANG_$$($observer_var$$,null)}return null}function $intersection_callback$$($and__5023__auto__$jscomp$inline_8890_entries$jscomp$42$$){$and__5023__auto__$jscomp$inline_8890_entries$jscomp$42$$=$APP.$cljs$core$first$$($and__5023__auto__$jscomp$inline_8890_entries$jscomp$42$$).isIntersecting;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8890_entries$jscomp$42$$)?
$show_more$$!=null:$and__5023__auto__$jscomp$inline_8890_entries$jscomp$42$$)?$show_more$$.$cljs$core$IFn$_invoke$arity$0$?$show_more$$.$cljs$core$IFn$_invoke$arity$0$():$show_more$$():null}$props_78537_size_parent$$=$props_78537_size_parent$$.sizeParent;var $filtered_objects$jscomp$1_page$jscomp$165$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page$$),$page_id$jscomp$423$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filtered_objects$jscomp$1_page$jscomp$165$$,$APP.$cljs$cst$266$id$$),
$focus$jscomp$17$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$objects$jscomp$785$$=$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($filtered_objects$jscomp$1_page$jscomp$165$$),$focus$jscomp$17$$),$title$jscomp$35$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($focus$jscomp$17$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$785$$,
$APP.$cljs$core$first$$($focus$jscomp$17$$)),$APP.$cljs$cst$725$name$$):null,$observer_var$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$lazy_load_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$filter_component_vec__78538$$=$app$main$ui$workspace$sidebar$layers$use_search$$($filtered_objects$jscomp$1_page$jscomp$165$$,$objects$jscomp$785$$);$filtered_objects$jscomp$1_page$jscomp$165$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_component_vec__78538$$,0,null);
var $show_more$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_component_vec__78538$$,1,null);$filter_component_vec__78538$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_component_vec__78538$$,2,null);var $toogle_focus_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",
{id:"layers","data-testid":"layer-tree",className:"main_ui_workspace_sidebar_layers__layers",children:[$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$17$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__tool-window-bar",children:(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$toogle_focus_mode$$,className:"main_ui_workspace_sidebar_layers__focus-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__focus-back-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-left"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__focus-name",children:$APP.$cljs$core$truth_$$($title$jscomp$35$$)?$title$jscomp$35$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__focus-mode-tag-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$badge$badge_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-mode"),
size:$APP.$cljs$cst$3877$small$$,"is-focus":!0})})]})}):$filter_component_vec__78538$$.$cljs$core$IFn$_invoke$arity$0$?$filter_component_vec__78538$$.$cljs$core$IFn$_invoke$arity$0$():$filter_component_vec__78538$$(),$filtered_objects$jscomp$1_page$jscomp$165$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{"data-scroll-container":!0,ref:$on_render_container$$,className:"main_ui_workspace_sidebar_layers__tool-window-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$filters_tree_STAR_$$,
{objects:$filtered_objects$jscomp$1_page$jscomp$165$$,parentSize:$props_78537_size_parent$$},""+($page_id$jscomp$423$$??"")),(0,$APP.$rumext$v2$jsx$$)("div",{ref:$lazy_load_ref$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{onScroll:$app$main$ui$workspace$sidebar$layers$on_scroll$$,"data-scroll-container":!0,style:{display:$filtered_objects$jscomp$1_page$jscomp$165$$!=null?"none":null},className:"main_ui_workspace_sidebar_layers__tool-window-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$,
{objects:$filtered_objects$jscomp$1_page$jscomp$165$$,isFiltered:!0,parentSize:$props_78537_size_parent$$},""+($page_id$jscomp$423$$??""))})]}):(0,$APP.$rumext$v2$jsx$$)("div",{onScroll:$app$main$ui$workspace$sidebar$layers$on_scroll$$,"data-scroll-container":!0,style:{display:$filtered_objects$jscomp$1_page$jscomp$165$$!=null?"none":null},className:"main_ui_workspace_sidebar_layers__tool-window-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$,
{objects:$objects$jscomp$785$$,isFiltered:!1,parentSize:$props_78537_size_parent$$},""+($page_id$jscomp$423$$??""))})]})});var $app$main$ui$workspace$sidebar$options$menus$border_radius$border_radius_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$6_props_78606$$){function $on_radius_r4_change$$($p1__78605_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78605_SHARP_$$,$APP.$cljs$cst$1649$r4$$):$on_single_radius_change$$($p1__78605_SHARP_$$,$APP.$cljs$cst$1649$r4$$)}function $on_radius_r3_change$$($p1__78604_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?
$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78604_SHARP_$$,$APP.$cljs$cst$1648$r3$$):$on_single_radius_change$$($p1__78604_SHARP_$$,$APP.$cljs$cst$1648$r3$$)}function $on_radius_r2_change$$($p1__78603_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78603_SHARP_$$,$APP.$cljs$cst$1647$r2$$):$on_single_radius_change$$($p1__78603_SHARP_$$,$APP.$cljs$cst$1647$r2$$)}function $on_radius_r1_change$$($p1__78602_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?
$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__78602_SHARP_$$,$APP.$cljs$cst$1646$r1$$):$on_single_radius_change$$($p1__78602_SHARP_$$,$APP.$cljs$cst$1646$r1$$)}var $ids$jscomp$279$$=$applied_tokens$jscomp$6_props_78606$$.ids,$class$$jscomp$70$$=$applied_tokens$jscomp$6_props_78606$$.className,$values$jscomp$79$$=$applied_tokens$jscomp$6_props_78606$$.values;$applied_tokens$jscomp$6_props_78606$$=$applied_tokens$jscomp$6_props_78606$$.appliedTokens;var $token_numeric_inputs$$=$app$main$features$use_feature$$("tokens/numeric-input"),
$all_values_equal_QMARK_$$=$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$($values$jscomp$79$$),$all_token_equal_QMARK_$$=$APP.$cljs$core$seq$$($applied_tokens$jscomp$6_props_78606$$)&&$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$($applied_tokens$jscomp$6_props_78606$$),$radius_expanded_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$radius_expanded$$=$APP.$cljs$core$_deref$$($radius_expanded_STAR_$$),$on_detach_token$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$279$$)],function($token_name$jscomp$18$$,$attr$jscomp$66$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$18$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$66$$]),
$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$279$$],null)))}),$on_detach_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$125$$){return $APP.$cljs$core$run_BANG_$$(function($p1__78599_SHARP_$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$125$$,$p1__78599_SHARP_$$):$on_detach_token$jscomp$2$$($token$jscomp$125$$,
$p1__78599_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$],null))}),$on_detach_r1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$126$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$126$$,
$APP.$cljs$cst$1646$r1$$):$on_detach_token$jscomp$2$$($token$jscomp$126$$,$APP.$cljs$cst$1646$r1$$)}),$on_detach_r2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$127$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$127$$,$APP.$cljs$cst$1647$r2$$):$on_detach_token$jscomp$2$$($token$jscomp$127$$,$APP.$cljs$cst$1647$r2$$)}),
$on_detach_r3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$128$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$128$$,$APP.$cljs$cst$1648$r3$$):$on_detach_token$jscomp$2$$($token$jscomp$128$$,$APP.$cljs$cst$1648$r3$$)}),$on_detach_r4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],
function($token$jscomp$129$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$129$$,$APP.$cljs$cst$1649$r4$$):$on_detach_token$jscomp$2$$($token$jscomp$129$$,$APP.$cljs$cst$1649$r4$$)}),$change_radius$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$279$$)],function($update_fn$jscomp$47$$){return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$279$$,
function($shape$jscomp$990$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$990$$)),$APP.$cljs$cst$1646$r1$$)?$update_fn$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?$update_fn$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$990$$):$update_fn$jscomp$47$$($shape$jscomp$990$$):$shape$jscomp$990$$},new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$],null)],null))}),$change_one_radius$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$279$$)],function($update_fn$jscomp$48$$,$attr$jscomp$67$$){return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$279$$,
function($shape$jscomp$991$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$991$$)),$APP.$cljs$cst$1646$r1$$)?$update_fn$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$update_fn$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$991$$):$update_fn$jscomp$48$$($shape$jscomp$991$$):$shape$jscomp$991$$},new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$attr$jscomp$67$$],null)],null))}),$toggle_radius_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($radius_expanded$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($radius_expanded_STAR_$$,$APP.$cljs$core$not$$)}),$on_all_radius_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_radius$$),
$APP.$rumext$v2$adapt$$($ids$jscomp$279$$)],function($value$jscomp$819$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$819$$,function($p1__78600_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){function $G__78607$$($shape$jscomp$992$$){return $APP.$app$common$types$shape$radius$set_radius_to_all_corners$$($shape$jscomp$992$$,$p1__78600_SHARP_$$)}return $change_radius$$.$cljs$core$IFn$_invoke$arity$1$?$change_radius$$.$cljs$core$IFn$_invoke$arity$1$($G__78607$$):
$change_radius$$($G__78607$$)}())},$ids$jscomp$279$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1649$r4$$,null],null),null))}),$on_single_radius_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_one_radius$$),$APP.$rumext$v2$adapt$$($ids$jscomp$279$$)],function($value$jscomp$820$$,$attr$jscomp$68$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$820$$,
function($p1__78601_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){function $G__78608$$($shape$jscomp$993$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($shape$jscomp$993$$,$attr$jscomp$68$$,$p1__78601_SHARP_$$)}return $change_one_radius$$.$cljs$core$IFn$_invoke$arity$2$?$change_one_radius$$.$cljs$core$IFn$_invoke$arity$2$($G__78608$$,$attr$jscomp$68$$):$change_one_radius$$($G__78608$$,$attr$jscomp$68$$)}())},$ids$jscomp$279$$,
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$68$$]))}),$expand_stream$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5682$expand_border_radius$$),$APP.$app$main$store$stream$$)});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($expand_stream$$,function(){return $APP.$cljs$core$reset_BANG_$$($radius_expanded_STAR_$$,
!0)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$279$$)],function(){return $APP.$cljs$core$reset_BANG_$$($radius_expanded_STAR_$$,!1)});return $token_numeric_inputs$$?(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.radius-section"),className:""+($class$$jscomp$70$$??"")+" main_ui_workspace_sidebar_options_menus_border_radius__radius-token",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-first-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_all_radius_change$$,placeholder:$all_values_equal_QMARK_$$&&$all_token_equal_QMARK_$$?"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),attr:$APP.$cljs$cst$1982$border_radius$$,appliedToken:$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($applied_tokens$jscomp$6_props_78606$$))?
null:$all_values_equal_QMARK_$$&&$all_token_equal_QMARK_$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1646$r1$$):$APP.$cljs$cst$1616$multiple$$,value:$all_values_equal_QMARK_$$?$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$)==null?0:$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$):null,onDetach:$on_detach_all$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius"),
nillable:!0,icon:"corner-radius"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:$APP.$cljs$core$truth_$$($radius_expanded$$)?"main_ui_workspace_sidebar_options_menus_border_radius__selected":"",variant:"ghost",tooltipPlacement:"top-left",onClick:$toggle_radius_mode$$,"aria-label":$APP.$cljs$core$truth_$$($radius_expanded$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.hide-all-corners"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.show-single-corners"),
icon:"corner-radius"})]}),$APP.$cljs$core$truth_$$($radius_expanded$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-4-token",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_radius_r1_change$$,className:"main_ui_workspace_sidebar_options_menus_border_radius__dropdown-offset",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1646$r1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$79$$,$APP.$cljs$cst$1646$r1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1982$border_radius$$,
appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1646$r1$$),value:$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$),onDetach:$on_detach_r1$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-left")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,
onChange:$on_radius_r2_change$$,tooltipPlacement:"top-left",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1647$r2$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$79$$,$APP.$cljs$cst$1647$r2$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1982$border_radius$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1647$r2$$),value:$APP.$cljs$cst$1647$r2$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$),onDetach:$on_detach_r2$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-right"),nillable:!0}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_radius_r4_change$$,className:"main_ui_workspace_sidebar_options_menus_border_radius__dropdown-offset",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1649$r4$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$79$$,
$APP.$cljs$cst$1649$r4$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1982$border_radius$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,$APP.$cljs$cst$1649$r4$$),value:$APP.$cljs$cst$1649$r4$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$),onDetach:$on_detach_r4$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-left"),
nillable:!0}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_radius_r3_change$$,tooltipPlacement:"top-left",className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-wrapper",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,
$APP.$cljs$cst$1648$r3$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$79$$,$APP.$cljs$cst$1648$r3$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1982$border_radius$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_78606$$,
$APP.$cljs$cst$1648$r3$$),value:$APP.$cljs$cst$1648$r3$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$),onDetach:$on_detach_r3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-right"),nillable:!0})]}):null]}):(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.radius-section"),className:""+($class$$jscomp$70$$??"")+" main_ui_workspace_sidebar_options_menus_border_radius__radius",
children:[$APP.$cljs$core$not$$($radius_expanded$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius"),className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-1",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"corner-radius",size:"s",className:"main_ui_workspace_sidebar_options_menus_border_radius__icon"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{placeholder:$all_values_equal_QMARK_$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),min:0,nillable:!0,onChange:$on_all_radius_change$$,value:$all_values_equal_QMARK_$$?$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$)==
null?0:$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$):null})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-4",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-left"),
min:0,onChange:$on_radius_r1_change$$,value:$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-right"),min:0,onChange:$on_radius_r2_change$$,value:$APP.$cljs$cst$1647$r2$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-left"),min:0,onChange:$on_radius_r4_change$$,value:$APP.$cljs$cst$1649$r4$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-right"),min:0,onChange:$on_radius_r3_change$$,value:$APP.$cljs$cst$1648$r3$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$79$$)})})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:$APP.$cljs$core$truth_$$($radius_expanded$$)?"main_ui_workspace_sidebar_options_menus_border_radius__selected":
"",variant:"ghost",onClick:$toggle_radius_mode$$,"aria-label":$APP.$cljs$core$truth_$$($radius_expanded$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.hide-all-corners"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.show-single-corners"),icon:"corner-radius"})]})},function($old_props$jscomp$2$$,$new_props$jscomp$3$$){var $old_values$$=$old_props$jscomp$2$$.values,$new_values$$=$new_props$jscomp$3$$.values,$old_applied_tokens$jscomp$1$$=
$old_props$jscomp$2$$.appliedTokens,$new_applied_tokens$jscomp$1$$=$new_props$jscomp$3$$.appliedTokens;return $old_props$jscomp$2$$["class"]===$new_props$jscomp$3$$["class"]&&$old_props$jscomp$2$$.ids===$new_props$jscomp$3$$.ids&&$old_props$jscomp$2$$.shapes===$new_props$jscomp$3$$.shapes&&$old_applied_tokens$jscomp$1$$===$new_applied_tokens$jscomp$1$$&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1646$r1$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,
$APP.$cljs$cst$1646$r1$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1647$r2$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,$APP.$cljs$cst$1647$r2$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1648$r3$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,$APP.$cljs$cst$1648$r3$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1649$r4$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,$APP.$cljs$cst$1649$r4$$)});var $app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1808$proportion_lock$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$3412$ox$$,$APP.$cljs$cst$3413$oy$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1605$selrect$$,
$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$cst$1875$hide_in_viewer$$],null),$app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$874$size$$,null,$APP.$cljs$cst$1676$position$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$measures$rect_options$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$2820$radius$$,null,$APP.$cljs$cst$874$size$$,null,$APP.$cljs$cst$1676$position$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$measures$frame_options$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$5683$show_in_viewer$$,null,$APP.$cljs$cst$1788$rotation$$,null,$cljs$cst$5684$clip_content$$,null,$APP.$cljs$cst$2820$radius$$,null,
$APP.$cljs$cst$874$size$$,null,$cljs$cst$5685$presets$$,null,$APP.$cljs$cst$1676$position$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_map_type$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$139$type$$),$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_mapcat_type_to_options$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$);var $app$main$ui$workspace$sidebar$options$drawing$drawing_options_STAR_$$=$rumext$v2$throttle$$(function($drawing_state$jscomp$2_props_78638$$){$drawing_state$jscomp$2_props_78638$$=$drawing_state$jscomp$2_props_78638$$.drawingState;var $G__78639$$=$APP.$cljs$cst$2197$tool$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$2_props_78638$$);switch($G__78639$$ instanceof $APP.$cljs$core$Keyword$$?$G__78639$$.$fqn$:null){case "frame":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$drawing$frame$options_STAR_$$,
{drawingState:$drawing_state$jscomp$2_props_78638$$});default:return null}},60);var $app$main$ui$workspace$sidebar$options$menus$bool$flatten_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_sidebar_options_menus_bool__flatten-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-flatten"})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$23$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$23$$,$cljs$cst$5687$variants_help_modal$$,$app$main$ui$workspace$sidebar$options$menus$variants_help_modal$variants_help_modal$$)});var $app$main$ui$workspace$sidebar$options$menus$component$ref_COLON_annotations_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4526$workspace_annotations$$,$APP.$app$main$store$state$$);var $app$main$ui$workspace$sidebar$options$menus$grid_cell$cell_props$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$,$APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1678$justify_self$$,$APP.$cljs$cst$1675$area_name$$],null),$app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$=
$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$){$map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$=$APP.$rumext$v2$util$wrap_props$$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$);$map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$=$APP.$cljs$core$__destructure_map$$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$);var $shape$jscomp$1001$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$,
$APP.$cljs$cst$1811$shape$$),$area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$,$APP.$cljs$cst$3525$cell$$),$cells$jscomp$31_column_end_map__78659__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$,$APP.$cljs$cst$4512$cells$$),$state_STAR_$jscomp$15$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3434$open$$,!0],null));$map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$=$APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state_STAR_$jscomp$15$$));var $cells__$1$jscomp$8$$=$APP.$app$main$ui$hooks$use_equal_memo$$($cells$jscomp$31_column_end_map__78659__$1$$),$cell__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$)?$area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$:$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($cells__$1$jscomp$8$$,
$app$main$ui$workspace$sidebar$options$menus$grid_cell$cell_props$$),$multiple_QMARK_$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$));$area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$=$multiple_QMARK_$jscomp$6$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cells__$1$jscomp$8$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)],null);var $cell_ids__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$);$cells$jscomp$31_column_end_map__78659__$1$$=$APP.$cljs$core$__destructure_map$$($cell__$1$jscomp$4$$);var $cell_mode_cell_mode__$1_position$jscomp$195$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1676$position$$);$area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1675$area_name$$);var $align_self$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1677$align_self$$),$justify_self$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1678$justify_self$$),$column$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,
$APP.$cljs$cst$216$column$$),$column_span$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1658$column_span$$),$row$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1656$row$$),$row_span$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$31_column_end_map__78659__$1$$,$APP.$cljs$cst$1657$row_span$$);$cells$jscomp$31_column_end_map__78659__$1$$=
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$798$$=$APP.$app$common$math$finite_QMARK_$$($column$jscomp$42$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$798$$)?$APP.$app$common$math$finite_QMARK_$$($column_span$jscomp$12$$):$and__5023__auto__$jscomp$798$$}())?$column$jscomp$42$$+$column_span$jscomp$12$$:null;var $row_end$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$799$$=$APP.$app$common$math$finite_QMARK_$$($row$jscomp$33$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$799$$)?
$APP.$app$common$math$finite_QMARK_$$($row_span$jscomp$12$$):$and__5023__auto__$jscomp$799$$}())?$row$jscomp$33$$+$row_span$jscomp$12$$:null;$cell_mode_cell_mode__$1_position$jscomp$195$$=$APP.$cljs$core$truth_$$($cell_mode_cell_mode__$1_position$jscomp$195$$)?$cell_mode_cell_mode__$1_position$jscomp$195$$:$APP.$cljs$cst$1672$auto$$;$cell_mode_cell_mode__$1_position$jscomp$195$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$cell_mode_cell_mode__$1_position$jscomp$195$$)&&
($APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)>1||$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)>1)?$APP.$cljs$cst$1673$manual$$:$cell_mode_cell_mode__$1_position$jscomp$195$$;var $valid_area_cells_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cells__$1$jscomp$8$$)],function(){return $app$common$types$shape$layout$valid_area_cells_QMARK_$$($cells__$1$jscomp$8$$)}),$set_alignment$jscomp$1$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($align_self$jscomp$5$$),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$)),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($value$jscomp$838$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$5$$,$value$jscomp$838$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),
$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1677$align_self$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1677$align_self$$,$value$jscomp$838$$],null)))}),$set_justify_self$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($justify_self$jscomp$4$$),
$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$)),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($value$jscomp$839$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($justify_self$jscomp$4$$,$value$jscomp$839$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),$cell_ids__$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1678$justify_self$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1678$justify_self$$,$value$jscomp$839$$],null)))}),$on_grid_coordinates$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($column$jscomp$42$$),
$APP.$rumext$v2$adapt$$($row$jscomp$33$$),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$))],function($field$jscomp$7_property$jscomp$86$$,$type$jscomp$626_value__$2$jscomp$8_vec__78660$$,$value$jscomp$840$$){if($multiple_QMARK_$jscomp$6$$)return null;var $value__$1$jscomp$50$$=$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$840$$),
$column__$1$jscomp$3$$=$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$42$$),$row__$1$jscomp$4$$=$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($row$jscomp$33$$);$type$jscomp$626_value__$2$jscomp$8_vec__78660$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$626_value__$2$jscomp$8_vec__78660$$,$APP.$cljs$cst$216$column$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$86$$,$APP.$cljs$cst$2124$all$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$86$$,$APP.$cljs$cst$1292$start$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,$value__$1$jscomp$50$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$626_value__$2$jscomp$8_vec__78660$$,$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$86$$,
$APP.$cljs$cst$1293$end$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$column_span$$,function(){var $y__5111__auto__$jscomp$140$$=$value__$1$jscomp$50$$-$column__$1$jscomp$3$$;return 1>$y__5111__auto__$jscomp$140$$?1:$y__5111__auto__$jscomp$140$$}()],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$626_value__$2$jscomp$8_vec__78660$$,$APP.$cljs$cst$1656$row$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$86$$,
$APP.$cljs$cst$2124$all$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$86$$,$APP.$cljs$cst$1292$start$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$value__$1$jscomp$50$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$626_value__$2$jscomp$8_vec__78660$$,$APP.$cljs$cst$1656$row$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$86$$,
$APP.$cljs$cst$1293$end$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1657$row_span$$,function(){var $y__5111__auto__$jscomp$141$$=$value__$1$jscomp$50$$-$row__$1$jscomp$4$$;return 1>$y__5111__auto__$jscomp$141$$?1:$y__5111__auto__$jscomp$141$$}()],null):null;$field$jscomp$7_property$jscomp$86$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$626_value__$2$jscomp$8_vec__78660$$,0,null);$type$jscomp$626_value__$2$jscomp$8_vec__78660$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$626_value__$2$jscomp$8_vec__78660$$,1,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$),$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$field$jscomp$7_property$jscomp$86$$,
$type$jscomp$626_value__$2$jscomp$8_vec__78660$$])))}),$on_area_name_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$)),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($event$jscomp$515_value$jscomp$841$$){$event$jscomp$515_value$jscomp$841$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$515_value$jscomp$841$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$515_value$jscomp$841$$,
"")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1675$area_name$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),
$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1675$area_name$$,$event$jscomp$515_value$jscomp$841$$],null)))}),$set_cell_mode$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$)),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($mode$jscomp$50_mode__$1$jscomp$2$$){$mode$jscomp$50_mode__$1$jscomp$2$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$50_mode__$1$jscomp$2$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_cells_mode$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$),$cell_ids__$1$$,$mode$jscomp$50_mode__$1$jscomp$2$$))}),$toggle_edit_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$))],function(){var $JSCompiler_temp_const$jscomp$1643$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$1645_param72191$jscomp$inline_8911$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$);$JSCompiler_inline_result$jscomp$1645_param72191$jscomp$inline_8911$$=$APP.$app$main$data$workspace$edition$start_edition_mode$$($JSCompiler_inline_result$jscomp$1645_param72191$jscomp$inline_8911$$);return $JSCompiler_temp_const$jscomp$1643$$.call($APP.$app$main$store$emit_BANG_$$,
$JSCompiler_inline_result$jscomp$1645_param72191$jscomp$inline_8911$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$grid_layout$editor$clear_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1001$$))]))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-title",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$),onCollapsed:function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$15$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$3434$open$$,$APP.$cljs$core$not$$)},title:"Grid cell"})}),$APP.$cljs$core$truth_$$($map__78658_map__78658__$1_open_QMARK_$jscomp$17_props_78657$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__cell-mode main_ui_workspace_sidebar_options_menus_grid_cell__row",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($cell_mode_cell_mode__$1_position$jscomp$195$$),"on-change":$set_cell_mode$$,name:"cell-mode",
wide:!0,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"auto",id:$APP.$cljs$cst$1672$auto$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"manual",id:$APP.$cljs$cst$1673$manual$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"area",id:$APP.$cljs$cst$1674$area$$,disabled:$APP.$cljs$core$not$$($valid_area_cells_QMARK_$$)})]})}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1674$area$$,
$cell_mode_cell_mode__$1_position$jscomp$195$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:(0,$APP.$rumext$v2$jsx$$)("input",{autoComplete:"off",placeholder:"Area name",defaultValue:$area_name$jscomp$2_cell$jscomp$46_cell_ids$jscomp$2$$,type:"text",id:"grid-area-name",className:"main_ui_workspace_sidebar_options_menus_grid_cell__area-input","aria-label":"grid-area-name",onChange:$on_area_name_change$$},"name-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)??
""))}):null,!$multiple_QMARK_$jscomp$6$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$cell_mode_cell_mode__$1_position$jscomp$195$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",
children:$APP.$app$main$ui$icons$flex_vertical$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:"Column",onClick:function($p1__78651_SHARP_$$){return $app$util$dom$select_target$$($p1__78651_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$2124$all$$,
$APP.$cljs$cst$216$column$$),integer:!0,value:$column$jscomp$42$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{placeholder:"--",title:"Row",onClick:function($p1__78652_SHARP_$$){return $app$util$dom$select_target$$($p1__78652_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$2124$all$$,$APP.$cljs$cst$1656$row$$),integer:!0,value:$row$jscomp$33$$})})]})]}):null,$multiple_QMARK_$jscomp$6$$||!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$cell_mode_cell_mode__$1_position$jscomp$195$$)&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1674$area$$,
$cell_mode_cell_mode__$1_position$jscomp$195$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_vertical$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__78653_SHARP_$$){return $app$util$dom$select_target$$($p1__78653_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$216$column$$),integer:!0,value:$column$jscomp$42$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__78654_SHARP_$$){return $app$util$dom$select_target$$($p1__78654_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$1293$end$$,$APP.$cljs$cst$216$column$$),integer:!0,value:$cells$jscomp$31_column_end_map__78659__$1$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input main_ui_workspace_sidebar_options_menus_grid_cell__double",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__78655_SHARP_$$){return $app$util$dom$select_target$$($p1__78655_SHARP_$$)},
onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$1656$row$$),integer:!0,value:$row$jscomp$33$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__78656_SHARP_$$){return $app$util$dom$select_target$$($p1__78656_SHARP_$$)},
onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$1293$end$$,$APP.$cljs$cst$1656$row$$),integer:!0,value:$row_end$$})})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$,{"is-col?":!1,alignment:$align_self$jscomp$5$$,"set-alignment":$set_alignment$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$,
{"is-col?":!0,alignment:$justify_self$jscomp$4$$,"set-alignment":$set_justify_self$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:(0,$APP.$rumext$v2$jsx$$)("button",{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.edit-grid"),onClick:$toggle_edit_mode$$,className:"main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.edit-grid")})})]}):
null]})});var $app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$1679$layout_flex_dir$$,$APP.$cljs$cst$1683$layout_gap_type$$,$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$cst$1689$layout_justify_content$$,$APP.$cljs$cst$1691$layout_align_content$$,$APP.$cljs$cst$1684$layout_wrap_type$$,$APP.$cljs$cst$1685$layout_padding_type$$,
$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1693$layout_grid_dir$$,$APP.$cljs$cst$1690$layout_justify_items$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1694$layout_grid_rows$$],null),$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$=function $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$($var_args$jscomp$1450$$){switch(arguments.length){case 1:return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);
case 4:return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$1$=function($p$jscomp$257$$){return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$257$$,$APP.$cljs$cst$1093$p1$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$257$$,$APP.$cljs$cst$1091$p2$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$257$$,
$APP.$cljs$cst$1687$p3$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$257$$,$APP.$cljs$cst$1688$p4$$))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$=function($p1_QMARK_$$,$p2_QMARK_$$,$p3_QMARK_$$,$p4_QMARK_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_paddings_selected$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$p1_QMARK_$$,$APP.$cljs$cst$1091$p2$$,$p2_QMARK_$$,$APP.$cljs$cst$1687$p3$$,$p3_QMARK_$$,$APP.$cljs$cst$1688$p4$$,$p4_QMARK_$$],null)))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$lang$maxFixedArity$=4;
var $app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$=function($component__44666__auto__$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($component__44666__auto__$$,function($new_props_78918$$,$old_props_78919$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78918$$.ids,$old_props_78919$$.ids)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78918$$.multiple,$old_props_78919$$.multiple)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78918$$.values,
$old_props_78919$$.values)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78918$$["applied-tokens"],$old_props_78919$$["applied-tokens"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78918$$.shapes,$old_props_78919$$.shapes)})}(function($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$){$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$=$APP.$rumext$v2$util$wrap_props$$($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$);
$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$=$APP.$cljs$core$__destructure_map$$($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$);var $ids$jscomp$286$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$,$APP.$cljs$cst$1723$ids$$),$values$jscomp$82$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$,$APP.$cljs$cst$301$values$$),
$multiple$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$,$APP.$cljs$cst$1616$multiple$$),$applied_tokens$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$,$APP.$cljs$cst$1873$applied_tokens$$),$layout_type$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$);$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$=
$layout_type$$!=null;var $show_dropdown_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_dropdown_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($show_dropdown_STAR_$$),$open_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($layout_type$$)?!0:!1}),$open_QMARK_$jscomp$18$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$7$$),$on_toggle_visibility$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$7$$,
$APP.$cljs$core$not$$)}),$on_add_layout$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$539_type$jscomp$636$$){$event$jscomp$539_type$jscomp$636$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$539_type$jscomp$636$$),"type"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$shape_layout$create_layout$$($event$jscomp$539_type$jscomp$636$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar"],null)));return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$7$$,!0)}),$on_remove_layout$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($ids$jscomp$286$$));
return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$7$$,!1)}),$saved_dir$$=$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$is_column$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$saved_dir$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1662$column_reverse$$,$saved_dir$$),$wrap_type$jscomp$4$$=$APP.$cljs$cst$1684$layout_wrap_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),
$toggle_wrap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wrap_type$jscomp$4$$),$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function(){var $type$jscomp$637$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($wrap_type$jscomp$4$$,$APP.$cljs$cst$896$wrap$$)?$APP.$cljs$cst$1664$nowrap$$:$APP.$cljs$cst$896$wrap$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1684$layout_wrap_type$$,$type$jscomp$637$$],null)))}),$align_items$jscomp$3$$=$APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$set_align_items$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$872$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$872$$)],null)))}),$justify_content$jscomp$4$$=$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$set_justify_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$873$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1689$layout_justify_content$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$873$$)],null)))}),$align_content$jscomp$3$$=$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$on_align_content_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$),$APP.$rumext$v2$adapt$$($align_content$jscomp$3$$)],function($value$jscomp$874$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_content$jscomp$3$$,
$value$jscomp$874$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_align_content$$,$APP.$cljs$cst$1669$stretch$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_align_content$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$874$$)],null)))}),$on_gap_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($multiple_QMARK_$jscomp$7$$,$type$jscomp$638$$,$val$jscomp$212_val__$1$jscomp$17$$){$val$jscomp$212_val__$1$jscomp$17$$=$APP.$app$common$math$finite$$($val$jscomp$212_val__$1$jscomp$17$$,0);
return $multiple_QMARK_$jscomp$7$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,$val$jscomp$212_val__$1$jscomp$17$$,$APP.$cljs$cst$1682$column_gap$$,$val$jscomp$212_val__$1$jscomp$17$$],null)],null))):$type$jscomp$638$$!=
null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$type$jscomp$638$$,$val$jscomp$212_val__$1$jscomp$17$$])],null))):null}),$on_padding_type_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],
function($type$jscomp$639$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_padding_type$$,$type$jscomp$639$$],null)))}),$on_padding_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($type$jscomp$640$$,$prop$jscomp$37$$,
$val$jscomp$213_val__$1$jscomp$18$$){$val$jscomp$213_val__$1$jscomp$18$$=$APP.$app$common$math$finite$$($val$jscomp$213_val__$1$jscomp$18$$,0);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$640$$,$APP.$cljs$cst$1663$simple$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$37$$,$APP.$cljs$cst$1093$p1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$37$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null)))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val$jscomp$213_val__$1$jscomp$18$$,$APP.$cljs$cst$1687$p3$$,$val$jscomp$213_val__$1$jscomp$18$$],
null)],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$640$$,$APP.$cljs$cst$1663$simple$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$37$$,$APP.$cljs$cst$1091$p2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$37$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null],null),null)))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val$jscomp$213_val__$1$jscomp$18$$,$APP.$cljs$cst$1688$p4$$,$val$jscomp$213_val__$1$jscomp$18$$],null)],null))):$prop$jscomp$37$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$prop$jscomp$37$$,$val$jscomp$213_val__$1$jscomp$18$$])],null))):null}),$saved_grid_dir$$=$APP.$cljs$cst$1693$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$on_direction_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout_type$$),$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($dir$jscomp$7$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,
$layout_type$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1679$layout_flex_dir$$,$dir$jscomp$7$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1693$layout_grid_dir$$,$dir$jscomp$7$$],null)))}),$align_items_row$$=$APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$align_items_column$$=$APP.$cljs$cst$1690$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$on_column_align_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$875$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1690$layout_justify_items$$,$value$jscomp$875$$],null)))}),$on_row_align_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$876$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1692$layout_align_items$$,$value$jscomp$876$$],null)))}),$grid_justify_content_row$$=$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$grid_justify_content_column$$=$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),$on_column_justify_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$877$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_align_content$$,$value$jscomp$877$$],null)))}),$on_row_justify_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$878$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1689$layout_justify_content$$,$value$jscomp$878$$],null)))}),$on_toggle_dropdown_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_STAR_$$,$APP.$cljs$core$not$$)}),$on_hide_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_STAR_$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"inspect-layout",
className:"main_ui_workspace_sidebar_options_menus_layout_container__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$18$$),onCollapsed:$on_toggle_visibility$jscomp$1$$,title:"Layout",className:$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$?
"":"main_ui_workspace_sidebar_options_menus_layout_container__title-spacing-layout",children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$802$$=$APP.$cljs$core$not$$($multiple$jscomp$1$$);return $and__5023__auto__$jscomp$802$$?$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$):$and__5023__auto__$jscomp$802$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__title-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-layout"),onClick:$on_toggle_dropdown_visibility$$,icon:"menu"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_dropdown_QMARK_$jscomp$5$$,"on-close":$on_hide_dropdown$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"flex",
onClick:$on_add_layout$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-option",children:"Flex layout"}),(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"grid",onClick:$on_add_layout$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-option",children:"Grid layout"})]})}),$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-layout"),onClick:$on_remove_layout$jscomp$1$$,icon:"remove"}):null]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__title-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-layout"),
onClick:$on_toggle_dropdown_visibility$$,icon:"add"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_dropdown_QMARK_$jscomp$5$$,"on-close":$on_hide_dropdown$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"flex",onClick:$on_add_layout$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-option",
children:"Flex layout"}),(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"grid",onClick:$on_add_layout$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-option",children:"Grid layout"})]})}),$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete"),
onClick:$on_remove_layout$jscomp$1$$,icon:"remove"}):null]})})}),$open_QMARK_$jscomp$18$$&&$has_layout_QMARK_$jscomp$4_map__78922_map__78922__$1_props_78917$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$layout_type$$)?function(){switch($layout_type$$ instanceof $APP.$cljs$core$Keyword$$?$layout_type$$.$fqn$:null){case "flex":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__flex-layout-menu",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__first-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_row$$,{"is-column":$is_column$jscomp$8$$,value:$align_items$jscomp$3$$,"on-change":$set_align_items$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_flex$$,{"on-change":$on_direction_change$$,value:$saved_dir$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$wrap_row$$,
{"wrap-type":$wrap_type$jscomp$4$$,"on-click":$toggle_wrap$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__second-row main_ui_workspace_sidebar_options_menus_layout_container__help-button-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_content_row$$,{"is-column":$is_column$jscomp$8$$,"justify-content":$justify_content$jscomp$4$$,"on-change":$set_justify_content$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center"),onClick:$app$main$ui$workspace$sidebar$options$menus$layout_container$open_flex_help$$,icon:"help"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$896$wrap$$,$wrap_type$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__third-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_content_row$$,
{"is-column":$is_column$jscomp$8$$,value:$align_content$jscomp$3$$,"on-change":$on_align_content_change$$})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__forth-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,{isColumn:$is_column$jscomp$8$$,wrapType:$wrap_type$jscomp$4$$,onChange:$on_gap_change$$,ids:$ids$jscomp$286$$,appliedTokens:$applied_tokens$jscomp$11$$,value:$APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$)}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,{value:$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),type:$APP.$cljs$cst$1685$layout_padding_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),onTypeChange:$on_padding_type_change$$,ids:$ids$jscomp$286$$,appliedTokens:$applied_tokens$jscomp$11$$,onChange:$on_padding_change$$})]})]});case "grid":return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($ids$jscomp$286$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__edit-grid-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_edit_mode$$,{id:$APP.$cljs$core$first$$($ids$jscomp$286$$)}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center"),onClick:$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$,icon:"help"})]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__first-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction-edit",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$,{value:$saved_grid_dir$$,"on-change":$on_direction_change$$})})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,{"is-column":!1,value:$align_items_row$$,"on-change":$on_row_align_change$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,
{"is-column":!0,value:$align_items_column$$,"on-change":$on_column_align_change$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__row main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-align",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!0,value:$grid_justify_content_column$$,"on-change":$on_column_justify_change$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,
{"is-column":!1,value:$grid_justify_content_row$$,"on-change":$on_row_justify_change$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__gap-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,{onChange:$on_gap_change$$,ids:$ids$jscomp$286$$,appliedTokens:$applied_tokens$jscomp$11$$,value:$APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,{value:$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),type:$APP.$cljs$cst$1685$layout_padding_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$82$$),ids:$ids$jscomp$286$$,appliedTokens:$applied_tokens$jscomp$11$$,onTypeChange:$on_padding_type_change$$,
onChange:$on_padding_change$$})})]});default:return null}}():null]})}),$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_layout_edition$$=function($component__44666__auto__$jscomp$1$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($component__44666__auto__$jscomp$1$$,function($new_props_78931$$,$old_props_78932$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78931$$.ids,$old_props_78932$$.ids)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78931$$.values,
$old_props_78932$$.values)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_78931$$["applied-tokens"],$old_props_78932$$["applied-tokens"])})}(function($map__78933_props_78930_values$jscomp$83$$){$map__78933_props_78930_values$jscomp$83$$=$APP.$rumext$v2$util$wrap_props$$($map__78933_props_78930_values$jscomp$83$$);var $applied_tokens$jscomp$12_map__78933__$1$$=$APP.$cljs$core$__destructure_map$$($map__78933_props_78930_values$jscomp$83$$),$ids$jscomp$287$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$12_map__78933__$1$$,
$APP.$cljs$cst$1723$ids$$);$map__78933_props_78930_values$jscomp$83$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$12_map__78933__$1$$,$APP.$cljs$cst$301$values$$);$applied_tokens$jscomp$12_map__78933__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$12_map__78933__$1$$,$APP.$cljs$cst$1873$applied_tokens$$);var $saved_grid_dir$jscomp$1$$=$APP.$cljs$cst$1693$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),
$on_direction_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($dir$jscomp$8$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1693$layout_grid_dir$$,$dir$jscomp$8$$],null)))}),$on_gap_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],
function($multiple_QMARK_$jscomp$8$$,$type$jscomp$641$$,$val$jscomp$214_val__$1$jscomp$19$$){$val$jscomp$214_val__$1$jscomp$19$$=$APP.$app$common$math$finite$$($val$jscomp$214_val__$1$jscomp$19$$,0);return $APP.$cljs$core$truth_$$($multiple_QMARK_$jscomp$8$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,$val$jscomp$214_val__$1$jscomp$19$$,$APP.$cljs$cst$1682$column_gap$$,$val$jscomp$214_val__$1$jscomp$19$$],null)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$type$jscomp$641$$,
$val$jscomp$214_val__$1$jscomp$19$$])],null)))}),$on_padding_type_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($type$jscomp$642$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_padding_type$$,$type$jscomp$642$$],
null)))}),$align_items_row$jscomp$1$$=$APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),$align_items_column$jscomp$1$$=$APP.$cljs$cst$1690$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),$on_column_align_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($value$jscomp$879$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1690$layout_justify_items$$,$value$jscomp$879$$],null)))}),$on_row_align_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($value$jscomp$880$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1692$layout_align_items$$,$value$jscomp$880$$],null)))}),$grid_justify_content_row$jscomp$1$$=$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),$grid_justify_content_column$jscomp$1$$=$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),$on_column_justify_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],
function($value$jscomp$881$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_align_content$$,$value$jscomp$881$$],null)))}),$on_row_justify_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($value$jscomp$882$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1689$layout_justify_content$$,$value$jscomp$882$$],null)))}),$columns_open_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$rows_open_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$column_values$jscomp$1$$=$APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),$rows_values$$=$APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),
$toggle_columns_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($columns_open_QMARK_$$,$APP.$cljs$core$not$$)}),$toggle_rows_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($rows_open_QMARK_$$,$APP.$cljs$core$not$$)}),$add_new_element$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],
function($type$jscomp$644$$,$value$jscomp$883$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$287$$,$type$jscomp$644$$,$value$jscomp$883$$))}),$remove_element$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($event$jscomp$540_index$jscomp$491$$){var $type$jscomp$645$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$540_index$jscomp$491$$),
"type"));$event$jscomp$540_index$jscomp$491$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$540_index$jscomp$491$$),"index"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$($ids$jscomp$287$$,$type$jscomp$645$$,$event$jscomp$540_index$jscomp$491$$))}),$reorder_track$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],
function($type$jscomp$646$$,$from_index$jscomp$12$$,$to_index$jscomp$19$$,$move_content_QMARK_$jscomp$5$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$reorder_layout_track$$($ids$jscomp$287$$,$type$jscomp$646$$,$from_index$jscomp$12$$,$to_index$jscomp$19$$,$move_content_QMARK_$jscomp$5$$))}),$hover_track$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($type$jscomp$647$$,
$index$jscomp$492$$,$hover_QMARK_$jscomp$7$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$hover_layout_track$$($ids$jscomp$287$$,$type$jscomp$647$$,$index$jscomp$492$$,$hover_QMARK_$jscomp$7$$))}),$handle_select_track$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($type$jscomp$648$$,$index$jscomp$493$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$select_track_cells$$($APP.$cljs$core$first$$($ids$jscomp$287$$),
$type$jscomp$648$$,$index$jscomp$493$$))}),$set_column_value$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($type$jscomp$649$$,$index$jscomp$494$$,$value$jscomp$884$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($ids$jscomp$287$$,$type$jscomp$649$$,$index$jscomp$494$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,
$value$jscomp$884$$],null)))}),$set_column_type$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],function($type$jscomp$650$$,$index$jscomp$495$$,$track_type$$){var $value$jscomp$885$$=function(){var $G__78941__$1$$=$track_type$$ instanceof $APP.$cljs$core$Keyword$$?$track_type$$.$fqn$:null;switch($G__78941__$1$$){case "auto":return null;case "flex":return 1;case "percent":return 20;case "fixed":return 100;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78941__$1$$)].join(""));}}();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($ids$jscomp$287$$,$type$jscomp$650$$,$index$jscomp$495$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$885$$,$APP.$cljs$cst$139$type$$,$track_type$$],null)))}),$handle_locate_grid$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$287$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$locate_board$$($APP.$cljs$core$first$$($ids$jscomp$287$$)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-first-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu-title",
children:"GRID LAYOUT"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_options_menus_layout_container__help-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center"),onClick:$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$,icon:"help"}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$())},
className:"main_ui_workspace_sidebar_options_menus_layout_container__exit-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.exit")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__row main_ui_workspace_sidebar_options_menus_layout_container__first-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction-edit",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$,{value:$saved_grid_dir$jscomp$1$$,"on-change":$on_direction_change$jscomp$1$$})})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,{"is-column":!1,value:$align_items_row$jscomp$1$$,"on-change":$on_row_align_change$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,
{"is-column":!0,value:$align_items_column$jscomp$1$$,"on-change":$on_column_align_change$jscomp$1$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__row main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-align",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!0,value:$grid_justify_content_column$jscomp$1$$,"on-change":$on_column_justify_change$jscomp$1$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!1,value:$grid_justify_content_row$jscomp$1$$,"on-change":$on_row_justify_change$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_options_menus_layout_container__locate-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.top-bar.locate.tooltip"),
onClick:$handle_locate_grid$$,icon:"locate"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__gap-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,{onChange:$on_gap_change$jscomp$1$$,ids:$ids$jscomp$287$$,appliedTokens:$applied_tokens$jscomp$12_map__78933__$1$$,value:$APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-row main_ui_workspace_sidebar_options_menus_layout_container__padding-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,{value:$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),type:$APP.$cljs$cst$1685$layout_padding_type$$.$cljs$core$IFn$_invoke$arity$1$($map__78933_props_78930_values$jscomp$83$$),
onTypeChange:$on_padding_type_change$jscomp$1$$,onChange:function($type$jscomp$643$$,$prop$jscomp$38$$,$val$jscomp$215_val__$1$jscomp$20$$){$val$jscomp$215_val__$1$jscomp$20$$=$APP.$app$common$math$finite$$($val$jscomp$215_val__$1$jscomp$20$$,0);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$643$$,$APP.$cljs$cst$1663$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$38$$,$APP.$cljs$cst$1093$p1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val$jscomp$215_val__$1$jscomp$20$$,$APP.$cljs$cst$1687$p3$$,$val$jscomp$215_val__$1$jscomp$20$$],null)],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$643$$,$APP.$cljs$cst$1663$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$38$$,$APP.$cljs$cst$1091$p2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val$jscomp$215_val__$1$jscomp$20$$,$APP.$cljs$cst$1688$p4$$,$val$jscomp$215_val__$1$jscomp$20$$],null)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$287$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$prop$jscomp$38$$,$val$jscomp$215_val__$1$jscomp$20$$])],null)))}})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$,{"is-column":!0,"hover-track":$hover_track$jscomp$2$$,"expanded?":$APP.$cljs$core$_deref$$($columns_open_QMARK_$$),"set-column-value":$set_column_value$jscomp$2$$,
toggle:$toggle_columns_open$$,"add-new-element":$add_new_element$jscomp$1$$,"reorder-track":$reorder_track$jscomp$2$$,"remove-element":$remove_element$jscomp$2$$,"set-column-type":$set_column_type$jscomp$2$$,"on-select-track":$handle_select_track$jscomp$1$$,"column-values":$column_values$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$,{"is-column":!1,"hover-track":$hover_track$jscomp$2$$,"expanded?":$APP.$cljs$core$_deref$$($rows_open_QMARK_$$),
"set-column-value":$set_column_value$jscomp$2$$,toggle:$toggle_rows_open$$,"add-new-element":$add_new_element$jscomp$1$$,"reorder-track":$reorder_track$jscomp$2$$,"remove-element":$remove_element$jscomp$2$$,"set-column-type":$set_column_type$jscomp$2$$,"on-select-track":$handle_select_track$jscomp$1$$,"column-values":$rows_values$$})]})]})});var $app$main$ui$workspace$sidebar$options$page$ref_COLON_background_color$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2058$background$$),$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_color$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2059$pixel_grid_color$$),$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_opacity$$=
$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2060$pixel_grid_opacity$$),$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$page$options_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $background$jscomp$12$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$page$ref_COLON_background_color$$),$grid_color$jscomp$2$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_color$$),
$grid_alpha$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_opacity$$),$on_change$jscomp$68$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78844_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$change_canvas_color$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$p1__78844_SHARP_$$))}),$on_open$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($APP.$cljs$cst$873$options$$))}),
$on_close$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($APP.$cljs$cst$873$options$$))}),$on_grid_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78845_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$change_pixel_grid_color$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__78845_SHARP_$$))}),
$color$jscomp$163$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($background$jscomp$12$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($background$jscomp$12$$,"#E8E9EA"),$APP.$cljs$cst$1734$opacity$$,1],null)}),$grid_color__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_color$jscomp$2$$),$APP.$rumext$v2$adapt$$($grid_alpha$$)],
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($grid_color$jscomp$2$$,"#0070E4"),$APP.$cljs$cst$1734$opacity$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($grid_alpha$$,.2)],null)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_page__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.canvas-background"),className:"main_ui_workspace_sidebar_options_page__title-spacing-page"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,
{origin:$APP.$cljs$cst$3083$canvas$$,onClose:$on_close$jscomp$32$$,onChange:$on_change$jscomp$68$$,disableOpacity:!0,disableGradient:!0,disableImage:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.canvas-background"),color:$color$jscomp$163$$,onOpen:$on_open$jscomp$3$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-title",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.pixel grid-color"),className:"main_ui_workspace_sidebar_options_page__title-spacing-page"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{disableGradient:!0,
disableImage:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.pixel grid-color"),color:$grid_color__$1$$,onChange:$on_grid_change$$,origin:$APP.$cljs$cst$3071$pixel_grid$$,onOpen:$on_open$jscomp$3$$,onClose:$on_close$jscomp$32$$})})]})]})});var $app$main$ui$workspace$sidebar$options$menus$blur$blur_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$],null);var $app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1645$fixed_scroll$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$],null);var $app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1870$exports$$],null),$app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$21_props_78936$$){var $shapes$jscomp$209$$=$open_QMARK_$jscomp$21_props_78936$$.shapes,$file_id$jscomp$409$$=$open_QMARK_$jscomp$21_props_78936$$.fileId,
$ids$jscomp$290$$=$open_QMARK_$jscomp$21_props_78936$$.ids,$type$jscomp$652$$=$open_QMARK_$jscomp$21_props_78936$$.type,$page_id$jscomp$424$$=$open_QMARK_$jscomp$21_props_78936$$.pageId,$exports__$1$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_QMARK_$jscomp$21_props_78936$$.values,$APP.$cljs$cst$1870$exports$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$open_STAR_$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$21_props_78936$$=
$APP.$cljs$core$_deref$$($open_STAR_$jscomp$8$$);var $in_progress_QMARK_$jscomp$2_state$jscomp$1188$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$export$0$$);$in_progress_QMARK_$jscomp$2_state$jscomp$1188$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$2_state$jscomp$1188$$,$APP.$cljs$cst$4762$in_progress$$);var $has_exports_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$exports__$1$jscomp$13$$)||$APP.$cljs$core$seq$$($exports__$1$jscomp$13$$)!=
null,$toggle_content$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$8$$,$APP.$cljs$core$not$$)}),$shapes_with_exports$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$209$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,
$APP.$cljs$cst$1870$exports$$),$shapes$jscomp$209$$)}),$sname$jscomp$3$$=$APP.$cljs$core$seqable_QMARK_$$($exports__$1$jscomp$13$$)?function(){var $sname$jscomp$4$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes_with_exports$$)),$suffix$jscomp$30$$=$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($exports__$1$jscomp$13$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($exports__$1$jscomp$13$$))&&
$suffix$jscomp$30$$!=null?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sname$jscomp$4$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($suffix$jscomp$30$$)].join(""):$sname$jscomp$4$$}():null,$scale_enabled_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__78939_export$$jscomp$11$$){$G__78939_export$$jscomp$11$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78939_export$$jscomp$11$$);var $fexpr__78938$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1534$png$$,null,$APP.$cljs$cst$1536$webp$$,null,$APP.$cljs$cst$1535$jpeg$$,null],null),null);return $fexpr__78938$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__78938$$.$cljs$core$IFn$_invoke$arity$1$($G__78939_export$$jscomp$11$$):$fexpr__78938$$($G__78939_export$$jscomp$11$$)}),$on_download$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$424$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$409$$),$APP.$rumext$v2$adapt$$($exports__$1$jscomp$13$$)],function($event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$type$jscomp$652$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($shapes_with_exports$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes_with_exports$$))))){var $shape$jscomp$1007$$=$APP.$cljs$core$first$$($shapes_with_exports$$);$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$));var $suffix$jscomp$31$$=$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$),
$sname__$1$$=function(){var $G__78940$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$);return $suffix$jscomp$31$$!=null?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78940$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($suffix$jscomp$31$$)].join(""):$G__78940$$}(),$defaults$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$424$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$409$$,$APP.$cljs$cst$725$name$$,
$sname__$1$$,$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes_with_exports$$))],null);$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$,$defaults$jscomp$5$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$exports$assets$request_simple_export$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2177$export$$,$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$exports$assets$export_shapes_event$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$],null),"workspace:sidebar")]))}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$exports$assets$show_workspace_export_dialog$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1921$selected$$,$APP.$cljs$core$reverse$$($ids$jscomp$290$$),$APP.$cljs$cst$1786$origin$$,"workspace:sidebar"],null)))}$defaults$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$424$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$409$$,$APP.$cljs$cst$725$name$$,$sname$jscomp$3$$,$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$core$first$$($ids$jscomp$290$$)],null);$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78935_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__78935_SHARP_$$,$defaults$jscomp$5$$]))},$exports__$1$jscomp$13$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$exports$assets$request_export$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1870$exports$$,$event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$exports$assets$export_shapes_event$$($event$jscomp$542_export$$jscomp$12_exports__$2$jscomp$3_full_export$$,"workspace:sidebar")]))}),$add_export$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function(){var $xspec$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1534$png$$,$APP.$cljs$cst$1371$suffix$$,
"",$APP.$cljs$cst$1902$scale$$,1],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$290$$,function($shape$jscomp$1008$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1008$$,$APP.$cljs$cst$1870$exports$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$xspec$jscomp$1$$],null),$APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1008$$)))}))}),$delete_export$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function($event$jscomp$543$$){function $remove_fill_by_index$jscomp$2$$($values__$1$jscomp$6$$,$index$jscomp$496$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filterv$$(function($p__78942$$){var $idx$jscomp$125$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78942$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78942$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$125$$,$index$jscomp$496$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($values__$1$jscomp$6$$)))}var $value$jscomp$890$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$543$$),
"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$290$$,function($shape$jscomp$1009$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1009$$,$APP.$cljs$cst$1870$exports$$,$remove_fill_by_index$jscomp$2$$,$value$jscomp$890$$)}))}),$on_scale_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],
function($index$jscomp$497$$,$event$jscomp$544$$){var $scale$jscomp$33$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$544$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$290$$,function($shape$jscomp$1010$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1010$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1870$exports$$,$index$jscomp$497$$,$APP.$cljs$cst$1902$scale$$],null),$scale$jscomp$33$$)}))}),$on_suffix_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function($event$jscomp$545$$){var $value$jscomp$891$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$545$$),$index$jscomp$498$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$545$$),
"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$290$$,function($shape$jscomp$1011$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1011$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1870$exports$$,$index$jscomp$498$$,$APP.$cljs$cst$1371$suffix$$],null),$value$jscomp$891$$)}))}),$on_type_change$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function($index$jscomp$499$$,$event$jscomp$546$$){var $type__$1$jscomp$16$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$546$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$290$$,function($shape$jscomp$1012$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1012$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1870$exports$$,$index$jscomp$499$$,$APP.$cljs$cst$139$type$$],null),$type__$1$jscomp$16$$)}))}),$on_remove_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$290$$,
function($shape$jscomp$1013$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1013$$,$APP.$cljs$cst$1870$exports$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}))}),$manage_key_down$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$547$$){var $esc_QMARK_$jscomp$7$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$547$$);return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$7$$)?$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$547$$)):
null}),$size_options$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"0.5",$APP.$cljs$cst$2287$label$$,"0.5x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"0.75",$APP.$cljs$cst$2287$label$$,"0.75x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"1",$APP.$cljs$cst$2287$label$$,"1x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,"1.5",$APP.$cljs$cst$2287$label$$,"1.5x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"2",$APP.$cljs$cst$2287$label$$,"2x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"4",$APP.$cljs$cst$2287$label$$,"4x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"6",$APP.$cljs$cst$2287$label$$,"6x"],null)],null),$format_options$jscomp$1$$=new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"png",$APP.$cljs$cst$2287$label$$,"PNG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"jpeg",$APP.$cljs$cst$2287$label$$,"JPG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"webp",$APP.$cljs$cst$2287$label$$,"WEBP"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"svg",
$APP.$cljs$cst$2287$label$$,"SVG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"pdf",$APP.$cljs$cst$2287$label$$,"PDF"],null)],null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_exports_QMARK_$$,
collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$21_props_78936$$),onCollapsed:$toggle_content$jscomp$7$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($ids$jscomp$290$$)>1?"workspace.options.export-multiple":"workspace.options.export"),className:$has_exports_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_exports__title-spacing-export",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.add-export"),onClick:$add_export$jscomp$1$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$21_props_78936$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-set-content",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$exports__$1$jscomp$13$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__multiple-exports",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__actions",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.remove-export"),
onClick:$on_remove_all$$,icon:"remove"})})]}):$APP.$cljs$core$seq$$($exports__$1$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$170$$,$export$$jscomp$13_p__78947$$){var $index$jscomp$500$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$13_p__78947$$,0,null);$export$$jscomp$13_p__78947$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$13_p__78947$$,
1,null);$out_arr__44124__auto__$jscomp$170$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-group",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__format-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__78947$$)),
options:$format_options$jscomp$1$$,"dropdown-class":"main_ui_workspace_sidebar_options_menus_exports__dropdown-upwards","on-change":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_type_change$jscomp$2$$,$index$jscomp$500$$)})}),$APP.$cljs$core$truth_$$($scale_enabled_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$scale_enabled_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__78947$$):$scale_enabled_QMARK_$jscomp$1$$($export$$jscomp$13_p__78947$$))?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_exports__size-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__78947$$)),options:$size_options$jscomp$2$$,"dropdown-class":"main_ui_workspace_sidebar_options_menus_exports__dropdown-upwards","on-change":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_scale_change$jscomp$1$$,
$index$jscomp$500$$)})}):null,(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"suffix-export-input",className:"main_ui_workspace_sidebar_options_menus_exports__suffix-input",children:(0,$APP.$rumext$v2$jsx$$)("input",{id:"suffix-export-input",type:"text",value:$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__78947$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.suffix"),"data-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$500$$),
onChange:$on_suffix_change$jscomp$1$$,onKeyDown:$manage_key_down$jscomp$2$$,className:"main_ui_workspace_sidebar_options_menus_exports__type-input"})})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.remove-export"),onClick:$delete_export$jscomp$1$$,"data-value":$index$jscomp$500$$,icon:"remove"})]},$index$jscomp$500$$));return $out_arr__44124__auto__$jscomp$170$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($exports__$1$jscomp$13$$))}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$exports__$1$jscomp$13$$)||$APP.$cljs$core$seq$$($exports__$1$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$2_state$jscomp$1188$$)?null:$on_download$jscomp$2$$,disabled:$in_progress_QMARK_$jscomp$2_state$jscomp$1188$$,className:"main_ui_workspace_sidebar_options_menus_exports__export-btn "+
($APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$2_state$jscomp$1188$$)?"main_ui_workspace_sidebar_options_menus_exports__btn-disabled":""),children:$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$2_state$jscomp$1188$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.export-object",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($shapes_with_exports$$))]))}):
null]}):null]})},function($old_props$jscomp$3$$,$new_props$jscomp$4$$){return $old_props$jscomp$3$$.ids===$new_props$jscomp$4$$.ids&&$old_props$jscomp$3$$.type===$new_props$jscomp$4$$.type&&$old_props$jscomp$3$$.pageId===$new_props$jscomp$4$$.pageId&&$old_props$jscomp$3$$.fileId===$new_props$jscomp$4$$.fileId&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_props$jscomp$3$$.values,$new_props$jscomp$4$$.values)});var $app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1874$hide_fill_on_export$$,null,$APP.$cljs$cst$1634$fills$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$fill$xf_COLON_process_fills$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$501$$,$item$jscomp$132$$){var $color$jscomp$164$$=$APP.$app$common$types$fills$fill__GT_color$$($item$jscomp$132$$);
return $APP.$cljs$core$with_meta$$($item$jscomp$132$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,$index$jscomp$501$$,$APP.$cljs$cst$1298$color$$,$color$jscomp$164$$],null))}),$app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$){var $ids$jscomp$291$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$.ids,$type$jscomp$653$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$.type,
$fills__$1$jscomp$7_values$jscomp$87$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$.values;$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$.appliedTokens;var $fills$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fills__$1$jscomp$7_values$jscomp$87$$,$APP.$cljs$cst$1634$fills$$),$hide_on_export$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($fills__$1$jscomp$7_values$jscomp$87$$,$APP.$cljs$cst$1874$hide_fill_on_export$$,
!1),$fill_token_applied$$=$APP.$cljs$cst$1403$fill$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$),$label$jscomp$43_render_wasm_QMARK_$jscomp$2$$=$app$main$features$use_feature$$("render-wasm/v1"),$multiple_QMARK_$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$fills$jscomp$31$$);$fills__$1$jscomp$7_values$jscomp$87$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fills$jscomp$31$$)],
function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$fills$jscomp$31$$)?$fills$jscomp$31$$:$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$fill$xf_COLON_process_fills$$,$fills$jscomp$31$$))});$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$=$multiple_QMARK_$jscomp$9$$||$fills__$1$jscomp$7_values$jscomp$87$$!=null;var $empty_fills_QMARK_$$=
!$multiple_QMARK_$jscomp$9$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$count$$($fills__$1$jscomp$7_values$jscomp$87$$)),$open_STAR_$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$),$open_QMARK_$jscomp$22$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$9$$),$toggle_content$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$9$$,
$APP.$cljs$core$not$$)}),$open_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$9$$,!0)}),$close_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$9$$,!1)}),$checkbox_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$can_add_fills_QMARK_$$=$label$jscomp$43_render_wasm_QMARK_$jscomp$2$$?!$multiple_QMARK_$jscomp$9$$&&$APP.$cljs$core$count$$($fills__$1$jscomp$7_values$jscomp$87$$)<
8:!$multiple_QMARK_$jscomp$9$$;$label$jscomp$43_render_wasm_QMARK_$jscomp$2$$=function(){switch($type$jscomp$653$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$653$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-fill");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.group-fill");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill")}}();
var $on_add$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$),$APP.$rumext$v2$adapt$$($multiple_QMARK_$jscomp$9$$),$APP.$rumext$v2$adapt$$($empty_fills_QMARK_$$)],function(){if($can_add_fills_QMARK_$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$291$$));var $JSCompiler_temp_const$jscomp$1678$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;
var $JSCompiler_inline_result$jscomp$1680$$=$app$main$data$workspace$colors$add_fill$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$291$$);$JSCompiler_temp_const$jscomp$1678$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1680$$);return $multiple_QMARK_$jscomp$9$$||$empty_fills_QMARK_$$?$open_content$$.$cljs$core$IFn$_invoke$arity$0$?$open_content$$.$cljs$core$IFn$_invoke$arity$0$():$open_content$$():null}return null}),$on_change$jscomp$69$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],
function($color$jscomp$165_color__$1$jscomp$33$$,$index$jscomp$502$$){$color$jscomp$165_color__$1$jscomp$33$$=$APP.$cljs$core$select_keys$$($color$jscomp$165_color__$1$jscomp$33$$,$APP.$app$common$types$color$color_attrs$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$291$$,$color$jscomp$165_color__$1$jscomp$33$$,$index$jscomp$502$$))}),$on_reorder$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],
function($from_pos$jscomp$15$$,$to_space_between_pos$jscomp$15$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$reorder_fills$$($ids$jscomp$291$$,$from_pos$jscomp$15$$,$to_space_between_pos$jscomp$15$$))}),$on_remove$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$),$APP.$rumext$v2$adapt$$($multiple_QMARK_$jscomp$9$$),$APP.$rumext$v2$adapt$$($empty_fills_QMARK_$$)],function($index$jscomp$503$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_fill$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$291$$,
$index$jscomp$503$$));return $multiple_QMARK_$jscomp$9$$||$empty_fills_QMARK_$$?$close_content$$.$cljs$core$IFn$_invoke$arity$0$?$close_content$$.$cljs$core$IFn$_invoke$arity$0$():$close_content$$():null}),$on_remove_all$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$remove_all_fills$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$291$$,
null))}),$on_detach$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function($index$jscomp$504$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$detach_fill$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$291$$,$index$jscomp$504$$))}),$on_change_show_on_export$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function($event$jscomp$548$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_hide_fill_on_export$$($ids$jscomp$291$$,
$APP.$cljs$core$not$$($APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$548$$)))))}),$disable_drag_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$disable_drag_QMARK_$$=$APP.$cljs$core$_deref$$($disable_drag_STAR_$$),$on_focus$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($disable_drag_STAR_$$,!0)}),$on_blur$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($disable_drag_STAR_$$,
!1)}),$on_token_change$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function($_$jscomp$3026$$,$token$jscomp$132$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$token$jscomp$132$$,$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$291$$,$APP.$cljs$cst$4653$expand_with_children$$,!0],null)))}),$on_detach_token$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function($token_name$jscomp$21$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$21$$,$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$291$$],null)))});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hide_on_export$$)],function(){var $temp__5825__auto__$jscomp$379$$=$APP.$rumext$v2$ref_val$$($checkbox_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$379$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hide_on_export$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$379$$,"indeterminate",!0):$APP.$app$util$dom$remove_attribute_BANG_$$($temp__5825__auto__$jscomp$379$$,"indeterminate"):null});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill.section"),className:"main_ui_workspace_sidebar_options_menus_fill__fill-section",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$22$$),onCollapsed:$toggle_content$jscomp$8$$,title:$label$jscomp$43_render_wasm_QMARK_$jscomp$2$$,className:$applied_tokens$jscomp$13_has_fills_QMARK__props_78951$$?"":"main_ui_workspace_sidebar_options_menus_fill__fill-title-bar",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$fills__$1$jscomp$7_values$jscomp$87$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill.add-fill"),onClick:$on_add$jscomp$1$$,"data-testid":"add-fill",disabled:!$can_add_fills_QMARK_$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$22$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-content",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$fills__$1$jscomp$7_values$jscomp$87$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$fill_token_applied$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-multiple-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill.remove-fill"),onClick:$on_remove_all$jscomp$1$$,icon:"remove"})]}):$fills__$1$jscomp$7_values$jscomp$87$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$171$$,
$JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$){var $JSCompiler_temp_const$jscomp$1828$$=$out_arr__44124__auto__$jscomp$171$$.push,$color$jscomp$inline_8933_mdata$jscomp$inline_8931$$=$APP.$cljs$core$meta$$($JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$);$JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$inline_8933_mdata$jscomp$inline_8931$$,
$APP.$cljs$cst$1795$index$$);$color$jscomp$inline_8933_mdata$jscomp$inline_8931$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$inline_8933_mdata$jscomp$inline_8931$$,$APP.$cljs$cst$1298$color$$);$JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{onRemove:$on_remove$jscomp$2$$,origin:$APP.$cljs$cst$1403$fill$$,index:$JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$,
onChange:$on_change$jscomp$69$$,selectOnFocus:$APP.$cljs$core$not$$($disable_drag_QMARK_$$),onReorder:$on_reorder$jscomp$3$$,onTokenChange:$on_token_change$jscomp$5$$,disableDrag:$disable_drag_QMARK_$$,onDetachToken:$on_detach_token$jscomp$7$$,appliedToken:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$,0)?$fill_token_applied$$:null,onFocus:$on_focus$jscomp$13$$,onDetach:$on_detach$jscomp$4$$,onBlur:$on_blur$jscomp$20$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill"),color:$color$jscomp$inline_8933_mdata$jscomp$inline_8931$$},$JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$);$JSCompiler_temp_const$jscomp$1828$$.call($out_arr__44124__auto__$jscomp$171$$,$JSCompiler_inline_result$jscomp$1830_index$jscomp$inline_8932_value$jscomp$893$$);return $out_arr__44124__auto__$jscomp$171$$},[],$fills__$1$jscomp$7_values$jscomp$87$$)}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$653$$,
$APP.$cljs$cst$1606$frame$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$653$$,$APP.$cljs$cst$1616$multiple$$)&&$hide_on_export$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-checkbox",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"show-fill-on-export",className:$APP.$cljs$core$not$$($hide_on_export$$)?"checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_fill__check-mark "+
($APP.$cljs$core$not$$($hide_on_export$$)?"main_ui_workspace_sidebar_options_menus_fill__checked":""),children:$APP.$cljs$core$not$$($hide_on_export$$)?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.show-fill-on-export"),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"show-fill-on-export",ref:$checkbox_ref$$,checked:$APP.$cljs$core$not$$($hide_on_export$$),onChange:$on_change_show_on_export$$})]})}):null]}):null]})},
function($n_props_o_fills$$,$n_fills_o_props$$){var $and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$=$n_props_o_fills$$.ids===$n_fills_o_props$$.ids;if($and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$){if($and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$=$n_props_o_fills$$.appliedTokens===$n_fills_o_props$$.appliedTokens){$and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$=$n_fills_o_props$$.values;
var $n_hide_n_vals$$=$n_props_o_fills$$.values;$n_props_o_fills$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$,$APP.$cljs$cst$1634$fills$$);$n_fills_o_props$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_hide_n_vals$$,$APP.$cljs$cst$1634$fills$$);$and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$,
$APP.$cljs$cst$1874$hide_fill_on_export$$);$n_hide_n_vals$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_hide_n_vals$$,$APP.$cljs$cst$1874$hide_fill_on_export$$);return $and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$===$n_hide_n_vals$$&&$n_props_o_fills$$===$n_fills_o_props$$}return $and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$}return $and__5023__auto__$jscomp$804_and__5023__auto____$1$jscomp$137_o_hide_o_vals$$});var $app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1867$blend_mode$$,$APP.$cljs$cst$1623$blocked$$,$APP.$cljs$cst$1620$hidden$$],null),$app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$14_props_78975$$){var $ids$jscomp$293$$=$applied_tokens$jscomp$14_props_78975$$.ids,
$values$jscomp$88$$=$applied_tokens$jscomp$14_props_78975$$.values;$applied_tokens$jscomp$14_props_78975$$=$applied_tokens$jscomp$14_props_78975$$.appliedTokens;var $token_numeric_inputs$jscomp$5$$=$app$main$features$use_feature$$("tokens/numeric-input"),$hidden_QMARK_$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$88$$,$APP.$cljs$cst$1620$hidden$$),$blocked_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$88$$,$APP.$cljs$cst$1623$blocked$$),
$opacity$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$88$$,$APP.$cljs$cst$1734$opacity$$),$on_detach_token$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($token_name$jscomp$22$$,$attr$jscomp$80$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,
$token_name$jscomp$22$$,$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$80$$]),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$293$$],null)))}),$current_blend_mode$$=function(){var $or__5025__auto__$jscomp$1195$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$88$$,$APP.$cljs$cst$1867$blend_mode$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1195$$)?$or__5025__auto__$jscomp$1195$$:$APP.$cljs$cst$2023$normal$$}(),$current_opacity$$=
$app$main$ui$workspace$sidebar$options$menus$layer$opacity__GT_string$$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$88$$)),$state_STAR_$jscomp$18$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5703$selected_blend_mode$$,$current_blend_mode$$,$cljs$cst$5704$option_highlighted_QMARK_$$,!1,$cljs$cst$5705$preview_complete_QMARK_$$,!0],null)}),$handle_change_blend_mode_state$jscomp$1189$$=
$APP.$cljs$core$_deref$$($state_STAR_$jscomp$18$$),$selected_blend_mode$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_change_blend_mode_state$jscomp$1189$$,$cljs$cst$5703$selected_blend_mode$$),$option_highlighted_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_change_blend_mode_state$jscomp$1189$$,$cljs$cst$5704$option_highlighted_QMARK_$$),$preview_complete_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_change_blend_mode_state$jscomp$1189$$,
$cljs$cst$5705$preview_complete_QMARK_$$),$wasm_renderer_enabled_QMARK_$$=$app$main$features$use_feature$$("render-wasm/v1");$handle_change_blend_mode_state$jscomp$1189$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($value$jscomp$895$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5703$selected_blend_mode$$,$value$jscomp$895$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5704$option_highlighted_QMARK_$$,
!1,$cljs$cst$5705$preview_complete_QMARK_$$,!0]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unset_preview_blend_mode$$($ids$jscomp$293$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$293$$,$APP.$cljs$cst$1867$blend_mode$$,$value$jscomp$895$$)});var $handle_blend_mode_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$),$APP.$rumext$v2$adapt$$($current_blend_mode$$)],
function($value$jscomp$896$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5705$preview_complete_QMARK_$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5704$option_highlighted_QMARK_$$,!0]));if($wasm_renderer_enabled_QMARK_$$)for(var $c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$=$APP.$cljs$core$seq$$($ids$jscomp$293$$),$G__79001_chunk__78978_78987_seq__78977_78997__$1$$=
null,$G__79002_count__78979_78988$$=0,$G__79000_i__78980_78989$$=0;;)if($G__79000_i__78980_78989$$<$G__79002_count__78979_78988$$){var $id_78990$$=$G__79001_chunk__78978_78987_seq__78977_78997__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__79000_i__78980_78989$$);$APP.$app$render_wasm$api$use_shape$$($id_78990$$);$APP.$app$render_wasm$api$set_shape_blend_mode$$($value$jscomp$896$$);$APP.$app$render_wasm$api$request_render$$("preview-blend-mode");$G__79000_i__78980_78989$$+=1}else if($c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$=
$APP.$cljs$core$seq$$($c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$))$G__79001_chunk__78978_78987_seq__78977_78997__$1$$=$c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__79001_chunk__78978_78987_seq__78977_78997__$1$$)?($c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$=$APP.$cljs$core$_chunked_first$$($G__79001_chunk__78978_78987_seq__78977_78997__$1$$),$G__79000_i__78980_78989$$=
$APP.$cljs$core$_chunked_rest$$($G__79001_chunk__78978_78987_seq__78977_78997__$1$$),$G__79001_chunk__78978_78987_seq__78977_78997__$1$$=$c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$,$G__79002_count__78979_78988$$=$APP.$cljs$core$count$$($c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$),$c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$=$G__79000_i__78980_78989$$):($c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$=
$APP.$cljs$core$first$$($G__79001_chunk__78978_78987_seq__78977_78997__$1$$),$APP.$app$render_wasm$api$use_shape$$($c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$),$APP.$app$render_wasm$api$set_shape_blend_mode$$($value$jscomp$896$$),$APP.$app$render_wasm$api$request_render$$("preview-blend-mode"),$c__5548__auto___78998_id_79005_seq__78977_78986_temp__5825__auto___78996$$=$APP.$cljs$core$next$$($G__79001_chunk__78978_78987_seq__78977_78997__$1$$),$G__79001_chunk__78978_78987_seq__78977_78997__$1$$=
null,$G__79002_count__78979_78988$$=0),$G__79000_i__78980_78989$$=0;else break;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$293$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_preview_blend_mode$$($ids$jscomp$293$$,$value$jscomp$896$$))}),$handle_blend_mode_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5705$preview_complete_QMARK_$$,!0);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unset_preview_blend_mode$$($ids$jscomp$293$$))}),$handle_opacity_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($value$jscomp$897$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$293$$));
return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$293$$,$APP.$cljs$cst$1734$opacity$$,$value$jscomp$897$$/100)}),$on_opacity_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_opacity_change$$)],function($value$jscomp$898$$){return typeof $value$jscomp$898$$==="string"||typeof $value$jscomp$898$$==="number"?$handle_opacity_change$$.$cljs$core$IFn$_invoke$arity$1$?$handle_opacity_change$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$898$$):
$handle_opacity_change$$($value$jscomp$898$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$898$$),$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1734$opacity$$,null],null),null),$APP.$cljs$cst$4641$shape_ids$$,
$ids$jscomp$293$$],null)))}),$handle_set_hidden$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$293$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$293$$,$APP.$cljs$cst$1620$hidden$$,!0)}),$handle_set_visible$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$293$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$293$$,$APP.$cljs$cst$1620$hidden$$,!1)}),$handle_set_blocked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$293$$));
return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$293$$,$APP.$cljs$cst$1623$blocked$$,!0)}),$handle_set_unblocked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$293$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$293$$,
$APP.$cljs$cst$1623$blocked$$,!1)}),$options$jscomp$624$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_blend_mode$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$current_blend_mode$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$2287$label$$,"--"],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2023$normal$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.normal")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2020$darken$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.darken")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2029$multiply$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.multiply")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2032$color_burn$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.color-burn")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2022$lighten$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.lighten")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2019$screen$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.screen")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2031$color_dodge$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.color-dodge")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2024$overlay$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.overlay")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2030$soft_light$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.soft-light")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2028$hard_light$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.hard-light")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2025$difference$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.difference")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2027$exclusion$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.exclusion")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2018$hue$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.hue")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2021$saturation$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.saturation")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.color")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2026$luminosity$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.luminosity")],null)],null)]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_blend_mode$$),$APP.$rumext$v2$adapt$$($option_highlighted_QMARK_$$),$APP.$rumext$v2$adapt$$($preview_complete_QMARK_$$)],function(){var $or__5025__auto__$jscomp$inline_8935$$=
$APP.$cljs$core$not$$($option_highlighted_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8935$$?$or__5025__auto__$jscomp$inline_8935$$:$APP.$cljs$core$truth_$$($option_highlighted_QMARK_$$)?$preview_complete_QMARK_$$:$option_highlighted_QMARK_$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5703$selected_blend_mode$$,$current_blend_mode$$):null});return $token_numeric_inputs$jscomp$5$$?(0,$APP.$rumext$v2$jsxs$$)("section",
{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.layer-section"),className:"main_ui_workspace_sidebar_options_menus_layer__element-set-content-token",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$selected_blend_mode$$,options:$options$jscomp$624$$,"on-change":$handle_change_blend_mode_state$jscomp$1189$$,"is-open?":$option_highlighted_QMARK_$$,"class":$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$6$$)?
"main_ui_workspace_sidebar_options_menus_layer__hidden-select":"","on-pointer-enter-option":$handle_blend_mode_enter$$,"on-pointer-leave-option":$handle_blend_mode_leave$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_opacity_change$jscomp$2$$,className:"main_ui_workspace_sidebar_options_menus_layer__numeric-input-wrapper",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$14_props_78975$$,$APP.$cljs$cst$1734$opacity$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,function(){var $or__5025__auto____$1$jscomp$132$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$88$$,$APP.$cljs$cst$1734$opacity$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$132$$)?$or__5025__auto____$1$jscomp$132$$:1}())?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",max:100,attr:$APP.$cljs$cst$1734$opacity$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$14_props_78975$$,$APP.$cljs$cst$1734$opacity$$),value:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$opacity$jscomp$51$$)?$opacity$jscomp$51$$:100*$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($opacity$jscomp$51$$,1),onDetach:$on_detach_token$jscomp$8$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.opacity"),
disabled:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1197$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$hidden_QMARK_$jscomp$6$$);return $or__5025__auto__$jscomp$1197$$?$or__5025__auto__$jscomp$1197$$:$hidden_QMARK_$jscomp$6$$}())?!0:!1,icon:"percentage"}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$hidden_QMARK_$jscomp$6$$)||$APP.$cljs$core$not$$($hidden_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),onClick:$handle_set_hidden$$,tooltipPlacement:"top-left",icon:"shown"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),onClick:$handle_set_visible$$,tooltipPlacement:"top-left",icon:"hide"}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$blocked_QMARK_$jscomp$3$$)||$APP.$cljs$core$not$$($blocked_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),onClick:$handle_set_blocked$$,tooltipPlacement:"top-left",icon:"unlock"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"),onClick:$handle_set_unblocked$$,tooltipPlacement:"top-left",icon:"lock"})]}):(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.layer-section"),className:"main_ui_workspace_sidebar_options_menus_layer__element-set-content "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$6$$)?"main_ui_workspace_sidebar_options_menus_layer__hidden":
""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layer__select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$selected_blend_mode$$,options:$options$jscomp$624$$,"on-change":$handle_change_blend_mode_state$jscomp$1189$$,"is-open?":$option_highlighted_QMARK_$$,"class":$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$6$$)?"main_ui_workspace_sidebar_options_menus_layer__hidden-select":"","on-pointer-enter-option":$handle_blend_mode_enter$$,
"on-pointer-leave-option":$handle_blend_mode_leave$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.opacity"),className:"main_ui_workspace_sidebar_options_menus_layer__input",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layer__icon",children:"%"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:$current_opacity$$,placeholder:"--",onChange:$handle_opacity_change$$,
min:0,max:100,className:"main_ui_workspace_sidebar_options_menus_layer__numeric-input"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layer__actions",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$hidden_QMARK_$jscomp$6$$)||$APP.$cljs$core$not$$($hidden_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),
onClick:$handle_set_hidden$$,icon:"shown"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),onClick:$handle_set_visible$$,icon:"hide"}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$blocked_QMARK_$jscomp$3$$)||$APP.$cljs$core$not$$($blocked_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),onClick:$handle_set_blocked$$,icon:"unlock"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"),onClick:$handle_set_unblocked$$,icon:"lock"})]})]})},function($old_props$jscomp$4$$,$new_props$jscomp$5$$){var $old_values$jscomp$1$$=
$old_props$jscomp$4$$.values,$new_values$jscomp$1$$=$new_props$jscomp$5$$.values,$old_applied_tokens$jscomp$2$$=$old_props$jscomp$4$$.appliedTokens,$new_applied_tokens$jscomp$2$$=$new_props$jscomp$5$$.appliedTokens;return $old_props$jscomp$4$$["class"]===$new_props$jscomp$5$$["class"]&&$old_props$jscomp$4$$.ids===$new_props$jscomp$5$$.ids&&$old_applied_tokens$jscomp$2$$===$new_applied_tokens$jscomp$2$$&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$1$$,$APP.$cljs$cst$1734$opacity$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$1$$,$APP.$cljs$cst$1734$opacity$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$1$$,$APP.$cljs$cst$1867$blend_mode$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$1$$,$APP.$cljs$cst$1867$blend_mode$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$1$$,$APP.$cljs$cst$1623$blocked$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$1$$,
$APP.$cljs$cst$1623$blocked$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$1$$,$APP.$cljs$cst$1620$hidden$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$1$$,$APP.$cljs$cst$1620$hidden$$)});var $app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1698$layout_item_margin_type$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1704$layout_item_max_h$$,$APP.$cljs$cst$1705$layout_item_min_h$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$APP.$cljs$cst$1707$layout_item_min_w$$,
$APP.$cljs$cst$1710$layout_item_align_self$$,$APP.$cljs$cst$1711$layout_item_absolute$$,$APP.$cljs$cst$1712$layout_item_z_index$$],null),$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$=function($component__44666__auto__$jscomp$2$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($component__44666__auto__$jscomp$2$$,function($new_props_79037$$,$old_props_79038$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$["is-flex-parent?"],$old_props_79038$$["is-flex-parent?"])&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$["is-grid-layout?"],$old_props_79038$$["is-grid-layout?"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$.ids,$old_props_79038$$.ids)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$.type,$old_props_79038$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$.values,$old_props_79038$$.values)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$["applied-tokens"],
$old_props_79038$$["applied-tokens"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$["is-grid-parent"],$old_props_79038$$["is-grid-parent"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$["is-flex-layout?"],$old_props_79038$$["is-flex-layout?"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79037$$["is-layout-child?"],$old_props_79038$$["is-layout-child?"])})}(function($applied_tokens$jscomp$18_props_79036$$){var $is_flex_layout_QMARK__title$jscomp$39$$=
$applied_tokens$jscomp$18_props_79036$$["is-flex-layout?"],$is_layout_child_QMARK__is_layout_child_QMARK___$1$$=$applied_tokens$jscomp$18_props_79036$$["is-layout-child?"],$is_layout_container_QMARK_$$=$applied_tokens$jscomp$18_props_79036$$["is-layout-container?"],$is_flex_parent_QMARK_$$=$applied_tokens$jscomp$18_props_79036$$["is-flex-parent?"],$is_grid_layout_QMARK__on_align_self_change$$=$applied_tokens$jscomp$18_props_79036$$["is-grid-layout?"],$is_grid_parent_QMARK__on_margin_type_change$$=
$applied_tokens$jscomp$18_props_79036$$["is-grid-parent?"],$ids$jscomp$297$$=$applied_tokens$jscomp$18_props_79036$$.ids,$values$jscomp$90$$=$applied_tokens$jscomp$18_props_79036$$.values;$applied_tokens$jscomp$18_props_79036$$=$applied_tokens$jscomp$18_props_79036$$["applied-tokens"];var $is_absolute_QMARK__selection_parents_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$297$$)}),
$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$=$APP.$rumext$v2$deref$$($is_absolute_QMARK__selection_parents_STAR_$$);$is_absolute_QMARK__selection_parents_STAR_$$=$APP.$cljs$cst$1711$layout_item_absolute$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$);$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$col_QMARK_$$,$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$);$is_layout_child_QMARK__is_layout_child_QMARK___$1$$=
$is_layout_child_QMARK__is_layout_child_QMARK___$1$$&&!$is_absolute_QMARK__selection_parents_STAR_$$;var $state_STAR_$jscomp$19$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$open_QMARK_$jscomp$23$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$19$$),$toggle_content$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$19$$,$APP.$cljs$core$not$$)}),$has_content_QMARK_$$=
$is_layout_child_QMARK__is_layout_child_QMARK___$1$$||$is_flex_parent_QMARK_$$||$is_grid_parent_QMARK__on_margin_type_change$$||$is_layout_container_QMARK_$$,$align_self$jscomp$6$$=$APP.$cljs$cst$1710$layout_item_align_self$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$),$h_sizing$jscomp$2$$=$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$),$v_sizing$jscomp$3$$=$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$);
$is_flex_layout_QMARK__title$jscomp$39$$=$is_layout_container_QMARK_$$&&$is_flex_layout_QMARK__title$jscomp$39$$&&!$is_layout_child_QMARK__is_layout_child_QMARK___$1$$?"Flex board":$is_layout_container_QMARK_$$&&$is_grid_layout_QMARK__on_align_self_change$$&&!$is_layout_child_QMARK__is_layout_child_QMARK___$1$$?"Grid board":$is_layout_container_QMARK_$$&&!$is_layout_child_QMARK__is_layout_child_QMARK___$1$$?"Layout board":$is_flex_parent_QMARK_$$?"Flex element":$is_grid_parent_QMARK__on_margin_type_change$$?
"Grid element":"Layout element";$is_grid_layout_QMARK__on_align_self_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$),$APP.$rumext$v2$adapt$$($align_self$jscomp$6$$)],function($value$jscomp$905$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$6$$,$value$jscomp$905$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1710$layout_item_align_self$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1710$layout_item_align_self$$,$value$jscomp$905$$],null)))});$is_grid_parent_QMARK__on_margin_type_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],
function($type$jscomp$655$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1698$layout_item_margin_type$$,$type$jscomp$655$$],null)))});var $on_margin_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($type$jscomp$656$$,
$prop$jscomp$41$$,$val$jscomp$216$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$656$$,$APP.$cljs$cst$1663$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$41$$,$APP.$cljs$cst$1700$m1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1700$m1$$,$val$jscomp$216$$,$APP.$cljs$cst$1702$m3$$,$val$jscomp$216$$],null)],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$656$$,$APP.$cljs$cst$1663$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$41$$,$APP.$cljs$cst$1701$m2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1701$m2$$,$val$jscomp$216$$,$APP.$cljs$cst$1703$m4$$,$val$jscomp$216$$],null)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$prop$jscomp$41$$,$val$jscomp$216$$])],null)))}),$on_behaviour_h_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($value$jscomp$906$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,$value$jscomp$906$$],null)))}),$on_behaviour_v_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($value$jscomp$907$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,
$value$jscomp$907$$],null)))}),$on_change_position$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($value$jscomp$908$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$908$$,$cljs$cst$5706$static$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1712$layout_item_z_index$$,null],null)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1711$layout_item_absolute$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$908$$,$APP.$cljs$cst$4078$absolute$$)],null)))}),$on_change_z_index$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],
function($value$jscomp$909$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1712$layout_item_z_index$$,$value$jscomp$909$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Layout item section",className:"main_ui_workspace_sidebar_options_menus_layout_item__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_content_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$23$$),onCollapsed:$toggle_content$jscomp$9$$,title:$is_flex_layout_QMARK__title$jscomp$39$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__title-spacing-layout-element "+($has_content_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_layout_item__title-spacing-empty")})}),
$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$23$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__flex-element-menu",children:[$is_layout_child_QMARK__is_layout_child_QMARK___$1$$||$is_absolute_QMARK__selection_parents_STAR_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__position-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__position-options",
children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$is_absolute_QMARK__selection_parents_STAR_$$?"absolute":"static","decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change_position$$,name:"layout-style",wide:!0,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"static",id:$cljs$cst$5707$static_position$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"absolute",
id:$cljs$cst$5708$absolute_position$$})]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:"z-index",className:"main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"Z"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",onFocus:function($p1__79034_SHARP_$$){return $app$util$dom$select_target$$($p1__79034_SHARP_$$)},
onChange:function($p1__79035_SHARP_$$){return $on_change_z_index$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_z_index$$.$cljs$core$IFn$_invoke$arity$1$($p1__79035_SHARP_$$):$on_change_z_index$$($p1__79035_SHARP_$$)},nillable:!0,value:$APP.$cljs$cst$1712$layout_item_z_index$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$)})]})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__behavior-row",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__behaviour-menu "+
($is_layout_child_QMARK__is_layout_child_QMARK___$1$$&&$is_layout_container_QMARK_$$?"main_ui_workspace_sidebar_options_menus_layout_item__wrap":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_horizontal$$,{"is-auto":$is_layout_container_QMARK_$$,"has-fill":$is_layout_child_QMARK__is_layout_child_QMARK___$1$$,value:$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$),"on-change":$on_behaviour_h_change$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_vertical$$,{"is-auto":$is_layout_container_QMARK_$$,"has-fill":$is_layout_child_QMARK__is_layout_child_QMARK___$1$$,value:$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$),"on-change":$on_behaviour_v_change$$})]})}),$is_layout_child_QMARK__is_layout_child_QMARK___$1$$&&$is_flex_parent_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__align-row",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$align_self_row$$,{"is-col":$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$,value:$align_self$jscomp$6$$,"on-change":$is_grid_layout_QMARK__on_align_self_change$$})}):null,$is_layout_child_QMARK__is_layout_child_QMARK___$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$margin_section_STAR_$$,{value:$APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$),
type:$APP.$cljs$cst$1698$layout_item_margin_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$),onTypeChange:$is_grid_parent_QMARK__on_margin_type_change$$,appliedTokens:$applied_tokens$jscomp$18_props_79036$$,ids:$ids$jscomp$297$$,onChange:$on_margin_change$$}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($h_sizing$jscomp$2$$,$APP.$cljs$cst$1403$fill$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v_sizing$jscomp$3$$,$APP.$cljs$cst$1403$fill$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_size_constraints_STAR_$$,
{ids:$ids$jscomp$297$$,values:$values$jscomp$90$$,appliedTokens:$applied_tokens$jscomp$18_props_79036$$}):null]}):null]})});var $app$main$ui$workspace$sidebar$options$menus$shadow$shadow_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$],null),$app$main$ui$workspace$sidebar$options$menus$shadow$xf_COLON_add_index$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$508$$,$shadow__$1$jscomp$18$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shadow__$1$jscomp$18$$,$cljs$cst$5710$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_menus_DOT_shadow_SLASH_index$$,
$index$jscomp$508$$)});var $app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1739$stroke_color$$,$APP.$cljs$cst$1742$stroke_color_ref_id$$,$APP.$cljs$cst$1641$stroke_color_ref_file$$,$APP.$cljs$cst$1740$stroke_opacity$$,$APP.$cljs$cst$1741$stroke_color_gradient$$,
$APP.$cljs$cst$1865$stroke_cap_start$$,$APP.$cljs$cst$1869$stroke_cap_end$$],null),$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$=function($p1__79077_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__79077_SHARP_$$,function($new_props_79080$$,$old_props_79081$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79080$$.ids,$old_props_79081$$.ids)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79080$$.values,$old_props_79081$$.values)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79080$$.type,$old_props_79081$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79080$$["show-caps"],$old_props_79081$$["show-caps"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79080$$["applied-tokens"],$old_props_79081$$["applied-tokens"])})}(function($label$jscomp$44_props_79079$$){function $on_blur$jscomp$25$$(){return $APP.$cljs$core$reset_BANG_$$($disable_drag$jscomp$3$$,!1)}function $on_focus$jscomp$17$$(){return $APP.$cljs$core$reset_BANG_$$($disable_drag$jscomp$3$$,
!0)}function $on_add_stroke$$(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$add_stroke$$($ids$jscomp$300$$,$APP.$app$common$types$stroke$default_stroke$$));return $APP.$cljs$core$seq$$($strokes$jscomp$10$$)==null?$open_content$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$open_content$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():
$open_content$jscomp$1$$():null}function $on_stroke_cap_switch$jscomp$1$$($index$jscomp$523$$){var $stroke_cap_start$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$93$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$index$jscomp$523$$,$APP.$cljs$cst$1865$stroke_cap_start$$],null)),$stroke_cap_end$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$93$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$index$jscomp$523$$,$APP.$cljs$cst$1869$stroke_cap_end$$],null));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($stroke_cap_start$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($stroke_cap_end$$,$APP.$cljs$cst$1616$multiple$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$)),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$300$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1865$stroke_cap_start$$,$stroke_cap_end$$,$APP.$cljs$cst$1869$stroke_cap_end$$,$stroke_cap_start$$],null),$index$jscomp$523$$))):null}function $on_stroke_cap_end_change$jscomp$1$$($index$jscomp$522$$,$value$jscomp$921$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$300$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1869$stroke_cap_end$$,$value$jscomp$921$$],null),$index$jscomp$522$$))}function $on_stroke_cap_start_change$jscomp$1$$($index$jscomp$521$$,$value$jscomp$920$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$300$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1865$stroke_cap_start$$,$value$jscomp$920$$],null),$index$jscomp$521$$))}function $close_caps_select$$($caps_state$jscomp$1$$){return function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($caps_state$jscomp$1$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$4533$open_QMARK_$$,!1)}}function $open_caps_select$$($caps_state$$){return function($event$jscomp$551_top$jscomp$17$$){var $left$jscomp$35_window_size$jscomp$5$$=$APP.$app$util$dom$get_window_size$$(),$rect$jscomp$46$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($event$jscomp$551_top$jscomp$17$$));$event$jscomp$551_top$jscomp$17$$=$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$46$$)+320<$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$35_window_size$jscomp$5$$)?
$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$46$$)+5:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$35_window_size$jscomp$5$$)-325;$left$jscomp$35_window_size$jscomp$5$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$46$$)+200<$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$35_window_size$jscomp$5$$)?$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$46$$):$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$35_window_size$jscomp$5$$)-
205;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($caps_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4533$open_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$257$left$$,$left$jscomp$35_window_size$jscomp$5$$,$APP.$cljs$cst$1562$top$$,$event$jscomp$551_top$jscomp$17$$]))}}function $on_stroke_width_change$jscomp$1$$($index$jscomp$520$$,$value$jscomp$919$$){if($APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$919$$))return null;
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$300$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,$value$jscomp$919$$],null),$index$jscomp$520$$))}function $on_stroke_alignment_change$jscomp$1$$($index$jscomp$519$$,
$value$jscomp$918$$){if($APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$918$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$300$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1868$stroke_alignment$$,
$value$jscomp$918$$],null),$index$jscomp$519$$))}var $shapes$jscomp$210$$=$label$jscomp$44_props_79079$$.shapes,$objects$jscomp$792$$=$label$jscomp$44_props_79079$$.objects,$disable_stroke_style$jscomp$1$$=$label$jscomp$44_props_79079$$.disableStrokeStyle,$ids$jscomp$300$$=$label$jscomp$44_props_79079$$.ids,$type$jscomp$658$$=$label$jscomp$44_props_79079$$.type,$show_caps$jscomp$1$$=$label$jscomp$44_props_79079$$.showCaps,$values$jscomp$93$$=$label$jscomp$44_props_79079$$.values,$applied_tokens$jscomp$20$$=
$label$jscomp$44_props_79079$$.appliedTokens;$label$jscomp$44_props_79079$$=function(){switch($type$jscomp$658$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$658$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-stroke");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.group-stroke");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.stroke")}}();
var $state_STAR_$jscomp$20$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$open_QMARK_$jscomp$24$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$20$$),$toggle_content$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$20$$,$APP.$cljs$core$not$$)}),$open_content$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$20$$,
!0)}),$strokes$jscomp$10$$=$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$93$$),$has_strokes_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$strokes$jscomp$10$$)||$APP.$cljs$core$seq$$($strokes$jscomp$10$$)!=null,$on_color_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],function($index$jscomp$515$$,$color$jscomp$170$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$300$$,$color$jscomp$170$$,$index$jscomp$515$$))}),$on_remove$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],function($index$jscomp$516$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_stroke$$($ids$jscomp$300$$,$index$jscomp$516$$))}),$handle_remove_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_all_strokes$$($ids$jscomp$300$$))}),
$on_color_detach$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],function($index$jscomp$517$$,$color$jscomp$171_color__$1$jscomp$34$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));$color$jscomp$171_color__$1$jscomp$34$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$171_color__$1$jscomp$34$$,
$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1736$ref_file$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$300$$,$color$jscomp$171_color__$1$jscomp$34$$,$index$jscomp$517$$))}),$handle_reorder$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],
function($from_pos$jscomp$19$$,$to_space_between_pos$jscomp$19$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$reorder_strokes$$($ids$jscomp$300$$,$from_pos$jscomp$19$$,$to_space_between_pos$jscomp$19$$))}),$on_stroke_style_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],
function($index$jscomp$518$$,$value$jscomp$917$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$300$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1866$stroke_style$$,$value$jscomp$917$$],null),$index$jscomp$518$$))}),
$on_toggle_visibility$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],function($index$jscomp$524$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$300$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$300$$,
function($p1__79078_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__79078_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$index$jscomp$524$$,$APP.$cljs$cst$1620$hidden$$],null),$APP.$cljs$core$not$$)})]))}),$disable_drag$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_detach_token$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],
function($token_name$jscomp$26$$,$attrs$jscomp$177$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$26$$,$APP.$cljs$cst$1993$attributes$$,$attrs$jscomp$177$$,$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$300$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Stroke section",className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-section",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_strokes_QMARK_$jscomp$1$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$24$$),onCollapsed:$toggle_content$jscomp$11$$,title:$label$jscomp$44_props_79079$$,className:$has_strokes_QMARK_$jscomp$1$$?"":"main_ui_workspace_sidebar_options_menus_stroke__stroke-title-bar",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$strokes$jscomp$10$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.add-stroke"),onClick:$on_add_stroke$$,icon:"add","data-testid":"add-stroke"})})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$24$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-content "+($has_strokes_QMARK_$jscomp$1$$?
"":"main_ui_workspace_sidebar_options_menus_stroke__stroke-content-empty"),children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$20$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$20$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,
$strokes$jscomp$10$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-multiple-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.remove-stroke"),
onClick:$handle_remove_all$$,icon:"remove"})]}):$APP.$cljs$core$seq$$($strokes$jscomp$10$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$173$$,$p__79083_value$jscomp$922$$){var $index$jscomp$525$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79083_value$jscomp$922$$,0,null);$p__79083_value$jscomp$922$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79083_value$jscomp$922$$,
1,null);$out_arr__44124__auto__$jscomp$173$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$stroke_row$stroke_row_STAR_$$,{onStrokeStyleChange:$on_stroke_style_change$jscomp$1$$,onRemove:$on_remove$jscomp$6$$,onToggleVisibility:$on_toggle_visibility$jscomp$5$$,index:$index$jscomp$525$$,appliedTokens:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$index$jscomp$525$$)?$applied_tokens$jscomp$20$$:null,closeCapsSelect:$close_caps_select$$,showCaps:$show_caps$jscomp$1$$,
onStrokeWidthChange:$on_stroke_width_change$jscomp$1$$,onStrokeCapEndChange:$on_stroke_cap_end_change$jscomp$1$$,selectOnFocus:$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($disable_drag$jscomp$3$$)),disableStrokeStyle:$disable_stroke_style$jscomp$1$$,onStrokeCapSwitch:$on_stroke_cap_switch$jscomp$1$$,objects:$objects$jscomp$792$$,onReorder:$handle_reorder$jscomp$1$$,disableDrag:$disable_drag$jscomp$3$$,ids:$ids$jscomp$300$$,onDetachToken:$on_detach_token$jscomp$13$$,stroke:$p__79083_value$jscomp$922$$,
onStrokeAlignmentChange:$on_stroke_alignment_change$jscomp$1$$,onColorDetach:$on_color_detach$jscomp$1$$,onFocus:$on_focus$jscomp$17$$,shapes:$shapes$jscomp$210$$,openCapsSelect:$open_caps_select$$,onColorChange:$on_color_change$jscomp$2$$,onBlur:$on_blur$jscomp$25$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-color"),onStrokeCapStartChange:$on_stroke_cap_start_change$jscomp$1$$},"stroke-"+($index$jscomp$525$$??"")+"-"+($APP.$cljs$core$hash$$($applied_tokens$jscomp$20$$)??
"")));return $out_arr__44124__auto__$jscomp$173$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$93$$,$APP.$cljs$core$PersistentVector$EMPTY$$)))}):null}):null]})});var $app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$=function $app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$($handle_change$jscomp$10_props_79089$$){var $on_change$jscomp$75$$=$handle_change$jscomp$10_props_79089$$.onChange,$attr$jscomp$90$$=$handle_change$jscomp$10_props_79089$$.attr,$value$jscomp$923$$=$handle_change$jscomp$10_props_79089$$.value,$on_delete$jscomp$11$$=$handle_change$jscomp$10_props_79089$$.onDelete,$last_value$jscomp$1$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($value$jscomp$923$$),$handle_change_STAR_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$functions$debounce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($val$jscomp$217$$){return $on_change$jscomp$75$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$75$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$90$$,$val$jscomp$217$$):$on_change$jscomp$75$$($attr$jscomp$90$$,$val$jscomp$217$$)},300));$handle_change$jscomp$10_props_79089$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($attr$jscomp$90$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$75$$),$APP.$rumext$v2$adapt$$($handle_change_STAR_$$)],function($G__79090_event$jscomp$552$$){$APP.$cljs$core$reset_BANG_$$($last_value$jscomp$1$$,(0,$APP.$app$util$dom$get_target_val$$)($G__79090_event$jscomp$552$$));$G__79090_event$jscomp$552$$=(0,$APP.$app$util$dom$get_target_val$$)($G__79090_event$jscomp$552$$);return $handle_change_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_change_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($G__79090_event$jscomp$552$$):$handle_change_STAR_$$($G__79090_event$jscomp$552$$)});var $handle_delete$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($attr$jscomp$90$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$11$$)],function(){return $on_delete$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$90$$):$on_delete$jscomp$11$$($attr$jscomp$90$$)}),
$label$jscomp$45$$=$APP.$app$common$data$name$$($APP.$cljs$core$last$$($attr$jscomp$90$$));return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:typeof $value$jscomp$923$$==="string"?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-content",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-name",children:$label$jscomp$45$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input",
children:(0,$APP.$rumext$v2$jsx$$)("input",{value:$APP.$cljs$core$_deref$$($last_value$jscomp$1$$),onChange:$handle_change$jscomp$10_props_79089$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-actions",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_delete$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn",children:$APP.$app$main$ui$icons$remove_icon$$})})]}):(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-nested-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-title",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$name$$($APP.$cljs$core$last$$($attr$jscomp$90$$)))}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$174$$,$p__79091_value__$1$jscomp$59$$){var $key$jscomp$415$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79091_value__$1$jscomp$59$$,
0,null);$p__79091_value__$1$jscomp$59$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79091_value__$1$jscomp$59$$,1,null);$out_arr__44124__auto__$jscomp$174$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$,{attr:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$90$$,$key$jscomp$415$$),value:$p__79091_value__$1$jscomp$59$$,
onChange:$on_change$jscomp$75$$,onDelete:$on_delete$jscomp$11$$},$key$jscomp$415$$)},$key$jscomp$415$$));return $out_arr__44124__auto__$jscomp$174$$},[],$value$jscomp$923$$)]})})};var $app$main$ui$workspace$sidebar$options$menus$color_selection$xf_COLON_map_shape_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2543$shape_id$$),$app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$=function($p1__79103_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__79103_SHARP_$$,function($new_props_79119$$,$old_props_79120$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79119$$.shapes,$old_props_79120$$.shapes)})}(function($colors$jscomp$26_map__79121_props_79118$$){var $shapes$jscomp$214$$=
$colors$jscomp$26_map__79121_props_79118$$.shapes,$file_id$jscomp$413$$=$colors$jscomp$26_map__79121_props_79118$$.fileId,$libraries$jscomp$149$$=$colors$jscomp$26_map__79121_props_79118$$.libraries;$colors$jscomp$26_map__79121_props_79118$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$413$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$214$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$149$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$color_selection$prepare_colors$$($shapes$jscomp$214$$,
$file_id$jscomp$413$$,$libraries$jscomp$149$$)});var $map__79121__$1_open_QMARK_$jscomp$26$$=$APP.$cljs$core$__destructure_map$$($colors$jscomp$26_map__79121_props_79118$$),$groups$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79121__$1_open_QMARK_$jscomp$26$$,$APP.$cljs$cst$4382$groups$$),$library_colors$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79121__$1_open_QMARK_$jscomp$26$$,$cljs$cst$5720$library_colors$$);$colors$jscomp$26_map__79121_props_79118$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79121__$1_open_QMARK_$jscomp$26$$,$APP.$cljs$cst$2212$colors$$);var $token_colors$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79121__$1_open_QMARK_$jscomp$26$$,$cljs$cst$5719$token_colors$$),$open_STAR_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$map__79121__$1_open_QMARK_$jscomp$26$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$10$$);var $has_colors_QMARK_$jscomp$1$$=$APP.$cljs$core$seq$$($colors$jscomp$26_map__79121_props_79118$$)!=
null||$APP.$cljs$core$seq$$($library_colors$jscomp$3$$)!=null,$toggle_content$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$10$$,$APP.$cljs$core$not$$)}),$expand_lib_color$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$expand_color$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$expand_token_color$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$prev_colors_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$groups_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$set_ref_val_BANG_$$($groups_ref$$,$groups$jscomp$16$$);var $on_change$jscomp$76$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($color_operations$jscomp$3_old_color$jscomp$4$$,$new_color$jscomp$4$$,$color_79191_from_picker_QMARK_$$){var $prev_colors$jscomp$1$$=$APP.$rumext$v2$ref_val$$($prev_colors_ref$$),$old_color__$1$jscomp$1_vec__79122$$=$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$($APP.$rumext$v2$ref_val$$($groups_ref$$),
$color_operations$jscomp$3_old_color$jscomp$4$$,$prev_colors$jscomp$1$$);$color_operations$jscomp$3_old_color$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color__$1$jscomp$1_vec__79122$$,0,null);$old_color__$1$jscomp$1_vec__79122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color__$1$jscomp$1_vec__79122$$,1,null);$APP.$cljs$core$truth_$$($color_79191_from_picker_QMARK_$$)&&($color_79191_from_picker_QMARK_$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($new_color$jscomp$4$$,
$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$]))),$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prev_colors$jscomp$1$$,$color_79191_from_picker_QMARK_$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_color_in_selected$$($color_operations$jscomp$3_old_color$jscomp$4$$,$new_color$jscomp$4$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($old_color__$1$jscomp$1_vec__79122$$,
$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4185$has_token_applied$$]))))}),$on_open$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}),$on_close$jscomp$33$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}),
$on_detach$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$16$$)],function($color$jscomp$172$$){var $color_operations$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$16$$,$color$jscomp$172$$),$color_SINGLEQUOTE_$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$172$$,$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1736$ref_file$$]));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_color_in_selected$$($color_operations$jscomp$4$$,$color_SINGLEQUOTE_$$,$color$jscomp$172$$))}),$on_detach_token$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_colors$jscomp$1$$),$APP.$rumext$v2$adapt$$($groups$jscomp$16$$)],function($token_name$jscomp$27$$){var $prev_colors$jscomp$2$$=$APP.$rumext$v2$ref_val$$($prev_colors_ref$$),
$token_color$jscomp$2$$=$APP.$cljs$core$some$$(function($p1__79104_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4186$token_name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79104_SHARP_$$),$token_name$jscomp$27$$)?$p1__79104_SHARP_$$:null},$token_colors$jscomp$1$$),$G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$=$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$($groups$jscomp$16$$,$token_color$jscomp$2$$,
$prev_colors$jscomp$2$$),$G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$,1,null);$G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$=$APP.$cljs$core$seq$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$);
for(var $attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$=null,$G__79208_color_79211_count__79130$$=0,$i__79131$$=0;;)if($i__79131$$<$G__79208_color_79211_count__79130$$){$G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$=$attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__79131$$);var $attr_79194$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4158$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$),
$APP.$cljs$cst$2903$stroke$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$color_79195$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($token_color$jscomp$2$$,$APP.$cljs$cst$4186$token_name$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4185$has_token_applied$$])));$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prev_colors$jscomp$2$$,$color_79195$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$27$$,$APP.$cljs$cst$1993$attributes$$,
$attr_79194$$,$APP.$cljs$cst$4641$shape_ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$)],null)],null)));$i__79131$$+=1}else if($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$=$APP.$cljs$core$seq$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$))$G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$=
$G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$)?($attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$=$APP.$cljs$core$_chunked_first$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$),$G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$=$APP.$cljs$core$_chunked_rest$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$),$G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$=
$attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$,$G__79208_color_79211_count__79130$$=$APP.$cljs$core$count$$($attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$),$attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$=$G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$):($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$=$APP.$cljs$core$first$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$),$attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4158$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$),
$APP.$cljs$cst$2903$stroke$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$G__79208_color_79211_count__79130$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($token_color$jscomp$2$$,
$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4185$has_token_applied$$]))),$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prev_colors$jscomp$2$$,$G__79208_color_79211_count__79130$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,
$token_name$jscomp$27$$,$APP.$cljs$cst$1993$attributes$$,$attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$,$APP.$cljs$cst$4641$shape_ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__79207_op$jscomp$21_temp__5825__auto__$jscomp$380_vec__79125$$)],null)],null))),$G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$=$APP.$cljs$core$next$$($G__79206_color_operations$jscomp$5_seq__79128_seq__79128__$1$$),
$attr_79210_c__5548__auto__$jscomp$43_chunk__79129$$=null,$G__79208_color_79211_count__79130$$=0),$i__79131$$=0;else return null}),$select_only$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$16$$)],function($color$jscomp$173_color_operations$jscomp$6_ids$jscomp$304$$){$color$jscomp$173_color_operations$jscomp$6_ids$jscomp$304$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$16$$,$color$jscomp$173_color_operations$jscomp$6_ids$jscomp$304$$);
$color$jscomp$173_color_operations$jscomp$6_ids$jscomp$304$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$app$main$ui$workspace$sidebar$options$menus$color_selection$xf_COLON_map_shape_id$$,$color$jscomp$173_color_operations$jscomp$6_ids$jscomp$304$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shapes$$($color$jscomp$173_color_operations$jscomp$6_ids$jscomp$304$$))}),
$on_token_change$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$16$$)],function($___$1$jscomp$2076_prev_colors$jscomp$3$$,$token$jscomp$138$$,$old_color$jscomp$5_vec__79132$$){$___$1$jscomp$2076_prev_colors$jscomp$3$$=$APP.$rumext$v2$ref_val$$($prev_colors_ref$$);var $color$jscomp$174_new_color$jscomp$5_resolved_value$jscomp$2$$=$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$138$$);$color$jscomp$174_new_color$jscomp$5_resolved_value$jscomp$2$$=
$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($color$jscomp$174_new_color$jscomp$5_resolved_value$jscomp$2$$);$color$jscomp$174_new_color$jscomp$5_resolved_value$jscomp$2$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$174_new_color$jscomp$5_resolved_value$jscomp$2$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$])));
$old_color$jscomp$5_vec__79132$$=$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$($groups$jscomp$16$$,$old_color$jscomp$5_vec__79132$$,$___$1$jscomp$2076_prev_colors$jscomp$3$$);var $color_operations$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color$jscomp$5_vec__79132$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color$jscomp$5_vec__79132$$,1,null);$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($___$1$jscomp$2076_prev_colors$jscomp$3$$,$color$jscomp$174_new_color$jscomp$5_resolved_value$jscomp$2$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_on_color_selected$$($color_operations$jscomp$7$$,$token$jscomp$138$$))});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-color.section"),
className:"main_ui_workspace_sidebar_options_menus_color_selection__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_colors_QMARK_$jscomp$1$$,collapsed:$APP.$cljs$core$not$$($map__79121__$1_open_QMARK_$jscomp$26$$),onCollapsed:$toggle_content$jscomp$13$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-color"),
className:$has_colors_QMARK_$jscomp$1$$?"":"main_ui_workspace_sidebar_options_menus_color_selection__title-spacing-selected-colors"})}),$APP.$cljs$core$truth_$$($map__79121__$1_open_QMARK_$jscomp$26$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__element-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group",children:[function(){var $library_colors_extract$$=
$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($expand_lib_color$$))?$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(3,$library_colors$jscomp$3$$):$library_colors$jscomp$3$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$176$$,$p__79139$$){var $index$jscomp$526$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79139$$,0,null),$color$jscomp$175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79139$$,1,null);
$out_arr__44124__auto__$jscomp$176$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$cljs$cst$5590$color_selection$$,onClose:$on_close$jscomp$33$$,index:$index$jscomp$526$$,onChange:function($p1__79106_SHARP_$$,$p2__79107_SHARP_$$){return $on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$3$?$on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$175$$,$p1__79106_SHARP_$$,$p2__79107_SHARP_$$):$on_change$jscomp$76$$($color$jscomp$175$$,
$p1__79106_SHARP_$$,$p2__79107_SHARP_$$)},onTokenChange:function($p1__79108_SHARP_$$,$p2__79109_SHARP_$$){return $on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79108_SHARP_$$,$p2__79109_SHARP_$$,$color$jscomp$175$$):$on_token_change$jscomp$7$$($p1__79108_SHARP_$$,$p2__79109_SHARP_$$,$color$jscomp$175$$)},onDetach:function($p1__79105_SHARP_$$){return $on_detach$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$175$$,
$p1__79105_SHARP_$$):$on_detach$jscomp$5$$($color$jscomp$175$$,$p1__79105_SHARP_$$)},selectOnly:$select_only$jscomp$2$$,color:$color$jscomp$175$$,onOpen:$on_open$jscomp$4$$},$index$jscomp$526$$));return $out_arr__44124__auto__$jscomp$176$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($library_colors_extract$$))}(),$APP.$cljs$core$_deref$$($expand_lib_color$$)===!1&&3<$APP.$cljs$core$count$$($library_colors$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$cljs$core$reset_BANG_$$($expand_lib_color$$,
!0)},className:"main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.more-lib-colors")}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$177$$,$p__79148$$){var $index$jscomp$527$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79148$$,
0,null),$color$jscomp$176$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79148$$,1,null);$out_arr__44124__auto__$jscomp$177$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{onTokenChange:function($p1__79112_SHARP_$$,$p2__79113_SHARP_$$){return $on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79112_SHARP_$$,$p2__79113_SHARP_$$,$color$jscomp$176$$):$on_token_change$jscomp$7$$($p1__79112_SHARP_$$,
$p2__79113_SHARP_$$,$color$jscomp$176$$)},selectOnly:$select_only$jscomp$2$$,color:$color$jscomp$176$$,index:$index$jscomp$527$$,onClose:$on_close$jscomp$33$$,origin:$cljs$cst$5590$color_selection$$,onChange:function($p1__79110_SHARP_$$,$p2__79111_SHARP_$$){return $on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$3$?$on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$176$$,$p1__79110_SHARP_$$,$p2__79111_SHARP_$$):$on_change$jscomp$76$$($color$jscomp$176$$,$p1__79110_SHARP_$$,$p2__79111_SHARP_$$)},
onOpen:$on_open$jscomp$4$$},$index$jscomp$527$$));return $out_arr__44124__auto__$jscomp$177$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($expand_color$$))?$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(3,$colors$jscomp$26_map__79121_props_79118$$):$colors$jscomp$26_map__79121_props_79118$$)),$APP.$cljs$core$_deref$$($expand_color$$)===!1&&3<$APP.$cljs$core$count$$($colors$jscomp$26_map__79121_props_79118$$)?(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:function(){return $APP.$cljs$core$reset_BANG_$$($expand_color$$,!0)},className:"main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.more-colors")}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group",children:[function(){var $token_color_extract$$=$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($expand_token_color$$))?
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(3,$token_colors$jscomp$1$$):$token_colors$jscomp$1$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$178$$,$p__79159$$){var $index$jscomp$528$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79159$$,0,null),$token_color$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79159$$,1,null);$out_arr__44124__auto__$jscomp$178$$.push(function(){var $color$jscomp$177$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($token_color$jscomp$3$$,$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4185$has_token_applied$$]));return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$cljs$cst$5590$color_selection$$,onClose:$on_close$jscomp$33$$,index:$index$jscomp$528$$,onChange:function($p1__79114_SHARP_$$,$p2__79115_SHARP_$$){return $on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$3$?
$on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$3$($token_color$jscomp$3$$,$p1__79114_SHARP_$$,$p2__79115_SHARP_$$):$on_change$jscomp$76$$($token_color$jscomp$3$$,$p1__79114_SHARP_$$,$p2__79115_SHARP_$$)},onTokenChange:function($p1__79116_SHARP_$$,$p2__79117_SHARP_$$){return $on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79116_SHARP_$$,$p2__79117_SHARP_$$,$token_color$jscomp$3$$):$on_token_change$jscomp$7$$($p1__79116_SHARP_$$,
$p2__79117_SHARP_$$,$token_color$jscomp$3$$)},onDetachToken:$on_detach_token$jscomp$14$$,appliedToken:$APP.$cljs$cst$4186$token_name$$.$cljs$core$IFn$_invoke$arity$1$($token_color$jscomp$3$$),selectOnly:$select_only$jscomp$2$$,color:$color$jscomp$177$$,onOpen:$on_open$jscomp$4$$},$index$jscomp$528$$)}());return $out_arr__44124__auto__$jscomp$178$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($token_color_extract$$))}(),$APP.$cljs$core$_deref$$($expand_token_color$$)===
!1&&3<$APP.$cljs$core$count$$($token_colors$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$cljs$core$reset_BANG_$$($expand_token_color$$,!0)},className:"main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.more-token-colors")}):null]})]}):null]})});var $app$main$data$workspace$grid$add_frame_grid_79221$$,$app$main$data$workspace$grid$remove_frame_grid_79225$$,$app$main$data$workspace$grid$set_frame_grid_79229$$,$app$main$data$workspace$grid$set_default_grid_79232$$;var $app$main$ui$workspace$sidebar$options$menus$frame_grid$lens_COLON_default_grids$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2055$default_grids$$,$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$menus$frame_grid$grid_options_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_remove$jscomp$7_props_79238$$){var $default_grid_params$$=$on_remove$jscomp$7_props_79238$$.defaultGridParams,$index$jscomp$533$$=
$on_remove$jscomp$7_props_79238$$.index,$frame_height$$=$on_remove$jscomp$7_props_79238$$.frameHeight,$frame_width$$=$on_remove$jscomp$7_props_79238$$.frameWidth,$grid$jscomp$15$$=$on_remove$jscomp$7_props_79238$$.grid,$shape_id$jscomp$161$$=$on_remove$jscomp$7_props_79238$$.shapeId,$on_change$jscomp$77$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$161$$),$APP.$rumext$v2$adapt$$($index$jscomp$533$$)],function($p1__79235_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$set_frame_grid$$($shape_id$jscomp$161$$,
$index$jscomp$533$$,$p1__79235_SHARP_$$))});$on_remove$jscomp$7_props_79238$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$161$$),$APP.$rumext$v2$adapt$$($index$jscomp$533$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$remove_frame_grid$$($shape_id$jscomp$161$$,$index$jscomp$533$$))});var $on_save_default$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79236_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$set_default_grid$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__79236_SHARP_$$),
$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($p1__79236_SHARP_$$)))}),$size_options$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$options$menus$frame_grid$get_size_options$$),$state_STAR_$jscomp$22$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5725$show_advanced_options$$,!1,$cljs$cst$5700$show_more_options$$,!1],null)),$show_more_options_QMARK__state$jscomp$1192$$=
$APP.$cljs$core$_deref$$($state_STAR_$jscomp$22$$),$open_QMARK_$jscomp$27$$=$cljs$cst$5725$show_advanced_options$$.$cljs$core$IFn$_invoke$arity$1$($show_more_options_QMARK__state$jscomp$1192$$);$show_more_options_QMARK__state$jscomp$1192$$=$cljs$cst$5700$show_more_options$$.$cljs$core$IFn$_invoke$arity$1$($show_more_options_QMARK__state$jscomp$1192$$);var $is_hidden_QMARK_$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1932$display$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$)),$map__79239__$1_toggle_advanced_options$$=
$APP.$cljs$core$__destructure_map$$($grid$jscomp$15$$),$type$jscomp$666$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79239__$1_toggle_advanced_options$$,$APP.$cljs$cst$139$type$$),$display$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79239__$1_toggle_advanced_options$$,$APP.$cljs$cst$1932$display$$),$params$jscomp$429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79239__$1_toggle_advanced_options$$,$APP.$cljs$cst$1430$params$$);$map__79239__$1_toggle_advanced_options$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$22$$,$APP.$cljs$core$update$$,$cljs$cst$5725$show_advanced_options$$,$APP.$cljs$core$not$$)});var $toggle_more_options$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$22$$,$APP.$cljs$core$update$$,$cljs$cst$5700$show_more_options$$,
$APP.$cljs$core$not$$)}),$close_more_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$22$$,$APP.$cljs$core$assoc$$,$cljs$cst$5700$show_more_options$$,!1)}),$handle_toggle_visibility$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function(){var $G__79240$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($grid$jscomp$15$$,
$APP.$cljs$cst$1932$display$$,function($p1__79237_SHARP_$$){return $p1__79237_SHARP_$$==null?!1:$APP.$cljs$core$not$$($p1__79237_SHARP_$$)});return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79240$$):$on_change$jscomp$77$$($G__79240$$)}),$handle_change_type$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function($G__79241_grid_type$jscomp$2$$){var $defaults$jscomp$6$$=
$G__79241_grid_type$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$G__79241_grid_type$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($default_grid_params$$):$G__79241_grid_type$jscomp$2$$($default_grid_params$$);$G__79241_grid_type$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($grid$jscomp$15$$,$APP.$cljs$cst$139$type$$,$G__79241_grid_type$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1430$params$$,$defaults$jscomp$6$$]));return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79241_grid_type$jscomp$2$$):$on_change$jscomp$77$$($G__79241_grid_type$jscomp$2$$)}),$handle_change$jscomp$12$$=function(){function $G__79269$$($var_args$jscomp$1451$$){var $G__79270__i_keys_path$jscomp$1$$=null;if(arguments.length>0){$G__79270__i_keys_path$jscomp$1$$=0;for(var $G__79270__a$$=Array(arguments.length-0);$G__79270__i_keys_path$jscomp$1$$<$G__79270__a$$.length;)$G__79270__a$$[$G__79270__i_keys_path$jscomp$1$$]=arguments[$G__79270__i_keys_path$jscomp$1$$+
0],++$G__79270__i_keys_path$jscomp$1$$;$G__79270__i_keys_path$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__79270__a$$,0,null)}return $G__79269__delegate$$.call(this,$G__79270__i_keys_path$jscomp$1$$)}function $G__79269__delegate$$($keys_path$$){return function($G__79242_value$jscomp$926$$){$G__79242_value$jscomp$926$$=$APP.$cljs$core$assoc_in$$($grid$jscomp$15$$,$keys_path$$,$G__79242_value$jscomp$926$$);return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79242_value$jscomp$926$$):
$on_change$jscomp$77$$($G__79242_value$jscomp$926$$)}}$G__79269$$.$cljs$lang$maxFixedArity$=0;$G__79269$$.$cljs$lang$applyTo$=function($arglist__79271_keys_path$jscomp$2$$){$arglist__79271_keys_path$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__79271_keys_path$jscomp$2$$);return $G__79269__delegate$$($arglist__79271_keys_path$jscomp$2$$)};$G__79269$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__79269__delegate$$;return $G__79269$$}(),$handle_change_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],
function($G__79244_size$jscomp$155$$){var $map__79243_margin$jscomp$5$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$),$item_length$jscomp$2_map__79243__$1$$=$APP.$cljs$core$__destructure_map$$($map__79243_margin$jscomp$5$$);$map__79243_margin$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item_length$jscomp$2_map__79243__$1$$,$APP.$cljs$cst$1929$margin$$);var $gutter$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item_length$jscomp$2_map__79243__$1$$,
$APP.$cljs$cst$1931$gutter$$);$item_length$jscomp$2_map__79243__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item_length$jscomp$2_map__79243__$1$$,$APP.$cljs$cst$1930$item_length$$);var $frame_length$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$))?$frame_width$$:$frame_height$$;$G__79244_size$jscomp$155$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($grid$jscomp$15$$,
$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$874$size$$,$G__79244_size$jscomp$155$$,$APP.$cljs$cst$1930$item_length$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__79244_size$jscomp$155$$==null?($frame_length$jscomp$2$$-($map__79243_margin$jscomp$5$$+($map__79243_margin$jscomp$5$$-$gutter$jscomp$4$$))-$gutter$jscomp$4$$*12)/12:$item_length$jscomp$2_map__79243__$1$$]));return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79244_size$jscomp$155$$):
$on_change$jscomp$77$$($G__79244_size$jscomp$155$$)}),$handle_change_item_length$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function($G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$){$G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$=$G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$===0?null:$G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$;var $size$jscomp$156$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$15$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$874$size$$],null));$G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($grid$jscomp$15$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$874$size$$,$G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$==null&&$size$jscomp$156$$==null?12:$size$jscomp$156$$,$APP.$cljs$cst$1930$item_length$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$]));return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$):$on_change$jscomp$77$$($G__79245_item_length$jscomp$3_item_length__$1$jscomp$3$$)}),$handle_change_color$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],
function($G__79246_color$jscomp$178_color__$1$jscomp$35$$){$G__79246_color$jscomp$178_color__$1$jscomp$35$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__79246_color$jscomp$178_color__$1$jscomp$35$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$]));$G__79246_color$jscomp$178_color__$1$jscomp$35$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($grid$jscomp$15$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1298$color$$,$G__79246_color$jscomp$178_color__$1$jscomp$35$$);return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79246_color$jscomp$178_color__$1$jscomp$35$$):$on_change$jscomp$77$$($G__79246_color$jscomp$178_color__$1$jscomp$35$$)}),$handle_detach_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function(){var $G__79247$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($grid$jscomp$15$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1298$color$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1644$file_id$$);return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79247$$):$on_change$jscomp$77$$($G__79247$$)}),$handle_use_default$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],
function(){var $params__$1$jscomp$57$$=function(){var $fexpr__79248$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$);return $fexpr__79248$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79248$$.$cljs$core$IFn$_invoke$arity$1$($default_grid_params$$):$fexpr__79248$$($default_grid_params$$)}(),$G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$=function(){var $or__5025__auto__$jscomp$1204$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$260$value$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1204$$)?$or__5025__auto__$jscomp$1204$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1298$color$$],null))}();$G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($params__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1298$color$$],null),$G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$),$APP.$cljs$cst$1298$color$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$260$value$$);$APP.$cljs$core$truth_$$($on_change$jscomp$77$$)&&($G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($grid$jscomp$15$$,$APP.$cljs$cst$1430$params$$,$G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$),$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$1$($G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$):$on_change$jscomp$77$$($G__79249_79272_color$jscomp$179_params__$2$jscomp$7$$));return $close_more_options$$.$cljs$core$IFn$_invoke$arity$0$?$close_more_options$$.$cljs$core$IFn$_invoke$arity$0$():
$close_more_options$$()}),$handle_set_as_default$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function(){$on_save_default$$.$cljs$core$IFn$_invoke$arity$1$?$on_save_default$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$):$on_save_default$$($grid$jscomp$15$$);return $close_more_options$$.$cljs$core$IFn$_invoke$arity$0$?$close_more_options$$.$cljs$core$IFn$_invoke$arity$0$():$close_more_options$$()}),$is_default$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$),
function(){var $G__79250$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$);return $default_grid_params$$.$cljs$core$IFn$_invoke$arity$1$?$default_grid_params$$.$cljs$core$IFn$_invoke$arity$1$($G__79250$$):$default_grid_params$$($G__79250$$)}());return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-option",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-title",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__option-row "+($is_hidden_QMARK_$$?"main_ui_workspace_sidebar_options_menus_frame_grid__hidden":""),children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$map__79239__$1_toggle_advanced_options$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__show-options "+($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$27$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__selected":""),children:$APP.$app$main$ui$icons$menu$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_frame_grid__grid-type-select","default-value":$type$jscomp$666$$,options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1933$square$$,
$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.square")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.column")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.row")],
null)],null),"on-change":$handle_change_type$jscomp$1$$})}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$666$$,$APP.$cljs$cst$1933$square$$)?(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size"),className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-size",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,value:function(){var $or__5025__auto__$jscomp$1205$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1205$$)?$or__5025__auto__$jscomp$1205$$:""}(),noValidate:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",onChange:$handle_change$jscomp$12$$($APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$874$size$$)})}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$editable_select$editable_select$$,
{value:$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$),type:"number","class":"main_ui_workspace_sidebar_options_menus_frame_grid__column-select","input-class":"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",min:1,options:$size_options$jscomp$3$$,placeholder:"Auto","on-change":$handle_change_size$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.toggle-guide"),onClick:$handle_toggle_visibility$jscomp$1$$,icon:$APP.$cljs$core$truth_$$($display$jscomp$2$$)?"shown":"hide"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.remove-guide"),onClick:$on_remove$jscomp$7_props_79238$$,icon:"remove"})]})]}),
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1932$display$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$))?(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-advanced-options",isVisible:$open_QMARK_$jscomp$27$$,onClose:$map__79239__$1_toggle_advanced_options$$,children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1933$square$$,$type$jscomp$666$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_frame_grid__square-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.color"),disableGradient:!0,
disableImage:!0,origin:$APP.$cljs$cst$2057$guides$$,onChange:$handle_change_color$jscomp$2$$,onDetach:$handle_detach_color$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_more_options$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options "+($APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1192$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__selected":""),children:$APP.$app$main$ui$icons$menu$$})]}),$APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1192$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__second-row",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$is_default$jscomp$1$$,onClick:$handle_use_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__btn-options "+($is_default$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_frame_grid__disabled":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.use-default")})}),
(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$is_default$jscomp$1$$,onClick:$handle_set_as_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__btn-options "+($is_default$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_frame_grid__disabled":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.set-default")})})]}):null]}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$type$jscomp$666$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,$type$jscomp$666$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__column-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__orientation-select-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"data-mousetrap-dont-stop":!0,"default-value":$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$),"class":"main_ui_workspace_sidebar_options_menus_frame_grid__orientation-select",options:new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1669$stretch$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.stretch")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$2287$label$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$666$$,$APP.$cljs$cst$1656$row$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.top"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$2287$label$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$666$$,$APP.$cljs$cst$1656$row$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.bottom"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.right")],
null)],null),"on-change":$handle_change$jscomp$12$$($APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$139$type$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__color-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.color"),
disableGradient:!0,disableImage:!0,origin:$APP.$cljs$cst$2057$guides$$,onChange:$handle_change_color$jscomp$2$$,onDetach:$handle_detach_color$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,$type$jscomp$666$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.height"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.width"),className:"main_ui_workspace_sidebar_options_menus_frame_grid__height",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__icon-text",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,$type$jscomp$666$$)?"H":"W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"Auto",
onChange:$handle_change_item_length$$,nillable:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",value:function(){var $or__5025__auto__$jscomp$1206$$=$APP.$cljs$cst$1930$item_length$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1206$$)?$or__5025__auto__$jscomp$1206$$:""}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.gutter"),
className:"main_ui_workspace_sidebar_options_menus_frame_grid__gutter",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__icon "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$666$$,$APP.$cljs$cst$1656$row$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__rotated":""),children:$APP.$app$main$ui$icons$gap_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"0",
onChange:$handle_change$jscomp$12$$($APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1931$gutter$$),nillable:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",value:function(){var $or__5025__auto__$jscomp$1207$$=$APP.$cljs$cst$1931$gutter$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1207$$)?$or__5025__auto__$jscomp$1207$$:0}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.margin"),
className:"main_ui_workspace_sidebar_options_menus_frame_grid__margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__icon "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$666$$,$APP.$cljs$cst$216$column$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__rotated":""),children:$APP.$app$main$ui$icons$grid_margin$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"0",
onChange:$handle_change$jscomp$12$$($APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1929$margin$$),nillable:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",value:function(){var $or__5025__auto__$jscomp$1208$$=$APP.$cljs$cst$1929$margin$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$429$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1208$$)?$or__5025__auto__$jscomp$1208$$:0}()})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_more_options$jscomp$1$$,
disabled:$is_default$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options "+($APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1192$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__selected":""),children:$APP.$app$main$ui$icons$menu$$}),$APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1192$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__more-options",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$handle_use_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__option-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.use-default")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_set_as_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__option-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.set-default")})]}):null]})]}):null]}):null]})});var $app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1243$token_typography_row$$),$app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($main_menu_open_QMARK__props_79302$$){var $ids$jscomp$307$$=$main_menu_open_QMARK__props_79302$$.ids,$type$jscomp$668$$=$main_menu_open_QMARK__props_79302$$.type,$values$jscomp$100$$=$main_menu_open_QMARK__props_79302$$.values,
$applied_tokens$jscomp$24_listbox_id$jscomp$3$$=$main_menu_open_QMARK__props_79302$$.appliedTokens,$file_id$jscomp$415$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$typographies$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$libraries$jscomp$151$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$menu_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$4892$main_menu$$,!0,$cljs$cst$5735$more_options$$,!1],null)),$menu_state$jscomp$4_more_options_open_QMARK_$$=$APP.$cljs$core$_deref$$($menu_state_STAR_$$);$main_menu_open_QMARK__props_79302$$=$APP.$cljs$cst$4892$main_menu$$.$cljs$core$IFn$_invoke$arity$1$($menu_state$jscomp$4_more_options_open_QMARK_$$);$menu_state$jscomp$4_more_options_open_QMARK_$$=$cljs$cst$5735$more_options$$.$cljs$core$IFn$_invoke$arity$1$($menu_state$jscomp$4_more_options_open_QMARK_$$);var $token_dropdown_open_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$token_dropdown_open_QMARK_$$=$APP.$cljs$core$_deref$$($token_dropdown_open_STAR_$$),$applied_token_name$jscomp$2$$=$APP.$cljs$cst$1981$typography$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$24_listbox_id$jscomp$3$$),$current_token_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($applied_token_name$jscomp$2$$),$current_token_name$$=$APP.$cljs$core$_deref$$($current_token_name_STAR_$$),$active_tokens$jscomp$7$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$),$typography_tokens$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$7$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($active_tokens$jscomp$7$$,$APP.$cljs$cst$1981$typography$$)});$applied_tokens$jscomp$24_listbox_id$jscomp$3$$=(0,$APP.$rumext$v2$use_id$$)();var $nodes_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$dropdown_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_options$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography_tokens$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$($typography_tokens$$,null)}),$selected_token_id_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($current_token_name$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$($dropdown_options$jscomp$2$$,
$current_token_name$$)):null}),$selected_token_id$$=$APP.$cljs$core$_deref$$($selected_token_id_STAR_$$),$typography_id$jscomp$10$$=$APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$100$$),$typography_file_id$$=$APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$100$$),$typography$jscomp$37$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography_id$jscomp$10$$),$APP.$rumext$v2$adapt$$($typography_file_id$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$415$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$151$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($typography_id$jscomp$10$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_file_id$$,$file_id$jscomp$415$$):$typography_id$jscomp$10$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$151$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$typography_file_id$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$,$typography_id$jscomp$10$$],null)),$APP.$cljs$cst$1644$file_id$$,$typography_file_id$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($typography_id$jscomp$10$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,$APP.$cljs$cst$1616$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_file_id$$,
$file_id$jscomp$415$$):$typography_id$jscomp$10$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typographies$jscomp$11$$,$typography_id$jscomp$10$$):null}),$multiple_QMARK_$jscomp$10$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79301_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79301_SHARP_$$,$APP.$cljs$cst$1616$multiple$$)},$APP.$cljs$core$vals$$($values$jscomp$100$$)),$apply_token_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$307$$),
$APP.$rumext$v2$adapt$$($typography_tokens$$)],function($id$jscomp$979$$){var $token$jscomp$140$$=$app$main$ui$workspace$sidebar$options$menus$text$find_token_by_id$$($app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($typography_tokens$$),$id$jscomp$979$$);$APP.$cljs$core$reset_BANG_$$($selected_token_id_STAR_$$,$id$jscomp$979$$);$APP.$cljs$core$reset_BANG_$$($token_dropdown_open_STAR_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$307$$,$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1981$typography$$,null],null),null),$APP.$cljs$cst$1136$token$$,$token$jscomp$140$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_typography$$],null)))}),$label$jscomp$48$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$668$$)],
function(){switch($type$jscomp$668$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$668$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.title-selection");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.title-group");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.title")}}),$set_option_ref$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$430$$){var $state$jscomp$1194$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$6$$),{}),$id$jscomp$980$$=$APP.$app$util$dom$get_data$$($node$jscomp$430$$,"id");$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$6$$,$APP.$app$util$object$set_BANG_$$($state$jscomp$1194$$,$id$jscomp$980$$,$node$jscomp$430$$));return function(){var $state__$1$jscomp$59$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$6$$),{});return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$6$$,
$APP.$app$util$object$unset_BANG_$$($state__$1$jscomp$59$$,$id$jscomp$980$$))}}),$toggle_main_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($menu_state_STAR_$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4892$main_menu$$,$APP.$cljs$core$not$$)}),$toggle_more_options$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($menu_state_STAR_$$,
$APP.$cljs$core$update$$,$cljs$cst$5735$more_options$$,$APP.$cljs$core$not$$)}),$toggle_token_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($token_dropdown_open_STAR_$$,$APP.$cljs$core$not$$)}),$on_option_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_token_BANG_$$)],function($event$jscomp$558_id$jscomp$981$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$558_id$jscomp$981$$);
$event$jscomp$558_id$jscomp$981$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$558_id$jscomp$981$$),"id");return $apply_token_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$apply_token_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$558_id$jscomp$981$$):$apply_token_BANG_$$($event$jscomp$558_id$jscomp$981$$)}),$emit_update_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($values$jscomp$100$$)],function($ids__$1$jscomp$30$$,
$attrs$jscomp$179$$){var $updated_attrs$jscomp$2$$=$APP.$cljs$core$select_keys$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$values$jscomp$100$$,$attrs$jscomp$179$$])),$APP.$app$common$types$text$text_node_attrs$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts_v3$v3_update_text_editor_styles$$($APP.$cljs$core$first$$($ids__$1$jscomp$30$$),
$attrs$jscomp$179$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$texts$save_font$$($updated_attrs$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$update_all_attrs$$($ids__$1$jscomp$30$$,$attrs$jscomp$179$$)]))}),$on_change$jscomp$83$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$307$$),$APP.$rumext$v2$adapt$$($emit_update_BANG_$$)],
function($attrs$jscomp$180$$){return $emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$?$emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$307$$,$attrs$jscomp$180$$):$emit_update_BANG_$$($ids$jscomp$307$$,$attrs$jscomp$180$$)}),$on_convert_to_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($values$jscomp$100$$),$APP.$rumext$v2$adapt$$($ids$jscomp$307$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$415$$),$APP.$rumext$v2$adapt$$($emit_update_BANG_$$)],
function(){var $G__79305_set_values_typography__$1$jscomp$3$$=$APP.$cljs$core$select_keys$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$100$$),$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$text$text_font_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_spacing_attrs$$,$APP.$app$common$types$text$text_transform_attrs$$])));$G__79305_set_values_typography__$1$jscomp$3$$=
$app$main$data$workspace$texts$generate_typography_name$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_typography$$,$G__79305_set_values_typography__$1$jscomp$3$$])));var $id$jscomp$982$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79305_set_values_typography__$1$jscomp$3$$,
$APP.$cljs$cst$266$id$$,$id$jscomp$982$$),!1));$G__79305_set_values_typography__$1$jscomp$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1756$typography_ref_id$$,$id$jscomp$982$$,$APP.$cljs$cst$1642$typography_ref_file$$,$file_id$jscomp$415$$],null);return $emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$?$emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$307$$,$G__79305_set_values_typography__$1$jscomp$3$$):$emit_update_BANG_$$($ids$jscomp$307$$,$G__79305_set_values_typography__$1$jscomp$3$$)}),
$handle_detach_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$83$$)],function(){var $G__79306$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1642$typography_ref_file$$,null,$APP.$cljs$cst$1756$typography_ref_id$$,null],null);return $on_change$jscomp$83$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$83$$.$cljs$core$IFn$_invoke$arity$1$($G__79306$$):$on_change$jscomp$83$$($G__79306$$)}),$handle_change_typography$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$37$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$415$$)],function($changes$jscomp$329$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$typography$jscomp$37$$,$changes$jscomp$329$$])),$file_id$jscomp$415$$))}),
$detach_token$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($token_name$jscomp$30$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$30$$,$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1981$typography$$,
null],null),null),$APP.$cljs$cst$4641$shape_ids$$,$ids$jscomp$307$$],null)))}),$expand_stream$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4638$expand_text_more_options$$),$APP.$app$main$store$stream$$)}),$common_props_on_text_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,
function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("INPUT",$APP.$app$util$dom$get_tag_name$$($APP.$app$util$globals$document$$.activeElement))?$APP.$app$util$dom$focus_BANG_$$($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$('[data-itype\x3d"editor"]'):$APP.$goog$dom$getElementByClass$$("public-DraftEditor-content")):null})});$common_props_on_text_blur$$=
{ids:$ids$jscomp$307$$,values:$values$jscomp$100$$,onChange:$on_change$jscomp$83$$,showRecent:!0,onBlur:$common_props_on_text_blur$$};$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($expand_stream$jscomp$1$$,function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($menu_state_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5735$more_options$$,!0)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$2$$)],
function(){return $APP.$cljs$core$reset_BANG_$$($current_token_name_STAR_$$,$applied_token_name$jscomp$2$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$2$$),$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$2$$)],function(){return $APP.$cljs$core$reset_BANG_$$($selected_token_id_STAR_$$,$APP.$cljs$core$truth_$$($applied_token_name$jscomp$2$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$($dropdown_options$jscomp$2$$,
$applied_token_name$jscomp$2$$)):null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_dropdown_open_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($token_dropdown_open_QMARK_$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(0,function(){var $G__79307$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$1$$);return $G__79307$$==null?null:$APP.$app$util$dom$focus_BANG_$$($G__79307$$)}):null});return(0,$APP.$rumext$v2$jsxs$$)("section",
{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-section"),className:"main_ui_workspace_sidebar_options_menus_text__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($main_menu_open_QMARK__props_79302$$),onCollapsed:$toggle_main_menu$$,
title:$label$jscomp$48$$,className:"main_ui_workspace_sidebar_options_menus_text__title-spacing-text",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($typography_tokens$$)!=null&&$APP.$cljs$core$not$$($typography$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),onClick:$toggle_token_dropdown$$,tooltipPlacement:"top-left",icon:"tokens"}):null,$APP.$cljs$core$not$$($typography$jscomp$37$$)&&$APP.$cljs$core$not$$($multiple_QMARK_$jscomp$10$$)&&$APP.$cljs$core$not$$($applied_token_name$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.convert-to-typography"),
onClick:$on_convert_to_typography$$,tooltipPlacement:"top-left",icon:"add"}):null]})})}),$APP.$cljs$core$truth_$$($main_menu_open_QMARK__props_79302$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__element-content",children:[$APP.$cljs$core$truth_$$($app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$?$current_token_name$$:$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$token_typography_row$token_typography_row_STAR_$$,
{tokenName:$current_token_name$$,detachToken:$detach_token$jscomp$5$$,activeTokens:$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($typography_tokens$$)}):$APP.$cljs$core$truth_$$($typography$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$typography_entry$$,{"file-id":$typography_file_id$$,typography:$typography$jscomp$37$$,"local?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_file_id$$,$file_id$jscomp$415$$),
"on-detach":$handle_detach_typography$$,"on-change":$handle_change_typography$$}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,$APP.$cljs$cst$1616$multiple$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-typography",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.multiple-typography")}),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.multiple-typography-tooltip"),onClick:$handle_detach_typography$$,icon:"detach"})]}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-align-options",
children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$text_align_options_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$grow_options_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),"data-testid":"text-align-options-button",
onClick:$toggle_more_options$jscomp$2$$,icon:"menu"})]}),$APP.$cljs$core$truth_$$($menu_state$jscomp$4_more_options_open_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-decoration-options",children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$vertical_align_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$text_decoration_options_STAR_$$,
{...$common_props_on_text_blur$$,tokenApplied:$current_token_name$$}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$text_direction_options_STAR_$$,$common_props_on_text_blur$$)]}):null]}):null,$APP.$cljs$core$truth_$$($app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$?$token_dropdown_open_QMARK_$$:$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$shared$searchable_options_dropdown$searchable_options_dropdown_STAR_$$,
{onClick:$on_option_click$jscomp$3$$,id:$applied_tokens$jscomp$24_listbox_id$jscomp$3$$,options:$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($dropdown_options$jscomp$2$$),selected:$selected_token_id$$,align:"right",ref:$set_option_ref$jscomp$4$$}):null]})},function($n_props$jscomp$1$$,$o_props$jscomp$1$$){return $n_props$jscomp$1$$.ids===$o_props$jscomp$1$$.ids&&$n_props$jscomp$1$$.appliedTokens===$o_props$jscomp$1$$.appliedTokens&&$n_props$jscomp$1$$.values===$o_props$jscomp$1$$.values});var $app$main$ui$workspace$sidebar$options$shapes$multiple$type__GT_read_mode$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$1417$circle$$,$APP.$cljs$cst$1613$svg_raw$$,$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,
$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,
$cljs$cst$5740$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$342$children$$,
$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$342$children$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,
$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$342$children$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,
$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,
$cljs$cst$5740$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,
$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,
$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,
$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,
$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,
$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$cljs$cst$5740$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,
$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1588$text$$,$cljs$cst$5740$ignore$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$1588$text$$])]),$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5736$constraint$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5737$layout_item$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2071$layout_container$$,
$cljs$cst$5738$measure$$,$APP.$cljs$cst$1870$exports$$,$cljs$cst$5739$layer$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1588$text$$],[$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$,$app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$,
$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$,$app$main$ui$workspace$sidebar$options$menus$blur$blur_attrs$$,$app$main$ui$workspace$sidebar$options$menus$shadow$shadow_attrs$$,$APP.$app$common$types$text$text_all_attrs$$]),$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1650$offset_x$$,$APP.$cljs$cst$1651$offset_y$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1652$spread$$,$APP.$cljs$cst$1620$hidden$$],null),$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1620$hidden$$],null),$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$=
function $app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$($shapes$jscomp$216$$,$objects$jscomp$793$$,$attr_group$$){function $merge_token_values$$($acc$jscomp$164$$,$shape_attrs$jscomp$1$$,$applied_tokens$jscomp$27$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__79324_SHARP_$$,$p2__79325_SHARP_$$){return $merge_shape_attr$$($p1__79324_SHARP_$$,$applied_tokens$jscomp$27$$,$p2__79325_SHARP_$$)},$acc$jscomp$164$$,$shape_attrs$jscomp$1$$)}function $merge_shape_attr$$($acc$jscomp$163$$,
$applied_tokens$jscomp$26$$,$shape_attr$jscomp$2_token_attrs$jscomp$4$$){$shape_attr$jscomp$2_token_attrs$jscomp$4$$=$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$2_token_attrs$jscomp$4$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__79322_SHARP_$$,$p2__79323_SHARP_$$){var $new_val$jscomp$inline_8951$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$26$$,$p2__79323_SHARP_$$),
$existing$jscomp$inline_8952$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__79322_SHARP_$$,$p2__79323_SHARP_$$,$cljs$cst$5741$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_shapes_DOT_multiple_SLASH_not_found$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($existing$jscomp$inline_8952$$,$cljs$cst$5741$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_shapes_DOT_multiple_SLASH_not_found$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79322_SHARP_$$,
$p2__79323_SHARP_$$,$new_val$jscomp$inline_8951$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($existing$jscomp$inline_8952$$,$new_val$jscomp$inline_8951$$)?$p1__79322_SHARP_$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79322_SHARP_$$,$p2__79323_SHARP_$$,$APP.$cljs$cst$1616$multiple$$)},$acc$jscomp$163$$,$shape_attr$jscomp$2_token_attrs$jscomp$4$$)}function $merge_attrs$$($v1$jscomp$41$$,$v2$jscomp$33$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,
$APP.$cljs$cst$1654$shadow$$)?$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v1$jscomp$41$$,$v2$jscomp$33$$],null),$attrs$jscomp$181$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_eq$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_sel$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,$APP.$cljs$cst$1653$blur$$)?$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v1$jscomp$41$$,$v2$jscomp$33$$],null),$attrs$jscomp$181$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_eq$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_sel$$):$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v1$jscomp$41$$,$v2$jscomp$33$$],null),$attrs$jscomp$181$$)}var $attrs$jscomp$181$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$.$cljs$core$IFn$_invoke$arity$1$($attr_group$$):$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$($attr_group$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$){var $ids$jscomp$308$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,
0,null),$values$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,1,null);$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,2,null);var $map__79334__$1_new_values$jscomp$2_shape_values__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$);
$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,$APP.$cljs$cst$266$id$$);var $editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,$APP.$cljs$cst$139$type$$),$applied_tokens$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,
$APP.$cljs$cst$1873$applied_tokens$$),$content_attrs_read_mode$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$options$shapes$multiple$type__GT_read_mode$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$,$attr_group$$],null));$editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$)),$attrs$jscomp$181$$);switch($content_attrs_read_mode$$ instanceof $APP.$cljs$core$Keyword$$?$content_attrs_read_mode$$.$fqn$:null){case "ignore":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ids$jscomp$308$$,$values$jscomp$101$$],null);case "shape":var $shape_values$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__79326_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__79326_SHARP_$$,null],null)}),$editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,$cljs$cst$5738$measure$$)?$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$):
$APP.$cljs$core$select_keys$$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,$editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$)]));$map__79334__$1_new_values$jscomp$2_shape_values__$1$$=function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,$cljs$cst$5739$layer$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape_values$$,$APP.$cljs$cst$1620$hidden$$,function($p1__79327_SHARP_$$){return $p1__79327_SHARP_$$==null?!1:$p1__79327_SHARP_$$}):$shape_values$$}();
$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$=$merge_token_values$$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,$editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$,$applied_tokens$jscomp$28$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$308$$,$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$),$merge_attrs$$($values$jscomp$101$$,
$map__79334__$1_new_values$jscomp$2_shape_values__$1$$),$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$],null);case "text":return $editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$=$APP.$cljs$core$select_keys$$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,$attrs$jscomp$181$$),$content_attrs_read_mode$$=$app$common$attrs$get_text_attrs_multi$$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,$attrs$jscomp$181$$),$map__79334__$1_new_values$jscomp$2_shape_values__$1$$=
$merge_attrs$$($merge_attrs$$($values$jscomp$101$$,$editable_attrs_shape_attrs$jscomp$2_type$jscomp$669$$),$content_attrs_read_mode$$),$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$=$merge_token_values$$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,$content_attrs_read_mode$$,$applied_tokens$jscomp$28$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$308$$,
$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$),$map__79334__$1_new_values$jscomp$2_shape_values__$1$$,$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$],null);case "children":return $children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79328_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$793$$,$p1__79328_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$2$($map__79334__$1_new_values$jscomp$2_shape_values__$1$$,
$APP.$cljs$core$PersistentVector$EMPTY$$)),$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$.$cljs$core$IFn$_invoke$arity$3$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,$objects$jscomp$793$$,$attr_group$$):$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$($children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$,
$objects$jscomp$793$$,$attr_group$$),$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$,0,null),$map__79334__$1_new_values$jscomp$2_shape_values__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$,1,null),$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$,
2,null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($ids$jscomp$308$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$300_new_ids$jscomp$1_new_token_acc_p__79329_token_acc$$])),$merge_attrs$$($values$jscomp$101$$,$map__79334__$1_new_values$jscomp$2_shape_values__$1$$),$id$jscomp$983_p__79330_tokens$jscomp$54_vec__79337$$],null);default:return $APP.$cljs$core$PersistentVector$EMPTY$$}},
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$shapes$jscomp$216$$)},$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$=function($f$jscomp$752$$){var $mem$jscomp$1$$=new $APP.$module$app$common$weak$impl_weak_map$$.$WeakEqMap$({hash:$APP.$cljs$core$hash$$,equals:$APP.$cljs$core$_EQ_$$});return function(){function $G__45422$$($var_args$jscomp$919$$){var $G__45423__i_args$jscomp$235$$=
null;if(arguments.length>0){$G__45423__i_args$jscomp$235$$=0;for(var $G__45423__a$$=Array(arguments.length-0);$G__45423__i_args$jscomp$235$$<$G__45423__a$$.length;)$G__45423__a$$[$G__45423__i_args$jscomp$235$$]=arguments[$G__45423__i_args$jscomp$235$$+0],++$G__45423__i_args$jscomp$235$$;$G__45423__i_args$jscomp$235$$=new $APP.$cljs$core$IndexedSeq$$($G__45423__a$$,0,null)}return $G__45422__delegate$$.call(this,$G__45423__i_args$jscomp$235$$)}function $G__45422__delegate$$($args$jscomp$234$$){var $ret$jscomp$144_v$jscomp$513$$=
$mem$jscomp$1$$.get($args$jscomp$234$$);return void 0===$ret$jscomp$144_v$jscomp$513$$?($ret$jscomp$144_v$jscomp$513$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$752$$,$args$jscomp$234$$),$mem$jscomp$1$$.set($args$jscomp$234$$,$ret$jscomp$144_v$jscomp$513$$),$ret$jscomp$144_v$jscomp$513$$):$ret$jscomp$144_v$jscomp$513$$}$G__45422$$.$cljs$lang$maxFixedArity$=0;$G__45422$$.$cljs$lang$applyTo$=function($arglist__45424_args$jscomp$236$$){$arglist__45424_args$jscomp$236$$=$APP.$cljs$core$seq$$($arglist__45424_args$jscomp$236$$);
return $G__45422__delegate$$($arglist__45424_args$jscomp$236$$)};$G__45422$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__45422__delegate$$;return $G__45422$$}()}($app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$),$app$main$ui$workspace$sidebar$options$shapes$multiple$options_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($page_id$jscomp$428_props_79343$$){var $shapes_with_children$jscomp$2$$=$page_id$jscomp$428_props_79343$$.shapesWithChildren,$shapes$jscomp$217$$=
$page_id$jscomp$428_props_79343$$.shapes,$file_id$jscomp$416$$=$page_id$jscomp$428_props_79343$$.fileId,$libraries$jscomp$152$$=$page_id$jscomp$428_props_79343$$.libraries;$page_id$jscomp$428_props_79343$$=$page_id$jscomp$428_props_79343$$.pageId;var $shape_ids$jscomp$108$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$217$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,
$shapes$jscomp$217$$)}),$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$108$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($shape_ids$jscomp$108$$)});$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$);var $is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$3$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$108$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($shape_ids$jscomp$108$$)});$is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$3$$);var $is_grid_parent_QMARK_$jscomp$4_is_grid_parent_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$108$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($shape_ids$jscomp$108$$)});$is_grid_parent_QMARK_$jscomp$4_is_grid_parent_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($is_grid_parent_QMARK_$jscomp$4_is_grid_parent_ref$jscomp$3$$);var $has_flex_layout_container_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$shapes$jscomp$217$$),$all_layout_child_QMARK__all_layout_child_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$108$$)],
function(){return $app$main$refs$all_layout_child_QMARK_$$($shape_ids$jscomp$108$$)});$all_layout_child_QMARK__all_layout_child_ref$$=$APP.$rumext$v2$deref$$($all_layout_child_QMARK__all_layout_child_ref$$);var $all_flex_layout_container_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$217$$)],function(){return $APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$shapes$jscomp$217$$)}),$show_caps_QMARK_$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$217$$)],function(){return $APP.$cljs$core$some$$(function($p1__79342_SHARP_$$){return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__79342_SHARP_$$)&&$APP.$app$common$types$path$shape_with_open_path_QMARK_$$($p1__79342_SHARP_$$)},$shapes$jscomp$217$$)}),$has_text_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$217$$)],
function(){return $APP.$cljs$core$some$$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$shapes$jscomp$217$$)}),$objects$jscomp$795$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes_with_children$jscomp$2$$)],function(){var $objects$jscomp$796$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$shapes_with_children$jscomp$2$$);return $APP.$cljs$core$reduce_kv$$(function($objects__$1$jscomp$39$$,$id$jscomp$984$$,
$JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$){a:{for(;;){var $parent$jscomp$inline_8958_parent_id$jscomp$inline_8957$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$);$parent$jscomp$inline_8958_parent_id$jscomp$inline_8957$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$39$$,$parent$jscomp$inline_8958_parent_id$jscomp$inline_8957$$);if($JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$==
null||$APP.$cljs$core$contains_QMARK_$$($shape_ids$jscomp$108$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$))){$JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$=!1;break a}if($APP.$app$common$files$helpers$bool_shape_QMARK_$$($parent$jscomp$inline_8958_parent_id$jscomp$inline_8957$$)){$JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$=!0;break a}$JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$=
$parent$jscomp$inline_8958_parent_id$jscomp$inline_8957$$}$JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$=void 0}return $JSCompiler_inline_result$jscomp$1834_object$jscomp$40_shape$jscomp$inline_8956$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$39$$,$id$jscomp$984$$):$objects__$1$jscomp$39$$},$objects$jscomp$796$$,$objects$jscomp$796$$)}),$layer_tokens_vec__79345$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,
$objects$jscomp$795$$,$cljs$cst$5739$layer$$),$layer_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_tokens_vec__79345$$,0,null),$layer_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_tokens_vec__79345$$,1,null);$layer_tokens_vec__79345$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_tokens_vec__79345$$,2,null);var $text_tokens_vec__79348$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,
$objects$jscomp$795$$,$APP.$cljs$cst$1588$text$$),$text_ids$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens_vec__79348$$,0,null),$text_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens_vec__79348$$,1,null);$text_tokens_vec__79348$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens_vec__79348$$,2,null);var $constraint_values$jscomp$3_vec__79351$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,
$objects$jscomp$795$$,$cljs$cst$5736$constraint$$),$constraint_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$3_vec__79351$$,0,null);$constraint_values$jscomp$3_vec__79351$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$3_vec__79351$$,1,null);var $fill_tokens_vec__79354$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,$objects$jscomp$795$$,$APP.$cljs$cst$1403$fill$$),$fill_ids$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens_vec__79354$$,0,null),$fill_values$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens_vec__79354$$,1,null);$fill_tokens_vec__79354$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens_vec__79354$$,2,null);var $shadow_values_vec__79357$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,$objects$jscomp$795$$,$APP.$cljs$cst$1654$shadow$$),$shadow_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shadow_values_vec__79357$$,
0,null);$shadow_values_vec__79357$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shadow_values_vec__79357$$,1,null);var $blur_values_vec__79360$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,$objects$jscomp$795$$,$APP.$cljs$cst$1653$blur$$),$blur_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values_vec__79360$$,0,null);$blur_values_vec__79360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values_vec__79360$$,
1,null);var $stroke_tokens_vec__79363$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,$objects$jscomp$795$$,$APP.$cljs$cst$2903$stroke$$),$stroke_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens_vec__79363$$,0,null),$stroke_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens_vec__79363$$,1,null);$stroke_tokens_vec__79363$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens_vec__79363$$,
2,null);var $exports_values_vec__79366$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,$objects$jscomp$795$$,$APP.$cljs$cst$1870$exports$$),$exports_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($exports_values_vec__79366$$,0,null);$exports_values_vec__79366$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($exports_values_vec__79366$$,1,null);var $layout_container_tokens_vec__79369$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,
$objects$jscomp$795$$,$APP.$cljs$cst$2071$layout_container$$),$layout_container_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_container_tokens_vec__79369$$,0,null),$layout_container_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_container_tokens_vec__79369$$,1,null);$layout_container_tokens_vec__79369$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_container_tokens_vec__79369$$,2,null);var $layout_item_tokens_vec__79372$$=
$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$217$$,$objects$jscomp$795$$,$cljs$cst$5737$layout_item$$),$layout_item_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_tokens_vec__79372$$,0,null),$layout_item_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_tokens_vec__79372$$,1,null);$layout_item_tokens_vec__79372$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_tokens_vec__79372$$,
2,null);var $components$jscomp$24$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$217$$)],function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,$shapes$jscomp$217$$))}),$workspace_modifiers$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$shapes__$1$jscomp$36$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($workspace_modifiers$$),
$APP.$rumext$v2$adapt$$($shapes$jscomp$217$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($shape$jscomp$1024$$){var $modifiers$jscomp$112_shape_id$jscomp$163$$=$shape$jscomp$1024$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1024$$,$APP.$cljs$cst$266$id$$);$modifiers$jscomp$112_shape_id$jscomp$163$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($workspace_modifiers$$,
$modifiers$jscomp$112_shape_id$jscomp$163$$),$APP.$cljs$cst$1810$modifiers$$);return $APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1024$$,$modifiers$jscomp$112_shape_id$jscomp$163$$)}),$shapes$jscomp$217$$)}),$measure_tokens_vec__79375$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$($shapes__$1$jscomp$36$$,$objects$jscomp$795$$,$cljs$cst$5738$measure$$),$measure_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_tokens_vec__79375$$,
0,null),$measure_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_tokens_vec__79375$$,1,null);$measure_tokens_vec__79375$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_tokens_vec__79375$$,2,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_shapes_multiple__options",children:[$APP.$cljs$core$empty_QMARK_$$($layer_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,
{type:$APP.$cljs$cst$1616$multiple$$,ids:$layer_ids$$,appliedTokens:$layer_tokens_vec__79345$$,values:$layer_values$jscomp$3$$}),$APP.$cljs$core$empty_QMARK_$$($measure_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{type:$APP.$cljs$cst$1616$multiple$$,ids:$measure_ids$$,values:$measure_values$jscomp$3$$,appliedTokens:$measure_tokens_vec__79375$$,shapes:$shapes__$1$jscomp$36$$}),$components$jscomp$24$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,
{shapes:$components$jscomp$24$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$APP.$cljs$cst$1616$multiple$$,ids:$layout_container_ids$$,values:$layout_container_values$jscomp$3$$,"applied-tokens":$layout_container_tokens_vec__79369$$,multiple:!0}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$)?$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$:
$has_flex_layout_container_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,{type:$APP.$cljs$cst$1616$multiple$$,ids:$layout_item_ids$$,"is-layout-child?":$all_layout_child_QMARK__all_layout_child_ref$$,"is-layout-container?":$all_flex_layout_container_QMARK_$$,"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$3$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$4_is_grid_parent_ref$jscomp$3$$,"applied-tokens":$layout_item_tokens_vec__79372$$,
values:$layout_item_values$jscomp$3$$}):null,$APP.$cljs$core$empty_QMARK_$$($constraint_ids$$)||$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$constraint_ids$$,values:$constraint_values$jscomp$3_vec__79351$$}),$APP.$cljs$core$empty_QMARK_$$($text_ids$jscomp$7$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$,{type:$APP.$cljs$cst$1616$multiple$$,
ids:$text_ids$jscomp$7$$,values:$text_values$jscomp$3$$,appliedTokens:$text_tokens_vec__79348$$}),$APP.$cljs$core$empty_QMARK_$$($fill_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{type:$APP.$cljs$cst$1616$multiple$$,ids:$fill_ids$$,values:$fill_values$$,appliedTokens:$fill_tokens_vec__79354$$}),$APP.$cljs$core$empty_QMARK_$$($stroke_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,
{type:$APP.$cljs$cst$1616$multiple$$,ids:$stroke_ids$$,showCaps:$show_caps_QMARK_$$,values:$stroke_values$jscomp$3$$,disableStrokeStyle:$has_text_QMARK_$$,appliedTokens:$stroke_tokens_vec__79363$$}),$APP.$cljs$core$empty_QMARK_$$($shapes__$1$jscomp$36$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{fileId:$file_id$jscomp$416$$,type:$APP.$cljs$cst$1616$multiple$$,shapes:$APP.$cljs$core$vals$$($objects$jscomp$795$$),libraries:$libraries$jscomp$152$$}),
$APP.$cljs$core$empty_QMARK_$$($shadow_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{type:$APP.$cljs$cst$1616$multiple$$,ids:$shadow_ids$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow_values_vec__79357$$,$APP.$cljs$cst$1654$shadow$$)}),$APP.$cljs$core$empty_QMARK_$$($blur_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{type:$APP.$cljs$cst$1616$multiple$$,
ids:$blur_ids$$,values:$blur_values_vec__79360$$}),$APP.$cljs$core$empty_QMARK_$$($exports_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$APP.$cljs$cst$1616$multiple$$,ids:$exports_ids$$,shapes:$shapes__$1$jscomp$36$$,values:$exports_values_vec__79366$$,pageId:$page_id$jscomp$428_props_79343$$,fileId:$file_id$jscomp$416$$})]})},function($new_props$jscomp$6$$,$old_props$jscomp$5$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$6$$.shapes,
$old_props$jscomp$5$$.shapes)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$6$$.shapesWithChildren,$old_props$jscomp$5$$.shapesWithChildren)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$6$$.pageId,$old_props$jscomp$5$$.pageId)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$6$$.fileId,$old_props$jscomp$5$$.fileId)});var $app$main$ui$workspace$sidebar$options$shapes$group$options_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_79381_type$jscomp$671$$){var $shapes_with_children$jscomp$3$$=$props_79381_type$jscomp$671$$.shapesWithChildren,$file_id$jscomp$417$$=$props_79381_type$jscomp$671$$.fileId,$libraries$jscomp$153$$=$props_79381_type$jscomp$671$$.libraries,$page_id$jscomp$429$$=$props_79381_type$jscomp$671$$.pageId,$shape$jscomp$1025$$=$props_79381_type$jscomp$671$$.shape,
$id$jscomp$985$$=$shape$jscomp$1025$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1025$$,$APP.$cljs$cst$266$id$$);$props_79381_type$jscomp$671$$=$shape$jscomp$1025$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1025$$,$APP.$cljs$cst$139$type$$);var $ids$jscomp$309$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$985$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$985$$],null)}),$shapes$jscomp$218$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1025$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1025$$],null)}),$applied_tokens$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1025$$,$APP.$cljs$cst$1873$applied_tokens$$),$objects$jscomp$797$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes_with_children$jscomp$3$$)],
function(){return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$shapes_with_children$jscomp$3$$)}),$layout_container_values$jscomp$4$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1025$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$svg_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1025$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$],
null)),$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$309$$)}),$is_layout_child_QMARK_$jscomp$5$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$);$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$309$$)});$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$);var $is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$309$$)}),$is_grid_parent_QMARK_$jscomp$5$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$);$is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1025$$);var $parents$jscomp$16_parents_by_ids_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$309$$)});$parents$jscomp$16_parents_by_ids_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($parents$jscomp$16_parents_by_ids_ref$jscomp$3$$);var $measure_values$jscomp$4_vec__79386$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$cljs$cst$5738$measure$$),$measure_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_values$jscomp$4_vec__79386$$,0,null);$measure_values$jscomp$4_vec__79386$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_values$jscomp$4_vec__79386$$,1,null);var $layer_values$jscomp$4_vec__79389$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$cljs$cst$5739$layer$$),$layer_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_values$jscomp$4_vec__79389$$,0,null);$layer_values$jscomp$4_vec__79389$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_values$jscomp$4_vec__79389$$,
1,null);var $constraint_values$jscomp$4_vec__79392$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$cljs$cst$5736$constraint$$),$constraint_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$4_vec__79392$$,0,null);$constraint_values$jscomp$4_vec__79392$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$4_vec__79392$$,1,null);var $fill_tokens$jscomp$1_vec__79395$$=
$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$APP.$cljs$cst$1403$fill$$),$fill_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens$jscomp$1_vec__79395$$,0,null),$fill_values$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens$jscomp$1_vec__79395$$,1,null);$fill_tokens$jscomp$1_vec__79395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens$jscomp$1_vec__79395$$,
2,null);var $shadow_ids$jscomp$1_vec__79398$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$APP.$cljs$cst$1654$shadow$$);$shadow_ids$jscomp$1_vec__79398$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shadow_ids$jscomp$1_vec__79398$$,0,null);var $blur_values$jscomp$1_vec__79401$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$APP.$cljs$cst$1653$blur$$),$blur_ids$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values$jscomp$1_vec__79401$$,0,null);$blur_values$jscomp$1_vec__79401$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values$jscomp$1_vec__79401$$,1,null);var $stroke_tokens$jscomp$1_vec__79404$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$APP.$cljs$cst$2903$stroke$$),$stroke_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens$jscomp$1_vec__79404$$,
0,null),$stroke_values$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens$jscomp$1_vec__79404$$,1,null);$stroke_tokens$jscomp$1_vec__79404$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens$jscomp$1_vec__79404$$,2,null);var $text_tokens$jscomp$1_vec__79407$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$APP.$cljs$cst$1588$text$$),$text_ids$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens$jscomp$1_vec__79407$$,
0,null),$text_values$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens$jscomp$1_vec__79407$$,1,null);$text_tokens$jscomp$1_vec__79407$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens$jscomp$1_vec__79407$$,2,null);var $layout_item_values$jscomp$4_vec__79410$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$218$$,$objects$jscomp$797$$,$cljs$cst$5737$layout_item$$),$layout_item_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_values$jscomp$4_vec__79410$$,
0,null);$layout_item_values$jscomp$4_vec__79410$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_values$jscomp$4_vec__79410$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_shapes_group__options",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{type:$props_79381_type$jscomp$671$$,ids:$layer_ids$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$29$$,values:$layer_values$jscomp$4_vec__79389$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{type:$props_79381_type$jscomp$671$$,ids:$measure_ids$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$29$$,values:$measure_values$jscomp$4_vec__79386$$,shapes:$shapes$jscomp$218$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu$$,{type:$props_79381_type$jscomp$671$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1025$$)],null),values:$layout_container_values$jscomp$4$$,"applied-tokens":$applied_tokens$jscomp$29$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$815$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$309$$),1);return $and__5023__auto__$jscomp$815$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$5$$)?$is_grid_parent_QMARK_$jscomp$5$$:$is_layout_child_QMARK_$jscomp$5$$:
$and__5023__auto__$jscomp$815$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options$$,{shape:$APP.$cljs$core$first$$($parents$jscomp$16_parents_by_ids_ref$jscomp$3$$),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$16_parents_by_ids_ref$jscomp$3$$),$APP.$cljs$core$first$$($ids$jscomp$309$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu$$,
{type:$props_79381_type$jscomp$671$$,ids:$layout_item_ids$jscomp$1$$,"is-layout-child?":!0,"is-layout-container?":!1,"is-flex-parent?":$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$,"is-grid-parent?":$is_grid_parent_QMARK_$jscomp$5$$,"applied-tokens":$applied_tokens$jscomp$29$$,values:$layout_item_values$jscomp$4_vec__79410$$}):null,!$is_layout_child_QMARK_$jscomp$5$$||$is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,
{ids:$constraint_ids$jscomp$1$$,values:$constraint_values$jscomp$4_vec__79392$$}):null,$APP.$cljs$core$empty_QMARK_$$($fill_ids$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{type:$props_79381_type$jscomp$671$$,ids:$fill_ids$jscomp$1$$,values:$fill_values$jscomp$1$$,appliedTokens:$fill_tokens$jscomp$1_vec__79395$$}),$APP.$cljs$core$empty_QMARK_$$($stroke_ids$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,
{type:$props_79381_type$jscomp$671$$,ids:$stroke_ids$jscomp$1$$,values:$stroke_values$jscomp$4$$,appliedTokens:$stroke_tokens$jscomp$1_vec__79404$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{type:$props_79381_type$jscomp$671$$,shapes:$APP.$cljs$core$vals$$($objects$jscomp$797$$),fileId:$file_id$jscomp$417$$,libraries:$libraries$jscomp$153$$}),$APP.$cljs$core$empty_QMARK_$$($shadow_ids$jscomp$1_vec__79398$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,
{ids:$ids$jscomp$309$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1025$$,$APP.$cljs$cst$1654$shadow$$),type:$props_79381_type$jscomp$671$$}),$APP.$cljs$core$empty_QMARK_$$($blur_ids$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{type:$props_79381_type$jscomp$671$$,ids:$blur_ids$jscomp$1$$,values:$blur_values$jscomp$1_vec__79401$$}),$APP.$cljs$core$empty_QMARK_$$($text_ids$jscomp$8$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$,
{type:$props_79381_type$jscomp$671$$,ids:$text_ids$jscomp$8$$,values:$text_values$jscomp$4$$,appliedTokens:$text_tokens$jscomp$1_vec__79407$$}),$APP.$cljs$core$empty_QMARK_$$($svg_values$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$309$$,values:$svg_values$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79381_type$jscomp$671$$,ids:$ids$jscomp$309$$,
shapes:$shapes$jscomp$218$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1025$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$429$$,fileId:$file_id$jscomp$417$$})]})});var $app$main$ui$workspace$sidebar$options$shapes$svg_raw$svg_elements$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,13,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2696$textPath$$,null,$APP.$cljs$cst$219$symbol$$,null,$APP.$cljs$cst$1417$circle$$,null,$APP.$cljs$cst$1744$g$$,null,$APP.$cljs$cst$209$line$$,null,$APP.$cljs$cst$1538$svg$$,null,$APP.$cljs$cst$2730$ellipse$$,null,$APP.$cljs$cst$1612$image$$,null,$APP.$cljs$cst$2743$polyline$$,null,$APP.$cljs$cst$1611$rect$$,
null,$APP.$cljs$cst$2750$polygon$$,null,$APP.$cljs$cst$1588$text$$,null],null),null);var $app$main$ui$workspace$sidebar$options$shape_options_STAR_$$=$rumext$v2$throttle$$(function($props_79430$$){var $shapes_with_children$jscomp$4$$=$props_79430$$.shapesWithChildren,$shapes$jscomp$223$$=$props_79430$$.shapes,$file_id$jscomp$423$$=$props_79430$$.fileId,$libraries$jscomp$156$$=$props_79430$$.libraries,$page_id$jscomp$435$$=$props_79430$$.pageId;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($props_79430$$.selected))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$single_shape_options_STAR_$$,
{pageId:$page_id$jscomp$435$$,fileId:$file_id$jscomp$423$$,libraries:$libraries$jscomp$156$$,shape:$APP.$cljs$core$first$$($shapes$jscomp$223$$),shapesWithChildren:$shapes_with_children$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$multiple$options_STAR_$$,{shapesWithChildren:$shapes_with_children$jscomp$4$$,shapes:$shapes$jscomp$223$$,pageId:$page_id$jscomp$435$$,fileId:$file_id$jscomp$423$$,libraries:$libraries$jscomp$156$$})},200),$app$main$ui$workspace$sidebar$options$options_tabs$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.design"),$APP.$cljs$cst$266$id$$,"design"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.prototype"),$APP.$cljs$cst$266$id$$,"prototype"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.inspect"),$APP.$cljs$cst$266$id$$,"inspect"],null)],null),$app$main$ui$workspace$sidebar$options$options_toolbox_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($objects$jscomp$801_objects_ref_props_79501$$){var $on_expand$jscomp$3$$=$objects$jscomp$801_objects_ref_props_79501$$.onExpand,$on_change_section$jscomp$2$$=$objects$jscomp$801_objects_ref_props_79501$$.onChangeSection,
$selected$jscomp$177$$=$objects$jscomp$801_objects_ref_props_79501$$.selected,$file_id$jscomp$427$$=$objects$jscomp$801_objects_ref_props_79501$$.fileId,$section$jscomp$30$$=$objects$jscomp$801_objects_ref_props_79501$$.section,$page_id$jscomp$439$$=$objects$jscomp$801_objects_ref_props_79501$$.pageId;$objects$jscomp$801_objects_ref_props_79501$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$439$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$427$$)],
function(){return $app$main$ui$workspace$sidebar$options$make_page_objects_ref$$($file_id$jscomp$427$$,$page_id$jscomp$439$$)});$objects$jscomp$801_objects_ref_props_79501$$=$APP.$rumext$v2$deref$$($objects$jscomp$801_objects_ref_props_79501$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$options_content_STAR_$$,{objects:$objects$jscomp$801_objects_ref_props_79501$$,selected:$selected$jscomp$177$$,fileId:$file_id$jscomp$427$$,pageId:$page_id$jscomp$439$$,section:$section$jscomp$30$$,
onChangeSection:$on_change_section$jscomp$2$$,onExpand:$on_expand$jscomp$3$$})});var $app$main$ui$workspace$sidebar$sitemap$ref_COLON_file_with_pages$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($map__79466__$1_p__79465$$){$map__79466__$1_p__79465$$=$APP.$cljs$core$__destructure_map$$($map__79466__$1_p__79465$$);var $data$jscomp$492$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79466__$1_p__79465$$,$APP.$cljs$cst$142$data$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__79466__$1_p__79465$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2228$pages$$,$APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$492$$))},$APP.$app$main$refs$file$$,$APP.$cljs$core$_EQ_$$);var $app$main$ui$workspace$sidebar$versions$versions$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4469$workspace_versions$$,$APP.$app$main$store$state$$);var $app$main$data$workspace$tokens$remapping$remap_tokens_79581$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_79594$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.tokens.remapping",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$main$ui$workspace$tokens$management$context_menu$shape_attribute_actions_map$$=function(){function $line_height$jscomp$21$$($p1__79641_SHARP_$$){return $app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1765$line_height$$,null],null),null),"Line Height",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79641_SHARP_$$,$APP.$cljs$cst$4646$on_update_shape$$,
$APP.$app$main$data$workspace$tokens$application$update_line_height$$))}var $stroke_width$jscomp$10$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,null],null),null),"Stroke Width"),$font_size$jscomp$13$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1760$font_size$$,null],null),null),"Font Size"),$letter_spacing$jscomp$8$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1766$letter_spacing$$,null],null),null),"Letter Spacing"),$font_family$jscomp$10$$=
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1758$font_family$$,null],null),null),"Font Family"),$text_case$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1979$text_case$$,null],null),null),"Text Case"),$text_decoration$jscomp$6$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,null],null),null),"Text Decoration"),$font_weight$jscomp$12$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1761$font_weight$$,null],null),null),"Font Weight"),$typography$jscomp$39$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1981$typography$$,null],null),null),"Typography"),$border_radius$$=
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$5785$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1646$r1$$,"Top Left",$APP.$cljs$cst$1647$r2$$,"Top Right",$APP.$cljs$cst$1649$r4$$,"Bottom Left",$APP.$cljs$cst$1648$r3$$,"Bottom Right"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.radius"),
$cljs$cst$5786$on_update_shape_all$$,$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_radius_for_corners$$],null));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1978$number$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,
$APP.$cljs$cst$1979$text_case$$,$APP.$cljs$cst$1980$dimensions$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1981$typography$$,$APP.$cljs$cst$1768$text_decoration$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1983$spacing$$],[$line_height$jscomp$21$$,$app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1788$rotation$$,null],null),null),"Rotation"),function($context_data$jscomp$2$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null),"Fill",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($context_data$jscomp$2$$,
$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_fill$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.color")]))),$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null),
"Stroke",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data$jscomp$2$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$)))},function($JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$){var $JSCompiler_temp_const$jscomp$1839$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1838$$=$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1788$rotation$$,null],null),null),"Rotation",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_rotation$$));$JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$=$line_height$jscomp$21$$($JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$);
$JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$)?$JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$:null;return $JSCompiler_temp_const$jscomp$1839$$.call($APP.$cljs$core$concat$$,$JSCompiler_temp_const$jscomp$1838$$,$JSCompiler_inline_result$jscomp$1841_context_data$jscomp$3_line_height__$1$jscomp$inline_8984$$)},
$font_size$jscomp$13$$,$font_weight$jscomp$12$$,$text_case$$,function($context_data$jscomp$4$$){return $app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$($context_data$jscomp$4$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,"Sizing",$cljs$cst$5791$submenu$$,$APP.$cljs$cst$1977$sizing$$],null)],null):null,$APP.$cljs$core$seq$$($app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$($context_data$jscomp$4$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"Spacing",$cljs$cst$5791$submenu$$,$APP.$cljs$cst$1983$spacing$$],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],null),$APP.$cljs$core$seq$$($border_radius$$($context_data$jscomp$4$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"Border Radius",$cljs$cst$5791$submenu$$,$APP.$cljs$cst$1982$border_radius$$],null)],null):null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1472$separator$$],null),$stroke_width$jscomp$10$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data$jscomp$4$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$],null),$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1510$x$$,null],null),null),"X",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($context_data$jscomp$4$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_shape_position$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.axis")]))),$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1511$y$$,null],null),null),"Y",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data$jscomp$4$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_shape_position$$))])))},$stroke_width$jscomp$10$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1734$opacity$$,null],null),null),"Opacity"),$typography$jscomp$39$$,$text_decoration$jscomp$6$$,$letter_spacing$jscomp$8$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1654$shadow$$,null],null),null),"Shadow"),$border_radius$$,$font_family$jscomp$10$$,
$app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$])}(),$app$main$ui$workspace$tokens$management$context_menu$tokens_menu_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2206$token_context_menu$$,$APP.$app$main$refs$workspace_tokens$$),$app$main$ui$workspace$tokens$management$context_menu$menu_tree$$=function $app$main$ui$workspace$tokens$management$context_menu$menu_tree$$($entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$){$entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$=
$APP.$rumext$v2$util$wrap_props$$($entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$);var $map__79652__$1$$=$APP.$cljs$core$__destructure_map$$($entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$);$entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79652__$1$$,$APP.$cljs$cst$5335$selected_shapes$$);var $submenu_offset$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79652__$1$$,$cljs$cst$5794$submenu_offset$$),$type$jscomp$679$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79652__$1$$,$APP.$cljs$cst$139$type$$),$errors$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79652__$1$$,$APP.$cljs$cst$570$errors$$),$shape_types$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,
$entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$)),$editing_ref_not_editing_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$);$editing_ref_not_editing_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($editing_ref_not_editing_QMARK_$$);$entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$=$errors$jscomp$31$$==null&&$APP.$cljs$core$seq$$($entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$)&&
$editing_ref_not_editing_QMARK_$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_types$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1608$group$$,null],null),null))?$type$jscomp$679$$!=null?$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$($map__79652__$1$$):$app$main$ui$workspace$tokens$management$context_menu$selection_actions$$($map__79652__$1$$):$app$main$ui$workspace$tokens$management$context_menu$default_actions$$($map__79652__$1$$);
$entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$=$app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$191$$,$map__79657_map__79657__$1_p__79653$$){var $index$jscomp$544$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79657_map__79657__$1_p__79653$$,
0,null);$map__79657_map__79657__$1_p__79653$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79657_map__79657__$1_p__79653$$,1,null);$map__79657_map__79657__$1_p__79653$$=$APP.$cljs$core$__destructure_map$$($map__79657_map__79657__$1_p__79653$$);var $title$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79657_map__79657__$1_p__79653$$,$APP.$cljs$cst$939$title$$),$action$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79657_map__79657__$1_p__79653$$,
$APP.$cljs$cst$2683$action$$),$selected_QMARK_$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79657_map__79657__$1_p__79653$$,$APP.$cljs$cst$5784$selected_QMARK_$$),$hint$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79657_map__79657__$1_p__79653$$,$APP.$cljs$cst$275$hint$$),$submenu$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79657_map__79657__$1_p__79653$$,$cljs$cst$5791$submenu$$),$no_selectable$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79657_map__79657__$1_p__79653$$,
$cljs$cst$5793$no_selectable$$);$out_arr__44124__auto__$jscomp$191$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1472$separator$$,$map__79657_map__79657__$1_p__79653$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_tokens_management_context_menu__separator"}):$APP.$cljs$core$truth_$$($submenu$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$menu_entry$$,{title:$title$jscomp$45$$,
hint:$hint$jscomp$20$$,"no-selectable":!0,"submenu-offset":$submenu_offset$jscomp$1$$,children:(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$context_menu$menu_tree$$,$APP.$rumext$v2$util$map__GT_obj$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__79652__$1$$,$APP.$cljs$cst$139$type$$,$submenu$$)))}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$menu_entry$$,{title:$title$jscomp$45$$,"on-click":$action$jscomp$6$$,hint:$hint$jscomp$20$$,
"no-selectable":$no_selectable$jscomp$1$$,"selected?":$selected_QMARK_$jscomp$9$$})},""+($title$jscomp$45$$??"")+" "+($index$jscomp$544$$??"")));return $out_arr__44124__auto__$jscomp$191$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($entries$jscomp$45_entries__$1$jscomp$6_map__79652_props_79651_selected_shapes$jscomp$18$$))};$APP.$cljs$core$set$$($APP.$cljs$core$list$$("token-status-partial","token-status-full","token-status-non-applied"));var $app$main$ui$workspace$tokens$management$token_pill$attribute_dictionary$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1688$p4$$,$APP.$cljs$cst$1687$p3$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1739$stroke_color$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1655$stroke_width$$,
$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1707$layout_item_min_w$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1705$layout_item_min_h$$,$APP.$cljs$cst$1704$layout_item_max_h$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1681$row_gap$$],"Y;Right;Left;Bottom;Rotation;Stroke Color;Fill;Width;Top Right;Top;Max Width;Column Gap;Bottom Right;Stroke Width;Top Left;Opacity;Min Width;X;Bottom Left;Min Height;Max Height;Height;Row Gap".split(";")),$app$main$ui$workspace$tokens$management$token_pill$dimensions_dictionary$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1688$p4$$,$APP.$cljs$cst$1687$p3$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1707$layout_item_min_w$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1705$layout_item_min_h$$,
$APP.$cljs$cst$1704$layout_item_max_h$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1681$row_gap$$],[$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1977$sizing$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1983$spacing$$]),$app$main$ui$workspace$tokens$management$token_pill$xf_COLON_map_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$app$main$ui$workspace$tokens$management$token_pill$token_types_with_status_icon$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
8,[$APP.$cljs$cst$1977$sizing$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$1980$dimensions$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1982$border_radius$$,null,$APP.$cljs$cst$1983$spacing$$,null],null),null),$app$main$ui$workspace$tokens$management$token_pill$token_pill_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($has_selected_QMARK__map__79685__$1_props_79684$$){var $active_theme_tokens$$=
$has_selected_QMARK__map__79685__$1_props_79684$$.activeThemeTokens,$selected_shapes$jscomp$22$$=$has_selected_QMARK__map__79685__$1_props_79684$$.selectedShapes,$disabled_QMARK_$jscomp$9_is_selected_inside_layout$jscomp$2$$=$has_selected_QMARK__map__79685__$1_props_79684$$.isSelectedInsideLayout,$on_context_menu$jscomp$13$$=$has_selected_QMARK__map__79685__$1_props_79684$$.onContextMenu,$on_click$jscomp$50$$=$has_selected_QMARK__map__79685__$1_props_79684$$.onClick,$token$jscomp$156$$=$has_selected_QMARK__map__79685__$1_props_79684$$.token;
$has_selected_QMARK__map__79685__$1_props_79684$$=$APP.$cljs$core$__destructure_map$$($token$jscomp$156$$);var $name$jscomp$463$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_selected_QMARK__map__79685__$1_props_79684$$,$APP.$cljs$cst$725$name$$),$errors_QMARK_$jscomp$1_value$jscomp$941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_selected_QMARK__map__79685__$1_props_79684$$,$APP.$cljs$cst$260$value$$),$type$jscomp$681$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_selected_QMARK__map__79685__$1_props_79684$$,
$APP.$cljs$cst$139$type$$),$resolved_token$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_tokens$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$156$$)),$errors$jscomp$34$$=$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$17$$);$has_selected_QMARK__map__79685__$1_props_79684$$=$APP.$cljs$core$count$$($selected_shapes$jscomp$22$$)>0;var $color$jscomp$183_is_reference_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$156$$),
"{"),$contains_path_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($name$jscomp$463$$,"."),$attributes$jscomp$86_status_icon_QMARK_$$=function(){var $$$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$type$jscomp$681$$);return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4655$all_attributes$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$35$$),$APP.$cljs$cst$1993$attributes$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$35$$))}(),
$full_applied_QMARK_$$=$has_selected_QMARK__map__79685__$1_props_79684$$?$app$main$ui$workspace$tokens$management$token_pill$applied_all_attributes_QMARK_$$($token$jscomp$156$$,$selected_shapes$jscomp$22$$,$attributes$jscomp$86_status_icon_QMARK_$$):!0,$applied_QMARK__token_status_id$$=$has_selected_QMARK__map__79685__$1_props_79684$$?$APP.$app$common$files$tokens$shapes_token_applied_QMARK_$$($token$jscomp$156$$,$selected_shapes$jscomp$22$$,$attributes$jscomp$86_status_icon_QMARK_$$):!1,$half_applied_QMARK_$$=
$APP.$cljs$core$truth_$$($applied_QMARK__token_status_id$$)?!$full_applied_QMARK_$$:$applied_QMARK__token_status_id$$;$disabled_QMARK_$jscomp$9_is_selected_inside_layout$jscomp$2$$=$has_selected_QMARK__map__79685__$1_props_79684$$&&$APP.$cljs$core$not$$($applied_QMARK__token_status_id$$)&&$APP.$cljs$core$not$$($half_applied_QMARK_$$)&&$APP.$cljs$core$not$$($app$main$ui$workspace$tokens$management$token_pill$attributes_match_selection_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($selected_shapes$jscomp$22$$,
$attributes$jscomp$86_status_icon_QMARK_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5799$selected_inside_layout_QMARK_$$,$disabled_QMARK_$jscomp$9_is_selected_inside_layout$jscomp$2$$],null)])));var $can_edit_QMARK_$jscomp$3$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$)),$is_viewer_QMARK_$$=$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$3$$),
$ref_not_in_active_set$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$cljs$core$seq$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$17$$)):$APP.$cljs$core$truth_$$($color$jscomp$183_is_reference_QMARK_$$)?!$app$main$ui$workspace$tokens$management$token_pill$contains_reference_value_QMARK_$$($errors_QMARK_$jscomp$1_value$jscomp$941$$,$active_theme_tokens$$):$color$jscomp$183_is_reference_QMARK_$$,$name_collision$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4593$error_DOT_token_SLASH_name_collision$$,$APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($errors$jscomp$34$$))),$no_valid_value$jscomp$1$$=$APP.$cljs$core$seq$$($errors$jscomp$34$$);$errors_QMARK_$jscomp$1_value$jscomp$941$$=$APP.$cljs$core$truth_$$($ref_not_in_active_set$jscomp$1$$)?$ref_not_in_active_set$jscomp$1$$:$no_valid_value$jscomp$1$$||$name_collision$$;$color$jscomp$183_is_reference_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$156$$),$APP.$cljs$cst$1298$color$$)?function(){var $or__5025__auto__$jscomp$1240$$=$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$($resolved_token$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1240$$)?$or__5025__auto__$jscomp$1240$$:$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$($token$jscomp$156$$)}():null;
$attributes$jscomp$86_status_icon_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($app$main$ui$workspace$tokens$management$token_pill$token_types_with_status_icon$$,$type$jscomp$681$$);var $on_click__$1$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($errors_QMARK_$jscomp$1_value$jscomp$941$$),$APP.$rumext$v2$adapt$$($on_click$jscomp$50$$),$APP.$rumext$v2$adapt$$($token$jscomp$156$$)],function($event$jscomp$583$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$583$$);
var $and__5023__auto__$jscomp$inline_8992$$=$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($errors$jscomp$34$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8992$$?$on_click$jscomp$50$$:$and__5023__auto__$jscomp$inline_8992$$)?$on_click$jscomp$50$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$50$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$583$$,$token$jscomp$156$$):$on_click$jscomp$50$$($event$jscomp$583$$,$token$jscomp$156$$):null});$applied_QMARK__token_status_id$$=$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?
"token-status-partial":$full_applied_QMARK_$$?"token-status-full":"token-status-non-applied";var $on_context_menu__$1$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_context_menu$jscomp$13$$),$APP.$rumext$v2$adapt$$($token$jscomp$156$$)],function($e$jscomp$353$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$353$$);return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?$on_context_menu$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?
$on_context_menu$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$353$$,$token$jscomp$156$$):$on_context_menu$jscomp$13$$($e$jscomp$353$$,$token$jscomp$156$$):null}),$on_click__$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($errors_QMARK_$jscomp$1_value$jscomp$941$$),$APP.$rumext$v2$adapt$$($on_click__$1$jscomp$3$$)],function($event$jscomp$584$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$584$$);var $JSCompiler_inline_result$jscomp$1846_and__5023__auto____$1$jscomp$inline_8994$$=
$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?($JSCompiler_inline_result$jscomp$1846_and__5023__auto____$1$jscomp$inline_8994$$=$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($errors$jscomp$34$$)))?$on_click__$1$jscomp$3$$:$JSCompiler_inline_result$jscomp$1846_and__5023__auto____$1$jscomp$inline_8994$$:$can_edit_QMARK_$jscomp$3$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1846_and__5023__auto____$1$jscomp$inline_8994$$)?$on_click__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?
$on_click__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$584$$):$on_click__$1$jscomp$3$$($event$jscomp$584$$):null}),$on_hover$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$22$$),$APP.$rumext$v2$adapt$$($is_viewer_QMARK_$$),$APP.$rumext$v2$adapt$$($active_theme_tokens$$),$APP.$rumext$v2$adapt$$($token$jscomp$156$$),$APP.$rumext$v2$adapt$$($half_applied_QMARK_$$),$APP.$rumext$v2$adapt$$($no_valid_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($ref_not_in_active_set$jscomp$1$$),
$APP.$rumext$v2$adapt$$($name_collision$$),$APP.$rumext$v2$adapt$$($errors$jscomp$34$$)],function($event$jscomp$585_node$jscomp$435$$){$event$jscomp$585_node$jscomp$435$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$585_node$jscomp$435$$);var $map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_tokens$$,$name$jscomp$463$$),$app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$=
$APP.$cljs$core$first$$($selected_shapes$jscomp$22$$),$map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$=$APP.$cljs$core$__destructure_map$$($token$jscomp$156$$),$base_title$jscomp$inline_13621_name$jscomp$inline_13606$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$,$APP.$cljs$cst$725$name$$);var $title$jscomp$47_type$jscomp$inline_13607$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$,
$APP.$cljs$cst$139$type$$);var $resolved_value$jscomp$inline_13608_resolved_value__$1$jscomp$inline_13611$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$,$APP.$cljs$cst$4605$resolved_value$$);$map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$,$APP.$cljs$cst$260$value$$);var $applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$=
$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$);$resolved_value$jscomp$inline_13608_resolved_value__$1$jscomp$inline_13611$$=$APP.$cljs$core$truth_$$($applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$)?$applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$:$resolved_value$jscomp$inline_13608_resolved_value__$1$jscomp$inline_13611$$;
$map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$=$app$main$data$workspace$tokens$application$get_token_properties$$($map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$);$applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$=$APP.$cljs$core$__destructure_map$$($map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$);$map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$,$APP.$cljs$cst$939$title$$);var $app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$);$app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$=
$APP.$cljs$core$set$$($APP.$cljs$core$vals$$($app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$));$app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$=$APP.$cljs$core$keys$$($app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$);$app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$=$APP.$cljs$core$contains_QMARK_$$($app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$,
$base_title$jscomp$inline_13621_name$jscomp$inline_13606$$);$applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$=$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?$app$main$ui$workspace$tokens$management$token_pill$partially_applied_attr$$($app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$,$app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$,
$applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.all");$app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$=$APP.$cljs$core$group_by$$($app$main$ui$workspace$tokens$management$token_pill$dimensions_dictionary$$,$app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$);
$base_title$jscomp$inline_13621_name$jscomp$inline_13606$$="Token: "+($base_title$jscomp$inline_13621_name$jscomp$inline_13606$$??"")+"\n"+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.original-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($map__79676__$1$jscomp$inline_13605_value$jscomp$inline_13609$$)]))??"")+"\n"+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($resolved_value$jscomp$inline_13608_resolved_value__$1$jscomp$inline_13611$$)]))??"")+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$156$$),$APP.$cljs$cst$1978$number$$)?"\n"+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.more-options")??""):null)??"");$title$jscomp$47_type$jscomp$inline_13607$$=
$APP.$cljs$core$truth_$$($ref_not_in_active_set$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.ref-not-valid"):$APP.$cljs$core$truth_$$($name_collision$$)?$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($errors$jscomp$34$$)):$APP.$cljs$core$truth_$$($no_valid_value$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.value-not-valid"):$APP.$cljs$core$truth_$$($app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$?
$is_viewer_QMARK_$$:$app_token_vals$jscomp$inline_13616_is_applied_QMARK_$jscomp$inline_13618_shape$jscomp$inline_13597$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_title$jscomp$inline_13621_name$jscomp$inline_13606$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.applied-to"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1980$dimensions$$,
$title$jscomp$47_type$jscomp$inline_13607$$)?$app$main$ui$workspace$tokens$management$token_pill$translate_and_format$$($app_token_keys$jscomp$inline_13617_applied_tokens$jscomp$inline_13615_grouped_values$jscomp$inline_13620$$):["- ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__79677$jscomp$inline_13612_theme_token$jscomp$1_title$jscomp$inline_13614$$),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($applied_to$jscomp$inline_13619_map__79677__$1$jscomp$inline_13613_resolved_value_theme$jscomp$inline_13610$$)].join("")],
null)):$base_title$jscomp$inline_13621_name$jscomp$inline_13606$$;return $APP.$app$util$dom$set_attribute_BANG_$$($event$jscomp$585_node$jscomp$435$$,"title",$title$jscomp$47_type$jscomp$inline_13607$$)});return(0,$APP.$rumext$v2$jsxs$$)("button",{type:"button",onFocus:$on_hover$$,onClick:$on_click__$2$$,onMouseEnter:$on_hover$$,onContextMenu:$on_context_menu__$1$jscomp$2$$,className:"main_ui_workspace_tokens_management_token_pill__token-pill "+(!$attributes$jscomp$86_status_icon_QMARK_$$&&$APP.$cljs$core$not$$($errors_QMARK_$jscomp$1_value$jscomp$941$$)?
"main_ui_workspace_tokens_management_token_pill__token-pill-no-icon":"")+" "+($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-default":"")+" "+($disabled_QMARK_$jscomp$9_is_selected_inside_layout$jscomp$2$$?"main_ui_workspace_tokens_management_token_pill__token-pill-disabled":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?$has_selected_QMARK__map__79685__$1_props_79684$$?$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?
$half_applied_QMARK_$$:$full_applied_QMARK_$$:$has_selected_QMARK__map__79685__$1_props_79684$$:$can_edit_QMARK_$jscomp$3$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-applied":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?$errors_QMARK_$jscomp$1_value$jscomp$941$$:$can_edit_QMARK_$jscomp$3$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid":"")+" "+($APP.$cljs$core$truth_$$($full_applied_QMARK_$$?$APP.$cljs$core$truth_$$($errors_QMARK_$jscomp$1_value$jscomp$941$$)?
$can_edit_QMARK_$jscomp$3$$:$errors_QMARK_$jscomp$1_value$jscomp$941$$:$full_applied_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied":"")+" "+($is_viewer_QMARK_$$?"main_ui_workspace_tokens_management_token_pill__token-pill-viewer":"")+" "+($APP.$cljs$core$truth_$$($is_viewer_QMARK_$$?$has_selected_QMARK__map__79685__$1_props_79684$$?$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?$half_applied_QMARK_$$:$full_applied_QMARK_$$:$has_selected_QMARK__map__79685__$1_props_79684$$:
$is_viewer_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-applied-viewer":"")+" "+($APP.$cljs$core$truth_$$($is_viewer_QMARK_$$?$errors_QMARK_$jscomp$1_value$jscomp$941$$:$is_viewer_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid-viewer":"")+" "+($APP.$cljs$core$truth_$$($is_viewer_QMARK_$$?$full_applied_QMARK_$$?$errors_QMARK_$jscomp$1_value$jscomp$941$$:$full_applied_QMARK_$$:$is_viewer_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied-viewer":
""),children:[$APP.$cljs$core$truth_$$($errors_QMARK_$jscomp$1_value$jscomp$941$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"broken-link",className:"main_ui_workspace_tokens_management_token_pill__token-pill-icon","aria-label":$name_collision$$?$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($errors$jscomp$34$$)):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.missing-reference")}):$APP.$cljs$core$truth_$$($color$jscomp$183_is_reference_QMARK_$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color$jscomp$183_is_reference_QMARK_$$,size:"small"}):$attributes$jscomp$86_status_icon_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$foundations$utilities$token$token_status$token_status_icon_STAR_$$,{iconId:$applied_QMARK__token_status_id$$,className:"main_ui_workspace_tokens_management_token_pill__token-pill-icon"}):null,$APP.$cljs$core$truth_$$($contains_path_QMARK_$$)?function(){var $last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$=
$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($name$jscomp$463$$,".");$last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$=$APP.$cljs$core$truth_$$($last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($name$jscomp$463$$,0,$last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$+1),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$463$$,
$last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$+1)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$name$jscomp$463$$,""],null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$,0,null);$last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$,
1,null);return(0,$APP.$rumext$v2$jsx$$)("span",{"aria-label":$name$jscomp$463$$,className:"main_ui_workspace_tokens_management_token_pill__divided-name-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_token_pill__last-name-wrapper",children:$last_part_temp__5823__auto__$jscomp$inline_8997_vec__79686$$})})}():(0,$APP.$rumext$v2$jsx$$)("span",{"aria-label":$name$jscomp$463$$,className:"main_ui_workspace_tokens_management_token_pill__name-wrapper",children:$name$jscomp$463$$})]})});var $app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$=function $app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$($is_folder_expanded_props_79692$$){var $active_theme_tokens$jscomp$1$$=$is_folder_expanded_props_79692$$.activeThemeTokens,$folded_token_paths$$=$is_folder_expanded_props_79692$$.foldedTokenPaths,$selected_shapes$jscomp$23$$=$is_folder_expanded_props_79692$$.selectedShapes,$is_selected_inside_layout$jscomp$3$$=$is_folder_expanded_props_79692$$.isSelectedInsideLayout,
$on_token_pill_click$jscomp$3$$=$is_folder_expanded_props_79692$$.onTokenPillClick,$selected_token_set_id$jscomp$2$$=$is_folder_expanded_props_79692$$.selectedTokenSetId,$type$jscomp$682$$=$is_folder_expanded_props_79692$$.type,$node$jscomp$436$$=$is_folder_expanded_props_79692$$.node,$on_pill_context_menu$$=$is_folder_expanded_props_79692$$.onPillContextMenu,$on_node_context_menu$$=$is_folder_expanded_props_79692$$.onNodeContextMenu,$tokens_lib$jscomp$39$$=$is_folder_expanded_props_79692$$.tokensLib,
$full_path$jscomp$2$$=[$APP.$cljs$core$name$$($type$jscomp$682$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$436$$))].join("");$is_folder_expanded_props_79692$$=!$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($APP.$cljs$core$truth_$$($folded_token_paths$$)?$folded_token_paths$$:$APP.$cljs$core$PersistentVector$EMPTY$$),$full_path$jscomp$2$$);var $children$jscomp$304$$=$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$436$$),
$sorted_children$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($children$jscomp$304$$)],function(){var $groups$jscomp$17_sorted_groups_vec__79693$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($g$jscomp$162_p__79696$$,$item$jscomp$137$$){var $l$jscomp$110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$162_p__79696$$,0,null);$g$jscomp$162_p__79696$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$162_p__79696$$,
1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$137$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l$jscomp$110$$,$item$jscomp$137$$),$g$jscomp$162_p__79696$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l$jscomp$110$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$162_p__79696$$,
$item$jscomp$137$$)],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$children$jscomp$304$$),$leafs_sorted_leafs$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$17_sorted_groups_vec__79693$$,0,null);$groups$jscomp$17_sorted_groups_vec__79693$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$17_sorted_groups_vec__79693$$,
1,null);$leafs_sorted_leafs$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$leafs_sorted_leafs$$);$groups$jscomp$17_sorted_groups_vec__79693$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$groups$jscomp$17_sorted_groups_vec__79693$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($leafs_sorted_leafs$$,$groups$jscomp$17_sorted_groups_vec__79693$$)}),
$swap_folder_expanded$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($full_path$jscomp$2$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$($full_path$jscomp$2$$))}),$node_context_menu_prep$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_node_context_menu$$),$APP.$rumext$v2$adapt$$($node$jscomp$436$$)],function($event$jscomp$586$$){return $APP.$cljs$core$truth_$$($on_node_context_menu$$)?
$on_node_context_menu$$.$cljs$core$IFn$_invoke$arity$2$?$on_node_context_menu$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$586$$,$node$jscomp$436$$):$on_node_context_menu$$($event$jscomp$586$$,$node$jscomp$436$$):null});return(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_tokens_management_token_tree__folder-node",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$layers$layer_button$layer_button_STAR_$$,{label:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$436$$),
expanded:$is_folder_expanded_props_79692$$,"aria-expanded":$is_folder_expanded_props_79692$$,"aria-controls":["folder-children-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$436$$))].join(""),isExpandable:$APP.$cljs$core$not$$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$436$$)),onToggleExpand:$swap_folder_expanded$$,onContextMenu:$node_context_menu_prep$$}),$is_folder_expanded_props_79692$$?
(0,$APP.$rumext$v2$jsx$$)("div",{id:["folder-children-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$436$$))].join(""),className:"main_ui_workspace_tokens_management_token_tree__folder-children-wrapper",children:$APP.$cljs$core$seq$$($children$jscomp$304$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$192$$,$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$){var $JSCompiler_temp_const$jscomp$1847$$=
$out_arr__44124__auto__$jscomp$192$$.push;if($APP.$cljs$core$not$$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$)))$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$=(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_management_token_tree__node-parent",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$,{foldedTokenPaths:$folded_token_paths$$,
tokensLib:$tokens_lib$jscomp$39$$,onPillContextMenu:$on_pill_context_menu$$,onTokenPillClick:$on_token_pill_click$jscomp$3$$,onNodeContextMenu:$on_node_context_menu$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$3$$,type:$type$jscomp$682$$,activeThemeTokens:$active_theme_tokens$jscomp$1$$,selectedShapes:$selected_shapes$jscomp$23$$,selectedTokenSetId:$selected_token_set_id$jscomp$2$$,node:$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$})},$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$));
else{$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1999$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$));var $token$jscomp$inline_9000$$=$APP.$app$common$types$tokens_lib$get_token$$($tokens_lib$jscomp$39$$,$selected_token_set_id$jscomp$2$$,$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$);$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$=
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_pill$token_pill_STAR_$$,{token:$token$jscomp$inline_9000$$,selectedShapes:$selected_shapes$jscomp$23$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$3$$,activeThemeTokens:$active_theme_tokens$jscomp$1$$,onClick:$on_token_pill_click$jscomp$3$$,onContextMenu:$on_pill_context_menu$$},$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$)}$JSCompiler_temp_const$jscomp$1847$$.call($out_arr__44124__auto__$jscomp$192$$,
$JSCompiler_temp$jscomp$1849_child$jscomp$123_id$jscomp$inline_8999$$);return $out_arr__44124__auto__$jscomp$192$$},[],$sorted_children$$):null}):null]})};var $app$main$ui$workspace$tokens$management$group$ref_COLON_folded_token_paths$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4693$folded_token_paths$$),$APP.$app$main$refs$workspace_tokens$$),$app$main$ui$workspace$tokens$management$group$ref_COLON_unfolded_token_types$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4686$unfolded_token_types$$),$APP.$app$main$refs$workspace_tokens$$);var $app$main$ui$workspace$tokens$management$node_context_menu$tokens_node_menu_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4724$token_node_context_menu$$,$APP.$app$main$refs$workspace_tokens$$);var $app$main$ui$workspace$tokens$sets$context_menu$ref_COLON_token_sets_context_menu$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4726$token_set_context_menu$$,$APP.$app$main$refs$workspace_tokens$$);var $app$main$ui$workspace$sidebar$toggle_collapse_left_sidebar$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$store$emit_BANG_$$,(0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5617$collapse_left_sidebar$$)),$app$main$ui$workspace$sidebar$collapsed_button_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){return(0,$APP.$rumext$v2$jsx$$)("div",{id:"left-sidebar-aside","data-width":"0",className:"main_ui_workspace_sidebar__collapsed-sidebar",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__collapsed-title",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.expand"),onClick:$app$main$ui$workspace$sidebar$toggle_collapse_left_sidebar$$,className:"main_ui_workspace_sidebar__collapsed-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.expand")})})})})}),
$app$main$ui$workspace$sidebar$layers_content_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_79820_width$jscomp$206$$){var $layout$jscomp$22$$=$props_79820_width$jscomp$206$$.layout;$props_79820_width$jscomp$206$$=$props_79820_width$jscomp$206$$.width;var $map__79821_on_pointer_down$jscomp$4$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$3714$sitemap$$,200,38,"0.6",$APP.$cljs$cst$1511$y$$,!1,null,null),$height$jscomp$176_map__79821__$1$$=
$APP.$cljs$core$__destructure_map$$($map__79821_on_pointer_down$jscomp$4$$);$map__79821_on_pointer_down$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$176_map__79821__$1$$,$APP.$cljs$cst$4542$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$176_map__79821__$1$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$176_map__79821__$1$$,
$APP.$cljs$cst$4544$on_pointer_move$$);$height$jscomp$176_map__79821__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$176_map__79821__$1$$,$APP.$cljs$cst$874$size$$);var $sitemap_collapsed_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5819$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_sitemap_collapsed$$,!1),$sitemap_collapsed_QMARK_$$=$APP.$cljs$core$_deref$$($sitemap_collapsed_STAR_$$),$on_toggle_sitemap_collapsed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($sitemap_collapsed_STAR_$$,
$APP.$cljs$core$not$$)});return(0,$APP.$rumext$v2$jsxs$$)("article",{style:{"--height":""+($height$jscomp$176_map__79821__$1$$??"")+"px"},className:"main_ui_workspace_sidebar__layers-tab",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$sitemap_STAR_$$,{layout:$layout$jscomp$22$$,height:$APP.$cljs$core$truth_$$($sitemap_collapsed_QMARK_$$)?32:$height$jscomp$176_map__79821__$1$$,collapsed:$sitemap_collapsed_QMARK_$$,onToggleCollapsed:$on_toggle_sitemap_collapsed$$}),$sitemap_collapsed_QMARK_$$?
null:(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__79821_on_pointer_down$jscomp$4$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$2$$,onPointerMove:$on_pointer_move$jscomp$3$$,className:"main_ui_workspace_sidebar__resize-area-horiz",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__resize-handle-horiz"})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$layers_toolbox_STAR_$$,{sizeParent:$props_79820_width$jscomp$206$$})]})}),$app$main$ui$workspace$sidebar$left_sidebar_STAR_$$=
(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($project$jscomp$22_props_79822$$){var $layout$jscomp$23$$=$project$jscomp$22_props_79822$$.layout,$resolved_active_tokens$jscomp$2$$=$project$jscomp$22_props_79822$$.resolvedActiveTokens,$file$jscomp$176$$=$project$jscomp$22_props_79822$$.file,$active_tokens$jscomp$10$$=$project$jscomp$22_props_79822$$.activeTokens,$tokens_lib$jscomp$51$$=$project$jscomp$22_props_79822$$.tokensLib,$options_mode$jscomp$2_shortcuts_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$options_mode_global$$);
$project$jscomp$22_props_79822$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$project$$);var $file_id$jscomp$429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$176$$,$APP.$cljs$cst$266$id$$),$design_tokens_QMARK_$$=$app$main$features$use_feature$$("design-tokens/v1"),$mode_inspect_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$2_shortcuts_QMARK_$$,$APP.$cljs$cst$2672$inspect$$);$options_mode$jscomp$2_shortcuts_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$23$$,
$APP.$cljs$cst$2950$shortcuts$$);var $show_debug_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$23$$,$cljs$cst$5652$debug_panel$$),$section$jscomp$34$$=$mode_inspect_QMARK_$$||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$23$$,$APP.$cljs$cst$3727$layers$$)?$APP.$cljs$cst$3727$layers$$:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$23$$,$APP.$cljs$cst$3718$assets$$)?$APP.$cljs$cst$3718$assets$$:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$23$$,$APP.$cljs$cst$2100$tokens$$)?$APP.$cljs$cst$2100$tokens$$:
null,$map__79823_on_pointer_down$jscomp$5$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($cljs$cst$5820$left_sidebar$$,318,318,500,$APP.$cljs$cst$1510$x$$,!1,$APP.$cljs$cst$257$left$$,null),$map__79823__$1_on_tab_change$$=$APP.$cljs$core$__destructure_map$$($map__79823_on_pointer_down$jscomp$5$$);$map__79823_on_pointer_down$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79823__$1_on_tab_change$$,$APP.$cljs$cst$4542$on_pointer_down$$);
var $on_lost_pointer_capture$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79823__$1_on_tab_change$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79823__$1_on_tab_change$$,$APP.$cljs$cst$4544$on_pointer_move$$),$parent_ref$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79823__$1_on_tab_change$$,$APP.$cljs$cst$4545$parent_ref$$),$width$jscomp$207$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79823__$1_on_tab_change$$,
$APP.$cljs$cst$874$size$$);$map__79823__$1_on_tab_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1017$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1017$$)])));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1017$$,
"tokens")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-tokens-tab"],null))):null});var $tabs$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mode_inspect_QMARK_$$),$APP.$rumext$v2$adapt$$($design_tokens_QMARK_$$)],function(){return $mode_inspect_QMARK_$$?new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers"),$APP.$cljs$cst$266$id$$,"layers"],null)],null):$design_tokens_QMARK_$$?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers"),
$APP.$cljs$cst$266$id$$,"layers"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.assets"),$APP.$cljs$cst$266$id$$,"assets"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Tokens",$APP.$cljs$cst$266$id$$,"tokens"],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers"),$APP.$cljs$cst$266$id$$,"layers"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.assets"),$APP.$cljs$cst$266$id$$,"assets"],null)],null)}),$aside_class$$="main_ui_workspace_sidebar__left-settings-bar "+($width$jscomp$207$$<=300?"two-row":"")+" "+($width$jscomp$207$$>300&&$width$jscomp$207$$<=
400?"three-row":"")+" "+($width$jscomp$207$$>400?"four-row":""),$tabs_action_button$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$collapse_button_STAR_$$,{})});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$sidebar$$),{value:$APP.$cljs$cst$257$left$$,children:(0,$APP.$rumext$v2$jsxs$$)("aside",{ref:$parent_ref$jscomp$3$$,id:"left-sidebar-aside","data-testid":"left-sidebar",
"data-width":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$207$$),onContextMenu:$app$util$dom$prevent_default_context_menu$$,style:{"--left-sidebar-width":""+($width$jscomp$207$$??"")+"px"},className:$aside_class$$,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$left_header$left_header_STAR_$$,{file:$file$jscomp$176$$,layout:$layout$jscomp$23$$,project:$project$jscomp$22_props_79822$$,className:"main_ui_workspace_sidebar__left-header"}),(0,$APP.$rumext$v2$jsx$$)("div",
{onPointerDown:$map__79823_on_pointer_down$jscomp$5$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$3$$,onPointerMove:$on_pointer_move$jscomp$4$$,className:"main_ui_workspace_sidebar__resize-area"}),$options_mode$jscomp$2_shortcuts_QMARK_$$===!0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR_$$,{className:"main_ui_workspace_sidebar__settings-bar-content"}):$show_debug_QMARK_$$===!0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug$debug_panel_STAR_$$,
{className:"main_ui_workspace_sidebar__settings-bar-content"}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__settings-bar-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$5$$,"default":"layers",selected:$APP.$cljs$core$name$$($section$jscomp$34$$),onChange:$map__79823__$1_on_tab_change$$,className:"main_ui_workspace_sidebar__left-sidebar-tabs",actionButtonPosition:"start",actionButton:$tabs_action_button$$,
children:function(){var $G__79824__$1$$=$section$jscomp$34$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$34$$.$fqn$:null;switch($G__79824__$1$$){case "assets":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$assets_toolbox_STAR_$$,{size:$width$jscomp$207$$-58,fileId:$file_id$jscomp$429$$});case "tokens":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sidebar$tokens_sidebar_tab_STAR_$$,{tokensLib:$tokens_lib$jscomp$51$$,activeTokens:$active_tokens$jscomp$10$$,
resolvedActiveTokens:$resolved_active_tokens$jscomp$2$$});case "layers":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers_content_STAR_$$,{layout:$layout$jscomp$23$$,width:$width$jscomp$207$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79824__$1$$)].join(""));}}()})})]})})}),$app$main$ui$workspace$sidebar$history_content_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){var $selected_STAR_$jscomp$2$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5821$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_history_sidebar$$,
"history"),$selected$jscomp$185$$=$APP.$cljs$core$_deref$$($selected_STAR_$jscomp$2$$),$on_change_tab$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79825_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected_STAR_$jscomp$2$$,$p1__79825_SHARP_$$)}),$tabs$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.tab.history"),$APP.$cljs$cst$266$id$$,"history"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.tab.actions"),$APP.$cljs$cst$266$id$$,"actions"],null)],null)}),$button$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$app$main$ui$workspace$sidebar$on_close_document_history$$,icon:"close"})});a:switch($selected$jscomp$185$$){case "history":var $JSCompiler_inline_result$jscomp$1866$$=(0,$APP.$rumext$v2$jsx$$)("article",{className:"main_ui_workspace_sidebar__history-tab",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$versions$versions_toolbox_STAR_$$,{})});break a;case "actions":$JSCompiler_inline_result$jscomp$1866$$=
(0,$APP.$rumext$v2$jsx$$)("article",{className:"main_ui_workspace_sidebar__versions-tab",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$,{})});break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$185$$)].join(""));}return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$6$$,selected:$selected$jscomp$185$$,onChange:$on_change_tab$jscomp$2$$,
className:"main_ui_workspace_sidebar__left-sidebar-tabs",actionButtonPosition:"end",actionButton:$button$jscomp$3$$,children:$JSCompiler_inline_result$jscomp$1866$$})});var $shadow$js$shim$module$0$0zip_js$0zip$$=shadow$bridge("@zip.js/zip.js");var $app$util$zip$reader$$=function $app$util$zip$reader$$($G__79833_blob$jscomp$39_breader$$){if($G__79833_blob$jscomp$39_breader$$ instanceof Blob)return $G__79833_blob$jscomp$39_breader$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.BlobReader($G__79833_blob$jscomp$39_breader$$),new $shadow$js$shim$module$0$0zip_js$0zip$$.ZipReader($G__79833_blob$jscomp$39_breader$$);if($G__79833_blob$jscomp$39_breader$$ instanceof Uint8Array)return $G__79833_blob$jscomp$39_breader$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.Uint8ArrayReader($G__79833_blob$jscomp$39_breader$$),
new $shadow$js$shim$module$0$0zip_js$0zip$$.ZipReader($G__79833_blob$jscomp$39_breader$$,{useWebWorkers:!1});if($G__79833_blob$jscomp$39_breader$$ instanceof ArrayBuffer)return $G__79833_blob$jscomp$39_breader$$=new Uint8Array($G__79833_blob$jscomp$39_breader$$),$app$util$zip$reader$$.$cljs$core$IFn$_invoke$arity$1$?$app$util$zip$reader$$.$cljs$core$IFn$_invoke$arity$1$($G__79833_blob$jscomp$39_breader$$):$app$util$zip$reader$$($G__79833_blob$jscomp$39_breader$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("invalid data received for zip/reader",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$cljs$cst$5822$coce$$,$APP.$cljs$cst$1754$invalid_type$$,$APP.$cljs$cst$275$hint$$,"invalid data received for zip/reader"],null),null])),null);};$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$24$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$24$$,$cljs$cst$5816$tokens_SLASH_export$$,$app$main$ui$workspace$tokens$export$0$export_modal_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$25$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$25$$,$cljs$cst$5817$tokens_SLASH_import$$,$app$main$ui$workspace$tokens$import$0$import_modal_STAR_$$)});var $app$main$ui$workspace$tokens$management$forms$validators$default_validators$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($token$jscomp$180_token_value$jscomp$10$$){$token$jscomp$180_token_value$jscomp$10$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$180_token_value$jscomp$10$$);return $APP.$cljs$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$180_token_value$jscomp$10$$))?
$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$):null},$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$],null);var $app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1650$offset_x$$,"4",$APP.$cljs$cst$1651$offset_y$$,"4",$APP.$cljs$cst$1653$blur$$,"4",$APP.$cljs$cst$1652$spread$$,"0"],null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$26$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$26$$,$cljs$cst$5840$tokens_SLASH_boolean$$,$app$main$ui$workspace$tokens$management$forms$modals$boolean_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$27$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$27$$,$APP.$cljs$cst$4658$tokens_SLASH_border_radius$$,$app$main$ui$workspace$tokens$management$forms$modals$border_radius_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$28$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$28$$,$APP.$cljs$cst$4661$tokens_SLASH_color$$,$app$main$ui$workspace$tokens$management$forms$modals$color_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$29$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$29$$,$APP.$cljs$cst$4669$tokens_SLASH_stroke_width$$,$app$main$ui$workspace$tokens$management$forms$modals$stroke_width_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$30$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$30$$,$APP.$cljs$cst$4660$tokens_SLASH_shadow$$,$app$main$ui$workspace$tokens$management$forms$modals$box_shadow_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$31$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$31$$,$APP.$cljs$cst$4670$tokens_SLASH_sizing$$,$app$main$ui$workspace$tokens$management$forms$modals$sizing_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$32$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$32$$,$APP.$cljs$cst$4671$tokens_SLASH_dimensions$$,$app$main$ui$workspace$tokens$management$forms$modals$dimensions_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$33$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$33$$,$APP.$cljs$cst$4673$tokens_SLASH_number$$,$app$main$ui$workspace$tokens$management$forms$modals$number_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$34$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$34$$,$APP.$cljs$cst$4672$tokens_SLASH_opacity$$,$app$main$ui$workspace$tokens$management$forms$modals$opacity_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$35$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$35$$,$cljs$cst$5841$tokens_SLASH_other$$,$app$main$ui$workspace$tokens$management$forms$modals$other_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$36$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$36$$,$APP.$cljs$cst$4674$tokens_SLASH_rotation$$,$app$main$ui$workspace$tokens$management$forms$modals$rotation_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$37$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$37$$,$APP.$cljs$cst$4675$tokens_SLASH_spacing$$,$app$main$ui$workspace$tokens$management$forms$modals$spacing_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$38$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$38$$,$cljs$cst$5842$tokens_SLASH_string$$,$app$main$ui$workspace$tokens$management$forms$modals$string_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$39$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$39$$,$APP.$cljs$cst$4667$tokens_SLASH_typography$$,$app$main$ui$workspace$tokens$management$forms$modals$typography_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$40$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$40$$,$APP.$cljs$cst$4662$tokens_SLASH_font_size$$,$app$main$ui$workspace$tokens$management$forms$modals$font_size_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$41$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$41$$,$APP.$cljs$cst$4663$tokens_SLASH_letter_spacing$$,$app$main$ui$workspace$tokens$management$forms$modals$letter_spacing_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$42$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$42$$,$APP.$cljs$cst$4664$tokens_SLASH_font_family$$,$app$main$ui$workspace$tokens$management$forms$modals$font_familiy_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$43$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$43$$,$APP.$cljs$cst$4665$tokens_SLASH_text_case$$,$app$main$ui$workspace$tokens$management$forms$modals$text_case_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$44$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$44$$,$APP.$cljs$cst$4668$tokens_SLASH_text_decoration$$,$app$main$ui$workspace$tokens$management$forms$modals$text_decoration_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$45$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$45$$,$APP.$cljs$cst$4666$tokens_SLASH_font_weight$$,$app$main$ui$workspace$tokens$management$forms$modals$font_weight_modal$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$46$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$46$$,$cljs$cst$5810$tokens_SLASH_rename_node$$,$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_modal$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$47$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$47$$,$cljs$cst$5806$tokens_SLASH_remapping_confirmation$$,$app$main$ui$workspace$tokens$remapping_modal$token_remapping_modal$$)});var $app$main$data$workspace$tokens$typography$set_base_font_size_80137$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$48$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$48$$,$cljs$cst$5818$tokens_SLASH_settings$$,$app$main$ui$workspace$tokens$settings$token_settings_modal_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$49$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$49$$,$cljs$cst$5815$tokens_SLASH_themes$$,$app$main$ui$workspace$tokens$themes$create_modal$token_themes_modal$$)});var $app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$main$ui$workspace$viewport$viewport_ref$current_observer$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);var $app$main$ui$workspace$shapes$text$editor$default_decorator$$;$app$main$ui$workspace$shapes$text$editor$default_decorator$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createDecorator("PENPOT_SELECTION",function($props_80321$$){return(0,$APP.$rumext$v2$jsx$$)("span",{style:{background:"#ccc",display:"inline-block"},children:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80321$$,"children")})});
var $app$main$ui$workspace$shapes$text$editor$empty_editor_state$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createEditorState(null,$app$main$ui$workspace$shapes$text$editor$default_decorator$$),$app$main$ui$workspace$shapes$text$editor$text_shape_edit_html$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$((0,$APP.$rumext$v2$forward_ref$$)(function($content$jscomp$258_props_80335$$){function $on_key_up$jscomp$1$$($event$jscomp$643$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$643$$);
return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$643$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()])):null}var $map__80344__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$258_props_80335$$,"shape")),$id$jscomp$1031_self_ref$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80344__$1$$,$APP.$cljs$cst$266$id$$);$content$jscomp$258_props_80335$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80344__$1$$,$APP.$cljs$cst$1637$content$$);var $on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$),$state$jscomp$1210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$,
$id$jscomp$1031_self_ref$$,$app$main$ui$workspace$shapes$text$editor$empty_editor_state$$);$id$jscomp$1031_self_ref$$=(0,$APP.$rumext$v2$use_ref$$)();$on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__80344__$1$$))],function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__80344__$1$$))});
$on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$);var $shape__$1$jscomp$111$$=$on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($map__80344__$1$$,$on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$):$map__80344__$1$$,
$blurred$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape__$1$jscomp$111$$),$APP.$rumext$v2$adapt$$($state$jscomp$1210$$)],function($event$jscomp$644$$){var $is_empty_QMARK_$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.isCurrentEmpty($state$jscomp$1210$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$644$$);
$APP.$app$util$dom$prevent_default$$($event$jscomp$644$$);$APP.$cljs$core$not$$($is_empty_QMARK_$$)&&($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4005$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$initialize_editor_state$$($shape__$1$jscomp$111$$)));return $APP.$cljs$core$reset_BANG_$$($blurred$$,!0)});var $on_focus$jscomp$18$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape__$1$jscomp$111$$),
$APP.$rumext$v2$adapt$$($state$jscomp$1210$$)],function(){return $APP.$cljs$core$reset_BANG_$$($blurred$$,!1)}),$prev_value$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)($state$jscomp$1210$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1210$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_value$jscomp$1$$,$state$jscomp$1210$$)});var $handle_change$jscomp$19$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($state__$1$jscomp$61$$){var $old_state$jscomp$1_prev_data$jscomp$1$$=
$APP.$rumext$v2$ref_val$$($prev_value$jscomp$1$$);if($state__$1$jscomp$61$$!=null&&$old_state$jscomp$1_prev_data$jscomp$1$$!=null){var $block_changes$jscomp$2_block_to_add_styles$$=$app$util$text_editor$get_content_changes$$($old_state$jscomp$1_prev_data$jscomp$1$$,$state__$1$jscomp$61$$);$old_state$jscomp$1_prev_data$jscomp$1$$=$APP.$app$util$text_editor$get_editor_current_inline_styles$$($old_state$jscomp$1_prev_data$jscomp$1$$);var $block_to_setup$$=$app$main$ui$workspace$shapes$text$editor$get_blocks_to_setup$$($block_changes$jscomp$2_block_to_add_styles$$);
$block_changes$jscomp$2_block_to_add_styles$$=$app$main$ui$workspace$shapes$text$editor$get_blocks_to_add_styles$$($block_changes$jscomp$2_block_to_add_styles$$);return $app$util$text_editor$apply_block_styles_to_content$$($app$util$text_editor$setup_block_styles$$($state__$1$jscomp$61$$,$block_to_setup$$,$old_state$jscomp$1_prev_data$jscomp$1$$),$block_changes$jscomp$2_block_to_add_styles$$)}return $state__$1$jscomp$61$$}),$on_change$jscomp$100$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($val$jscomp$228$$){var $prev_val$jscomp$1$$=
$APP.$rumext$v2$ref_val$$($prev_value$jscomp$1$$),$styleOverride$$=$prev_val$jscomp$1$$.getInlineStyleOverride(),$keep_style_QMARK_$$=function(){var $and__5023__auto__$jscomp$909_and__5023__auto____$1$jscomp$156$$=$styleOverride$$!=null;return $and__5023__auto__$jscomp$909_and__5023__auto____$1$jscomp$156$$?($and__5023__auto__$jscomp$909_and__5023__auto____$1$jscomp$156$$=$prev_val$jscomp$1$$.getCurrentContent().equals($val$jscomp$228$$.getCurrentContent()),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$909_and__5023__auto____$1$jscomp$156$$)?
$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.selectionEquals($prev_val$jscomp$1$$.getSelection(),$val$jscomp$228$$.getSelection()):$and__5023__auto__$jscomp$909_and__5023__auto____$1$jscomp$156$$):$and__5023__auto__$jscomp$909_and__5023__auto____$1$jscomp$156$$}(),$val__$1$jscomp$21$$=function(){var $G__80356_G__80356__$1_G__80356__$2$$=$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$228$$):$handle_change$jscomp$19$$($val$jscomp$228$$);
$G__80356_G__80356__$1_G__80356__$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($blurred$$))?$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.addBlurSelectionEntity($G__80356_G__80356__$1_G__80356__$2$$):$G__80356_G__80356__$1_G__80356__$2$$;$G__80356_G__80356__$1_G__80356__$2$$=$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($blurred$$))?$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.removeBlurSelectionEntity($G__80356_G__80356__$1_G__80356__$2$$):$G__80356_G__80356__$1_G__80356__$2$$;
return $APP.$cljs$core$truth_$$($keep_style_QMARK_$$)?$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.setInlineStyleOverride($G__80356_G__80356__$1_G__80356__$2$$,$styleOverride$$):$G__80356_G__80356__$1_G__80356__$2$$}();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($shape__$1$jscomp$111$$,$val__$1$jscomp$21$$))}),$on_editor$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($editor$jscomp$9$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_editor$$($editor$jscomp$9$$));
return $APP.$cljs$core$truth_$$($editor$jscomp$9$$)?($APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("public-DraftEditor-content"),"mousetrap"),$editor$jscomp$9$$.focus()):null}),$handle_return$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($___$2$jscomp$719_style_80384$$,$G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$){$___$2$jscomp$719_style_80384$$=$APP.$app$util$text_editor$get_editor_current_block_data$$($G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$);
$G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$=$app$util$text_editor$insert_text$$($G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$,"\n",$___$2$jscomp$719_style_80384$$);$G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$=$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$):$handle_change$jscomp$19$$($G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($shape__$1$jscomp$111$$,$G__80357$jscomp$inline_9107_state_80385__$2_state__$1$jscomp$62$$));return"handled"}),$on_pointer_down$jscomp$12$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$645$$){$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$645$$),"DraftEditor-root")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$cursor_to_end$$($shape__$1$jscomp$111$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$focus_editor$$())});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $keys$jscomp$57$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$(document,"keyup",$on_key_up$jscomp$1$$)],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$texts$initialize_editor_state$$($shape__$1$jscomp$111$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$select_all$$($shape__$1$jscomp$111$$)]));return function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4005$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$);for(var $c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$=$APP.$cljs$core$seq$$($keys$jscomp$57$$),$G__80377_chunk__80349_seq__80348__$1$$=null,$G__80376_count__80350$$=
0,$i__80351$$=0;;)if($i__80351$$<$G__80376_count__80350$$){var $G__80378_key$jscomp$418$$=$G__80377_chunk__80349_seq__80348__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__80351$$);$APP.$goog$events$unlistenByKey$$($G__80378_key$jscomp$418$$);$i__80351$$+=1}else if($c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$))$G__80377_chunk__80349_seq__80348__$1$$=$c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__80377_chunk__80349_seq__80348__$1$$)?($c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$=$APP.$cljs$core$_chunked_first$$($G__80377_chunk__80349_seq__80348__$1$$),$G__80376_count__80350$$=$APP.$cljs$core$_chunked_rest$$($G__80377_chunk__80349_seq__80348__$1$$),$G__80377_chunk__80349_seq__80348__$1$$=$c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$,$G__80378_key$jscomp$418$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$),
$c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$=$G__80376_count__80350$$,$G__80376_count__80350$$=$G__80378_key$jscomp$418$$):($G__80378_key$jscomp$418$$=$APP.$cljs$core$first$$($G__80377_chunk__80349_seq__80348__$1$$),$APP.$goog$events$unlistenByKey$$($G__80378_key$jscomp$418$$),$c__5548__auto__$jscomp$44_seq__80348_temp__5825__auto__$jscomp$416$$=$APP.$cljs$core$next$$($G__80377_chunk__80349_seq__80348__$1$$),$G__80377_chunk__80349_seq__80348__$1$$=null,$G__80376_count__80350$$=
0),$i__80351$$=0;else return null}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"text-editor "+($APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$css_cursors$get_dynamic$$("text",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$111$$)),!0,$APP.$cljs$cst$4875$align_top$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$258_props_80335$$,
"top"),"top"),$cljs$cst$5867$align_center$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$258_props_80335$$),"center"),$APP.$cljs$cst$4878$align_bottom$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$258_props_80335$$),"bottom")]))??""),ref:$id$jscomp$1031_self_ref$$,style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$111$$),
height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$111$$),opacity:$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($blurred$$))?0:null},onPointerDown:$on_pointer_down$jscomp$12$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.Editor,{stripPastedStyles:!0,onChange:$on_change$jscomp$100$$,blockRendererFn:function($JSCompiler_inline_result$jscomp$1881_p1__80334_SHARP_$$){a:switch($JSCompiler_inline_result$jscomp$1881_p1__80334_SHARP_$$.getType()){case "unstyled":$JSCompiler_inline_result$jscomp$1881_p1__80334_SHARP_$$=
{editable:!0,component:$app$main$ui$workspace$shapes$text$editor$block_component$$,props:{data:$APP.$app$util$text_editor$immutable_map__GT_map$$($JSCompiler_inline_result$jscomp$1881_p1__80334_SHARP_$$.getData()),shape:$shape__$1$jscomp$111$$}};break a;default:$JSCompiler_inline_result$jscomp$1881_p1__80334_SHARP_$$=null}return $JSCompiler_inline_result$jscomp$1881_p1__80334_SHARP_$$},handleReturn:$handle_return$$,style:{border:"1px solid red"},onFocus:$on_focus$jscomp$18$$,onBlur:$on_blur$jscomp$32_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$,
ref:$on_editor$$,handlePastedText:function($G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$){if($APP.$cljs$core$seq$$($G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$)){var $current_block_styles_80389_style_80391$$=$APP.$app$util$text_editor$get_editor_current_block_data$$($state$jscomp$1210$$),$inline_styles_80390$$=$APP.$app$util$text_editor$get_editor_current_inline_styles$$($state$jscomp$1210$$);$current_block_styles_80389_style_80391$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$current_block_styles_80389_style_80391$$,
$inline_styles_80390$$]));$G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$=$app$util$text_editor$insert_text$$($state$jscomp$1210$$,$G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$,$current_block_styles_80389_style_80391$$);$G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$=$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$):$handle_change$jscomp$19$$($G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($shape__$1$jscomp$111$$,$G__80358$jscomp$inline_9112_state_80392__$1_text$jscomp$147$$))}return"handled"},customStyleFn:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$shapes$text$editor$styles_fn$$,$shape__$1$jscomp$111$$),editorState:$state$jscomp$1210$$})})}));var $app$main$ui$workspace$shapes$text$v2_editor$text_editor_html$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($align_center_QMARK__page$jscomp$171_props_80367$$){var $align_top_QMARK__render_wasm_QMARK_$jscomp$4$$=$align_center_QMARK__page$jscomp$171_props_80367$$["render-wasm?"]??!1,$shape$jscomp$1050$$=$align_center_QMARK__page$jscomp$171_props_80367$$.shape,$canvas_ref$jscomp$3$$=$align_center_QMARK__page$jscomp$171_props_80367$$["canvas-ref"],$content$jscomp$263$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1050$$),
$shape_id$jscomp$169$$=$shape$jscomp$1050$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1050$$,$APP.$cljs$cst$266$id$$),$fill_color$jscomp$5$$=$app$main$ui$workspace$shapes$text$v2_editor$get_color_from_content$$($content$jscomp$263$$),$editor_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$container_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null);$align_center_QMARK__page$jscomp$171_props_80367$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page$$);var $align_bottom_QMARK__objects$jscomp$806_vec__80369$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($align_center_QMARK__page$jscomp$171_props_80367$$,$APP.$cljs$cst$1631$objects$$),$frame$jscomp$79$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($align_bottom_QMARK__objects$jscomp$806_vec__80369$$,$shape_id$jscomp$169$$),$background_color$jscomp$3$$=$APP.$cljs$cst$2058$background$$.$cljs$core$IFn$_invoke$arity$1$($align_center_QMARK__page$jscomp$171_props_80367$$),$text_color$jscomp$3$$=function(){if($APP.$cljs$core$truth_$$($fill_color$jscomp$5$$))return $fill_color$jscomp$5$$;
var $or__5025__auto____$1$jscomp$141$$=$app$main$ui$workspace$shapes$text$v2_editor$get_default_text_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1606$frame$$,$frame$jscomp$79$$,$APP.$cljs$cst$3779$background_color$$,$background_color$jscomp$3$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$141$$)?$or__5025__auto____$1$jscomp$141$$:"#000000"}();$align_bottom_QMARK__objects$jscomp$806_vec__80369$$=$app$main$ui$workspace$shapes$text$v2_editor$vertical_align_editor_classes$$($content$jscomp$263$$,
$align_top_QMARK__render_wasm_QMARK_$jscomp$4$$);$align_top_QMARK__render_wasm_QMARK_$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($align_bottom_QMARK__objects$jscomp$806_vec__80369$$,0,null);$align_center_QMARK__page$jscomp$171_props_80367$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($align_bottom_QMARK__objects$jscomp$806_vec__80369$$,1,null);$align_bottom_QMARK__objects$jscomp$806_vec__80369$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($align_bottom_QMARK__objects$jscomp$806_vec__80369$$,
2,null);var $fonts$jscomp$37$$=$APP.$app$main$ui$hooks$use_equal_memo$$($APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$263$$)],function(){var $extract_fn$jscomp$inline_9129$$=$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1759$font_variant_id$$),$default$$jscomp$inline_9130$$=$extract_fn$jscomp$inline_9129$$($APP.$app$common$types$text$default_typography$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$default$$jscomp$inline_9130$$]),
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($extract_fn$jscomp$inline_9129$$),$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$content$jscomp$263$$))}));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$37$$)],function(){return $app$main$ui$workspace$shapes$text$v2_editor$load_fonts_BANG_$$($fonts$jscomp$37$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$169$$)],
function(){return $app$main$ui$workspace$shapes$text$v2_editor$initialize_event_handlers$$($shape_id$jscomp$169$$,$content$jscomp$263$$,$editor_ref$jscomp$2$$,$canvas_ref$jscomp$3$$,$container_ref$jscomp$4$$,$text_color$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_color$jscomp$3$$)],function(){return $app$util$dom$set_style_BANG_$$($APP.$rumext$v2$ref_val$$($container_ref$jscomp$4$$),"--text-editor-caret-color",$text_color$jscomp$3$$)});
return(0,$APP.$rumext$v2$jsx$$)("div",{ref:$container_ref$jscomp$4$$,"data-testid":"text-editor-container",style:{width:"var(--editor-container-width)",height:"var(--editor-container-height)",minWidth:"var(--editor-container-min-width, 1px)",minHeight:"var(--editor-container-min-height, 1px)"},className:""+($app$main$ui$css_cursors$get_dynamic$$("text",$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1050$$))??"")+" main_ui_workspace_shapes_text_v2_editor__text-editor-container",
children:(0,$APP.$rumext$v2$jsx$$)("div",{role:"textbox","aria-multiline":!0,"data-x":$shape$jscomp$1050$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1050$$,$APP.$cljs$cst$1510$x$$),className:"mousetrap main_ui_workspace_shapes_text_v2_editor__text-editor-content "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1050$$),$APP.$cljs$cst$1671$fixed$$)?"main_ui_workspace_shapes_text_v2_editor__grow-type-fixed":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1050$$),$APP.$cljs$cst$2036$auto_width$$)?"main_ui_workspace_shapes_text_v2_editor__grow-type-auto-width":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1050$$),$APP.$cljs$cst$2035$auto_height$$)?"main_ui_workspace_shapes_text_v2_editor__grow-type-auto-height":"")+
" "+($APP.$cljs$core$truth_$$($align_top_QMARK__render_wasm_QMARK_$jscomp$4$$)?"main_ui_workspace_shapes_text_v2_editor__align-top":"")+" "+($APP.$cljs$core$truth_$$($align_center_QMARK__page$jscomp$171_props_80367$$)?"main_ui_workspace_shapes_text_v2_editor__align-center":"")+" "+($APP.$cljs$core$truth_$$($align_bottom_QMARK__objects$jscomp$806_vec__80369$$)?"main_ui_workspace_shapes_text_v2_editor__align-bottom":"")),"aria-autocomplete":"none","data-testid":"text-editor-content","data-y":$shape$jscomp$1050$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1050$$,$APP.$cljs$cst$1511$y$$),ref:$editor_ref$jscomp$2$$,contentEditable:!0})})}),$app$main$ui$workspace$shapes$text$v2_editor$text_editor$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$((0,$APP.$rumext$v2$forward_ref$$)(function($canvas_ref$jscomp$4_props_80393$$){var $clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$=$canvas_ref$jscomp$4_props_80393$$.modifiers,$shape$jscomp$1051$$=$canvas_ref$jscomp$4_props_80393$$.shape;
$canvas_ref$jscomp$4_props_80393$$=$canvas_ref$jscomp$4_props_80393$$["canvas-ref"];var $shape_id$jscomp$170$$=$shape$jscomp$1051$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1051$$,$APP.$cljs$cst$266$id$$),$modifiers__$1$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$,$shape_id$jscomp$170$$),$APP.$cljs$cst$1810$modifiers$$);$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$=
$APP.$app$render_wasm$api$fonts_from_text_content$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1051$$),!1);var $fallback_families$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$){$JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$=$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$);
$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$,"gfont-noto-sans"))?($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$=$APP.$cuerdas$core$replace$$($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$,/gfont\-noto\-sans\-/,""),$JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$)>=3?$APP.$cuerdas$core$capital$$($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$):$APP.$cuerdas$core$upper$$($JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$)):$JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$=
"Noto Color Emoji";return $JSCompiler_inline_result$jscomp$1883_font$jscomp$51_font_id$jscomp$inline_9132_lang$jscomp$inline_9133$$},$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$);$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$="text-edition-clip"+($shape_id$jscomp$170$$??"");var $text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1051$$))],
function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1051$$))}),$text_modifier$jscomp$6$$=$APP.$rumext$v2$deref$$($text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$),$maybe_zoom$jscomp$1$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$)?$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$):null,$vbox$jscomp$38$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$vbox$$),$shape__$1$jscomp$114$$=
function(){var $G__80398__$1$$=$text_modifier$jscomp$6$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($shape$jscomp$1051$$,$text_modifier$jscomp$6$$):$shape$jscomp$1051$$;return $modifiers__$1$jscomp$19$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__80398__$1$$,$modifiers__$1$jscomp$19$$):$G__80398__$1$$}(),$render_wasm_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"render-wasm/v1")});$text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$=$APP.$cljs$core$truth_$$($render_wasm_QMARK_$jscomp$5$$)?function(){var $map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$=$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id$jscomp$170$$);$map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$);
var $max_height$jscomp$4_width$jscomp$217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$,$APP.$cljs$cst$290$width$$),$height$jscomp$185$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$,$APP.$cljs$cst$1522$height$$);$map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);
var $transform$jscomp$109_vec__80400$$=$app$main$data$helpers$get_selrect$$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$,$shape__$1$jscomp$114$$);$map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$109_vec__80400$$,0,null);$transform$jscomp$109_vec__80400$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$109_vec__80400$$,1,null);var $selrect_height$jscomp$1$$=
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$),$selrect_width$jscomp$1$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$),$max_width$jscomp$8_overlay_width$$=$max_height$jscomp$4_width$jscomp$217$$>$selrect_width$jscomp$1$$?$max_height$jscomp$4_width$jscomp$217$$:$selrect_width$jscomp$1$$;$max_height$jscomp$4_width$jscomp$217$$=
$height$jscomp$185$$>$selrect_height$jscomp$1$$?$height$jscomp$185$$:$selrect_height$jscomp$1$$;var $viewport_width$$=function(){var $or__5025__auto__$jscomp$1304$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$38$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1304$$)?$or__5025__auto__$jscomp$1304$$:0}();$max_width$jscomp$8_overlay_width$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$114$$),
$APP.$cljs$cst$2036$auto_width$$)?$max_width$jscomp$8_overlay_width$$+$viewport_width$$:$max_width$jscomp$8_overlay_width$$;var $valign$jscomp$1$$=$APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$114$$)),$y$jscomp$495$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__80399_map__80399__$1_selrect$jscomp$83_selrect_transform$jscomp$2$$,$APP.$cljs$cst$1511$y$$,function(){switch($valign$jscomp$1$$){case "bottom":return $y$jscomp$495$$+($selrect_height$jscomp$1$$-$height$jscomp$185$$);case "center":return $y$jscomp$495$$+($selrect_height$jscomp$1$$-$height$jscomp$185$$)/2;default:return $y$jscomp$495$$}}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,
$max_width$jscomp$8_overlay_width$$,$APP.$cljs$cst$1522$height$$,$max_height$jscomp$4_width$jscomp$217$$,$cljs$cst$5868$selrect_width$$,$selrect_width$jscomp$1$$,$cljs$cst$5869$selrect_height$$,$selrect_height$jscomp$1$$])),$transform$jscomp$109_vec__80400$$],null)}():function(){var $bounds$jscomp$85_height$jscomp$186$$=$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape__$1$jscomp$114$$),$x$jscomp$1273$$=Math.min($bounds$jscomp$85_height$jscomp$186$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$186$$,
$APP.$cljs$cst$1510$x$$),$shape__$1$jscomp$114$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1510$x$$)),$y$jscomp$496$$=Math.min($bounds$jscomp$85_height$jscomp$186$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$186$$,$APP.$cljs$cst$1511$y$$),$shape__$1$jscomp$114$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1511$y$$)),$width$jscomp$218$$=Math.max($bounds$jscomp$85_height$jscomp$186$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$186$$,$APP.$cljs$cst$290$width$$),$shape__$1$jscomp$114$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$290$width$$));$bounds$jscomp$85_height$jscomp$186$$=Math.max($bounds$jscomp$85_height$jscomp$186$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$186$$,$APP.$cljs$cst$1522$height$$),$shape__$1$jscomp$114$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1522$height$$));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1273$$,$y$jscomp$496$$,$width$jscomp$218$$,$bounds$jscomp$85_height$jscomp$186$$),$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$114$$)],null)}();var $map__80397_map__80397__$1_style$jscomp$80$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$,0,null);$map__80397_map__80397__$1_style$jscomp$80$$=$APP.$cljs$core$__destructure_map$$($map__80397_map__80397__$1_style$jscomp$80$$);var $x$jscomp$1272$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80397_map__80397__$1_style$jscomp$80$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80397_map__80397__$1_style$jscomp$80$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80397_map__80397__$1_style$jscomp$80$$,$APP.$cljs$cst$290$width$$),$height$jscomp$184$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80397_map__80397__$1_style$jscomp$80$$,$APP.$cljs$cst$1522$height$$),$selrect_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80397_map__80397__$1_style$jscomp$80$$,$cljs$cst$5868$selrect_width$$),$selrect_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80397_map__80397__$1_style$jscomp$80$$,
$cljs$cst$5869$selrect_height$$);$text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$,1,null);$map__80397_map__80397__$1_style$jscomp$80$$=function(){var $G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$={pointerEvents:"all"};$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$=$APP.$cljs$core$truth_$$($render_wasm_QMARK_$jscomp$5$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$,{"--editor-container-width":"auto","--editor-container-height":"auto","--editor-container-min-width":""+((1>$selrect_width$$?1:$selrect_width$$)??"")+"px","--editor-container-min-height":""+((1>$selrect_height$$?1:$selrect_height$$)??"")+"px","--fallback-families":$APP.$cljs$core$seq$$($fallback_families$$)?""+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",
$fallback_families$$)??""):"sourcesanspro",display:"flex"}):$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$;$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$=$APP.$cljs$core$not$$($render_wasm_QMARK_$jscomp$5$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$,{"--editor-container-width":""+((1>$width$jscomp$216$$?1:$width$jscomp$216$$)??"")+"px",
"--editor-container-height":""+((1>$height$jscomp$184$$?1:$height$jscomp$184$$)??"")+"px"}):$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$;$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$=$APP.$cljs$core$not$$($render_wasm_QMARK_$jscomp$5$$)&&!$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1347$safari_16$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$,
{transform:"translate("+(($shape__$1$jscomp$114$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1510$x$$))-$x$jscomp$1272$$)+"px, "+(($shape__$1$jscomp$114$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1511$y$$))-$y$jscomp$494$$)+"px)"}):$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$;$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$)&&
!$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1347$safari_16$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$,{height:"100%",display:"flex",flexDirection:"column",justifyContent:$app$main$ui$workspace$shapes$text$v2_editor$shape__GT_justify$$($shape__$1$jscomp$114$$)}):$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$;$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$=
$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1353$safari_26$$)||$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1348$safari_18$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$,{position:"fixed","transform-origin":"top left",transform:"scale("+($maybe_zoom$jscomp$1$$??"")+")"}):$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$;return $APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1347$safari_16$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$,{position:"fixed",left:0,top:($shape__$1$jscomp$114$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1511$y$$))-$y$jscomp$494$$,"transform-origin":"top left",transform:$maybe_zoom$jscomp$1$$!=null?"scale("+($maybe_zoom$jscomp$1$$??"")+")":null}):$G__80404_G__80404__$1_G__80404__$2_G__80404__$3_G__80404__$4_G__80404__$5$$}();
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"text-editor",clipPath:"url(#"+($clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$??"")+")",transform:""+($text_modifier_ref$jscomp$4_transform$jscomp$108_vec__80394$$??""),"data-testid":"text-editor",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$123$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1272$$,y:$y$jscomp$494$$,
width:$width$jscomp$216$$,height:$height$jscomp$184$$})})}),(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$x$jscomp$1272$$,y:$y$jscomp$494$$,width:$width$jscomp$216$$,height:$height$jscomp$184$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{style:$map__80397_map__80397__$1_style$jscomp$80$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v2_editor$text_editor_html$$,{shape:$shape__$1$jscomp$114$$,"canvas-ref":$canvas_ref$jscomp$4_props_80393$$,"render-wasm?":$render_wasm_QMARK_$jscomp$5$$},
""+($shape_id$jscomp$170$$??""))})})]})}));var $app$util$text_svg_position$load_promises$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($handle_update_props_80433$$){var $shape$jscomp$1058$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_update_props_80433$$,"shape"),$on_update$jscomp$2$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_update_props_80433$$,"on-update");$handle_update_props_80433$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1058$$),
$APP.$rumext$v2$adapt$$($on_update$jscomp$2$$)],function($node$jscomp$470$$){return $node$jscomp$470$$!=null?$on_update$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_update$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1058$$,$node$jscomp$470$$):$on_update$jscomp$2$$($shape$jscomp$1058$$,$node$jscomp$470$$):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$text$html_text$text_shape$$,{ref:$handle_update_props_80433$$,shape:$shape$jscomp$1058$$,"grow-type":$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1058$$)},
["shape-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1058$$))].join(""))}),$app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_text_editing$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$){var $shape$jscomp$1063$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$,
"shape"),$shape_id$jscomp$173$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1063$$);$handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$);var $workspace_v2_editor_state$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_v2_editor_state$$),$workspace_editor$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor$$),$editor_state$jscomp$11$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$,$shape_id$jscomp$173$$),$v2_editor_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($workspace_v2_editor_state$$,$shape_id$jscomp$173$$);$handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$173$$)],
function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($shape_id$jscomp$173$$)});var $text_modifier$jscomp$7$$=$APP.$rumext$v2$deref$$($handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$),$shape__$1$jscomp$115$$=function(){if($editor_state$jscomp$11$$!=null){var $G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1063$$);
var $content$jscomp$inline_9149_editor_content$jscomp$inline_9145$$=$APP.$cljs$core$truth_$$($editor_state$jscomp$11$$)?$app$util$text_editor$export_content$$($editor_state$jscomp$11$$.getCurrentContent()):null;$G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$=$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$($shape$jscomp$1063$$,$G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$,
$content$jscomp$inline_9149_editor_content$jscomp$inline_9145$$)}else $G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$=$shape$jscomp$1063$$;if($v2_editor_state$$!=null&&$workspace_editor$$!=null){$content$jscomp$inline_9149_editor_content$jscomp$inline_9145$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$);var $editor_content$jscomp$inline_9150$$=
$APP.$app$util$text$content$dom__GT_cljs$$($workspace_editor$$.root);$G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$=$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$($G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$,$content$jscomp$inline_9149_editor_content$jscomp$inline_9145$$,$editor_content$jscomp$inline_9150$$)}return $G__80442__$1_JSCompiler_temp$jscomp$1885_JSCompiler_temp$jscomp$1886_content$jscomp$inline_9144$$}();
$handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$text_modifier$jscomp$7$$!=null?function(){var $map__80443_width$jscomp$220$$=$APP.$app$main$data$workspace$texts$apply_text_modifier$$($shape__$1$jscomp$115$$,$text_modifier$jscomp$7$$),$height$jscomp$188_map__80443__$1$$=$APP.$cljs$core$__destructure_map$$($map__80443_width$jscomp$220$$);$map__80443_width$jscomp$220$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$188_map__80443__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$188_map__80443__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$188_map__80443__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape__$1$jscomp$115$$,$APP.$cljs$cst$290$width$$,$map__80443_width$jscomp$220$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1522$height$$,$height$jscomp$188_map__80443__$1$$]))}():$shape__$1$jscomp$115$$;var $shape__$3$$=
$APP.$app$main$ui$hooks$use_equal_memo$$($handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$);$handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$3$$))],
function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$remove_text_modifier$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$3$$)))}});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$,{shape:$shape__$3$$,"on-update":$handle_update_shape$jscomp$2_props_80441_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$})}),$app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_texts$$=
(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$){var $objects$jscomp$807$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$,"objects"),$edition$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$,"edition"),$modifiers$jscomp$125$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$,
"modifiers");$editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$807$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$second$$)),$objects$jscomp$807$$)});
var $text_shapes__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$);$editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes__$1$$),$APP.$rumext$v2$adapt$$($edition$jscomp$9$$)],function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes__$1$$,$edition$jscomp$9$$)});$editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$=
$APP.$app$main$ui$hooks$use_equal_memo$$($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$);var $text_shapes_changes$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes__$1$$),$APP.$rumext$v2$adapt$$($edition$jscomp$9$$)],function(){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes__$1$$,$edition$jscomp$9$$)}),$text_shapes_modifiers$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($modifiers$jscomp$125$$),
$APP.$rumext$v2$adapt$$($text_shapes__$1$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers__$1$jscomp$20_p__80447$$){var $id$jscomp$1039$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers__$1$jscomp$20_p__80447$$,0,null);$modifiers__$1$jscomp$20_p__80447$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers__$1$jscomp$20_p__80447$$,
1,null);var $temp__5825__auto__$jscomp$419$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes__$1$$,$id$jscomp$1039$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$419$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1039$$,$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto__$jscomp$419$$,$modifiers__$1$jscomp$20_p__80447$$)],null):null}),$modifiers$jscomp$125$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $fonts$jscomp$38_text_nodes$jscomp$1$$=
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__80445_SHARP_$$){return $APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($p1__80445_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($text_shapes__$1$$)]));$fonts$jscomp$38_text_nodes$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1757$font_id$$),$fonts$jscomp$38_text_nodes$jscomp$1$$);return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,$fonts$jscomp$38_text_nodes$jscomp$1$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_text_editing$$,
{shape:$editing_shape_editing_shape__$1_props_80446_text_shapes$jscomp$4$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_modifiers_renderer$$,{"text-shapes":$text_shapes_modifiers$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_changes_renderer$$,{"text-shapes":$text_shapes_changes$$})]})},function($new_props$jscomp$7$$,$old_props$jscomp$6$$){return $new_props$jscomp$7$$.objects===$old_props$jscomp$6$$.objects&&
$new_props$jscomp$7$$.modifiers===$old_props$jscomp$6$$.modifiers&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$7$$.edition,$old_props$jscomp$6$$.edition)});var $app$main$ui$workspace$top_toolbar$image_upload_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $ref$jscomp$58$$=(0,$APP.$rumext$v2$use_ref$$)(null),$file_id$jscomp$433$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$on_click$jscomp$55$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]));
return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($ref$jscomp$58$$))}),$on_selected$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$433$$)],function($blobs$jscomp$3_params$jscomp$432$$){var $vbox$jscomp$39_y$jscomp$497$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$),$x$jscomp$1274$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$39_y$jscomp$497$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$39_y$jscomp$497$$)/
2;$vbox$jscomp$39_y$jscomp$497$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$39_y$jscomp$497$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$39_y$jscomp$497$$)/2;$blobs$jscomp$3_params$jscomp$432$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$433$$,$APP.$cljs$cst$3698$blobs$$,$APP.$cljs$core$seq$$($blobs$jscomp$3_params$jscomp$432$$),$APP.$cljs$cst$1676$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1274$$,
$vbox$jscomp$39_y$jscomp$497$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($blobs$jscomp$3_params$jscomp$432$$))});return(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsxs$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.image",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4838$insert_image$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.image",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4838$insert_image$$)])),onClick:$on_click$jscomp$55$$,className:"main_ui_workspace_top_toolbar__main-toolbar-options-button",children:[$APP.$app$main$ui$icons$img$$,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{"input-id":"image-upload",
accept:$APP.$app$main$data$workspace$media$accept_image_types$$,multi:!0,ref:$ref$jscomp$58$$,"on-selected":$on_selected$jscomp$1$$})]})})}),$app$main$ui$workspace$top_toolbar$toolbar_hidden_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($edition$jscomp$10_state$jscomp$1211$$){var $visibility$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1211$$,$APP.$cljs$cst$3752$hide_toolbar$$),$path_edit_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1211$$,
$APP.$cljs$cst$1923$edit_path$$),$selected$jscomp$188$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1211$$,$APP.$cljs$cst$1921$selected$$);$edition$jscomp$10_state$jscomp$1211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1211$$,$APP.$cljs$cst$2199$edition$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$188$$),1)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_state$$,
$edition$jscomp$10_state$jscomp$1211$$)!=null?!0:$visibility$$},$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$top_toolbar$top_toolbar_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($drawtool_props_80435$$){var $layout$jscomp$26$$=$drawtool_props_80435$$.layout;$drawtool_props_80435$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_drawing_tool$$);var $edition$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$profile$jscomp$76_read_only_QMARK_$jscomp$23$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$props$jscomp$399_test_tooltip_board_text$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$76_read_only_QMARK_$jscomp$23$$,$APP.$cljs$cst$575$props$$);$profile$jscomp$76_read_only_QMARK_$jscomp$23$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);var $rulers_QMARK_$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$),$hide_toolbar_QMARK_$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$top_toolbar$toolbar_hidden_ref$$),
$interrupt$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]))}),$select_drawtool$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$649$$){var $tool$jscomp$3$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$649$$),
"tool"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$select_for_drawing$$($tool$jscomp$3$$))})}),$toggle_debug_panel$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$26$$)],function(){$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$26$$,$cljs$cst$5617$collapse_left_sidebar$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5617$collapse_left_sidebar$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$2950$shortcuts$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5652$debug_panel$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar")]))}),$toggle_toolbar$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$650$$){$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$650$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$common$toggle_toolbar_visibility$$())});$props$jscomp$399_test_tooltip_board_text$$=$APP.$cljs$core$not$$($APP.$cljs$cst$3750$workspace_visited$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$399_test_tooltip_board_text$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.frame-first-time",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4794$draw_frame$$)])):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.frame",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4794$draw_frame$$)]));return $profile$jscomp$76_read_only_QMARK_$jscomp$23$$?null:(0,$APP.$rumext$v2$jsxs$$)("aside",{className:"main_ui_workspace_top_toolbar__main-toolbar "+($APP.$cljs$core$not$$($rulers_QMARK_$jscomp$4$$)?"main_ui_workspace_top_toolbar__main-toolbar-no-rulers":"")+
" "+($APP.$cljs$core$truth_$$($hide_toolbar_QMARK_$$)?"main_ui_workspace_top_toolbar__main-toolbar-hidden":""),children:[(0,$APP.$rumext$v2$jsxs$$)("ul",{"data-testid":"toolbar-options",className:"main_ui_workspace_top_toolbar__main-toolbar-options",children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.move",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$1798$move$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.move",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$1798$move$$)])),onClick:$interrupt$$,className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($drawtool_props_80435$$==null&&$APP.$cljs$core$not$$($edition$jscomp$11$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$move$$})}),
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$props$jscomp$399_test_tooltip_board_text$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.frame",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4794$draw_frame$$)])),onClick:$select_drawtool$$,"data-tool":"frame","data-testid":"artboard-btn",
className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80435$$,$APP.$cljs$cst$1606$frame$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$board$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.rect",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4815$draw_rect$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.rect",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4815$draw_rect$$)])),onClick:$select_drawtool$$,"data-tool":"rect","data-testid":"rect-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80435$$,$APP.$cljs$cst$1611$rect$$)?
"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$rectangle$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.ellipse",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4797$draw_ellipse$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.ellipse",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4797$draw_ellipse$$)])),onClick:$select_drawtool$$,"data-tool":"circle","data-testid":"ellipse-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80435$$,$APP.$cljs$cst$1417$circle$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$elipse$$})}),
(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4813$draw_text$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4813$draw_text$$)])),
onClick:$select_drawtool$$,"data-tool":"text",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80435$$,$APP.$cljs$cst$1588$text$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$text$$})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$image_upload_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.curve",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4883$draw_curve$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.curve",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4883$draw_curve$$)])),onClick:$select_drawtool$$,"data-tool":"curve","data-testid":"curve-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80435$$,$APP.$cljs$cst$2052$curve$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$curve$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.path",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4816$draw_path$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.path",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4816$draw_path$$)])),onClick:$select_drawtool$$,"data-tool":"path","data-testid":"path-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80435$$,$APP.$cljs$cst$296$path$$)?"main_ui_workspace_top_toolbar__selected":
""),children:$APP.$app$main$ui$icons$path$$})}),$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")?(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.plugins",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$3197$plugins$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.plugins",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$3197$plugins$$)])),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-plugins-manager",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:toolbar"],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4894$plugin_management$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))},"data-tool":"plugins","data-testid":"plugins-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button",children:$APP.$app$main$ui$icons$puzzle$$})}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",
{title:"Debugging tool",onClick:$toggle_debug_panel$$,className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$contains_QMARK_$$($layout$jscomp$26$$,$cljs$cst$5652$debug_panel$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$bug$$})}):null]})]}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.toggle-toolbar"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.toggle-toolbar"),
onClick:$toggle_toolbar$$,className:"main_ui_workspace_top_toolbar__toolbar-handler",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_top_toolbar__toolbar-handler-btn"})})]})});var $app$main$ui$workspace$viewport$actions$invalid_paste_targets$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["INPUT",null,"TEXTAREA",null],null),null);var $app$main$ui$workspace$viewport$comments$comments_layer_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_80469_vport$jscomp$11$$){var $zoom$jscomp$85$$=$props_80469_vport$jscomp$11$$.zoom,$file_id$jscomp$434$$=$props_80469_vport$jscomp$11$$.fileId,$vbox$jscomp$40_vport_w$$=$props_80469_vport$jscomp$11$$.vbox,$page_id$jscomp$445$$=$props_80469_vport$jscomp$11$$.pageId;$props_80469_vport$jscomp$11$$=$props_80469_vport$jscomp$11$$.vport;var $pos_x$jscomp$6_vbox_x$jscomp$1$$=
$vbox$jscomp$40_vport_w$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$40_vport_w$$,$APP.$cljs$cst$1510$x$$),$pos_y$jscomp$6_vbox_y$jscomp$1$$=$vbox$jscomp$40_vport_w$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$40_vport_w$$,$APP.$cljs$cst$1511$y$$);$vbox$jscomp$40_vport_w$$=$props_80469_vport$jscomp$11$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80469_vport$jscomp$11$$,$APP.$cljs$cst$290$width$$);var $vport_h$$=$props_80469_vport$jscomp$11$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80469_vport$jscomp$11$$,$APP.$cljs$cst$1522$height$$);$pos_x$jscomp$6_vbox_x$jscomp$1$$=-$pos_x$jscomp$6_vbox_x$jscomp$1$$*$zoom$jscomp$85$$;$pos_y$jscomp$6_vbox_y$jscomp$1$$=-$pos_y$jscomp$6_vbox_y$jscomp$1$$*$zoom$jscomp$85$$;var $profile$jscomp$77$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$local$jscomp$31$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$threads_map$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$threads$$),
$threads$jscomp$12$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($threads_map$jscomp$7$$),$APP.$rumext$v2$adapt$$($local$jscomp$31$$),$APP.$rumext$v2$adapt$$($profile$jscomp$77$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$445$$)],function(){return $APP.$app$main$data$comments$apply_filters$$($local$jscomp$31$$,$profile$jscomp$77$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80468_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80468_SHARP_$$),
$page_id$jscomp$445$$)},$APP.$cljs$core$vals$$($threads_map$jscomp$7$$)))}),$viewport$jscomp$6$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($props_80469_vport$jscomp$11$$,$APP.$cljs$cst$1650$offset_x$$,$pos_x$jscomp$6_vbox_x$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1651$offset_y$$,$pos_y$jscomp$6_vbox_y$jscomp$1$$])),$on_draft_cancel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2169$interrupt$$)}),
$on_draft_submit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($draft$jscomp$3$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$create_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$03$$($draft$jscomp$3$$,$APP.$cljs$core$identity$$,!0))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$434$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$comments$initialize_comments$$($file_id$jscomp$434$$));
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4273$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_finalize$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_comments__comments-section",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"comments",style:{width:""+($vbox$jscomp$40_vport_w$$??"")+"px",height:""+($vport_h$$??"")+"px"},className:"main_ui_workspace_viewport_comments__workspace-comments-container",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{style:{transform:"translate("+($pos_x$jscomp$6_vbox_x$jscomp$1$$??"")+"px, "+($pos_y$jscomp$6_vbox_y$jscomp$1$$??"")+"px)"},className:"main_ui_workspace_viewport_comments__threads",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$208$$,$JSCompiler_inline_result$jscomp$1892_thread_group$jscomp$2$$){var $JSCompiler_temp_const$jscomp$1890$$=$out_arr__44124__auto__$jscomp$208$$.push,$group_QMARK_$jscomp$inline_9194$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1892_thread_group$jscomp$2$$)>1,$thread$jscomp$inline_9195$$=$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1892_thread_group$jscomp$2$$);$JSCompiler_inline_result$jscomp$1892_thread_group$jscomp$2$$=$group_QMARK_$jscomp$inline_9194$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_group_STAR_$$,{threadGroup:$JSCompiler_inline_result$jscomp$1892_thread_group$jscomp$2$$,zoom:$zoom$jscomp$85$$},$APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$inline_9195$$)):
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_bubble_STAR_$$,{thread:$thread$jscomp$inline_9195$$,zoom:$zoom$jscomp$85$$,isOpen:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$inline_9195$$),$APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$31$$))},$APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$inline_9195$$));$JSCompiler_temp_const$jscomp$1890$$.call($out_arr__44124__auto__$jscomp$208$$,
$JSCompiler_inline_result$jscomp$1892_thread_group$jscomp$2$$);return $out_arr__44124__auto__$jscomp$208$$},[],$APP.$app$main$ui$comments$group_bubbles$cljs$0core$0IFn$0_invoke$0arity$04$$($zoom$jscomp$85$$,$threads$jscomp$12$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$)),function(){var $temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$=$APP.$cljs$cst$3434$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$31$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$)?
($temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($threads_map$jscomp$7$$,$temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$),$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$)?$APP.$cljs$core$seq$$($APP.$app$main$data$comments$apply_filters$$($local$jscomp$31$$,$profile$jscomp$77$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$],null)))?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_thread_STAR_$$,{thread:$temp__5825__auto__$jscomp$427_temp__5825__auto____$1$jscomp$24$$,viewport:$viewport$jscomp$6$$,zoom:$zoom$jscomp$85$$}):null:null):null}(),function(){var $temp__5825__auto__$jscomp$428$$=$APP.$cljs$cst$3435$draft$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$31$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$428$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$comments$comment_floating_thread_draft_STAR_$$,{draft:$temp__5825__auto__$jscomp$428$$,onCancel:$on_draft_cancel$jscomp$1$$,onSubmit:$on_draft_submit$jscomp$1$$,viewport:$viewport$jscomp$6$$,zoom:$zoom$jscomp$85$$}):null}()]})})})});var $app$main$ui$workspace$viewport$debug$debug_drop_zones$$=function($p1__80504_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__80504_SHARP_$$,function($new_props_80509$$,$old_props_80510$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80509$$.objects,$old_props_80510$$.objects)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80509$$["selected-shapes"],$old_props_80510$$["selected-shapes"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80509$$["hover-top-frame-id"],
$old_props_80510$$["hover-top-frame-id"])})}(function($bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$){var $objects$jscomp$811$$=$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$.objects,$zoom$jscomp$88$$=$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$.objects,$selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$=$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$["selected-shapes"];
$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$=$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$["hover-top-frame-id"];$selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$)))?
$APP.$cljs$core$first$$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$):null;$selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$=$APP.$cljs$core$truth_$$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$)?$selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$811$$,$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$);$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$=
$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$811$$),function($p1__80506_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$811$$,$p1__80506_SHARP_$$),$APP.$cljs$cst$1604$points$$)});return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$)?$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$):
$selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$)?($bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$=$APP.$app$common$geom$shapes$flex_layout$drop_area$get_drop_areas$$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$,$objects$jscomp$811$$,$bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$),(0,$APP.$rumext$v2$jsx$$)("g",{className:"debug-layout",pointerEvents:"none",transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$2_selected_shapes$jscomp$29_shape$jscomp$1070$$),
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$211$$,$drop_area_p__80512$$){var $idx$jscomp$132$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_area_p__80512$$,0,null);$drop_area_p__80512$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_area_p__80512$$,1,null);$out_arr__44124__auto__$jscomp$211$$.push((0,$APP.$rumext$v2$jsxs$$)("g",{className:"drop-area",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),
y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),style:{fill:"blue",fillOpacity:.3,stroke:"red",strokeWidth:$zoom$jscomp$88$$/1,strokeDasharray:""+3/$zoom$jscomp$88$$+" "+6/$zoom$jscomp$88$$}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),
y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$),alignmentBaseline:"hanging",fill:"black",children:$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80512$$)})]},"drop-area-"+($idx$jscomp$132$$??"")));return $out_arr__44124__auto__$jscomp$211$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($bounds$jscomp$88_drop_areas$jscomp$2_hover_top_frame_id$jscomp$3_props_80507$$))})):
null}),$app$main$ui$workspace$viewport$debug$shape_parent_bound$$=function($p1__80518_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__80518_SHARP_$$,function($new_props_80521$$,$old_props_80522$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80521$$.shape,$old_props_80522$$.shape)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80521$$.parent,$old_props_80522$$.parent)})}(function($i1$jscomp$4_props_80520$$){var $i2$jscomp$4_parent$jscomp$302$$=
$i1$jscomp$4_props_80520$$.parent,$zoom$jscomp$89$$=$i1$jscomp$4_props_80520$$.zoom,$i4$jscomp$1_vec__80523$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80520$$.shape),$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$4_parent$jscomp$302$$));$i1$jscomp$4_props_80520$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80523$$,0,null);$i2$jscomp$4_parent$jscomp$302$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80523$$,1,null);var $i3$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80523$$,2,null);$i4$jscomp$1_vec__80523$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80523$$,3,null);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80519_SHARP_$$){return""+
($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80519_SHARP_$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80519_SHARP_$$)??"")},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$i1$jscomp$4_props_80520$$,$i2$jscomp$4_parent$jscomp$302$$,$i3$jscomp$1$$,$i4$jscomp$1_vec__80523$$],null))),style:{fill:"none",stroke:"red",strokeWidth:1/$zoom$jscomp$89$$}}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80520$$),
y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80520$$),x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$4_parent$jscomp$302$$),y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$4_parent$jscomp$302$$),style:{stroke:"green",strokeWidth:1/$zoom$jscomp$89$$}}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80520$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80520$$),
x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($i4$jscomp$1_vec__80523$$),y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($i4$jscomp$1_vec__80523$$),style:{stroke:"blue",strokeWidth:1/$zoom$jscomp$89$$}})]})});var $app$main$ui$workspace$viewport$frame_grid$grid_display_frame_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($clip_area_parents_ref_props_80568$$){var $zoom$jscomp$97$$=$clip_area_parents_ref_props_80568$$.zoom,$frame$jscomp$82$$=$clip_area_parents_ref_props_80568$$.frame,$transforming$$=$clip_area_parents_ref_props_80568$$.transforming,$frame_id$jscomp$148$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$82$$);$clip_area_parents_ref_props_80568$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$148$$)],function(){return $app$main$refs$shape_parents$$($frame_id$jscomp$148$$)});var $parents$jscomp$22$$=$APP.$rumext$v2$deref$$($clip_area_parents_ref_props_80568$$);$clip_area_parents_ref_props_80568$$=$app$main$ui$workspace$viewport$frame_grid$frame_clip_area$$($frame$jscomp$82$$,$parents$jscomp$22$$);var $clip_id$jscomp$5$$=""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$82$$)??
"")+"-grid-clip",$transform_QMARK_$$=function(){var $or__5025__auto__$jscomp$1325$$=$APP.$cljs$core$contains_QMARK_$$($transforming$$,$frame_id$jscomp$148$$);return $or__5025__auto__$jscomp$1325$$?$or__5025__auto__$jscomp$1325$$:$APP.$cljs$core$some$$(function($p1__80567_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($transforming$$,$p1__80567_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$parents$jscomp$22$$))}();return $APP.$cljs$core$truth_$$($transform_QMARK_$$)?
null:(0,$APP.$rumext$v2$jsxs$$)("g",{clipPath:"url(#"+($clip_id$jscomp$5$$??"")+")",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$5$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_80568$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_80568$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_80568$$),
height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_80568$$)})})}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$217$$,$p__80569$$){var $index$jscomp$563$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80569$$,0,null),$grid$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80569$$,1,null);$out_arr__44124__auto__$jscomp$217$$.push(function(){var $props$jscomp$410$$=
{key:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$82$$)),"-grid-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$563$$)].join(""),frame:$frame$jscomp$82$$,zoom:$zoom$jscomp$97$$,grid:$grid$jscomp$19$$},$G__80573_G__80573__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$19$$);$G__80573_G__80573__$1$$=$G__80573_G__80573__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__80573_G__80573__$1$$.$fqn$:
null;switch($G__80573_G__80573__$1$$){case "square":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$frame_grid$square_grid_STAR_$$,$props$jscomp$410$$);case "column":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$,$props$jscomp$410$$);case "row":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$,$props$jscomp$410$$);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80573_G__80573__$1$$)].join(""));}}());return $out_arr__44124__auto__$jscomp$217$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$2050$grids$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$82$$))))]})}),$app$main$ui$workspace$viewport$frame_grid$frame_grid_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($frames$jscomp$32_props_80576$$){var $zoom$jscomp$98$$=
$frames$jscomp$32_props_80576$$.zoom,$transform$jscomp$112$$=$frames$jscomp$32_props_80576$$.transform,$selected$jscomp$195$$=$frames$jscomp$32_props_80576$$.selected,$focus$jscomp$18$$=$frames$jscomp$32_props_80576$$.focus;$frames$jscomp$32_props_80576$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$viewport$frame_grid$has_grid_QMARK_$$,$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_frames$$));var $transforming$jscomp$1$$=$transform$jscomp$112$$!=null?$selected$jscomp$195$$:
null;return(0,$APP.$rumext$v2$jsx$$)("g",{className:"grid-display",style:{pointerEvents:"none"},children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$218$$,$frame$jscomp$83$$){$out_arr__44124__auto__$jscomp$218$$.push($APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$83$$,0))&&($APP.$cljs$core$empty_QMARK_$$($focus$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$18$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$83$$)))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$frame_grid$grid_display_frame_STAR_$$,{zoom:$zoom$jscomp$98$$,frame:$frame$jscomp$83$$,transforming:$transforming$jscomp$1$$},["grid-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$83$$))].join("")):null);return $out_arr__44124__auto__$jscomp$218$$},[],$frames$jscomp$32_props_80576$$)})});var $app$main$ui$workspace$viewport$gradients$gradient_handlers_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$){var $zoom$jscomp$102$$=$props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$.zoom,$id$jscomp$1047$$=$props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$.id;$props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1047$$)],
function(){return $app$main$refs$object_by_id$$($id$jscomp$1047$$)});$props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$);var $editing_stop$jscomp$4_state$jscomp$1214$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$colorpicker$$),$gradient$jscomp$29$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1214$$),$stops$jscomp$23$$=$app$main$features$use_feature$$("render-wasm/v1")?
$APP.$cljs$core$vec$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(16,$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1214$$))):$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1214$$);$editing_stop$jscomp$4_state$jscomp$1214$$=$APP.$cljs$cst$4162$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1214$$);return $gradient$jscomp$29$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1047$$,
$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handlers_impl_STAR_$$,{zoom:$zoom$jscomp$102$$,gradient:$gradient$jscomp$29$$,stops:$stops$jscomp$23$$,editing:$editing_stop$jscomp$4_state$jscomp$1214$$,shape:$props_80597_shape$jscomp$1076_shape_ref$jscomp$3$$}):null});var $app$main$ui$workspace$viewport$grid_layout_editor$grid_cell$$=function($component__44666__auto__$jscomp$3$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($component__44666__auto__$jscomp$3$$,function($new_props_80635$$,$old_props_80636$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$.zoom,$old_props_80636$$.zoom)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$["on-clear-modifiers"],$old_props_80636$$["on-clear-modifiers"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$["on-set-modifiers"],
$old_props_80636$$["on-set-modifiers"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$.shape,$old_props_80636$$.shape)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$["layout-data"],$old_props_80636$$["layout-data"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$.cell,$old_props_80636$$.cell)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$["selected?"],$old_props_80636$$["selected?"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80635$$["hover?"],
$old_props_80636$$["hover?"])})}(function($cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$){var $layout_data$jscomp$20$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$["layout-data"],$selected_QMARK_$jscomp$26$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$["selected?"],$cell$jscomp$47$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$.cell,$hover_QMARK_$jscomp$13$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$["hover?"],$zoom$jscomp$106$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$.zoom,
$on_clear_modifiers$jscomp$1$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$["on-clear-modifiers"],$on_set_modifiers$jscomp$1$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$["on-set-modifiers"],$shape$jscomp$1079$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$.shape;$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$=$APP.$app$common$geom$shapes$grid_layout$positions$cell_bounds$$($layout_data$jscomp$20$$,$cell$jscomp$47$$);var $cell_origin$jscomp$3_handle_pointer_leave$$=
$APP.$app$common$geom$shapes$points$origin$$($cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$),$cell_width$jscomp$3$$=$APP.$app$common$geom$shapes$points$width_points$$($cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$),$cell_height$jscomp$1$$=$APP.$app$common$geom$shapes$points$height_points$$($cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$),$cell_center$jscomp$1$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$),
$cell_origin__$1$jscomp$1$$=$APP.$app$common$geom$point$transform$$($cell_origin$jscomp$3_handle_pointer_leave$$,$APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)));$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$hover_grid_cell$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),!0))});$cell_origin$jscomp$3_handle_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$hover_grid_cell$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),!1))});var $handle_pointer_down$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)),$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$26$$)],function($JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$){if($app$util$dom$left_mouse_QMARK_$$($JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$))if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$26$$)?
$APP.$app$util$keyboard$mod_QMARK_$$($JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$)||$JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$.shiftKey:$selected_QMARK_$jscomp$26$$))$JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$remove_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)));else if($APP.$cljs$core$not$$($selected_QMARK_$jscomp$26$$)&&$APP.$app$util$keyboard$mod_QMARK_$$($JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$)){$JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$10979_grid_id$jscomp$inline_13716$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$);var $cell_id$jscomp$inline_13717$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$);$JSCompiler_inline_result$jscomp$10979_grid_id$jscomp$inline_13716$$=$app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$10979_grid_id$jscomp$inline_13716$$,
$cell_id$jscomp$inline_13717$$,!1);$JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$=$JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$10979_grid_id$jscomp$inline_13716$$)}else $JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$=
$APP.$cljs$core$not$$($selected_QMARK_$jscomp$26$$)&&$JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$.shiftKey?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),
!0)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$set_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)));else $JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$=null;return $JSCompiler_temp$jscomp$10974_JSCompiler_temp$jscomp$10975_JSCompiler_temp$jscomp$10976_JSCompiler_temp_const$jscomp$10977_event$jscomp$686$$}),
$handle_context_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)),$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$26$$)],function($event$jscomp$687_position$jscomp$223$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$687_position$jscomp$223$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$687_position$jscomp$223$$);
$event$jscomp$687_position$jscomp$223$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$687_position$jscomp$223$$);return $APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$26$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_grid_cell_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$event$jscomp$687_position$jscomp$223$$,$APP.$cljs$cst$4420$grid_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)],
null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$grid_layout$editor$set_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$show_grid_cell_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$event$jscomp$687_position$jscomp$223$$,
$APP.$cljs$cst$4420$grid_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$)],null))]))});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"cell-editor",children:[$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3057$grid_cells$$)?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"debug-cell",pointerEvents:"none",transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$))??
""),children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),width:$cell_width$jscomp$3$$,height:$cell_height$jscomp$1$$,fill:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),$APP.$cljs$cst$1672$auto$$)?"green":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),
$APP.$cljs$cst$1673$manual$$)?"red":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),$APP.$cljs$cst$1674$area$$)?"yellow":"black",fillOpacity:.2}),$APP.$cljs$core$seq$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))?(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+$cell_width$jscomp$3$$+-(7/$zoom$jscomp$106$$),
cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+7/$zoom$jscomp$106$$,r:5/$zoom$jscomp$106$$,fill:"red"}):null]}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:$cell_width$jscomp$3$$,height:$cell_height$jscomp$1$$,className:$APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["main_ui_workspace_viewport_grid_layout_editor__grid-cell-outline",!0,"main_ui_workspace_viewport_grid_layout_editor__hover",
$hover_QMARK_$jscomp$13$$,"main_ui_workspace_viewport_grid_layout_editor__selected",$selected_QMARK_$jscomp$26$$])),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$))??""),onContextMenu:$handle_context_menu$$,y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),
onPointerDown:$handle_pointer_down$jscomp$3$$,onPointerLeave:$cell_origin$jscomp$3_handle_pointer_leave$$,onPointerEnter:$cell_bounds$jscomp$5_handle_pointer_enter_props_80634$$}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_cell_area_label$$,{origin:$cell_origin__$1$jscomp$1$$,width:$cell_width$jscomp$3$$,zoom:$zoom$jscomp$106$$,text:$APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)}):
null,$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$26$$)?function(){var $handlers$jscomp$8$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+-10/$zoom$jscomp$106$$,
$cell_width$jscomp$3$$,20/$zoom$jscomp$106$$,$APP.$cljs$cst$1656$row$$],null),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+$cell_width$jscomp$3$$+-10/$zoom$jscomp$106$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),20/$zoom$jscomp$106$$,$cell_height$jscomp$1$$,$APP.$cljs$cst$216$column$$],null),new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+$cell_height$jscomp$1$$+-10/$zoom$jscomp$106$$,$cell_width$jscomp$3$$,20/$zoom$jscomp$106$$,$APP.$cljs$cst$1656$row$$],null),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+
-10/$zoom$jscomp$106$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),20/$zoom$jscomp$106$$,$cell_height$jscomp$1$$,$APP.$cljs$cst$216$column$$],null)],null);return(0,$APP.$rumext$v2$jsx$$)("g",{transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1079$$))??""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$220$$,
$dir$jscomp$10_p__80641$$){var $handler$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__80641$$,0,null),$x$jscomp$1281$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__80641$$,1,null),$y$jscomp$505$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__80641$$,2,null),$width$jscomp$231$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__80641$$,3,null),$height$jscomp$198$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__80641$$,
4,null);$dir$jscomp$10_p__80641$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__80641$$,5,null);$out_arr__44124__auto__$jscomp$220$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_cell_handler$$,{y:$y$jscomp$505$$,width:$width$jscomp$231$$,"on-clear-modifiers":$on_clear_modifiers$jscomp$1$$,"on-set-modifiers":$on_set_modifiers$jscomp$1$$,shape:$shape$jscomp$1079$$,x:$x$jscomp$1281$$,"layout-data":$layout_data$jscomp$20$$,cell:$cell$jscomp$47$$,
handler:$handler$jscomp$49$$,direction:$dir$jscomp$10_p__80641$$,height:$height$jscomp$198$$},"resize-"+($APP.$app$common$data$name$$($handler$jscomp$49$$)??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)??"")));return $out_arr__44124__auto__$jscomp$220$$},[],$handlers$jscomp$8$$)})}():null]})}),$app$main$ui$workspace$viewport$grid_layout_editor$track$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_clear_modifiers$jscomp$5_props_80691$$){var $shape$jscomp$1083$$=
$on_clear_modifiers$jscomp$5_props_80691$$.shape,$zoom$jscomp$111$$=$on_clear_modifiers$jscomp$5_props_80691$$.zoom,$type$jscomp$716$$=$on_clear_modifiers$jscomp$5_props_80691$$.type,$index$jscomp$571$$=$on_clear_modifiers$jscomp$5_props_80691$$.index,$snap_pixel_QMARK_$jscomp$12$$=$on_clear_modifiers$jscomp$5_props_80691$$["snap-pixel?"],$track_data$$=$on_clear_modifiers$jscomp$5_props_80691$$["track-data"],$layout_data$jscomp$22$$=$on_clear_modifiers$jscomp$5_props_80691$$["layout-data"],$hovering_QMARK_$jscomp$4$$=
$on_clear_modifiers$jscomp$5_props_80691$$["hovering?"],$drop_QMARK_$jscomp$2$$=$on_clear_modifiers$jscomp$5_props_80691$$["drop?"],$on_start_reorder_track$$=$on_clear_modifiers$jscomp$5_props_80691$$["on-start-reorder-track"],$on_move_reorder_track$$=$on_clear_modifiers$jscomp$5_props_80691$$["on-move-reorder-track"],$on_end_reorder_track$$=$on_clear_modifiers$jscomp$5_props_80691$$["on-end-reorder-track"],$on_set_modifiers$jscomp$5$$=$on_clear_modifiers$jscomp$5_props_80691$$["on-set-modifiers"];
$on_clear_modifiers$jscomp$5_props_80691$$=$on_clear_modifiers$jscomp$5_props_80691$$["on-clear-modifiers"];var $track_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$start_p$jscomp$18_vec__80692$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$1083$$),$layout_gap_row$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_p$jscomp$18_vec__80692$$,0,null),$layout_gap_col$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_p$jscomp$18_vec__80692$$,
1,null),$bounds$jscomp$93$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$);$start_p$jscomp$18_vec__80692$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);var $hpt$$=$APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$93$$,$APP.$cljs$cst$1899$h$$,$start_p$jscomp$18_vec__80692$$),$vpt$$=$APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$93$$,$APP.$cljs$cst$3670$v$$,$start_p$jscomp$18_vec__80692$$),$marker_p$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,$APP.$cljs$cst$216$column$$)?function(){var $G__80699$$=$APP.$app$common$geom$point$subtract$$($hpt$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,20/$zoom$jscomp$111$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$571$$,0)?$APP.$app$common$geom$point$subtract$$($G__80699$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$layout_gap_col$jscomp$15$$/
2)):$G__80699$$}():function(){var $G__80700$$=$APP.$app$common$geom$point$subtract$$($vpt$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,20/$zoom$jscomp$111$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$571$$,0)?$APP.$app$common$geom$point$subtract$$($G__80700$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$layout_gap_row$jscomp$15$$/2)):$G__80700$$}(),$text_p$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,
$APP.$cljs$cst$216$column$$)?$hpt$$:$vpt$$,$handle_blur_track_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$))],function($event$jscomp$688_target$jscomp$166$$){$event$jscomp$688_target$jscomp$166$$=$APP.$app$util$dom$get_target$$($event$jscomp$688_target$jscomp$166$$);var $track_type$jscomp$1_value$jscomp$1002$$=$APP.$cuerdas$core$upper$$($APP.$app$util$dom$get_input_value$$($event$jscomp$688_target$jscomp$166$$)),
$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($track_type$jscomp$1_value$jscomp$1002$$);$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$=$APP.$cljs$core$truth_$$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$)?0>$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$?0:$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$:
null;$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$=$APP.$cuerdas$core$ends_with_QMARK_$$($track_type$jscomp$1_value$jscomp$1002$$,"%")?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1670$percent$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$,50)],null):$APP.$cuerdas$core$ends_with_QMARK_$$($track_type$jscomp$1_value$jscomp$1002$$,
"FR")?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1660$flex$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$,1)],null):$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1671$fixed$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$,
100)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1672$auto$$,null],null);$track_type$jscomp$1_value$jscomp$1002$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$,0,null);$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$,
1,null);$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$=$track_type$jscomp$1_value$jscomp$1002$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$track_type$jscomp$1_value$jscomp$1002$$,$APP.$cljs$cst$260$value$$,$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$],null):null;$app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($track_input_ref$$),$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$));
return $track_type$jscomp$1_value$jscomp$1002$$!=null?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$)],null),$type$jscomp$716$$,$index$jscomp$571$$,$track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$)),$APP.$app$util$dom$set_data_BANG_$$($event$jscomp$688_target$jscomp$166$$,
"default-value",$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data__$1_value__$1$jscomp$83_value_int_value_int__$1_vec__80701$$))):$APP.$app$util$object$set_BANG_$$($event$jscomp$688_target$jscomp$166$$,"value",$APP.$app$util$dom$get_attribute$$($event$jscomp$688_target$jscomp$166$$,"data-default-value"))}),$handle_keydown_track_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$689$$){var $enter_QMARK_$jscomp$7$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$689$$),
$esc_QMARK_$jscomp$9$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$689$$);$APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$7$$)&&$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$689$$));return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$9$$)?$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$689$$)):null}),$handle_pointer_enter$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$)),
$APP.$rumext$v2$adapt$$($type$jscomp$716$$),$APP.$rumext$v2$adapt$$($index$jscomp$571$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$hover_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$)],null),$type$jscomp$716$$,$index$jscomp$571$$,!0))}),$handle_pointer_leave$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$)),
$APP.$rumext$v2$adapt$$($type$jscomp$716$$),$APP.$rumext$v2$adapt$$($index$jscomp$571$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$hover_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$)],null),$type$jscomp$716$$,$index$jscomp$571$$,!1))}),$track_before$jscomp$3_track_list_prop$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,
$APP.$cljs$cst$216$column$$)?$APP.$cljs$cst$3662$column_tracks$$:$APP.$cljs$cst$3661$row_tracks$$,$text_height_vec__80695$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$)-36/$zoom$jscomp$111$$,function(){var $y__5111__auto__$jscomp$173$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);return 0>$y__5111__auto__$jscomp$173$$?0:$y__5111__auto__$jscomp$173$$}(),36/$zoom$jscomp$111$$],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$)-function(){var $y__5111__auto__$jscomp$174$$=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);return 0>$y__5111__auto__$jscomp$174$$?0:$y__5111__auto__$jscomp$174$$}(),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$)-36/$zoom$jscomp$111$$,function(){var $y__5111__auto__$jscomp$175$$=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);return 0>$y__5111__auto__$jscomp$175$$?0:$y__5111__auto__$jscomp$175$$}(),36/$zoom$jscomp$111$$],null),$text_x$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__80695$$,0,null),$text_y$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__80695$$,
1,null),$text_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__80695$$,2,null);$text_height_vec__80695$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__80695$$,3,null);var $handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__80698$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_reorder_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$716$$),$APP.$rumext$v2$adapt$$($index$jscomp$571$$)],
function(){return $on_start_reorder_track$$.$cljs$core$IFn$_invoke$arity$2$?$on_start_reorder_track$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,$index$jscomp$571$$):$on_start_reorder_track$$($type$jscomp$716$$,$index$jscomp$571$$)}),$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_end_reorder_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$716$$),$APP.$rumext$v2$adapt$$($index$jscomp$571$$)],
function($G__80712_event$jscomp$690$$,$position$jscomp$227$$){$G__80712_event$jscomp$690$$=!$APP.$app$util$keyboard$mod_QMARK_$$($G__80712_event$jscomp$690$$);return $on_end_reorder_track$$.$cljs$core$IFn$_invoke$arity$4$?$on_end_reorder_track$$.$cljs$core$IFn$_invoke$arity$4$($type$jscomp$716$$,$index$jscomp$571$$,$position$jscomp$227$$,$G__80712_event$jscomp$690$$):$on_end_reorder_track$$($type$jscomp$716$$,$index$jscomp$571$$,$position$jscomp$227$$,$G__80712_event$jscomp$690$$)}),$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_move_reorder_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$716$$),$APP.$rumext$v2$adapt$$($index$jscomp$571$$)],function($_$jscomp$3096$$,$position$jscomp$228$$){return $on_move_reorder_track$$.$cljs$core$IFn$_invoke$arity$3$?$on_move_reorder_track$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$716$$,$index$jscomp$571$$,$position$jscomp$228$$):$on_move_reorder_track$$($type$jscomp$716$$,$index$jscomp$571$$,$position$jscomp$228$$)}),
$handle_show_track_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$){$APP.$app$util$dom$stop_propagation$$($G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$);$APP.$app$util$dom$prevent_default$$($G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$);$G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$=
$APP.$app$util$dom$get_client_position$$($G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$);$G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$,
$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,40):$G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$;$G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,$APP.$cljs$cst$1656$row$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,30):$G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_track_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1676$position$$,$G__80717$jscomp$inline_9225_G__80717__$1$jscomp$inline_9226_event$jscomp$691_position$jscomp$229$$,$APP.$cljs$cst$4420$grid_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$),
$APP.$cljs$cst$139$type$$,$type$jscomp$716$$,$APP.$cljs$cst$1795$index$$,$index$jscomp$571$$],null)))}),$small_QMARK__trackwidth$$=$text_width$$*$zoom$jscomp$111$$,$medium_QMARK_$$=$small_QMARK__trackwidth$$>=60&&$small_QMARK__trackwidth$$<110;$small_QMARK__trackwidth$$=$small_QMARK__trackwidth$$<60;$track_before$jscomp$3_track_list_prop$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($layout_data$jscomp$22$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$track_before$jscomp$3_track_list_prop$$,$index$jscomp$571$$-1],null));$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__80698$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5874$on_drag_start$$,$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__80698$$,$cljs$cst$5875$on_drag_end$$,$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$,$cljs$cst$5877$on_drag_position$$,$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$],
null));$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$=$APP.$cljs$core$__destructure_map$$($handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__80698$$);$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__80698$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$,$cljs$cst$5878$handle_pointer_down$$);$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$,
$cljs$cst$5879$handle_lost_pointer_capture$$);$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$,$cljs$cst$5880$handle_pointer_move$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($track_data$$)],function(){return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($track_input_ref$$),$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data$$))});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"track",children:[(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerEnter:$handle_pointer_enter$jscomp$1$$,onPointerLeave:$handle_pointer_leave$jscomp$1$$,transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,$APP.$cljs$cst$216$column$$)?""+($APP.$app$common$geom$matrix$transform_in$$($text_p$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$))??""):""+($APP.$app$common$geom$matrix$transform_in$$($text_p$$,
$APP.$app$common$geom$matrix$rotate$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1083$$),-90))??""),children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$text_x$jscomp$2$$+18/$zoom$jscomp$111$$,y:$text_y$jscomp$2$$,width:$text_width$$-36/$zoom$jscomp$111$$,height:$text_height_vec__80695$$-5/$zoom$jscomp$111$$,rx:3/$zoom$jscomp$111$$,style:{cursor:"pointer"},opacity:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hovering_QMARK_$jscomp$4$$)?
!$small_QMARK__trackwidth$$:$hovering_QMARK_$jscomp$4$$)?.2:0,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-header-hover"}),$small_QMARK__trackwidth$$?null:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_x$jscomp$2$$,y:$text_y$jscomp$2$$,width:$text_width$$,height:$text_height_vec__80695$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{onContextMenu:$handle_show_track_menu$$,onPointerDown:$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__80698$$,onLostPointerCapture:$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$,
onPointerMove:$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__80698__$1$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("input",{ref:$track_input_ref$$,style:{},type:"text",defaultValue:$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data$$),"data-default-value":$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data$$),onKeyDown:$handle_keydown_track_input$$,onBlur:$handle_blur_track_input$$,
className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-label"}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hovering_QMARK_$jscomp$4$$)?!$medium_QMARK_$$&&!$small_QMARK__trackwidth$$:$hovering_QMARK_$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_show_track_menu$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-button",children:$APP.$app$main$ui$icons$menu$$}):null]})})]}),(0,$APP.$rumext$v2$jsx$$)("g",{transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$716$$,
$APP.$cljs$cst$1656$row$$)?"rotate(-90 "+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($marker_p$$)??"")+" "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($marker_p$$)??"")+")":null,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,{zoom:$zoom$jscomp$111$$,index:$index$jscomp$571$$,value:""+($index$jscomp$571$$+1??""),"track-before":$track_before$jscomp$3_track_list_prop$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$12$$,type:$type$jscomp$716$$,
"on-clear-modifiers":$on_clear_modifiers$jscomp$5_props_80691$$,"track-after":$track_data$$,center:$marker_p$$,"on-set-modifiers":$on_set_modifiers$jscomp$5$$,shape:$shape$jscomp$1083$$})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,{zoom:$zoom$jscomp$111$$,index:$index$jscomp$571$$,"track-before":$track_before$jscomp$3_track_list_prop$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$12$$,type:$type$jscomp$716$$,"on-clear-modifiers":$on_clear_modifiers$jscomp$5_props_80691$$,
"track-after":$track_data$$,"on-set-modifiers":$on_set_modifiers$jscomp$5$$,"start-p":$start_p$jscomp$18_vec__80692$$,shape:$shape$jscomp$1083$$,"layout-data":$layout_data$jscomp$22$$,"drop?":$drop_QMARK_$jscomp$2$$})]})}),$app$main$ui$workspace$viewport$grid_layout_editor$editor$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_80737_view_only$$){function $vv$jscomp$16$$($p1__80726_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$94$$,$p1__80726_SHARP_$$)}function $hv$jscomp$16$$($p1__80725_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$94$$,
$p1__80725_SHARP_$$)}var $base_shape$jscomp$1$$=$props_80737_view_only$$.shape,$objects$jscomp$815$$=$props_80737_view_only$$.objects,$modifiers$jscomp$130$$=$props_80737_view_only$$.modifiers,$zoom$jscomp$112$$=$props_80737_view_only$$.zoom;$props_80737_view_only$$=$props_80737_view_only$$["view-only"];var $st_modif$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$shape$jscomp$1084$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_shape$jscomp$1$$),
$APP.$rumext$v2$adapt$$($modifiers$jscomp$130$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($st_modif$$))],function(){var $G__80740__$1$$=$modifiers$jscomp$130$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($base_shape$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$130$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_shape$jscomp$1$$)),$APP.$cljs$cst$1810$modifiers$$)):
$base_shape$jscomp$1$$;return $APP.$cljs$core$_deref$$($st_modif$$)!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__80740__$1$$,$APP.$cljs$core$_deref$$($st_modif$$)):$G__80740__$1$$}),$snap_pixel_QMARK_$jscomp$13$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$snap_pixel_QMARK_$$),$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))],
function(){return $app$main$refs$workspace_grid_edition_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))});$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$=$APP.$rumext$v2$deref$$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$);var $hover_cells$$=$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$),
$selected_cells$jscomp$1$$=$APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$),$hover_columns$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80741$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80741$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80741$$,
1,null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80745$$){var $t$jscomp$100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80745$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80745$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($t$jscomp$100$$,$APP.$cljs$cst$216$column$$)},$APP.$cljs$cst$4409$hover_track$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$)))),
$hover_rows$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80750$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80750$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80750$$,1,null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80754$$){var $t$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80754$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80754$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($t$jscomp$101$$,$APP.$cljs$cst$1656$row$$)},$APP.$cljs$cst$4409$hover_track$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$)))),$bounds$jscomp$94$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$),$origin$jscomp$65$$=$APP.$app$common$geom$shapes$points$origin$$($bounds$jscomp$94$$),
$layout_data$jscomp$23$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1084$$),$APP.$rumext$v2$adapt$$($modifiers$jscomp$130$$)],function(){var $children$jscomp$312_objects__$1$jscomp$40$$=$APP.$app$common$geom$shapes$apply_objects_modifiers$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$815$$,$modifiers$jscomp$130$$),$children_bounds$jscomp$2_ids$jscomp$316$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$312_objects__$1$jscomp$40$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)),$objects__$2$jscomp$1$$=$app$common$geom$shapes$update_shapes_geometry$$($children$jscomp$312_objects__$1$jscomp$40$$,$APP.$cljs$core$reverse$$($children_bounds$jscomp$2_ids$jscomp$316$$));$children$jscomp$312_objects__$1$jscomp$40$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80727_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80727_SHARP_$$),
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)),$p1__80727_SHARP_$$],null)},$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects__$2$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1621$remove_hidden$$,!0],null)));$children_bounds$jscomp$2_ids$jscomp$316$$=$APP.$app$common$data$lazy_map$$($children_bounds$jscomp$2_ids$jscomp$316$$,
function($p1__80728_SHARP_$$){return $APP.$app$common$geom$shapes$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$2$jscomp$1$$,$p1__80728_SHARP_$$))});return $APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$1084$$,$bounds$jscomp$94$$,$children$jscomp$312_objects__$1$jscomp$40$$,$children_bounds$jscomp$2_ids$jscomp$316$$,$objects__$2$jscomp$1$$)});$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$=
$APP.$cljs$core$__destructure_map$$($layout_data$jscomp$23$$);var $row_tracks$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,$APP.$cljs$cst$3661$row_tracks$$),$column_tracks$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,$APP.$cljs$cst$3662$column_tracks$$),$column_total_size$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,$APP.$cljs$cst$3664$column_total_size$$),$column_total_gap$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,$APP.$cljs$cst$3665$column_total_gap$$),$row_total_size$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,
$APP.$cljs$cst$3669$row_total_size$$),$row_total_gap$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,$APP.$cljs$cst$3667$row_total_gap$$),$width$jscomp$233$$=function(){var $x__5110__auto__$jscomp$176$$=$APP.$app$common$geom$shapes$points$width_points$$($bounds$jscomp$94$$),$map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$1084$$);
var $JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$,$APP.$cljs$cst$1685$layout_padding_type$$);$map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$,
$APP.$cljs$cst$1686$layout_padding$$);var $map__47866__$1$jscomp$inline_9232_pad_left$jscomp$inline_9234$$=$APP.$cljs$core$__destructure_map$$($map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$);$map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47866__$1$jscomp$inline_9232_pad_left$jscomp$inline_9234$$,$APP.$cljs$cst$1091$p2$$);$map__47866__$1$jscomp$inline_9232_pad_left$jscomp$inline_9234$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47866__$1$jscomp$inline_9232_pad_left$jscomp$inline_9234$$,$APP.$cljs$cst$1688$p4$$);$JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1663$simple$$,$JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$)?$map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$+
$map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$:$map__47865__$1$jscomp$inline_9229_map__47866$jscomp$inline_9231_pad_right$jscomp$inline_9233$$+$map__47866__$1$jscomp$inline_9232_pad_left$jscomp$inline_9234$$;$JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$=$column_total_size$jscomp$2$$+$column_total_gap$jscomp$2$$+$JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$;
return $x__5110__auto__$jscomp$176$$>$JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$?$x__5110__auto__$jscomp$176$$:$JSCompiler_inline_result$jscomp$1536_layout_padding_type$jscomp$inline_9230_y__5111__auto__$jscomp$176$$}(),$height$jscomp$200$$=function(){var $x__5110__auto__$jscomp$177$$=$APP.$app$common$geom$shapes$points$height_points$$($bounds$jscomp$94$$),$map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$=
$APP.$cljs$core$__destructure_map$$($shape$jscomp$1084$$);var $JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$,$APP.$cljs$cst$1685$layout_padding_type$$);$map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$,
$APP.$cljs$cst$1686$layout_padding$$);var $map__47869__$1$jscomp$inline_9240_pad_bottom$jscomp$inline_9242$$=$APP.$cljs$core$__destructure_map$$($map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$);$map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47869__$1$jscomp$inline_9240_pad_bottom$jscomp$inline_9242$$,$APP.$cljs$cst$1093$p1$$);$map__47869__$1$jscomp$inline_9240_pad_bottom$jscomp$inline_9242$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47869__$1$jscomp$inline_9240_pad_bottom$jscomp$inline_9242$$,$APP.$cljs$cst$1687$p3$$);$JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1663$simple$$,$JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$)?$map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$+
$map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$:$map__47868__$1$jscomp$inline_9237_map__47869$jscomp$inline_9239_pad_top$jscomp$inline_9241$$+$map__47869__$1$jscomp$inline_9240_pad_bottom$jscomp$inline_9242$$;$JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$=$row_total_size$jscomp$2$$+$row_total_gap$jscomp$2$$+$JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$;
return $x__5110__auto__$jscomp$177$$>$JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$?$x__5110__auto__$jscomp$177$$:$JSCompiler_inline_result$jscomp$1535_layout_padding_type$jscomp$inline_9238_y__5111__auto__$jscomp$177$$}();$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$692$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$692$$)?
$APP.$app$util$dom$stop_propagation$$($event$jscomp$692$$):null});var $handle_add_column$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)],null),$APP.$cljs$cst$216$column$$,$APP.$app$common$types$shape$layout$default_track_value$$))}),$handle_add_row$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)],null),$APP.$cljs$cst$1656$row$$,$APP.$app$common$types$shape$layout$default_track_value$$))}),$target_tracks_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$drop_track_type_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$drop_track_target_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$handle_start_reorder_track$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout_data$jscomp$23$$)],function($type$jscomp$717$$){var $line_vec$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$717$$,$APP.$cljs$cst$216$column$$)?$vv$jscomp$16$$(1):$hv$jscomp$16$$(1),$last_point$jscomp$5_tracks$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$717$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($bounds$jscomp$94$$,
1):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($bounds$jscomp$94$$,3),$mid_points$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$717$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80729_SHARP_$$){return $APP.$app$common$geom$point$add$$($APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($p1__80729_SHARP_$$),$hv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p1__80729_SHARP_$$)/
2))},$APP.$cljs$cst$3662$column_tracks$$.$cljs$core$IFn$_invoke$arity$1$($layout_data$jscomp$23$$)):$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80730_SHARP_$$){return $APP.$app$common$geom$point$add$$($APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($p1__80730_SHARP_$$),$vv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p1__80730_SHARP_$$)/2))},$APP.$cljs$cst$3661$row_tracks$$.$cljs$core$IFn$_invoke$arity$1$($layout_data$jscomp$23$$));
$last_point$jscomp$5_tracks$jscomp$6$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($current$jscomp$60_p__80760$$){var $index$jscomp$572$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($current$jscomp$60_p__80760$$,0,null),$prev$jscomp$20_vec__80764$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($current$jscomp$60_p__80760$$,1,null);$current$jscomp$60_p__80760$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($prev$jscomp$20_vec__80764$$,0,null);
$prev$jscomp$20_vec__80764$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($prev$jscomp$20_vec__80764$$,1,null);return $prev$jscomp$20_vec__80764$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev$jscomp$20_vec__80764$$,$current$jscomp$60_p__80760$$,$line_vec$jscomp$1$$],null),$index$jscomp$572$$-1],null):null},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$with_prev$$($APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$origin$jscomp$65$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$mid_points$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$last_point$jscomp$5_tracks$jscomp$6$$],null)])))));$APP.$rumext$v2$set_ref_val_BANG_$$($target_tracks_STAR_$$,$last_point$jscomp$5_tracks$jscomp$6$$);return $APP.$cljs$core$reset_BANG_$$($drop_track_type_STAR_$$,$type$jscomp$717$$)}),$handle_move_reorder_track$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($_type$jscomp$3_index$jscomp$573$$,$_from_idx$jscomp$1$$,$position$jscomp$230$$){$_type$jscomp$3_index$jscomp$573$$=$APP.$cljs$core$second$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($line_2$jscomp$inline_9245_p__80767$$){var $v$jscomp$685_vec__80772$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($line_2$jscomp$inline_9245_p__80767$$,0,null),$p1$jscomp$86$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$685_vec__80772$$,
0,null),$p2$jscomp$67$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$685_vec__80772$$,1,null);$v$jscomp$685_vec__80772$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$685_vec__80772$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($line_2$jscomp$inline_9245_p__80767$$,1,null);$line_2$jscomp$inline_9245_p__80767$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p2$jscomp$67$$,$v$jscomp$685_vec__80772$$],
null);return $APP.$app$common$geom$line$line_value$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$86$$,$v$jscomp$685_vec__80772$$],null),$position$jscomp$230$$)*$APP.$app$common$geom$line$line_value$$($line_2$jscomp$inline_9245_p__80767$$,$position$jscomp$230$$)<0},$APP.$rumext$v2$ref_val$$($target_tracks_STAR_$$)));return $_type$jscomp$3_index$jscomp$573$$!=null?$APP.$cljs$core$reset_BANG_$$($drop_track_target_STAR_$$,$_type$jscomp$3_index$jscomp$573$$):
null}),$handle_end_reorder_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_shape$jscomp$1$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($drop_track_target_STAR_$$))],function($type$jscomp$718$$,$from_index$jscomp$13$$,$_position$jscomp$1_temp__5825__auto___80853$$,$move_content_QMARK_$jscomp$6$$){$_position$jscomp$1_temp__5825__auto___80853$$=$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$);if($APP.$cljs$core$truth_$$($_position$jscomp$1_temp__5825__auto___80853$$)){var $ids_80855$$=
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_shape$jscomp$1$$)],null);$from_index$jscomp$13$$<$_position$jscomp$1_temp__5825__auto___80853$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$reorder_layout_track$$($ids_80855$$,$type$jscomp$718$$,$from_index$jscomp$13$$,$_position$jscomp$1_temp__5825__auto___80853$$-1,$move_content_QMARK_$jscomp$6$$)):
$from_index$jscomp$13$$>$_position$jscomp$1_temp__5825__auto___80853$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$reorder_layout_track$$($ids_80855$$,$type$jscomp$718$$,$from_index$jscomp$13$$,$_position$jscomp$1_temp__5825__auto___80853$$-1,$move_content_QMARK_$jscomp$6$$))}$APP.$rumext$v2$set_ref_val_BANG_$$($target_tracks_STAR_$$,null);$APP.$cljs$core$reset_BANG_$$($drop_track_type_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($drop_track_target_STAR_$$,
null)}),$handle_set_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifier$jscomp$7$$){return $APP.$cljs$core$reset_BANG_$$($st_modif$$,$modifier$jscomp$7$$)}),$handle_clear_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($st_modif$$,null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)))}});
return $APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid-editor",pointerEvents:$APP.$cljs$core$truth_$$($props_80737_view_only$$)?"none":null,onPointerDown:$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__80739__$1$$,children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"cells",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$221$$,$cell$jscomp$48$$){$out_arr__44124__auto__$jscomp$221$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_cell$$,{zoom:$zoom$jscomp$112$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-set-modifiers":$handle_set_modifiers$$,shape:$base_shape$jscomp$1$$,"layout-data":$layout_data$jscomp$23$$,cell:$cell$jscomp$48$$,"selected?":$APP.$cljs$core$contains_QMARK_$$($selected_cells$jscomp$1$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$48$$)),"hover?":$APP.$cljs$core$contains_QMARK_$$($hover_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$48$$))},"cell-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$48$$)??"")));return $out_arr__44124__auto__$jscomp$221$$},[],$APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1084$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$1713$sort_QMARK_$$,!0],null)))}),$props_80737_view_only$$?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_editor_frame$$,{zoom:$zoom$jscomp$112$$,bounds:$bounds$jscomp$94$$,width:$width$jscomp$233$$,height:$height$jscomp$200$$}),function(){var $start_p$jscomp$19$$=$APP.$app$common$geom$point$add$$($origin$jscomp$65$$,$hv$jscomp$16$$($width$jscomp$233$$+30/$zoom$jscomp$112$$));return(0,$APP.$rumext$v2$jsx$$)("g",
{transform:""+($APP.$app$common$geom$matrix$transform_in$$($start_p$jscomp$19$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))??""),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$,{"start-p":$start_p$jscomp$19$$,zoom:$zoom$jscomp$112$$,type:$APP.$cljs$cst$216$column$$,"on-click":$handle_add_column$$})})}(),function(){var $start_p$jscomp$20$$=$APP.$app$common$geom$point$add$$($origin$jscomp$65$$,$vv$jscomp$16$$($height$jscomp$200$$+
30/$zoom$jscomp$112$$));return(0,$APP.$rumext$v2$jsx$$)("g",{transform:""+($APP.$app$common$geom$matrix$transform_in$$($start_p$jscomp$20$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$))??""),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$,{"start-p":$start_p$jscomp$20$$,zoom:$zoom$jscomp$112$$,type:$APP.$cljs$cst$1656$row$$,"on-click":$handle_add_row$$})})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$222$$,
$JSCompiler_temp_const$jscomp$1905_p__80777$$){var $JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1905_p__80777$$,0,null),$column_data$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1905_p__80777$$,1,null);$JSCompiler_temp_const$jscomp$1905_p__80777$$=$out_arr__44124__auto__$jscomp$222$$.push;var $drop_QMARK_$jscomp$inline_9248$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$,$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track$$,{zoom:$zoom$jscomp$112$$,"hovering?":$APP.$cljs$core$contains_QMARK_$$($hover_columns$$,$JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$),
index:$JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$216$column$$,"track-data":$column_data$jscomp$1$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-start-reorder-track":$handle_start_reorder_track$$,"on-set-modifiers":$handle_set_modifiers$$,"on-end-reorder-track":$handle_end_reorder_track$$,shape:$shape$jscomp$1084$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9248$$,"on-move-reorder-track":$handle_move_reorder_track$$},
"column-track-"+($JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$??""));$JSCompiler_temp_const$jscomp$1905_p__80777$$.call($out_arr__44124__auto__$jscomp$222$$,$JSCompiler_inline_result$jscomp$1907_idx$jscomp$137$$);return $out_arr__44124__auto__$jscomp$222$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($column_tracks$jscomp$6$$)),$APP.$cljs$core$empty_QMARK_$$($column_tracks$jscomp$6$$)?null:function(){var $JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$=
$APP.$cljs$core$last$$($column_tracks$jscomp$6$$),$JSCompiler_temp_const$jscomp$1908_marker_p$jscomp$1_start_p$jscomp$21$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$);$JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$=$APP.$app$common$geom$point$add$$($JSCompiler_temp_const$jscomp$1908_marker_p$jscomp$1_start_p$jscomp$21$$,$hv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$)));
$JSCompiler_temp_const$jscomp$1908_marker_p$jscomp$1_start_p$jscomp$21$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$94$$,$APP.$cljs$cst$1899$h$$,$JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$),$vv$jscomp$16$$(20/$zoom$jscomp$112$$));$JSCompiler_temp_const$jscomp$1908_marker_p$jscomp$1_start_p$jscomp$21$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,{zoom:$zoom$jscomp$112$$,
index:$APP.$cljs$core$count$$($column_tracks$jscomp$6$$),value:""+($APP.$cljs$core$count$$($column_tracks$jscomp$6$$)+1??""),"track-before":$APP.$cljs$core$last$$($column_tracks$jscomp$6$$),"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$216$column$$,"on-clear-modifiers":$handle_clear_modifiers$$,center:$JSCompiler_temp_const$jscomp$1908_marker_p$jscomp$1_start_p$jscomp$21$$,"on-set-modifiers":$handle_set_modifiers$$,shape:$shape$jscomp$1084$$});var $drop_QMARK_$jscomp$inline_9250$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($column_tracks$jscomp$6$$),$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,{zoom:$zoom$jscomp$112$$,index:$APP.$cljs$core$count$$($column_tracks$jscomp$6$$),
"last?":!0,"track-before":$APP.$cljs$core$last$$($column_tracks$jscomp$6$$),"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$216$column$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-set-modifiers":$handle_set_modifiers$$,"start-p":$JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$,shape:$shape$jscomp$1084$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9250$$});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"track",children:[$JSCompiler_temp_const$jscomp$1908_marker_p$jscomp$1_start_p$jscomp$21$$,
$JSCompiler_inline_result$jscomp$1909_end_p$jscomp$7_last_track$$]})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$223$$,$JSCompiler_temp_const$jscomp$1910_p__80783$$){var $JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1910_p__80783$$,0,null),$row_data$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1910_p__80783$$,
1,null);$JSCompiler_temp_const$jscomp$1910_p__80783$$=$out_arr__44124__auto__$jscomp$223$$.push;var $drop_QMARK_$jscomp$inline_9252$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$,$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track$$,
{zoom:$zoom$jscomp$112$$,"hovering?":$APP.$cljs$core$contains_QMARK_$$($hover_rows$$,$JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$),index:$JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$1656$row$$,"track-data":$row_data$jscomp$1$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-start-reorder-track":$handle_start_reorder_track$$,"on-set-modifiers":$handle_set_modifiers$$,"on-end-reorder-track":$handle_end_reorder_track$$,
shape:$shape$jscomp$1084$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9252$$,"on-move-reorder-track":$handle_move_reorder_track$$},"row-track-"+($JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$??""));$JSCompiler_temp_const$jscomp$1910_p__80783$$.call($out_arr__44124__auto__$jscomp$223$$,$JSCompiler_inline_result$jscomp$1912_idx$jscomp$138$$);return $out_arr__44124__auto__$jscomp$223$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($row_tracks$jscomp$6$$)),
$APP.$cljs$core$empty_QMARK_$$($row_tracks$jscomp$6$$)?null:function(){var $JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$=$APP.$cljs$core$last$$($row_tracks$jscomp$6$$),$JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$);$JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$=$APP.$app$common$geom$point$add$$($JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$,
$vv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$)));$JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$94$$,$APP.$cljs$cst$3670$v$$,$JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$),$hv$jscomp$16$$(20/$zoom$jscomp$112$$));$JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$=
(0,$APP.$rumext$v2$jsx$$)("g",{transform:"rotate(-90 "+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$)??"")+" "+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$)??"")+")",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,{zoom:$zoom$jscomp$112$$,index:$APP.$cljs$core$count$$($row_tracks$jscomp$6$$),
value:""+($APP.$cljs$core$count$$($row_tracks$jscomp$6$$)+1??""),"track-before":$APP.$cljs$core$last$$($row_tracks$jscomp$6$$),"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$1656$row$$,"on-clear-modifiers":$handle_clear_modifiers$$,center:$JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$,"on-set-modifiers":$handle_set_modifiers$$,shape:$shape$jscomp$1084$$})});var $drop_QMARK_$jscomp$inline_9254$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,
$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($row_tracks$jscomp$6$$),$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,{zoom:$zoom$jscomp$112$$,index:$APP.$cljs$core$count$$($row_tracks$jscomp$6$$),"last?":!0,"track-before":$APP.$cljs$core$last$$($row_tracks$jscomp$6$$),
"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$1656$row$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-set-modifiers":$handle_set_modifiers$$,"start-p":$JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$,shape:$shape$jscomp$1084$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9254$$});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"track",children:[$JSCompiler_temp_const$jscomp$1913_marker_p$jscomp$2_start_p$jscomp$22$$,$JSCompiler_inline_result$jscomp$1914_end_p$jscomp$8_last_track$jscomp$1$$]})}()]})]}):
null});var $app$main$ui$workspace$viewport$rulers$rulers$$=function($p1__80659_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__80659_SHARP_$$,function($new_props_80662$$,$old_props_80663$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80662$$.zoom,$old_props_80663$$.zoom)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80662$$.vbox,$old_props_80663$$.vbox)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80662$$["selected-shapes"],
$old_props_80663$$["selected-shapes"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80662$$["show-rulers?"],$old_props_80663$$["show-rulers?"])})}(function($props_80660_show_rulers_QMARK_$$){var $zoom$jscomp$115$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,"zoom"),$zoom_inverse$jscomp$8$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,"zoom-inverse"),$vbox$jscomp$48$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,
"vbox"),$offset_x$jscomp$15$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,"offset-x"),$offset_y$jscomp$15$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,"offset-y"),$selected_shapes$jscomp$33$$=$APP.$app$main$ui$hooks$use_equal_memo$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,"selected-shapes"));$props_80660_show_rulers_QMARK_$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80660_show_rulers_QMARK_$$,
"show-rulers?");var $selection_rect$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$33$$)],function(){return $APP.$app$common$data$not_empty_QMARK_$$($selected_shapes$jscomp$33$$)?$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($selected_shapes$jscomp$33$$):null});return $vbox$jscomp$48$$!=null?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"viewport-frame",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$viewport_frame_STAR_$$,
{showRulers:$props_80660_show_rulers_QMARK_$$,zoom:$zoom$jscomp$115$$,zoomInverse:$zoom_inverse$jscomp$8$$,vbox:$vbox$jscomp$48$$,offsetX:$offset_x$jscomp$15$$,offsetY:$offset_y$jscomp$15$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_80660_show_rulers_QMARK_$$)?$selection_rect$jscomp$1$$!=null:$props_80660_show_rulers_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$selection_area_STAR_$$,{zoom:$zoom$jscomp$115$$,zoomInverse:$zoom_inverse$jscomp$8$$,vbox:$vbox$jscomp$48$$,
selectionRect:$selection_rect$jscomp$1$$,offsetX:$offset_x$jscomp$15$$,offsetY:$offset_y$jscomp$15$$}):null]}):null});var $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$=function $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$($var_args$jscomp$1464$$){switch(arguments.length){case 2:return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($zoom$jscomp$119$$,$vbox$jscomp$53$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$,$zoom$jscomp$119$$,$vbox$jscomp$53$$)};
$app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$=function($rule_area_size_zoom$jscomp$120$$,$p__80721_x$jscomp$1285$$,$axis$jscomp$53_p__80722$$){var $height$jscomp$205_map__80723__$1_y2$jscomp$45$$=$APP.$cljs$core$__destructure_map$$($p__80721_x$jscomp$1285$$);$p__80721_x$jscomp$1285$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$205_map__80723__$1_y2$jscomp$45$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$509$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$205_map__80723__$1_y2$jscomp$45$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$238_x2$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$205_map__80723__$1_y2$jscomp$45$$,$APP.$cljs$cst$290$width$$);$height$jscomp$205_map__80723__$1_y2$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$205_map__80723__$1_y2$jscomp$45$$,$APP.$cljs$cst$1522$height$$);var $map__80724__$1_position$jscomp$232$$=$APP.$cljs$core$__destructure_map$$($axis$jscomp$53_p__80722$$);$axis$jscomp$53_p__80722$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80724__$1_position$jscomp$232$$,$APP.$cljs$cst$2054$axis$$);$map__80724__$1_position$jscomp$232$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80724__$1_position$jscomp$232$$,$APP.$cljs$cst$1676$position$$);$rule_area_size_zoom$jscomp$120$$=22/$rule_area_size_zoom$jscomp$120$$;$width$jscomp$238_x2$jscomp$43$$=$p__80721_x$jscomp$1285$$+$width$jscomp$238_x2$jscomp$43$$;$height$jscomp$205_map__80723__$1_y2$jscomp$45$$=$y$jscomp$509$$+
$height$jscomp$205_map__80723__$1_y2$jscomp$45$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$53_p__80722$$,$APP.$cljs$cst$1510$x$$)?$map__80724__$1_position$jscomp$232$$>=$p__80721_x$jscomp$1285$$+$rule_area_size_zoom$jscomp$120$$&&$map__80724__$1_position$jscomp$232$$<=$width$jscomp$238_x2$jscomp$43$$:$map__80724__$1_position$jscomp$232$$>=$y$jscomp$509$$+$rule_area_size_zoom$jscomp$120$$&&$map__80724__$1_position$jscomp$232$$<=$height$jscomp$205_map__80723__$1_y2$jscomp$45$$};
$app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$lang$maxFixedArity$=3;
var $app$main$ui$workspace$viewport$guides$guide_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($handle_change_position_props_80738$$){var $zoom$jscomp$122$$=$handle_change_position_props_80738$$.zoom,$vbox$jscomp$55$$=$handle_change_position_props_80738$$.vbox,$guide$jscomp$13$$=$handle_change_position_props_80738$$.guide,$frame_modifier$$=$handle_change_position_props_80738$$.frameModifier,$frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$=$handle_change_position_props_80738$$.getHoverFrame,
$on_guide_change$jscomp$1$$=$handle_change_position_props_80738$$.onGuideChange,$disabled_guides$$=$handle_change_position_props_80738$$.disabledGuides,$hover_frame_move_vec$jscomp$5$$=$handle_change_position_props_80738$$.hoverFrame,$is_hover$jscomp$2$$=$handle_change_position_props_80738$$.isHover,$frame_transform$$=$handle_change_position_props_80738$$.frameTransform,$on_guide_context_menu$$=$handle_change_position_props_80738$$.onGuideContextMenu,$axis$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide$jscomp$13$$,
$APP.$cljs$cst$2054$axis$$),$guide_color$$=function(){var $or__5025__auto__$jscomp$1326$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$13$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1326$$)?$or__5025__auto__$jscomp$1326$$:"#ff3277"}(),$read_only_QMARK_$jscomp$32$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$is_editing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$is_editing$jscomp$6$$=
$APP.$cljs$core$_deref$$($is_editing_STAR_$$),$input_ref$jscomp$13$$=(0,$APP.$rumext$v2$use_ref$$)(null);$handle_change_position_props_80738$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_guide_change$jscomp$1$$),$APP.$rumext$v2$adapt$$($guide$jscomp$13$$)],function($G__80758_changes$jscomp$334$$){return $APP.$cljs$core$truth_$$($on_guide_change$jscomp$1$$)?($G__80758_changes$jscomp$334$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$guide$jscomp$13$$,
$G__80758_changes$jscomp$334$$])),$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80758_changes$jscomp$334$$):$on_guide_change$jscomp$1$$($G__80758_changes$jscomp$334$$)):null});$frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$=$app$main$ui$workspace$viewport$guides$use_guide$$($handle_change_position_props_80738$$,$frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,$zoom$jscomp$122$$,
$guide$jscomp$13$$);$frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$);var $on_pointer_enter$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,$cljs$cst$5853$on_pointer_enter$$),$on_pointer_leave$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,
$cljs$cst$5851$on_pointer_leave$$),$on_pointer_down$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,$APP.$cljs$cst$4542$on_pointer_down$$),$on_pointer_up$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,$cljs$cst$5888$on_pointer_up$$),$on_lost_pointer_capture$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,
$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_pointer_move$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,$APP.$cljs$cst$4544$on_pointer_move$$),$state$jscomp$1216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,$APP.$cljs$cst$769$state$$);$frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$,
$APP.$cljs$cst$1606$frame$$);var $base_frame$jscomp$10$$=$APP.$cljs$core$truth_$$($frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$)?$frame$jscomp$88_get_hover_frame$jscomp$1_map__80749_map__80749__$1$$:$hover_frame_move_vec$jscomp$5$$,$frame__$1$jscomp$8$$=function(){var $G__80759__$1$$=$frame_modifier$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($base_frame$jscomp$10$$,$frame_modifier$$):$base_frame$jscomp$10$$;return $frame_transform$$!=
null?$APP.$app$common$geom$shapes$transforms$apply_transform$$($G__80759__$1$$,$frame_transform$$):$G__80759__$1$$}();$hover_frame_move_vec$jscomp$5$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$10$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$10$$)),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)));var $pos$jscomp$162$$=function(){var $or__5025__auto__$jscomp$1328$$=$cljs$cst$5887$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1216$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1328$$)?$or__5025__auto__$jscomp$1328$$:$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$13$$)}()+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hover_frame_move_vec$jscomp$5$$,
$axis$jscomp$55$$),$guide_width$$=1/$zoom$jscomp$122$$,$guide_pill_corner_radius$$=4/$zoom$jscomp$122$$,$frame_guide_outside_QMARK_$$=$frame__$1$jscomp$8$$!=null&&!$app$main$ui$workspace$viewport$guides$is_guide_inside_frame_QMARK_$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$13$$,$APP.$cljs$cst$1676$position$$,$pos$jscomp$162$$),$frame__$1$jscomp$8$$),$frame_offset$jscomp$9$$=$frame__$1$jscomp$8$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,
$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$):$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$):0,$accept_editing$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_offset$jscomp$9$$),$APP.$rumext$v2$adapt$$($on_guide_change$jscomp$1$$),$APP.$rumext$v2$adapt$$($guide$jscomp$13$$)],function(){var $G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$13$$);
return $APP.$cljs$core$truth_$$($G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$)&&($G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$))),$APP.$cljs$core$reset_BANG_$$($is_editing_STAR_$$,!1),$G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$!=null&&$on_guide_change$jscomp$1$$!=
null)?($G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$13$$,$APP.$cljs$cst$1676$position$$,$G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$+$frame_offset$jscomp$9$$),$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$):$on_guide_change$jscomp$1$$($G__80768_parsed$jscomp$9_temp__5825__auto__$jscomp$430$$)):
null}),$cancel_editing$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($is_editing_STAR_$$,!1)}),$on_input_key_down$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($accept_editing$$),$APP.$rumext$v2$adapt$$($cancel_editing$$)],function($event$jscomp$696$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$696$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$696$$),
$APP.$app$util$dom$stop_propagation$$($event$jscomp$696$$),$accept_editing$$.$cljs$core$IFn$_invoke$arity$0$?$accept_editing$$.$cljs$core$IFn$_invoke$arity$0$():$accept_editing$$()):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$696$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$696$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$696$$),$cancel_editing$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_editing$$.$cljs$core$IFn$_invoke$arity$0$():$cancel_editing$$()):
null}),$on_double_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$32$$)],function($event$jscomp$697$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$32$$))return null;$APP.$app$util$dom$stop_propagation$$($event$jscomp$697$$);return $APP.$cljs$core$reset_BANG_$$($is_editing_STAR_$$,!0)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$6$$)],function(){if($APP.$cljs$core$truth_$$($is_editing$jscomp$6$$)){var $G__80775$$=
$APP.$rumext$v2$ref_val$$($input_ref$jscomp$13$$);return $G__80775$$==null?null:$APP.$app$util$dom$select_text_BANG_$$($G__80775$$)}return null});return $frame__$1$jscomp$8$$==null||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$8$$,0))?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"guide-area",opacity:$frame_guide_outside_QMARK_$$?
0:null,children:[$APP.$cljs$core$truth_$$($disabled_guides$$)?null:function(){var $map__80776_x$jscomp$1286$$=$app$main$ui$workspace$viewport$guides$guide_area_axis$$($pos$jscomp$162$$,$vbox$jscomp$55$$,$zoom$jscomp$122$$,$frame__$1$jscomp$8$$,$axis$jscomp$55$$),$height$jscomp$206_map__80776__$1$$=$APP.$cljs$core$__destructure_map$$($map__80776_x$jscomp$1286$$);$map__80776_x$jscomp$1286$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$206_map__80776__$1$$,$APP.$cljs$cst$1510$x$$);
var $y$jscomp$510$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$206_map__80776__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$206_map__80776__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$206_map__80776__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$206_map__80776__$1$$,$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{onDoubleClick:$on_double_click$jscomp$5$$,
width:$width$jscomp$239$$,height:$height$jscomp$206_map__80776__$1$$,className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,$APP.$cljs$cst$1510$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",0),x:$map__80776_x$jscomp$1286$$,onPointerUp:$on_pointer_up$jscomp$5$$,onContextMenu:function($event$jscomp$698$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$698$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$698$$);
return $APP.$cljs$core$truth_$$($on_guide_context_menu$$)?$on_guide_context_menu$$.$cljs$core$IFn$_invoke$arity$2$?$on_guide_context_menu$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$698$$,$guide$jscomp$13$$):$on_guide_context_menu$$($event$jscomp$698$$,$guide$jscomp$13$$):null},style:{fill:"none",pointerEvents:$frame_guide_outside_QMARK_$$?"none":"fill"},onLostPointerCapture:$on_lost_pointer_capture$jscomp$10$$,y:$y$jscomp$510$$,onPointerMove:$on_pointer_move$jscomp$13$$,onPointerDown:$on_pointer_down$jscomp$16$$,
onPointerLeave:$on_pointer_leave$jscomp$14$$,onPointerEnter:$on_pointer_enter$jscomp$14$$})}(),$frame__$1$jscomp$8$$!=null?function(){var $l2_x1_map__80781$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5889$l2_x2$$,$cljs$cst$5890$l1_x2$$,$cljs$cst$5891$l3_x2$$,$cljs$cst$5892$l3_x1$$,$cljs$cst$5893$l1_y1$$,$cljs$cst$5894$l3_y1$$,$cljs$cst$5895$l3_y2$$,$cljs$cst$5896$l1_y2$$,$cljs$cst$5897$l2_x1$$,
$cljs$cst$5898$l1_x1$$,$cljs$cst$5899$l2_y2$$,$cljs$cst$5900$l2_y1$$],[$pos$jscomp$162$$,$pos$jscomp$162$$,$pos$jscomp$162$$,$pos$jscomp$162$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$pos$jscomp$162$$,$pos$jscomp$162$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)]):$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5889$l2_x2$$,$cljs$cst$5890$l1_x2$$,$cljs$cst$5891$l3_x2$$,$cljs$cst$5892$l3_x1$$,$cljs$cst$5893$l1_y1$$,
$cljs$cst$5894$l3_y1$$,$cljs$cst$5895$l3_y2$$,$cljs$cst$5896$l1_y2$$,$cljs$cst$5897$l2_x1$$,$cljs$cst$5898$l1_x1$$,$cljs$cst$5899$l2_y2$$,$cljs$cst$5900$l2_y1$$],[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$pos$jscomp$162$$,$pos$jscomp$162$$,$pos$jscomp$162$$,$pos$jscomp$162$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),$pos$jscomp$162$$,$pos$jscomp$162$$]);var $l3_y2_map__80781__$1$$=$APP.$cljs$core$__destructure_map$$($l2_x1_map__80781$$);
$l2_x1_map__80781$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5897$l2_x1$$);var $l1_x1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5898$l1_x1$$),$l2_y2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5899$l2_y2$$),$l2_y1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5900$l2_y1$$),$l2_x2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,
$cljs$cst$5889$l2_x2$$),$l1_x2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5890$l1_x2$$),$l3_x2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5891$l3_x2$$),$l3_x1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5892$l3_x1$$),$l1_y1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5893$l1_y1$$),$l1_y2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,
$cljs$cst$5896$l1_y2$$),$l3_y1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5894$l3_y1$$);$l3_y2_map__80781__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__80781__$1$$,$cljs$cst$5895$l3_y2$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?$is_hover$jscomp$2$$:$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1216$$)))?
(0,$APP.$rumext$v2$jsx$$)("line",{x1:$l1_x1$$,y1:$l1_y1$$,x2:$l1_x2$$,y2:$l1_y2$$,style:{stroke:$guide_color$$,strokeOpacity:1,strokeDasharray:["0, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(6/$zoom$jscomp$122$$)].join(""),strokeLinecap:"round",strokeWidth:$guide_width$$}}):null,(0,$APP.$rumext$v2$jsx$$)("line",{x1:$l2_x1_map__80781$$,y1:$l2_y1$$,x2:$l2_x2$$,y2:$l2_y2$$,style:{stroke:$guide_color$$,strokeWidth:$guide_width$$,strokeOpacity:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?
$is_hover$jscomp$2$$:$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1216$$)))?1:.7}}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?$is_hover$jscomp$2$$:$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1216$$)))?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$l3_x1$$,y1:$l3_y1$$,x2:$l3_x2$$,y2:$l3_y2_map__80781__$1$$,style:{stroke:$guide_color$$,strokeOpacity:1,strokeWidth:$guide_width$$,
strokeDasharray:["0, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(6/$zoom$jscomp$122$$)].join(""),strokeLinecap:"round"}}):null]})}():function(){var $map__80782_x1$jscomp$47$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1523$x1$$,$pos$jscomp$162$$,$APP.$cljs$cst$1524$y1$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),$APP.$cljs$cst$1525$x2$$,
$pos$jscomp$162$$,$APP.$cljs$cst$1526$y2$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1523$x1$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),$APP.$cljs$cst$1524$y1$$,$pos$jscomp$162$$,$APP.$cljs$cst$1525$x2$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),
$APP.$cljs$cst$1526$y2$$,$pos$jscomp$162$$],null);var $map__80782__$1_y2$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($map__80782_x1$jscomp$47$$);$map__80782_x1$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80782__$1_y2$jscomp$46$$,$APP.$cljs$cst$1523$x1$$);var $y1$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80782__$1_y2$jscomp$46$$,$APP.$cljs$cst$1524$y1$$),$x2$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80782__$1_y2$jscomp$46$$,
$APP.$cljs$cst$1525$x2$$);$map__80782__$1_y2$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80782__$1_y2$jscomp$46$$,$APP.$cljs$cst$1526$y2$$);return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__80782_x1$jscomp$47$$,y1:$y1$jscomp$49$$,x2:$x2$jscomp$44$$,y2:$map__80782__$1_y2$jscomp$46$$,style:{stroke:$guide_color$$,strokeWidth:$guide_width$$,strokeOpacity:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?$is_hover$jscomp$2$$:$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1216$$)))?
1:.7}})}(),$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$))return $is_hover$jscomp$2$$;var $or__5025__auto____$1$jscomp$148$$=$APP.$cljs$cst$2204$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1216$$));return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$148$$)?$or__5025__auto____$1$jscomp$148$$:$is_editing$jscomp$6$$}())?function(){var $map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$=15/$zoom$jscomp$122$$;var $guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$=
34/$zoom$jscomp$122$$,$guide_pill_height$jscomp$inline_9284_rect_width$jscomp$2$$=20/$zoom$jscomp$122$$;$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5901$rect_x$$,$pos$jscomp$162$$-$guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$/2,$cljs$cst$5902$rect_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+
$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$+-($guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$/2)+3/$zoom$jscomp$122$$,$cljs$cst$5903$rect_width$$,$guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$,$cljs$cst$5904$rect_height$$,$guide_pill_height$jscomp$inline_9284_rect_width$jscomp$2$$,$cljs$cst$5881$text_x$$,$pos$jscomp$162$$,$cljs$cst$5882$text_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$+
-(3/$zoom$jscomp$122$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5901$rect_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$+-($guide_pill_height$jscomp$inline_9284_rect_width$jscomp$2$$/2)+-(4/$zoom$jscomp$122$$),$cljs$cst$5902$rect_y$$,$pos$jscomp$162$$-$guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$/2,$cljs$cst$5903$rect_width$$,$guide_pill_height$jscomp$inline_9284_rect_width$jscomp$2$$,
$cljs$cst$5904$rect_height$$,$guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$,$cljs$cst$5881$text_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$+-(3/$zoom$jscomp$122$$),$cljs$cst$5882$text_y$$,$pos$jscomp$162$$],null);var $map__80787__$1_text_y$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$);$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80787__$1_text_y$jscomp$4$$,$cljs$cst$5901$rect_x$$);$guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80787__$1_text_y$jscomp$4$$,$cljs$cst$5902$rect_y$$);$guide_pill_height$jscomp$inline_9284_rect_width$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80787__$1_text_y$jscomp$4$$,$cljs$cst$5903$rect_width$$);var $rect_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80787__$1_text_y$jscomp$4$$,
$cljs$cst$5904$rect_height$$),$text_x$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80787__$1_text_y$jscomp$4$$,$cljs$cst$5881$text_x$$);$map__80787__$1_text_y$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80787__$1_text_y$jscomp$4$$,$cljs$cst$5882$text_y$$);var $display_value$jscomp$1$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($pos$jscomp$162$$-$frame_offset$jscomp$9$$),$input_w$$=34/$zoom$jscomp$122$$,$input_h$$=
20/$zoom$jscomp$122$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"guide-pill",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__80787_rect_x$jscomp$2_rulers_pos$jscomp$inline_9282$$,y:$guide_pill_width$jscomp$inline_9283_rect_y$jscomp$2$$,width:$guide_pill_height$jscomp$inline_9284_rect_width$jscomp$2$$,height:$rect_height$jscomp$2$$,rx:$guide_pill_corner_radius$$,ry:$guide_pill_corner_radius$$,style:{fill:$guide_color$$},onDoubleClick:$on_double_click$jscomp$5$$}),$APP.$cljs$core$truth_$$($is_editing$jscomp$6$$)?
(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_x$jscomp$4$$-$input_w$$/2,y:$map__80787__$1_text_y$jscomp$4$$-$input_h$$/2,width:$input_w$$,height:$input_h$$,transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,$APP.$cljs$cst$1511$y$$)?["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($text_x$jscomp$4$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80787__$1_text_y$jscomp$4$$),")"].join(""):null,children:(0,$APP.$rumext$v2$jsx$$)("input",
{style:{width:"100%",height:"100%",margin:0,fontFamily:"worksans",border:"none",padding:0,outline:"none",fontSize:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(12/$zoom$jscomp$122$$),"px"].join(""),MozAppearance:"textfield",background:"transparent",color:"#FFFFFF",textAlign:"center"},onBlur:$accept_editing$$,type:"number",ref:$input_ref$jscomp$13$$,onPointerDown:$APP.$app$util$dom$stop_propagation$$,defaultValue:$display_value$jscomp$1$$,onKeyDown:$on_input_key_down$jscomp$1$$,autoFocus:!0,
step:"any"})}):(0,$APP.$rumext$v2$jsx$$)("text",{x:$text_x$jscomp$4$$,y:$map__80787__$1_text_y$jscomp$4$$,textAnchor:"middle",dominantBaseline:"middle",transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55$$,$APP.$cljs$cst$1511$y$$)?["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($text_x$jscomp$4$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80787__$1_text_y$jscomp$4$$),")"].join(""):null,style:{fontSize:12/$zoom$jscomp$122$$,fontFamily:"worksans",
fill:"#FFFFFF"},children:$display_value$jscomp$1$$})]})}():null]}):null}),$app$main$ui$workspace$viewport$guides$viewport_guides_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($guides__$1$jscomp$2_props_80795$$){var $zoom$jscomp$124$$=$guides__$1$jscomp$2_props_80795$$.zoom,$vbox$jscomp$57$$=$guides__$1$jscomp$2_props_80795$$.vbox,$modifiers$jscomp$131$$=$guides__$1$jscomp$2_props_80795$$.modifiers,$guides$jscomp$10$$=$guides__$1$jscomp$2_props_80795$$.guides,$disabled_guides$jscomp$2$$=
$guides__$1$jscomp$2_props_80795$$.disabledGuides,$hover_frame$jscomp$1$$=$guides__$1$jscomp$2_props_80795$$.hoverFrame;$guides__$1$jscomp$2_props_80795$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guides$jscomp$10$$),$APP.$rumext$v2$adapt$$($vbox$jscomp$57$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$,
$zoom$jscomp$124$$,$vbox$jscomp$57$$),$APP.$cljs$core$vals$$($guides$jscomp$10$$))});var $focus$jscomp$19$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$hover_frame_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$get_hover_frame$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$ref_val$$($hover_frame_ref$$)}),$on_guide_change$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vbox$jscomp$57$$)],
function($guide$jscomp$15$$){return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$($zoom$jscomp$124$$,$vbox$jscomp$57$$,$guide$jscomp$15$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$update_guides$$($guide$jscomp$15$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$15$$))}),$on_guide_context_menu$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$699_position$jscomp$233$$,$guide$jscomp$16$$){$event$jscomp$699_position$jscomp$233$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$699_position$jscomp$233$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_guide_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$event$jscomp$699_position$jscomp$233$$,$APP.$cljs$cst$3848$guide$$,
$guide$jscomp$16$$],null)))}),$frame_modifiers$$=$APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$266$id$$,$modifiers$jscomp$131$$),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1289$transform$$,$APP.$cljs$core$first$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hover_frame$jscomp$1$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($hover_frame_ref$$,$hover_frame$jscomp$1$$)});return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"guides",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$,{vbox:$vbox$jscomp$57$$,zoom:$zoom$jscomp$124$$,axis:$APP.$cljs$cst$1510$x$$,getHoverFrame:$get_hover_frame$jscomp$3$$,disabledGuides:$disabled_guides$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$,{vbox:$vbox$jscomp$57$$,zoom:$zoom$jscomp$124$$,axis:$APP.$cljs$cst$1511$y$$,getHoverFrame:$get_hover_frame$jscomp$3$$,
disabledGuides:$disabled_guides$jscomp$2$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$225$$,$map__80804__$1_p__80803$$){$map__80804__$1_p__80803$$=$APP.$cljs$core$__destructure_map$$($map__80804__$1_p__80803$$);var $id$jscomp$1049$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80804__$1_p__80803$$,$APP.$cljs$cst$266$id$$),$frame_id$jscomp$150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80804__$1_p__80803$$,
$APP.$cljs$cst$1607$frame_id$$);$out_arr__44124__auto__$jscomp$225$$.push($frame_id$jscomp$150$$==null||$APP.$cljs$core$empty_QMARK_$$($focus$jscomp$19$$)||$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$19$$,$frame_id$jscomp$150$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_STAR_$$,{zoom:$zoom$jscomp$124$$,vbox:$vbox$jscomp$57$$,guide:$map__80804__$1_p__80803$$,getHoverFrame:$get_hover_frame$jscomp$3$$,disabledGuides:$disabled_guides$jscomp$2$$,onGuideChange:$on_guide_change$jscomp$3$$,
frameTransform:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_modifiers$$,$frame_id$jscomp$150$$),onGuideContextMenu:$on_guide_context_menu$jscomp$1$$},"guide-"+($id$jscomp$1049$$??"")):null);return $out_arr__44124__auto__$jscomp$225$$},[],$guides__$1$jscomp$2_props_80795$$)]})});var $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_80681$$,$app$main$data$workspace$grid_layout$shortcuts$shortcuts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$4792$escape$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$esc$$(),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["escape","enter","v"],null),$APP.$cljs$cst$516$fn$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$shortcuts$esc_pressed$$())}],null),$APP.$cljs$cst$4850$undo$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Z"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("z"),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$undo$$)}],
null),$APP.$cljs$cst$4822$redo$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Y"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("shift+z"),$APP.$app$main$data$shortcuts$c_mod$$("y")],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$redo$$)}],
null),$APP.$cljs$cst$4846$increase_zoom$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"+",$APP.$cljs$cst$1812$command$$,"+",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}],null),$APP.$cljs$cst$4841$decrease_zoom$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"-",$APP.$cljs$cst$1812$command$$,
"-",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}],null),$APP.$cljs$cst$4849$reset_zoom$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("0"),$APP.$cljs$cst$1812$command$$,"shift+0",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}],
null),$APP.$cljs$cst$4806$fit_all$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("1"),$APP.$cljs$cst$1812$command$$,"shift+1",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}],null),$APP.$cljs$cst$4856$zoom_selected$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("2"),
$APP.$cljs$cst$1812$command$$,"shift+2",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)}],null)],null);var $app$main$ui$workspace$viewport$outline$shape_outlines_render$$=function($p1__80713_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__80713_SHARP_$$,function($new_props_80715$$,$old_props_80716$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80715$$.shapes,$old_props_80716$$.shapes)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80715$$.zoom,$old_props_80716$$.zoom)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80715$$.modifiers,
$old_props_80716$$.modifiers)})}(function($props_80714$$){var $zoom$jscomp$129$$=$props_80714$$.zoom,$modifiers$jscomp$133$$=$props_80714$$.modifiers;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$226$$,$JSCompiler_inline_result$jscomp$1925_shape$jscomp$1087$$){var $JSCompiler_temp_const$jscomp$1923$$=$out_arr__44124__auto__$jscomp$226$$.push,$shape_id$jscomp$inline_9296$$=$JSCompiler_inline_result$jscomp$1925_shape$jscomp$1087$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1925_shape$jscomp$1087$$,
$APP.$cljs$cst$266$id$$),$modifier$jscomp$inline_9297$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$133$$,$shape_id$jscomp$inline_9296$$);$JSCompiler_inline_result$jscomp$1925_shape$jscomp$1087$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$outline$$,{shape:$JSCompiler_inline_result$jscomp$1925_shape$jscomp$1087$$,modifier:$modifier$jscomp$inline_9297$$,zoom:$zoom$jscomp$129$$},"outline-"+($shape_id$jscomp$inline_9296$$??""));$JSCompiler_temp_const$jscomp$1923$$.call($out_arr__44124__auto__$jscomp$226$$,
$JSCompiler_inline_result$jscomp$1925_shape$jscomp$1087$$);return $out_arr__44124__auto__$jscomp$226$$},[],$props_80714$$.shapes)});var $app$main$ui$workspace$viewport$interactions$interactions_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__80788_SHARP_$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4314$draw_interaction_to_frame$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80788_SHARP_$$,$APP.$cljs$cst$4314$draw_interaction_to_frame$$),$APP.$cljs$cst$4311$editing_interaction_index$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80788_SHARP_$$,
$APP.$cljs$cst$4311$editing_interaction_index$$),$APP.$cljs$cst$4318$move_overlay_index$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80788_SHARP_$$,$APP.$cljs$cst$4318$move_overlay_index$$),$APP.$cljs$cst$4317$move_overlay_to$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80788_SHARP_$$,$APP.$cljs$cst$4317$move_overlay_to$$),$APP.$cljs$cst$4313$draw_interaction_to$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80788_SHARP_$$,$APP.$cljs$cst$4313$draw_interaction_to$$)],
null)},$APP.$app$main$refs$workspace_local$$,$APP.$cljs$core$_EQ_$$);var $app$main$ui$workspace$viewport$pixel_overlay$get_offscreen_canvas$$=function(){var $internal_state$jscomp$4$$={canvas:null};return function($new_canvas_width$jscomp$245$$,$height$jscomp$212$$){var $canvas$jscomp$15$$=$internal_state$jscomp$4$$.canvas;if($APP.$cljs$core$truth_$$($canvas$jscomp$15$$)){var $resized$jscomp$inline_9311$$=$APP.$cljs$core$volatile_BANG_$$(!1);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($canvas$jscomp$15$$.width,$new_canvas_width$jscomp$245$$)||($APP.$app$util$object$set_BANG_$$($canvas$jscomp$15$$,
"width",$new_canvas_width$jscomp$245$$),$APP.$cljs$core$_vreset_BANG_$$($resized$jscomp$inline_9311$$,!0));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($canvas$jscomp$15$$.height,$height$jscomp$212$$)||($APP.$app$util$object$set_BANG_$$($canvas$jscomp$15$$,"height",$height$jscomp$212$$),$APP.$cljs$core$_vreset_BANG_$$($resized$jscomp$inline_9311$$,!0));return $canvas$jscomp$15$$}$new_canvas_width$jscomp$245$$=new OffscreenCanvas($new_canvas_width$jscomp$245$$,$height$jscomp$212$$);$APP.$app$util$object$set_BANG_$$($internal_state$jscomp$4$$,
"canvas",$new_canvas_width$jscomp$245$$);return $new_canvas_width$jscomp$245$$}}();var $app$main$ui$workspace$viewport$presence$session_cursor$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_80870_transform$jscomp$117_zoom$jscomp$135$$){var $fullname$jscomp$6_fullname__$1_profile$jscomp$78$$=$props_80870_transform$jscomp$117_zoom$jscomp$135$$.profile,$bg_color_session$jscomp$5$$=$props_80870_transform$jscomp$117_zoom$jscomp$135$$.session;$props_80870_transform$jscomp$117_zoom$jscomp$135$$=$props_80870_transform$jscomp$117_zoom$jscomp$135$$.zoom;var $point$jscomp$89$$=
$APP.$cljs$cst$2163$point$$.$cljs$core$IFn$_invoke$arity$1$($bg_color_session$jscomp$5$$);$bg_color_session$jscomp$5$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($bg_color_session$jscomp$5$$);$props_80870_transform$jscomp$117_zoom$jscomp$135$$="translate("+($point$jscomp$89$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$89$$,$APP.$cljs$cst$1510$x$$)??"")+", "+($point$jscomp$89$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$89$$,
$APP.$cljs$cst$1511$y$$)??"")+") scale("+1/$props_80870_transform$jscomp$117_zoom$jscomp$135$$+")";$fullname$jscomp$6_fullname__$1_profile$jscomp$78$$=$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($fullname$jscomp$6_fullname__$1_profile$jscomp$78$$);$fullname$jscomp$6_fullname__$1_profile$jscomp$78$$=$APP.$cljs$core$count$$($fullname$jscomp$6_fullname__$1_profile$jscomp$78$$)>16?""+($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($fullname$jscomp$6_fullname__$1_profile$jscomp$78$$,
0,12)??"")+"...":$fullname$jscomp$6_fullname__$1_profile$jscomp$78$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{transform:$props_80870_transform$jscomp$117_zoom$jscomp$135$$,className:"main_ui_workspace_viewport_presence__multiuser-cursor",children:[(0,$APP.$rumext$v2$jsx$$)("path",{fill:$bg_color_session$jscomp$5$$,d:"M11.58,-0.47L11.47,-0.35L0.34,10.77L0.30,10.96L-0.46,15.52L4.29,14.72L15.53,3.47L11.58,-0.47ZL11.58,-0.47ZL11.58,-0.47ZM11.58,1.3C12.31,2.05,13.02,2.742,13.76,3.47L4.0053,13.23C3.27,12.50,2.55,11.78,1.82,11.05L11.58,1.30ZL11.58,1.30ZM1.37,12.15L2.90,13.68L1.67,13.89L1.165,13.39L1.37,12.15ZL1.37,12.15Z"}),
(0,$APP.$rumext$v2$jsx$$)("g",{transform:"translate(17 -10)",children:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:-.3,y:-12.5,width:300,height:120,children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundColor:$bg_color_session$jscomp$5$$,color:"var(--app-white)"},className:"main_ui_workspace_viewport_presence__profile-name",children:$fullname$jscomp$6_fullname__$1_profile$jscomp$78$$})})})]})});var $app$main$ui$workspace$viewport$scroll_bars$viewport_scrollbars_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($bottom_padding_props_80882_show_h_scroll_QMARK_$$){function $on_pointer_up$jscomp$7$$(){$APP.$cljs$core$reset_BANG_$$($v_scrolling_QMARK_$$,!1);return $APP.$cljs$core$reset_BANG_$$($h_scrolling_QMARK_$$,!1)}function $on_pointer_down$jscomp$19$$($event$jscomp$712_start_pt$jscomp$4$$,$axis$jscomp$58$$){$event$jscomp$712_start_pt$jscomp$4$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$712_start_pt$jscomp$4$$);
var $new_v_scrollbar_y$jscomp$1_viewport_point$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$712_start_pt$jscomp$4$$),$new_h_scrollbar_x$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y$jscomp$1_viewport_point$$);$new_v_scrollbar_y$jscomp$1_viewport_point$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y$jscomp$1_viewport_point$$);var $v_scrollbar_y_padding$$=$v_scrollbar_y__$2$$-$new_v_scrollbar_y$jscomp$1_viewport_point$$,
$h_scrollbar_x_padding$$=$h_scrollbar_x__$2$$-$new_h_scrollbar_x$jscomp$1$$,$height_factor_vbox_rect$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1510$x$$,$vbox_x$jscomp$2$$,$APP.$cljs$cst$1511$y$$,$vbox_y$jscomp$2$$,$APP.$cljs$cst$1523$x1$$,$vbox_x$jscomp$2$$,$APP.$cljs$cst$1524$y1$$,$vbox_y$jscomp$2$$,$APP.$cljs$cst$1525$x2$$,$vbox_x$jscomp$2$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$),$APP.$cljs$cst$1526$y2$$,$vbox_y$jscomp$2$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$),
$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)],null),$containing_rect_width_factor$$=$APP.$app$common$geom$rect$join_rects$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_objects_rect$$,$height_factor_vbox_rect$$],null));$height_factor_vbox_rect$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($containing_rect_width_factor$$)/
$vbox_height$jscomp$2$$;$containing_rect_width_factor$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($containing_rect_width_factor$$)/$vbox_width$jscomp$2$$;$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$4$$,$event$jscomp$712_start_pt$jscomp$4$$);$APP.$rumext$v2$set_ref_val_BANG_$$($v_scrollbar_y_padding_ref$$,$v_scrollbar_y_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($h_scrollbar_x_padding_ref$$,$h_scrollbar_x_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($v_scrollbar_y_ref$$,
$new_v_scrollbar_y$jscomp$1_viewport_point$$+$v_scrollbar_y_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($h_scrollbar_x_ref$$,$new_h_scrollbar_x$jscomp$1$$+$h_scrollbar_x_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_y_ref$$,$vbox_y$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_x_ref$$,$vbox_x$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($scrollbar_height_ref$$,$scrollbar_height__$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($scrollbar_width_ref$$,$scrollbar_width__$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($height_factor_ref$$,
$height_factor_vbox_rect$$);$APP.$rumext$v2$set_ref_val_BANG_$$($width_factor_ref$$,$containing_rect_width_factor$$);$APP.$cljs$core$reset_BANG_$$($v_scrolling_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58$$,$APP.$cljs$cst$1511$y$$));return $APP.$cljs$core$reset_BANG_$$($h_scrolling_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58$$,$APP.$cljs$cst$1510$x$$))}function $on_pointer_move$jscomp$15$$($current_pt$jscomp$3_event$jscomp$711$$,
$axis$jscomp$57$$){var $new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$=function(){var $or__5025__auto__$jscomp$1348$$=$APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1348$$)?$or__5025__auto__$jscomp$1348$$:$APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$)}();if($APP.$cljs$core$truth_$$($new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$)){$new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$=
$APP.$rumext$v2$ref_val$$($start_ref$jscomp$4$$);$current_pt$jscomp$3_event$jscomp$711$$=$APP.$app$util$dom$get_client_position$$($current_pt$jscomp$3_event$jscomp$711$$);var $current_pt_viewport_new_h_scrollbar_x$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($current_pt$jscomp$3_event$jscomp$711$$),$y_delta$$=$APP.$rumext$v2$ref_val$$($height_factor_ref$$)*($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$jscomp$3_event$jscomp$711$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$))/
$zoom$jscomp$137$$,$x_delta$$=$APP.$rumext$v2$ref_val$$($width_factor_ref$$)*($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$jscomp$3_event$jscomp$711$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$))/$zoom$jscomp$137$$;$new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($current_pt_viewport_new_h_scrollbar_x$$)+$APP.$rumext$v2$ref_val$$($v_scrollbar_y_padding_ref$$);
$current_pt_viewport_new_h_scrollbar_x$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($current_pt_viewport_new_h_scrollbar_x$$)+$APP.$rumext$v2$ref_val$$($h_scrollbar_x_padding_ref$$);var $viewport_update$$=function(){var $G__80884$$=function(){var $G__80885$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$57$$,$APP.$cljs$cst$1511$y$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80885$$,$APP.$cljs$cst$1511$y$$,
function($p1__80876_SHARP_$$){return $p1__80876_SHARP_$$+$y_delta$$}):$G__80885$$}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$57$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80884$$,$APP.$cljs$cst$1510$x$$,function($p1__80877_SHARP_$$){return $p1__80877_SHARP_$$+$x_delta$$}):$G__80884$$}();$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_y_ref$$,$vbox_y$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_x_ref$$,$vbox_x$jscomp$2$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$viewport$update_viewport_position$$($viewport_update$$));$APP.$rumext$v2$set_ref_val_BANG_$$($v_scrollbar_y_ref$$,$new_v_scrollbar_y_start_pt$jscomp$3_temp__5825__auto__$jscomp$437$$);$APP.$rumext$v2$set_ref_val_BANG_$$($h_scrollbar_x_ref$$,$current_pt_viewport_new_h_scrollbar_x$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$4$$,$current_pt$jscomp$3_event$jscomp$711$$)}return null}var $zoom$jscomp$137$$=
$bottom_padding_props_80882_show_h_scroll_QMARK_$$.zoom,$objects$jscomp$824$$=$bottom_padding_props_80882_show_h_scroll_QMARK_$$.objects,$show_v_scroll_QMARK__vbox$jscomp$60$$=$bottom_padding_props_80882_show_h_scroll_QMARK_$$.vbox;$bottom_padding_props_80882_show_h_scroll_QMARK_$$=$bottom_padding_props_80882_show_h_scroll_QMARK_$$.bottomPadding;var $v_scrolling_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$h_scrolling_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$start_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null),$v_scrollbar_y_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$h_scrollbar_x_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$v_scrollbar_y_stored$$=$APP.$rumext$v2$ref_val$$($v_scrollbar_y_ref$$),$h_scrollbar_x_stored$$=$APP.$rumext$v2$ref_val$$($h_scrollbar_x_ref$$),$v_scrollbar_y_padding_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$h_scrollbar_x_padding_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$scrollbar_height_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$scrollbar_width_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$scrollbar_height_stored$$=$APP.$rumext$v2$ref_val$$($scrollbar_height_ref$$),$scrollbar_width_stored$$=$APP.$rumext$v2$ref_val$$($scrollbar_width_ref$$),$height_factor_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$width_factor_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$vbox_y_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$vbox_x_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$vbox_x$jscomp$2$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($show_v_scroll_QMARK__vbox$jscomp$60$$),
$vbox_y$jscomp$2$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($show_v_scroll_QMARK__vbox$jscomp$60$$),$base_objects_rect$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$824$$)],function(){return $APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$824$$,$APP.$app$common$uuid$zero$$,null))}),$vbox__$1$$=$bottom_padding_props_80882_show_h_scroll_QMARK_$$!=
null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($show_v_scroll_QMARK__vbox$jscomp$60$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$_$$,$bottom_padding_props_80882_show_h_scroll_QMARK_$$/$zoom$jscomp$137$$):$show_v_scroll_QMARK__vbox$jscomp$60$$,$inv_zoom$jscomp$2$$=1/$zoom$jscomp$137$$,$vbox_height$jscomp$2$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)-$inv_zoom$jscomp$2$$*14,$vbox_width$jscomp$2$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)-
$inv_zoom$jscomp$2$$*14,$top_offset$jscomp$2$$=function(){var $x__5110__auto__$jscomp$179$$=$vbox_y$jscomp$2$$-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$);return $x__5110__auto__$jscomp$179$$>0?$x__5110__auto__$jscomp$179$$:0}()*$vbox_height$jscomp$2$$/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$),$left_offset$jscomp$2$$=function(){var $x__5110__auto__$jscomp$180$$=$vbox_x$jscomp$2$$-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$);
return $x__5110__auto__$jscomp$180$$>0?$x__5110__auto__$jscomp$180$$:0}()*$vbox_width$jscomp$2$$/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$),$bottom_offset$jscomp$2$$=function(){var $x__5110__auto__$jscomp$181$$=$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$)-($vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$);return $x__5110__auto__$jscomp$181$$>0?$x__5110__auto__$jscomp$181$$:0}()*$vbox_height$jscomp$2$$/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$),
$right_offset$jscomp$1$$=function(){var $x__5110__auto__$jscomp$182$$=$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$)-($vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$);return $x__5110__auto__$jscomp$182$$>0?$x__5110__auto__$jscomp$182$$:0}()*$vbox_width$jscomp$2$$/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$);$show_v_scroll_QMARK__vbox$jscomp$60$$=function(){var $or__5025__auto__$jscomp$1346$$=$APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1346$$)?$or__5025__auto__$jscomp$1346$$:$top_offset$jscomp$2$$>0||$bottom_offset$jscomp$2$$>0}();$bottom_padding_props_80882_show_h_scroll_QMARK_$$=function(){var $or__5025__auto__$jscomp$1347$$=$APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1347$$)?$or__5025__auto__$jscomp$1347$$:$left_offset$jscomp$2$$>0||$right_offset$jscomp$1$$>0}();var $v_scrollbar_x$$=$vbox_x$jscomp$2$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)+
$inv_zoom$jscomp$2$$*-10,$v_scrollbar_y$$=$vbox_y$jscomp$2$$+$top_offset$jscomp$2$$,$h_scrollbar_x$$=$vbox_x$jscomp$2$$+$left_offset$jscomp$2$$,$h_scrollbar_y$$=$vbox_y$jscomp$2$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)+$inv_zoom$jscomp$2$$*-10,$scrollbar_height$$=$vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$-$bottom_offset$jscomp$2$$-$v_scrollbar_y$$,$scrollbar_height__$1$$=function(){var $x__5110__auto__$jscomp$183$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$))?
$scrollbar_height_stored$$:$scrollbar_height$$,$y__5111__auto__$jscomp$183$$=$inv_zoom$jscomp$2$$*100;return $x__5110__auto__$jscomp$183$$>$y__5111__auto__$jscomp$183$$?$x__5110__auto__$jscomp$183$$:$y__5111__auto__$jscomp$183$$}(),$scrollbar_width$$=$vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$-$right_offset$jscomp$1$$-$h_scrollbar_x$$,$scrollbar_width__$1$$=function(){var $x__5110__auto__$jscomp$184$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$))?$scrollbar_width_stored$$:
$scrollbar_width$$,$y__5111__auto__$jscomp$184$$=$inv_zoom$jscomp$2$$*100;return $x__5110__auto__$jscomp$184$$>$y__5111__auto__$jscomp$184$$?$x__5110__auto__$jscomp$184$$:$y__5111__auto__$jscomp$184$$}(),$h_scrollbar_x__$1_v_scrollbar_y__$1$$=function(){var $x__5110__auto__$jscomp$185$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$))?$v_scrollbar_y_stored$$- -($vbox_y$jscomp$2$$-$APP.$rumext$v2$ref_val$$($vbox_y_ref$$)):$v_scrollbar_y$$,$y__5111__auto__$jscomp$185$$=$vbox_y$jscomp$2$$+
$inv_zoom$jscomp$2$$*26;return $x__5110__auto__$jscomp$185$$>$y__5111__auto__$jscomp$185$$?$x__5110__auto__$jscomp$185$$:$y__5111__auto__$jscomp$185$$}(),$v_scrollbar_y__$2$$=$h_scrollbar_x__$1_v_scrollbar_y__$1$$+$scrollbar_height__$1$$>$vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$?$vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$-$scrollbar_height__$1$$:$h_scrollbar_x__$1_v_scrollbar_y__$1$$;$h_scrollbar_x__$1_v_scrollbar_y__$1$$=function(){var $x__5110__auto__$jscomp$186$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$))?
$h_scrollbar_x_stored$$- -($vbox_x$jscomp$2$$-$APP.$rumext$v2$ref_val$$($vbox_x_ref$$)):$h_scrollbar_x$$,$y__5111__auto__$jscomp$186$$=$vbox_x$jscomp$2$$+$inv_zoom$jscomp$2$$*26;return $x__5110__auto__$jscomp$186$$>$y__5111__auto__$jscomp$186$$?$x__5110__auto__$jscomp$186$$:$y__5111__auto__$jscomp$186$$}();var $h_scrollbar_x__$2$$=$h_scrollbar_x__$1_v_scrollbar_y__$1$$+$scrollbar_width__$1$$>$vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$?$vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$-$scrollbar_width__$1$$:
$h_scrollbar_x__$1_v_scrollbar_y__$1$$;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($show_v_scroll_QMARK__vbox$jscomp$60$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"v-scroll",fill:"#000000","data-testid":"vertical-scrollbar",children:(0,$APP.$rumext$v2$jsx$$)("rect",{width:$inv_zoom$jscomp$2$$*7,height:$scrollbar_height__$1$$,x:$v_scrollbar_x$$,onPointerUp:$on_pointer_up$jscomp$7$$,style:{stroke:"white",strokeWidth:.15/$zoom$jscomp$137$$},ry:$inv_zoom$jscomp$2$$*
3,rx:$inv_zoom$jscomp$2$$*3,y:$v_scrollbar_y__$2$$,onPointerMove:function($p1__80878_SHARP_$$){return $on_pointer_move$jscomp$15$$($p1__80878_SHARP_$$,$APP.$cljs$cst$1511$y$$)},fillOpacity:.4,onPointerDown:function($p1__80879_SHARP_$$){return $on_pointer_down$jscomp$19$$($p1__80879_SHARP_$$,$APP.$cljs$cst$1511$y$$)}})}):null,$APP.$cljs$core$truth_$$($bottom_padding_props_80882_show_h_scroll_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"h-scroll",fill:"#000000","data-testid":"horizontal-scrollbar",
children:(0,$APP.$rumext$v2$jsx$$)("rect",{width:$scrollbar_width__$1$$,height:$inv_zoom$jscomp$2$$*7,x:$h_scrollbar_x__$2$$,onPointerUp:$on_pointer_up$jscomp$7$$,style:{stroke:"white",strokeWidth:.15/$zoom$jscomp$137$$},ry:$inv_zoom$jscomp$2$$*3,rx:$inv_zoom$jscomp$2$$*3,y:$h_scrollbar_y$$,onPointerMove:function($p1__80880_SHARP_$$){return $on_pointer_move$jscomp$15$$($p1__80880_SHARP_$$,$APP.$cljs$cst$1510$x$$)},fillOpacity:.4,onPointerDown:function($p1__80881_SHARP_$$){return $on_pointer_down$jscomp$19$$($p1__80881_SHARP_$$,
$APP.$cljs$cst$1510$x$$)}})}):null]})});var $app$main$ui$workspace$viewport$snap_points$snap_points_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$){var $zoom$jscomp$159$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.zoom,$remove_snap$jscomp$2_selected$jscomp$207$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.selected,$objects$jscomp$827$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.objects,$layout$jscomp$28$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.layout,
$page_id$jscomp$455$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.pageId,$focus$jscomp$21$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.focus;$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$=$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$.drawing;var $frame_id$jscomp$154_shapes$jscomp$238$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$827$$)),
$remove_snap$jscomp$2_selected$jscomp$207$$),$filter_shapes$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($remove_snap$jscomp$2_selected$jscomp$207$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81010_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$827$$,$p1__81010_SHARP_$$)}),$remove_snap$jscomp$2_selected$jscomp$207$$),$remove_snap_base_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$28$$),
$APP.$rumext$v2$adapt$$($filter_shapes$jscomp$3$$),$APP.$rumext$v2$adapt$$($objects$jscomp$827$$),$APP.$rumext$v2$adapt$$($focus$jscomp$21$$)],function(){return $APP.$app$main$snap$make_remove_snap$$($layout$jscomp$28$$,$filter_shapes$jscomp$3$$,$objects$jscomp$827$$,$focus$jscomp$21$$)});$remove_snap$jscomp$2_selected$jscomp$207$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($remove_snap_base_QMARK_$$)],function($p__81014_type$jscomp$721$$){var $map__81015__$1_or__5025__auto__$jscomp$1352$$=
$APP.$cljs$core$__destructure_map$$($p__81014_type$jscomp$721$$);$p__81014_type$jscomp$721$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81015__$1_or__5025__auto__$jscomp$1352$$,$APP.$cljs$cst$139$type$$);var $grid$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81015__$1_or__5025__auto__$jscomp$1352$$,$APP.$cljs$cst$1659$grid$$);$map__81015__$1_or__5025__auto__$jscomp$1352$$=$remove_snap_base_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$remove_snap_base_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__81015__$1_or__5025__auto__$jscomp$1352$$):
$remove_snap_base_QMARK_$$($map__81015__$1_or__5025__auto__$jscomp$1352$$);return $APP.$cljs$core$truth_$$($map__81015__$1_or__5025__auto__$jscomp$1352$$)?$map__81015__$1_or__5025__auto__$jscomp$1352$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__81014_type$jscomp$721$$,$APP.$cljs$cst$1615$layout$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$20$$,$APP.$cljs$cst$1933$square$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__81014_type$jscomp$721$$,
$APP.$cljs$cst$3848$guide$$)});$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$=$APP.$cljs$core$truth_$$($drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$],null):$frame_id$jscomp$154_shapes$jscomp$238$$;$frame_id$jscomp$154_shapes$jscomp$238$$=$APP.$app$main$snap$snap_frame_id$$($drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$827$$,
$frame_id$jscomp$154_shapes$jscomp$238$$))?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_feedback_STAR_$$,{shapes:$drawing$jscomp$4_props_81011_shapes__$1$jscomp$39$$,pageId:$page_id$jscomp$455$$,removeSnap:$remove_snap$jscomp$2_selected$jscomp$207$$,zoom:$zoom$jscomp$159$$})});var $app$main$ui$workspace$viewport$path_actions$pentool_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__pentool-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pentool"})}),$app$main$ui$workspace$viewport$path_actions$move_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__move-icon main_ui_workspace_viewport_path_actions__pathbar-icon",
height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-move"})}),$app$main$ui$workspace$viewport$path_actions$add_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__add-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})}),$app$main$ui$workspace$viewport$path_actions$remove_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__remove main_ui_workspace_viewport_path_actions__pathbar-icon",
height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-remove"})}),$app$main$ui$workspace$viewport$path_actions$merge_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__merge-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-merge-nodes"})}),$app$main$ui$workspace$viewport$path_actions$join_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__join-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",
height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-join-nodes"})}),$app$main$ui$workspace$viewport$path_actions$separate_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__separate-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-separate-nodes"})}),$app$main$ui$workspace$viewport$path_actions$to_corner_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,
className:"main_ui_workspace_viewport_path_actions__to-corner-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-to-corner"})}),$app$main$ui$workspace$viewport$path_actions$to_curve_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__to-curve-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-to-curve"})}),
$app$main$ui$workspace$viewport$path_actions$snap_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__snap-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-snap-nodes"})});var $app$main$ui$workspace$viewport$widgets$selection_rect_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81022_zoom$jscomp$162$$){var $data$jscomp$506$$=$props_81022_zoom$jscomp$162$$.data;$props_81022_zoom$jscomp$162$$=$props_81022_zoom$jscomp$162$$.zoom;return $APP.$cljs$core$truth_$$($data$jscomp$506$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{className:"selection-rect",x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),
"data-testid":"workspace-selection-rect",width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),style:{fill:"var(--color-accent-tertiary-muted)",stroke:"var(--color-accent-tertiary)",strokeWidth:1/$props_81022_zoom$jscomp$162$$}}):null}),$app$main$ui$workspace$viewport$widgets$frame_title_STAR_$$,$p1__81023_SHARP_$jscomp$inline_9368$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$((0,$APP.$rumext$v2$forward_ref$$)(function($color$jscomp$205_is_selected$jscomp$11_props_81024$$,
$external_ref$jscomp$4_start_edit$jscomp$1$$){var $is_grid_edition$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.isGridEdition,$is_show_artboard_names$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.isShowArtboardNames,$zoom$jscomp$163$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.zoom,$is_show_id$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.isShowId,$on_frame_select$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.onFrameSelect,$frame$jscomp$95$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.frame,
$on_frame_enter$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.onFrameEnter,$on_frame_leave$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.onFrameLeave;$color$jscomp$205_is_selected$jscomp$11_props_81024$$=$color$jscomp$205_is_selected$jscomp$11_props_81024$$.isSelected;var $workspace_read_only_QMARK_$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$objects$jscomp$828$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);
$color$jscomp$205_is_selected$jscomp$11_props_81024$$=$APP.$cljs$core$truth_$$($color$jscomp$205_is_selected$jscomp$11_props_81024$$)?$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1353$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$828$$,$frame$jscomp$95$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1353$$)?$or__5025__auto__$jscomp$1353$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($frame$jscomp$95$$)}())?"var(--assets-component-hightlight)":
"var(--color-accent-tertiary)":"#8f9da3";var $blocked_QMARK_$jscomp$4$$=$APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$),$on_pointer_down$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$)),$APP.$rumext$v2$adapt$$($on_frame_select$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($blocked_QMARK_$jscomp$4$$)],
function($event$jscomp$717$$){var $G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$;if($G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$=$app$util$dom$left_mouse_QMARK_$$($event$jscomp$717$$))$G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$=($G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$=
$APP.$cljs$core$not$$($blocked_QMARK_$jscomp$4$$))?$G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$:$workspace_read_only_QMARK_$jscomp$2$$;return $APP.$cljs$core$truth_$$($G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$717$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$717$$),$G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$),$on_frame_select$$.$cljs$core$IFn$_invoke$arity$2$?$on_frame_select$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$717$$,$G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$):$on_frame_select$$($event$jscomp$717$$,$G__81026_JSCompiler_inline_result$jscomp$1942_and__5023__auto__$jscomp$inline_9363_or__5025__auto__$jscomp$inline_9364$$)):null}),$on_context_menu$jscomp$28$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame$jscomp$95$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$2$$)],function($bevent$jscomp$4_event$jscomp$718$$){$bevent$jscomp$4_event$jscomp$718$$=$bevent$jscomp$4_event$jscomp$718$$.nativeEvent;var $position$jscomp$241$$=$APP.$app$util$dom$get_client_position$$($bevent$jscomp$4_event$jscomp$718$$);$APP.$app$util$dom$prevent_default$$($bevent$jscomp$4_event$jscomp$718$$);$APP.$app$util$dom$stop_propagation$$($bevent$jscomp$4_event$jscomp$718$$);
return $APP.$cljs$core$truth_$$($workspace_read_only_QMARK_$jscomp$2$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$position$jscomp$241$$,$APP.$cljs$cst$1811$shape$$,$frame$jscomp$95$$],null)))}),$on_pointer_enter$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$)),
$APP.$rumext$v2$adapt$$($on_frame_enter$$)],function(){var $G__81027$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$);return $on_frame_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_enter$$.$cljs$core$IFn$_invoke$arity$1$($G__81027$$):$on_frame_enter$$($G__81027$$)}),$on_pointer_leave$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$)),$APP.$rumext$v2$adapt$$($on_frame_leave$$)],
function(){var $G__81028$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$);return $on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$($G__81028$$):$on_frame_leave$$($G__81028$$)}),$main_instance_QMARK_$jscomp$6$$=$APP.$app$common$types$component$main_instance_QMARK_$$($frame$jscomp$95$$),$is_variant_QMARK_$jscomp$5$$=$APP.$cljs$cst$2004$is_variant_container$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$),$text_width$jscomp$1$$=
($app$main$ui$workspace$viewport$utils$title_transform_use_width_QMARK_$$($frame$jscomp$95$$)?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$):$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$))*$zoom$jscomp$163$$,$show_icon_QMARK_$$=function(){var $and__5023__auto__$jscomp$957_or__5025__auto__$jscomp$inline_9366$$=$APP.$cljs$cst$2964$use_for_thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$);$and__5023__auto__$jscomp$957_or__5025__auto__$jscomp$inline_9366$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$957_or__5025__auto__$jscomp$inline_9366$$)?$and__5023__auto__$jscomp$957_or__5025__auto__$jscomp$inline_9366$$:$APP.$cljs$core$truth_$$($is_grid_edition$$)?$is_grid_edition$$:$main_instance_QMARK_$jscomp$6$$?$main_instance_QMARK_$jscomp$6$$:$is_variant_QMARK_$jscomp$5$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$957_or__5025__auto__$jscomp$inline_9366$$)?!($text_width$jscomp$1$$<=15):$and__5023__auto__$jscomp$957_or__5025__auto__$jscomp$inline_9366$$}(),
$text_pos_x$$=$APP.$cljs$core$truth_$$($show_icon_QMARK_$$)?15:0,$edition_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$edition_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($edition_STAR_$jscomp$2$$),$local_ref$jscomp$5_on_key_down$jscomp$28$$=(0,$APP.$rumext$v2$use_ref$$)(),$ref$jscomp$59$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($external_ref$jscomp$4_start_edit$jscomp$1$$,$local_ref$jscomp$5_on_key_down$jscomp$28$$),$frame_id$jscomp$155$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$);$external_ref$jscomp$4_start_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$155$$),$APP.$rumext$v2$adapt$$($edition_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($blocked_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$2$$)],function(){return $APP.$cljs$core$not$$($blocked_QMARK_$jscomp$4$$)&&$APP.$cljs$core$not$$($workspace_read_only_QMARK_$jscomp$2$$)?
$APP.$cljs$core$not$$($edition_QMARK_$jscomp$3$$)?$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$2$$,!0):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_rename_shape$$($frame_id$jscomp$155$$)):null});var $accept_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$155$$)],function(){var $name$jscomp$499$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($ref$jscomp$59$$)));
$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$2$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$155$$,$name$jscomp$499$$));return $on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$155$$):$on_frame_leave$$($frame_id$jscomp$155$$)}),$cancel_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$155$$)],
function(){$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$2$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$155$$,null));return $on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$155$$):$on_frame_leave$$($frame_id$jscomp$155$$)});$local_ref$jscomp$5_on_key_down$jscomp$28$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($accept_edit$jscomp$1$$),
$APP.$rumext$v2$adapt$$($cancel_edit$jscomp$1$$)],function($event$jscomp$719$$){$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$719$$))&&($accept_edit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$accept_edit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$accept_edit$jscomp$1$$());return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$719$$))?$cancel_edit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_edit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():
$cancel_edit$jscomp$1$$():null});return $APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$))?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"frame-title",id:"frame-title-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$)??""),"data-edit-grid":$is_grid_edition$$,transform:$APP.$app$main$ui$workspace$viewport$utils$title_transform$$($frame$jscomp$95$$,$zoom$jscomp$163$$,$is_grid_edition$$),pointerEvents:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$958$$=
$APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$958$$)?$APP.$cljs$core$not$$($workspace_read_only_QMARK_$jscomp$2$$):$and__5023__auto__$jscomp$958$$}())?"none":null,children:[$APP.$cljs$core$truth_$$($show_icon_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("svg",{x:0,y:-9,width:12,height:12,style:{stroke:$color$jscomp$205_is_selected$jscomp$11_props_81024$$,fill:"none"},visibility:$APP.$cljs$core$truth_$$($is_show_artboard_names$$)?
"visible":"hidden",className:"workspace-frame-icon",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$2964$use_for_thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$))?(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boards-thumbnail"}):$APP.$cljs$core$truth_$$($is_grid_edition$$)?(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid"}):$main_instance_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-component"}):$APP.$cljs$core$truth_$$($is_variant_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)("use",
{href:"#icon-component"}):null}):null,$edition_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_pos_x$$,y:-15,width:function(){var $y__5111__auto__$jscomp$189$$=$text_width$jscomp$1$$-$text_pos_x$$;return 0>$y__5111__auto__$jscomp$189$$?0:$y__5111__auto__$jscomp$189$$}(),height:22,style:{fill:$color$jscomp$205_is_selected$jscomp$11_props_81024$$},visibility:$APP.$cljs$core$truth_$$($is_show_artboard_names$$)?"visible":"hidden",className:"main_ui_workspace_viewport_widgets__frame-title-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",style:{color:$color$jscomp$205_is_selected$jscomp$11_props_81024$$},autoFocus:!0,onKeyDown:$local_ref$jscomp$5_on_key_down$jscomp$28$$,ref:$ref$jscomp$59$$,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$),onBlur:$accept_edit$jscomp$1$$,className:"main_ui_workspace_viewport_widgets__frame-title-label main_ui_workspace_viewport_widgets__frame-title-input"})}):(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_pos_x$$,
y:-11,width:function(){var $y__5111__auto__$jscomp$190$$=$text_width$jscomp$1$$-$text_pos_x$$;return 0>$y__5111__auto__$jscomp$190$$?0:$y__5111__auto__$jscomp$190$$}(),height:20,style:{fill:$color$jscomp$205_is_selected$jscomp$11_props_81024$$},visibility:$APP.$cljs$core$truth_$$($is_show_artboard_names$$)?"visible":"hidden",className:"main_ui_workspace_viewport_widgets__frame-title-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{onDoubleClick:$external_ref$jscomp$4_start_edit$jscomp$1$$,className:"main_ui_workspace_viewport_widgets__frame-title-label",
children:$APP.$cljs$core$truth_$$($is_show_id$$)?""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$)??"")+" - "+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$)??""):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$95$$),onContextMenu:$on_context_menu$jscomp$28$$,style:{color:$color$jscomp$205_is_selected$jscomp$11_props_81024$$},ref:$ref$jscomp$59$$,onPointerDown:$on_pointer_down$jscomp$20$$,onPointerLeave:$on_pointer_leave$jscomp$16$$,
onPointerEnter:$on_pointer_enter$jscomp$16$$})})]}):null}));$app$main$ui$workspace$viewport$widgets$frame_title_STAR_$$=$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__81023_SHARP_$jscomp$inline_9368$$,function($f$jscomp$651$$){return(0,$APP.$app$util$timers$request_animation_frame$$)($f$jscomp$651$$)});
var $app$main$ui$workspace$viewport$widgets$frame_titles_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$){var $is_show_artboard_names$jscomp$1$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.isShowArtboardNames,$zoom$jscomp$164$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.zoom,$selected$jscomp$208$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.selected,$on_frame_select$jscomp$1$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.onFrameSelect,
$on_frame_enter$jscomp$1$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.onFrameEnter,$objects$jscomp$829$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.objects,$on_frame_leave$jscomp$1$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.onFrameLeave,$focus$jscomp$22$$=$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$.focus,$selected__$1$jscomp$19$$=$APP.$cljs$core$truth_$$($selected$jscomp$208$$)?$selected$jscomp$208$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$=
$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$829$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2084$skip_copies_QMARK_$$,!0,$APP.$cljs$cst$2085$ignore_index_QMARK_$$,!0],null));$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$shape_titles$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$set$$($props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$829$$)),$selected__$1$jscomp$19$$):$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$;var $edition$jscomp$17$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$grid_edition_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$829$$,$edition$jscomp$17$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-titles blurrable",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$234$$,$JSCompiler_temp_const$jscomp$1943_p__81030$$){var $JSCompiler_temp$jscomp$1945_map__81031__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$1943_p__81030$$),$id$jscomp$1054$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1945_map__81031__$1$$,$APP.$cljs$cst$266$id$$),$JSCompiler_temp_const$jscomp$1947_parent_id$jscomp$108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1945_map__81031__$1$$,
$APP.$cljs$cst$1619$parent_id$$);$JSCompiler_temp_const$jscomp$1943_p__81030$$=$out_arr__44124__auto__$jscomp$234$$.push;if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1054$$,$APP.$app$common$uuid$zero$$)&&($APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$shape_titles$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1947_parent_id$jscomp$108$$,$APP.$app$common$uuid$zero$$))&&($APP.$cljs$core$empty_QMARK_$$($focus$jscomp$22$$)||
$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$22$$,$id$jscomp$1054$$))){$JSCompiler_temp_const$jscomp$1947_parent_id$jscomp$108$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$shape_titles$$);var $JSCompiler_temp_const$jscomp$1946$$=$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$19$$,$id$jscomp$1054$$),$and__5023__auto__$jscomp$inline_9370$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1054$$,$edition$jscomp$17$$);$JSCompiler_temp$jscomp$1945_map__81031__$1$$=
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_title_STAR_$$,{onFrameLeave:$on_frame_leave$jscomp$1$$,zoom:$zoom$jscomp$164$$,isShowArtboardNames:$is_show_artboard_names$jscomp$1$$,isShowId:$JSCompiler_temp_const$jscomp$1947_parent_id$jscomp$108$$,onFrameEnter:$on_frame_enter$jscomp$1$$,isSelected:$JSCompiler_temp_const$jscomp$1946$$,isGridEdition:$and__5023__auto__$jscomp$inline_9370$$?$grid_edition_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$inline_9370$$,frame:$JSCompiler_temp$jscomp$1945_map__81031__$1$$,
onFrameSelect:$on_frame_select$jscomp$1$$},"frame-title-"+($id$jscomp$1054$$??""))}else $JSCompiler_temp$jscomp$1945_map__81031__$1$$=null;$JSCompiler_temp_const$jscomp$1943_p__81030$$.call($out_arr__44124__auto__$jscomp$234$$,$JSCompiler_temp$jscomp$1945_map__81031__$1$$);return $out_arr__44124__auto__$jscomp$234$$},[],$props_81029_shapes$jscomp$239_shapes__$1$jscomp$40$$)})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$50$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$50$$,$cljs$cst$5930$webgl_unavailable$$,$app$main$ui$workspace$webgl_unavailable_modal$webgl_unavailable_modal_STAR_$$)});var $app$main$ui$workspace$workspace_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($layout$jscomp$34_props_81145$$){var $project_id$jscomp$37$$=$layout$jscomp$34_props_81145$$.projectId,$team_id$jscomp$147$$=$layout$jscomp$34_props_81145$$.teamId,$layout_name$$=$layout$jscomp$34_props_81145$$.layoutName,$page_id$jscomp$462_wglobal$jscomp$5$$=$layout$jscomp$34_props_81145$$.pageId,$file_id__$1$jscomp$12$$=$APP.$app$main$ui$hooks$use_equal_memo$$($layout$jscomp$34_props_81145$$.fileId),
$page_id__$1$jscomp$26$$=$APP.$app$main$ui$hooks$use_equal_memo$$($page_id$jscomp$462_wglobal$jscomp$5$$);$layout$jscomp$34_props_81145$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_layout$$);$page_id$jscomp$462_wglobal$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_global$$);var $permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$147$$)],function(){return $app$main$ui$workspace$make_team_ref$$($team_id$jscomp$147$$)}),
$file$jscomp$188_file_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$12$$)],function(){return $app$main$ui$workspace$make_file_ref$$($file_id__$1$jscomp$12$$)});$permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$=$APP.$rumext$v2$deref$$($permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$);$file$jscomp$188_file_ref$$=$APP.$rumext$v2$deref$$($file$jscomp$188_file_ref$$);var $file_loaded_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$188_file_ref$$,
$cljs$cst$5937$app_DOT_main_DOT_ui_DOT_workspace_SLASH_has_data$$),$file_name$jscomp$13$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$188_file_ref$$);$permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$);var $design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$38$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_read_only_QMARK_$$);
$permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$=$APP.$cljs$core$truth_$$($design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$38$$)?$design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$38$$:$APP.$cljs$core$not$$($APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$));$design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$38$$=$app$main$features$use_feature$$("design-tokens/v1");var $wasm_renderer_enabled_QMARK_$jscomp$1$$=
$app$main$features$use_feature$$("render-wasm/v1"),$first_frame_rendered_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$background_color$jscomp$4$$=$APP.$cljs$cst$3779$background_color$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$462_wglobal$jscomp$5$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$persistence$initialize_persistence$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$plugins$update_plugins_permissions_peek$$()]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout_name$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$initialize_workspace_layout$$($layout_name$$))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_name$jscomp$13$$)],
function(){return $APP.$cljs$core$truth_$$($file_name$jscomp$13$$)?$APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.workspace",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_name$jscomp$13$$]))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$147$$),$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$12$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$initialize_workspace$$($team_id$jscomp$147$$,
$file_id__$1$jscomp$12$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$finalize_workspace$$($team_id$jscomp$147$$,$file_id__$1$jscomp$12$$)]))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$12$$),$APP.$rumext$v2$adapt$$($page_id__$1$jscomp$26$$),
$APP.$rumext$v2$adapt$$($file_loaded_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($file_loaded_QMARK_$$)?$APP.$cljs$core$not$$($page_id__$1$jscomp$26$$):$file_loaded_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$file_id__$1$jscomp$12$$,$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$,
!0]))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$12$$),$APP.$rumext$v2$adapt$$($page_id__$1$jscomp$26$$)],function(){return $APP.$cljs$core$reset_BANG_$$($first_frame_rendered_QMARK_$$,!1)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $listener_key$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"penpot:wasm:render",function(){return $APP.$cljs$core$reset_BANG_$$($first_frame_rendered_QMARK_$$,
!0)});return function(){return $APP.$goog$events$unlistenByKey$$($listener_key$$)}});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_project_id$$),{value:$project_id$jscomp$37$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_file_id$$),{value:$file_id__$1$jscomp$12$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_page_id$$),{value:$page_id__$1$jscomp$26$$,
children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$design_tokens$$),{value:$design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$38$$,children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),{value:$permissions$jscomp$39_read_only_QMARK___$1_team$jscomp$59_team_ref$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,{}),(0,$APP.$rumext$v2$jsxs$$)("section",{style:{backgroundColor:$background_color$jscomp$4$$,
touchAction:"none",position:"relative"},className:"main_ui_workspace__workspace",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$context_menu_STAR_$$,{}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($file_loaded_QMARK_$$)?$page_id__$1$jscomp$26$$:$file_loaded_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_inner_STAR_$$,{pageId:$page_id__$1$jscomp$26$$,fileId:$file_id__$1$jscomp$12$$,file:$file$jscomp$188_file_ref$$,wglobal:$page_id$jscomp$462_wglobal$jscomp$5$$,
layout:$layout$jscomp$34_props_81145$$}):null,$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($file_loaded_QMARK_$$)?$page_id__$1$jscomp$26$$:$file_loaded_QMARK_$$)||$wasm_renderer_enabled_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($file_loaded_QMARK_$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($first_frame_rendered_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_loader_STAR_$$,{}):null]})]})})})})})});
//# sourceMappingURL=main-workspace.js.map
